-- phpMyAdmin SQL Dump
-- version 5.2.1
-- https://www.phpmyadmin.net/
--
-- Host: localhost
-- Tempo de geração: 13/01/2026 às 12:24
-- Versão do servidor: 10.6.22-MariaDB-0ubuntu0.22.04.1
-- Versão do PHP: 8.1.2-1ubuntu2.22

SET SQL_MODE = "NO_AUTO_VALUE_ON_ZERO";
START TRANSACTION;
SET time_zone = "+00:00";


/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8mb4 */;

--
-- Banco de dados: `officextream`
--

-- --------------------------------------------------------

--
-- Estrutura para tabela `active_connections`
--

CREATE TABLE `active_connections` (
  `id` int(11) NOT NULL,
  `user_id` int(11) NOT NULL,
  `username` varchar(100) DEFAULT NULL,
  `stream_id` int(11) DEFAULT 0,
  `stream_type` varchar(50) DEFAULT 'app_login',
  `content_name` varchar(255) DEFAULT 'Logado no App',
  `content_image` text DEFAULT NULL,
  `user_ip` varchar(50) DEFAULT NULL,
  `start_time` int(11) NOT NULL,
  `user_agent` text DEFAULT NULL,
  `content_id` int(11) DEFAULT 0
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

--
-- Despejando dados para a tabela `active_connections`
--

INSERT INTO `active_connections` (`id`, `user_id`, `username`, `stream_id`, `stream_type`, `content_name`, `content_image`, `user_ip`, `start_time`, `user_agent`, `content_id`) VALUES
(71, 38, 'kauafilho', 0, 'app_login', 'Logado no App', NULL, '5.223.49.52', 1768264033, 'axios/1.4.0', 0);

-- --------------------------------------------------------

--
-- Estrutura para tabela `adm`
--

CREATE TABLE `adm` (
  `id` int(11) NOT NULL,
  `username` varchar(50) NOT NULL,
  `password` varchar(255) NOT NULL,
  `chatbot_token` varchar(255) DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE=latin1_swedish_ci;

--
-- Despejando dados para a tabela `adm`
--

INSERT INTO `adm` (`id`, `username`, `password`, `chatbot_token`) VALUES
(1, 'admin', 'admin', '58101eb6cea628b2d81ec996da1019eb353f9ca5b7fef4c59090140c92831136');

-- --------------------------------------------------------

--
-- Estrutura para tabela `blocked_ips`
--

CREATE TABLE `blocked_ips` (
  `id` int(11) NOT NULL,
  `ip` varchar(50) NOT NULL,
  `notes` text DEFAULT NULL,
  `date` int(11) NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb3 COLLATE=utf8mb3_general_ci;

--
-- Despejando dados para a tabela `blocked_ips`
--

INSERT INTO `blocked_ips` (`id`, `ip`, `notes`, `date`) VALUES
(1, '185.177.72.49', 'Bloqueio Automático (Ataque DDoS/Flood)', 1767834546),
(2, '213.209.159.181', 'Bloqueio Automático (Ataque DDoS/Flood)', 1768257990);

-- --------------------------------------------------------

--
-- Estrutura para tabela `blocked_user_agents`
--

CREATE TABLE `blocked_user_agents` (
  `id` int(11) NOT NULL,
  `user_agent` varchar(255) NOT NULL,
  `description` text DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb3 COLLATE=utf8mb3_general_ci;

--
-- Despejando dados para a tabela `blocked_user_agents`
--

INSERT INTO `blocked_user_agents` (`id`, `user_agent`, `description`) VALUES
(1, 'curl', 'Bloqueio de ferramenta Curl'),
(2, 'python', 'Bloqueio de scripts Python'),
(3, 'wget', 'Bloqueio de Wget');

-- --------------------------------------------------------

--
-- Estrutura para tabela `bouquets`
--

CREATE TABLE `bouquets` (
  `id` int(11) NOT NULL,
  `name` varchar(255) NOT NULL,
  `bouq_channels` text DEFAULT '[]',
  `bouq_movies` text DEFAULT '[]',
  `bouq_series` text DEFAULT '[]'
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

--
-- Despejando dados para a tabela `bouquets`
--

INSERT INTO `bouquets` (`id`, `name`, `bouq_channels`, `bouq_movies`, `bouq_series`) VALUES
(1, 'Pacote | Completo', '[\"18\",\"6\",\"17\",\"5\",\"12\",\"11\",\"8\",\"2\",\"7\",\"3\",\"13\",\"14\",\"9\",\"16\",\"15\",\"99\",\"10\",\"4\",\"1\",\"19\"]', '[\"50\",\"80\",\"100\",\"101\",\"64\",\"61\",\"58\",\"84\",\"66\",\"54\",\"82\",\"56\",\"65\",\"57\",\"53\",\"55\",\"85\",\"103\",\"86\",\"52\",\"60\",\"59\",\"62\",\"83\",\"51\"]', '[\"63\",\"75\",\"71\",\"94\",\"79\",\"95\",\"77\",\"90\",\"87\",\"76\",\"78\",\"93\",\"92\",\"72\",\"73\",\"88\",\"67\",\"68\",\"70\",\"69\",\"97\",\"98\",\"81\",\"74\",\"89\",\"96\"]'),
(2, 'Pacote | Canais', '[\"18\",\"6\",\"17\",\"5\",\"12\",\"11\",\"8\",\"2\",\"7\",\"3\",\"13\",\"14\",\"9\",\"16\",\"15\",\"99\",\"10\",\"4\",\"1\",\"19\"]', '[]', '[]'),
(3, 'Pacote | Completo S/ Adultos', '[\"18\",\"6\",\"17\",\"5\",\"12\",\"11\",\"8\",\"2\",\"7\",\"3\",\"13\",\"14\",\"9\",\"16\",\"15\",\"99\",\"10\",\"4\",\"1\"]', '[\"50\",\"80\",\"100\",\"101\",\"64\",\"61\",\"58\",\"84\",\"66\",\"54\",\"82\",\"56\",\"65\",\"57\",\"53\",\"55\",\"85\",\"86\",\"52\",\"60\",\"59\",\"62\",\"83\"]', '[\"63\",\"75\",\"71\",\"94\",\"79\",\"95\",\"77\",\"90\",\"87\",\"76\",\"78\",\"93\",\"92\",\"72\",\"73\",\"88\",\"67\",\"68\",\"70\",\"69\",\"97\",\"98\",\"81\",\"74\",\"89\",\"96\"]');

-- --------------------------------------------------------

--
-- Estrutura para tabela `categories`
--

CREATE TABLE `categories` (
  `id` int(11) NOT NULL,
  `name` varchar(255) NOT NULL,
  `type` varchar(50) NOT NULL,
  `order_id` int(11) DEFAULT 0
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

--
-- Despejando dados para a tabela `categories`
--

INSERT INTO `categories` (`id`, `name`, `type`, `order_id`) VALUES
(1, 'Canais | Variedades', 'channel', 10),
(2, 'Canais | Filmes e Séries', 'channel', 9),
(3, 'Canais | HBO', 'channel', 7),
(4, 'Canais | Telecine', 'channel', 6),
(5, 'Canais | Cine SKY', 'channel', 8),
(6, 'Canais | Abertos', 'channel', 4),
(7, 'Canais | Globo', 'channel', 1),
(8, 'Canais | Esportes', 'channel', 11),
(9, 'Canais | Premiere', 'channel', 12),
(10, 'Canais | SporTV', 'channel', 13),
(11, 'Canais | ESPN', 'channel', 14),
(12, 'Canais | Documentários', 'channel', 15),
(13, 'Canais | Infantis', 'channel', 5),
(14, 'Canais | Notícias', 'channel', 16),
(15, 'Canais | Religiosos', 'channel', 17),
(16, 'Canais | Record TV', 'channel', 3),
(17, 'Canais | Band', 'channel', 2),
(18, 'Canais | 24 Horas', 'channel', 18),
(19, 'Canais | XXX Adultos', 'channel', 19),
(50, 'Canais | Filmes e Séries', 'movie', 5),
(51, 'Filmes | [XXX] Adultos', 'movie', 23),
(52, 'Filmes | Nacionais', 'movie', 6),
(53, 'Filmes | Ficcao', 'movie', 7),
(54, 'Filmes | Crime', 'movie', 8),
(55, 'Filmes | Guerra', 'movie', 9),
(56, 'Filmes | Família', 'movie', 4),
(57, 'Filmes | Faroeste', 'movie', 10),
(58, 'Filmes | Aventura', 'movie', 11),
(59, 'Filmes | Romance', 'movie', 12),
(60, 'Filmes | Religiosos', 'movie', 13),
(61, 'Filmes | Animacao', 'movie', 14),
(62, 'Filmes | Suspense', 'movie', 15),
(63, 'Filmes | Suspense', 'series', 6),
(64, 'Filmes | Acao', 'movie', 16),
(65, 'Filmes | Fantasia', 'movie', 17),
(66, 'Filmes | Comedia', 'movie', 18),
(67, 'Series | Max', 'series', 5),
(68, 'Series | Netflix', 'series', 0),
(69, 'Series | Paramount', 'series', 7),
(70, 'Series | Outras Produtoras', 'series', 9),
(71, 'Series | Amazon Prime Video', 'series', 1),
(72, 'Series | Globoplay', 'series', 2),
(73, 'Series | Legendadas', 'series', 10),
(74, 'Series | Star Plus', 'series', 3),
(75, 'Novelas', 'series', 11),
(76, 'Series | Discovery Plus', 'series', 4),
(77, 'Series | Claro video', 'series', 8),
(78, 'Series | Disney Plus', 'series', 12),
(79, 'Series | Apple TV Plus', 'series', 13),
(80, 'Filmes I Animacao²', 'movie', 19),
(81, 'Series | SBT', 'series', 14),
(82, 'Filmes | Drama', 'movie', 20),
(83, 'Filmes | Terror', 'movie', 21),
(84, 'Filmes | Cinema', 'movie', 0),
(85, 'Filmes | Lancamentos', 'movie', 2),
(86, 'Filmes | Legendados', 'movie', 22),
(87, 'Series | DirecTV', 'series', 15),
(88, 'Series | Lionsgate', 'series', 16),
(89, 'Series | Turcas', 'series', 17),
(90, 'Series | Crunchyroll', 'series', 18),
(92, 'Series | Funimation Now', 'series', 19),
(93, 'Series | Dorama', 'series', 20),
(94, 'Series | AMC Plus', 'series', 21),
(95, 'Series | Brasil Paralelo', 'series', 22),
(96, 'Series | Univer', 'series', 23),
(97, 'Series | Play Plus', 'series', 24),
(98, 'Series | PlutoTV', 'series', 25),
(99, 'Canais | SBT', 'channel', 0),
(100, 'Filmes I Diversos', 'movie', 3),
(101, 'Filmes I Lancamentos 2025', 'movie', 1),
(102, 'Filmes I Teste 2', 'movie', 0),
(103, 'FILMES | LANÇAMENTOS 2025', 'movie', 0);

-- --------------------------------------------------------

--
-- Estrutura para tabela `channels`
--

CREATE TABLE `channels` (
  `id` int(11) NOT NULL,
  `category_id` int(11) DEFAULT 0,
  `name` varchar(255) NOT NULL,
  `stream_url` text NOT NULL,
  `logo_url` text DEFAULT NULL,
  `epg_id` varchar(255) DEFAULT NULL,
  `pid` int(11) DEFAULT 0,
  `running` tinyint(1) DEFAULT 0,
  `transcode_quality` varchar(20) DEFAULT 'original',
  `uptime` datetime DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

--
-- Despejando dados para a tabela `channels`
--

INSERT INTO `channels` (`id`, `category_id`, `name`, `stream_url`, `logo_url`, `epg_id`, `pid`, `running`, `transcode_quality`, `uptime`) VALUES
(1, 1, 'A&E FHD', 'http://sinalprivado.info:80/1533784/1533784/12000', 'http://www.fontedecanais.tv/logos/canais/ae.png', 'Ae.br', 0, 0, 'original', NULL),
(2, 1, 'A&E HD', 'http://sinalprivado.info:80/1533784/1533784/12001', 'http://www.fontedecanais.tv/logos/canais/ae.png', 'Ae.br', 0, 0, 'original', NULL),
(3, 1, 'A&E SD', 'http://sinalprivado.info:80/1533784/1533784/12002', 'http://www.fontedecanais.tv/logos/canais/ae.png', 'Ae.br', 0, 0, 'original', NULL),
(4, 1, 'BIS FHD', 'http://sinalprivado.info:80/1533784/1533784/12003', 'http://www.fontedecanais.tv/logos/canais/bis.png', 'Bis.br', 0, 0, 'original', NULL),
(5, 1, 'BIS HD', 'http://sinalprivado.info:80/1533784/1533784/12004', 'http://www.fontedecanais.tv/logos/canais/bis.png', 'Bis.br', 0, 0, 'original', NULL),
(6, 1, 'BIS SD', 'http://sinalprivado.info:80/1533784/1533784/12005', 'http://www.fontedecanais.tv/logos/canais/bis.png', 'Bis.br', 0, 0, 'original', NULL),
(7, 1, 'Discovery H&H FHD', 'http://sinalprivado.info:80/1533784/1533784/12012', 'http://www.fontedecanais.tv/logos/canais/discoveryhh.png', NULL, 0, 0, 'original', NULL),
(8, 1, 'Discovery H&H HD', 'http://sinalprivado.info:80/1533784/1533784/12013', 'http://www.fontedecanais.tv/logos/canais/discoveryhh.png', NULL, 0, 0, 'original', NULL),
(9, 1, 'Discovery H&H SD', 'http://sinalprivado.info:80/1533784/1533784/12014', 'http://www.fontedecanais.tv/logos/canais/discoveryhh.png', NULL, 0, 0, 'original', NULL),
(10, 1, 'Discovery Turbo FHD', 'http://sinalprivado.info:80/1533784/1533784/12015', 'http://www.fontedecanais.tv/logos/canais/discoveryturbo.png', 'Discovery Turbo FHD H.265', 0, 0, 'original', NULL),
(11, 1, 'Discovery Turbo HD', 'http://sinalprivado.info:80/1533784/1533784/12016', 'http://www.fontedecanais.tv/logos/canais/discoveryturbo.png', 'Discovery Turbo FHD H.265', 0, 0, 'original', NULL),
(12, 1, 'Discovery Turbo SD', 'http://sinalprivado.info:80/1533784/1533784/12017', 'http://www.fontedecanais.tv/logos/canais/discoveryturbo.png', 'Discovery Turbo FHD H.265', 0, 0, 'original', NULL),
(13, 1, 'E! FHD', 'http://sinalprivado.info:80/1533784/1533784/12018', 'http://www.fontedecanais.tv/logos/canais/e.png', 'E.br', 0, 0, 'original', NULL),
(14, 1, 'E! HD', 'http://sinalprivado.info:80/1533784/1533784/12019', 'http://www.fontedecanais.tv/logos/canais/e.png', 'E.br', 0, 0, 'original', NULL),
(15, 1, 'E! SD', 'http://sinalprivado.info:80/1533784/1533784/12020', 'http://www.fontedecanais.tv/logos/canais/e.png', 'E.br', 0, 0, 'original', NULL),
(16, 1, 'FishTV FHD', 'http://sinalprivado.info:80/1533784/1533784/12021', 'http://www.fontedecanais.tv/logos/canais/fishtv.png', 'Fishtv.br', 0, 0, 'original', NULL),
(17, 1, 'FishTV HD', 'http://sinalprivado.info:80/1533784/1533784/12022', 'http://www.fontedecanais.tv/logos/canais/fishtv.png', 'Fishtv.br', 0, 0, 'original', NULL),
(18, 1, 'FishTV SD', 'http://sinalprivado.info:80/1533784/1533784/12023', 'http://www.fontedecanais.tv/logos/canais/fishtv.png', 'Fishtv.br', 0, 0, 'original', NULL),
(19, 1, 'Food Network FHD', 'http://sinalprivado.info:80/1533784/1533784/12024', 'http://www.fontedecanais.tv/logos/canais/foodnetwork.png', 'Foodnetworkhd.br', 0, 0, 'original', NULL),
(20, 1, 'Food Network HD', 'http://sinalprivado.info:80/1533784/1533784/12025', 'http://www.fontedecanais.tv/logos/canais/foodnetwork.png', 'Foodnetworkhd.br', 0, 0, 'original', NULL),
(21, 1, 'Food Network SD', 'http://sinalprivado.info:80/1533784/1533784/12026', 'http://www.fontedecanais.tv/logos/canais/foodnetwork.png', 'Foodnetworkhd.br', 0, 0, 'original', NULL),
(22, 1, 'GNT FHD', 'http://sinalprivado.info:80/1533784/1533784/12027', 'http://www.fontedecanais.tv/logos/canais/gnt.png', 'Gnthd.br', 0, 0, 'original', NULL),
(23, 1, 'GNT HD', 'http://sinalprivado.info:80/1533784/1533784/12028', 'http://www.fontedecanais.tv/logos/canais/gnt.png', 'Gnthd.br', 0, 0, 'original', NULL),
(24, 1, 'GNT SD', 'http://sinalprivado.info:80/1533784/1533784/12029', 'http://www.fontedecanais.tv/logos/canais/gnt.png', 'Gnthd.br', 0, 0, 'original', NULL),
(25, 1, 'Lifetime FHD', 'http://sinalprivado.info:80/1533784/1533784/12030', 'http://www.fontedecanais.tv/logos/canais/lifetime.png', 'Lifetime.br', 0, 0, 'original', NULL),
(26, 1, 'Lifetime HD', 'http://sinalprivado.info:80/1533784/1533784/12031', 'http://www.fontedecanais.tv/logos/canais/lifetime.png', 'Lifetime.br', 0, 0, 'original', NULL),
(27, 1, 'Lifetime SD', 'http://sinalprivado.info:80/1533784/1533784/12032', 'http://www.fontedecanais.tv/logos/canais/lifetime.png', 'Lifetime.br', 0, 0, 'original', NULL),
(28, 1, 'Modo Viagem FHD', 'http://sinalprivado.info:80/1533784/1533784/12033', 'http://www.fontedecanais.tv/logos/canais/modoviagem.png', NULL, 0, 0, 'original', NULL),
(29, 1, 'Modo Viagem HD', 'http://sinalprivado.info:80/1533784/1533784/12034', 'http://www.fontedecanais.tv/logos/canais/modoviagem.png', NULL, 0, 0, 'original', NULL),
(30, 1, 'Modo Viagem SD', 'http://sinalprivado.info:80/1533784/1533784/12035', 'http://www.fontedecanais.tv/logos/canais/modoviagem.png', NULL, 0, 0, 'original', NULL),
(31, 1, 'Trace Brasil FHD', 'http://sinalprivado.info:80/1533784/1533784/12039', 'http://www.fontedecanais.tv/logos/canais/tracebrasil.png', NULL, 0, 0, 'original', NULL),
(32, 1, 'Trace Brasil HD', 'http://sinalprivado.info:80/1533784/1533784/12040', 'http://www.fontedecanais.tv/logos/canais/tracebrasil.png', NULL, 0, 0, 'original', NULL),
(33, 1, 'Trace Brasil SD', 'http://sinalprivado.info:80/1533784/1533784/12041', 'http://www.fontedecanais.tv/logos/canais/tracebrasil.png', NULL, 0, 0, 'original', NULL),
(34, 1, 'Multishow FHD', 'http://sinalprivado.info:80/1533784/1533784/12045', 'http://www.fontedecanais.tv/logos/canais/multishow.png', 'Multishow.br', 0, 0, 'original', NULL),
(35, 1, 'Multishow HD', 'http://sinalprivado.info:80/1533784/1533784/12046', 'http://www.fontedecanais.tv/logos/canais/multishow.png', 'Multishow.br', 0, 0, 'original', NULL),
(36, 1, 'Multishow SD', 'http://sinalprivado.info:80/1533784/1533784/12047', 'http://www.fontedecanais.tv/logos/canais/multishow.png', 'Multishow.br', 0, 0, 'original', NULL),
(37, 1, 'Off FHD', 'http://sinalprivado.info:80/1533784/1533784/12048', 'http://www.fontedecanais.tv/logos/canais/off.png', 'Off.br', 0, 0, 'original', NULL),
(38, 1, 'Off HD', 'http://sinalprivado.info:80/1533784/1533784/12049', 'http://www.fontedecanais.tv/logos/canais/off.png', 'Off.br', 0, 0, 'original', NULL),
(39, 1, 'Off SD', 'http://sinalprivado.info:80/1533784/1533784/12050', 'http://www.fontedecanais.tv/logos/canais/off.png', 'Off.br', 0, 0, 'original', NULL),
(40, 1, 'TLC FHD', 'http://sinalprivado.info:80/1533784/1533784/12051', 'http://www.fontedecanais.tv/logos/canais/tlc.png', 'Tlc.br', 0, 0, 'original', NULL),
(41, 1, 'TLC HD', 'http://sinalprivado.info:80/1533784/1533784/12052', 'http://www.fontedecanais.tv/logos/canais/tlc.png', 'Tlc.br', 0, 0, 'original', NULL),
(42, 1, 'TLC SD', 'http://sinalprivado.info:80/1533784/1533784/12053', 'http://www.fontedecanais.tv/logos/canais/tlc.png', 'Tlc.br', 0, 0, 'original', NULL),
(43, 1, 'Travel Box Brazil FHD', 'http://sinalprivado.info:80/1533784/1533784/12054', 'http://www.fontedecanais.tv/logos/canais/travelboxbrazil.png', NULL, 0, 0, 'original', NULL),
(44, 1, 'Travel Box Brazil HD', 'http://sinalprivado.info:80/1533784/1533784/12055', 'http://www.fontedecanais.tv/logos/canais/travelboxbrazil.png', NULL, 0, 0, 'original', NULL),
(45, 1, 'Travel Box Brazil SD', 'http://sinalprivado.info:80/1533784/1533784/12056', 'http://www.fontedecanais.tv/logos/canais/travelboxbrazil.png', NULL, 0, 0, 'original', NULL),
(46, 1, 'Adult Swim FHD', 'http://sinalprivado.info:80/1533784/1533784/12057', 'http://www.fontedecanais.tv/logos/canais/adultswim.png', NULL, 0, 0, 'original', NULL),
(47, 1, 'Adult Swim HD', 'http://sinalprivado.info:80/1533784/1533784/12058', 'http://www.fontedecanais.tv/logos/canais/adultswim.png', NULL, 0, 0, 'original', NULL),
(48, 1, 'Adult Swim SD', 'http://sinalprivado.info:80/1533784/1533784/12059', 'http://www.fontedecanais.tv/logos/canais/adultswim.png', NULL, 0, 0, 'original', NULL),
(49, 1, 'Globoplay Novelas FHD', 'http://sinalprivado.info:80/1533784/1533784/12060', 'http://www.fontedecanais.tv/logos/canais/globoplaynovelas.png', NULL, 0, 0, 'original', NULL),
(50, 1, 'Globoplay Novelas HD', 'http://sinalprivado.info:80/1533784/1533784/12061', 'http://www.fontedecanais.tv/logos/canais/globoplaynovelas.png', NULL, 0, 0, 'original', NULL),
(51, 1, 'Globoplay Novelas SD', 'http://sinalprivado.info:80/1533784/1533784/12062', 'http://www.fontedecanais.tv/logos/canais/globoplaynovelas.png', NULL, 0, 0, 'original', NULL),
(52, 1, 'WooHoo FHD', 'http://sinalprivado.info:80/1533784/1533784/12063', 'http://www.fontedecanais.tv/logos/canais/woohoo.png', 'Woohoo.br', 0, 0, 'original', NULL),
(53, 1, 'WooHoo HD', 'http://sinalprivado.info:80/1533784/1533784/12064', 'http://www.fontedecanais.tv/logos/canais/woohoo.png', 'Woohoo.br', 0, 0, 'original', NULL),
(54, 1, 'WooHoo SD', 'http://sinalprivado.info:80/1533784/1533784/12065', 'http://www.fontedecanais.tv/logos/canais/woohoo.png', 'Woohoo.br', 0, 0, 'original', NULL),
(55, 3, 'HBO FHD', 'http://sinalprivado.info:80/1533784/1533784/14000', 'http://www.fontedecanais.tv/logos/canais/hbo.png', 'Hbo.br', 0, 0, 'original', NULL),
(56, 3, 'HBO HD', 'http://sinalprivado.info:80/1533784/1533784/14001', 'http://www.fontedecanais.tv/logos/canais/hbo.png', 'Hbo.br', 0, 1, 'original', '2026-01-05 03:10:24'),
(57, 3, 'HBO SD', 'http://sinalprivado.info:80/1533784/1533784/14002', 'http://www.fontedecanais.tv/logos/canais/hbo.png', 'Hbo.br', 0, 1, 'original', '2026-01-05 03:10:24'),
(58, 3, 'HBO 2 FHD', 'http://sinalprivado.info:80/1533784/1533784/14003', 'http://www.fontedecanais.tv/logos/canais/hbo2.png', 'Hbo2.br', 0, 0, 'original', NULL),
(59, 3, 'HBO 2 HD', 'http://sinalprivado.info:80/1533784/1533784/14004', 'http://www.fontedecanais.tv/logos/canais/hbo2.png', 'Hbo2.br', 0, 1, 'original', '2026-01-05 03:10:27'),
(60, 3, 'HBO 2 SD', 'http://sinalprivado.info:80/1533784/1533784/14005', 'http://www.fontedecanais.tv/logos/canais/hbo2.png', 'Hbo2.br', 0, 1, 'original', '2026-01-05 03:10:27'),
(61, 3, 'HBO Family FHD', 'http://sinalprivado.info:80/1533784/1533784/14006', 'http://www.fontedecanais.tv/logos/canais/hbofamily.png', 'Hbofamily.br', 0, 0, 'original', NULL),
(62, 3, 'HBO Family HD', 'http://sinalprivado.info:80/1533784/1533784/14007', 'http://www.fontedecanais.tv/logos/canais/hbofamily.png', 'Hbofamily.br', 0, 1, 'original', '2026-01-05 03:10:33'),
(63, 3, 'HBO Family SD', 'http://sinalprivado.info:80/1533784/1533784/14008', 'http://www.fontedecanais.tv/logos/canais/hbofamily.png', 'Hbofamily.br', 0, 1, 'original', '2026-01-05 03:10:34'),
(64, 3, 'HBO Mundi FHD', 'http://sinalprivado.info:80/1533784/1533784/14009', 'http://www.fontedecanais.tv/logos/canais/hbomundi.png', 'HBO Mundi FHD H.265', 0, 0, 'original', NULL),
(65, 3, 'HBO Mundi HD', 'http://sinalprivado.info:80/1533784/1533784/14010', 'http://www.fontedecanais.tv/logos/canais/hbomundi.png', 'HBO Mundi FHD H.265', 0, 1, 'original', '2026-01-05 03:10:40'),
(66, 3, 'HBO Mundi SD', 'http://sinalprivado.info:80/1533784/1533784/14011', 'http://www.fontedecanais.tv/logos/canais/hbomundi.png', 'HBO Mundi FHD H.265', 0, 0, 'original', NULL),
(67, 3, 'HBO Plus FHD', 'http://sinalprivado.info:80/1533784/1533784/14012', 'http://www.fontedecanais.tv/logos/canais/hboplus.png', NULL, 0, 0, 'original', NULL),
(68, 3, 'HBO Plus HD', 'http://sinalprivado.info:80/1533784/1533784/14013', 'http://www.fontedecanais.tv/logos/canais/hboplus.png', NULL, 0, 1, 'original', '2026-01-05 03:10:47'),
(69, 3, 'HBO Plus SD', 'http://sinalprivado.info:80/1533784/1533784/14014', 'http://www.fontedecanais.tv/logos/canais/hboplus.png', NULL, 0, 1, 'original', '2026-01-05 03:10:47'),
(70, 3, 'HBO Pop FHD', 'http://sinalprivado.info:80/1533784/1533784/14015', 'http://www.fontedecanais.tv/logos/canais/hbopop.png', NULL, 0, 0, 'original', NULL),
(71, 3, 'HBO Pop HD', 'http://sinalprivado.info:80/1533784/1533784/14016', 'http://www.fontedecanais.tv/logos/canais/hbopop.png', NULL, 0, 1, 'original', '2026-01-05 03:10:52'),
(72, 3, 'HBO Pop SD', 'http://sinalprivado.info:80/1533784/1533784/14017', 'http://www.fontedecanais.tv/logos/canais/hbopop.png', NULL, 0, 1, 'original', '2026-01-05 03:10:52'),
(73, 3, 'HBO Signature FHD', 'http://sinalprivado.info:80/1533784/1533784/14018', 'http://www.fontedecanais.tv/logos/canais/hbosignature.png', 'Hbosignature.br', 0, 0, 'original', NULL),
(74, 3, 'HBO Signature HD', 'http://sinalprivado.info:80/1533784/1533784/14019', 'http://www.fontedecanais.tv/logos/canais/hbosignature.png', 'Hbosignature.br', 0, 1, 'original', '2026-01-05 03:10:56'),
(75, 3, 'HBO Signature SD', 'http://sinalprivado.info:80/1533784/1533784/14020', 'http://www.fontedecanais.tv/logos/canais/hbosignature.png', 'Hbosignature.br', 0, 1, 'original', '2026-01-05 03:10:56'),
(76, 3, 'HBO Xtreme FHD', 'http://sinalprivado.info:80/1533784/1533784/14021', 'http://www.fontedecanais.tv/logos/canais/hboxtreme.png', 'HBO Xtreme FHD H.265', 0, 0, 'original', NULL),
(77, 3, 'HBO Xtreme HD', 'http://sinalprivado.info:80/1533784/1533784/14022', 'http://www.fontedecanais.tv/logos/canais/hboxtreme.png', 'HBO Xtreme FHD H.265', 0, 1, 'original', '2026-01-05 03:11:01'),
(78, 3, 'HBO Xtreme SD', 'http://sinalprivado.info:80/1533784/1533784/14023', 'http://www.fontedecanais.tv/logos/canais/hboxtreme.png', 'HBO Xtreme FHD H.265', 0, 1, 'original', '2026-01-05 03:11:02'),
(79, 4, 'Telecine Action FHD', 'http://sinalprivado.info:80/1533784/1533784/15000', 'http://www.fontedecanais.tv/logos/canais/telecineaction.png', 'Telecine Action FHD H.265', 0, 0, 'original', NULL),
(80, 4, 'Telecine Action HD', 'http://sinalprivado.info:80/1533784/1533784/15001', 'http://www.fontedecanais.tv/logos/canais/telecineaction.png', 'Telecine Action FHD H.265', 0, 1, 'original', '2026-01-05 03:09:50'),
(81, 4, 'Telecine Action SD', 'http://sinalprivado.info:80/1533784/1533784/15002', 'http://www.fontedecanais.tv/logos/canais/telecineaction.png', 'Telecine Action FHD H.265', 0, 1, 'original', '2026-01-05 03:09:51'),
(82, 4, 'Telecine Cult FHD', 'http://sinalprivado.info:80/1533784/1533784/15003', 'http://www.fontedecanais.tv/logos/canais/telecinecult.png', 'Telecine Cult FHD H.265', 0, 0, 'original', NULL),
(83, 4, 'Telecine Cult HD', 'http://sinalprivado.info:80/1533784/1533784/15004', 'http://www.fontedecanais.tv/logos/canais/telecinecult.png', 'Telecine Cult FHD H.265', 0, 0, 'original', NULL),
(84, 4, 'Telecine Cult SD', 'http://sinalprivado.info:80/1533784/1533784/15005', 'http://www.fontedecanais.tv/logos/canais/telecinecult.png', 'Telecine Cult FHD H.265', 0, 0, 'original', NULL),
(85, 4, 'Telecine Fun FHD', 'http://sinalprivado.info:80/1533784/1533784/15006', 'http://www.fontedecanais.tv/logos/canais/telecinefun.png', 'Telecine Fun FHD H.265', 0, 0, 'original', NULL),
(86, 4, 'Telecine Fun HD', 'http://sinalprivado.info:80/1533784/1533784/15007', 'http://www.fontedecanais.tv/logos/canais/telecinefun.png', 'Telecine Fun FHD H.265', 0, 1, 'original', '2026-01-05 03:09:55'),
(87, 4, 'Telecine Fun SD', 'http://sinalprivado.info:80/1533784/1533784/15008', 'http://www.fontedecanais.tv/logos/canais/telecinefun.png', 'Telecine Fun FHD H.265', 0, 1, 'original', '2026-01-05 03:09:56'),
(88, 4, 'Telecine Pipoca FHD', 'http://sinalprivado.info:80/1533784/1533784/15009', 'http://www.fontedecanais.tv/logos/canais/telecinepipoca.png', 'Telecine Pipoca FHD H.265', 0, 0, 'original', NULL),
(89, 4, 'Telecine Pipoca HD', 'http://sinalprivado.info:80/1533784/1533784/15010', 'http://www.fontedecanais.tv/logos/canais/telecinepipoca.png', 'Telecine Pipoca FHD H.265', 0, 1, 'original', '2026-01-05 03:10:01'),
(90, 4, 'Telecine Pipoca SD', 'http://sinalprivado.info:80/1533784/1533784/15011', 'http://www.fontedecanais.tv/logos/canais/telecinepipoca.png', 'Telecine Pipoca FHD H.265', 0, 1, 'original', '2026-01-05 03:10:01'),
(91, 4, 'Telecine Premium FHD', 'http://sinalprivado.info:80/1533784/1533784/15012', 'http://www.fontedecanais.tv/logos/canais/telecinepremium.png', 'Telecine Premium FHD H.265', 0, 0, 'original', NULL),
(92, 4, 'Telecine Premium HD', 'http://sinalprivado.info:80/1533784/1533784/15013', 'http://www.fontedecanais.tv/logos/canais/telecinepremium.png', 'Telecine Premium FHD H.265', 0, 1, 'original', '2026-01-05 03:10:06'),
(93, 4, 'Telecine Premium SD', 'http://sinalprivado.info:80/1533784/1533784/15014', 'http://www.fontedecanais.tv/logos/canais/telecinepremium.png', 'Telecine Premium FHD H.265', 0, 1, 'original', '2026-01-05 03:10:06'),
(94, 4, 'Telecine Touch FHD', 'http://sinalprivado.info:80/1533784/1533784/15015', 'http://www.fontedecanais.tv/logos/canais/telecinetouch.png', 'Telecine Touch FHD H.265', 0, 0, 'original', NULL),
(95, 4, 'Telecine Touch HD', 'http://sinalprivado.info:80/1533784/1533784/15016', 'http://www.fontedecanais.tv/logos/canais/telecinetouch.png', 'Telecine Touch FHD H.265', 0, 1, 'original', '2026-01-05 03:10:11'),
(96, 4, 'Telecine Touch SD', 'http://sinalprivado.info:80/1533784/1533784/15017', 'http://www.fontedecanais.tv/logos/canais/telecinetouch.png', 'Telecine Touch FHD H.265', 0, 1, 'original', '2026-01-05 03:10:12'),
(97, 5, 'Cine SKY 01', 'http://sinalprivado.info:80/1533784/1533784/16000', 'http://www.fontedecanais.tv/logos/canais/cinesky.png', NULL, 0, 0, 'original', NULL),
(98, 5, 'Cine SKY 02', 'http://sinalprivado.info:80/1533784/1533784/16001', 'http://www.fontedecanais.tv/logos/canais/cinesky.png', NULL, 0, 0, 'original', NULL),
(99, 5, 'Cine SKY 03', 'http://sinalprivado.info:80/1533784/1533784/16002', 'http://www.fontedecanais.tv/logos/canais/cinesky.png', NULL, 0, 0, 'original', NULL),
(100, 5, 'Cine SKY 04', 'http://sinalprivado.info:80/1533784/1533784/16003', 'http://www.fontedecanais.tv/logos/canais/cinesky.png', NULL, 0, 0, 'original', NULL),
(101, 5, 'Cine SKY 05', 'http://sinalprivado.info:80/1533784/1533784/16004', 'http://www.fontedecanais.tv/logos/canais/cinesky.png', NULL, 0, 0, 'original', NULL),
(102, 5, 'Cine SKY 06', 'http://sinalprivado.info:80/1533784/1533784/16005', 'http://www.fontedecanais.tv/logos/canais/cinesky.png', NULL, 0, 0, 'original', NULL),
(103, 5, 'Cine SKY 07', 'http://sinalprivado.info:80/1533784/1533784/16006', 'http://www.fontedecanais.tv/logos/canais/cinesky.png', NULL, 0, 0, 'original', NULL),
(104, 5, 'Cine SKY 08', 'http://sinalprivado.info:80/1533784/1533784/16007', 'http://www.fontedecanais.tv/logos/canais/cinesky.png', NULL, 0, 0, 'original', NULL),
(105, 5, 'Cine SKY 09', 'http://sinalprivado.info:80/1533784/1533784/16008', 'http://www.fontedecanais.tv/logos/canais/cinesky.png', NULL, 0, 0, 'original', NULL),
(106, 5, 'Cine SKY 10', 'http://sinalprivado.info:80/1533784/1533784/16009', 'http://www.fontedecanais.tv/logos/canais/cinesky.png', NULL, 0, 0, 'original', NULL),
(107, 6, 'Cultura FHD', 'http://sinalprivado.info:80/1533784/1533784/17003', 'http://www.fontedecanais.tv/logos/canais/cultura.png', NULL, 0, 0, 'original', NULL),
(108, 6, 'Cultura HD', 'http://sinalprivado.info:80/1533784/1533784/17004', 'http://www.fontedecanais.tv/logos/canais/cultura.png', NULL, 0, 0, 'original', NULL),
(109, 6, 'Cultura SD', 'http://sinalprivado.info:80/1533784/1533784/17005', 'http://www.fontedecanais.tv/logos/canais/cultura.png', NULL, 0, 0, 'original', NULL),
(110, 6, 'Futura FHD', 'http://sinalprivado.info:80/1533784/1533784/17006', 'http://www.fontedecanais.tv/logos/canais/futura.png', 'Futura.br', 0, 0, 'original', NULL),
(111, 6, 'Futura HD', 'http://sinalprivado.info:80/1533784/1533784/17007', 'http://www.fontedecanais.tv/logos/canais/futura.png', 'Futura.br', 0, 0, 'original', NULL),
(112, 6, 'Futura SD', 'http://sinalprivado.info:80/1533784/1533784/17008', 'http://www.fontedecanais.tv/logos/canais/futura.png', 'Futura.br', 0, 0, 'original', NULL),
(113, 6, 'RedeTV! FHD', 'http://sinalprivado.info:80/1533784/1533784/17036', 'http://www.fontedecanais.tv/logos/canais/redetv.png', 'Redetv.br', 0, 0, 'original', NULL),
(114, 6, 'RedeTV! HD', 'http://sinalprivado.info:80/1533784/1533784/17037', 'http://www.fontedecanais.tv/logos/canais/redetv.png', 'Redetv.br', 0, 0, 'original', NULL),
(115, 6, 'RedeTV! SD', 'http://sinalprivado.info:80/1533784/1533784/17038', 'http://www.fontedecanais.tv/logos/canais/redetv.png', 'Redetv.br', 0, 0, 'original', NULL),
(116, 99, 'SBT FHD', 'http://sinalprivado.info:80/1533784/1533784/17039', 'http://www.fontedecanais.tv/logos/canais/sbt.png', 'Sbt.br', 0, 0, 'original', NULL),
(117, 99, 'SBT HD', 'http://sinalprivado.info:80/1533784/1533784/17040', 'http://www.fontedecanais.tv/logos/canais/sbt.png', 'Sbt.br', 0, 1, 'original', '2026-01-05 03:01:21'),
(118, 99, 'SBT SD', 'http://sinalprivado.info:80/1533784/1533784/17041', 'http://www.fontedecanais.tv/logos/canais/sbt.png', 'Sbt.br', 0, 1, 'original', '2026-01-05 03:01:21'),
(119, 6, 'Canal do Boi', 'http://sinalprivado.info:80/1533784/1533784/17042', 'https://www.fontedecanais.tv/logos/canais/canaldoboi.png', 'Canal do Boi FHD', 0, 0, 'original', NULL),
(120, 6, 'Canal Rural', 'http://sinalprivado.info:80/1533784/1533784/17043', 'https://www.fontedecanais.tv/logos/canais/canalrural.png', 'Canalrural.br', 0, 0, 'original', NULL),
(121, 6, 'TV Brasil', 'http://sinalprivado.info:80/1533784/1533784/17044', 'https://www.fontedecanais.tv/logos/canais/tvbrasil.png', 'Tvbrasil.br', 0, 0, 'original', NULL),
(122, 6, 'TV Camara', 'http://sinalprivado.info:80/1533784/1533784/17045', 'https://www.fontedecanais.tv/logos/canais/tvcamara.png', 'Tvcamara.br', 0, 0, 'original', NULL),
(123, 6, 'TV Justica e Radio Justica', 'http://sinalprivado.info:80/1533784/1533784/17046', 'https://www.fontedecanais.tv/logos/canais/tvjustica.png', NULL, 0, 0, 'original', NULL),
(124, 6, 'TV Senado', 'http://sinalprivado.info:80/1533784/1533784/17047', 'https://www.fontedecanais.tv/logos/canais/tvsenado.png', 'Tvsenado.br', 0, 0, 'original', NULL),
(125, 6, 'TV Gazeta', 'http://sinalprivado.info:80/1533784/1533784/17048', 'http://www.fontedecanais.tv/logos/canais/tvgazeta.png', 'TVGazeta.br', 0, 0, 'original', NULL),
(126, 6, 'Agro+', 'http://sinalprivado.info:80/1533784/1533784/17049', 'http://www.fontedecanais.tv/logos/canais/agromais.png', NULL, 0, 0, 'original', NULL),
(127, 6, 'Terra Viva', 'http://sinalprivado.info:80/1533784/1533784/17050', 'https://i.imgur.com/0idNHMj.png', 'Terraviva.br', 0, 0, 'original', NULL),
(128, 6, 'TVE Bahia', 'http://sinalprivado.info:80/1533784/1533784/17051', 'http://i.imgur.com/IWGyp65.jpeg', NULL, 0, 0, 'original', NULL),
(129, 7, 'EPTV Campinas FHD', 'http://sinalprivado.info:80/1533784/1533784/18000', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(130, 7, 'EPTV Campinas HD', 'http://sinalprivado.info:80/1533784/1533784/18001', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(131, 7, 'EPTV Campinas SD', 'http://sinalprivado.info:80/1533784/1533784/18002', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(132, 7, 'EPTV Central FHD', 'http://sinalprivado.info:80/1533784/1533784/18003', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(133, 7, 'EPTV Central HD', 'http://sinalprivado.info:80/1533784/1533784/18004', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(134, 7, 'EPTV Central SD', 'http://sinalprivado.info:80/1533784/1533784/18005', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(135, 7, 'EPTV Ribeirão FHD', 'http://sinalprivado.info:80/1533784/1533784/18006', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(136, 7, 'EPTV Ribeirão HD', 'http://sinalprivado.info:80/1533784/1533784/18007', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(137, 7, 'EPTV Ribeirão SD', 'http://sinalprivado.info:80/1533784/1533784/18008', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(138, 7, 'EPTV Sul de Minas FHD', 'http://sinalprivado.info:80/1533784/1533784/18009', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(139, 7, 'EPTV Sul de Minas HD', 'http://sinalprivado.info:80/1533784/1533784/18010', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(140, 7, 'EPTV Sul de Minas SD', 'http://sinalprivado.info:80/1533784/1533784/18011', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(141, 7, 'Globo Brasília FHD', 'http://sinalprivado.info:80/1533784/1533784/18012', 'http://www.fontedecanais.tv/logos/canais/globo.png', 'Globo Brasilia FHD', 0, 0, 'original', NULL),
(142, 7, 'Globo Brasília HD', 'http://sinalprivado.info:80/1533784/1533784/18013', 'http://www.fontedecanais.tv/logos/canais/globo.png', 'Globo Brasilia HD', 0, 0, 'original', NULL),
(143, 7, 'Globo Brasília SD', 'http://sinalprivado.info:80/1533784/1533784/18014', 'http://www.fontedecanais.tv/logos/canais/globo.png', 'Globo Brasilia SD', 0, 0, 'original', NULL),
(144, 7, 'Globo Minas FHD', 'http://sinalprivado.info:80/1533784/1533784/18015', 'http://www.fontedecanais.tv/logos/canais/globo.png', 'Globominas.br', 0, 0, 'original', NULL),
(145, 7, 'Globo Minas HD', 'http://sinalprivado.info:80/1533784/1533784/18016', 'http://www.fontedecanais.tv/logos/canais/globo.png', 'Globominas.br', 0, 0, 'original', NULL),
(146, 7, 'Globo Minas SD', 'http://sinalprivado.info:80/1533784/1533784/18017', 'http://www.fontedecanais.tv/logos/canais/globo.png', 'Globominas.br', 0, 0, 'original', NULL),
(147, 7, 'Globo Nordeste FHD', 'http://sinalprivado.info:80/1533784/1533784/18018', 'http://www.fontedecanais.tv/logos/canais/globo.png', 'Globo Nordeste FHD', 0, 0, 'original', NULL),
(148, 7, 'Globo Nordeste HD', 'http://sinalprivado.info:80/1533784/1533784/18019', 'http://www.fontedecanais.tv/logos/canais/globo.png', 'Globo Nordeste FHD', 0, 0, 'original', NULL),
(149, 7, 'Globo Nordeste SD', 'http://sinalprivado.info:80/1533784/1533784/18020', 'http://www.fontedecanais.tv/logos/canais/globo.png', 'Globo Nordeste FHD', 0, 0, 'original', NULL),
(150, 7, 'Globo Rio FHD', 'http://sinalprivado.info:80/1533784/1533784/18021', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(151, 7, 'Globo Rio HD', 'http://sinalprivado.info:80/1533784/1533784/18022', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(152, 7, 'Globo Rio SD', 'http://sinalprivado.info:80/1533784/1533784/18023', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(153, 7, 'Globo São Paulo FHD', 'http://sinalprivado.info:80/1533784/1533784/18024', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(154, 7, 'Globo São Paulo HD', 'http://sinalprivado.info:80/1533784/1533784/18025', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 1, 'original', '2026-01-05 03:01:44'),
(155, 7, 'Globo São Paulo SD', 'http://sinalprivado.info:80/1533784/1533784/18026', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 1, 'original', '2026-01-05 03:01:45'),
(156, 7, 'Inter TV Alto Litoral FHD', 'http://sinalprivado.info:80/1533784/1533784/18027', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(157, 7, 'Inter TV Alto Litoral HD', 'http://sinalprivado.info:80/1533784/1533784/18028', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(158, 7, 'Inter TV Alto Litoral SD', 'http://sinalprivado.info:80/1533784/1533784/18029', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(159, 7, 'Inter TV Cabugi FHD', 'http://sinalprivado.info:80/1533784/1533784/18030', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(160, 7, 'Inter TV Cabugi HD', 'http://sinalprivado.info:80/1533784/1533784/18031', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(161, 7, 'Inter TV Cabugi SD', 'http://sinalprivado.info:80/1533784/1533784/18032', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(162, 7, 'Inter TV Costa Branca FHD', 'http://sinalprivado.info:80/1533784/1533784/18033', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(163, 7, 'Inter TV Costa Branca HD', 'http://sinalprivado.info:80/1533784/1533784/18034', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(164, 7, 'Inter TV Costa Branca SD', 'http://sinalprivado.info:80/1533784/1533784/18035', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(165, 7, 'Inter TV dos Vales FHD', 'http://sinalprivado.info:80/1533784/1533784/18036', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(166, 7, 'Inter TV dos Vales HD', 'http://sinalprivado.info:80/1533784/1533784/18037', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(167, 7, 'Inter TV dos Vales SD', 'http://sinalprivado.info:80/1533784/1533784/18038', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(168, 7, 'Inter TV Grande Minas FHD', 'http://sinalprivado.info:80/1533784/1533784/18039', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(169, 7, 'Inter TV Grande Minas HD', 'http://sinalprivado.info:80/1533784/1533784/18040', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(170, 7, 'Inter TV Grande Minas SD', 'http://sinalprivado.info:80/1533784/1533784/18041', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(171, 7, 'Inter TV Planície FHD', 'http://sinalprivado.info:80/1533784/1533784/18042', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(172, 7, 'Inter TV Planície HD', 'http://sinalprivado.info:80/1533784/1533784/18043', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(173, 7, 'Inter TV Planície SD', 'http://sinalprivado.info:80/1533784/1533784/18044', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(174, 7, 'Inter TV Serra Mar FHD', 'http://sinalprivado.info:80/1533784/1533784/18045', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(175, 7, 'Inter TV Serra Mar HD', 'http://sinalprivado.info:80/1533784/1533784/18046', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(176, 7, 'Inter TV Serra Mar SD', 'http://sinalprivado.info:80/1533784/1533784/18047', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(177, 7, 'RBS TV Caxias do Sul FHD', 'http://sinalprivado.info:80/1533784/1533784/18048', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(178, 7, 'RBS TV Caxias do Sul HD', 'http://sinalprivado.info:80/1533784/1533784/18049', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(179, 7, 'RBS TV Caxias do Sul SD', 'http://sinalprivado.info:80/1533784/1533784/18050', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(180, 7, 'RBS TV Centro-Oeste FHD', 'http://sinalprivado.info:80/1533784/1533784/18051', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(181, 7, 'RBS TV Centro-Oeste HD', 'http://sinalprivado.info:80/1533784/1533784/18052', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(182, 7, 'RBS TV Centro-Oeste SD', 'http://sinalprivado.info:80/1533784/1533784/18053', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(183, 7, 'RBS TV Chapecó FHD', 'http://sinalprivado.info:80/1533784/1533784/18054', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(184, 7, 'RBS TV Chapecó HD', 'http://sinalprivado.info:80/1533784/1533784/18055', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 1, 'original', '2026-01-05 03:01:56'),
(185, 7, 'RBS TV Chapecó SD', 'http://sinalprivado.info:80/1533784/1533784/18056', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 1, 'original', '2026-01-05 03:01:56'),
(186, 7, 'RBS TV Criciúma FHD', 'http://sinalprivado.info:80/1533784/1533784/18057', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(187, 7, 'RBS TV Criciúma HD', 'http://sinalprivado.info:80/1533784/1533784/18058', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(188, 7, 'RBS TV Criciúma SD', 'http://sinalprivado.info:80/1533784/1533784/18059', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(189, 7, 'RBS TV Florianópolis FHD', 'http://sinalprivado.info:80/1533784/1533784/18060', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(190, 7, 'RBS TV Florianópolis HD', 'http://sinalprivado.info:80/1533784/1533784/18061', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 1, 'original', '2026-01-05 03:02:02'),
(191, 7, 'RBS TV Florianópolis SD', 'http://sinalprivado.info:80/1533784/1533784/18062', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 1, 'original', '2026-01-05 03:02:02'),
(192, 7, 'RBS TV Joinville FHD', 'http://sinalprivado.info:80/1533784/1533784/18063', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(193, 7, 'RBS TV Joinville HD', 'http://sinalprivado.info:80/1533784/1533784/18064', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 1, 'original', '2026-01-05 03:02:06'),
(194, 7, 'RBS TV Joinville SD', 'http://sinalprivado.info:80/1533784/1533784/18065', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 1, 'original', '2026-01-05 03:02:07'),
(195, 7, 'RBS TV Porto Alegre FHD', 'http://sinalprivado.info:80/1533784/1533784/18066', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(196, 7, 'RBS TV Porto Alegre HD', 'http://sinalprivado.info:80/1533784/1533784/18067', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(197, 7, 'RBS TV Porto Alegre SD', 'http://sinalprivado.info:80/1533784/1533784/18068', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(198, 7, 'Rede Amazônica Macapá FHD', 'http://sinalprivado.info:80/1533784/1533784/18069', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(199, 7, 'Rede Amazônica Macapá HD', 'http://sinalprivado.info:80/1533784/1533784/18070', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(200, 7, 'Rede Amazônica Macapá SD', 'http://sinalprivado.info:80/1533784/1533784/18071', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(201, 7, 'Rede Amazônica Manaus FHD', 'http://sinalprivado.info:80/1533784/1533784/18072', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(202, 7, 'Rede Amazônica Manaus HD', 'http://sinalprivado.info:80/1533784/1533784/18073', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(203, 7, 'Rede Amazônica Manaus SD', 'http://sinalprivado.info:80/1533784/1533784/18074', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(204, 7, 'Rede Amazônica Parintins FHD', 'http://sinalprivado.info:80/1533784/1533784/18075', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(205, 7, 'Rede Amazônica Parintins HD', 'http://sinalprivado.info:80/1533784/1533784/18076', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(206, 7, 'Rede Amazônica Parintins SD', 'http://sinalprivado.info:80/1533784/1533784/18077', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(207, 7, 'Rede Amazônica Porto Velho FHD', 'http://sinalprivado.info:80/1533784/1533784/18078', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(208, 7, 'Rede Amazônica Porto Velho HD', 'http://sinalprivado.info:80/1533784/1533784/18079', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(209, 7, 'Rede Amazônica Porto Velho SD', 'http://sinalprivado.info:80/1533784/1533784/18080', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(210, 7, 'Rede Amazônica Boa Vista FHD', 'http://sinalprivado.info:80/1533784/1533784/18081', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(211, 7, 'Rede Amazônica Boa Vista HD', 'http://sinalprivado.info:80/1533784/1533784/18082', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(212, 7, 'Rede Amazônica Boa Vista SD', 'http://sinalprivado.info:80/1533784/1533784/18083', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(213, 7, 'Rede Amazônica Rio Branco FHD', 'http://sinalprivado.info:80/1533784/1533784/18084', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(214, 7, 'Rede Amazônica Rio Branco HD', 'http://sinalprivado.info:80/1533784/1533784/18085', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(215, 7, 'Rede Amazônica Rio Branco SD', 'http://sinalprivado.info:80/1533784/1533784/18086', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(216, 7, 'RPC Cascavel FHD', 'http://sinalprivado.info:80/1533784/1533784/18087', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(217, 7, 'RPC Cascavel HD', 'http://sinalprivado.info:80/1533784/1533784/18088', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(218, 7, 'RPC Cascavel SD', 'http://sinalprivado.info:80/1533784/1533784/18089', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(219, 7, 'RPC Curitiba FHD', 'http://sinalprivado.info:80/1533784/1533784/18090', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(220, 7, 'RPC Curitiba HD', 'http://sinalprivado.info:80/1533784/1533784/18091', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(221, 7, 'RPC Curitiba SD', 'http://sinalprivado.info:80/1533784/1533784/18092', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(222, 7, 'RPC Foz do Iguaçu FHD', 'http://sinalprivado.info:80/1533784/1533784/18093', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(223, 7, 'RPC Foz do Iguaçu HD', 'http://sinalprivado.info:80/1533784/1533784/18094', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(224, 7, 'RPC Foz do Iguaçu SD', 'http://sinalprivado.info:80/1533784/1533784/18095', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(225, 7, 'RPC Guarapuava FHD', 'http://sinalprivado.info:80/1533784/1533784/18096', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(226, 7, 'RPC Guarapuava HD', 'http://sinalprivado.info:80/1533784/1533784/18097', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(227, 7, 'RPC Guarapuava SD', 'http://sinalprivado.info:80/1533784/1533784/18098', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(228, 7, 'RPC Londrina FHD', 'http://sinalprivado.info:80/1533784/1533784/18099', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(229, 7, 'RPC Londrina HD', 'http://sinalprivado.info:80/1533784/1533784/18100', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(230, 7, 'RPC Londrina SD', 'http://sinalprivado.info:80/1533784/1533784/18101', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(231, 7, 'RPC Maringá FHD', 'http://sinalprivado.info:80/1533784/1533784/18102', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(232, 7, 'RPC Maringá HD', 'http://sinalprivado.info:80/1533784/1533784/18103', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(233, 7, 'RPC Maringá SD', 'http://sinalprivado.info:80/1533784/1533784/18104', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(234, 7, 'RPC Paranavaí FHD', 'http://sinalprivado.info:80/1533784/1533784/18105', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(235, 7, 'RPC Paranavaí HD', 'http://sinalprivado.info:80/1533784/1533784/18106', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(236, 7, 'RPC Paranavaí SD', 'http://sinalprivado.info:80/1533784/1533784/18107', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(237, 7, 'RPC Ponta Grossa FHD', 'http://sinalprivado.info:80/1533784/1533784/18108', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(238, 7, 'RPC Ponta Grossa HD', 'http://sinalprivado.info:80/1533784/1533784/18109', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(239, 7, 'RPC Ponta Grossa SD', 'http://sinalprivado.info:80/1533784/1533784/18110', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(240, 7, 'TV Alvorada do Sul FHD', 'http://sinalprivado.info:80/1533784/1533784/18111', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(241, 7, 'TV Alvorada do Sul HD', 'http://sinalprivado.info:80/1533784/1533784/18112', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(242, 7, 'TV Alvorada do Sul SD', 'http://sinalprivado.info:80/1533784/1533784/18113', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(243, 7, 'TV Anhanguera Goiânia FHD', 'http://sinalprivado.info:80/1533784/1533784/18114', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(244, 7, 'TV Anhanguera Goiânia HD', 'http://sinalprivado.info:80/1533784/1533784/18115', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(245, 7, 'TV Anhanguera Goiânia SD', 'http://sinalprivado.info:80/1533784/1533784/18116', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(246, 7, 'TV Asa Branca FHD', 'http://sinalprivado.info:80/1533784/1533784/18117', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(247, 7, 'TV Asa Branca HD', 'http://sinalprivado.info:80/1533784/1533784/18118', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(248, 7, 'TV Asa Branca SD', 'http://sinalprivado.info:80/1533784/1533784/18119', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(249, 7, 'TV Bahia FHD', 'http://sinalprivado.info:80/1533784/1533784/18120', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(250, 7, 'TV Bahia HD', 'http://sinalprivado.info:80/1533784/1533784/18121', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(251, 7, 'TV Bahia SD', 'http://sinalprivado.info:80/1533784/1533784/18122', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(252, 7, 'TV Cabo Branco FHD', 'http://sinalprivado.info:80/1533784/1533784/18123', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(253, 7, 'TV Cabo Branco HD', 'http://sinalprivado.info:80/1533784/1533784/18124', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(254, 7, 'TV Cabo Branco SD', 'http://sinalprivado.info:80/1533784/1533784/18125', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(255, 7, 'TV Centro-américa Cuiabá FHD', 'http://sinalprivado.info:80/1533784/1533784/18126', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(256, 7, 'TV Centro-américa Cuiabá HD', 'http://sinalprivado.info:80/1533784/1533784/18127', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(257, 7, 'TV Centro-américa Cuiabá SD', 'http://sinalprivado.info:80/1533784/1533784/18128', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(258, 7, 'TV Clube FHD', 'http://sinalprivado.info:80/1533784/1533784/18129', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(259, 7, 'TV Clube HD', 'http://sinalprivado.info:80/1533784/1533784/18130', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(260, 7, 'TV Clube SD', 'http://sinalprivado.info:80/1533784/1533784/18131', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(261, 7, 'TV Fronteira FHD', 'http://sinalprivado.info:80/1533784/1533784/18132', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(262, 7, 'TV Fronteira HD', 'http://sinalprivado.info:80/1533784/1533784/18133', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(263, 7, 'TV Fronteira SD', 'http://sinalprivado.info:80/1533784/1533784/18134', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(264, 7, 'TV Gazeta Vitória FHD', 'http://sinalprivado.info:80/1533784/1533784/18135', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(265, 7, 'TV Gazeta Vitória HD', 'http://sinalprivado.info:80/1533784/1533784/18136', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(266, 7, 'TV Gazeta Vitória SD', 'http://sinalprivado.info:80/1533784/1533784/18137', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(267, 7, 'TV Grande Rio FHD', 'http://sinalprivado.info:80/1533784/1533784/18138', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(268, 7, 'TV Grande Rio HD', 'http://sinalprivado.info:80/1533784/1533784/18139', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(269, 7, 'TV Grande Rio SD', 'http://sinalprivado.info:80/1533784/1533784/18140', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(270, 7, 'TV Integração Ituiutaba FHD', 'http://sinalprivado.info:80/1533784/1533784/18141', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(271, 7, 'TV Integração Ituiutaba HD', 'http://sinalprivado.info:80/1533784/1533784/18142', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(272, 7, 'TV Integração Ituiutaba SD', 'http://sinalprivado.info:80/1533784/1533784/18143', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(273, 7, 'TV Integração Uberlândia FHD', 'http://sinalprivado.info:80/1533784/1533784/18144', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(274, 7, 'TV Integração Uberlândia HD', 'http://sinalprivado.info:80/1533784/1533784/18145', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(275, 7, 'TV Integração Uberlândia SD', 'http://sinalprivado.info:80/1533784/1533784/18146', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(276, 7, 'TV Liberal Belém FHD', 'http://sinalprivado.info:80/1533784/1533784/18147', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(277, 7, 'TV Liberal Belém HD', 'http://sinalprivado.info:80/1533784/1533784/18148', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(278, 7, 'TV Liberal Belém SD', 'http://sinalprivado.info:80/1533784/1533784/18149', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(279, 7, 'TV Mirante Balsas FHD', 'http://sinalprivado.info:80/1533784/1533784/18150', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(280, 7, 'TV Mirante Balsas HD', 'http://sinalprivado.info:80/1533784/1533784/18151', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(281, 7, 'TV Mirante Balsas SD', 'http://sinalprivado.info:80/1533784/1533784/18152', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(282, 7, 'TV Mirante Cocais FHD', 'http://sinalprivado.info:80/1533784/1533784/18153', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(283, 7, 'TV Mirante Cocais HD', 'http://sinalprivado.info:80/1533784/1533784/18154', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(284, 7, 'TV Mirante Cocais SD', 'http://sinalprivado.info:80/1533784/1533784/18155', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(285, 7, 'TV Mirante Imperatriz FHD', 'http://sinalprivado.info:80/1533784/1533784/18156', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(286, 7, 'TV Mirante Imperatriz HD', 'http://sinalprivado.info:80/1533784/1533784/18157', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(287, 7, 'TV Mirante Imperatriz SD', 'http://sinalprivado.info:80/1533784/1533784/18158', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(288, 7, 'TV Mirante São Luís FHD', 'http://sinalprivado.info:80/1533784/1533784/18159', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(289, 7, 'TV Mirante São Luís HD', 'http://sinalprivado.info:80/1533784/1533784/18160', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL);
INSERT INTO `channels` (`id`, `category_id`, `name`, `stream_url`, `logo_url`, `epg_id`, `pid`, `running`, `transcode_quality`, `uptime`) VALUES
(290, 7, 'TV Mirante São Luís SD', 'http://sinalprivado.info:80/1533784/1533784/18161', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(291, 7, 'TV Morena Campo Grande FHD', 'http://sinalprivado.info:80/1533784/1533784/18162', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(292, 7, 'TV Morena Campo Grande HD', 'http://sinalprivado.info:80/1533784/1533784/18163', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(293, 7, 'TV Morena Campo Grande SD', 'http://sinalprivado.info:80/1533784/1533784/18164', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(294, 7, 'TV Oeste FHD', 'http://sinalprivado.info:80/1533784/1533784/18165', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(295, 7, 'TV Oeste HD', 'http://sinalprivado.info:80/1533784/1533784/18166', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(296, 7, 'TV Oeste SD', 'http://sinalprivado.info:80/1533784/1533784/18167', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(297, 7, 'TV Paraíba FHD', 'http://sinalprivado.info:80/1533784/1533784/18168', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(298, 7, 'TV Paraíba HD', 'http://sinalprivado.info:80/1533784/1533784/18169', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(299, 7, 'TV Paraíba SD', 'http://sinalprivado.info:80/1533784/1533784/18170', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(300, 7, 'TV Rio Sul FHD', 'http://sinalprivado.info:80/1533784/1533784/18171', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(301, 7, 'TV Rio Sul HD', 'http://sinalprivado.info:80/1533784/1533784/18172', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(302, 7, 'TV Rio Sul SD', 'http://sinalprivado.info:80/1533784/1533784/18173', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(303, 7, 'TV Santa Cruz FHD', 'http://sinalprivado.info:80/1533784/1533784/18174', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(304, 7, 'TV Santa Cruz HD', 'http://sinalprivado.info:80/1533784/1533784/18175', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(305, 7, 'TV Santa Cruz SD', 'http://sinalprivado.info:80/1533784/1533784/18176', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(306, 7, 'TV São Francisco FHD', 'http://sinalprivado.info:80/1533784/1533784/18177', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(307, 7, 'TV São Francisco HD', 'http://sinalprivado.info:80/1533784/1533784/18178', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(308, 7, 'TV São Francisco SD', 'http://sinalprivado.info:80/1533784/1533784/18179', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(309, 7, 'TV Sergipe FHD', 'http://sinalprivado.info:80/1533784/1533784/18180', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(310, 7, 'TV Sergipe HD', 'http://sinalprivado.info:80/1533784/1533784/18181', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(311, 7, 'TV Sergipe SD', 'http://sinalprivado.info:80/1533784/1533784/18182', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(312, 7, 'TV Subaé FHD', 'http://sinalprivado.info:80/1533784/1533784/18183', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(313, 7, 'TV Subaé HD', 'http://sinalprivado.info:80/1533784/1533784/18184', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(314, 7, 'TV Subaé SD', 'http://sinalprivado.info:80/1533784/1533784/18185', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(315, 7, 'TV Sudoeste FHD', 'http://sinalprivado.info:80/1533784/1533784/18186', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(316, 7, 'TV Sudoeste HD', 'http://sinalprivado.info:80/1533784/1533784/18187', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(317, 7, 'TV Sudoeste SD', 'http://sinalprivado.info:80/1533784/1533784/18188', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(318, 7, 'TV TEM Bauru FHD', 'http://sinalprivado.info:80/1533784/1533784/18189', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(319, 7, 'TV TEM Bauru HD', 'http://sinalprivado.info:80/1533784/1533784/18190', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(320, 7, 'TV TEM Bauru SD', 'http://sinalprivado.info:80/1533784/1533784/18191', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(321, 7, 'TV TEM Itapetininga FHD', 'http://sinalprivado.info:80/1533784/1533784/18192', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(322, 7, 'TV TEM Itapetininga HD', 'http://sinalprivado.info:80/1533784/1533784/18193', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(323, 7, 'TV TEM Itapetininga SD', 'http://sinalprivado.info:80/1533784/1533784/18194', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(324, 7, 'TV TEM São José do Rio Preto FHD', 'http://sinalprivado.info:80/1533784/1533784/18195', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(325, 7, 'TV TEM São José do Rio Preto HD', 'http://sinalprivado.info:80/1533784/1533784/18196', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(326, 7, 'TV TEM São José do Rio Preto SD', 'http://sinalprivado.info:80/1533784/1533784/18197', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(327, 7, 'TV TEM Sorocaba  FHD', 'http://sinalprivado.info:80/1533784/1533784/18198', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(328, 7, 'TV TEM Sorocaba  HD', 'http://sinalprivado.info:80/1533784/1533784/18199', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(329, 7, 'TV TEM Sorocaba  SD', 'http://sinalprivado.info:80/1533784/1533784/18200', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(330, 7, 'TV Tribuna FHD', 'http://sinalprivado.info:80/1533784/1533784/18201', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(331, 7, 'TV Tribuna HD', 'http://sinalprivado.info:80/1533784/1533784/18202', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(332, 7, 'TV Tribuna SD', 'http://sinalprivado.info:80/1533784/1533784/18203', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(333, 7, 'TV Verdes Mares Cariri FHD', 'http://sinalprivado.info:80/1533784/1533784/18204', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(334, 7, 'TV Verdes Mares Cariri HD', 'http://sinalprivado.info:80/1533784/1533784/18205', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(335, 7, 'TV Verdes Mares Cariri SD', 'http://sinalprivado.info:80/1533784/1533784/18206', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(336, 7, 'TV Verdes Mares Fortaleza FHD', 'http://sinalprivado.info:80/1533784/1533784/18207', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(337, 7, 'TV Verdes Mares Fortaleza HD', 'http://sinalprivado.info:80/1533784/1533784/18208', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(338, 7, 'TV Verdes Mares Fortaleza SD', 'http://sinalprivado.info:80/1533784/1533784/18209', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(339, 7, 'Vanguarda São José dos Campos FHD', 'http://sinalprivado.info:80/1533784/1533784/18210', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(340, 7, 'Vanguarda São José dos Campos HD', 'http://sinalprivado.info:80/1533784/1533784/18211', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(341, 7, 'Vanguarda São José dos Campos SD', 'http://sinalprivado.info:80/1533784/1533784/18212', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(342, 7, 'Vanguarda Taubaté FHD', 'http://sinalprivado.info:80/1533784/1533784/18213', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(343, 7, 'Vanguarda Taubaté HD', 'http://sinalprivado.info:80/1533784/1533784/18214', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(344, 7, 'Vanguarda Taubaté SD', 'http://sinalprivado.info:80/1533784/1533784/18215', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(345, 7, 'RBS TV Passo Fundo FHD', 'http://sinalprivado.info:80/1533784/1533784/18216', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(346, 7, 'RBS TV Passo Fundo HD', 'http://sinalprivado.info:80/1533784/1533784/18217', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(347, 7, 'RBS TV Passo Fundo HD', 'http://sinalprivado.info:80/1533784/1533784/18218', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(348, 7, 'RBS TV Santa Maria FHD', 'http://sinalprivado.info:80/1533784/1533784/18219', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(349, 7, 'RBS TV Santa Maria HD', 'http://sinalprivado.info:80/1533784/1533784/18220', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(350, 7, 'RBS TV Santa Maria SD', 'http://sinalprivado.info:80/1533784/1533784/18221', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(351, 7, 'TV Asa Branca de Alagoas FHD', 'http://sinalprivado.info:80/1533784/1533784/18222', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(352, 7, 'TV Asa Branca de Alagoas HD', 'http://sinalprivado.info:80/1533784/1533784/18223', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(353, 7, 'TV Asa Branca de Alagoas SD', 'http://sinalprivado.info:80/1533784/1533784/18224', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(354, 7, 'TV Centro-América Sinop FHD', 'http://sinalprivado.info:80/1533784/1533784/18225', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(355, 7, 'TV Centro-América Sinop HD', 'http://sinalprivado.info:80/1533784/1533784/18226', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(356, 7, 'TV Centro-América Sinop SD', 'http://sinalprivado.info:80/1533784/1533784/18227', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(357, 7, 'TV Centro-América Rondonópolis FHD', 'http://sinalprivado.info:80/1533784/1533784/18228', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(358, 7, 'TV Centro-América Rondonópolis HD', 'http://sinalprivado.info:80/1533784/1533784/18229', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(359, 7, 'TV Centro-América Rondonópolis SD', 'http://sinalprivado.info:80/1533784/1533784/18230', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(360, 7, 'TV Morena Corumbá FHD', 'http://sinalprivado.info:80/1533784/1533784/18231', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(361, 7, 'TV Morena Corumbá HD', 'http://sinalprivado.info:80/1533784/1533784/18232', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(362, 7, 'TV Morena Corumbá SD', 'http://sinalprivado.info:80/1533784/1533784/18233', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(363, 7, 'TV Morena Ponta Porã FHD', 'http://sinalprivado.info:80/1533784/1533784/18234', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(364, 7, 'TV Morena Ponta Porã HD', 'http://sinalprivado.info:80/1533784/1533784/18235', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(365, 7, 'TV Morena Ponta Porã SD', 'http://sinalprivado.info:80/1533784/1533784/18236', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(366, 7, 'TV Integração Araxá FHD', 'http://sinalprivado.info:80/1533784/1533784/18237', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(367, 7, 'TV Integração Araxá HD', 'http://sinalprivado.info:80/1533784/1533784/18238', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(368, 7, 'TV Integração Araxá SD', 'http://sinalprivado.info:80/1533784/1533784/18239', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(369, 7, 'TV Integração Uberaba FHD', 'http://sinalprivado.info:80/1533784/1533784/18240', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(370, 7, 'TV Integração Uberaba HD', 'http://sinalprivado.info:80/1533784/1533784/18241', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(371, 7, 'TV Integração Uberaba SD', 'http://sinalprivado.info:80/1533784/1533784/18242', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(372, 7, 'TV Integração Juiz de Fora FHD', 'http://sinalprivado.info:80/1533784/1533784/18243', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(373, 7, 'TV Integração Juiz de Fora HD', 'http://sinalprivado.info:80/1533784/1533784/18244', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(374, 7, 'TV Integração Juiz de Fora SD', 'http://sinalprivado.info:80/1533784/1533784/18245', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(375, 7, 'RBS TV Pelotas FHD', 'http://sinalprivado.info:80/1533784/1533784/18246', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(376, 7, 'RBS TV Pelotas HD', 'http://sinalprivado.info:80/1533784/1533784/18247', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(377, 7, 'RBS TV Pelotas SD', 'http://sinalprivado.info:80/1533784/1533784/18248', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(378, 7, 'RBS TV Blumenau FHD', 'http://sinalprivado.info:80/1533784/1533784/18249', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(379, 7, 'RBS TV Blumenau HD', 'http://sinalprivado.info:80/1533784/1533784/18250', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(380, 7, 'RBS TV Blumenau SD', 'http://sinalprivado.info:80/1533784/1533784/18251', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(381, 7, 'TV Gazeta Sul FHD', 'http://sinalprivado.info:80/1533784/1533784/18252', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(382, 7, 'TV Gazeta Sul HD', 'http://sinalprivado.info:80/1533784/1533784/18253', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(383, 7, 'TV Gazeta Sul SD', 'http://sinalprivado.info:80/1533784/1533784/18254', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(384, 7, 'TV Anhanguera Palmas FHD', 'http://sinalprivado.info:80/1533784/1533784/18255', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(385, 7, 'TV Anhanguera Palmas HD', 'http://sinalprivado.info:80/1533784/1533784/18256', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(386, 7, 'TV Anhanguera Palmas SD', 'http://sinalprivado.info:80/1533784/1533784/18257', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(387, 7, 'RBS TV Santa Cruz FHD', 'http://sinalprivado.info:80/1533784/1533784/18258', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(388, 7, 'RBS TV Santa Cruz HD', 'http://sinalprivado.info:80/1533784/1533784/18259', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(389, 7, 'RBS TV Santa Cruz SD', 'http://sinalprivado.info:80/1533784/1533784/18260', 'http://www.fontedecanais.tv/logos/canais/globo.png', NULL, 0, 0, 'original', NULL),
(390, 8, 'Band Sports FHD', 'http://sinalprivado.info:80/1533784/1533784/19000', 'http://www.fontedecanais.tv/logos/canais/bandsports.png', 'Bandsports.br', 0, 0, 'original', NULL),
(391, 8, 'Band Sports HD', 'http://sinalprivado.info:80/1533784/1533784/19001', 'http://www.fontedecanais.tv/logos/canais/bandsports.png', 'Bandsports.br', 0, 0, 'original', NULL),
(392, 8, 'Band Sports SD', 'http://sinalprivado.info:80/1533784/1533784/19002', 'http://www.fontedecanais.tv/logos/canais/bandsports.png', 'Bandsports.br', 0, 0, 'original', NULL),
(393, 8, 'UFC Fight Pass 1 (reprises)', 'http://sinalprivado.info:80/1533784/1533784/19003', 'http://www.fontedecanais.tv/logos/canais/ufcfightpass.png', NULL, 0, 0, 'original', NULL),
(394, 8, 'UFC Fight Pass 2 (ao vivo)', 'http://sinalprivado.info:80/1533784/1533784/19004', 'http://www.fontedecanais.tv/logos/canais/ufcfightpass.png', NULL, 0, 0, 'original', NULL),
(395, 8, 'UFC Fight Pass 3 (ao vivo)', 'http://sinalprivado.info:80/1533784/1533784/19005', 'http://www.fontedecanais.tv/logos/canais/ufcfightpass.png', NULL, 0, 0, 'original', NULL),
(396, 8, 'Combate FHD', 'http://sinalprivado.info:80/1533784/1533784/19006', 'http://www.fontedecanais.tv/logos/canais/combate.png', 'Combate.br', 0, 0, 'original', NULL),
(397, 8, 'Combate HD', 'http://sinalprivado.info:80/1533784/1533784/19007', 'http://www.fontedecanais.tv/logos/canais/combate.png', 'Combate.br', 0, 0, 'original', NULL),
(398, 8, 'Combate SD', 'http://sinalprivado.info:80/1533784/1533784/19008', 'http://www.fontedecanais.tv/logos/canais/combate.png', 'Combate.br', 0, 0, 'original', NULL),
(399, 8, 'GE TV FHD', 'http://sinalprivado.info:80/1533784/1533784/19009', 'http://www.fontedecanais.tv/logos/canais/getv.png', NULL, 0, 0, 'original', NULL),
(400, 8, 'GE TV HD', 'http://sinalprivado.info:80/1533784/1533784/19010', 'http://www.fontedecanais.tv/logos/canais/getv.png', NULL, 0, 0, 'original', NULL),
(401, 8, 'GE TV SD', 'http://sinalprivado.info:80/1533784/1533784/19011', 'http://www.fontedecanais.tv/logos/canais/getv.png', NULL, 0, 0, 'original', NULL),
(402, 8, 'Amazon Prime Video 01', 'http://sinalprivado.info:80/1533784/1533784/19021', 'http://www.fontedecanais.tv/logos/canais/primevideo.png', NULL, 0, 0, 'original', NULL),
(403, 8, 'Amazon Prime Video 02', 'http://sinalprivado.info:80/1533784/1533784/19022', 'http://www.fontedecanais.tv/logos/canais/primevideo.png', NULL, 0, 0, 'original', NULL),
(404, 8, 'Amazon Prime Video 03', 'http://sinalprivado.info:80/1533784/1533784/19023', 'http://www.fontedecanais.tv/logos/canais/primevideo.png', NULL, 0, 0, 'original', NULL),
(405, 8, 'SportyNet 01', 'http://sinalprivado.info:80/1533784/1533784/19024', 'http://www.fontedecanais.tv/logos/canais/sportynet.png', NULL, 0, 0, 'original', NULL),
(406, 8, 'SportyNet 02', 'http://sinalprivado.info:80/1533784/1533784/19025', 'http://www.fontedecanais.tv/logos/canais/sportynet2.png', NULL, 0, 0, 'original', NULL),
(407, 8, 'SportyNet 03', 'http://sinalprivado.info:80/1533784/1533784/19026', 'http://www.fontedecanais.tv/logos/canais/sportynet3.png', NULL, 0, 0, 'original', NULL),
(408, 8, 'DAZN 1', 'http://sinalprivado.info:80/1533784/1533784/19028', 'http://www.fontedecanais.tv/logos/canais/dazn.png', 'Dazn 1 HD', 0, 0, 'original', NULL),
(409, 8, 'DAZN 2', 'http://sinalprivado.info:80/1533784/1533784/19029', 'http://www.fontedecanais.tv/logos/canais/dazn.png', 'Dazn 2 HD', 0, 0, 'original', NULL),
(410, 8, 'DAZN 3', 'http://sinalprivado.info:80/1533784/1533784/19030', 'http://www.fontedecanais.tv/logos/canais/dazn.png', 'Dazn 3 HD', 0, 0, 'original', NULL),
(411, 8, 'MAX 01', 'http://sinalprivado.info:80/1533784/1533784/19033', 'http://www.fontedecanais.tv/logos/canais/max.png', NULL, 0, 0, 'original', NULL),
(412, 8, 'MAX 02', 'http://sinalprivado.info:80/1533784/1533784/19034', 'http://www.fontedecanais.tv/logos/canais/max.png', NULL, 0, 0, 'original', NULL),
(413, 8, 'MAX 03', 'http://sinalprivado.info:80/1533784/1533784/19035', 'http://www.fontedecanais.tv/logos/canais/max.png', NULL, 0, 0, 'original', NULL),
(414, 8, 'MAX 04', 'http://sinalprivado.info:80/1533784/1533784/19036', 'http://www.fontedecanais.tv/logos/canais/max.png', NULL, 0, 0, 'original', NULL),
(415, 8, 'MAX 05', 'http://sinalprivado.info:80/1533784/1533784/19037', 'http://www.fontedecanais.tv/logos/canais/max.png', NULL, 0, 0, 'original', NULL),
(416, 8, 'MAX 06', 'http://sinalprivado.info:80/1533784/1533784/19038', 'http://www.fontedecanais.tv/logos/canais/max.png', NULL, 0, 0, 'original', NULL),
(417, 8, 'MAX 07', 'http://sinalprivado.info:80/1533784/1533784/19039', 'http://www.fontedecanais.tv/logos/canais/max.png', NULL, 0, 0, 'original', NULL),
(418, 8, 'Disney+ 1', 'http://sinalprivado.info:80/1533784/1533784/19041', 'http://www.fontedecanais.tv/logos/canais/disneyplus.png', NULL, 0, 0, 'original', NULL),
(419, 8, 'Disney+ 2', 'http://sinalprivado.info:80/1533784/1533784/19042', 'http://www.fontedecanais.tv/logos/canais/disneyplus.png', NULL, 0, 0, 'original', NULL),
(420, 8, 'Disney+ 3', 'http://sinalprivado.info:80/1533784/1533784/19043', 'http://www.fontedecanais.tv/logos/canais/disneyplus.png', NULL, 0, 0, 'original', NULL),
(421, 8, 'Disney+ 4', 'http://sinalprivado.info:80/1533784/1533784/19044', 'http://www.fontedecanais.tv/logos/canais/disneyplus.png', NULL, 0, 0, 'original', NULL),
(422, 8, 'Disney+ 5', 'http://sinalprivado.info:80/1533784/1533784/19045', 'http://www.fontedecanais.tv/logos/canais/disneyplus.png', NULL, 0, 0, 'original', NULL),
(423, 8, 'Disney+ 6', 'http://sinalprivado.info:80/1533784/1533784/19046', 'http://www.fontedecanais.tv/logos/canais/disneyplus.png', NULL, 0, 0, 'original', NULL),
(424, 8, 'Disney+ 7', 'http://sinalprivado.info:80/1533784/1533784/19047', 'http://www.fontedecanais.tv/logos/canais/disneyplus.png', NULL, 0, 0, 'original', NULL),
(425, 8, 'Disney+ 8', 'http://sinalprivado.info:80/1533784/1533784/19048', 'http://www.fontedecanais.tv/logos/canais/disneyplus.png', NULL, 0, 0, 'original', NULL),
(426, 8, 'Disney+ 9', 'http://sinalprivado.info:80/1533784/1533784/19049', 'http://www.fontedecanais.tv/logos/canais/disneyplus.png', NULL, 0, 0, 'original', NULL),
(427, 8, 'Disney+ 10', 'http://sinalprivado.info:80/1533784/1533784/19050', 'http://www.fontedecanais.tv/logos/canais/disneyplus.png', NULL, 0, 0, 'original', NULL),
(428, 8, 'Disney+ 11', 'http://sinalprivado.info:80/1533784/1533784/19051', 'http://www.fontedecanais.tv/logos/canais/disneyplus.png', NULL, 0, 0, 'original', NULL),
(429, 8, 'Disney+ 12', 'http://sinalprivado.info:80/1533784/1533784/19052', 'http://www.fontedecanais.tv/logos/canais/disneyplus.png', NULL, 0, 0, 'original', NULL),
(430, 8, 'Disney+ 13', 'http://sinalprivado.info:80/1533784/1533784/19053', 'http://www.fontedecanais.tv/logos/canais/disneyplus.png', NULL, 0, 0, 'original', NULL),
(431, 8, 'Disney+ 14', 'http://sinalprivado.info:80/1533784/1533784/19054', 'http://www.fontedecanais.tv/logos/canais/disneyplus.png', NULL, 0, 0, 'original', NULL),
(432, 8, 'Disney+ 15', 'http://sinalprivado.info:80/1533784/1533784/19055', 'http://www.fontedecanais.tv/logos/canais/disneyplus.png', NULL, 0, 0, 'original', NULL),
(433, 8, 'Disney+ 16', 'http://sinalprivado.info:80/1533784/1533784/19056', 'http://www.fontedecanais.tv/logos/canais/disneyplus.png', NULL, 0, 0, 'original', NULL),
(434, 8, 'Disney+ 17', 'http://sinalprivado.info:80/1533784/1533784/19057', 'http://www.fontedecanais.tv/logos/canais/disneyplus.png', NULL, 0, 0, 'original', NULL),
(435, 8, 'Disney+ 18', 'http://sinalprivado.info:80/1533784/1533784/19058', 'http://www.fontedecanais.tv/logos/canais/disneyplus.png', NULL, 0, 0, 'original', NULL),
(436, 8, 'Disney+ 19', 'http://sinalprivado.info:80/1533784/1533784/19059', 'http://www.fontedecanais.tv/logos/canais/disneyplus.png', NULL, 0, 0, 'original', NULL),
(437, 8, 'Disney+ 20', 'http://sinalprivado.info:80/1533784/1533784/19060', 'http://www.fontedecanais.tv/logos/canais/disneyplus.png', NULL, 0, 0, 'original', NULL),
(438, 8, 'NSports FHD', 'http://sinalprivado.info:80/1533784/1533784/19064', 'http://www.fontedecanais.tv/logos/canais/nsports.png', NULL, 0, 0, 'original', NULL),
(439, 8, 'NSports HD', 'http://sinalprivado.info:80/1533784/1533784/19065', 'http://www.fontedecanais.tv/logos/canais/nsports.png', NULL, 0, 0, 'original', NULL),
(440, 8, 'NSports SD', 'http://sinalprivado.info:80/1533784/1533784/19066', 'http://www.fontedecanais.tv/logos/canais/nsports.png', NULL, 0, 0, 'original', NULL),
(441, 8, 'CazeTV 01', 'http://sinalprivado.info:80/1533784/1533784/19068', 'http://www.fontedecanais.tv/logos/canais/cazetv.png', NULL, 0, 0, 'original', NULL),
(442, 8, 'CazeTV 02', 'http://sinalprivado.info:80/1533784/1533784/19069', 'http://www.fontedecanais.tv/logos/canais/cazetv.png', NULL, 0, 0, 'original', NULL),
(443, 8, 'CazeTV 03', 'http://sinalprivado.info:80/1533784/1533784/19070', 'http://www.fontedecanais.tv/logos/canais/cazetv.png', NULL, 0, 0, 'original', NULL),
(444, 8, 'Paramount+ 1', 'http://sinalprivado.info:80/1533784/1533784/19071', 'https://www.fontedecanais.tv/logos/canais/paramountplus.png', NULL, 0, 0, 'original', NULL),
(445, 8, 'Paramount+ 2', 'http://sinalprivado.info:80/1533784/1533784/19072', 'https://www.fontedecanais.tv/logos/canais/paramountplus.png', NULL, 0, 0, 'original', NULL),
(446, 8, 'Paramount+ 3', 'http://sinalprivado.info:80/1533784/1533784/19073', 'https://www.fontedecanais.tv/logos/canais/paramountplus.png', NULL, 0, 0, 'original', NULL),
(447, 8, 'Paramount+ 4', 'http://sinalprivado.info:80/1533784/1533784/19074', 'https://www.fontedecanais.tv/logos/canais/paramountplus.png', NULL, 0, 0, 'original', NULL),
(448, 8, 'XSports', 'http://sinalprivado.info:80/1533784/1533784/19079', 'https://www.fontedecanais.tv/logos/canais/xsports.png', NULL, 0, 0, 'original', NULL),
(449, 8, 'Canal Goat 01', 'http://sinalprivado.info:80/1533784/1533784/19080', 'http://www.fontedecanais.tv/logos/canais/canalgoat.png', NULL, 0, 0, 'original', NULL),
(450, 8, 'Canal Goat 02', 'http://sinalprivado.info:80/1533784/1533784/19081', 'http://www.fontedecanais.tv/logos/canais/canalgoat.png', NULL, 0, 0, 'original', NULL),
(451, 8, 'Canal Goat 03', 'http://sinalprivado.info:80/1533784/1533784/19082', 'http://www.fontedecanais.tv/logos/canais/canalgoat.png', NULL, 0, 0, 'original', NULL),
(452, 9, '﻿Premiere 1 FHD', 'http://sinalprivado.info:80/1533784/1533784/20000', 'http://www.fontedecanais.tv/logos/canais/premiere.png', NULL, 0, 0, 'original', NULL),
(453, 9, 'Premiere 1 HD', 'http://sinalprivado.info:80/1533784/1533784/20001', 'http://www.fontedecanais.tv/logos/canais/premiere.png', NULL, 0, 1, 'original', '2026-01-05 03:02:27'),
(454, 9, 'Premiere 1 SD', 'http://sinalprivado.info:80/1533784/1533784/20002', 'http://www.fontedecanais.tv/logos/canais/premiere.png', NULL, 0, 1, 'original', '2026-01-05 03:02:27'),
(455, 9, 'Premiere 2 FHD', 'http://sinalprivado.info:80/1533784/1533784/20003', 'http://www.fontedecanais.tv/logos/canais/premiere.png', 'Premiere2.br', 0, 0, 'original', NULL),
(456, 9, 'Premiere 2 HD', 'http://sinalprivado.info:80/1533784/1533784/20004', 'http://www.fontedecanais.tv/logos/canais/premiere.png', 'Premiere2.br', 0, 0, 'original', NULL),
(457, 9, 'Premiere 2 SD', 'http://sinalprivado.info:80/1533784/1533784/20005', 'http://www.fontedecanais.tv/logos/canais/premiere.png', 'Premiere2.br', 0, 0, 'original', NULL),
(458, 9, 'Premiere 3 FHD', 'http://sinalprivado.info:80/1533784/1533784/20006', 'http://www.fontedecanais.tv/logos/canais/premiere.png', 'Premiere3.br', 0, 0, 'original', NULL),
(459, 9, 'Premiere 3 HD', 'http://sinalprivado.info:80/1533784/1533784/20007', 'http://www.fontedecanais.tv/logos/canais/premiere.png', 'Premiere3.br', 0, 0, 'original', NULL),
(460, 9, 'Premiere 3 SD', 'http://sinalprivado.info:80/1533784/1533784/20008', 'http://www.fontedecanais.tv/logos/canais/premiere.png', 'Premiere3.br', 0, 0, 'original', NULL),
(461, 9, 'Premiere 4 FHD', 'http://sinalprivado.info:80/1533784/1533784/20009', 'http://www.fontedecanais.tv/logos/canais/premiere.png', 'Premiere4.br', 0, 0, 'original', NULL),
(462, 9, 'Premiere 4 HD', 'http://sinalprivado.info:80/1533784/1533784/20010', 'http://www.fontedecanais.tv/logos/canais/premiere.png', 'Premiere4.br', 0, 0, 'original', NULL),
(463, 9, 'Premiere 4 SD', 'http://sinalprivado.info:80/1533784/1533784/20011', 'http://www.fontedecanais.tv/logos/canais/premiere.png', 'Premiere4.br', 0, 0, 'original', NULL),
(464, 9, 'Premiere 5 FHD', 'http://sinalprivado.info:80/1533784/1533784/20012', 'http://www.fontedecanais.tv/logos/canais/premiere.png', 'Premiere5.br', 0, 0, 'original', NULL),
(465, 9, 'Premiere 5 HD', 'http://sinalprivado.info:80/1533784/1533784/20013', 'http://www.fontedecanais.tv/logos/canais/premiere.png', 'Premiere5.br', 0, 0, 'original', NULL),
(466, 9, 'Premiere 5 SD', 'http://sinalprivado.info:80/1533784/1533784/20014', 'http://www.fontedecanais.tv/logos/canais/premiere.png', 'Premiere5.br', 0, 0, 'original', NULL),
(467, 9, 'Premiere 6 FHD', 'http://sinalprivado.info:80/1533784/1533784/20015', 'http://www.fontedecanais.tv/logos/canais/premiere.png', 'Premiere6.br', 0, 0, 'original', NULL),
(468, 9, 'Premiere 6 HD', 'http://sinalprivado.info:80/1533784/1533784/20016', 'http://www.fontedecanais.tv/logos/canais/premiere.png', 'Premiere6.br', 0, 0, 'original', NULL),
(469, 9, 'Premiere 6 SD', 'http://sinalprivado.info:80/1533784/1533784/20017', 'http://www.fontedecanais.tv/logos/canais/premiere.png', 'Premiere6.br', 0, 0, 'original', NULL),
(470, 9, 'Premiere 7 FHD', 'http://sinalprivado.info:80/1533784/1533784/20018', 'http://www.fontedecanais.tv/logos/canais/premiere.png', 'Premiere7.br', 0, 0, 'original', NULL),
(471, 9, 'Premiere 7 HD', 'http://sinalprivado.info:80/1533784/1533784/20019', 'http://www.fontedecanais.tv/logos/canais/premiere.png', 'Premiere7.br', 0, 0, 'original', NULL),
(472, 9, 'Premiere 7 SD', 'http://sinalprivado.info:80/1533784/1533784/20020', 'http://www.fontedecanais.tv/logos/canais/premiere.png', 'Premiere7.br', 0, 0, 'original', NULL),
(473, 9, 'Premiere 8 FHD', 'http://sinalprivado.info:80/1533784/1533784/20021', 'http://www.fontedecanais.tv/logos/canais/premiere.png', NULL, 0, 0, 'original', NULL),
(474, 9, 'Premiere 8 HD', 'http://sinalprivado.info:80/1533784/1533784/20022', 'http://www.fontedecanais.tv/logos/canais/premiere.png', NULL, 0, 0, 'original', NULL),
(475, 9, 'Premiere 8 SD', 'http://sinalprivado.info:80/1533784/1533784/20023', 'http://www.fontedecanais.tv/logos/canais/premiere.png', NULL, 0, 0, 'original', NULL),
(476, 10, 'SporTV FHD', 'http://sinalprivado.info:80/1533784/1533784/21000', 'http://www.fontedecanais.tv/logos/canais/sportv.png', 'Sportv.br', 0, 0, 'original', NULL),
(477, 10, 'SporTV HD', 'http://sinalprivado.info:80/1533784/1533784/21001', 'http://www.fontedecanais.tv/logos/canais/sportv.png', 'Sportv.br', 0, 1, 'original', '2026-01-05 03:02:37'),
(478, 10, 'SporTV SD', 'http://sinalprivado.info:80/1533784/1533784/21002', 'http://www.fontedecanais.tv/logos/canais/sportv.png', 'Sportv.br', 0, 1, 'original', '2026-01-05 03:02:37'),
(479, 10, 'SporTV 2 FHD', 'http://sinalprivado.info:80/1533784/1533784/21003', 'http://www.fontedecanais.tv/logos/canais/sportv2.png', 'Sportv2.br', 0, 0, 'original', NULL),
(480, 10, 'SporTV 2 HD', 'http://sinalprivado.info:80/1533784/1533784/21004', 'http://www.fontedecanais.tv/logos/canais/sportv2.png', 'Sportv2.br', 0, 0, 'original', NULL),
(481, 10, 'SporTV 2 SD', 'http://sinalprivado.info:80/1533784/1533784/21005', 'http://www.fontedecanais.tv/logos/canais/sportv2.png', 'Sportv2.br', 0, 0, 'original', NULL),
(482, 10, 'SporTV 3 FHD', 'http://sinalprivado.info:80/1533784/1533784/21006', 'http://www.fontedecanais.tv/logos/canais/sportv3.png', 'Sportv3.br', 0, 0, 'original', NULL),
(483, 10, 'SporTV 3 HD', 'http://sinalprivado.info:80/1533784/1533784/21007', 'http://www.fontedecanais.tv/logos/canais/sportv3.png', 'Sportv3.br', 0, 0, 'original', NULL),
(484, 10, 'SporTV 3 SD', 'http://sinalprivado.info:80/1533784/1533784/21008', 'http://www.fontedecanais.tv/logos/canais/sportv3.png', 'Sportv3.br', 0, 0, 'original', NULL),
(485, 10, 'SporTV 4 FHD', 'http://sinalprivado.info:80/1533784/1533784/21009', 'http://www.fontedecanais.tv/logos/canais/sportv4.png', NULL, 0, 0, 'original', NULL),
(486, 10, 'SporTV 4 HD', 'http://sinalprivado.info:80/1533784/1533784/21010', 'http://www.fontedecanais.tv/logos/canais/sportv4.png', NULL, 0, 0, 'original', NULL),
(487, 10, 'SporTV 4 SD', 'http://sinalprivado.info:80/1533784/1533784/21011', 'http://www.fontedecanais.tv/logos/canais/sportv4.png', NULL, 0, 0, 'original', NULL),
(488, 11, 'ESPN FHD', 'http://sinalprivado.info:80/1533784/1533784/22000', 'http://www.fontedecanais.tv/logos/canais/espn.png', 'Espn.br', 0, 0, 'original', NULL),
(489, 11, 'ESPN HD', 'http://sinalprivado.info:80/1533784/1533784/22001', 'http://www.fontedecanais.tv/logos/canais/espn.png', 'Espn.br', 0, 0, 'original', NULL),
(490, 11, 'ESPN SD', 'http://sinalprivado.info:80/1533784/1533784/22002', 'http://www.fontedecanais.tv/logos/canais/espn.png', 'Espn.br', 0, 0, 'original', NULL),
(491, 11, 'ESPN 2 FHD', 'http://sinalprivado.info:80/1533784/1533784/22003', 'http://www.fontedecanais.tv/logos/canais/espn2.png', 'ESPN2.br', 0, 0, 'original', NULL),
(492, 11, 'ESPN 2 HD', 'http://sinalprivado.info:80/1533784/1533784/22004', 'http://www.fontedecanais.tv/logos/canais/espn2.png', 'ESPN2.br', 0, 0, 'original', NULL),
(493, 11, 'ESPN 2 SD', 'http://sinalprivado.info:80/1533784/1533784/22005', 'http://www.fontedecanais.tv/logos/canais/espn2.png', 'ESPN2.br', 0, 0, 'original', NULL),
(494, 11, 'ESPN 3 FHD', 'http://sinalprivado.info:80/1533784/1533784/22006', 'http://www.fontedecanais.tv/logos/canais/espn3.png', 'ESPN3.br', 0, 0, 'original', NULL),
(495, 11, 'ESPN 3 HD', 'http://sinalprivado.info:80/1533784/1533784/22007', 'http://www.fontedecanais.tv/logos/canais/espn3.png', 'ESPN3.br', 0, 0, 'original', NULL),
(496, 11, 'ESPN 3 SD', 'http://sinalprivado.info:80/1533784/1533784/22008', 'http://www.fontedecanais.tv/logos/canais/espn3.png', 'ESPN3.br', 0, 0, 'original', NULL),
(497, 11, 'ESPN 4 FHD', 'http://sinalprivado.info:80/1533784/1533784/22009', 'http://www.fontedecanais.tv/logos/canais/espn4.png', 'ESPN4.br', 0, 0, 'original', NULL),
(498, 11, 'ESPN 4 HD', 'http://sinalprivado.info:80/1533784/1533784/22010', 'http://www.fontedecanais.tv/logos/canais/espn4.png', 'ESPN4.br', 0, 0, 'original', NULL),
(499, 11, 'ESPN 4 SD', 'http://sinalprivado.info:80/1533784/1533784/22011', 'http://www.fontedecanais.tv/logos/canais/espn4.png', 'ESPN4.br', 0, 0, 'original', NULL),
(500, 11, 'ESPN 5 FHD', 'http://sinalprivado.info:80/1533784/1533784/22012', 'http://www.fontedecanais.tv/logos/canais/espn5.png', NULL, 0, 0, 'original', NULL),
(501, 11, 'ESPN 5 HD', 'http://sinalprivado.info:80/1533784/1533784/22013', 'http://www.fontedecanais.tv/logos/canais/espn5.png', NULL, 0, 0, 'original', NULL),
(502, 11, 'ESPN 5 SD', 'http://sinalprivado.info:80/1533784/1533784/22014', 'http://www.fontedecanais.tv/logos/canais/espn5.png', NULL, 0, 0, 'original', NULL),
(503, 11, 'ESPN 6 FHD', 'http://sinalprivado.info:80/1533784/1533784/22015', 'http://www.fontedecanais.tv/logos/canais/espn6.png', NULL, 0, 0, 'original', NULL),
(504, 11, 'ESPN 6 HD', 'http://sinalprivado.info:80/1533784/1533784/22016', 'http://www.fontedecanais.tv/logos/canais/espn6.png', NULL, 0, 0, 'original', NULL),
(505, 11, 'ESPN 6 SD', 'http://sinalprivado.info:80/1533784/1533784/22017', 'http://www.fontedecanais.tv/logos/canais/espn6.png', NULL, 0, 0, 'original', NULL),
(506, 12, 'Animal Planet FHD', 'http://sinalprivado.info:80/1533784/1533784/23000', 'http://www.fontedecanais.tv/logos/canais/animalplanet.png', 'Animalplanet.br', 0, 0, 'original', NULL),
(507, 12, 'Animal Planet HD', 'http://sinalprivado.info:80/1533784/1533784/23001', 'http://www.fontedecanais.tv/logos/canais/animalplanet.png', 'Animalplanet.br', 0, 0, 'original', NULL),
(508, 12, 'Animal Planet SD', 'http://sinalprivado.info:80/1533784/1533784/23002', 'http://www.fontedecanais.tv/logos/canais/animalplanet.png', 'Animalplanet.br', 0, 0, 'original', NULL),
(509, 12, 'Arte1 FHD', 'http://sinalprivado.info:80/1533784/1533784/23003', 'http://www.fontedecanais.tv/logos/canais/arte1.png', 'Arte1.br', 0, 0, 'original', NULL),
(510, 12, 'Arte1 HD', 'http://sinalprivado.info:80/1533784/1533784/23004', 'http://www.fontedecanais.tv/logos/canais/arte1.png', 'Arte1.br', 0, 0, 'original', NULL),
(511, 12, 'Arte1 SD', 'http://sinalprivado.info:80/1533784/1533784/23005', 'http://www.fontedecanais.tv/logos/canais/arte1.png', 'Arte1.br', 0, 0, 'original', NULL),
(512, 12, 'Curta! FHD', 'http://sinalprivado.info:80/1533784/1533784/23006', 'http://www.fontedecanais.tv/logos/canais/curta.png', 'Curta FHD [Alter]', 0, 0, 'original', NULL),
(513, 12, 'Curta! HD', 'http://sinalprivado.info:80/1533784/1533784/23007', 'http://www.fontedecanais.tv/logos/canais/curta.png', 'Curta FHD [Alter]', 0, 0, 'original', NULL),
(514, 12, 'Curta! SD', 'http://sinalprivado.info:80/1533784/1533784/23008', 'http://www.fontedecanais.tv/logos/canais/curta.png', 'Curta FHD [Alter]', 0, 0, 'original', NULL),
(515, 12, 'Discovery Channel FHD', 'http://sinalprivado.info:80/1533784/1533784/23009', 'http://www.fontedecanais.tv/logos/canais/discoverychannel.png', 'Discovery Channel 4K', 0, 0, 'original', NULL),
(516, 12, 'Discovery Channel HD', 'http://sinalprivado.info:80/1533784/1533784/23010', 'http://www.fontedecanais.tv/logos/canais/discoverychannel.png', 'Discovery Channel 4K', 0, 0, 'original', NULL),
(517, 12, 'Discovery Channel SD', 'http://sinalprivado.info:80/1533784/1533784/23011', 'http://www.fontedecanais.tv/logos/canais/discoverychannel.png', 'Discovery Channel 4K', 0, 0, 'original', NULL),
(518, 12, 'Discovery Science FHD', 'http://sinalprivado.info:80/1533784/1533784/23012', 'http://www.fontedecanais.tv/logos/canais/discoveryscience.png', 'DiscoveryScience.br', 0, 0, 'original', NULL),
(519, 12, 'Discovery Science HD', 'http://sinalprivado.info:80/1533784/1533784/23013', 'http://www.fontedecanais.tv/logos/canais/discoveryscience.png', 'DiscoveryScience.br', 0, 0, 'original', NULL),
(520, 12, 'Discovery Science SD', 'http://sinalprivado.info:80/1533784/1533784/23014', 'http://www.fontedecanais.tv/logos/canais/discoveryscience.png', 'DiscoveryScience.br', 0, 0, 'original', NULL),
(521, 12, 'Discovery Theater FHD', 'http://sinalprivado.info:80/1533784/1533784/23015', 'http://www.fontedecanais.tv/logos/canais/discoverytheater.png', 'Discoverytheaterhd.br', 0, 0, 'original', NULL),
(522, 12, 'Discovery Theater HD', 'http://sinalprivado.info:80/1533784/1533784/23016', 'http://www.fontedecanais.tv/logos/canais/discoverytheater.png', 'Discoverytheaterhd.br', 0, 0, 'original', NULL),
(523, 12, 'Discovery Theater SD', 'http://sinalprivado.info:80/1533784/1533784/23017', 'http://www.fontedecanais.tv/logos/canais/discoverytheater.png', 'Discoverytheaterhd.br', 0, 0, 'original', NULL),
(524, 12, 'Discovery World FHD', 'http://sinalprivado.info:80/1533784/1533784/23018', 'http://www.fontedecanais.tv/logos/canais/discoveryworld.png', 'Discoveryworldhd.br', 0, 0, 'original', NULL),
(525, 12, 'Discovery World HD', 'http://sinalprivado.info:80/1533784/1533784/23019', 'http://www.fontedecanais.tv/logos/canais/discoveryworld.png', 'Discoveryworldhd.br', 0, 0, 'original', NULL),
(526, 12, 'Discovery World SD', 'http://sinalprivado.info:80/1533784/1533784/23020', 'http://www.fontedecanais.tv/logos/canais/discoveryworld.png', 'Discoveryworldhd.br', 0, 0, 'original', NULL),
(527, 12, 'H2 FHD', 'http://sinalprivado.info:80/1533784/1533784/23021', 'http://www.fontedecanais.tv/logos/canais/h2.png', 'H2.br', 0, 0, 'original', NULL),
(528, 12, 'H2 HD', 'http://sinalprivado.info:80/1533784/1533784/23022', 'http://www.fontedecanais.tv/logos/canais/h2.png', 'H2.br', 0, 0, 'original', NULL),
(529, 12, 'H2 SD', 'http://sinalprivado.info:80/1533784/1533784/23023', 'http://www.fontedecanais.tv/logos/canais/h2.png', 'H2.br', 0, 0, 'original', NULL),
(530, 12, 'HGTV FHD', 'http://sinalprivado.info:80/1533784/1533784/23024', 'http://www.fontedecanais.tv/logos/canais/hgtv.png', NULL, 0, 0, 'original', NULL),
(531, 12, 'HGTV HD', 'http://sinalprivado.info:80/1533784/1533784/23025', 'http://www.fontedecanais.tv/logos/canais/hgtv.png', NULL, 0, 0, 'original', NULL),
(532, 12, 'HGTV SD', 'http://sinalprivado.info:80/1533784/1533784/23026', 'http://www.fontedecanais.tv/logos/canais/hgtv.png', NULL, 0, 0, 'original', NULL),
(533, 12, 'History FHD', 'http://sinalprivado.info:80/1533784/1533784/23027', 'http://www.fontedecanais.tv/logos/canais/history.png', 'History FHD H.265', 0, 0, 'original', NULL),
(534, 12, 'History HD', 'http://sinalprivado.info:80/1533784/1533784/23028', 'http://www.fontedecanais.tv/logos/canais/history.png', 'History FHD H.265', 0, 0, 'original', NULL),
(535, 12, 'History SD', 'http://sinalprivado.info:80/1533784/1533784/23029', 'http://www.fontedecanais.tv/logos/canais/history.png', 'History FHD H.265', 0, 0, 'original', NULL),
(536, 12, 'ID: Investigação Discovery FHD', 'http://sinalprivado.info:80/1533784/1533784/23030', 'http://www.fontedecanais.tv/logos/canais/id.png', NULL, 0, 0, 'original', NULL),
(537, 12, 'ID: Investigação Discovery HD', 'http://sinalprivado.info:80/1533784/1533784/23031', 'http://www.fontedecanais.tv/logos/canais/id.png', NULL, 0, 0, 'original', NULL),
(538, 12, 'ID: Investigação Discovery SD', 'http://sinalprivado.info:80/1533784/1533784/23032', 'http://www.fontedecanais.tv/logos/canais/id.png', NULL, 0, 0, 'original', NULL),
(539, 13, 'Cartoon Network FHD', 'http://sinalprivado.info:80/1533784/1533784/24003', 'http://www.fontedecanais.tv/logos/canais/cartoonnetwork.png', 'Cartoonnetwork.br', 0, 0, 'original', NULL),
(540, 13, 'Cartoon Network HD', 'http://sinalprivado.info:80/1533784/1533784/24004', 'http://www.fontedecanais.tv/logos/canais/cartoonnetwork.png', 'Cartoonnetwork.br', 0, 0, 'original', NULL),
(541, 13, 'Cartoon Network SD', 'http://sinalprivado.info:80/1533784/1533784/24005', 'http://www.fontedecanais.tv/logos/canais/cartoonnetwork.png', 'Cartoonnetwork.br', 0, 0, 'original', NULL),
(542, 13, 'Cartoonito FHD', 'http://sinalprivado.info:80/1533784/1533784/24006', 'http://www.fontedecanais.tv/logos/canais/cartoonito.png', NULL, 0, 0, 'original', NULL),
(543, 13, 'Cartoonito HD', 'http://sinalprivado.info:80/1533784/1533784/24007', 'http://www.fontedecanais.tv/logos/canais/cartoonito.png', NULL, 0, 0, 'original', NULL),
(544, 13, 'Cartoonito SD', 'http://sinalprivado.info:80/1533784/1533784/24008', 'http://www.fontedecanais.tv/logos/canais/cartoonito.png', NULL, 0, 0, 'original', NULL),
(545, 13, 'Discovery Kids FHD', 'http://sinalprivado.info:80/1533784/1533784/24009', 'http://www.fontedecanais.tv/logos/canais/discoverykids.png', 'Discoverykids.br', 0, 0, 'original', NULL),
(546, 13, 'Discovery Kids HD', 'http://sinalprivado.info:80/1533784/1533784/24010', 'http://www.fontedecanais.tv/logos/canais/discoverykids.png', 'Discoverykids.br', 0, 0, 'original', NULL),
(547, 13, 'Discovery Kids SD', 'http://sinalprivado.info:80/1533784/1533784/24011', 'http://www.fontedecanais.tv/logos/canais/discoverykids.png', 'Discoverykids.br', 0, 0, 'original', NULL),
(548, 13, 'Gloob FHD', 'http://sinalprivado.info:80/1533784/1533784/24015', 'http://www.fontedecanais.tv/logos/canais/gloob.png', 'Gloob.br', 0, 0, 'original', NULL),
(549, 13, 'Gloob HD', 'http://sinalprivado.info:80/1533784/1533784/24016', 'http://www.fontedecanais.tv/logos/canais/gloob.png', 'Gloob.br', 0, 0, 'original', NULL),
(550, 13, 'Gloob SD', 'http://sinalprivado.info:80/1533784/1533784/24017', 'http://www.fontedecanais.tv/logos/canais/gloob.png', 'Gloob.br', 0, 0, 'original', NULL),
(551, 13, 'Gloobinho FHD', 'http://sinalprivado.info:80/1533784/1533784/24018', 'http://www.fontedecanais.tv/logos/canais/gloobinho.png', NULL, 0, 0, 'original', NULL),
(552, 13, 'Gloobinho HD', 'http://sinalprivado.info:80/1533784/1533784/24019', 'http://www.fontedecanais.tv/logos/canais/gloobinho.png', NULL, 0, 0, 'original', NULL),
(553, 13, 'Gloobinho SD', 'http://sinalprivado.info:80/1533784/1533784/24020', 'http://www.fontedecanais.tv/logos/canais/gloobinho.png', NULL, 0, 0, 'original', NULL),
(554, 13, 'Nick Jr FHD', 'http://sinalprivado.info:80/1533784/1533784/24021', 'http://www.fontedecanais.tv/logos/canais/nickjr.png', 'NickJr.br', 0, 0, 'original', NULL),
(555, 13, 'Nick Jr HD', 'http://sinalprivado.info:80/1533784/1533784/24022', 'http://www.fontedecanais.tv/logos/canais/nickjr.png', 'NickJr.br', 0, 0, 'original', NULL),
(556, 13, 'Nick Jr SD', 'http://sinalprivado.info:80/1533784/1533784/24023', 'http://www.fontedecanais.tv/logos/canais/nickjr.png', 'NickJr.br', 0, 0, 'original', NULL),
(557, 13, 'Nickelodeon FHD', 'http://sinalprivado.info:80/1533784/1533784/24024', 'http://www.fontedecanais.tv/logos/canais/nickelodeon.png', 'Nickelodeon.br', 0, 0, 'original', NULL),
(558, 13, 'Nickelodeon HD', 'http://sinalprivado.info:80/1533784/1533784/24025', 'http://www.fontedecanais.tv/logos/canais/nickelodeon.png', 'Nickelodeon.br', 0, 0, 'original', NULL),
(559, 13, 'Nickelodeon SD', 'http://sinalprivado.info:80/1533784/1533784/24026', 'http://www.fontedecanais.tv/logos/canais/nickelodeon.png', 'Nickelodeon.br', 0, 0, 'original', NULL),
(560, 13, 'Tooncast FHD', 'http://sinalprivado.info:80/1533784/1533784/24027', 'http://www.fontedecanais.tv/logos/canais/tooncast.png', 'Tooncast.br', 0, 0, 'original', NULL),
(561, 13, 'Tooncast HD', 'http://sinalprivado.info:80/1533784/1533784/24028', 'http://www.fontedecanais.tv/logos/canais/tooncast.png', 'Tooncast.br', 0, 0, 'original', NULL),
(562, 13, 'Tooncast SD', 'http://sinalprivado.info:80/1533784/1533784/24029', 'http://www.fontedecanais.tv/logos/canais/tooncast.png', 'Tooncast.br', 0, 0, 'original', NULL),
(563, 13, 'ZooMoo FHD', 'http://sinalprivado.info:80/1533784/1533784/24030', 'http://www.fontedecanais.tv/logos/canais/zoomoo.png', 'Zoomoo.br', 0, 0, 'original', NULL),
(564, 13, 'ZooMoo HD', 'http://sinalprivado.info:80/1533784/1533784/24031', 'http://www.fontedecanais.tv/logos/canais/zoomoo.png', 'Zoomoo.br', 0, 0, 'original', NULL),
(565, 13, 'ZooMoo SD', 'http://sinalprivado.info:80/1533784/1533784/24032', 'http://www.fontedecanais.tv/logos/canais/zoomoo.png', 'Zoomoo.br', 0, 0, 'original', NULL),
(566, 13, 'TV Rá Tim Bum FHD', 'http://sinalprivado.info:80/1533784/1533784/24039', 'http://www.fontedecanais.tv/logos/canais/tvratimbum.png', 'TV Ra tim bum FHD', 0, 0, 'original', NULL),
(567, 13, 'TV Rá Tim Bum HD', 'http://sinalprivado.info:80/1533784/1533784/24040', 'http://www.fontedecanais.tv/logos/canais/tvratimbum.png', 'TV Ra tim bum HD', 0, 0, 'original', NULL),
(568, 13, 'TV Rá Tim Bum SD', 'http://sinalprivado.info:80/1533784/1533784/24041', 'http://www.fontedecanais.tv/logos/canais/tvratimbum.png', 'TV Ra tim bum SD', 0, 0, 'original', NULL),
(569, 14, 'Band News FHD', 'http://sinalprivado.info:80/1533784/1533784/25000', 'http://www.fontedecanais.tv/logos/canais/bandnews.png', 'Bandnews.br', 0, 0, 'original', NULL),
(570, 14, 'Band News HD', 'http://sinalprivado.info:80/1533784/1533784/25001', 'http://www.fontedecanais.tv/logos/canais/bandnews.png', 'Bandnews.br', 0, 0, 'original', NULL),
(571, 14, 'Band News SD', 'http://sinalprivado.info:80/1533784/1533784/25002', 'http://www.fontedecanais.tv/logos/canais/bandnews.png', 'Bandnews.br', 0, 0, 'original', NULL),
(572, 14, 'CNN Brasil FHD', 'http://sinalprivado.info:80/1533784/1533784/25003', 'http://www.fontedecanais.tv/logos/canais/cnnbrasil.png', 'CNNBrasil.br', 0, 0, 'original', NULL),
(573, 14, 'CNN Brasil HD', 'http://sinalprivado.info:80/1533784/1533784/25004', 'http://www.fontedecanais.tv/logos/canais/cnnbrasil.png', 'CNNBrasil.br', 0, 0, 'original', NULL),
(574, 14, 'CNN Brasil SD', 'http://sinalprivado.info:80/1533784/1533784/25005', 'http://www.fontedecanais.tv/logos/canais/cnnbrasil.png', 'CNNBrasil.br', 0, 0, 'original', NULL),
(575, 14, 'Globo News FHD', 'http://sinalprivado.info:80/1533784/1533784/25006', 'http://www.fontedecanais.tv/logos/canais/globonews.png', 'Globonewshd.br', 0, 0, 'original', NULL),
(576, 14, 'Globo News HD', 'http://sinalprivado.info:80/1533784/1533784/25007', 'http://www.fontedecanais.tv/logos/canais/globonews.png', 'Globonewshd.br', 0, 0, 'original', NULL),
(577, 14, 'Globo News SD', 'http://sinalprivado.info:80/1533784/1533784/25008', 'http://www.fontedecanais.tv/logos/canais/globonews.png', 'Globonewshd.br', 0, 0, 'original', NULL),
(578, 14, 'Jovem Pan News FHD', 'http://sinalprivado.info:80/1533784/1533784/25009', 'http://www.fontedecanais.tv/logos/canais/jpnews.png', NULL, 0, 0, 'original', NULL),
(579, 14, 'Jovem Pan News HD', 'http://sinalprivado.info:80/1533784/1533784/25010', 'http://www.fontedecanais.tv/logos/canais/jpnews.png', NULL, 0, 0, 'original', NULL),
(580, 14, 'Jovem Pan News SD', 'http://sinalprivado.info:80/1533784/1533784/25011', 'http://www.fontedecanais.tv/logos/canais/jpnews.png', NULL, 0, 0, 'original', NULL);
INSERT INTO `channels` (`id`, `category_id`, `name`, `stream_url`, `logo_url`, `epg_id`, `pid`, `running`, `transcode_quality`, `uptime`) VALUES
(581, 14, 'Record News FHD', 'http://sinalprivado.info:80/1533784/1533784/25012', 'http://www.fontedecanais.tv/logos/canais/recordnews.png', 'Recordnews.br', 0, 0, 'original', NULL),
(582, 14, 'Record News HD', 'http://sinalprivado.info:80/1533784/1533784/25013', 'http://www.fontedecanais.tv/logos/canais/recordnews.png', 'Recordnews.br', 0, 0, 'original', NULL),
(583, 14, 'Record News SD', 'http://sinalprivado.info:80/1533784/1533784/25014', 'http://www.fontedecanais.tv/logos/canais/recordnews.png', 'Recordnews.br', 0, 0, 'original', NULL),
(584, 14, 'CNN Money FHD', 'http://sinalprivado.info:80/1533784/1533784/25015', 'http://www.fontedecanais.tv/logos/canais/cnnmoney.png', NULL, 0, 0, 'original', NULL),
(585, 14, 'CNN Money HD', 'http://sinalprivado.info:80/1533784/1533784/25016', 'http://www.fontedecanais.tv/logos/canais/cnnmoney.png', NULL, 0, 0, 'original', NULL),
(586, 14, 'CNN Money SD', 'http://sinalprivado.info:80/1533784/1533784/25017', 'http://www.fontedecanais.tv/logos/canais/cnnmoney.png', NULL, 0, 0, 'original', NULL),
(587, 14, 'Times Brasil (CNBC) FHD', 'http://sinalprivado.info:80/1533784/1533784/25018', 'http://www.fontedecanais.tv/logos/canais/timesbrasil.png', NULL, 0, 0, 'original', NULL),
(588, 14, 'Times Brasil (CNBC) HD', 'http://sinalprivado.info:80/1533784/1533784/25019', 'http://www.fontedecanais.tv/logos/canais/timesbrasil.png', NULL, 0, 0, 'original', NULL),
(589, 14, 'Times Brasil (CNBC) SD', 'http://sinalprivado.info:80/1533784/1533784/25020', 'http://www.fontedecanais.tv/logos/canais/timesbrasil.png', NULL, 0, 0, 'original', NULL),
(590, 14, 'SBT News FHD', 'http://sinalprivado.info:80/1533784/1533784/25021', 'http://www.fontedecanais.tv/logos/canais/sbtnews.png', NULL, 0, 0, 'original', NULL),
(591, 14, 'SBT News HD', 'http://sinalprivado.info:80/1533784/1533784/25022', 'http://www.fontedecanais.tv/logos/canais/sbtnews.png', NULL, 0, 0, 'original', NULL),
(592, 14, 'SBT News SD', 'http://sinalprivado.info:80/1533784/1533784/25023', 'http://www.fontedecanais.tv/logos/canais/sbtnews.png', NULL, 0, 0, 'original', NULL),
(593, 15, 'Canção Nova', 'http://sinalprivado.info:80/1533784/1533784/26000', 'http://www.fontedecanais.tv/logos/canais/cancaonova.png', NULL, 0, 0, 'original', NULL),
(594, 15, 'Novo Tempo', 'http://sinalprivado.info:80/1533784/1533784/26001', 'http://www.fontedecanais.tv/logos/canais/novotempo.png', 'NovoTempo SD', 0, 0, 'original', NULL),
(595, 15, 'Rede Familia', 'http://sinalprivado.info:80/1533784/1533784/26002', 'http://www.fontedecanais.tv/logos/canais/redefamilia.png', NULL, 0, 0, 'original', NULL),
(596, 15, 'Rede Gospel', 'http://sinalprivado.info:80/1533784/1533784/26003', 'http://www.fontedecanais.tv/logos/canais/redegospel.png', NULL, 0, 0, 'original', NULL),
(597, 15, 'Rede Vida', 'http://sinalprivado.info:80/1533784/1533784/26004', 'http://www.fontedecanais.tv/logos/canais/redevida.png', 'Redevida.br', 0, 0, 'original', NULL),
(598, 15, 'Rede CNT', 'http://sinalprivado.info:80/1533784/1533784/26005', 'http://www.fontedecanais.tv/logos/canais/cnt.png', NULL, 0, 0, 'original', NULL),
(599, 15, 'TV Aparecida', 'http://sinalprivado.info:80/1533784/1533784/26006', 'http://www.fontedecanais.tv/logos/canais/tvaparecida.png', 'Tvaparecida.br', 0, 0, 'original', NULL),
(600, 15, 'TV Pai Eterno', 'http://sinalprivado.info:80/1533784/1533784/26007', 'http://www.fontedecanais.tv/logos/canais/tvpaieterno.png', NULL, 0, 0, 'original', NULL),
(601, 15, 'Sem Canal', 'http://sinalprivado.info:80/1533784/1533784/26008', '', NULL, 0, 0, 'original', NULL),
(602, 15, 'TV Evangelizar', 'http://sinalprivado.info:80/1533784/1533784/26009', 'http://www.fontedecanais.tv/logos/canais/tvevangelizar.png', 'TV Evangelizar SD', 0, 0, 'original', NULL),
(603, 16, 'Record TV Bahia FHD', 'http://sinalprivado.info:80/1533784/1533784/27003', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(604, 16, 'Record TV Bahia HD', 'http://sinalprivado.info:80/1533784/1533784/27004', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(605, 16, 'Record TV Bahia SD', 'http://sinalprivado.info:80/1533784/1533784/27005', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(606, 16, 'Record TV Bahia Itabuna FHD', 'http://sinalprivado.info:80/1533784/1533784/27006', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(607, 16, 'Record TV Bahia Itabuna HD', 'http://sinalprivado.info:80/1533784/1533784/27007', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(608, 16, 'Record TV Bahia Itabuna SD', 'http://sinalprivado.info:80/1533784/1533784/27008', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(609, 16, 'Record TV Bauru FHD', 'http://sinalprivado.info:80/1533784/1533784/27009', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(610, 16, 'Record TV Bauru HD', 'http://sinalprivado.info:80/1533784/1533784/27010', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(611, 16, 'Record TV Bauru SD', 'http://sinalprivado.info:80/1533784/1533784/27011', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(612, 16, 'Record TV Belém FHD', 'http://sinalprivado.info:80/1533784/1533784/27012', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(613, 16, 'Record TV Belém HD', 'http://sinalprivado.info:80/1533784/1533784/27013', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(614, 16, 'Record TV Belém SD', 'http://sinalprivado.info:80/1533784/1533784/27014', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(615, 16, 'Record TV Brasília FHD', 'http://sinalprivado.info:80/1533784/1533784/27015', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(616, 16, 'Record TV Brasília HD', 'http://sinalprivado.info:80/1533784/1533784/27016', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(617, 16, 'Record TV Brasília SD', 'http://sinalprivado.info:80/1533784/1533784/27017', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(618, 16, 'Record TV Campinas FHD', 'http://sinalprivado.info:80/1533784/1533784/27018', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(619, 16, 'Record TV Campinas HD', 'http://sinalprivado.info:80/1533784/1533784/27019', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(620, 16, 'Record TV Campinas SD', 'http://sinalprivado.info:80/1533784/1533784/27020', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(621, 16, 'Record TV Campos dos Goytacazes FHD', 'http://sinalprivado.info:80/1533784/1533784/27021', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(622, 16, 'Record TV Campos dos Goytacazes HD', 'http://sinalprivado.info:80/1533784/1533784/27022', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(623, 16, 'Record TV Campos dos Goytacazes SD', 'http://sinalprivado.info:80/1533784/1533784/27023', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(624, 16, 'Record TV Curitiba FHD', 'http://sinalprivado.info:80/1533784/1533784/27024', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(625, 16, 'Record TV Curitiba HD', 'http://sinalprivado.info:80/1533784/1533784/27025', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(626, 16, 'Record TV Curitiba SD', 'http://sinalprivado.info:80/1533784/1533784/27026', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(627, 16, 'Record TV Florianópolis FHD', 'http://sinalprivado.info:80/1533784/1533784/27027', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(628, 16, 'Record TV Florianópolis HD', 'http://sinalprivado.info:80/1533784/1533784/27028', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(629, 16, 'Record TV Florianópolis SD', 'http://sinalprivado.info:80/1533784/1533784/27029', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(630, 16, 'Record TV Fortaleza FHD', 'http://sinalprivado.info:80/1533784/1533784/27030', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(631, 16, 'Record TV Fortaleza HD', 'http://sinalprivado.info:80/1533784/1533784/27031', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(632, 16, 'Record TV Fortaleza SD', 'http://sinalprivado.info:80/1533784/1533784/27032', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(633, 16, 'Record TV Goiás FHD', 'http://sinalprivado.info:80/1533784/1533784/27033', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(634, 16, 'Record TV Goiás HD', 'http://sinalprivado.info:80/1533784/1533784/27034', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(635, 16, 'Record TV Goiás SD', 'http://sinalprivado.info:80/1533784/1533784/27035', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(636, 16, 'Record TV Guaíba FHD', 'http://sinalprivado.info:80/1533784/1533784/27036', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(637, 16, 'Record TV Guaíba HD', 'http://sinalprivado.info:80/1533784/1533784/27037', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(638, 16, 'Record TV Guaíba SD', 'http://sinalprivado.info:80/1533784/1533784/27038', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(639, 16, 'Record TV Manaus FHD', 'http://sinalprivado.info:80/1533784/1533784/27039', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(640, 16, 'Record TV Manaus HD', 'http://sinalprivado.info:80/1533784/1533784/27040', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(641, 16, 'Record TV Manaus SD', 'http://sinalprivado.info:80/1533784/1533784/27041', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(642, 16, 'Record TV Minas FHD', 'http://sinalprivado.info:80/1533784/1533784/27042', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(643, 16, 'Record TV Minas HD', 'http://sinalprivado.info:80/1533784/1533784/27043', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(644, 16, 'Record TV Minas SD', 'http://sinalprivado.info:80/1533784/1533784/27044', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(645, 16, 'Record TV Recife FHD', 'http://sinalprivado.info:80/1533784/1533784/27045', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(646, 16, 'Record TV Recife HD', 'http://sinalprivado.info:80/1533784/1533784/27046', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(647, 16, 'Record TV Recife SD', 'http://sinalprivado.info:80/1533784/1533784/27047', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(648, 16, 'Record TV Ribeirão Preto FHD', 'http://sinalprivado.info:80/1533784/1533784/27048', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(649, 16, 'Record TV Ribeirão Preto HD', 'http://sinalprivado.info:80/1533784/1533784/27049', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(650, 16, 'Record TV Ribeirão Preto SD', 'http://sinalprivado.info:80/1533784/1533784/27050', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(651, 16, 'Record TV Rio FHD', 'http://sinalprivado.info:80/1533784/1533784/27051', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(652, 16, 'Record TV Rio HD', 'http://sinalprivado.info:80/1533784/1533784/27052', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(653, 16, 'Record TV Rio SD', 'http://sinalprivado.info:80/1533784/1533784/27053', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(654, 16, 'Record TV Rio Preto FHD', 'http://sinalprivado.info:80/1533784/1533784/27054', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(655, 16, 'Record TV Rio Preto HD', 'http://sinalprivado.info:80/1533784/1533784/27055', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(656, 16, 'Record TV Rio Preto SD', 'http://sinalprivado.info:80/1533784/1533784/27056', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(657, 16, 'Record TV Santos e Vale FHD', 'http://sinalprivado.info:80/1533784/1533784/27057', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(658, 16, 'Record TV Santos e Vale HD', 'http://sinalprivado.info:80/1533784/1533784/27058', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(659, 16, 'Record TV Santos e Vale SD', 'http://sinalprivado.info:80/1533784/1533784/27059', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(660, 16, 'Record TV São Paulo FHD', 'http://sinalprivado.info:80/1533784/1533784/27060', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(661, 16, 'Record TV São Paulo HD', 'http://sinalprivado.info:80/1533784/1533784/27061', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 1, 'original', '2026-01-05 03:11:15'),
(662, 16, 'Record TV São Paulo SD', 'http://sinalprivado.info:80/1533784/1533784/27062', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 1, 'original', '2026-01-05 03:11:15'),
(663, 16, 'Record TV Vitória FHD', 'http://sinalprivado.info:80/1533784/1533784/27063', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(664, 16, 'Record TV Vitória HD', 'http://sinalprivado.info:80/1533784/1533784/27064', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(665, 16, 'Record TV Vitória SD', 'http://sinalprivado.info:80/1533784/1533784/27065', 'http://www.fontedecanais.tv/logos/canais/record.png', NULL, 0, 0, 'original', NULL),
(666, 17, 'Band Bahia FHD', 'http://sinalprivado.info:80/1533784/1533784/28000', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(667, 17, 'Band Bahia HD', 'http://sinalprivado.info:80/1533784/1533784/28001', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(668, 17, 'Band Bahia SD', 'http://sinalprivado.info:80/1533784/1533784/28002', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(669, 17, 'Band Brasilia FHD', 'http://sinalprivado.info:80/1533784/1533784/28003', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(670, 17, 'Band Brasilia HD', 'http://sinalprivado.info:80/1533784/1533784/28004', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(671, 17, 'Band Brasilia SD', 'http://sinalprivado.info:80/1533784/1533784/28005', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(672, 17, 'Band Campinas FHD', 'http://sinalprivado.info:80/1533784/1533784/28006', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(673, 17, 'Band Campinas HD', 'http://sinalprivado.info:80/1533784/1533784/28007', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(674, 17, 'Band Campinas SD', 'http://sinalprivado.info:80/1533784/1533784/28008', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(675, 17, 'Band Minas FHD', 'http://sinalprivado.info:80/1533784/1533784/28009', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(676, 17, 'Band Minas HD', 'http://sinalprivado.info:80/1533784/1533784/28010', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(677, 17, 'Band Minas SD', 'http://sinalprivado.info:80/1533784/1533784/28011', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(678, 17, 'Band Paraná FHD', 'http://sinalprivado.info:80/1533784/1533784/28012', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(679, 17, 'Band Paraná HD', 'http://sinalprivado.info:80/1533784/1533784/28013', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(680, 17, 'Band Paraná SD', 'http://sinalprivado.info:80/1533784/1533784/28014', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(681, 17, 'Band Rio FHD', 'http://sinalprivado.info:80/1533784/1533784/28015', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(682, 17, 'Band Rio HD', 'http://sinalprivado.info:80/1533784/1533784/28016', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(683, 17, 'Band Rio SD', 'http://sinalprivado.info:80/1533784/1533784/28017', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(684, 17, 'Band Rio Grande do Sul FHD', 'http://sinalprivado.info:80/1533784/1533784/28018', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(685, 17, 'Band Rio Grande do Sul HD', 'http://sinalprivado.info:80/1533784/1533784/28019', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(686, 17, 'Band Rio Grande do Sul SD', 'http://sinalprivado.info:80/1533784/1533784/28020', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(687, 17, 'Band São Paulo FHD', 'http://sinalprivado.info:80/1533784/1533784/28021', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(688, 17, 'Band São Paulo HD', 'http://sinalprivado.info:80/1533784/1533784/28022', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 1, 'original', '2026-01-05 03:11:35'),
(689, 17, 'Band São Paulo SD', 'http://sinalprivado.info:80/1533784/1533784/28023', 'http://www.fontedecanais.tv/logos/canais/band.png', NULL, 0, 0, 'original', NULL),
(690, 18, '24H Os Simpsons', 'http://sinalprivado.info:80/1533784/1533784/38000', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(691, 18, '24H Chaves', 'http://sinalprivado.info:80/1533784/1533784/38001', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(692, 18, '24H Chapolin Colorado', 'http://sinalprivado.info:80/1533784/1533784/38002', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(693, 18, 'a Patroa e as Crianças', 'http://sinalprivado.info:80/1533784/1533784/38003', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(694, 18, '24H Dois Homens e Meio', 'http://sinalprivado.info:80/1533784/1533784/38004', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(695, 18, '24H Bob Esponja Calça Quadrada', 'http://sinalprivado.info:80/1533784/1533784/38005', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(696, 18, '24H Naruto Uzumaki', 'http://sinalprivado.info:80/1533784/1533784/38006', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(697, 18, '24H Naruto Shippuden', 'http://sinalprivado.info:80/1533784/1533784/38007', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(698, 18, '24H Um Maluco no Pedaço', 'http://sinalprivado.info:80/1533784/1533784/38008', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(699, 18, '24H iCarly Revival', 'http://sinalprivado.info:80/1533784/1533784/38009', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(700, 18, '24H South Park', 'http://sinalprivado.info:80/1533784/1533784/38010', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(701, 18, '24H Steven Universo', 'http://sinalprivado.info:80/1533784/1533784/38011', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(702, 18, '24H Truques da Mente', 'http://sinalprivado.info:80/1533784/1533784/38012', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(703, 18, '24H Largados e Pelados', 'http://sinalprivado.info:80/1533784/1533784/38013', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(704, 18, '24H Todo Mundo Odeia o Chris', 'http://sinalprivado.info:80/1533784/1533784/38014', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(705, 18, '24H Dragon Ball Z', 'http://sinalprivado.info:80/1533784/1533784/38015', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(706, 18, '24H Digimon Adventure', 'http://sinalprivado.info:80/1533784/1533784/38016', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(707, 18, '24H Snoopy', 'http://sinalprivado.info:80/1533784/1533784/38017', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(708, 18, '24h Big Bang: A Teoria', 'http://sinalprivado.info:80/1533784/1533784/38018', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(709, 18, '24h Boku no Hero Academia', 'http://sinalprivado.info:80/1533784/1533784/38019', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(710, 18, '24H Apenas um Show', 'http://sinalprivado.info:80/1533784/1533784/38020', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(711, 18, '24H BoJack Horseman', 'http://sinalprivado.info:80/1533784/1533784/38021', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(712, 18, '24H Galinha Pintadinha', 'http://sinalprivado.info:80/1533784/1533784/38022', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(713, 18, '24H Futurama', 'http://sinalprivado.info:80/1533784/1533784/38023', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(714, 18, '24H DPA - Detetives do Predio Azul', 'http://sinalprivado.info:80/1533784/1533784/38024', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(715, 18, '24H Familia Dinoussauros', 'http://sinalprivado.info:80/1533784/1533784/38025', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(716, 18, '24H Aeroporto Area Restrita', 'http://sinalprivado.info:80/1533784/1533784/38026', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(717, 18, '24H As Visões da Raven', 'http://sinalprivado.info:80/1533784/1533784/38027', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(718, 18, '24H Filmes Ação', 'http://sinalprivado.info:80/1533784/1533784/38028', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(719, 18, '24H Filmes Animação Infantil', 'http://sinalprivado.info:80/1533784/1533784/38029', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(720, 18, '24H Filmes Comédia', 'http://sinalprivado.info:80/1533784/1533784/38030', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(721, 18, '24H Filmes Drama', 'http://sinalprivado.info:80/1533784/1533784/38031', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(722, 18, '24H Filmes Romance', 'http://sinalprivado.info:80/1533784/1533784/38032', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(723, 18, '24H Filmes Suspense', 'http://sinalprivado.info:80/1533784/1533784/38033', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(724, 18, '24H Filmes Lancamentos', 'http://sinalprivado.info:80/1533784/1533784/38034', 'http://www.fontedecanais.tv/logos/canais/24h.png', NULL, 0, 0, 'original', NULL),
(725, 19, 'PLAYBOY', 'http://sinalprivado.info:80/1533784/1533784/40000', '', 'Playboy.br', 0, 0, 'original', NULL),
(726, 19, 'SEX PRIVE', 'http://sinalprivado.info:80/1533784/1533784/40001', '', NULL, 0, 0, 'original', NULL),
(727, 19, 'SEXTREME', 'http://sinalprivado.info:80/1533784/1533784/40002', '', 'Sextreme SD [Alter]', 0, 0, 'original', NULL),
(728, 19, 'SEXY HOT', 'http://sinalprivado.info:80/1533784/1533784/40003', '', 'Sexyhot.br', 0, 0, 'original', NULL),
(729, 19, 'VENUS', 'http://sinalprivado.info:80/1533784/1533784/40004', '', 'Venus HD', 0, 0, 'original', NULL),
(730, 19, 'Hardcore Erotic TV Online', 'http://sinalprivado.info:80/1533784/1533784/40005', '', NULL, 0, 0, 'original', NULL),
(731, 19, 'Hardcore Web Tv', 'http://sinalprivado.info:80/1533784/1533784/40006', '', NULL, 0, 0, 'original', NULL),
(732, 19, 'Hardcore Videos Non Stop', 'http://sinalprivado.info:80/1533784/1533784/40007', '', NULL, 0, 0, 'original', NULL),
(733, 19, 'Adult TV Online POV', 'http://sinalprivado.info:80/1533784/1533784/40008', '', NULL, 0, 0, 'original', NULL),
(734, 19, 'Adult TV Online Pornstar', 'http://sinalprivado.info:80/1533784/1533784/40009', '', NULL, 0, 0, 'original', NULL),
(735, 19, 'Adult TV Online Milfs', 'http://sinalprivado.info:80/1533784/1533784/40010', '', NULL, 0, 0, 'original', NULL),
(736, 19, 'Adult TV Live Cams', 'http://sinalprivado.info:80/1533784/1533784/40011', '', NULL, 0, 0, 'original', NULL),
(737, 19, 'Adult TV Online Lesbian', 'http://sinalprivado.info:80/1533784/1533784/40012', '', NULL, 0, 0, 'original', NULL),
(738, 19, 'Adult TV online Latina', 'http://sinalprivado.info:80/1533784/1533784/40013', '', NULL, 0, 0, 'original', NULL),
(739, 19, 'Adult TV Online Interracial', 'http://sinalprivado.info:80/1533784/1533784/40014', '', NULL, 0, 0, 'original', NULL),
(740, 19, 'Live Adult TV Hardcore', 'http://sinalprivado.info:80/1533784/1533784/40015', '', NULL, 0, 0, 'original', NULL),
(741, 19, 'Adult IPTV Brunette', 'http://sinalprivado.info:80/1533784/1533784/40016', '', NULL, 0, 0, 'original', NULL),
(742, 19, 'Adult IPTV Sexy Blondes', 'http://sinalprivado.info:80/1533784/1533784/40017#EXTM3U', '', NULL, 0, 0, 'original', NULL),
(743, 33, 'O Homem que Quer Viver para Sempre', 'http://sinalprivado.info:80/movie/1533784/1533784/647708.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s6mdvaGWxdfLb23wWBO1gHdnMdG.jpg', NULL, 0, 0, 'original', NULL),
(744, 33, 'Resplendor', 'http://sinalprivado.info:80/movie/1533784/1533784/647709.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f7vhStgvLkxcUbz8gtOoEIoxc5W.jpg', NULL, 0, 0, 'original', NULL),
(745, 33, 'Operação de Espionagem', 'http://sinalprivado.info:80/movie/1533784/1533784/647710.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/muJDzLs7uWuKEM0qUXEVaKikcK5.jpg', NULL, 0, 0, 'original', NULL),
(746, 33, 'As Crianças do Lixão', 'http://sinalprivado.info:80/movie/1533784/1533784/647711.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hwcm3PG2xRMXlklzSWc57UiHZj2.jpg', NULL, 0, 0, 'original', NULL),
(747, 33, 'The Mountain Within Me', 'http://sinalprivado.info:80/movie/1533784/1533784/647712.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mRwlV2K8RKj9bJxPqVmEtjd1zAC.jpg', NULL, 0, 0, 'original', NULL),
(748, 33, 'Blink', 'http://sinalprivado.info:80/movie/1533784/1533784/647713.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w8w7QbN4gyX4tL2nvenS7Xh44su.jpg', NULL, 0, 0, 'original', NULL),
(749, 33, 'Triunfo: Jesse Owens e os Jogos de Berlim', 'http://sinalprivado.info:80/movie/1533784/1533784/647714.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tY5Paf9y2v6IKLWcgsFY5eajdAG.jpg', NULL, 0, 0, 'original', NULL),
(750, 33, 'A Voz de Makayla Uma Carta ao Mundo', 'http://sinalprivado.info:80/movie/1533784/1533784/647715.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Mmft9Q4hkNAiHMWLR0ttSEIP88.jpg', NULL, 0, 0, 'original', NULL),
(751, 33, 'Sugarcane', 'http://sinalprivado.info:80/movie/1533784/1533784/647716.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9Xx4o4MVSDv0pojOzoHMH5y85hB.jpg', NULL, 0, 0, 'original', NULL),
(752, 33, '137 Disparos', 'http://sinalprivado.info:80/movie/1533784/1533784/647717.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6SzCf03ItJIPBegMqXsYgxKMXZo.jpg', NULL, 0, 0, 'original', NULL),
(753, 33, 'Roubo Cibernético: Bilhões em Bitcoins', 'http://sinalprivado.info:80/movie/1533784/1533784/647718.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bU3Ff7vCK8kLTjt3Z9Yx2wf0aLa.jpg', NULL, 0, 0, 'original', NULL),
(754, 33, 'Refúgio dos Pássaros', 'http://sinalprivado.info:80/movie/1533784/1533784/647719.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zQvLQyfHCfGXGtFIWTtqMhOsNvK.jpg', NULL, 0, 0, 'original', NULL),
(755, 33, 'Mundo Escondido', 'http://sinalprivado.info:80/movie/1533784/1533784/647720.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jTng9Z9DcaZyBVZsKeXuXqsUG6Z.jpg', NULL, 0, 0, 'original', NULL),
(756, 33, 'Chris Brown: Uma História de Violência', 'http://sinalprivado.info:80/movie/1533784/1533784/647721.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/etFYR5GGg4CdQEO2veAoX9ADYn2.jpg', NULL, 0, 0, 'original', NULL),
(757, 33, 'Robin Williams: Entre na Minha Mente', 'http://sinalprivado.info:80/movie/1533784/1533784/647722.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lM7nzdJYv5MeZ1yzT8MKLas8nI6.jpg', NULL, 0, 0, 'original', NULL),
(758, 33, 'Florida Shark: Blood in the Water', 'http://sinalprivado.info:80/movie/1533784/1533784/647723.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/40HH9nmPRkyWjWaoHgSZQNN6pFe.jpg', NULL, 0, 0, 'original', NULL),
(759, 33, 'Almost Human: Rise of the Apes', 'http://sinalprivado.info:80/movie/1533784/1533784/647724.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1nENCuHh1KzbuCiYb99kEhtY1iM.jpg', NULL, 0, 0, 'original', NULL),
(760, 33, 'Compre! A Conspiração Consumista', 'http://sinalprivado.info:80/movie/1533784/1533784/647725.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2qWoea16DIdfEZscAjzLHNgWa5P.jpg', NULL, 0, 0, 'original', NULL),
(761, 33, 'As Crianças Perdidas', 'http://sinalprivado.info:80/movie/1533784/1533784/647726.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s0rtiZojWCizvu6K4PJZu6Cjf0c.jpg', NULL, 0, 0, 'original', NULL),
(762, 33, 'O Retorno do Rei: Queda e Ascensão de Elvis Presley', 'http://sinalprivado.info:80/movie/1533784/1533784/647727.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1caQcjEZwGHNPvGd4bUa4qshfbc.jpg', NULL, 0, 0, 'original', NULL),
(763, 33, 'Feitos de Plástico', 'http://sinalprivado.info:80/movie/1533784/1533784/647728.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c4g82ZjkSJXAUnzxfU7yRW8V3dl.jpg', NULL, 0, 0, 'original', NULL),
(764, 33, 'Atleta A', 'http://sinalprivado.info:80/movie/1533784/1533784/647729.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/afBJ2k0p4ojBFHbMcJY9fZHxjRh.jpg', NULL, 0, 0, 'original', NULL),
(765, 33, 'Nem Tudo se Desfaz', 'http://sinalprivado.info:80/movie/1533784/1533784/647730.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zoQYJzuHFc1cAB1Mtog6GPaA6bH.jpg', NULL, 0, 0, 'original', NULL),
(766, 33, 'Endurance', 'http://sinalprivado.info:80/movie/1533784/1533784/647731.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7LPRuJ7pSxUB559ac8SS5mdElz8.jpg', NULL, 0, 0, 'original', NULL),
(767, 33, 'Dra. Sandra Lee: Um Natal sem Cravos', 'http://sinalprivado.info:80/movie/1533784/1533784/647732.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kMQgMTmGbrwzsOOub8SCenOw1z8.jpg', NULL, 0, 0, 'original', NULL),
(768, 33, '#SeAcabó: Diário das Campeãs', 'http://sinalprivado.info:80/movie/1533784/1533784/647733.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3P1CNp2iTmW0MZTIfbPH9Zr7QQr.jpg', NULL, 0, 0, 'original', NULL),
(769, 33, 'O Silêncio das Rosas', 'http://sinalprivado.info:80/movie/1533784/1533784/647734.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zYkRHLcjyJLSndISpRI9GROZzzl.jpg', NULL, 0, 0, 'original', NULL),
(770, 33, 'O Colírio do Corman Me Deixou Doido Demais', 'http://sinalprivado.info:80/movie/1533784/1533784/647735.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ucLCYcdUR09HtwSdUFOQPQ8JTSy.jpg', NULL, 0, 0, 'original', NULL),
(771, 33, 'Martha', 'http://sinalprivado.info:80/movie/1533784/1533784/647736.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4WN19oCTXlK8jXC0QZgNkBpcJcw.jpg', NULL, 0, 0, 'original', NULL),
(772, 33, 'Guaxuma', 'http://sinalprivado.info:80/movie/1533784/1533784/647737.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2Iy37kbJf4e40upqxQ6nru4ARJa.jpg', NULL, 0, 0, 'original', NULL),
(773, 33, 'From the River to the Sea - Um Filme Sobre a Guerra em Israel', 'http://sinalprivado.info:80/movie/1533784/1533784/647738.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3iFmtROx5NIuXpJ1GuqvBZV3W7C.jpg', NULL, 0, 0, 'original', NULL),
(774, 33, 'Mar Brasileiro', 'http://sinalprivado.info:80/movie/1533784/1533784/647739.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ka2URcxr122Mzv9WgQ7lkBqVIDE.jpg', NULL, 0, 0, 'original', NULL),
(775, 33, 'A Extraordinária Vida de Ibelin', 'http://sinalprivado.info:80/movie/1533784/1533784/647740.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1FkHH0g2CFPvREqwQy74vJyEnnY.jpg', NULL, 0, 0, 'original', NULL),
(776, 33, 'Ed Stafford: Desafio em Família', 'http://sinalprivado.info:80/movie/1533784/1533784/647741.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4PgYrpxTYZ3APGN9VJeTcDOM2Pq.jpg', NULL, 0, 0, 'original', NULL),
(777, 33, 'O Reflexo do Lago', 'http://sinalprivado.info:80/movie/1533784/1533784/647742.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1updTZcXO6jmbL97SNPKK7kmQa.jpg', NULL, 0, 0, 'original', NULL),
(778, 33, 'Meu Querido Bobby: Era Tudo uma Farsa', 'http://sinalprivado.info:80/movie/1533784/1533784/647743.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vOYSWDkW3lKOZNHkR4WdHG0sb8R.jpg', NULL, 0, 0, 'original', NULL),
(779, 33, 'Fernanda Young: Foge-me ao Controle', 'http://sinalprivado.info:80/movie/1533784/1533784/647744.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2fyzTdgN3Ob8nyTs3e2vQfIbPkm.jpg', NULL, 0, 0, 'original', NULL),
(780, 33, 'Expedição Amazônia', 'http://sinalprivado.info:80/movie/1533784/1533784/647745.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eXYEWG6k94ZAJBMXuAPJ238JmTs.jpg', NULL, 0, 0, 'original', NULL),
(781, 33, 'María Soledad: O Fim do Silêncio', 'http://sinalprivado.info:80/movie/1533784/1533784/647746.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3irwzj1cFInr0g6N0j2eSymJ6b6.jpg', NULL, 0, 0, 'original', NULL),
(782, 33, 'Massacre de Tulsa', 'http://sinalprivado.info:80/movie/1533784/1533784/647747.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qQQBCtmHaUreTLljfRhAju3bBcb.jpg', NULL, 0, 0, 'original', NULL),
(783, 33, 'Protegendo o Paraíso: A História de Niue', 'http://sinalprivado.info:80/movie/1533784/1533784/647748.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8QjT0rbicohkCUc5143yiStHssU.jpg', NULL, 0, 0, 'original', NULL),
(784, 33, 'O Grito', 'http://sinalprivado.info:80/movie/1533784/1533784/647749.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cI9c5NwX4J4ioeQayMg3BO27FhS.jpg', NULL, 0, 0, 'original', NULL),
(785, 33, 'Fuga de Alcatraz: A Pista Perdida', 'http://sinalprivado.info:80/movie/1533784/1533784/647750.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rdl7F6maBY2nCYuNZZ5J0v3X1YE.jpg', NULL, 0, 0, 'original', NULL),
(786, 33, 'Nelson Pereira dos Santos – Vida de Cinema', 'http://sinalprivado.info:80/movie/1533784/1533784/647751.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xEaok7TtsruHjnRIPpAY0sP7Vui.jpg', NULL, 0, 0, 'original', NULL),
(787, 33, 'Fly', 'http://sinalprivado.info:80/movie/1533784/1533784/647752.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/siAxvbUlj5z0YtauqBz4EoqG1hU.jpg', NULL, 0, 0, 'original', NULL),
(788, 33, 'A Vítima Invisível: O Caso Eliza Samudio', 'http://sinalprivado.info:80/movie/1533784/1533784/647753.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fT1RYNqASGR4QEi5mJNbFz754d3.jpg', NULL, 0, 0, 'original', NULL),
(789, 33, 'À Solta: Amor em Fuga', 'http://sinalprivado.info:80/movie/1533784/1533784/647754.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rbyFNHS0IluRYKwvwFepnzQPY3t.jpg', NULL, 0, 0, 'original', NULL),
(790, 33, 'Fartura', 'http://sinalprivado.info:80/movie/1533784/1533784/647755.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hxCNwqwSNnQjosQLalzezzpM3TW.jpg', NULL, 0, 0, 'original', NULL),
(791, 33, 'Ensinando Como Apreciar Vinhos', 'http://sinalprivado.info:80/movie/1533784/1533784/647756.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qwihkmUuQcS0lfKDsBMvLl32NfE.jpg', NULL, 0, 0, 'original', NULL),
(792, 33, 'Correntes', 'http://sinalprivado.info:80/movie/1533784/1533784/647757.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6Il3uLf24KGsC6UUrHrJ71kvWYV.jpg', NULL, 0, 0, 'original', NULL),
(793, 33, 'Cidade de Quem Corre', 'http://sinalprivado.info:80/movie/1533784/1533784/647758.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ktn3jJwdI62KHuv8v9pVlPyFHMT.jpg', NULL, 0, 0, 'original', NULL),
(794, 33, 'Bem-Vindos de Novo', 'http://sinalprivado.info:80/movie/1533784/1533784/647759.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kPWlUjAg5pSCKFu7QLiYLZmqqnZ.jpg', NULL, 0, 0, 'original', NULL),
(795, 33, 'Menendez Brothers: Misjudged?', 'http://sinalprivado.info:80/movie/1533784/1533784/647760.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zGgG5OpgF9keHMmodWUwQkmxJKS.jpg', NULL, 0, 0, 'original', NULL),
(796, 33, 'Huck e Zelensky - Não Está Tudo Bem', 'http://sinalprivado.info:80/movie/1533784/1533784/647761.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vYuxuS6Se2rWQ9BNF0Vq71PiOpK.jpg', NULL, 0, 0, 'original', NULL),
(797, 33, 'A História do Maior Best-Seller de Todos os Tempos', 'http://sinalprivado.info:80/movie/1533784/1533784/647762.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lxb81S1VBB6LZqkhsxV71AM4RDX.jpg', NULL, 0, 0, 'original', NULL),
(798, 33, '11/09: Os Quatro Voos Fatais', 'http://sinalprivado.info:80/movie/1533784/1533784/647763.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n9UnhTs0pvnut86nbuk8qfkWHqR.jpg', NULL, 0, 0, 'original', NULL),
(799, 33, 'Maria: Ninguém Sabe Quem Sou Eu', 'http://sinalprivado.info:80/movie/1533784/1533784/647764.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/btcG6egm8eXgzl0VFvLFGcehcau.jpg', NULL, 0, 0, 'original', NULL),
(800, 33, 'Um Dia na Disney', 'http://sinalprivado.info:80/movie/1533784/1533784/647765.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2It1Fw5IF9jQOTdrhx0Em1eKGJY.jpg', NULL, 0, 0, 'original', NULL),
(801, 33, 'Cavalo', 'http://sinalprivado.info:80/movie/1533784/1533784/647766.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tEOEnshcgjK70t13W3viHWS5sAq.jpg', NULL, 0, 0, 'original', NULL),
(802, 33, 'A Era de Lareokotô', 'http://sinalprivado.info:80/movie/1533784/1533784/647767.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tWKq17VKsU1SZb9uMeCGgLHYxFQ.jpg', NULL, 0, 0, 'original', NULL),
(803, 33, 'A Vida Pós 11 de Setembro', 'http://sinalprivado.info:80/movie/1533784/1533784/647768.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mPTQtQC1gWgfWjYq7k0boR7Ly9m.jpg', NULL, 0, 0, 'original', NULL),
(804, 33, 'Utopia Distopia', 'http://sinalprivado.info:80/movie/1533784/1533784/647769.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/amMBFvXCv8Opc0RrAtRRmy3AnsI.jpg', NULL, 0, 0, 'original', NULL),
(805, 33, 'Negro Leo', 'http://sinalprivado.info:80/movie/1533784/1533784/647770.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rmWbAiOP3vZ0pbt2kVOyituSuJv.jpg', NULL, 0, 0, 'original', NULL),
(806, 33, 'Apollo 13: Sobrevivendo no Espaço', 'http://sinalprivado.info:80/movie/1533784/1533784/647771.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zWVaJTYhOoXsDEm5TlfArkDJOD3.jpg', NULL, 0, 0, 'original', NULL),
(807, 33, 'Toada para José Siqueira', 'http://sinalprivado.info:80/movie/1533784/1533784/647772.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ueB5JwjdSQbxUO4DFatFonV46gv.jpg', NULL, 0, 0, 'original', NULL),
(808, 33, 'Limiar', 'http://sinalprivado.info:80/movie/1533784/1533784/647773.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yX0IChgBW8JVCNxDADcXN66NUaV.jpg', NULL, 0, 0, 'original', NULL),
(809, 33, 'Herchcovitch; Exposto', 'http://sinalprivado.info:80/movie/1533784/1533784/647774.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pzW10yefH9jcAAPSraJevW15mpG.jpg', NULL, 0, 0, 'original', NULL),
(810, 33, 'Yaõkwa - Imagem e Memória', 'http://sinalprivado.info:80/movie/1533784/1533784/647775.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/unAyFveg2nspQ4aKCvEVORMYG2f.jpg', NULL, 0, 0, 'original', NULL),
(811, 33, 'Untold: O Assassinato de Steve McNair', 'http://sinalprivado.info:80/movie/1533784/1533784/647776.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rIftnxHrJnQkLmP3Ga3WvjN0via.jpg', NULL, 0, 0, 'original', NULL),
(812, 33, 'Favela é Moda', 'http://sinalprivado.info:80/movie/1533784/1533784/647777.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Assl2oyMwKCp92qo71jIwyz32N.jpg', NULL, 0, 0, 'original', NULL),
(813, 33, 'Diálogos com Ruth de Souza', 'http://sinalprivado.info:80/movie/1533784/1533784/647778.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sGUjnu6r4UzaPoTcVn3ry0wh4MP.jpg', NULL, 0, 0, 'original', NULL),
(814, 33, 'Um Filho Perigoso', 'http://sinalprivado.info:80/movie/1533784/1533784/647779.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8dCd7jzIOX0lcSdi9cKbyqooqEt.jpg', NULL, 0, 0, 'original', NULL),
(815, 33, 'Dr. Death: Cutthroat Conman', 'http://sinalprivado.info:80/movie/1533784/1533784/647780.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/16MvBZ65pUOdSCz2ngQQ7KLwYaa.jpg', NULL, 0, 0, 'original', NULL),
(816, 33, 'O Resgate', 'http://sinalprivado.info:80/movie/1533784/1533784/647781.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oh7Os4AU5PhT3D3myN64crigJ.jpg', NULL, 0, 0, 'original', NULL),
(817, 33, 'Assassinatos na Hamburgueria', 'http://sinalprivado.info:80/movie/1533784/1533784/647782.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/voKQNtqMxjBUu020drx1EkG2MVP.jpg', NULL, 0, 0, 'original', NULL),
(818, 33, 'Dentro da Mente de um Cachorro', 'http://sinalprivado.info:80/movie/1533784/1533784/647783.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b1R6RDLVpHhVUKLvgD7npI4sphF.jpg', NULL, 0, 0, 'original', NULL),
(819, 33, 'Rainha do Everest: No Topo com Lhakpa Sherpa', 'http://sinalprivado.info:80/movie/1533784/1533784/647784.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gg1w4ShSSZVZNjLKax7Zh4NkY4d.jpg', NULL, 0, 0, 'original', NULL),
(820, 33, 'O Legado de 11 de Setembro', 'http://sinalprivado.info:80/movie/1533784/1533784/647785.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r049Bl2ri7WI66p856ncUZTBmch.jpg', NULL, 0, 0, 'original', NULL),
(821, 33, 'O Horror na Casa Amityville', 'http://sinalprivado.info:80/movie/1533784/1533784/647786.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x67Relf7iq2BC4KAKqvOc27SiIE.jpg', NULL, 0, 0, 'original', NULL),
(822, 33, 'O Caso Matthew Shepard: Homofobia e Morte', 'http://sinalprivado.info:80/movie/1533784/1533784/647787.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mk40s2bOC2huyvFst6EZCx0FDbL.jpg', NULL, 0, 0, 'original', NULL),
(823, 33, 'Invasão Alienígena: Hudson Valley', 'http://sinalprivado.info:80/movie/1533784/1533784/647788.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iGeS46JuFkpfjCSYO3G7xQK4UPn.jpg', NULL, 0, 0, 'original', NULL),
(824, 33, 'Roland Doe: A Verdadeira História de O Exorcista', 'http://sinalprivado.info:80/movie/1533784/1533784/647789.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5dHeon4cc4PeDo2NXpgrTBgieMh.jpg', NULL, 0, 0, 'original', NULL),
(825, 33, 'Os Túneis Secretos de Hitler', 'http://sinalprivado.info:80/movie/1533784/1533784/647790.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4FWokJyJoBRwzGVCScYi6lkLJIv.jpg', NULL, 0, 0, 'original', NULL),
(826, 33, 'The Real Red Tails', 'http://sinalprivado.info:80/movie/1533784/1533784/647791.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c36UIVlX5gPkrznrbumhaaLtNDN.jpg', NULL, 0, 0, 'original', NULL),
(827, 33, 'Óvnis: Tecnologias Ultrassecretas', 'http://sinalprivado.info:80/movie/1533784/1533784/647792.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gvs9N8wsyetx8WFaQOhD5o8MtVg.jpg', NULL, 0, 0, 'original', NULL),
(828, 33, 'Óvnis: Missões Espaciais Ultrassecretas', 'http://sinalprivado.info:80/movie/1533784/1533784/647793.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9l7FmY7OoAYpv8KUKHbAmBJMZZK.jpg', NULL, 0, 0, 'original', NULL),
(829, 33, 'Partido', 'http://sinalprivado.info:80/movie/1533784/1533784/647794.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9Aalp6ycjNW3Ut0pJtg6GFQsewz.jpg', NULL, 0, 0, 'original', NULL),
(830, 33, 'A Vida dos Leopardos', 'http://sinalprivado.info:80/movie/1533784/1533784/647795.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4I9CClpKze9rwW78fuMSluq2OvE.jpg', NULL, 0, 0, 'original', NULL),
(831, 33, '20 Dias em Mauripol', 'http://sinalprivado.info:80/movie/1533784/1533784/647796.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/21rFQUyP8SDJhWm6cpAbHdOL5f0.jpg', NULL, 0, 0, 'original', NULL),
(832, 33, 'O Assassino das Rodovias', 'http://sinalprivado.info:80/movie/1533784/1533784/647797.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4PTPSF5nsQVNroqa4iT3zHF7wty.jpg', NULL, 0, 0, 'original', NULL),
(833, 33, 'Irmãos por Acidente', 'http://sinalprivado.info:80/movie/1533784/1533784/647798.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b8BS8gF7O90vmb71vSo3nk1uzwJ.jpg', NULL, 0, 0, 'original', NULL),
(834, 33, 'A Primeira Barbie Negra', 'http://sinalprivado.info:80/movie/1533784/1533784/647799.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y6vyzS6gIhC8vriCf0axTZyxErg.jpg', NULL, 0, 0, 'original', NULL),
(835, 33, 'Os Mistérios dos Guerreiros de Terracota', 'http://sinalprivado.info:80/movie/1533784/1533784/647800.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/izD8QoAoyGD8y0tQGt4ksMX00GK.jpg', NULL, 0, 0, 'original', NULL),
(836, 33, 'Drogas: O Vício Secreto dos Nazistas', 'http://sinalprivado.info:80/movie/1533784/1533784/647801.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g2oVRHYHdB3OxdXgxg3TALzoI9I.jpg', NULL, 0, 0, 'original', NULL),
(837, 33, 'As Pegadas de Jesus em Roma', 'http://sinalprivado.info:80/movie/1533784/1533784/647802.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3l8WLZjetMhes6PELEZxwHsK2fj.jpg', NULL, 0, 0, 'original', NULL),
(838, 33, 'Billy e Molly: Uma História de Amor Diferente', 'http://sinalprivado.info:80/movie/1533784/1533784/647803.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ksvg5VoDKcGBFt3Q2aLT2wOMKG.jpg', NULL, 0, 0, 'original', NULL),
(839, 33, 'Rafa Márquez: O Capitão', 'http://sinalprivado.info:80/movie/1533784/1533784/647804.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A1BNL3BLzrUkm7MN9VlkTyR2DCa.jpg', NULL, 0, 0, 'original', NULL),
(840, 33, 'Como Roubar um Banco', 'http://sinalprivado.info:80/movie/1533784/1533784/647805.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wbpo8IBtg1NZ4FHJxMaRTPJoBUg.jpg', NULL, 0, 0, 'original', NULL),
(841, 33, 'Caçando Assassinos: O Homem Sem Rosto', 'http://sinalprivado.info:80/movie/1533784/1533784/647806.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dG1XfJTyo4nPST17cby8ojJb8us.jpg', NULL, 0, 0, 'original', NULL),
(842, 33, 'Caçando Assassinos: Justiça Feita', 'http://sinalprivado.info:80/movie/1533784/1533784/647807.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/34kQ9wg4OnS2lSqaPDlHCon8Cv0.jpg', NULL, 0, 0, 'original', NULL),
(843, 33, 'Mary J. Blige: Minha Vida', 'http://sinalprivado.info:80/movie/1533784/1533784/647808.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zlnZnhYHl9gfBoEWvOA1T7HNBwy.jpg', NULL, 0, 0, 'original', NULL),
(844, 33, 'Depois da Morte', 'http://sinalprivado.info:80/movie/1533784/1533784/647809.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jftgQ8mYaPFYf0UywgwgqimAkmu.jpg', NULL, 0, 0, 'original', NULL),
(845, 33, 'Poder Policial', 'http://sinalprivado.info:80/movie/1533784/1533784/647810.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5nYbyTa3w8Ijid53exglHX25A3x.jpg', NULL, 0, 0, 'original', NULL),
(846, 33, 'Agrogliflos: Círculos Nas Plantações', 'http://sinalprivado.info:80/movie/1533784/1533784/647811.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wc3yFypRulTnFFP2HU1iy5lqBYK.jpg', NULL, 0, 0, 'original', NULL),
(847, 33, 'Davi: Um Cara Comum da Bahia', 'http://sinalprivado.info:80/movie/1533784/1533784/647812.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hoLltWSfNbH3erey3tWd9Xp81TY.jpg', NULL, 0, 0, 'original', NULL),
(848, 33, 'A Final: Caos em Wembley', 'http://sinalprivado.info:80/movie/1533784/1533784/647813.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/htDKDbcotRlymVLY2eup0sRSBAH.jpg', NULL, 0, 0, 'original', NULL),
(849, 33, 'Capitão', 'http://sinalprivado.info:80/movie/1533784/1533784/647814.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qTP40kJeJ6IUsurQxtHJ1bqow83.jpg', NULL, 0, 0, 'original', NULL);
INSERT INTO `channels` (`id`, `category_id`, `name`, `stream_url`, `logo_url`, `epg_id`, `pid`, `running`, `transcode_quality`, `uptime`) VALUES
(850, 33, 'Perseguindo Demônios: O Herói de Nuremberg', 'http://sinalprivado.info:80/movie/1533784/1533784/647815.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/PXo5oaPqJ7SFtSWQMl53OHlCSV.jpg', NULL, 0, 0, 'original', NULL),
(851, 33, 'Os Segredos dos Neandertais', 'http://sinalprivado.info:80/movie/1533784/1533784/647816.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3jSrvyWRdaLhcZpQg4l3pVI0lZj.jpg', NULL, 0, 0, 'original', NULL),
(852, 33, 'O Avanço das Superbombas', 'http://sinalprivado.info:80/movie/1533784/1533784/647817.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fdpTIpzb8dopSG7uUcPG5dTKfzV.jpg', NULL, 0, 0, 'original', NULL),
(853, 33, 'Antares de la Luz: Uma Seita Apocalíptica', 'http://sinalprivado.info:80/movie/1533784/1533784/647818.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n51gQ3x8nTgHOGnHb2MJpOnCJzd.jpg', NULL, 0, 0, 'original', NULL),
(854, 33, 'Já que Ninguém me Tira Para Dançar', 'http://sinalprivado.info:80/movie/1533784/1533784/647819.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iHM6zlVWNDzxoNgaJN2Wv51o2l5.jpg', NULL, 0, 0, 'original', NULL),
(855, 33, 'O Que Jennifer Fez?', 'http://sinalprivado.info:80/movie/1533784/1533784/647820.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r3PJPXuSArGK8tM6lBUyPUTtIbJ.jpg', NULL, 0, 0, 'original', NULL),
(856, 33, 'O Último Papa', 'http://sinalprivado.info:80/movie/1533784/1533784/647821.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kLrjDRjICIdIILBpwYwOBgCuxhU.jpg', NULL, 0, 0, 'original', NULL),
(857, 33, 'O Código de Deus', 'http://sinalprivado.info:80/movie/1533784/1533784/647822.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/terEbhko603bvVnicNqlIl9FSZU.jpg', NULL, 0, 0, 'original', NULL),
(858, 33, 'Lauri e a Subversão', 'http://sinalprivado.info:80/movie/1533784/1533784/647823.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6f7ziq35oqJBIAeXaAde3KKNf0c.jpg', NULL, 0, 0, 'original', NULL),
(859, 33, 'Matar um Tigre', 'http://sinalprivado.info:80/movie/1533784/1533784/647824.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/954awevQWhHGrtTVlbUJoLX0h5b.jpg', NULL, 0, 0, 'original', NULL),
(860, 33, 'Salvatore: Shoemaker of Dreams', 'http://sinalprivado.info:80/movie/1533784/1533784/647825.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hnX54hxajalmK2p0UrcEdFNX4TV.jpg', NULL, 0, 0, 'original', NULL),
(861, 33, 'Óvnis: Arquivos Ultrassecretos', 'http://sinalprivado.info:80/movie/1533784/1533784/647826.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jklB0ZmuUCHMhKw6tKgQGMmZxTu.jpg', NULL, 0, 0, 'original', NULL),
(862, 33, 'Indianara', 'http://sinalprivado.info:80/movie/1533784/1533784/647827.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zED6UCrldkbBkV6zWD9LuZPJwkT.jpg', NULL, 0, 0, 'original', NULL),
(863, 33, 'Déjà Vu - O Primeiro Ano do \"Novo\" Governo Lula', 'http://sinalprivado.info:80/movie/1533784/1533784/647828.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1ESbIOki2zEDCYeYmdySdRTZvau.jpg', NULL, 0, 0, 'original', NULL),
(864, 33, 'Cher e o Elefante Solitário', 'http://sinalprivado.info:80/movie/1533784/1533784/647829.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nFYtX5MDzh8TCqKcaREDoENPJDt.jpg', NULL, 0, 0, 'original', NULL),
(865, 33, 'Buffalo Soldiers: O Exército Negro', 'http://sinalprivado.info:80/movie/1533784/1533784/647830.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9e4ICNKLbsWPrgxWtaVqZUd19nm.jpg', NULL, 0, 0, 'original', NULL),
(866, 33, 'Holocausto Brasileiro', 'http://sinalprivado.info:80/movie/1533784/1533784/647831.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/76muwL3vWeojBD5N2ARsgFrtXPx.jpg', NULL, 0, 0, 'original', NULL),
(867, 33, 'Uma canção', 'http://sinalprivado.info:80/movie/1533784/1533784/647832.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/10sXvhdDZgwlEe7cw1EYdlaCVOH.jpg', NULL, 0, 0, 'original', NULL),
(868, 33, 'They Called Him Mostly Harmless', 'http://sinalprivado.info:80/movie/1533784/1533784/647833.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i3Ngi39RT9kxTPyGN5CwK2XEZrk.jpg', NULL, 0, 0, 'original', NULL),
(869, 33, 'A Grande Viagem de Fernão de Magalhães', 'http://sinalprivado.info:80/movie/1533784/1533784/647834.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ubw4fkFZGK2yzc6f3mrTfaWeGXQ.jpg', NULL, 0, 0, 'original', NULL),
(870, 33, 'Every Body', 'http://sinalprivado.info:80/movie/1533784/1533784/647835.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9VDdHICgCaKyeeuAlNPDEwbeSYT.jpg', NULL, 0, 0, 'original', NULL),
(871, 33, 'O Paradoxo da Democracia', 'http://sinalprivado.info:80/movie/1533784/1533784/647836.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gQQPkFYR4w4gsgim6hwgSUOkYZX.jpg', NULL, 0, 0, 'original', NULL),
(872, 33, 'O Alpinista', 'http://sinalprivado.info:80/movie/1533784/1533784/647837.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tYbSGAVbyACEExptLu63CxCGm4O.jpg', NULL, 0, 0, 'original', NULL),
(873, 33, 'Atletas Negros: Uma Luta pela Igualdade', 'http://sinalprivado.info:80/movie/1533784/1533784/647838.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pcDm9slR1QE4czkEkhcdBNaxlgk.jpg', NULL, 0, 0, 'original', NULL),
(874, 33, 'A Metamorfose dos Pássaros', 'http://sinalprivado.info:80/movie/1533784/1533784/647839.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/quAcjurYntxpVVerkYxz7d7xgbe.jpg', NULL, 0, 0, 'original', NULL),
(875, 33, 'Mandado', 'http://sinalprivado.info:80/movie/1533784/1533784/647840.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8Uqe13id9BPNAQzRAqjJsli1vr4.jpg', NULL, 0, 0, 'original', NULL),
(876, 33, 'Einstein e a Bomba', 'http://sinalprivado.info:80/movie/1533784/1533784/647841.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pGEB1qR73d8XNhnHCXqnkuMokIk.jpg', NULL, 0, 0, 'original', NULL),
(877, 33, 'Bobi Wine: The People\'s President', 'http://sinalprivado.info:80/movie/1533784/1533784/647842.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j0CxiYRhjDn1jwL6OTzdrLUPLBM.jpg', NULL, 0, 0, 'original', NULL),
(878, 33, 'The Space Race', 'http://sinalprivado.info:80/movie/1533784/1533784/647843.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k92rpuDXYxdy4c4LHMNNhU12lov.jpg', NULL, 0, 0, 'original', NULL),
(879, 33, 'Obra & Vida', 'http://sinalprivado.info:80/movie/1533784/1533784/647844.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kp93Oj16b0JuuSfLLEfBJDAKV8c.jpg', NULL, 0, 0, 'original', NULL),
(880, 33, 'a Voz da Bossa Nova', 'http://sinalprivado.info:80/movie/1533784/1533784/647845.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hGVMNLUAWhuPiE6qAI8f5HSamsj.jpg', NULL, 0, 0, 'original', NULL),
(881, 33, 'Chiquinha Gonzaga - Música Substantivo Feminino', 'http://sinalprivado.info:80/movie/1533784/1533784/647846.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rTpMDIm54FPiSDPRhPYkDWQ4G1m.jpg', NULL, 0, 0, 'original', NULL),
(882, 33, 'Nuremberg: As Fitas Perdidas', 'http://sinalprivado.info:80/movie/1533784/1533784/647847.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xobaJbWHEkX9032TdQeRJEIoD3f.jpg', NULL, 0, 0, 'original', NULL),
(883, 33, 'Stalker e Mortal', 'http://sinalprivado.info:80/movie/1533784/1533784/647848.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6kQodHV31ffIaE1vhEBo3as8Hon.jpg', NULL, 0, 0, 'original', NULL),
(884, 33, 'Fake News - Made in Brazil', 'http://sinalprivado.info:80/movie/1533784/1533784/647849.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rvnOjkeWKxg9dXj849K2mfj4r2E.jpg', NULL, 0, 0, 'original', NULL),
(885, 33, 'Under the Volcano', 'http://sinalprivado.info:80/movie/1533784/1533784/647850.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h5qQZl0i9iWbhhaFAHBh0GokX3V.jpg', NULL, 0, 0, 'original', NULL),
(886, 33, 'Desastre Vulcânico', 'http://sinalprivado.info:80/movie/1533784/1533784/647851.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/paF8ONqVa2RHkSAX867JExumGBE.jpg', NULL, 0, 0, 'original', NULL),
(887, 33, 'A Noite que Mudou o Pop', 'http://sinalprivado.info:80/movie/1533784/1533784/647852.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c5Dz7xZMxPbdaLn5nte4DCa61Gy.jpg', NULL, 0, 0, 'original', NULL),
(888, 33, 'Somos Guardiões', 'http://sinalprivado.info:80/movie/1533784/1533784/647853.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/onJwNkFurxZ0sC9pNqUkFB8nF7G.jpg', NULL, 0, 0, 'original', NULL),
(889, 33, 'Tributo Ary Fontoura', 'http://sinalprivado.info:80/movie/1533784/1533784/647854.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yVIapbKlMcOw7P3Bb9auLxUUxra.jpg', NULL, 0, 0, 'original', NULL),
(890, 33, 'Expedição Roosevelt Rondon', 'http://sinalprivado.info:80/movie/1533784/1533784/647855.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hd8Wrtv3y2VOTjk40wsTfC1Tfz4.jpg', NULL, 0, 0, 'original', NULL),
(891, 33, 'Primavera Brasileira', 'http://sinalprivado.info:80/movie/1533784/1533784/647856.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2vluF4SGnCSihbTUEvsfWhL6uTD.jpg', NULL, 0, 0, 'original', NULL),
(892, 33, 'Pessoas - Contar para Viver', 'http://sinalprivado.info:80/movie/1533784/1533784/647857.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g9tZHrVRMzrvoCTTQQYna59Etuj.jpg', NULL, 0, 0, 'original', NULL),
(893, 33, 'EU', 'http://sinalprivado.info:80/movie/1533784/1533784/647858.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2pqvKW9VMpJQUscyFaFPJdhXcw1.jpg', NULL, 0, 0, 'original', NULL),
(894, 33, 'o Preto Que Virou Mar', 'http://sinalprivado.info:80/movie/1533784/1533784/647859.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5eRLu0dFiSPGRBfuNdM3MCKcaYa.jpg', NULL, 0, 0, 'original', NULL),
(895, 33, 'Do Jazz ao Samba', 'http://sinalprivado.info:80/movie/1533784/1533784/647860.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7j1ZwPTzsY86w7rocmLFNpOS7Fb.jpg', NULL, 0, 0, 'original', NULL),
(896, 33, 'Banquete Coutinho', 'http://sinalprivado.info:80/movie/1533784/1533784/647861.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aiQEAQsq5H8AJ5GDIdKi6UcOsP4.jpg', NULL, 0, 0, 'original', NULL),
(897, 33, 'Operação Camanducaia', 'http://sinalprivado.info:80/movie/1533784/1533784/647862.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u8ge7A9YIcVoxbOJJKYgLACEmg.jpg', NULL, 0, 0, 'original', NULL),
(898, 33, 'Tubarões do Triângulo das Bermudas', 'http://sinalprivado.info:80/movie/1533784/1533784/647863.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ogslu6CAggSHIC4dX0qccvdxjm7.jpg', NULL, 0, 0, 'original', NULL),
(899, 33, 'Rio Negro', 'http://sinalprivado.info:80/movie/1533784/1533784/647864.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/czPiD1mbftZrjCQGecE5BBE2dFc.jpg', NULL, 0, 0, 'original', NULL),
(900, 33, 'Petra: Cidade das Riquezas', 'http://sinalprivado.info:80/movie/1533784/1533784/647865.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n48K1cYBC6t3J8s7g3e9oA6iFPL.jpg', NULL, 0, 0, 'original', NULL),
(901, 33, 'Onde Eu Moro', 'http://sinalprivado.info:80/movie/1533784/1533784/647866.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rrsrOldUfXn5vd5HP3BAYxLTjpO.jpg', NULL, 0, 0, 'original', NULL),
(902, 33, 'O Índio Cor de Rosa Contra a Fera Invisível: A Peleja de Noel Nutels', 'http://sinalprivado.info:80/movie/1533784/1533784/647867.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lAmAyvrKvfkbDonZC758HwKVXIu.jpg', NULL, 0, 0, 'original', NULL),
(903, 33, 'Hitler: Guerra no Deserto', 'http://sinalprivado.info:80/movie/1533784/1533784/647868.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zWPWKpXdzA3SWJ2Vahb0yterNz6.jpg', NULL, 0, 0, 'original', NULL),
(904, 33, 'Com as Próprias Mãos', 'http://sinalprivado.info:80/movie/1533784/1533784/647869.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rReJxeXTh6rbVCrPN4i5CNDyyCv.jpg', NULL, 0, 0, 'original', NULL),
(905, 33, 'O Desmonte do Monte', 'http://sinalprivado.info:80/movie/1533784/1533784/647870.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kYt45V9W9tUUyWNdQUOyoX7p2Gb.jpg', NULL, 0, 0, 'original', NULL),
(906, 33, 'Leopoldina - A Imperatriz do Brasil', 'http://sinalprivado.info:80/movie/1533784/1533784/647871.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o2V29kR9G2GmwqhOivgva8yWRBC.jpg', NULL, 0, 0, 'original', NULL),
(907, 33, '8/1 – A Democracia Resiste', 'http://sinalprivado.info:80/movie/1533784/1533784/647872.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7WwyrCZORz8qR2iizhUEZx5iZDu.jpg', NULL, 0, 0, 'original', NULL),
(908, 33, 'A Maldição do Boneco Robert', 'http://sinalprivado.info:80/movie/1533784/1533784/647873.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zrEpRwFOKDKzDStnHRwFhZKkY1O.jpg', NULL, 0, 0, 'original', NULL),
(909, 33, 'Criptofraude', 'http://sinalprivado.info:80/movie/1533784/1533784/647874.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5HHMl8k7cugjUUXQYx85eD0A0tf.jpg', NULL, 0, 0, 'original', NULL),
(910, 33, 'Incompatível com a Vida', 'http://sinalprivado.info:80/movie/1533784/1533784/647875.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s3hjvbZuXRVmfGanJyx0AdGzoPB.jpg', NULL, 0, 0, 'original', NULL),
(911, 33, 'Fédro', 'http://sinalprivado.info:80/movie/1533784/1533784/647876.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4YlRcAKGt24lVrrmFJ8ElsLbZBY.jpg', NULL, 0, 0, 'original', NULL),
(912, 33, 'TINA', 'http://sinalprivado.info:80/movie/1533784/1533784/647877.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uYhCOMQk5XO4rwoq83iiGPZV78t.jpg', NULL, 0, 0, 'original', NULL),
(913, 33, 'Curry com Cianeto', 'http://sinalprivado.info:80/movie/1533784/1533784/647878.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sdXu8YeDqg1qxEP9LJuTIFBtR5L.jpg', NULL, 0, 0, 'original', NULL),
(914, 33, 'Casamento às Cegas Brasil: Depois do Altar', 'http://sinalprivado.info:80/movie/1533784/1533784/647879.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qRNPA0pjTNEZuLEuhF1CeOzpwWS.jpg', NULL, 0, 0, 'original', NULL),
(915, 33, 'The Mission', 'http://sinalprivado.info:80/movie/1533784/1533784/647880.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kSLbmZ6R1VaNM1Kr1EJcdvHV94v.jpg', NULL, 0, 0, 'original', NULL),
(916, 33, 'Cara a Cara com o ETA', 'http://sinalprivado.info:80/movie/1533784/1533784/647881.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pUThEccecvgCERVJEUzZUBdqFO2.jpg', NULL, 0, 0, 'original', NULL),
(917, 33, 'Todo Dia é 4 de Novembro: O Fluminense Conquista a América', 'http://sinalprivado.info:80/movie/1533784/1533784/647882.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7bcY323Jdlz5c0SEQrMg8AS2khn.jpg', NULL, 0, 0, 'original', NULL),
(918, 33, 'Deive Leonardo: A Resposta', 'http://sinalprivado.info:80/movie/1533784/1533784/647883.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e81XmfQOdwctYYg1qP7IGPgbeVl.jpg', NULL, 0, 0, 'original', NULL),
(919, 33, 'Diário de uma onça', 'http://sinalprivado.info:80/movie/1533784/1533784/647884.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lk9Wh8LeWxg4R2eMlqiYRs9ZpHR.jpg', NULL, 0, 0, 'original', NULL),
(920, 33, 'A MEMORIA INFINITA', 'http://sinalprivado.info:80/movie/1533784/1533784/647885.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1Uwk8H0me0um5XVeEorsxgxBQfE.jpg', NULL, 0, 0, 'original', NULL),
(921, 33, 'A História de Um Silva', 'http://sinalprivado.info:80/movie/1533784/1533784/647886.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gosDb93s0CRKEDAwXmcwhLcRQBX.jpg', NULL, 0, 0, 'original', NULL),
(922, 33, 'Doido', 'http://sinalprivado.info:80/movie/1533784/1533784/647887.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5NCSkyVXVpMOUc6u8yhyXo107Qu.jpg', NULL, 0, 0, 'original', NULL),
(923, 33, 'Badi', 'http://sinalprivado.info:80/movie/1533784/1533784/647888.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mKb9LI8pzaZ1sbZdZjViQSimNQP.jpg', NULL, 0, 0, 'original', NULL),
(924, 33, 'Marcados: A História do Racismo nos EUA', 'http://sinalprivado.info:80/movie/1533784/1533784/647889.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dksKQ0jEpKCG31tfyh7Pag7ALiA.jpg', NULL, 0, 0, 'original', NULL),
(925, 33, 'Meu Sangue é Vermelho', 'http://sinalprivado.info:80/movie/1533784/1533784/647890.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f2szRIWAsuhDxD20hHhmcEkzttd.jpg', NULL, 0, 0, 'original', NULL),
(926, 33, 'Elis e Tom So Tinha de Ser com Voce', 'http://sinalprivado.info:80/movie/1533784/1533784/647891.mp4', 'https://i.bj-share.info/8c840cba092e87167cc642d743491bf6.jpg', NULL, 0, 0, 'original', NULL),
(927, 33, 'A Pequena Grande Fazenda: O Retorno', 'http://sinalprivado.info:80/movie/1533784/1533784/647892.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eAfojsKXl9ZPyUW207oOta9ETC2.jpg', NULL, 0, 0, 'original', NULL),
(928, 33, 'Os Pais', 'http://sinalprivado.info:80/movie/1533784/1533784/647893.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/shokHKaEqGPI8jx4uP5LPrgLjcd.jpg', NULL, 0, 0, 'original', NULL),
(929, 33, 'Kobra Auto Retrato', 'http://sinalprivado.info:80/movie/1533784/1533784/647894.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4SQR4bRTYZpVZyHHgdpimNMXVz2.jpg', NULL, 0, 0, 'original', NULL),
(930, 33, 'Mario Batali: A Queda do Superchef', 'http://sinalprivado.info:80/movie/1533784/1533784/647895.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wjA2DA3PrGpNbvGmEylmKIPaEZc.jpg', NULL, 0, 0, 'original', NULL),
(931, 33, 'The Last Mountain', 'http://sinalprivado.info:80/movie/1533784/1533784/647896.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/adNemSIVVpQ1EwiBjygJCh6N9iF.jpg', NULL, 0, 0, 'original', NULL),
(932, 33, 'Sly', 'http://sinalprivado.info:80/movie/1533784/1533784/647897.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/flnrKe85SfgcRCW2KgUhz2Bn9yE.jpg', NULL, 0, 0, 'original', NULL),
(933, 33, 'Aeroporto de Cabul', 'http://sinalprivado.info:80/movie/1533784/1533784/647898.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t5J7gt6amDUZIQVGJ2JBNEsgVW0.jpg', NULL, 0, 0, 'original', NULL),
(934, 33, 'Higuita: El camino del Escorpión', 'http://sinalprivado.info:80/movie/1533784/1533784/647899.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hdSnhdqNE5bKa57qCwtCkWESjBA.jpg', NULL, 0, 0, 'original', NULL),
(935, 33, 'Explorer: Lago de Fogo', 'http://sinalprivado.info:80/movie/1533784/1533784/647900.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dPvrybP5kiLrKAuymDkfI6LlaSo.jpg', NULL, 0, 0, 'original', NULL),
(936, 33, 'O Marinheiro das Montanhas', 'http://sinalprivado.info:80/movie/1533784/1533784/647901.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/irOVXxNIL5mM4R1kCba0Eh03mww.jpg', NULL, 0, 0, 'original', NULL),
(937, 33, 'Porta Amarela: O Cineclube dos Anos 90', 'http://sinalprivado.info:80/movie/1533784/1533784/647902.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/znlWjvwrcSOcP3P43zvZLkAusys.jpg', NULL, 0, 0, 'original', NULL),
(938, 33, 'Clementina', 'http://sinalprivado.info:80/movie/1533784/1533784/647903.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A04WGl8ZMjV1SATCbcTk5wE2CI4.jpg', NULL, 0, 0, 'original', NULL),
(939, 33, 'ONEFOUR: Contra Tudo e Contra Todos', 'http://sinalprivado.info:80/movie/1533784/1533784/647904.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jyGwp6crW97VwexQWuUVmC4CcSO.jpg', NULL, 0, 0, 'original', NULL),
(940, 33, 'Porta Amarela: O Cineclube dos Anos 90', 'http://sinalprivado.info:80/movie/1533784/1533784/647905.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/znlWjvwrcSOcP3P43zvZLkAusys.jpg', NULL, 0, 0, 'original', NULL),
(941, 33, 'Livre Pensar', 'http://sinalprivado.info:80/movie/1533784/1533784/647906.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dLQ4tntEqFnmADPbfNN9NsSgCnT.jpg', NULL, 0, 0, 'original', NULL),
(942, 33, 'Duas Vidas: Do que Estamos Falando Quando Falamos Sobre Aborto', 'http://sinalprivado.info:80/movie/1533784/1533784/647907.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5p3I4AnmviNAFRrrf7u9U6B8Gxc.jpg', NULL, 0, 0, 'original', NULL),
(943, 33, 'O Método', 'http://sinalprivado.info:80/movie/1533784/1533784/647908.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/okYtQgJiVCcSyinavVIznAdbXKu.jpg', NULL, 0, 0, 'original', NULL),
(944, 33, 'Candeia', 'http://sinalprivado.info:80/movie/1533784/1533784/647909.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sJjUk5d5Pum3CL0QBFR5dTzHbvb.jpg', NULL, 0, 0, 'original', NULL),
(945, 33, 'Scott', 'http://sinalprivado.info:80/movie/1533784/1533784/647910.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/egCl6L7hrFhTpBf9dVc9G7Amh70.jpg', NULL, 0, 0, 'original', NULL),
(946, 33, 'A Lenda do Submundo', 'http://sinalprivado.info:80/movie/1533784/1533784/647911.mp4', 'http://gstaticontent.com/images/43bc8fb93a26a44ff6dbb3e938c49017.jpg', NULL, 0, 0, 'original', NULL),
(947, 33, 'A Sexplanation - Educação Sexual sem Tabu', 'http://sinalprivado.info:80/movie/1533784/1533784/647912.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9MLMKuLhAyqMTJmKajrJQNMdEmL.jpg', NULL, 0, 0, 'original', NULL),
(948, 33, 'O Diabo no Tribunal', 'http://sinalprivado.info:80/movie/1533784/1533784/647913.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AuRvQGdCRb3Gg4HuMVJDOJQNavl.jpg', NULL, 0, 0, 'original', NULL),
(949, 33, 'Camp Courage', 'http://sinalprivado.info:80/movie/1533784/1533784/647914.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l4p7Rzb7CGUhueRWWoIU75wvEYz.jpg', NULL, 0, 0, 'original', NULL),
(950, 33, 'Enquanto estamos aqui', 'http://sinalprivado.info:80/movie/1533784/1533784/647915.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/28uM98oviCGPB8DuSCM99kUoQGg.jpg', NULL, 0, 0, 'original', NULL),
(951, 33, 'Retratos Fantasmas', 'http://sinalprivado.info:80/movie/1533784/1533784/647916.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/akVsEkPbb41DQ0vODFZRtzXjuyy.jpg', NULL, 0, 0, 'original', NULL),
(952, 33, 'Corrida Para o Topo', 'http://sinalprivado.info:80/movie/1533784/1533784/647917.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/858KNVTGtmgjlELgmfXVchLVu7Z.jpg', NULL, 0, 0, 'original', NULL),
(953, 33, 'Mensagem Para a Humanidade', 'http://sinalprivado.info:80/movie/1533784/1533784/647918.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dirsPTc4YBn57rc4ZI1vmmDudnD.jpg', NULL, 0, 0, 'original', NULL),
(954, 33, 'A Face Oculta da Medicina', 'http://sinalprivado.info:80/movie/1533784/1533784/647919.mp4', 'https://i.bj-share.info/3dd57e508840983bfc1e736806f72275.jpg', NULL, 0, 0, 'original', NULL),
(955, 33, 'Escândalos Na Igreja A Luz Do Mundo', 'http://sinalprivado.info:80/movie/1533784/1533784/647920.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k7qyALu6MlC7DZVtDopWTvtoLN6.jpg', NULL, 0, 0, 'original', NULL),
(956, 33, 'Ice Cold O Caso Jessica Wongso', 'http://sinalprivado.info:80/movie/1533784/1533784/647921.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jKLFppqqwVq0ZRp5iKJboMf2EzL.jpg', NULL, 0, 0, 'original', NULL),
(957, 33, 'Lançando Segundas Chances', 'http://sinalprivado.info:80/movie/1533784/1533784/647922.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4yGhktbhmLixEfpK3yrRFHXdL7W.jpg', NULL, 0, 0, 'original', NULL),
(958, 33, 'Tributo - Lea Garcia', 'http://sinalprivado.info:80/movie/1533784/1533784/647923.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qp4CV7uYaP13RRWXg6imLNzYsb1.jpg', NULL, 0, 0, 'original', NULL),
(959, 33, 'Arquivos da Perversão: Os Abusos na Boy Scouts of America', 'http://sinalprivado.info:80/movie/1533784/1533784/647924.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dP6QJ62LQL8xPqBTueXRYILJKm0.jpg', NULL, 0, 0, 'original', NULL),
(960, 33, 'A Sutil Arte de Ligar o F*da-se', 'http://sinalprivado.info:80/movie/1533784/1533784/647925.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jRRXELIL5G2L8SqrpZEEQF6MfwZ.jpg', NULL, 0, 0, 'original', NULL),
(961, 33, 'O Caso Rosa Peral', 'http://sinalprivado.info:80/movie/1533784/1533784/647926.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8jAnsIm4qzy28IBJeJsTQCdnORE.jpg', NULL, 0, 0, 'original', NULL),
(962, 33, 'A Música Está Servida: Thiaguinho', 'http://sinalprivado.info:80/movie/1533784/1533784/647927.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tebCWa4ODUqLtkTn6mrblHRuiwA.jpg', NULL, 0, 0, 'original', NULL),
(963, 33, 'Palmeiras Gloria Eterna Cabeca Fria e Coracao Quente', 'http://sinalprivado.info:80/movie/1533784/1533784/647928.mp4', 'https://i.bj-share.info/99c3ecd2968780758043c378ed105c06.jpg', NULL, 0, 0, 'original', NULL),
(964, 33, 'O Diário de Lidwina', 'http://sinalprivado.info:80/movie/1533784/1533784/647929.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/unw4T59tl1DIvkyE2Q0s4ZN6n5R.jpg', NULL, 0, 0, 'original', NULL),
(965, 33, 'Coronavírus: A História Não Contada', 'http://sinalprivado.info:80/movie/1533784/1533784/647930.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cg6mXmO8z0KjgGDCJKlA7qD9BWC.jpg', NULL, 0, 0, 'original', NULL),
(966, 33, 'Abrigo Inocentes Sob Ataque', 'http://sinalprivado.info:80/movie/1533784/1533784/647931.mp4', 'https://i.bj-share.info/9478e84d4655beadb00e4fe517b9a16a.jpg', NULL, 0, 0, 'original', NULL),
(967, 33, 'O Último Navio Negreiro', 'http://sinalprivado.info:80/movie/1533784/1533784/647932.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lIBLJHHRkv1zxdPEhqF8FoieEN3.jpg', NULL, 0, 0, 'original', NULL),
(968, 33, 'Isabella: o Caso Nardoni', 'http://sinalprivado.info:80/movie/1533784/1533784/647933.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/53pmHd5XialRnoTXlLwwBaezEOs.jpg', NULL, 0, 0, 'original', NULL),
(969, 33, 'Untold: A Vergonha do Doping', 'http://sinalprivado.info:80/movie/1533784/1533784/647934.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sIk2wnKj9OSMrUNZ5Z97XkzUICK.jpg', NULL, 0, 0, 'original', NULL),
(970, 33, 'Revolution Rent', 'http://sinalprivado.info:80/movie/1533784/1533784/647935.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fuuxg6rfd2KOISI7sKQpsBCOHHb.jpg', NULL, 0, 0, 'original', NULL),
(971, 33, 'Querido Rider: a História de Jake Burton', 'http://sinalprivado.info:80/movie/1533784/1533784/647936.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tkr9G0QOarjBStPMVJpIiB1PyBt.jpg', NULL, 0, 0, 'original', NULL),
(972, 33, 'Untold: Johnny Football', 'http://sinalprivado.info:80/movie/1533784/1533784/647937.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e7CKgRnRdE7bk1jl2vhJniX89cU.jpg', NULL, 0, 0, 'original', NULL),
(973, 33, 'O Último Cruzeiro', 'http://sinalprivado.info:80/movie/1533784/1533784/647938.mp4', 'http://gstaticontent.com/images/47bf7a75c290e6f62a47c86e36c6cfe2.jpg', NULL, 0, 0, 'original', NULL),
(974, 33, 'Our Towns - Uma Viagem ao Coração dos EUA', 'http://sinalprivado.info:80/movie/1533784/1533784/647939.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gmyqbXOgTndbBPPVDlomkyCPDB3.jpg', NULL, 0, 0, 'original', NULL),
(975, 33, 'Vulcões e Tubarões: Havaí', 'http://sinalprivado.info:80/movie/1533784/1533784/647940.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q3N44XL6l1AHRyDgTN1BRTEfRvV.jpg', NULL, 0, 0, 'original', NULL),
(976, 33, 'Shark Below Zero', 'http://sinalprivado.info:80/movie/1533784/1533784/647941.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c1UAwMeuBXVluMNCJ4EYqFfy52E.jpg', NULL, 0, 0, 'original', NULL),
(977, 33, 'Resgatados dos Tubarões', 'http://sinalprivado.info:80/movie/1533784/1533784/647942.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3df3FZ0q0DCTFUwmi7d43fuaIaQ.jpg', NULL, 0, 0, 'original', NULL),
(978, 33, 'Chico Para Sempre', 'http://sinalprivado.info:80/movie/1533784/1533784/647943.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wqXF7uGE76v8JVbHws9s9qSN7P6.jpg', NULL, 0, 0, 'original', NULL),
(979, 33, 'O Garoto Problema', 'http://sinalprivado.info:80/movie/1533784/1533784/647944.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qvl8lx0wIK5VyFMLEOKmdaoR2XJ.jpg', NULL, 0, 0, 'original', NULL),
(980, 33, 'Pedalando Até O Fim', 'http://sinalprivado.info:80/movie/1533784/1533784/647945.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uhYZEOkOEByyEMD8C6oUPn7gAa.jpg', NULL, 0, 0, 'original', NULL),
(981, 33, 'A Turma do Pererê.DOC', 'http://sinalprivado.info:80/movie/1533784/1533784/647946.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dLibYW1rC8Zil2sUtygWDPlZ71m.jpg', NULL, 0, 0, 'original', NULL),
(982, 33, 'Currais', 'http://sinalprivado.info:80/movie/1533784/1533784/647947.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qpbPsjAH2pLu3pWDhyLwsToysJu.jpg', NULL, 0, 0, 'original', NULL),
(983, 33, 'A Dama do Silêncio: La Mataviejitas', 'http://sinalprivado.info:80/movie/1533784/1533784/647948.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fd5B1I6riT7oze7FntN51RvTPyn.jpg', NULL, 0, 0, 'original', NULL),
(984, 33, 'O Amigo do Rei', 'http://sinalprivado.info:80/movie/1533784/1533784/647949.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/54dQOF5XIS6ZXzx9WUtPYziqmNc.jpg', NULL, 0, 0, 'original', NULL),
(985, 33, 'Um Tiro no Escuro', 'http://sinalprivado.info:80/movie/1533784/1533784/647950.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r3HBViPKRfQJ0nwIuo93N5N9MGF.jpg', NULL, 0, 0, 'original', NULL),
(986, 33, 'O Mochileiro Kai: Herói ou Assassino?', 'http://sinalprivado.info:80/movie/1533784/1533784/647951.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kqLloC5n66fLvhlWtZBr8h4SVF6.jpg', NULL, 0, 0, 'original', NULL),
(987, 33, 'A Alma da América', 'http://sinalprivado.info:80/movie/1533784/1533784/647952.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kqEFRpM6j4314nO2No6xYzhvAyx.jpg', NULL, 0, 0, 'original', NULL),
(988, 33, 'Desaparecida: O Caso Lucie Blackman', 'http://sinalprivado.info:80/movie/1533784/1533784/647953.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bz44Ug0pzMwV0kjNTeS4y1lxUar.jpg', NULL, 0, 0, 'original', NULL),
(989, 33, 'Explorando o Desconhecido: A Maquina do Tempo Cosmica', 'http://sinalprivado.info:80/movie/1533784/1533784/647954.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2vGLKTPSFP90A2N1glcVlrIs3nM.jpg', NULL, 0, 0, 'original', NULL),
(990, 33, 'Nheengatu – A Língua da Amazónia', 'http://sinalprivado.info:80/movie/1533784/1533784/647955.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kAPqVSVvtRD5kJ6w6oXuwK5q8gr.jpg', NULL, 0, 0, 'original', NULL),
(991, 33, 'De Tirar o Fôlego', 'http://sinalprivado.info:80/movie/1533784/1533784/647956.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dinZWscZF1xjO6T36dHRB11ZWx7.jpg', NULL, 0, 0, 'original', NULL),
(992, 33, 'A Queda e a Ascensão do Lutador Vampiro', 'http://sinalprivado.info:80/movie/1533784/1533784/647957.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7DlkMtc6tCDeYxJSkBn06PKv88I.jpg', NULL, 0, 0, 'original', NULL),
(993, 33, 'Unknown: Cave of Bones', 'http://sinalprivado.info:80/movie/1533784/1533784/647958.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/irDu0rnlzTpl8RkOEl7XG2B88tJ.jpg', NULL, 0, 0, 'original', NULL),
(994, 33, 'Cadê o Amarildo?', 'http://sinalprivado.info:80/movie/1533784/1533784/647959.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j8EynTfwbqMnjQ7Z1kNoct9UAb4.jpg', NULL, 0, 0, 'original', NULL),
(995, 33, 'A Cobra do Alabama', 'http://sinalprivado.info:80/movie/1533784/1533784/647960.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hgPy5fkCKzHi7F6EcWX8QxGDTPG.jpg', NULL, 0, 0, 'original', NULL),
(996, 33, 'A Venezuela em Solo Brasileiro', 'http://sinalprivado.info:80/movie/1533784/1533784/647961.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cdYFiGE3ClOCd4eocV2VQnVRbxj.jpg', NULL, 0, 0, 'original', NULL),
(997, 33, 'Infiltrados: Venezuela', 'http://sinalprivado.info:80/movie/1533784/1533784/647962.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tch6Om8GiDF0d2fGdymbltctPrh.jpg', NULL, 0, 0, 'original', NULL),
(998, 33, 'Explorando o Desconhecido Robos Assassinos', 'http://sinalprivado.info:80/movie/1533784/1533784/647963.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kStspgmYJUfRarvEmJcsKds8m1o.jpg', NULL, 0, 0, 'original', NULL),
(999, 33, 'Amazônia Sociedade Anônima', 'http://sinalprivado.info:80/movie/1533784/1533784/647964.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jpTPLytxrsrTEVS5B7piwjZislC.jpg', NULL, 0, 0, 'original', NULL),
(1000, 33, 'Amazônia - O Despertar da Florestania', 'http://sinalprivado.info:80/movie/1533784/1533784/647965.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oGPNoTBCpkcMLD8JZkn8kFyhYX6.jpg', NULL, 0, 0, 'original', NULL),
(1001, 33, 'Amazônia na Encruzilhada', 'http://sinalprivado.info:80/movie/1533784/1533784/647966.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eFChFiliYjjnh0Ms5yNfI0PsDNi.jpg', NULL, 0, 0, 'original', NULL),
(1002, 33, '12 Moedas', 'http://sinalprivado.info:80/movie/1533784/1533784/647967.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cFhlpp2YQLDSKcvMHbgkPtuJfHl.jpg', NULL, 0, 0, 'original', NULL),
(1003, 33, 'Sharks vs. Dolphins: Bahamas Battleground', 'http://sinalprivado.info:80/movie/1533784/1533784/647968.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jjcrRAFGWDbhfyLUhTWbRaM5yCR.jpg', NULL, 0, 0, 'original', NULL),
(1004, 33, 'Tubarões Cabeça-Chata Bandidos', 'http://sinalprivado.info:80/movie/1533784/1533784/647969.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sWZU0KVXAuqyIivpTuXptOOxE2Q.jpg', NULL, 0, 0, 'original', NULL),
(1005, 33, 'Olavo Tem Razão - O Filme', 'http://sinalprivado.info:80/movie/1533784/1533784/647970.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/23znVCWbJ5HgthMzVxGHhz4PxYe.jpg', NULL, 0, 0, 'original', NULL),
(1006, 33, 'Complexo de Deus: Os Bebês do Dr. Quincy Fortier', 'http://sinalprivado.info:80/movie/1533784/1533784/647971.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iJ7k5pR5hKc6nII53I318l3ZnBJ.jpg', NULL, 0, 0, 'original', NULL),
(1007, 33, 'Bull Shark vs. Hammerhead', 'http://sinalprivado.info:80/movie/1533784/1533784/647972.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9iE64XDswcaLPi0A1XN910Ue7Ro.jpg', NULL, 0, 0, 'original', NULL),
(1008, 33, 'Unknown: The Lost Pyramid', 'http://sinalprivado.info:80/movie/1533784/1533784/647973.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5KV7WxGjF5O5fhBJnjNME4jkJC7.jpg', NULL, 0, 0, 'original', NULL),
(1009, 33, 'Como ser Warren Buffett', 'http://sinalprivado.info:80/movie/1533784/1533784/647974.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sMS6f2uBu0tyGK9iowA21La9F1o.jpg', NULL, 0, 0, 'original', NULL),
(1010, 33, 'A História do Hino Americano', 'http://sinalprivado.info:80/movie/1533784/1533784/647975.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iVLreoOLMg2qP8NcTNY88BqTCkz.jpg', NULL, 0, 0, 'original', NULL),
(1011, 33, 'Filhas Roubadas: Sequestro pelo Boko Haram', 'http://sinalprivado.info:80/movie/1533784/1533784/647976.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mQlpWxBzH4GosnQ5MT75Oi4zxF0.jpg', NULL, 0, 0, 'original', NULL),
(1012, 33, 'Cabaré Eldorado: O Alvo dos Nazistas', 'http://sinalprivado.info:80/movie/1533784/1533784/647977.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8acQ699CU6hNzH3Quxc6C2CaD6.jpg', NULL, 0, 0, 'original', NULL),
(1013, 33, 'De Volta ao Titanic', 'http://sinalprivado.info:80/movie/1533784/1533784/647978.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tHQFLTI6man9BfELaQVCr6LRDd2.jpg', NULL, 0, 0, 'original', NULL),
(1014, 33, 'O Rei dos Clones', 'http://sinalprivado.info:80/movie/1533784/1533784/647979.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jJAF2h2iLLCpKUocEnoJz7wKtWq.jpg', NULL, 0, 0, 'original', NULL),
(1015, 33, 'O Mistério de Maya', 'http://sinalprivado.info:80/movie/1533784/1533784/647980.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9niJrWHUCnPnDTrnYmVki663Esf.jpg', NULL, 0, 0, 'original', NULL),
(1016, 33, 'Rewind', 'http://sinalprivado.info:80/movie/1533784/1533784/647981.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gMq3nv8zlShHy2E9NTOwdECsdN3.jpg', NULL, 0, 0, 'original', NULL),
(1017, 33, 'Irmãos por escolha', 'http://sinalprivado.info:80/movie/1533784/1533784/647982.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fN8SBoDHYT2zO1x80GhhX605WuX.jpg', NULL, 0, 0, 'original', NULL),
(1018, 33, 'Isto (não) é um Assalto', 'http://sinalprivado.info:80/movie/1533784/1533784/647983.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bTkXF0Ap2zzh71UEOvgXEC91Vag.jpg', NULL, 0, 0, 'original', NULL),
(1019, 33, 'O Massacre na Universidade de Idaho', 'http://sinalprivado.info:80/movie/1533784/1533784/647984.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dMDuHlUhxyZnlMBCncwz6GCoylk.jpg', NULL, 0, 0, 'original', NULL),
(1020, 33, 'Os Donos da Casa', 'http://sinalprivado.info:80/movie/1533784/1533784/647985.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d0yFbGq9zPNunjf9bpJqHgF7VeS.jpg', NULL, 0, 0, 'original', NULL),
(1021, 33, 'Antena da Raça', 'http://sinalprivado.info:80/movie/1533784/1533784/647986.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7tlQPPtRy56eT3ENHH7u38BKzZT.jpg', NULL, 0, 0, 'original', NULL),
(1022, 33, 'Àkàrà: No Fogo da Intolerância', 'http://sinalprivado.info:80/movie/1533784/1533784/647987.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/68QOpNSKy7uc8dSKivu7cJKbxkS.jpg', NULL, 0, 0, 'original', NULL),
(1023, 33, 'Vítima X Suspeita', 'http://sinalprivado.info:80/movie/1533784/1533784/647988.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tGaFFNfqS6rH51LJS8a663OGwdO.jpg', NULL, 0, 0, 'original', NULL),
(1024, 33, 'É Noite na América', 'http://sinalprivado.info:80/movie/1533784/1533784/647989.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wm9Ml0ddyOfd7BXLKWvoRNynNmy.jpg', NULL, 0, 0, 'original', NULL),
(1025, 33, 'Anna Nicole Smith: Vocês Não Me Conhecem', 'http://sinalprivado.info:80/movie/1533784/1533784/647990.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mybL2Hd3PvsY7Qyjf7W6BKsoECu.jpg', NULL, 0, 0, 'original', NULL),
(1026, 33, 'HIV A Pandemia Negligenciada', 'http://sinalprivado.info:80/movie/1533784/1533784/647991.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfSR8Y7jxVlLMCgwH2cz8Te4kU.jpg', NULL, 0, 0, 'original', NULL),
(1027, 33, 'Andança – Os Encontros e as Memórias de Beth Carvalho', 'http://sinalprivado.info:80/movie/1533784/1533784/647992.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5dF2RNPdAB44rgtbwFzvFKVbSxh.jpg', NULL, 0, 0, 'original', NULL),
(1028, 33, 'Charles: Do Berço ao Trono', 'http://sinalprivado.info:80/movie/1533784/1533784/647993.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b1bjrOExjYxKDFH8wxfmZX4cVsw.jpg', NULL, 0, 0, 'original', NULL),
(1029, 33, 'Ademã – A Vida e as Notas de Ibrahim Sued', 'http://sinalprivado.info:80/movie/1533784/1533784/647994.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/78YNWIaQbjWHPEXwlqxeOg10I3N.jpg', NULL, 0, 0, 'original', NULL),
(1030, 33, 'Brasileiríssima - A história da telenovela', 'http://sinalprivado.info:80/movie/1533784/1533784/647995.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g5GQzpzh1Wrg2ppUOMButuLe8vG.jpg', NULL, 0, 0, 'original', NULL),
(1031, 33, 'A Primeira Pedra', 'http://sinalprivado.info:80/movie/1533784/1533784/647996.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oLhjXm83XgLK8haxY1iNzp2Rs7D.jpg', NULL, 0, 0, 'original', NULL),
(1032, 33, 'Harry: O Príncipe que Sobrou', 'http://sinalprivado.info:80/movie/1533784/1533784/647997.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4qi9618AMRE9jgqEAro34cGSqNq.jpg', NULL, 0, 0, 'original', NULL),
(1033, 33, 'O Caminho da Pantera', 'http://sinalprivado.info:80/movie/1533784/1533784/647998.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/548qM0s0xKFrU793G9dYXaIdwIk.jpg', NULL, 0, 0, 'original', NULL),
(1034, 33, 'Destinado Ao Trono', 'http://sinalprivado.info:80/movie/1533784/1533784/647999.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9Q3vAWEerqmYAnIqQBeJ98qCrl7.jpg', NULL, 0, 0, 'original', NULL),
(1035, 33, 'Audrey', 'http://sinalprivado.info:80/movie/1533784/1533784/648000.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ikAgImz1rkedYM2mW0TeGZP1xdi.jpg', NULL, 0, 0, 'original', NULL),
(1036, 33, 'The Wonderful: Stories from the Space Station', 'http://sinalprivado.info:80/movie/1533784/1533784/648001.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gpnR96cBUz0oy0F6sDdLwRqzW2s.jpg', NULL, 0, 0, 'original', NULL),
(1037, 33, 'O Encontro Mais Longo de Todos', 'http://sinalprivado.info:80/movie/1533784/1533784/648002.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pzusJE1LqhG06S92IdPYlTu8N1p.jpg', NULL, 0, 0, 'original', NULL),
(1038, 33, 'Untold: Crime e Infrações', 'http://sinalprivado.info:80/movie/1533784/1533784/648003.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4SdpmFatNnyJBCB7cpBPA7BIAj5.jpg', NULL, 0, 0, 'original', NULL),
(1039, 33, 'Criminoso ou Inocente: O Caso Big Mäck', 'http://sinalprivado.info:80/movie/1533784/1533784/648004.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k5qs9mKMMA0gBIdJnYOxSwgWc6u.jpg', NULL, 0, 0, 'original', NULL),
(1040, 33, 'Fahrenheit 11 de Setembro', 'http://sinalprivado.info:80/movie/1533784/1533784/648005.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fqYHw4cCgEbbWqhA4MIuWKZZ4RA.jpg', NULL, 0, 0, 'original', NULL),
(1041, 33, 'Caçando Assassinos: Morte na Montanha', 'http://sinalprivado.info:80/movie/1533784/1533784/648006.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c0JpWqxEoeaQdD0n2Bqn5EvhAhA.jpg', NULL, 0, 0, 'original', NULL),
(1042, 33, 'A Misteriosa Tumba de Tutancâmon', 'http://sinalprivado.info:80/movie/1533784/1533784/648007.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bx3UBNjbmxCrHZWve7Jz3sEnggB.jpg', NULL, 0, 0, 'original', NULL),
(1043, 33, 'Vivo', 'http://sinalprivado.info:80/movie/1533784/1533784/648008.mp4', 'https://i.bj-share.info/c1247a51400bc48e6ce278754f309ddb.jpg', NULL, 0, 0, 'original', NULL),
(1044, 33, 'A Arca das Girafas', 'http://sinalprivado.info:80/movie/1533784/1533784/648009.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/87xYDGhbi9xdM5MAhs6YM5qJWoy.jpg', NULL, 0, 0, 'original', NULL),
(1045, 33, 'O Leonardo Perdido', 'http://sinalprivado.info:80/movie/1533784/1533784/648010.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8CCtH4klPFUOtW6sO17fJUnEIhj.jpg', NULL, 0, 0, 'original', NULL),
(1046, 33, 'Pornhub: Sexo Bilionário', 'http://sinalprivado.info:80/movie/1533784/1533784/648011.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ae9ooWLtS4LEsSBCUvaFkrrxqiH.jpg', NULL, 0, 0, 'original', NULL),
(1047, 33, 'Dentro da Mente de um Gato', 'http://sinalprivado.info:80/movie/1533784/1533784/648012.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gTlxP1yJFPB2jegg4ece5iIWfgr.jpg', NULL, 0, 0, 'original', NULL),
(1048, 33, 'A Academia do Diabo', 'http://sinalprivado.info:80/movie/1533784/1533784/648013.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tCd9zcdjHcidTkGNgwRx4hhXkI5.jpg', NULL, 0, 0, 'original', NULL),
(1049, 33, 'As Almas Perdidas do Voo 401', 'http://sinalprivado.info:80/movie/1533784/1533784/648014.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3eZmNQpFNf7KSoMVLi13di00ZQv.jpg', NULL, 0, 0, 'original', NULL),
(1050, 33, 'O Rei Macaco: A Lenda Começa', 'http://sinalprivado.info:80/movie/1533784/1533784/648015.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aYEWg7ir0XD4mMUA1pyHNGImrOZ.jpg', NULL, 0, 0, 'original', NULL),
(1051, 33, 'Foster: Adotados Pelo Sistema', 'http://sinalprivado.info:80/movie/1533784/1533784/648016.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kwTaA6QqpOWf0qsejIlcmTaBoU.jpg', NULL, 0, 0, 'original', NULL),
(1052, 33, 'Nicarágua: Liberdade Exilada', 'http://sinalprivado.info:80/movie/1533784/1533784/648017.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dQHYtI1LFZjv0zss12fm7XX7bfm.jpg', NULL, 0, 0, 'original', NULL),
(1053, 33, 'O Dissidente', 'http://sinalprivado.info:80/movie/1533784/1533784/648018.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sWOydQT9v8aNWnzStzoKsi2mcIh.jpg', NULL, 0, 0, 'original', NULL),
(1054, 33, 'Pamela Anderson: Uma História de Amor', 'http://sinalprivado.info:80/movie/1533784/1533784/648019.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lBR1sFFfwZLVz22ZvjD5GYDp8yC.jpg', NULL, 0, 0, 'original', NULL),
(1055, 33, 'Transversais', 'http://sinalprivado.info:80/movie/1533784/1533784/648020.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4SOT9FbmPna3z7ve8u9LgbF264p.jpg', NULL, 0, 0, 'original', NULL),
(1056, 33, 'Chico Rei Entre Nós', 'http://sinalprivado.info:80/movie/1533784/1533784/648021.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iJlEM9DpOmTKyZ8hv43bnIQRnU0.jpg', NULL, 0, 0, 'original', NULL),
(1057, 33, 'Kaiser: O Jogador De Futebol Que Nunca Jogou', 'http://sinalprivado.info:80/movie/1533784/1533784/648022.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fJU0pVoQ8zvlnROxiIj6wKTo0vW.jpg', NULL, 0, 0, 'original', NULL),
(1058, 33, 'O Ataque ao Capitólio', 'http://sinalprivado.info:80/movie/1533784/1533784/648023.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5z3dkp3l6TwVDp1cNdQaLGtk0oT.jpg', NULL, 0, 0, 'original', NULL),
(1059, 33, 'O Segredo', 'http://sinalprivado.info:80/movie/1533784/1533784/648024.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9MwvHnVXqkTx7eMuFWuqfJ3ccIm.jpg', NULL, 0, 0, 'original', NULL),
(1060, 33, 'Diana A Eterna Princesa', 'http://sinalprivado.info:80/movie/1533784/1533784/648025.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xp88sGrHWVn6N2s3xmg3SGfuxR9.jpg', NULL, 0, 0, 'original', NULL),
(1061, 33, 'The Real Charlie Chaplin', 'http://sinalprivado.info:80/movie/1533784/1533784/648026.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fFTdUcQWp9xYtpuuddWts02bp3M.jpg', NULL, 0, 0, 'original', NULL),
(1062, 33, 'Bisping', 'http://sinalprivado.info:80/movie/1533784/1533784/648027.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tybqRPpxnaoQiCxFmy3Yz3GoOub.jpg', NULL, 0, 0, 'original', NULL),
(1063, 33, 'O Amor Sertanejo', 'http://sinalprivado.info:80/movie/1533784/1533784/648028.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lCeivb6kEiA2Y0Yb30BT2IL7wuN.jpg', NULL, 0, 0, 'original', NULL),
(1064, 33, 'Jack Osbourne: Em Busca dos Óvnis', 'http://sinalprivado.info:80/movie/1533784/1533784/648029.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6DESAF0DIpMxAjQpqkSeOmi70tu.jpg', NULL, 0, 0, 'original', NULL),
(1065, 33, 'O Time da Redenção', 'http://sinalprivado.info:80/movie/1533784/1533784/648030.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8G9XOb9bO9LusWEI2dOAyaCf8Bb.jpg', NULL, 0, 0, 'original', NULL),
(1066, 33, 'Retrospectiva Globo (2022)', 'http://sinalprivado.info:80/movie/1533784/1533784/648031.mp4', 'https://i.bj-share.info/e18a251cab1eeb30ffbe60348236221a.jpg', NULL, 0, 0, 'original', NULL),
(1067, 33, 'Varig: A Caixa-Preta do Brasil', 'http://sinalprivado.info:80/movie/1533784/1533784/648032.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3HEADpGkr12fXev9TPsUDOQfttS.jpg', NULL, 0, 0, 'original', NULL),
(1068, 33, 'Kangaroo Valley', 'http://sinalprivado.info:80/movie/1533784/1533784/648033.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5pl84OGmiTSKgZNcGF2w3S9W0DB.jpg', NULL, 0, 0, 'original', NULL),
(1069, 33, 'Vulcão Whakaari: Resgate na Nova Zelândia', 'http://sinalprivado.info:80/movie/1533784/1533784/648034.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gSTZ7B1yn6AeTAbxKvwqOkbXKyh.jpg', NULL, 0, 0, 'original', NULL),
(1070, 33, 'Explorer', 'http://sinalprivado.info:80/movie/1533784/1533784/648035.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/faxYsLLhZS95cycP5ParjFs79ZS.jpg', NULL, 0, 0, 'original', NULL),
(1071, 33, 'Lutar', 'http://sinalprivado.info:80/movie/1533784/1533784/648036.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4e7JBYHF7UDBHYwOKUqPKGYloAY.jpg', NULL, 0, 0, 'original', NULL),
(1072, 33, 'Filho da Mãe', 'http://sinalprivado.info:80/movie/1533784/1533784/648037.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z8ZbaGCahlXwri66rPHjgw54jo1.jpg', NULL, 0, 0, 'original', NULL),
(1073, 33, 'Oppy', 'http://sinalprivado.info:80/movie/1533784/1533784/648038.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7DTWN79hsN5AZEhW8w4SOquSI4D.jpg', NULL, 0, 0, 'original', NULL),
(1074, 33, 'Ghislaine Maxwell: Filthy Rich', 'http://sinalprivado.info:80/movie/1533784/1533784/648039.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i9vl0FxtPQaiTOMRoKYhEuu9xw3.jpg', NULL, 0, 0, 'original', NULL),
(1075, 33, 'O Skate Me Levou', 'http://sinalprivado.info:80/movie/1533784/1533784/648040.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9Rckj6QGD9eadX8VSsOM2lD4gT3.jpg', NULL, 0, 0, 'original', NULL),
(1076, 33, 'Visitas Extraterrestres', 'http://sinalprivado.info:80/movie/1533784/1533784/648041.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mC0GjHcnrkQRVBmHEVd54dGV1m0.jpg', NULL, 0, 0, 'original', NULL),
(1077, 33, 'O Impostor Mascarado', 'http://sinalprivado.info:80/movie/1533784/1533784/648042.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oAcf5WdiBB3VfdIMpR7tRUnZ6yC.jpg', NULL, 0, 0, 'original', NULL),
(1078, 33, 'Cavalo de Santo', 'http://sinalprivado.info:80/movie/1533784/1533784/648043.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mf7v0JqgsvFot7EpoouptYU1G7x.jpg', NULL, 0, 0, 'original', NULL),
(1079, 33, 'Racionais: Das Ruas de São Paulo pro Mundo', 'http://sinalprivado.info:80/movie/1533784/1533784/648044.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mRsRonH875t4CU7wFpDCqCPQ9Qz.jpg', NULL, 0, 0, 'original', NULL),
(1080, 33, 'Moment of Contact', 'http://sinalprivado.info:80/movie/1533784/1533784/648045.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aZDura0Fm3OZtPlBqMkWDs04C7a.jpg', NULL, 0, 0, 'original', NULL),
(1081, 33, 'O Território', 'http://sinalprivado.info:80/movie/1533784/1533784/648046.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/88lHYgTEPiXiMRZRgudfPMHzML3.jpg', NULL, 0, 0, 'original', NULL),
(1082, 33, 'O Método de Stutz', 'http://sinalprivado.info:80/movie/1533784/1533784/648047.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uOiJmotRM12wsgfwiEXsp3AErdU.jpg', NULL, 0, 0, 'original', NULL);
INSERT INTO `channels` (`id`, `category_id`, `name`, `stream_url`, `logo_url`, `epg_id`, `pid`, `running`, `transcode_quality`, `uptime`) VALUES
(1083, 33, 'Uma Viagem ao Infinito', 'http://sinalprivado.info:80/movie/1533784/1533784/648048.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/38KllKVpeTLvirHvuLWWy5I71rX.jpg', NULL, 0, 0, 'original', NULL),
(1084, 33, 'Mickey: A História de um Camundongo', 'http://sinalprivado.info:80/movie/1533784/1533784/648049.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ryZX7DPAl2Wv5LMR4JsBJUy5RPr.jpg', NULL, 0, 0, 'original', NULL),
(1085, 33, 'Eu Sou Vanessa Guillen', 'http://sinalprivado.info:80/movie/1533784/1533784/648050.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/idRnGEvyYN44wlp39WYVz4lpLK8.jpg', NULL, 0, 0, 'original', NULL),
(1086, 33, 'Vulcões: A Tragédia de Katia e Maurice Krafft', 'http://sinalprivado.info:80/movie/1533784/1533784/648051.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jT8R2lqEpC49odCc1fCzAi6Z0ZE.jpg', NULL, 0, 0, 'original', NULL),
(1087, 33, 'Em Busca do Enfermeiro da Noite', 'http://sinalprivado.info:80/movie/1533784/1533784/648052.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1LyrqFX0yHVutUt1U5SsefF0i7A.jpg', NULL, 0, 0, 'original', NULL),
(1088, 33, 'Cracolândia', 'http://sinalprivado.info:80/movie/1533784/1533784/648053.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lVqaxodyMIuS4Km1Ru67GxYZLsB.jpg', NULL, 0, 0, 'original', NULL),
(1089, 33, 'Sobre Nós', 'http://sinalprivado.info:80/movie/1533784/1533784/648054.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jyWC1262VLW1qt8ByDXFpGgqStV.jpg', NULL, 0, 0, 'original', NULL),
(1090, 33, 'O Fenômeno', 'http://sinalprivado.info:80/movie/1533784/1533784/648055.mp4', 'http://gstaticontent.com/images/4ddff30a25077666f38bff7848797537.jpg', NULL, 0, 0, 'original', NULL),
(1091, 33, 'Brasil 2002: Os Bastidores do Penta', 'http://sinalprivado.info:80/movie/1533784/1533784/648056.mp4', 'http://gstaticontent.com/images/26d76fc9e04b0ea557c8b141749e2b59.jpg', NULL, 0, 0, 'original', NULL),
(1092, 33, 'A Primeira-Dama do Estado Islâmico', 'http://sinalprivado.info:80/movie/1533784/1533784/648057.mp4', 'http://gstaticontent.com/images/d68874ef3de483c6cad24ef266d53a3c.jpg', NULL, 0, 0, 'original', NULL),
(1093, 33, 'Amigo Secreto', 'http://sinalprivado.info:80/movie/1533784/1533784/648058.mp4', 'http://gstaticontent.com/images/99b1397527cd8f4f14c579769b841226.jpg', NULL, 0, 0, 'original', NULL),
(1094, 33, 'Ana. Sem Título', 'http://sinalprivado.info:80/movie/1533784/1533784/648059.mp4', 'http://gstaticontent.com/images/8cb1c76165a643913ab861d03f777371.jpg', NULL, 0, 0, 'original', NULL),
(1095, 33, 'Antraz: EUA Sob Ataque', 'http://sinalprivado.info:80/movie/1533784/1533784/648060.mp4', 'http://gstaticontent.com/images/3b59eaae4089b6856f0f54b3adf5e12e.jpg', NULL, 0, 0, 'original', NULL),
(1096, 33, 'Obi-Wan Kenobi: O Retorno do Jedi', 'http://sinalprivado.info:80/movie/1533784/1533784/648061.mp4', 'http://gstaticontent.com/images/0171ea78bf63d56cb6dee8a60630f6c7.jpg', NULL, 0, 0, 'original', NULL),
(1097, 33, 'UNTOLD: A Regata do Século', 'http://sinalprivado.info:80/movie/1533784/1533784/648062.mp4', 'http://gstaticontent.com/images/3c136af579c95befc34fe9c5203b70ad.jpg', NULL, 0, 0, 'original', NULL),
(1098, 33, 'O Caso Figo: A Transferência que Mudou o Futebol', 'http://sinalprivado.info:80/movie/1533784/1533784/648063.mp4', 'http://gstaticontent.com/images/09289cc51f54218f1d7f01bb288c4673.jpg', NULL, 0, 0, 'original', NULL),
(1099, 33, 'A Verdadeira História do Roubo do Século', 'http://sinalprivado.info:80/movie/1533784/1533784/648064.mp4', 'http://gstaticontent.com/images/64a95764268bc22ec470b915077642c7.jpg', NULL, 0, 0, 'original', NULL),
(1100, 33, 'O Sequestrador de Cleveland', 'http://sinalprivado.info:80/movie/1533784/1533784/648065.mp4', 'http://gstaticontent.com/images/755d15eb204a0babe1cde7e0c14d4b3e.jpg', NULL, 0, 0, 'original', NULL),
(1101, 33, 'Bios. Vidas que marcaram a sua: Titãs', 'http://sinalprivado.info:80/movie/1533784/1533784/648066.mp4', 'http://gstaticontent.com/images/9388f362943cfbae26d794554eaffd88.jpg', NULL, 0, 0, 'original', NULL),
(1102, 33, 'João Gilberto?', 'http://sinalprivado.info:80/movie/1533784/1533784/648067.mp4', 'http://gstaticontent.com/images/a9aaa0d4c8b5eca9da36c709cb215715.jpg', NULL, 0, 0, 'original', NULL),
(1103, 33, 'Titanic: No Coração do Naufrágio', 'http://sinalprivado.info:80/movie/1533784/1533784/648068.mp4', 'http://gstaticontent.com/images/f64e34ab67aed4a8b8e772a2acd046e7.jpg', NULL, 0, 0, 'original', NULL),
(1104, 33, 'Apollo: Missão à Lua', 'http://sinalprivado.info:80/movie/1533784/1533784/648069.mp4', 'http://gstaticontent.com/images/ad72ff41f3fc98be78eca31a40975562.jpg', NULL, 0, 0, 'original', NULL),
(1105, 33, 'Flee: Nenhum Lugar Para Chamar de Lar', 'http://sinalprivado.info:80/movie/1533784/1533784/648070.mp4', 'http://gstaticontent.com/images/fc929016ffe8cbded3d55ddee7b03da1.jpg', NULL, 0, 0, 'original', NULL),
(1106, 33, 'Colonização Espacial: A Última Esperança', 'http://sinalprivado.info:80/movie/1533784/1533784/648071.mp4', 'http://gstaticontent.com/images/a056a9b046be3ac2a3bc1bc212371cda.jpg', NULL, 0, 0, 'original', NULL),
(1107, 33, 'A Garota da Foto', 'http://sinalprivado.info:80/movie/1533784/1533784/648072.mp4', 'http://gstaticontent.com/images/36a16210db0e467091cf7e623cb3fcf4.jpg', NULL, 0, 0, 'original', NULL),
(1108, 33, 'Belchior - Apenas um Coração Selvagem', 'http://sinalprivado.info:80/movie/1533784/1533784/648073.mp4', 'http://gstaticontent.com/images/e4681216f1049478c3f07e4179f818cb.jpg', NULL, 0, 0, 'original', NULL),
(1109, 33, 'Ao Infinito e Além: Buzz e sua Jornada para ser Lightyear', 'http://sinalprivado.info:80/movie/1533784/1533784/648074.mp4', 'http://gstaticontent.com/images/e2f9a1d7b55b51c523b6e3efee1e2171.jpg', NULL, 0, 0, 'original', NULL),
(1110, 33, 'A Nau dos Loucos: Mergulho e Decolagem de Pazucus', 'http://sinalprivado.info:80/movie/1533784/1533784/648075.mp4', 'http://gstaticontent.com/images/9d39dbb1c5b5d2b4704d20cf77f042ff.jpg', NULL, 0, 0, 'original', NULL),
(1111, 33, 'Felinos da Tailândia', 'http://sinalprivado.info:80/movie/1533784/1533784/648076.mp4', 'http://gstaticontent.com/images/6f022c186c714308d9700aa0e6fe6fc6.jpg', NULL, 0, 0, 'original', NULL),
(1112, 33, 'Andre Matos - Maestro do Rock', 'http://sinalprivado.info:80/movie/1533784/1533784/648077.mp4', 'http://gstaticontent.com/images/1533b11914e35563403307cfffa3b81a.jpg', NULL, 0, 0, 'original', NULL),
(1113, 33, 'A Jangada', 'http://sinalprivado.info:80/movie/1533784/1533784/648078.mp4', 'http://gstaticontent.com/images/1a2746ffacb4485b9294362265f4aaa4.jpg', NULL, 0, 0, 'original', NULL),
(1114, 33, 'Na Teia do Predador', 'http://sinalprivado.info:80/movie/1533784/1533784/648079.mp4', 'http://gstaticontent.com/images/4be38899f4d807d114ade72e0f79e552.jpg', NULL, 0, 0, 'original', NULL),
(1115, 33, 'Enron: Os Mais Espertos da Sala', 'http://sinalprivado.info:80/movie/1533784/1533784/648080.mp4', 'http://gstaticontent.com/images/8c1a3fb3f52dd67643e4d87ae8563e72.jpg', NULL, 0, 0, 'original', NULL),
(1116, 33, 'Sebastiana', 'http://sinalprivado.info:80/movie/1533784/1533784/648081.mp4', 'http://gstaticontent.com/images/205fac23d0fc0796c05c7c47075730b8.jpg', NULL, 0, 0, 'original', NULL),
(1117, 33, 'Jackass 4.5', 'http://sinalprivado.info:80/movie/1533784/1533784/648082.mp4', 'http://gstaticontent.com/images/19da4d68a67ae7910561b362c16d9e82.jpg', NULL, 0, 0, 'original', NULL),
(1118, 33, '8 Presidentes 1 Juramento: A História de um Tempo Presente', 'http://sinalprivado.info:80/movie/1533784/1533784/648083.mp4', 'http://gstaticontent.com/images/12fa723eba3adcd140146c559b8f6c87.jpg', NULL, 0, 0, 'original', NULL),
(1119, 33, 'A Face Oculta do Feminismo', 'http://sinalprivado.info:80/movie/1533784/1533784/648084.mp4', 'http://gstaticontent.com/images/d44f52fc6fbbf834b6ec077e196429b3.jpg', NULL, 0, 0, 'original', NULL),
(1120, 33, 'Air Force One: A Nova Fortaleza Voadora', 'http://sinalprivado.info:80/movie/1533784/1533784/648085.mp4', 'http://gstaticontent.com/images/91093ef01384fd1c797bf0d94cdc85c9.jpg', NULL, 0, 0, 'original', NULL),
(1121, 33, 'O Branco da Raiz', 'http://sinalprivado.info:80/movie/1533784/1533784/648086.mp4', 'http://gstaticontent.com/images/23ad33cc957f081f82210377b57a67ff.jpg', NULL, 0, 0, 'original', NULL),
(1122, 33, 'A Ursa Polar', 'http://sinalprivado.info:80/movie/1533784/1533784/648087.mp4', 'http://gstaticontent.com/images/272d24463cc2a9f8b5996564a377dbc4.jpg', NULL, 0, 0, 'original', NULL),
(1123, 33, 'Abercrombie & Fitch: Ascensão e Queda', 'http://sinalprivado.info:80/movie/1533784/1533784/648088.mp4', 'http://gstaticontent.com/images/8d9eb308cdd590b8c7c3d845171888d5.jpg', NULL, 0, 0, 'original', NULL),
(1124, 33, 'Sérgio Mendes: No Tom da Alegria', 'http://sinalprivado.info:80/movie/1533784/1533784/648089.mp4', 'http://gstaticontent.com/images/5438bf575394cdacde343a5e35b15995.jpg', NULL, 0, 0, 'original', NULL),
(1125, 33, 'Tony Hawk: Até as Rodinhas Caírem', 'http://sinalprivado.info:80/movie/1533784/1533784/648090.mp4', 'http://gstaticontent.com/images/6bfa8bf22aa9aa18a96947050c6e424d.jpg', NULL, 0, 0, 'original', NULL),
(1126, 33, 'Não Confie em Ninguém: A Caça ao Rei da Criptomoeda', 'http://sinalprivado.info:80/movie/1533784/1533784/648091.mp4', 'http://gstaticontent.com/images/69778d59dce1bfd279a24fe1942c5783.jpg', NULL, 0, 0, 'original', NULL),
(1127, 33, 'Vale dos Reis: Os Segredos do Egito', 'http://sinalprivado.info:80/movie/1533784/1533784/648092.mp4', 'http://gstaticontent.com/images/fe7f55f539cb653463f73a708bde6b0a.jpg', NULL, 0, 0, 'original', NULL),
(1128, 33, 'Sobrevivendo ao Paraíso: Contos de Famílias', 'http://sinalprivado.info:80/movie/1533784/1533784/648093.mp4', 'http://gstaticontent.com/images/fd678b6d2c643ef113d7eabd343040dc.jpg', NULL, 0, 0, 'original', NULL),
(1129, 33, 'O Grande Nado', 'http://sinalprivado.info:80/movie/1533784/1533784/648094.mp4', 'http://gstaticontent.com/images/9e2d5e8678ab6574f378c2803fa57917.jpg', NULL, 0, 0, 'original', NULL),
(1130, 33, 'Simples Como a Água', 'http://sinalprivado.info:80/movie/1533784/1533784/648095.mp4', 'http://gstaticontent.com/images/73d9173470331cdede7e6d5613648589.jpg', NULL, 0, 0, 'original', NULL),
(1131, 33, 'Seleção Militar', 'http://sinalprivado.info:80/movie/1533784/1533784/648096.mp4', 'http://gstaticontent.com/images/1c2904534fd529f88226589e391419e7.jpg', NULL, 0, 0, 'original', NULL),
(1132, 33, 'O Golpista do Tinder', 'http://sinalprivado.info:80/movie/1533784/1533784/648097.mp4', 'http://gstaticontent.com/images/8c4d94d0e0b8849b1a3a2515e9fea864.jpg', NULL, 0, 0, 'original', NULL),
(1133, 33, 'O Réu de Si Mesmo', 'http://sinalprivado.info:80/movie/1533784/1533784/648098.mp4', 'http://gstaticontent.com/images/99c445d12a2f8fffa424197af558a2c2.jpg', NULL, 0, 0, 'original', NULL),
(1134, 33, 'Torn', 'http://sinalprivado.info:80/movie/1533784/1533784/648099.mp4', 'http://gstaticontent.com/images/71a0c619e5e89fb06d4a137981513697.jpg', NULL, 0, 0, 'original', NULL),
(1135, 33, 'Ostinato', 'http://sinalprivado.info:80/movie/1533784/1533784/648100.mp4', 'http://gstaticontent.com/images/fb67912f573c2b2fcca35d94212c6c87.jpg', NULL, 0, 0, 'original', NULL),
(1136, 33, 'A Primeira Onda', 'http://sinalprivado.info:80/movie/1533784/1533784/648101.mp4', 'http://gstaticontent.com/images/9259e7e75a6174208a26c274e77f464f.jpg', NULL, 0, 0, 'original', NULL),
(1137, 33, 'Elizabeth II e Margaret: Amor e Lealdade', 'http://sinalprivado.info:80/movie/1533784/1533784/648102.mp4', 'http://gstaticontent.com/images/4770ee12f06340d8199d22ca647298ac.jpg', NULL, 0, 0, 'original', NULL),
(1138, 33, 'Comemoração de 20 anos de Harry Potter: De Volta a Hogwarts', 'http://sinalprivado.info:80/movie/1533784/1533784/648103.mp4', 'http://gstaticontent.com/images/9f8f1ea446fe2de4d71c5a375f705a49.jpg', NULL, 0, 0, 'original', NULL),
(1139, 33, 'Billy Graham: Uma Jornada Extraordinária', 'http://sinalprivado.info:80/movie/1533784/1533784/648104.mp4', 'http://gstaticontent.com/images/4222ec7bfe627c1bf0bfd6f52df7a3a8.jpg', NULL, 0, 0, 'original', NULL),
(1140, 33, 'Os Beatles e a Índia', 'http://sinalprivado.info:80/movie/1533784/1533784/648105.mp4', 'http://gstaticontent.com/images/24ddd8e5df89376b914dedaf86d97687.jpg', NULL, 0, 0, 'original', NULL),
(1141, 33, 'Mostra-Me O Pai', 'http://sinalprivado.info:80/movie/1533784/1533784/648106.mp4', 'http://gstaticontent.com/images/9b9d4b62e6feb6c9ba8004486f151738.jpg', NULL, 0, 0, 'original', NULL),
(1142, 33, 'Prisioneiro Para Sempre', 'http://sinalprivado.info:80/movie/1533784/1533784/648107.mp4', 'http://gstaticontent.com/images/f651986900e7d88502c05907c290958a.jpg', NULL, 0, 0, 'original', NULL),
(1143, 33, 'Bezos e Branson', 'http://sinalprivado.info:80/movie/1533784/1533784/648108.mp4', 'http://gstaticontent.com/images/8cc425b06dfc61ac237f6a45f13406f6.jpg', NULL, 0, 0, 'original', NULL),
(1144, 33, 'Lady Gucci: A História de Patrizia Reggiani', 'http://sinalprivado.info:80/movie/1533784/1533784/648109.mp4', 'http://gstaticontent.com/images/df8496ed14593def5e54961010a431b9.jpg', NULL, 0, 0, 'original', NULL),
(1145, 33, 'Retrospectiva SBT (2021)', 'http://sinalprivado.info:80/movie/1533784/1533784/648110.mp4', 'http://gstaticontent.com/images/03669c6cdddf46a0966e5eacc38eeeb4.png', NULL, 0, 0, 'original', NULL),
(1146, 33, 'Retrospectiva Record (2021)', 'http://sinalprivado.info:80/movie/1533784/1533784/648111.mp4', 'http://gstaticontent.com/images/f58426588ef4e0940af71aeef5b9f584.png', NULL, 0, 0, 'original', NULL),
(1147, 33, '137 Disparos', 'http://sinalprivado.info:80/movie/1533784/1533784/648112.mp4', 'http://gstaticontent.com/images/9ee9b2eb1106ce6af843511922bc4575.jpg', NULL, 0, 0, 'original', NULL),
(1148, 33, 'Insecure: O Fim', 'http://sinalprivado.info:80/movie/1533784/1533784/648113.mp4', 'http://gstaticontent.com/images/6857f026f12385ce0cdffb2aa99d0780.jpg', NULL, 0, 0, 'original', NULL),
(1149, 33, 'Retrospectiva Rede Globo (2021)', 'http://sinalprivado.info:80/movie/1533784/1533784/648114.mp4', 'http://gstaticontent.com/images/817e3298b4bdc19440924c628cea9ec2.jpg', NULL, 0, 0, 'original', NULL),
(1150, 33, '70 Anos Esta Noite', 'http://sinalprivado.info:80/movie/1533784/1533784/648115.mp4', 'http://gstaticontent.com/images/71b1efa048150a8dcfb5b8cd84bc3ef4.jpg', NULL, 0, 0, 'original', NULL),
(1151, 33, 'Gênesis In Concert', 'http://sinalprivado.info:80/movie/1533784/1533784/648116.mp4', 'http://gstaticontent.com/images/8120e8bb46b61639de8dfeeb3defdda1.png', NULL, 0, 0, 'original', NULL),
(1152, 33, 'Retrospectiva Band (2021)', 'http://sinalprivado.info:80/movie/1533784/1533784/648117.mp4', 'http://gstaticontent.com/images/9b551cac1dcc7ea70bdcb15f5a5812a7.png', NULL, 0, 0, 'original', NULL),
(1153, 33, 'Especial Roberto Carlos Reencontro', 'http://sinalprivado.info:80/movie/1533784/1533784/648118.mp4', 'http://gstaticontent.com/images/fa40db79deb7b114f73879fd4c763e3a.jpg', NULL, 0, 0, 'original', NULL),
(1154, 33, 'The Slow Hustle: Corrupção e Morte na Polícia de Baltimore', 'http://sinalprivado.info:80/movie/1533784/1533784/648119.mp4', 'http://gstaticontent.com/images/3a442b80102af7bcd0a7228451cee3ab.jpg', NULL, 0, 0, 'original', NULL),
(1155, 33, 'Carlos Ghosn - The Last Flight', 'http://sinalprivado.info:80/movie/1533784/1533784/648120.mp4', 'http://gstaticontent.com/images/2fce10398014dca2211350326df3fd43.jpg', NULL, 0, 0, 'original', NULL),
(1156, 33, 'Dentro de Casa: O Dilema do Contra-Terrorismo', 'http://sinalprivado.info:80/movie/1533784/1533784/648121.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bQjPreMNttvKyJZAol95TE12oMQ.jpg', NULL, 0, 0, 'original', NULL),
(1157, 33, 'Arte Negra - Na Ausência da Luz', 'http://sinalprivado.info:80/movie/1533784/1533784/648122.mp4', 'http://gstaticontent.com/images/43f9f77941c5dcffd353349df0e1e53f.jpg', NULL, 0, 0, 'original', NULL),
(1158, 33, '8 Mil Metros e 7 Meses', 'http://sinalprivado.info:80/movie/1533784/1533784/648123.mp4', 'http://gstaticontent.com/images/698fd16e61a74f4d47fca9c3e7597abe.jpg', NULL, 0, 0, 'original', NULL),
(1159, 33, 'Becoming Cousteau', 'http://sinalprivado.info:80/movie/1533784/1533784/648124.mp4', 'http://gstaticontent.com/images/39a925bf9883b321b28c075dac0c80a4.jpg', NULL, 0, 0, 'original', NULL),
(1160, 33, 'No Caminho da Cura', 'http://sinalprivado.info:80/movie/1533784/1533784/648125.mp4', 'http://gstaticontent.com/images/fcaadc4b6f58ab4c9e7db7066942ab22.jpg', NULL, 0, 0, 'original', NULL),
(1161, 33, 'Mamãe Morta e Querida', 'http://sinalprivado.info:80/movie/1533784/1533784/648126.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6e2VqtP7XtJQ0QCc7NLrtTUaIN2.jpg', NULL, 0, 0, 'original', NULL),
(1162, 33, 'A Cancao de Xiara', 'http://sinalprivado.info:80/movie/1533784/1533784/648127.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qN1roVNOsSJUuSe6JqUpkGxrZve.jpg', NULL, 0, 0, 'original', NULL),
(1163, 33, 'Have You Seen Andy?', 'http://sinalprivado.info:80/movie/1533784/1533784/648128.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ApbBnHMAW8dJuKons40Q8XkfwBN.jpg', NULL, 0, 0, 'original', NULL),
(1164, 33, 'Francesco', 'http://sinalprivado.info:80/movie/1533784/1533784/648129.mp4', 'http://gstaticontent.com/images/221189e270c82af310bf8c03030f38ea.jpg', NULL, 0, 0, 'original', NULL),
(1165, 33, 'O Último Cruzeiro', 'http://sinalprivado.info:80/movie/1533784/1533784/648130.mp4', 'http://gstaticontent.com/images/47bf7a75c290e6f62a47c86e36c6cfe2.jpg', NULL, 0, 0, 'original', NULL),
(1166, 33, 'A Lenda do Submundo', 'http://sinalprivado.info:80/movie/1533784/1533784/648131.mp4', 'http://gstaticontent.com/images/ada39c0e6ad3910ec874c570f35aae81.jpg', NULL, 0, 0, 'original', NULL),
(1167, 33, 'Assassinas', 'http://sinalprivado.info:80/movie/1533784/1533784/648132.mp4', 'http://gstaticontent.com/images/060f8a05a3b54fe72f6f8bae886c2e9b.jpg', NULL, 0, 0, 'original', NULL),
(1168, 33, 'A Conspiração Antivacina', 'http://sinalprivado.info:80/movie/1533784/1533784/648133.mp4', 'http://gstaticontent.com/images/a9427b9d7d01d28252797355fa050403.jpg', NULL, 0, 0, 'original', NULL),
(1169, 33, 'O Dia em que o Esporte Parou', 'http://sinalprivado.info:80/movie/1533784/1533784/648134.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xy0FIKNzPCEB5vu33MTWW44XWFW.jpg', NULL, 0, 0, 'original', NULL),
(1170, 33, 'Americanos na Cama', 'http://sinalprivado.info:80/movie/1533784/1533784/648135.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k2Wkb4E1JUdWgCAGZ2tQkXqICpq.jpg', NULL, 0, 0, 'original', NULL),
(1171, 33, 'A Heroína em Cape Cod', 'http://sinalprivado.info:80/movie/1533784/1533784/648136.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ozpUSU6ee7nmryiTWGMiK1hx8wy.jpg', NULL, 0, 0, 'original', NULL),
(1172, 33, 'Alcorão de Cor', 'http://sinalprivado.info:80/movie/1533784/1533784/648137.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n81MMUHdxYy8nNzlJZgCNNXUprH.jpg', NULL, 0, 0, 'original', NULL),
(1173, 33, 'Tony Robbins: I Am Not Your Guru', 'http://sinalprivado.info:80/movie/1533784/1533784/648138.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wmDvMAjePKhcxAfbNvVUDqld779.jpg', NULL, 0, 0, 'original', NULL),
(1174, 33, 'The Velvet Underground', 'http://sinalprivado.info:80/movie/1533784/1533784/648139.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9uRF6vERWfhlSZKc1sAJTTdG2Ix.jpg', NULL, 0, 0, 'original', NULL),
(1175, 33, 'Fake Famous: Uma Experiência Surreal nas Redes', 'http://sinalprivado.info:80/movie/1533784/1533784/648140.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uAXVDwLbrzzqaX8hHSRoCwBVkWz.jpg', NULL, 0, 0, 'original', NULL),
(1176, 33, 'Aborto: Histórias Contadas por Mulheres', 'http://sinalprivado.info:80/movie/1533784/1533784/648141.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aMITbqqE9DmRriPpcE2UuZtTrv4.jpg', NULL, 0, 0, 'original', NULL),
(1177, 33, 'Divisão de Classes', 'http://sinalprivado.info:80/movie/1533784/1533784/648142.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uAvtsFNCIf8rl3BMPQXjTjyTVfA.jpg', NULL, 0, 0, 'original', NULL),
(1178, 33, 'Convergência: Coragem em Tempos de Crise', 'http://sinalprivado.info:80/movie/1533784/1533784/648143.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j76kEZClLY7mFpS619zV6a0gGHN.jpg', NULL, 0, 0, 'original', NULL),
(1179, 33, 'Justiça', 'http://sinalprivado.info:80/movie/1533784/1533784/648144.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mSx0KORbnavSku7dHyhNmEBfcIT.jpg', NULL, 0, 0, 'original', NULL),
(1180, 33, 'Vinicius', 'http://sinalprivado.info:80/movie/1533784/1533784/648145.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tVmlwnKFJ9htheUtIOwMha9fH9X.jpg', NULL, 0, 0, 'original', NULL),
(1181, 33, 'Shiny_Flakes: Drogas Online', 'http://sinalprivado.info:80/movie/1533784/1533784/648146.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A90byJpjV0DvuozHQAxE5lZgd8D.jpg', NULL, 0, 0, 'original', NULL),
(1182, 33, 'Preto Fica', 'http://sinalprivado.info:80/movie/1533784/1533784/648147.mp4', 'http://gstaticontent.com/images/82b908bd6ddc21654250c307a0cfc980.jpg', NULL, 0, 0, 'original', NULL),
(1183, 33, 'Meus Heróis Eram Cowboys', 'http://sinalprivado.info:80/movie/1533784/1533784/648148.mp4', 'http://gstaticontent.com/images/2d736aef58ab9983fad56d6364896580.jpg', NULL, 0, 0, 'original', NULL),
(1184, 33, 'Schumacher', 'http://sinalprivado.info:80/movie/1533784/1533784/648149.mp4', 'http://gstaticontent.com/images/4e83194aad8ed53ed3d7a19c079fc570.jpg', NULL, 0, 0, 'original', NULL),
(1185, 33, 'Os Quatro Paralamas', 'http://sinalprivado.info:80/movie/1533784/1533784/648150.mp4', 'http://gstaticontent.com/images/bfd1ab0824a31fe9611cb623e23fe7fc.jpg', NULL, 0, 0, 'original', NULL),
(1186, 33, 'NARUTO to BORUTO The Live 2019', 'http://sinalprivado.info:80/movie/1533784/1533784/648151.mp4', 'http://gstaticontent.com/images/601ae534dac7054c4804cf080c882f12.jpg', NULL, 0, 0, 'original', NULL),
(1187, 33, 'Irmãos de Sangue: Muhammad Ali e Malcolm X', 'http://sinalprivado.info:80/movie/1533784/1533784/648152.mp4', 'http://gstaticontent.com/images/3a320f975f188aad6af6b45b01e114e3.jpg', NULL, 0, 0, 'original', NULL),
(1188, 33, 'Sepultura - O Filme', 'http://sinalprivado.info:80/movie/1533784/1533784/648153.mp4', 'http://gstaticontent.com/images/19a444ddb0b544cb3301e84e85e015f0.jpg', NULL, 0, 0, 'original', NULL),
(1189, 33, '11/9: A Vida Sob Ataque', 'http://sinalprivado.info:80/movie/1533784/1533784/648154.mp4', 'http://gstaticontent.com/images/c0c46f9e4391ec8cc6d5ecbc5ea60ea1.jpg', NULL, 0, 0, 'original', NULL),
(1190, 33, 'Difícil Decisão', 'http://sinalprivado.info:80/movie/1533784/1533784/648155.mp4', 'http://gstaticontent.com/images/a0bcaa8eab4176a4326e79d885b66066.jpg', NULL, 0, 0, 'original', NULL),
(1191, 33, 'Elas Contra o Serial Killer', 'http://sinalprivado.info:80/movie/1533784/1533784/648156.mp4', 'http://gstaticontent.com/images/bea3664212eeaf9ef084e4a41a5f09ec.jpg', NULL, 0, 0, 'original', NULL),
(1192, 33, 'Bob Ross Alegria Traição e Ganância', 'http://sinalprivado.info:80/movie/1533784/1533784/648157.mp4', 'http://gstaticontent.com/images/c71efd51840877a73cdcfa84ba0fb979.jpg', NULL, 0, 0, 'original', NULL),
(1193, 33, 'Especial: 40 Anos do SBT', 'http://sinalprivado.info:80/movie/1533784/1533784/648158.mp4', 'http://gstaticontent.com/images/ce0ce04b18969b9b7047590048ad6c04.jpg', NULL, 0, 0, 'original', NULL),
(1194, 33, 'Bob Ross Alegria Traição e Ganância', 'http://sinalprivado.info:80/movie/1533784/1533784/648159.mp4', 'http://gstaticontent.com/images/c71efd51840877a73cdcfa84ba0fb979.jpg', NULL, 0, 0, 'original', NULL),
(1195, 33, 'Arquivos de um Serial Killer', 'http://sinalprivado.info:80/movie/1533784/1533784/648160.mp4', 'http://gstaticontent.com/images/b6e75ef42a92890ec87de746e7d394e7.jpg', NULL, 0, 0, 'original', NULL),
(1196, 33, 'Meu Nome é Greta', 'http://sinalprivado.info:80/movie/1533784/1533784/648161.mp4', 'http://gstaticontent.com/images/9b1ec0591663c5414dbbda8a9c821030.jpg', NULL, 0, 0, 'original', NULL),
(1197, 33, 'Pray Away', 'http://sinalprivado.info:80/movie/1533784/1533784/648162.mp4', 'http://gstaticontent.com/images/22c8fe549a1fbabd73c8c3b9b03e35ea.jpg', NULL, 0, 0, 'original', NULL),
(1198, 33, 'Ela Luta Sumô', 'http://sinalprivado.info:80/movie/1533784/1533784/648163.mp4', 'http://gstaticontent.com/images/cfa220ca960b18453722a004515703b9.jpg', NULL, 0, 0, 'original', NULL),
(1199, 33, 'A Guerra dos Consoles', 'http://sinalprivado.info:80/movie/1533784/1533784/648164.mp4', 'http://gstaticontent.com/images/613374ed92ed1997b9ee95c75419d591.jpg', NULL, 0, 0, 'original', NULL),
(1200, 33, 'Brincando com Tubarões', 'http://sinalprivado.info:80/movie/1533784/1533784/648165.mp4', 'http://gstaticontent.com/images/7585a7376bf838c414186a992163a9d6.jpg', NULL, 0, 0, 'original', NULL),
(1201, 33, 'O Pântano', 'http://sinalprivado.info:80/movie/1533784/1533784/648166.mp4', 'http://gstaticontent.com/images/f0c654f20cbfe9765c56694afc95c443.jpg', NULL, 0, 0, 'original', NULL),
(1202, 33, 'Dublê de Risco', 'http://sinalprivado.info:80/movie/1533784/1533784/648167.mp4', 'http://gstaticontent.com/images/fbc4f7ae02eed669c427d12f526e934b.jpg', NULL, 0, 0, 'original', NULL),
(1203, 33, 'Quando a Revolução Não Pode Ser Televisionada)', 'http://sinalprivado.info:80/movie/1533784/1533784/648168.mp4', 'http://gstaticontent.com/images/90adb13ab0c9dbf93987862e54a18208.jpg', NULL, 0, 0, 'original', NULL),
(1204, 33, 'A Senhora que Morreu no Trailer', 'http://sinalprivado.info:80/movie/1533784/1533784/648169.mp4', 'http://gstaticontent.com/images/b27a44b5eba942515b0c22c09dd8ff73.jpg', NULL, 0, 0, 'original', NULL),
(1205, 33, 'O Ataque A Newburgh', 'http://sinalprivado.info:80/movie/1533784/1533784/648170.mp4', 'http://gstaticontent.com/images/b5cf8b3c8b42f053b3c448f1d5be8d03.jpg', NULL, 0, 0, 'original', NULL),
(1206, 33, 'Irmãs Sheppard: Das Ruas ao Pódio', 'http://sinalprivado.info:80/movie/1533784/1533784/648171.mp4', 'http://gstaticontent.com/images/696a2293076bafb32844b090a0808b05.jpg', NULL, 0, 0, 'original', NULL),
(1207, 33, 'Friends: A Reunião', 'http://sinalprivado.info:80/movie/1533784/1533784/648172.mp4', 'http://gstaticontent.com/images/fcf29037e1d9ac556fb2fb0df2c02c63.jpg', NULL, 0, 0, 'original', NULL),
(1208, 33, 'Ronaldo', 'http://sinalprivado.info:80/movie/1533784/1533784/648173.mp4', 'http://gstaticontent.com/images/qdr6Jx39KErvSeQFVREjxeEK4lk_big.jpg', NULL, 0, 0, 'original', NULL),
(1209, 33, 'Soldados do Araguaia', 'http://sinalprivado.info:80/movie/1533784/1533784/648174.mp4', 'http://gstaticontent.com/images/ap8kC7g8qsO3PIaITmJu9squMvD_big.jpg', NULL, 0, 0, 'original', NULL),
(1210, 33, 'Ártico Ameaçado', 'http://sinalprivado.info:80/movie/1533784/1533784/648175.mp4', 'http://gstaticontent.com/images/5fa713a0f5f4245064383e29b2efa7ad.jpg', NULL, 0, 0, 'original', NULL),
(1211, 33, 'Uma Gota de Esperança', 'http://sinalprivado.info:80/movie/1533784/1533784/648176.mp4', 'http://gstaticontent.com/images/3b498dc984c39887b6e74c7f20473096.jpg', NULL, 0, 0, 'original', NULL),
(1212, 33, 'Cabra Marcado Para Morrer', 'http://sinalprivado.info:80/movie/1533784/1533784/648177.mp4', 'http://gstaticontent.com/images/fdll4h8DHM4W1AXDh44WlfvY1rC_big.jpg', NULL, 0, 0, 'original', NULL),
(1213, 33, 'Por Que Você Me Matou?', 'http://sinalprivado.info:80/movie/1533784/1533784/648178.mp4', 'http://gstaticontent.com/images/cae2115b73eafb8e530c6e4b2bfb1ea9.jpg', NULL, 0, 0, 'original', NULL),
(1214, 33, 'Chorao Marginal Alado', 'http://sinalprivado.info:80/movie/1533784/1533784/648179.mp4', 'http://gstaticontent.com/images/37533088df6899056c6e9964fcdc04e8.jpg', NULL, 0, 0, 'original', NULL),
(1215, 33, 'Legado Italiano', 'http://sinalprivado.info:80/movie/1533784/1533784/648180.mp4', 'http://gstaticontent.com/images/c75456aceab867aa459915b8937c99bc.jpg', NULL, 0, 0, 'original', NULL),
(1216, 33, 'Alex Camera 10', 'http://sinalprivado.info:80/movie/1533784/1533784/648181.mp4', 'http://gstaticontent.com/images/eGv4q0BG8lTFJFSeyfBAZjM4sK8_big.jpg', NULL, 0, 0, 'original', NULL),
(1217, 33, 'Memorias Secretas', 'http://sinalprivado.info:80/movie/1533784/1533784/648182.mp4', 'http://gstaticontent.com/images/aAf4Pg4BuN0r4FHQ0N8eXorn3AY_big.jpg', NULL, 0, 0, 'original', NULL),
(1218, 33, 'Pelé', 'http://sinalprivado.info:80/movie/1533784/1533784/648183.mp4', 'http://gstaticontent.com/images/ffdf0cb0a0f6abbcef2626d2fc64d978.jpg', NULL, 0, 0, 'original', NULL),
(1219, 33, 'Pole Dance: Dança do Poder', 'http://sinalprivado.info:80/movie/1533784/1533784/648184.mp4', 'http://gstaticontent.com/images/2fd70747c7f61a57cd786cbacd1e18cc.jpg', NULL, 0, 0, 'original', NULL),
(1220, 33, 'A Nossa Bandeira Jamais Será Vermelha', 'http://sinalprivado.info:80/movie/1533784/1533784/648185.mp4', 'http://gstaticontent.com/images/a1d280dea730719deed8e89ce0316ab4.jpg', NULL, 0, 0, 'original', NULL),
(1221, 33, 'Marighella', 'http://sinalprivado.info:80/movie/1533784/1533784/648186.mp4', 'http://gstaticontent.com/images/cT1LDiWCt7ijRHZwUMyGXrCs6q7_big.jpg', NULL, 0, 0, 'original', NULL),
(1222, 33, 'Grand Canyon ao Extremo', 'http://sinalprivado.info:80/movie/1533784/1533784/648187.mp4', 'http://gstaticontent.com/images/4abc7d07820f5908a7b1154761f70281.jpg', NULL, 0, 0, 'original', NULL),
(1223, 33, 'Crack Cocaina Corrupcao e Conspiracao', 'http://sinalprivado.info:80/movie/1533784/1533784/648188.mp4', 'http://gstaticontent.com/images/a60901a2911419e57fa5e4dba5be26c1.jpg', NULL, 0, 0, 'original', NULL),
(1224, 33, 'BISDocs Princesas do Funk', 'http://sinalprivado.info:80/movie/1533784/1533784/648189.mp4', 'http://gstaticontent.com/images/45c86a4f986f9304db06e65b505451a3.jpg', NULL, 0, 0, 'original', NULL),
(1225, 33, 'Tony Parker Entre Os Maiores', 'http://sinalprivado.info:80/movie/1533784/1533784/648190.mp4', 'http://gstaticontent.com/images/c75d275178f44d604dd34136b80010dd.jpg', NULL, 0, 0, 'original', NULL),
(1226, 33, 'Minimalismo Já', 'http://sinalprivado.info:80/movie/1533784/1533784/648191.mp4', 'http://gstaticontent.com/images/36f9d471c5020f89e295f882d5e36e2a.jpg', NULL, 0, 0, 'original', NULL),
(1227, 33, 'A Trajetoria De Pablo Escobar', 'http://sinalprivado.info:80/movie/1533784/1533784/648192.mp4', 'http://gstaticontent.com/images/2ef1408b8a6c455ad71efa9438525196.jpg', NULL, 0, 0, 'original', NULL),
(1228, 33, 'Babenco - Alguém Tem que Ouvir o Coração e Dizer: Parou', 'http://sinalprivado.info:80/movie/1533784/1533784/648193.mp4', 'http://gstaticontent.com/images/fdb563643c779584d6e12413f63034bb.jpg', NULL, 0, 0, 'original', NULL),
(1229, 33, 'Vozes Que Inspiram', 'http://sinalprivado.info:80/movie/1533784/1533784/648194.mp4', 'http://gstaticontent.com/images/5e1b993b2f7d045d796bc222bb6e990f.jpg', NULL, 0, 0, 'original', NULL),
(1230, 33, 'Emicida Amarelo E Tudo Pra Ontem', 'http://sinalprivado.info:80/movie/1533784/1533784/648195.mp4', 'http://gstaticontent.com/images/74555011648fdf2921e83664e4d377c7.jpg', NULL, 0, 0, 'original', NULL),
(1231, 33, 'Stalking Chernobyl Exploracao Apos o Apocalypse', 'http://sinalprivado.info:80/movie/1533784/1533784/648196.mp4', 'http://gstaticontent.com/images/At68XeIDZOfn1yRKyVgPMjSz64r_big.jpg', NULL, 0, 0, 'original', NULL),
(1232, 33, 'Mosul', 'http://sinalprivado.info:80/movie/1533784/1533784/648197.mp4', 'http://gstaticontent.com/images/2vjephttoBH1ujOZcsqWlftLbhg_big.jpg', NULL, 0, 0, 'original', NULL),
(1233, 33, 'Projeto Mercury Os Sete Escolhidos', 'http://sinalprivado.info:80/movie/1533784/1533784/648198.mp4', 'http://gstaticontent.com/images/sC3gj5GrU4wtkZt5BQTftnnqaNa_big.jpg', NULL, 0, 0, 'original', NULL),
(1234, 33, 'Despertar - Data Limite', 'http://sinalprivado.info:80/movie/1533784/1533784/648199.mp4', 'http://gstaticontent.com/images/ha6r0JOUQlspTbPF4CJyJoWo8G9_big.jpg', NULL, 0, 0, 'original', NULL),
(1235, 33, 'Pátria', 'http://sinalprivado.info:80/movie/1533784/1533784/648200.mp4', 'http://gstaticontent.com/images/ulUEelaJcab8uNZGyytFSuumXB9_big.jpg', NULL, 0, 0, 'original', NULL),
(1236, 33, 'Como Você Me Vê?', 'http://sinalprivado.info:80/movie/1533784/1533784/648201.mp4', 'http://gstaticontent.com/images/vAHjv4PRfCTxk3LKkZkBaoNyn5q_big.jpg', NULL, 0, 0, 'original', NULL),
(1237, 33, 'As Mortes de Dick Johnson', 'http://sinalprivado.info:80/movie/1533784/1533784/648202.mp4', 'http://gstaticontent.com/images/vnfI34kmi3fcdgP7HZjIgGOJHGY_big.jpg', NULL, 0, 0, 'original', NULL),
(1238, 33, 'Uma Canção para Latasha', 'http://sinalprivado.info:80/movie/1533784/1533784/648203.mp4', 'http://gstaticontent.com/images/14iHzYmdS9hfAnwwwQfvGhewy7r_big.jpg', NULL, 0, 0, 'original', NULL),
(1239, 33, 'Sete Anos em Maio', 'http://sinalprivado.info:80/movie/1533784/1533784/648204.mp4', 'http://gstaticontent.com/images/qMo8I1knXmhkKf0xINTAYJqBdaf_big.jpg', NULL, 0, 0, 'original', NULL),
(1240, 33, 'GIMS: Ícone do Rap', 'http://sinalprivado.info:80/movie/1533784/1533784/648205.mp4', 'http://gstaticontent.com/images/qDTIyjUIufAZZ3jMmHOfC1AkoYU_big.jpg', NULL, 0, 0, 'original', NULL),
(1241, 33, 'Contornando a Morte', 'http://sinalprivado.info:80/movie/1533784/1533784/648206.mp4', 'http://gstaticontent.com/images/1sCawwtBif3Ggt6sr4DXG7SYf8d_big.jpg', NULL, 0, 0, 'original', NULL),
(1242, 33, 'O Dilema das Redes', 'http://sinalprivado.info:80/movie/1533784/1533784/648207.mp4', 'http://gstaticontent.com/images/4ca2o7afA65YGoc9hsmwobIivsQ_big.jpg', NULL, 0, 0, 'original', NULL),
(1243, 33, 'Narciso Em Férias', 'http://sinalprivado.info:80/movie/1533784/1533784/648208.mp4', 'http://gstaticontent.com/images/108ynF1kuaKJSXrv1ni9WvQUeJg_big.jpg', NULL, 0, 0, 'original', NULL),
(1244, 33, 'Dentro Da Minha Pele', 'http://sinalprivado.info:80/movie/1533784/1533784/648209.mp4', 'http://gstaticontent.com/images/5ZOmLiti7rfjsQRDucZal7flgCa_big.jpg', NULL, 0, 0, 'original', NULL),
(1245, 33, 'Quentin Tarantino Os Oito Primeiros', 'http://sinalprivado.info:80/movie/1533784/1533784/648210.mp4', 'http://gstaticontent.com/images/rGPwMYUeygsUAmo0NS8IPlhQEfH_big.jpg', NULL, 0, 0, 'original', NULL),
(1246, 33, 'Anelka - O incompreendido', 'http://sinalprivado.info:80/movie/1533784/1533784/648211.mp4', 'http://gstaticontent.com/images/q6mk7JtdWu2cUZV7vk6VN7cJNen_big.jpg', NULL, 0, 0, 'original', NULL),
(1247, 33, 'Magos do Cubo', 'http://sinalprivado.info:80/movie/1533784/1533784/648212.mp4', 'http://gstaticontent.com/images/6smiZ4d4q8QdYdNKn0Qmr7OsGbD_big.jpg', NULL, 0, 0, 'original', NULL),
(1248, 33, 'Nostalgia Ciência: Onde Estão Todos os Alienígenas?', 'http://sinalprivado.info:80/movie/1533784/1533784/648213.mp4', 'http://gstaticontent.com/images/mcpVhPdvRMqTzXC0w6DOCoGR72g_big.jpg', NULL, 0, 0, 'original', NULL),
(1249, 33, 'Winter on Fire: Ukraine\'s Fight for Freedom', 'http://sinalprivado.info:80/movie/1533784/1533784/648214.mp4', 'http://gstaticontent.com/images/50ygDdzH1sK8b92FCurOexzJQOf_big.jpg', NULL, 0, 0, 'original', NULL),
(1250, 33, 'Ligue Djá: O Lendário Walter Mercado', 'http://sinalprivado.info:80/movie/1533784/1533784/648215.mp4', 'http://gstaticontent.com/images/mBqSHu6jkWHbyNFmIvc2rmKQspN_big.jpg', NULL, 0, 0, 'original', NULL),
(1251, 33, '7 Denúncias: As Consequências do Caso COVID-19', 'http://sinalprivado.info:80/movie/1533784/1533784/648216.mp4', 'http://gstaticontent.com/images/h8TMe2p5ENCuIb0tJRb21NRqiHU_big.jpg', NULL, 0, 0, 'original', NULL),
(1252, 33, 'Olhar Instigado', 'http://sinalprivado.info:80/movie/1533784/1533784/648217.mp4', 'http://gstaticontent.com/images/bgNnCZj6TdujoYPjufLus2dHFkh_big.jpg', NULL, 0, 0, 'original', NULL),
(1253, 33, 'Coronavírus: A origem', 'http://sinalprivado.info:80/movie/1533784/1533784/648218.mp4', 'http://gstaticontent.com/images/llRfKnAIvrIOMeeuiz55Dz0P3ij_big.jpg', NULL, 0, 0, 'original', NULL),
(1254, 33, 'Toda Palavra Conta', 'http://sinalprivado.info:80/movie/1533784/1533784/648219.mp4', 'http://gstaticontent.com/images/2TEsgfYtwvcMgHHkHhmdBT4UJ0u_big.jpg', NULL, 0, 0, 'original', NULL),
(1255, 33, 'Maior Viagem: Uma Aventura Psicodélica', 'http://sinalprivado.info:80/movie/1533784/1533784/648220.mp4', 'http://gstaticontent.com/images/hUEdgqgl7OSL3hoCOes7lTQGzTM_big.jpg', NULL, 0, 0, 'original', NULL),
(1256, 33, 'Coreia do Norte: Segredos Obscuros', 'http://sinalprivado.info:80/movie/1533784/1533784/648221.mp4', 'http://gstaticontent.com/images/b94qGU8uMcRI4hQYcCnSHoZkR0v_big.jpg', NULL, 0, 0, 'original', NULL),
(1257, 33, 'Atras da Estante', 'http://sinalprivado.info:80/movie/1533784/1533784/648222.mp4', 'http://gstaticontent.com/images/y19U39IccjFpn70UmYIET9B3dBV_big.jpg', NULL, 0, 0, 'original', NULL),
(1258, 33, 'Viveiro', 'http://sinalprivado.info:80/movie/1533784/1533784/648223.mp4', 'http://gstaticontent.com/images/iMh6JXkXMhr5UDu4swFNaRA4Sqx_big.jpg', NULL, 0, 0, 'original', NULL),
(1259, 33, 'Nos Bastidores de Elefante', 'http://sinalprivado.info:80/movie/1533784/1533784/648224.mp4', 'http://gstaticontent.com/images/A5MNeo1jsBUFyPo890tWILvKuzS_big.jpg', NULL, 0, 0, 'original', NULL),
(1260, 33, 'Elefante', 'http://sinalprivado.info:80/movie/1533784/1533784/648225.mp4', 'http://gstaticontent.com/images/32jFoyxJSZ3cN2SHjqwFDQMdTJ8_big.jpg', NULL, 0, 0, 'original', NULL),
(1261, 33, 'Pinguins: Vida ao Extremo', 'http://sinalprivado.info:80/movie/1533784/1533784/648226.mp4', 'http://gstaticontent.com/images/gliWtVkDZ3PrVAzbd4cqNv0SWEn_big.jpg', NULL, 0, 0, 'original', NULL),
(1262, 33, 'Torturado por Cristo', 'http://sinalprivado.info:80/movie/1533784/1533784/648227.mp4', 'http://gstaticontent.com/images/5ViMmECe04QwF6Sj4XGh6XDrsDQ_big.jpg', NULL, 0, 0, 'original', NULL),
(1263, 33, 'La casa de papel: El fenómeno', 'http://sinalprivado.info:80/movie/1533784/1533784/648228.mp4', 'http://gstaticontent.com/images/AboUXTrDWEi0PuZUqaft0iwBTm7_big.jpg', NULL, 0, 0, 'original', NULL),
(1264, 33, 'Eldorado - Mengele Vivo ou Morto?', 'http://sinalprivado.info:80/movie/1533784/1533784/648229.mp4', 'http://gstaticontent.com/images/6u9zp0AO1LbXx8CDPl0wXkbLY9e_big.jpg', NULL, 0, 0, 'original', NULL),
(1265, 33, 'Crip Camp: Revolução pela Inclusão', 'http://sinalprivado.info:80/movie/1533784/1533784/648230.mp4', 'http://gstaticontent.com/images/hBCoAbuFGiQeNQXU0QNjtR0RKzW_big.jpg', NULL, 0, 0, 'original', NULL),
(1266, 33, 'Resiliência', 'http://sinalprivado.info:80/movie/1533784/1533784/648231.mp4', 'http://gstaticontent.com/images/_big.jpg', NULL, 0, 0, 'original', NULL),
(1267, 33, 'A Cabana e Seus Segredos', 'http://sinalprivado.info:80/movie/1533784/1533784/648232.mp4', 'http://gstaticontent.com/images/6Wmrid7234ui9pBB8dZ0luOyIJv_big.jpg', NULL, 0, 0, 'original', NULL),
(1268, 33, 'Estrada de Sonhos', 'http://sinalprivado.info:80/movie/1533784/1533784/648233.mp4', 'http://gstaticontent.com/images/12YpKqcJgeQGttX4D9P9L3p9S7E_big.jpg', NULL, 0, 0, 'original', NULL),
(1269, 33, 'Gabriel Medina', 'http://sinalprivado.info:80/movie/1533784/1533784/648234.mp4', 'http://gstaticontent.com/images/3GyadvHTeIbovM249Gvtewxwngd_big.jpg', NULL, 0, 0, 'original', NULL),
(1270, 33, 'O Corpo é Nosso!', 'http://sinalprivado.info:80/movie/1533784/1533784/648235.mp4', 'http://gstaticontent.com/images/l37kX8yPq0RyGlxSj5dCCGHfX4s_big.jpg', NULL, 0, 0, 'original', NULL),
(1271, 33, 'Meu Tricolor de Aço', 'http://sinalprivado.info:80/movie/1533784/1533784/648236.mp4', 'http://gstaticontent.com/images/qlAGF4AyDmMR0otbMl2BhwFM0ZV_big.jpg', NULL, 0, 0, 'original', NULL),
(1272, 33, 'Apollo 11', 'http://sinalprivado.info:80/movie/1533784/1533784/648237.mp4', 'http://gstaticontent.com/images/woLMRroHyoTGoXyxdEeBJEYBFtu_big.jpg', NULL, 0, 0, 'original', NULL),
(1273, 33, 'Ursos Polares', 'http://sinalprivado.info:80/movie/1533784/1533784/648238.mp4', 'http://gstaticontent.com/images/37ZjYyJuTVy1aS268KUTeTFASKP_big.jpg', NULL, 0, 0, 'original', NULL),
(1274, 33, 'The Elephant Queen', 'http://sinalprivado.info:80/movie/1533784/1533784/648239.mp4', 'http://gstaticontent.com/images/cX3fl80NMXILgmsy0blU9ir6sy1_big.jpg', NULL, 0, 0, 'original', NULL),
(1275, 33, 'Refavela 40', 'http://sinalprivado.info:80/movie/1533784/1533784/648240.mp4', 'http://gstaticontent.com/images/4OGJKgH6nHEqSG1RZkjmJShBq7Q_big.jpg', NULL, 0, 0, 'original', NULL),
(1276, 33, 'Muito Ralph: Vida e Obra de Ralph Lauren', 'http://sinalprivado.info:80/movie/1533784/1533784/648241.mp4', 'http://gstaticontent.com/images/35B9HpDJPCoaaz70qeERBZPu4eH_big.jpg', NULL, 0, 0, 'original', NULL),
(1277, 33, 'Fascination Coral Reef: Mysterious Worlds Underwater', 'http://sinalprivado.info:80/movie/1533784/1533784/648242.mp4', 'http://gstaticontent.com/images/xQa1rlqu5ECtn1yGpU88Ojf3uv0_big.jpg', NULL, 0, 0, 'original', NULL),
(1278, 33, 'Especial - A Revolucao Dos Games', 'http://sinalprivado.info:80/movie/1533784/1533784/648243.mp4', 'http://gstaticontent.com/images/lOAu6vIAQad94uc1IU4kHC52DXm_big.jpg', NULL, 0, 0, 'original', NULL),
(1279, 33, 'Desarmados', 'http://sinalprivado.info:80/movie/1533784/1533784/648244.mp4', 'http://gstaticontent.com/images/psI16IuKKL8WkWojLO7VOu1S9C7_big.jpg', NULL, 0, 0, 'original', NULL),
(1280, 33, 'Carta Para Além dos Muros', 'http://sinalprivado.info:80/movie/1533784/1533784/648245.mp4', 'http://gstaticontent.com/images/aQakkvHa2BFChEvPHzm9iPvvyHC_big.jpg', NULL, 0, 0, 'original', NULL),
(1281, 33, 'Autoescola Para Mulheres Sauditas', 'http://sinalprivado.info:80/movie/1533784/1533784/648246.mp4', 'http://gstaticontent.com/images/snQQ8RRnEG7K4Tl5gT78vsSy0BT_big.jpg', NULL, 0, 0, 'original', NULL),
(1282, 33, 'O Barato de Iacanga', 'http://sinalprivado.info:80/movie/1533784/1533784/648247.mp4', 'http://gstaticontent.com/images/5ZGD235cQxGfhQjGbnGpM15eoVy_big.jpg', NULL, 0, 0, 'original', NULL),
(1283, 33, 'Havaí: Terra Dos Vulcões', 'http://sinalprivado.info:80/movie/1533784/1533784/648248.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4SYKUGEXCybaanvctTL4x4fp7PJ.jpg', NULL, 0, 0, 'original', NULL),
(1284, 33, 'Trabalho Interno', 'http://sinalprivado.info:80/movie/1533784/1533784/648249.mp4', 'http://gstaticontent.com/images/7O7DBUqbD1z7lhjC9VP95scA1Dt_big.jpg', NULL, 0, 0, 'original', NULL),
(1285, 33, 'Danca dos Passaros', 'http://sinalprivado.info:80/movie/1533784/1533784/648250.mp4', 'http://gstaticontent.com/images/jtLhDn39Pq3AThPLovcGzN43JtI_big.jpg', NULL, 0, 0, 'original', NULL),
(1286, 33, 'O Legado de um Lunatico', 'http://sinalprivado.info:80/movie/1533784/1533784/648251.mp4', 'http://a5.vc/EbY', NULL, 0, 0, 'original', NULL),
(1287, 33, 'Passarinheiros', 'http://sinalprivado.info:80/movie/1533784/1533784/648252.mp4', 'http://gstaticontent.com/images/mgCajUbbAy9uIJiIXKXBypBZj1L_big.jpg', NULL, 0, 0, 'original', NULL),
(1288, 33, 'Fantasmas de Sugar Land', 'http://sinalprivado.info:80/movie/1533784/1533784/648253.mp4', 'http://gstaticontent.com/images/6tSIss3QHysjzhZxSOKgjWjAe55_big.jpg', NULL, 0, 0, 'original', NULL),
(1289, 33, 'A Vida em Mim', 'http://sinalprivado.info:80/movie/1533784/1533784/648254.mp4', 'http://gstaticontent.com/images/uv4a1MntQA8pydnTTf3iICEFcHB_big.jpg', NULL, 0, 0, 'original', NULL),
(1290, 33, 'Não Vai Ter Golpe', 'http://sinalprivado.info:80/movie/1533784/1533784/648255.mp4', 'http://gstaticontent.com/images/872wX6ND9lOGx7mCYGPmOePYZFc_big.jpg', NULL, 0, 0, 'original', NULL),
(1291, 33, 'Do Panama Ao Mundo Roberto Duran', 'http://sinalprivado.info:80/movie/1533784/1533784/648256.mp4', 'http://gstaticontent.com/images/aq1gs52Cs9IhPP1eL6cuO3dlYFa_big.jpg', NULL, 0, 0, 'original', NULL),
(1292, 33, 'Mussum - Um Filme do Cacildis', 'http://sinalprivado.info:80/movie/1533784/1533784/648257.mp4', 'http://gstaticontent.com/images/ec0UeELw5HnGHzwkDtMZstFYpGC_big.jpg', NULL, 0, 0, 'original', NULL),
(1293, 33, 'Indústria Americana', 'http://sinalprivado.info:80/movie/1533784/1533784/648258.mp4', 'http://gstaticontent.com/images/9kLpTYpnbnJWq6IwY6DOyyEDaN3_big.jpg', NULL, 0, 0, 'original', NULL),
(1294, 33, 'A Conquista Da Lua Parte 2', 'http://sinalprivado.info:80/movie/1533784/1533784/648259.mp4', 'http://a5.vc/uUz', NULL, 0, 0, 'original', NULL),
(1295, 33, 'A Conquista Da Lua Parte 1', 'http://sinalprivado.info:80/movie/1533784/1533784/648260.mp4', 'http://a5.vc/2T1', NULL, 0, 0, 'original', NULL),
(1296, 33, 'Gelo em Chamas', 'http://sinalprivado.info:80/movie/1533784/1533784/648261.mp4', 'http://gstaticontent.com/images/9xWrasURZTWbSiulhyxCmJlYTkD_big.jpg', NULL, 0, 0, 'original', NULL),
(1297, 33, 'Privacidade Hackeada', 'http://sinalprivado.info:80/movie/1533784/1533784/648262.mp4', 'http://gstaticontent.com/images/20KWEm4IJ6M6IoE77NFaqwkkJpk_big.jpg', NULL, 0, 0, 'original', NULL),
(1298, 33, 'No Coração do Ouro: O Escândalo da Seleção Americana de Ginastica', 'http://sinalprivado.info:80/movie/1533784/1533784/648263.mp4', 'http://gstaticontent.com/images/lXsZvcUq8F7cweAY9uYDiMORVmO_big.jpg', NULL, 0, 0, 'original', NULL),
(1299, 33, 'Neil Armstrong: A Verdadeira História', 'http://sinalprivado.info:80/movie/1533784/1533784/648264.mp4', 'http://gstaticontent.com/images/aMw5eJo88RFHx1JuDrBsRsKGocx_big.jpg', NULL, 0, 0, 'original', NULL),
(1300, 33, 'Struggle: A Vida e a Arte de Szukalski', 'http://sinalprivado.info:80/movie/1533784/1533784/648265.mp4', 'http://gstaticontent.com/images/uvBJHkVGLwAqUbiNtxsUfVITBcT_big.jpg', NULL, 0, 0, 'original', NULL),
(1301, 33, 'Tres Estranhos Identicos', 'http://sinalprivado.info:80/movie/1533784/1533784/648266.mp4', 'http://gstaticontent.com/images/3C3FxKqBHF3D7ek9IHAIcNdbbLl_big.jpg', NULL, 0, 0, 'original', NULL),
(1302, 33, 'O Inventor A Procura de Sangue no Vale do Silicio', 'http://sinalprivado.info:80/movie/1533784/1533784/648267.mp4', 'http://gstaticontent.com/images/ocittoEQCmUDVaNPWFON6zm0WJ4_big.jpg', NULL, 0, 0, 'original', NULL),
(1303, 33, 'Wig', 'http://sinalprivado.info:80/movie/1533784/1533784/648268.mp4', 'http://gstaticontent.com/images/rHYJo4528f4KCRbgKgQGYOnaqFx_big.jpg', NULL, 0, 0, 'original', NULL),
(1304, 33, 'Nureyev', 'http://sinalprivado.info:80/movie/1533784/1533784/648269.mp4', 'http://gstaticontent.com/images/5aoUC9nl1wJWZNUVG5p2kJUTddA_big.jpg', NULL, 0, 0, 'original', NULL),
(1305, 33, 'Shirkers O Filme Roubado', 'http://sinalprivado.info:80/movie/1533784/1533784/648270.mp4', 'http://gstaticontent.com/images/65ZhFYz0tTLpoDZy2qShsHW92qu_big.jpg', NULL, 0, 0, 'original', NULL),
(1306, 33, 'Free Solo', 'http://sinalprivado.info:80/movie/1533784/1533784/648271.mp4', 'http://gstaticontent.com/images/3vE3t4Pa2CAe8RmjOfp93hL6zXn_big.jpg', NULL, 0, 0, 'original', NULL),
(1307, 33, 'Feministas - O Que Elas Estavam Pensando', 'http://sinalprivado.info:80/movie/1533784/1533784/648272.mp4', 'http://gstaticontent.com/images/1JNfXy6qGYNW8hAJurTramSe9mF_big.jpg', NULL, 0, 0, 'original', NULL),
(1308, 33, 'Virando a Mesa do Poder', 'http://sinalprivado.info:80/movie/1533784/1533784/648273.mp4', 'http://gstaticontent.com/images/uAfixuZIFVbWIsWytzROJDY85D7_big.jpg', NULL, 0, 0, 'original', NULL),
(1309, 33, 'Um Novo Mundo', 'http://sinalprivado.info:80/movie/1533784/1533784/648274.mp4', 'http://gstaticontent.com/images/yWjOPkUjgOpSaBJu1eAJiXmM16s_big.jpg', NULL, 0, 0, 'original', NULL),
(1310, 33, 'Ser Tao Velho Cerrado', 'http://sinalprivado.info:80/movie/1533784/1533784/648275.mp4', 'http://gstaticontent.com/images/B3VXxQs57WvSrcuET2y5ZDSyFg_big.jpg', NULL, 0, 0, 'original', NULL),
(1311, 33, 'Pegue a Bola Passe a Bola', 'http://sinalprivado.info:80/movie/1533784/1533784/648276.mp4', 'http://gstaticontent.com/images/ncNuVIVSQqKJ3xDoMC3DxhElqgO_big.jpg', NULL, 0, 0, 'original', NULL),
(1312, 33, 'A Morte de Jesus: Uma Investigação Médica', 'http://sinalprivado.info:80/movie/1533784/1533784/770238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tvp0pN9T9my1hCGyhech62gOrvx.jpg', NULL, 0, 0, 'original', NULL),
(1313, 33, 'Libelu: Abaixo a Ditadura', 'http://sinalprivado.info:80/movie/1533784/1533784/770239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kpNREpNqvbG0QHLWklUCCuYscD.jpg', NULL, 0, 0, 'original', NULL),
(1314, 33, 'Diddy: Como Nasce Um Bad Boy', 'http://sinalprivado.info:80/movie/1533784/1533784/770240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qBjBdxi1wiOhuN4UabLs9AnL4Q6.jpg', NULL, 0, 0, 'original', NULL),
(1315, 33, 'Jesus: Seguindo os Passos do Messias', 'http://sinalprivado.info:80/movie/1533784/1533784/770241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3IG2rfFaxZ3vWFzQ6ngaAnzHq6P.jpg', NULL, 0, 0, 'original', NULL),
(1316, 33, 'Chile 8.8', 'http://sinalprivado.info:80/movie/1533784/1533784/770242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ds7sey2oo8PszQFfPA27nfrZ2D4.jpg', NULL, 0, 0, 'original', NULL),
(1317, 33, 'O Céu Não Pode Esperar', 'http://sinalprivado.info:80/movie/1533784/1533784/770243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g0UhzvACMrwRUndO8WMYmwD7j1D.jpg', NULL, 0, 0, 'original', NULL),
(1318, 33, 'Mamãe Golpista', 'http://sinalprivado.info:80/movie/1533784/1533784/770244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iA5ZHflyzsxmR09Ce53w9Ng0tIx.jpg', NULL, 0, 0, 'original', NULL),
(1319, 33, 'Profecias Reveladas', 'http://sinalprivado.info:80/movie/1533784/1533784/770245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dwOvzaH6fDI7yYF05q4nP3NLjI1.jpg', NULL, 0, 0, 'original', NULL),
(1320, 33, 'Os Óvnis dos Álamos', 'http://sinalprivado.info:80/movie/1533784/1533784/770246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nLRBZuO4tlcMbRMUNEHxPuqLyDT.jpg', NULL, 0, 0, 'original', NULL),
(1321, 33, 'A Vizinhança do Tigre', 'http://sinalprivado.info:80/movie/1533784/1533784/770247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hGi4HyIyLlfZCQgGSclbjfQnLot.jpg', NULL, 0, 0, 'original', NULL),
(1322, 33, 'Lutar', 'http://sinalprivado.info:80/movie/1533784/1533784/770248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSqDWnzKPq7hHOlcBWp6LRkGAj2.jpg', NULL, 0, 0, 'original', NULL),
(1323, 33, '11/9:  Ataque ao Pentágono', 'http://sinalprivado.info:80/movie/1533784/1533784/770249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cyOPVUkRJ4tOY7LFUn49qH3ol8A.jpg', NULL, 0, 0, 'original', NULL),
(1324, 33, 'A Gente', 'http://sinalprivado.info:80/movie/1533784/1533784/770250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGDnBdmJQEtXbVZ0EWmhCM5BTxD.jpg', NULL, 0, 0, 'original', NULL),
(1325, 33, 'Larissa: O Outro Lado de Anitta', 'http://sinalprivado.info:80/movie/1533784/1533784/770251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e1znkPMVSZv44DfRMeTrQ6G6Da2.jpg', NULL, 0, 0, 'original', NULL);
INSERT INTO `channels` (`id`, `category_id`, `name`, `stream_url`, `logo_url`, `epg_id`, `pid`, `running`, `transcode_quality`, `uptime`) VALUES
(1326, 33, 'A Serva', 'http://sinalprivado.info:80/movie/1533784/1533784/770252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mrzxl9eBtPcD9m4pk5U81xL4RSc.jpg', NULL, 0, 0, 'original', NULL),
(1327, 33, 'Miss Itália Não Pode Morrer', 'http://sinalprivado.info:80/movie/1533784/1533784/770253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9B3D8pMyBaFsOn9D7YTyhpnU7y.jpg', NULL, 0, 0, 'original', NULL),
(1328, 33, 'Brasil Azul', 'http://sinalprivado.info:80/movie/1533784/1533784/770254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jhqCxdztL9fDhETUJdWuBG4d2VL.jpg', NULL, 0, 0, 'original', NULL),
(1329, 33, 'Passinho Foda - O Corre Por Trás da Dança', 'http://sinalprivado.info:80/movie/1533784/1533784/770255.mp4', 'https://i.bj-share.info/16840bc4ad1e7289e2bdfc27ed4ca7cc.jpg', NULL, 0, 0, 'original', NULL),
(1330, 33, 'Polêmico e Fugitivo', 'http://sinalprivado.info:80/movie/1533784/1533784/770256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uTqjzvCJSPjpuRRsTy5GNqkI6zN.jpg', NULL, 0, 0, 'original', NULL),
(1331, 33, 'Luigi Mangione: O Assassino do CEO', 'http://sinalprivado.info:80/movie/1533784/1533784/770257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hhndjUdo9wblPlcu1pjwu6rrCjH.jpg', NULL, 0, 0, 'original', NULL),
(1332, 33, 'Aventuras no Fundo do Mar', 'http://sinalprivado.info:80/movie/1533784/1533784/770258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nZp3wSY9VaDYAFjFuKPyThVy8Xa.jpg', NULL, 0, 0, 'original', NULL),
(1333, 33, 'O Menino da Internet: A História de Aaron Swartz', 'http://sinalprivado.info:80/movie/1533784/1533784/770259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/72rf6z3E8gpbdXbAdIy7uWYdo8Z.jpg', NULL, 0, 0, 'original', NULL),
(1334, 33, 'A Glória Por Eles', 'http://sinalprivado.info:80/movie/1533784/1533784/770260.mp4', 'https://i.bj-share.info/ff934a252cbf8a1e928f31f3fe5af79f.jpg', NULL, 0, 0, 'original', NULL),
(1335, 33, 'Grand Canyon ao Extremo', 'http://sinalprivado.info:80/movie/1533784/1533784/770261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9r6xO7Q1y29ljzxsJnVexDmgKAo.jpg', NULL, 0, 0, 'original', NULL),
(1336, 33, 'Chichén Itzá: A Lenda da Caverna', 'http://sinalprivado.info:80/movie/1533784/1533784/770262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJKchsih91c8hDtJcYXEGQctupv.jpg', NULL, 0, 0, 'original', NULL),
(1337, 33, 'Atlântida: Os Segredos da Cidade Perdida', 'http://sinalprivado.info:80/movie/1533784/1533784/770263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/myc6yvSu98m9vtjNXRVNOnw2vlx.jpg', NULL, 0, 0, 'original', NULL),
(1338, 33, 'Twin Peaks: Os Últimos Dias de Laura Palmer', 'http://sinalprivado.info:80/movie/1533784/1533784/770264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69GrIEaBRM4YxdTfr1mazm9yUDE.jpg', NULL, 0, 0, 'original', NULL),
(1339, 33, 'The Cat Returns - Making of', 'http://sinalprivado.info:80/movie/1533784/1533784/770265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iWuacy2b0Cn4GPGEwLpbwl9rl7S.jpg', NULL, 0, 0, 'original', NULL),
(1340, 33, 'Resistentes', 'http://sinalprivado.info:80/movie/1533784/1533784/770266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/szoh48L6pmxEPKeV7IznCkglS5k.jpg', NULL, 0, 0, 'original', NULL),
(1341, 33, 'Expedição no Everest', 'http://sinalprivado.info:80/movie/1533784/1533784/770267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gZMfHhM2SmQlUtcaVkckO35bPvi.jpg', NULL, 0, 0, 'original', NULL),
(1342, 33, 'Chão', 'http://sinalprivado.info:80/movie/1533784/1533784/770268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/E0KTAa4Roq750YFrN5KjYtTWhZ.jpg', NULL, 0, 0, 'original', NULL),
(1343, 33, 'MTV Video Music Awards', 'http://sinalprivado.info:80/movie/1533784/1533784/770269.mp4', 'https://www.acstatic.co/vod/capinha/mtvvma.jpg', NULL, 0, 0, 'original', NULL),
(1344, 33, 'Torre das Donzelas', 'http://sinalprivado.info:80/movie/1533784/1533784/770270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kHOjWsFqnkHpBRg48E05VEqnLLd.jpg', NULL, 0, 0, 'original', NULL),
(1345, 33, 'Nickelodeon Kids\' Choice Awards', 'http://sinalprivado.info:80/movie/1533784/1533784/770271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k614wdsqbfIUbc3M6glfkO4SJa3.jpg', NULL, 0, 0, 'original', NULL),
(1346, 33, 'MTV Europe Music Awards', 'http://sinalprivado.info:80/movie/1533784/1533784/770272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r9a2io8bitn1s8Hwe7C1ArQlawH.jpg', NULL, 0, 0, 'original', NULL),
(1347, 33, 'Retrospectiva Band (2022)', 'http://sinalprivado.info:80/movie/1533784/1533784/770273.mp4', 'https://i.bj-share.info/ceefebd829f0f8543d943dc62e8b1f7e.jpg', NULL, 0, 0, 'original', NULL),
(1348, 33, 'Retrospectiva Record (2022)', 'http://sinalprivado.info:80/movie/1533784/1533784/770274.mp4', 'http://gstaticontent.com/images/f58426588ef4e0940af71aeef5b9f584.png', NULL, 0, 0, 'original', NULL),
(1349, 33, 'Confisco', 'http://sinalprivado.info:80/movie/1533784/1533784/846452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6TzJUkKCQSg84WG2ew0WNC4gHBq.jpg', NULL, 0, 0, 'original', NULL),
(1350, 33, 'Partido Alto', 'http://sinalprivado.info:80/movie/1533784/1533784/846453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f6n6Q67XDf248IMUi6Ff5saXqWH.jpg', NULL, 0, 0, 'original', NULL),
(1351, 33, 'Nelson Freire', 'http://sinalprivado.info:80/movie/1533784/1533784/846454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNTgddWatf6BdYGzWdnNOHv4ABR.jpg', NULL, 0, 0, 'original', NULL),
(1352, 33, 'A Fuga de Hitler', 'http://sinalprivado.info:80/movie/1533784/1533784/846455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gjYja1WTHMDdoZtrkDmdNWzbR0O.jpg', NULL, 0, 0, 'original', NULL),
(1353, 33, 'Soldados Nissei da 2ª Guerra Mundial', 'http://sinalprivado.info:80/movie/1533784/1533784/846456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tzhRQQhMMtUO4QNPncQqMSUKhx1.jpg', NULL, 0, 0, 'original', NULL),
(1354, 33, 'Michigan Hell House', 'http://sinalprivado.info:80/movie/1533784/1533784/846457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cbkvw3bFTynQf8ZTUKdFifWJUGq.jpg', NULL, 0, 0, 'original', NULL),
(1355, 33, 'Visitantes Alienígenas', 'http://sinalprivado.info:80/movie/1533784/1533784/846458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4vZRsYeKQ2DrC35biZlyXNFyJZb.jpg', NULL, 0, 0, 'original', NULL),
(1356, 33, 'Fantasmas na Casa Branca', 'http://sinalprivado.info:80/movie/1533784/1533784/846459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r30zsarcgssBXDILLLDvotywusW.jpg', NULL, 0, 0, 'original', NULL),
(1357, 33, 'El Titán: The Adrián González Story', 'http://sinalprivado.info:80/movie/1533784/1533784/846460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jRjzvCaGj5DFgHHtz5ZCRYepOFp.jpg', NULL, 0, 0, 'original', NULL),
(1358, 33, 'A Cidade Perdida de Tutancâmon', 'http://sinalprivado.info:80/movie/1533784/1533784/846461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7DWLLFJdzldEucXQrA3Bhvvfjhq.jpg', NULL, 0, 0, 'original', NULL),
(1359, 33, 'Resgate Impossível: 70 Dias Sob a Terra', 'http://sinalprivado.info:80/movie/1533784/1533784/846462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8DJTj9HoeAL0Ycql38SJp6XumIY.jpg', NULL, 0, 0, 'original', NULL),
(1360, 33, 'Titan: O Desastre da OceanGate', 'http://sinalprivado.info:80/movie/1533784/1533784/846463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tcdz5yKjEvJQxJzjvbsphjNSNCe.jpg', NULL, 0, 0, 'original', NULL),
(1361, 33, 'Rita Lee: Mania de Você', 'http://sinalprivado.info:80/movie/1533784/1533784/846464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7bD5lOOfWCcrlav2U8IzbEfETp0.jpg', NULL, 0, 0, 'original', NULL),
(1362, 33, 'A Maldição de Lizzie Borden', 'http://sinalprivado.info:80/movie/1533784/1533784/846465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yD5z6Ha9tlgjT2EjIZeimuMH5cq.jpg', NULL, 0, 0, 'original', NULL),
(1363, 33, 'O Livro Perdido de Nostradamus', 'http://sinalprivado.info:80/movie/1533784/1533784/846466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlmlH6AzGdzeMhvu0ah0RsVyzgD.jpg', NULL, 0, 0, 'original', NULL),
(1364, 33, 'Conspiração Nazi', 'http://sinalprivado.info:80/movie/1533784/1533784/846467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Z1MIATq7rkPVdHkrXVdDxzoXyX.jpg', NULL, 0, 0, 'original', NULL),
(1365, 33, 'As Doutrinas Nazistas', 'http://sinalprivado.info:80/movie/1533784/1533784/846468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uLDGPCHDNSmulV3dbclat9oUqtn.jpg', NULL, 0, 0, 'original', NULL),
(1366, 33, 'o Caçador', 'http://sinalprivado.info:80/movie/1533784/1533784/846469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rS1RhHcwJGunzlMav233anqnKyl.jpg', NULL, 0, 0, 'original', NULL),
(1367, 33, '', 'http://sinalprivado.info:80/movie/1533784/1533784/846470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iWXnE2RlnTZNqpMUkcFZhJ1E21I.jpg', NULL, 0, 0, 'original', NULL),
(1368, 33, 'Identity Crisis', 'http://sinalprivado.info:80/movie/1533784/1533784/846471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exn8EHcWO00Sb7LtZG4h4xLboiS.jpg', NULL, 0, 0, 'original', NULL),
(1369, 33, 'Ilha Christmas: O Reino do Caranguejo-Ladrão', 'http://sinalprivado.info:80/movie/1533784/1533784/846472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nw31zaIhzA7WmZ9fEUOo5a9eP7I.jpg', NULL, 0, 0, 'original', NULL),
(1370, 33, 'O Que Aconteceu com o Rei dos Golfinhos?', 'http://sinalprivado.info:80/movie/1533784/1533784/846473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eALBxCLwgOECIbEVH8aa5UAWLW0.jpg', NULL, 0, 0, 'original', NULL),
(1371, 33, 'Tubarões vs. Embarcações', 'http://sinalprivado.info:80/movie/1533784/1533784/846474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9keFa1FEc3GZJLdGZzH2hNRquer.jpg', NULL, 0, 0, 'original', NULL),
(1372, 33, 'Andre Matos - Maestro do Rock - Episódio II', 'http://sinalprivado.info:80/movie/1533784/1533784/846475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtZqtGJMqcoSjLOkzCviIRNM9Lf.jpg', NULL, 0, 0, 'original', NULL),
(1373, 33, 'Andre Matos - Maestro do Rock - Episódio I', 'http://sinalprivado.info:80/movie/1533784/1533784/846476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fthRn3Avd3BitVt0OHoaxnOfbDn.jpg', NULL, 0, 0, 'original', NULL),
(1374, 33, 'Imagens do Inconsciente - Em Busca do Espaço Cotidiano', 'http://sinalprivado.info:80/movie/1533784/1533784/846477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dS5LBLdczfuBFHXHJVG6SseRRT2.jpg', NULL, 0, 0, 'original', NULL),
(1375, 33, 'Belov: Uma Vida no Mar', 'http://sinalprivado.info:80/movie/1533784/1533784/846478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/daRaf2hmRqXwAO978BHuks9LQ14.jpg', NULL, 0, 0, 'original', NULL),
(1376, 33, 'MST - Terra Prometida', 'http://sinalprivado.info:80/movie/1533784/1533784/846479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKeRZMctf0HhvlXSlNO3MOxBrJ8.jpg', NULL, 0, 0, 'original', NULL),
(1377, 33, 'Thunderbirds: A Elite da Força Aérea dos EUA', 'http://sinalprivado.info:80/movie/1533784/1533784/846480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fGGovl6p5qQ5wfRbhwjqypejOtQ.jpg', NULL, 0, 0, 'original', NULL),
(1378, 33, 'Untold: A Queda de Brett Favre', 'http://sinalprivado.info:80/movie/1533784/1533784/846481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9bVfFo7PLMcRICRIbzPkWZzYIWY.jpg', NULL, 0, 0, 'original', NULL),
(1379, 33, 'Óvnis: Segredos na Casa Branca', 'http://sinalprivado.info:80/movie/1533784/1533784/846482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XU6sKrhrw7zAh3p23Fes3oiFpQ.jpg', NULL, 0, 0, 'original', NULL),
(1380, 33, 'O Caso Anat Kamm', 'http://sinalprivado.info:80/movie/1533784/1533784/846483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mTRautAXsAKjpeFl9v9dzvaTbAm.jpg', NULL, 0, 0, 'original', NULL),
(1381, 33, 'Os Caçadores de Óvnis', 'http://sinalprivado.info:80/movie/1533784/1533784/846484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xClHAH3EREc1oHXVTLRWgIgRUim.jpg', NULL, 0, 0, 'original', NULL),
(1382, 33, 'Vini', 'http://sinalprivado.info:80/movie/1533784/1533784/846485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yzoEUZTf41h6SXVz6V0Z9fHkHN.jpg', NULL, 0, 0, 'original', NULL),
(1383, 33, 'Untold: O Rei do Fígado', 'http://sinalprivado.info:80/movie/1533784/1533784/846486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vuAqZ4Ugc7ZJYOgrpSWpx6n06ao.jpg', NULL, 0, 0, 'original', NULL),
(1384, 33, 'Casamento Letal nos EUA', 'http://sinalprivado.info:80/movie/1533784/1533784/846487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ajoYbGEbI7Rffj1P695iAEmDUo7.jpg', NULL, 0, 0, 'original', NULL),
(1385, 33, 'Vai Corinthians', 'http://sinalprivado.info:80/movie/1533784/1533784/846488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sEIoMxHIbIGQPPjJew0CNgy9bMZ.jpg', NULL, 0, 0, 'original', NULL),
(1386, 33, 'Clarão/Chuva Negra: A Destruição de Hiroshima e Nagasaki', 'http://sinalprivado.info:80/movie/1533784/1533784/846489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/viceMdFGy8aIyJFb07mwAeMbpwW.jpg', NULL, 0, 0, 'original', NULL),
(1387, 33, 'Untold: Defesa Armada', 'http://sinalprivado.info:80/movie/1533784/1533784/846490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3ZDz3IQjq2tWGi46UALvMBqYG1r.jpg', NULL, 0, 0, 'original', NULL),
(1388, 33, 'A Grã-Bretanha e a Blitz', 'http://sinalprivado.info:80/movie/1533784/1533784/846491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6vB4qFbQe67KfaJ9Ne6zItt3gVX.jpg', NULL, 0, 0, 'original', NULL),
(1389, 33, 'Rio de Janeiro: Paraíso em Chamas', 'http://sinalprivado.info:80/movie/1533784/1533784/846492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6zRaBLTmdnP2pkaOtrPlEbkPULe.jpg', NULL, 0, 0, 'original', NULL),
(1390, 33, 'Josef Mengele: O Anjo da Morte', 'http://sinalprivado.info:80/movie/1533784/1533784/846493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yf6RnMH0XtuyONgkIiFRBVDj2b6.jpg', NULL, 0, 0, 'original', NULL),
(1391, 33, 'Carmen Miranda: Bananas Is My Business', 'http://sinalprivado.info:80/movie/1533784/1533784/846494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYYFx5SDQmhTwZnYxSA3r5xlAir.jpg', NULL, 0, 0, 'original', NULL),
(1392, 33, 'Americano', 'http://sinalprivado.info:80/movie/1533784/1533784/846495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/psxATL48MT6MGg1fFht42pW0Dvm.jpg', NULL, 0, 0, 'original', NULL),
(1393, 33, 'A Gente', 'http://sinalprivado.info:80/movie/1533784/1533784/846496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGDnBdmJQEtXbVZ0EWmhCM5BTxD.jpg', NULL, 0, 0, 'original', NULL),
(1394, 33, 'O Papa do Fim do Mundo', 'http://sinalprivado.info:80/movie/1533784/1533784/846497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5wGHM0fIp8F6CiFGL5orQatmg4E.jpg', NULL, 0, 0, 'original', NULL),
(1395, 33, 'Os Segredos da Construção do Vaticano', 'http://sinalprivado.info:80/movie/1533784/1533784/846498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4JvTiwRoJAAKKsXy25ufatvonag.jpg', NULL, 0, 0, 'original', NULL),
(1396, 33, 'Setenta', 'http://sinalprivado.info:80/movie/1533784/1533784/846499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c1c672Zm4S2VhPe9anLWewogayO.jpg', NULL, 0, 0, 'original', NULL),
(1397, 33, 'Provando a Existência de Deus', 'http://sinalprivado.info:80/movie/1533784/1533784/846500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n5qsObi9OjgC5UuHiu0fUGXbPPA.jpg', NULL, 0, 0, 'original', NULL),
(1398, 33, 'Pangolim: A Viagem de Kulu', 'http://sinalprivado.info:80/movie/1533784/1533784/846501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Ky1cTLJzOk8or25YGEvw8S6oxI.jpg', NULL, 0, 0, 'original', NULL),
(1399, 33, 'Atentado em Oklahoma: Terror nos EUA', 'http://sinalprivado.info:80/movie/1533784/1533784/846502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e5fgv7EHBCQG07x09RaiOFRrGN3.jpg', NULL, 0, 0, 'original', NULL),
(1400, 33, 'Os Afro-Sambas: O Brasil de Baden e Vinícius', 'http://sinalprivado.info:80/movie/1533784/1533784/849241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wNwgrnFdzPUdEBSjhOw7QIcQzfR.jpg', NULL, 0, 0, 'original', NULL),
(1401, 33, 'Desastre Total: Cruzeiro do Cocô', 'http://sinalprivado.info:80/movie/1533784/1533784/849242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vfFtFjilnMD2wHllClPzyBfictX.jpg', NULL, 0, 0, 'original', NULL),
(1402, 33, 'Ação', 'http://sinalprivado.info:80/movie/1533784/1533784/849243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1zgwv9FgKFrBPS7nCE5TdtrW79T.jpg', NULL, 0, 0, 'original', NULL),
(1403, 33, 'Precious Life', 'http://sinalprivado.info:80/movie/1533784/1533784/849244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qZVPMVdiTqiE6L47blUOrSID5Ut.jpg', NULL, 0, 0, 'original', NULL),
(1404, 33, 'Bellatrix', 'http://sinalprivado.info:80/movie/1533784/1533784/849245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1o6KWMf8dHYLK7WEHvxedKxpz6d.jpg', NULL, 0, 0, 'original', NULL),
(1405, 33, 'Torre Greenfell: A Verdade por Trás do Desastre', 'http://sinalprivado.info:80/movie/1533784/1533784/849246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dC8cD7EJTqGmUbwWOq3VKEAmLUU.jpg', NULL, 0, 0, 'original', NULL),
(1406, 91, 'The Voice Kids S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1407, 91, 'The Voice Kids S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1408, 91, 'The Voice Kids S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1409, 91, 'The Voice Kids S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1410, 91, 'The Voice Kids S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1411, 91, 'The Voice Kids S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1412, 91, 'The Voice Kids S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1413, 91, 'The Voice Kids S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1414, 91, 'The Voice Kids S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1415, 91, 'The Voice Kids S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1416, 91, 'The Voice Kids S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1417, 91, 'The Voice Kids S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1418, 91, 'The Voice Kids S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/223768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1419, 91, 'The Voice Kids S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/223769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1420, 91, 'The Voice Kids S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1421, 91, 'The Voice Kids S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1422, 91, 'The Voice Kids S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1423, 91, 'The Voice Kids S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1424, 91, 'The Voice Kids S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1425, 91, 'The Voice Kids S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1426, 91, 'The Voice Kids S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1427, 91, 'The Voice Kids S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1428, 91, 'The Voice Kids S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1429, 91, 'The Voice Kids S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1430, 91, 'The Voice Kids S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1431, 91, 'The Voice Kids S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1432, 91, 'The Voice Kids S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/223782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1433, 91, 'The Voice Kids S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/223783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1434, 91, 'The Voice Kids S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/223784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1435, 91, 'The Voice Kids S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/223785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1436, 91, 'The Voice Kids S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1437, 91, 'The Voice Kids S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1438, 91, 'The Voice Kids S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1439, 91, 'The Voice Kids S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1440, 91, 'The Voice Kids S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1441, 91, 'The Voice Kids S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1442, 91, 'The Voice Kids S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1443, 91, 'The Voice Kids S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1444, 91, 'The Voice Kids S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1445, 91, 'The Voice Kids S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1446, 91, 'The Voice Kids S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1447, 91, 'The Voice Kids S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1448, 91, 'The Voice Kids S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/223798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1449, 91, 'The Voice Kids S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/223799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1450, 91, 'The Voice Kids S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/223800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1451, 91, 'The Voice Kids S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/223801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1452, 91, 'The Voice Kids S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/223802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1453, 91, 'The Voice Kids S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1454, 91, 'The Voice Kids S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1455, 91, 'The Voice Kids S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1456, 91, 'The Voice Kids S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1457, 91, 'The Voice Kids S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1458, 91, 'The Voice Kids S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1459, 91, 'The Voice Kids S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1460, 91, 'The Voice Kids S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1461, 91, 'The Voice Kids S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1462, 91, 'The Voice Kids S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1463, 91, 'The Voice Kids S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1464, 91, 'The Voice Kids S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1465, 91, 'The Voice Kids S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1466, 91, 'The Voice Kids S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1467, 91, 'The Voice Kids S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1468, 91, 'The Voice Kids S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1469, 91, 'The Voice Kids S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1470, 91, 'The Voice Kids S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1471, 91, 'The Voice Kids S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1472, 91, 'The Voice Kids S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1473, 91, 'The Voice Kids S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1474, 91, 'The Voice Kids S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1475, 91, 'The Voice Kids S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1476, 91, 'The Voice Kids S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1477, 91, 'The Voice Kids S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/223827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1478, 91, 'The Voice Kids S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/223828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zTRzccT8ZMByiIgczdHD8Qx0nJ.jpg', NULL, 0, 0, 'original', NULL),
(1479, 91, 'The Voice Brasil S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255386.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1480, 91, 'The Voice Brasil S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255387.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1481, 91, 'The Voice Brasil S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255388.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1482, 91, 'The Voice Brasil S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255389.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1483, 91, 'The Voice Brasil S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255390.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1484, 91, 'The Voice Brasil S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255391.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1485, 91, 'The Voice Brasil S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255392.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1486, 91, 'The Voice Brasil S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255393.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1487, 91, 'The Voice Brasil S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255394.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1488, 91, 'The Voice Brasil S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255395.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1489, 91, 'The Voice Brasil S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255396.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1490, 91, 'The Voice Brasil S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255397.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1491, 91, 'The Voice Brasil S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255398.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1492, 91, 'The Voice Brasil S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255399.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1493, 91, 'The Voice Brasil S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255400.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1494, 91, 'The Voice Brasil S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255401.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1495, 91, 'The Voice Brasil S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255402.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1496, 91, 'The Voice Brasil S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255403.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1497, 91, 'The Voice Brasil S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255404.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1498, 91, 'The Voice Brasil S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255405.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1499, 91, 'The Voice Brasil S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255406.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1500, 91, 'The Voice Brasil S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255407.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1501, 91, 'The Voice Brasil S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255408.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1502, 91, 'The Voice Brasil S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255409.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1503, 91, 'The Voice Brasil S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255410.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1504, 91, 'The Voice Brasil S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255411.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1505, 91, 'The Voice Brasil S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255412.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1506, 91, 'The Voice Brasil S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255413.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1507, 91, 'The Voice Brasil S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255414.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1508, 91, 'The Voice Brasil S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255415.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1509, 91, 'The Voice Brasil S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255416.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1510, 91, 'The Voice Brasil S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255417.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1511, 91, 'The Voice Brasil S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255418.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1512, 91, 'The Voice Brasil S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255419.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1513, 91, 'The Voice Brasil S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255420.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1514, 91, 'The Voice Brasil S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255421.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1515, 91, 'The Voice Brasil S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255422.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1516, 91, 'The Voice Brasil S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255423.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1517, 91, 'The Voice Brasil S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255424.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1518, 91, 'The Voice Brasil S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255425.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1519, 91, 'The Voice Brasil S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255426.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1520, 91, 'The Voice Brasil S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255427.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1521, 91, 'The Voice Brasil S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255428.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1522, 91, 'The Voice Brasil S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255429.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1523, 91, 'The Voice Brasil S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255430.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1524, 91, 'The Voice Brasil S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255431.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1525, 91, 'The Voice Brasil S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/589536.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1526, 91, 'The Voice Brasil S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255434.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1527, 91, 'The Voice Brasil S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255435.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1528, 91, 'The Voice Brasil S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255436.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1529, 91, 'The Voice Brasil S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255437.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1530, 91, 'The Voice Brasil S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255438.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1531, 91, 'The Voice Brasil S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255439.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1532, 91, 'The Voice Brasil S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255440.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1533, 91, 'The Voice Brasil S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255441.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1534, 91, 'The Voice Brasil S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255442.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1535, 91, 'The Voice Brasil S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255443.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1536, 91, 'The Voice Brasil S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255444.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1537, 91, 'The Voice Brasil S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pLIYVXRuuZYTMfSyfoeJN8WPvkU.jpg', NULL, 0, 0, 'original', NULL),
(1538, 91, 'The Voice Brasil S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255446.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1539, 91, 'The Voice Brasil S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255447.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1540, 91, 'The Voice Brasil S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255448.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1541, 91, 'The Voice Brasil S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255449.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1542, 91, 'The Voice Brasil S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255450.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1543, 91, 'The Voice Brasil S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255451.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1544, 91, 'The Voice Brasil S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255452.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1545, 91, 'The Voice Brasil S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255453.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1546, 91, 'The Voice Brasil S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255454.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1547, 91, 'The Voice Brasil S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255455.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1548, 91, 'The Voice Brasil S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255456.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1549, 91, 'The Voice Brasil S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255457.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1550, 91, 'The Voice Brasil S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255458.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1551, 91, 'The Voice Brasil S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255459.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1552, 91, 'The Voice Brasil S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255460.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1553, 91, 'The Voice Brasil S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255461.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1554, 91, 'The Voice Brasil S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255462.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1555, 91, 'The Voice Brasil S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255463.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1556, 91, 'The Voice Brasil S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255464.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1557, 91, 'The Voice Brasil S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255465.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1558, 91, 'The Voice Brasil S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255466.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1559, 91, 'The Voice Brasil S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255467.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1560, 91, 'The Voice Brasil S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255468.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL);
INSERT INTO `channels` (`id`, `category_id`, `name`, `stream_url`, `logo_url`, `epg_id`, `pid`, `running`, `transcode_quality`, `uptime`) VALUES
(1561, 91, 'The Voice Brasil S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255469.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1562, 91, 'The Voice Brasil S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/891820.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1563, 91, 'The Voice Brasil S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/891821.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1564, 91, 'The Voice Brasil S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/891822.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1565, 91, 'The Voice Brasil S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/891823.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1566, 91, 'The Voice Brasil S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/891824.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1567, 91, 'The Voice Brasil S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/892411.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1568, 91, 'The Voice Brasil S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/893059.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1569, 91, 'The Voice Brasil S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/893448.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1570, 91, 'The Voice Brasil S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/894196.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1571, 91, 'The Voice Brasil S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/895832.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1572, 91, 'The Voice Brasil S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/896388.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1573, 91, 'The Voice Brasil S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/897398.mp4', 'http://gstaticontent.com/images/b7XwtlZDMGIAURFcTErae6p8P1m_big.jpg', NULL, 0, 0, 'original', NULL),
(1574, 91, 'The Voice Mais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176583.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1575, 91, 'The Voice Mais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176584.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1576, 91, 'The Voice Mais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176585.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1577, 91, 'The Voice Mais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176586.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1578, 91, 'The Voice Mais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176587.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1579, 91, 'The Voice Mais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176588.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1580, 91, 'The Voice Mais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176589.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1581, 91, 'The Voice Mais S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176590.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1582, 91, 'The Voice Mais S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176591.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1583, 91, 'The Voice Mais S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176592.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1584, 91, 'The Voice Mais S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/176593.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1585, 91, 'The Voice Mais S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/176594.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1586, 91, 'The Voice Mais S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176595.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1587, 91, 'The Voice Mais S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176596.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1588, 91, 'The Voice Mais S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176597.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1589, 91, 'The Voice Mais S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176598.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1590, 91, 'The Voice Mais S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176599.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1591, 91, 'The Voice Mais S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176600.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1592, 91, 'The Voice Mais S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176601.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1593, 91, 'The Voice Mais S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176602.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1594, 91, 'The Voice Mais S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176603.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1595, 91, 'The Voice Mais S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176604.mp4', 'http://gstaticontent.com/images/r7FF5G90sB3Zr66L19esRscZ3L9_big.jpg', NULL, 0, 0, 'original', NULL),
(1596, 91, 'No Limite S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228857.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1597, 91, 'No Limite S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228858.mp4', 'http://timg.bdta.pro/images/91e7428045458d3ca84fd8a8e7786403.jpg', NULL, 0, 0, 'original', NULL),
(1598, 91, 'No Limite S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228859.mp4', 'http://timg.bdta.pro/images/2041fad915f233b2131632dc962a4186.jpg', NULL, 0, 0, 'original', NULL),
(1599, 91, 'No Limite S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228860.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1600, 91, 'No Limite S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228861.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1601, 91, 'No Limite S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228862.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1602, 91, 'No Limite S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228863.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1603, 91, 'No Limite S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228864.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1604, 91, 'No Limite S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228865.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1605, 91, 'No Limite S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228866.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1606, 91, 'No Limite S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228867.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1607, 91, 'No Limite S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228868.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1608, 91, 'No Limite S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228869.mp4', 'http://timg.bdta.pro/images/c681ee7c2f70e76b02d2d2af0b055607.jpg', NULL, 0, 0, 'original', NULL),
(1609, 91, 'No Limite S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228870.mp4', 'http://timg.bdta.pro/images/d819ba9d9a152b38cbb1c6b401f9f016.jpg', NULL, 0, 0, 'original', NULL),
(1610, 91, 'No Limite S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228871.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1611, 91, 'No Limite S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228872.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1612, 91, 'No Limite S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228873.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1613, 91, 'No Limite S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228874.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1614, 91, 'No Limite S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228875.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1615, 91, 'No Limite S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228876.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1616, 91, 'No Limite S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228877.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1617, 91, 'No Limite S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228878.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1618, 91, 'No Limite S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228879.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1619, 91, 'No Limite S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228880.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1620, 91, 'No Limite S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228881.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1621, 91, 'No Limite S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228882.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1622, 91, 'No Limite S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228883.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1623, 91, 'No Limite S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/228884.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1624, 91, 'No Limite S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/228885.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1625, 91, 'No Limite S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/228886.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1626, 91, 'No Limite S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/228887.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1627, 91, 'No Limite S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/228888.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1628, 91, 'No Limite S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZIoGTSKf02oycH3XEAqU85zTEg.jpg', NULL, 0, 0, 'original', NULL),
(1629, 91, 'No Limite S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yo5KlWxPcQjTjHwfXZH4KMjKN3m.jpg', NULL, 0, 0, 'original', NULL),
(1630, 91, 'No Limite S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bXXuJVeofI0wj6nI9M7MD0guDIc.jpg', NULL, 0, 0, 'original', NULL),
(1631, 91, 'No Limite S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228892.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1632, 91, 'No Limite S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228893.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1633, 91, 'No Limite S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228894.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1634, 91, 'No Limite S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228895.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1635, 91, 'No Limite S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228896.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1636, 91, 'No Limite S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228897.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1637, 91, 'No Limite S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228898.mp4', 'http://gstaticontent.com/images/oT2qnoGedxlO7Z3qar3uojMZoBY_big.jpg', NULL, 0, 0, 'original', NULL),
(1638, 91, 'Pequenas Empresas  & Grandes Negocios S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231630.mp4', 'https://i.bj-share.info/f2db3b440db1be4c471d7e6db72ae134.jpg', NULL, 0, 0, 'original', NULL),
(1639, 91, 'Pequenas Empresas  & Grandes Negocios S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231631.mp4', 'https://i.bj-share.info/f2db3b440db1be4c471d7e6db72ae134.jpg', NULL, 0, 0, 'original', NULL),
(1640, 91, 'Pequenas Empresas  & Grandes Negocios S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231632.mp4', 'https://i.bj-share.info/f2db3b440db1be4c471d7e6db72ae134.jpg', NULL, 0, 0, 'original', NULL),
(1641, 91, 'Pequenas Empresas  & Grandes Negocios S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231633.mp4', 'https://i.bj-share.info/f2db3b440db1be4c471d7e6db72ae134.jpg', NULL, 0, 0, 'original', NULL),
(1642, 91, 'Pequenas Empresas  & Grandes Negocios S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231634.mp4', 'https://i.bj-share.info/f2db3b440db1be4c471d7e6db72ae134.jpg', NULL, 0, 0, 'original', NULL),
(1643, 91, 'Pequenas Empresas  & Grandes Negocios S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231635.mp4', 'https://i.bj-share.info/f2db3b440db1be4c471d7e6db72ae134.jpg', NULL, 0, 0, 'original', NULL),
(1644, 91, 'Pequenas Empresas  & Grandes Negocios S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231636.mp4', 'https://i.bj-share.info/f2db3b440db1be4c471d7e6db72ae134.jpg', NULL, 0, 0, 'original', NULL),
(1645, 91, 'Pequenas Empresas  & Grandes Negocios S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231637.mp4', 'https://i.bj-share.info/f2db3b440db1be4c471d7e6db72ae134.jpg', NULL, 0, 0, 'original', NULL),
(1646, 91, 'Pequenas Empresas  & Grandes Negocios S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231638.mp4', 'https://i.bj-share.info/f2db3b440db1be4c471d7e6db72ae134.jpg', NULL, 0, 0, 'original', NULL),
(1647, 91, 'Auto Esporte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231693.mp4', 'https://i.bj-share.info/5bb4f17dbf2980c679d6f935e10c058e.jpg', NULL, 0, 0, 'original', NULL),
(1648, 91, 'Auto Esporte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231694.mp4', 'https://i.bj-share.info/5bb4f17dbf2980c679d6f935e10c058e.jpg', NULL, 0, 0, 'original', NULL),
(1649, 91, 'Auto Esporte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231695.mp4', 'https://i.bj-share.info/5bb4f17dbf2980c679d6f935e10c058e.jpg', NULL, 0, 0, 'original', NULL),
(1650, 91, 'Auto Esporte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231696.mp4', 'https://i.bj-share.info/5bb4f17dbf2980c679d6f935e10c058e.jpg', NULL, 0, 0, 'original', NULL),
(1651, 91, 'Auto Esporte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231697.mp4', 'https://i.bj-share.info/5bb4f17dbf2980c679d6f935e10c058e.jpg', NULL, 0, 0, 'original', NULL),
(1652, 91, 'Auto Esporte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231698.mp4', 'https://i.bj-share.info/5bb4f17dbf2980c679d6f935e10c058e.jpg', NULL, 0, 0, 'original', NULL),
(1653, 91, 'Auto Esporte S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231699.mp4', 'https://i.bj-share.info/5bb4f17dbf2980c679d6f935e10c058e.jpg', NULL, 0, 0, 'original', NULL),
(1654, 91, 'Auto Esporte S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231700.mp4', 'https://i.bj-share.info/5bb4f17dbf2980c679d6f935e10c058e.jpg', NULL, 0, 0, 'original', NULL),
(1655, 91, 'Auto Esporte S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231701.mp4', 'https://i.bj-share.info/5bb4f17dbf2980c679d6f935e10c058e.jpg', NULL, 0, 0, 'original', NULL),
(1656, 91, 'Auto Esporte S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231702.mp4', 'https://i.bj-share.info/5bb4f17dbf2980c679d6f935e10c058e.jpg', NULL, 0, 0, 'original', NULL),
(1657, 91, 'Auto Esporte S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/231703.mp4', 'https://i.bj-share.info/5bb4f17dbf2980c679d6f935e10c058e.jpg', NULL, 0, 0, 'original', NULL),
(1658, 91, 'Auto Esporte S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/231704.mp4', 'https://i.bj-share.info/5bb4f17dbf2980c679d6f935e10c058e.jpg', NULL, 0, 0, 'original', NULL),
(1659, 91, 'Auto Esporte S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/231705.mp4', 'https://i.bj-share.info/5bb4f17dbf2980c679d6f935e10c058e.jpg', NULL, 0, 0, 'original', NULL),
(1660, 91, 'Auto Esporte S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/231706.mp4', 'https://i.bj-share.info/5bb4f17dbf2980c679d6f935e10c058e.jpg', NULL, 0, 0, 'original', NULL),
(1661, 91, 'Auto Esporte S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/231707.mp4', 'https://i.bj-share.info/5bb4f17dbf2980c679d6f935e10c058e.jpg', NULL, 0, 0, 'original', NULL),
(1662, 91, 'Auto Esporte S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/231708.mp4', 'https://i.bj-share.info/5bb4f17dbf2980c679d6f935e10c058e.jpg', NULL, 0, 0, 'original', NULL),
(1663, 91, 'Auto Esporte S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/231709.mp4', 'https://i.bj-share.info/5bb4f17dbf2980c679d6f935e10c058e.jpg', NULL, 0, 0, 'original', NULL),
(1664, 91, 'Auto Esporte S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/231710.mp4', 'https://i.bj-share.info/5bb4f17dbf2980c679d6f935e10c058e.jpg', NULL, 0, 0, 'original', NULL),
(1665, 91, 'Auto Esporte S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/231711.mp4', 'https://i.bj-share.info/5bb4f17dbf2980c679d6f935e10c058e.jpg', NULL, 0, 0, 'original', NULL),
(1666, 91, 'Caldeirao Com Mion S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231682.mp4', 'https://i.bj-share.info/c401ffb156ced9c4403fe744139702f1.jpg', NULL, 0, 0, 'original', NULL),
(1667, 91, 'Caldeirao Com Mion S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231683.mp4', 'https://i.bj-share.info/c401ffb156ced9c4403fe744139702f1.jpg', NULL, 0, 0, 'original', NULL),
(1668, 91, 'Caldeirao Com Mion S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231684.mp4', 'https://i.bj-share.info/c401ffb156ced9c4403fe744139702f1.jpg', NULL, 0, 0, 'original', NULL),
(1669, 91, 'Caldeirao Com Mion S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231685.mp4', 'https://i.bj-share.info/c401ffb156ced9c4403fe744139702f1.jpg', NULL, 0, 0, 'original', NULL),
(1670, 91, 'Caldeirao Com Mion S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231686.mp4', 'https://i.bj-share.info/c401ffb156ced9c4403fe744139702f1.jpg', NULL, 0, 0, 'original', NULL),
(1671, 91, 'Caldeirao Com Mion S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231687.mp4', 'https://i.bj-share.info/c401ffb156ced9c4403fe744139702f1.jpg', NULL, 0, 0, 'original', NULL),
(1672, 91, 'Caldeirao Com Mion S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231688.mp4', 'https://i.bj-share.info/c401ffb156ced9c4403fe744139702f1.jpg', NULL, 0, 0, 'original', NULL),
(1673, 91, 'Caldeirao Com Mion S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231689.mp4', 'https://i.bj-share.info/c401ffb156ced9c4403fe744139702f1.jpg', NULL, 0, 0, 'original', NULL),
(1674, 91, 'Caldeirao Com Mion S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231690.mp4', 'https://i.bj-share.info/c401ffb156ced9c4403fe744139702f1.jpg', NULL, 0, 0, 'original', NULL),
(1675, 91, 'Caldeirao Com Mion S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231691.mp4', 'https://i.bj-share.info/c401ffb156ced9c4403fe744139702f1.jpg', NULL, 0, 0, 'original', NULL),
(1676, 91, 'Caldeirao Com Mion S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/231692.mp4', 'https://i.bj-share.info/c401ffb156ced9c4403fe744139702f1.jpg', NULL, 0, 0, 'original', NULL),
(1677, 91, 'Domingao Com Huck S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231671.mp4', 'https://i.bj-share.info/6ef505cc418e67af141a56666024feb3.jpg', NULL, 0, 0, 'original', NULL),
(1678, 91, 'Domingao Com Huck S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231672.mp4', 'https://i.bj-share.info/6ef505cc418e67af141a56666024feb3.jpg', NULL, 0, 0, 'original', NULL),
(1679, 91, 'Domingao Com Huck S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231673.mp4', 'https://i.bj-share.info/6ef505cc418e67af141a56666024feb3.jpg', NULL, 0, 0, 'original', NULL),
(1680, 91, 'Domingao Com Huck S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231674.mp4', 'https://i.bj-share.info/6ef505cc418e67af141a56666024feb3.jpg', NULL, 0, 0, 'original', NULL),
(1681, 91, 'Domingao Com Huck S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231675.mp4', 'https://i.bj-share.info/6ef505cc418e67af141a56666024feb3.jpg', NULL, 0, 0, 'original', NULL),
(1682, 91, 'Domingao Com Huck S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231676.mp4', 'https://i.bj-share.info/6ef505cc418e67af141a56666024feb3.jpg', NULL, 0, 0, 'original', NULL),
(1683, 91, 'Domingao Com Huck S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231677.mp4', 'https://i.bj-share.info/6ef505cc418e67af141a56666024feb3.jpg', NULL, 0, 0, 'original', NULL),
(1684, 91, 'Domingao Com Huck S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231678.mp4', 'https://i.bj-share.info/6ef505cc418e67af141a56666024feb3.jpg', NULL, 0, 0, 'original', NULL),
(1685, 91, 'Domingao Com Huck S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231679.mp4', 'https://i.bj-share.info/6ef505cc418e67af141a56666024feb3.jpg', NULL, 0, 0, 'original', NULL),
(1686, 91, 'Domingao Com Huck S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231680.mp4', 'https://i.bj-share.info/6ef505cc418e67af141a56666024feb3.jpg', NULL, 0, 0, 'original', NULL),
(1687, 91, 'Domingao Com Huck S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/231681.mp4', 'https://i.bj-share.info/6ef505cc418e67af141a56666024feb3.jpg', NULL, 0, 0, 'original', NULL),
(1688, 91, 'Fantastico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231660.mp4', 'https://i.bj-share.info/3a1b3927d500330310bffbd26a9ebb88.jpg', NULL, 0, 0, 'original', NULL),
(1689, 91, 'Fantastico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231661.mp4', 'https://i.bj-share.info/3a1b3927d500330310bffbd26a9ebb88.jpg', NULL, 0, 0, 'original', NULL),
(1690, 91, 'Fantastico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231662.mp4', 'https://i.bj-share.info/3a1b3927d500330310bffbd26a9ebb88.jpg', NULL, 0, 0, 'original', NULL),
(1691, 91, 'Fantastico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231663.mp4', 'https://i.bj-share.info/3a1b3927d500330310bffbd26a9ebb88.jpg', NULL, 0, 0, 'original', NULL),
(1692, 91, 'Fantastico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231664.mp4', 'https://i.bj-share.info/3a1b3927d500330310bffbd26a9ebb88.jpg', NULL, 0, 0, 'original', NULL),
(1693, 91, 'Fantastico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231665.mp4', 'https://i.bj-share.info/3a1b3927d500330310bffbd26a9ebb88.jpg', NULL, 0, 0, 'original', NULL),
(1694, 91, 'Fantastico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231666.mp4', 'https://i.bj-share.info/3a1b3927d500330310bffbd26a9ebb88.jpg', NULL, 0, 0, 'original', NULL),
(1695, 91, 'Fantastico S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231667.mp4', 'https://i.bj-share.info/3a1b3927d500330310bffbd26a9ebb88.jpg', NULL, 0, 0, 'original', NULL),
(1696, 91, 'Fantastico S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231668.mp4', 'https://i.bj-share.info/3a1b3927d500330310bffbd26a9ebb88.jpg', NULL, 0, 0, 'original', NULL),
(1697, 91, 'Fantastico S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231669.mp4', 'https://i.bj-share.info/3a1b3927d500330310bffbd26a9ebb88.jpg', NULL, 0, 0, 'original', NULL),
(1698, 91, 'Fantastico S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/231670.mp4', 'https://i.bj-share.info/3a1b3927d500330310bffbd26a9ebb88.jpg', NULL, 0, 0, 'original', NULL),
(1699, 91, 'Globo Reporter S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231649.mp4', 'https://i.bj-share.info/ff558fb86c16557e8b9528835982493b.jpg', NULL, 0, 0, 'original', NULL),
(1700, 91, 'Globo Reporter S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231650.mp4', 'https://i.bj-share.info/ff558fb86c16557e8b9528835982493b.jpg', NULL, 0, 0, 'original', NULL),
(1701, 91, 'Globo Reporter S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231651.mp4', 'https://i.bj-share.info/ff558fb86c16557e8b9528835982493b.jpg', NULL, 0, 0, 'original', NULL),
(1702, 91, 'Globo Reporter S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231652.mp4', 'https://i.bj-share.info/ff558fb86c16557e8b9528835982493b.jpg', NULL, 0, 0, 'original', NULL),
(1703, 91, 'Globo Reporter S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231653.mp4', 'https://i.bj-share.info/ff558fb86c16557e8b9528835982493b.jpg', NULL, 0, 0, 'original', NULL),
(1704, 91, 'Globo Reporter S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231654.mp4', 'https://i.bj-share.info/ff558fb86c16557e8b9528835982493b.jpg', NULL, 0, 0, 'original', NULL),
(1705, 91, 'Globo Reporter S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231655.mp4', 'https://i.bj-share.info/ff558fb86c16557e8b9528835982493b.jpg', NULL, 0, 0, 'original', NULL),
(1706, 91, 'Globo Reporter S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231656.mp4', 'https://i.bj-share.info/ff558fb86c16557e8b9528835982493b.jpg', NULL, 0, 0, 'original', NULL),
(1707, 91, 'Globo Reporter S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231657.mp4', 'https://i.bj-share.info/ff558fb86c16557e8b9528835982493b.jpg', NULL, 0, 0, 'original', NULL),
(1708, 91, 'Globo Reporter S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231658.mp4', 'https://i.bj-share.info/ff558fb86c16557e8b9528835982493b.jpg', NULL, 0, 0, 'original', NULL),
(1709, 91, 'Globo Reporter S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/231659.mp4', 'https://i.bj-share.info/ff558fb86c16557e8b9528835982493b.jpg', NULL, 0, 0, 'original', NULL),
(1710, 91, 'Globo Rural S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231639.mp4', 'https://i.bj-share.info/51e000644c7bf73a88f5e53cf376c35e.jpg', NULL, 0, 0, 'original', NULL),
(1711, 91, 'Globo Rural S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231640.mp4', 'https://i.bj-share.info/51e000644c7bf73a88f5e53cf376c35e.jpg', NULL, 0, 0, 'original', NULL),
(1712, 91, 'Globo Rural S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231641.mp4', 'https://i.bj-share.info/51e000644c7bf73a88f5e53cf376c35e.jpg', NULL, 0, 0, 'original', NULL),
(1713, 91, 'Globo Rural S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231642.mp4', 'https://i.bj-share.info/51e000644c7bf73a88f5e53cf376c35e.jpg', NULL, 0, 0, 'original', NULL),
(1714, 91, 'Globo Rural S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231643.mp4', 'https://i.bj-share.info/51e000644c7bf73a88f5e53cf376c35e.jpg', NULL, 0, 0, 'original', NULL),
(1715, 91, 'Globo Rural S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231644.mp4', 'https://i.bj-share.info/51e000644c7bf73a88f5e53cf376c35e.jpg', NULL, 0, 0, 'original', NULL),
(1716, 91, 'Globo Rural S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231645.mp4', 'https://i.bj-share.info/51e000644c7bf73a88f5e53cf376c35e.jpg', NULL, 0, 0, 'original', NULL),
(1717, 91, 'Globo Rural S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231646.mp4', 'https://i.bj-share.info/51e000644c7bf73a88f5e53cf376c35e.jpg', NULL, 0, 0, 'original', NULL),
(1718, 91, 'Globo Rural S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231647.mp4', 'https://i.bj-share.info/51e000644c7bf73a88f5e53cf376c35e.jpg', NULL, 0, 0, 'original', NULL),
(1719, 91, 'Globo Rural S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231648.mp4', 'https://i.bj-share.info/51e000644c7bf73a88f5e53cf376c35e.jpg', NULL, 0, 0, 'original', NULL),
(1720, 91, 'Profissao Reporter S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231621.mp4', 'https://i.bj-share.info/f93102376b76add087aeab499baf2007.jpg', NULL, 0, 0, 'original', NULL),
(1721, 91, 'Profissao Reporter S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231622.mp4', 'https://i.bj-share.info/f93102376b76add087aeab499baf2007.jpg', NULL, 0, 0, 'original', NULL),
(1722, 91, 'Profissao Reporter S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231623.mp4', 'https://i.bj-share.info/f93102376b76add087aeab499baf2007.jpg', NULL, 0, 0, 'original', NULL),
(1723, 91, 'Profissao Reporter S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231624.mp4', 'https://i.bj-share.info/f93102376b76add087aeab499baf2007.jpg', NULL, 0, 0, 'original', NULL),
(1724, 91, 'Profissao Reporter S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231625.mp4', 'https://i.bj-share.info/f93102376b76add087aeab499baf2007.jpg', NULL, 0, 0, 'original', NULL),
(1725, 91, 'Profissao Reporter S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231626.mp4', 'https://i.bj-share.info/f93102376b76add087aeab499baf2007.jpg', NULL, 0, 0, 'original', NULL),
(1726, 91, 'Profissao Reporter S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231627.mp4', 'https://i.bj-share.info/f93102376b76add087aeab499baf2007.jpg', NULL, 0, 0, 'original', NULL),
(1727, 91, 'Profissao Reporter S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/576343.mp4', 'https://i.bj-share.info/f93102376b76add087aeab499baf2007.jpg', NULL, 0, 0, 'original', NULL),
(1728, 91, 'Show do Milhao PicPay S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VBAWKk77xcEhLMUlpGSqILv1Rb.jpg', NULL, 0, 1, 'original', '2026-01-06 19:52:11'),
(1729, 18, 'Show do Milhao PicPay S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VBAWKk77xcEhLMUlpGSqILv1Rb.jpg', NULL, 0, 1, 'original', '2026-01-06 04:00:24'),
(1730, 0, 'Show do Milhao PicPay S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VBAWKk77xcEhLMUlpGSqILv1Rb.jpg', NULL, 0, 1, 'original', '2026-01-06 04:00:09');

-- --------------------------------------------------------

--
-- Estrutura para tabela `chatbot`
--

CREATE TABLE `chatbot` (
  `id` int(11) NOT NULL,
  `admin_id` int(11) NOT NULL,
  `rule_type` enum('equals','contains') NOT NULL DEFAULT 'equals',
  `rule_action` enum('text','test_iptv') NOT NULL DEFAULT 'text',
  `response` text DEFAULT NULL,
  `status` int(1) NOT NULL DEFAULT 1,
  `runs` int(11) NOT NULL DEFAULT 0
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

--
-- Despejando dados para a tabela `chatbot`
--

INSERT INTO `chatbot` (`id`, `admin_id`, `rule_type`, `rule_action`, `response`, `status`, `runs`) VALUES
(1, 1, 'equals', 'test_iptv', '', 1, 10),
(2, 1, 'equals', 'text', 'Ola', 1, 4),
(3, 1, 'equals', 'text', 'Oi, tudo bem ', 1, 1);

-- --------------------------------------------------------

--
-- Estrutura para tabela `chatbot_messages`
--

CREATE TABLE `chatbot_messages` (
  `id` int(11) NOT NULL,
  `chatbot_id` int(11) NOT NULL,
  `admin_id` int(11) NOT NULL,
  `message` varchar(255) NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

--
-- Despejando dados para a tabela `chatbot_messages`
--

INSERT INTO `chatbot_messages` (`id`, `chatbot_id`, `admin_id`, `message`) VALUES
(2, 2, 1, '2'),
(3, 1, 1, '1'),
(4, 3, 1, 'Oi');

-- --------------------------------------------------------

--
-- Estrutura para tabela `configuracoes`
--

CREATE TABLE `configuracoes` (
  `id` int(11) NOT NULL,
  `usuario_adm` varchar(50) NOT NULL,
  `senha_adm` varchar(50) NOT NULL,
  `whatsapp` varchar(20) NOT NULL,
  `dominio_url` varchar(255) NOT NULL,
  `nome_servidor` varchar(100) DEFAULT 'TOP IPTV',
  `confianca_ativo` tinyint(1) DEFAULT 0,
  `confianca_dias` int(11) DEFAULT 2
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE=latin1_swedish_ci;

--
-- Despejando dados para a tabela `configuracoes`
--

INSERT INTO `configuracoes` (`id`, `usuario_adm`, `senha_adm`, `whatsapp`, `dominio_url`, `nome_servidor`, `confianca_ativo`, `confianca_dias`) VALUES
(1, 'admin', 'admin', '47988870797', 'http://axr.topiptv.one', 'TOP IPTV', 1, 1);

-- --------------------------------------------------------

--
-- Estrutura para tabela `credits_log`
--

CREATE TABLE `credits_log` (
  `id` int(11) NOT NULL,
  `target_id` int(11) DEFAULT NULL,
  `admin_id` int(11) DEFAULT NULL,
  `amount` float DEFAULT NULL,
  `date` int(11) DEFAULT NULL,
  `reason` text DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb3 COLLATE=utf8mb3_general_ci;

--
-- Despejando dados para a tabela `credits_log`
--

INSERT INTO `credits_log` (`id`, `target_id`, `admin_id`, `amount`, `date`, `reason`) VALUES
(1, 4, 1, 1, 1767321535, 'Adicionado Manualmente'),
(2, 4, 1, 10, 1767324460, 'Adicionado Manualmente');

-- --------------------------------------------------------

--
-- Estrutura para tabela `episodes`
--

CREATE TABLE `episodes` (
  `id` int(11) NOT NULL,
  `season_id` int(11) NOT NULL,
  `name` varchar(255) NOT NULL,
  `stream_url` text NOT NULL,
  `cover_url` text DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

--
-- Despejando dados para a tabela `episodes`
--

INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(1, 1, '3 Palavrinhas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101467.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(2, 1, '3 Palavrinhas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101468.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(3, 1, '3 Palavrinhas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101469.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(4, 1, '3 Palavrinhas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101470.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(5, 1, '3 Palavrinhas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101471.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(6, 1, '3 Palavrinhas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101472.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(7, 1, '3 Palavrinhas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101473.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(8, 1, '3 Palavrinhas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101474.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(9, 1, '3 Palavrinhas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101475.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(10, 1, '3 Palavrinhas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101476.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(11, 2, '3 Palavrinhas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101477.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(12, 2, '3 Palavrinhas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101478.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(13, 2, '3 Palavrinhas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101479.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(14, 2, '3 Palavrinhas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101480.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(15, 2, '3 Palavrinhas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101481.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(16, 2, '3 Palavrinhas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101482.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(17, 2, '3 Palavrinhas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101483.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(18, 2, '3 Palavrinhas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101484.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(19, 2, '3 Palavrinhas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101485.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(20, 2, '3 Palavrinhas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101486.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(21, 3, '3 Palavrinhas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101487.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(22, 3, '3 Palavrinhas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101488.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(23, 3, '3 Palavrinhas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101489.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(24, 3, '3 Palavrinhas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101490.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(25, 3, '3 Palavrinhas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101491.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(26, 3, '3 Palavrinhas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101492.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(27, 3, '3 Palavrinhas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101493.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(28, 3, '3 Palavrinhas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101494.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(29, 3, '3 Palavrinhas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101495.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(30, 3, '3 Palavrinhas S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101496.mp4', 'https://images-na.ssl-images-amazon.com/images/I/71vhGZ-8w3L.jpg'),
(31, 4, '9-1-1 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(32, 4, '9-1-1 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(33, 4, '9-1-1 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(34, 4, '9-1-1 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(35, 4, '9-1-1 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(36, 4, '9-1-1 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(37, 4, '9-1-1 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(38, 4, '9-1-1 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(39, 4, '9-1-1 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215583.mkv', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(40, 4, '9-1-1 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215584.mkv', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(41, 5, '9-1-1 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(42, 5, '9-1-1 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(43, 5, '9-1-1 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(44, 5, '9-1-1 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(45, 5, '9-1-1 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(46, 5, '9-1-1 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(47, 5, '9-1-1 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(48, 5, '9-1-1 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(49, 5, '9-1-1 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(50, 5, '9-1-1 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(51, 5, '9-1-1 S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(52, 5, '9-1-1 S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(53, 5, '9-1-1 S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(54, 5, '9-1-1 S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(55, 5, '9-1-1 S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(56, 5, '9-1-1 S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(57, 5, '9-1-1 S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/215601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(58, 5, '9-1-1 S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/215602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(59, 6, '9-1-1 S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(60, 6, '9-1-1 S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(61, 6, '9-1-1 S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(62, 6, '9-1-1 S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(63, 6, '9-1-1 S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(64, 6, '9-1-1 S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(65, 6, '9-1-1 S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(66, 6, '9-1-1 S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(67, 6, '9-1-1 S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(68, 6, '9-1-1 S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(69, 6, '9-1-1 S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(70, 6, '9-1-1 S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(71, 6, '9-1-1 S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(72, 6, '9-1-1 S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(73, 6, '9-1-1 S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(74, 6, '9-1-1 S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(75, 6, '9-1-1 S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/215619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(76, 6, '9-1-1 S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/215620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(77, 7, '9-1-1 S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215621.mp4', 'http://timg.bdta.pro/images/421ecf2b07155db77d1dd706d04b9220.jpg'),
(78, 7, '9-1-1 S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215622.mp4', 'http://timg.bdta.pro/images/49a3bc979bde8709b88df344ada2a59c.jpg'),
(79, 7, '9-1-1 S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215623.mp4', 'http://timg.bdta.pro/images/7da512b4b67bd9fa854714bd6f31c57a.jpg'),
(80, 7, '9-1-1 S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215624.mp4', 'http://timg.bdta.pro/images/9d4ee424980107296165070b3aef6496.jpg'),
(81, 7, '9-1-1 S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215625.mp4', 'http://timg.bdta.pro/images/347a8630bcc00074fc68f03508c61378.jpg'),
(82, 7, '9-1-1 S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215626.mp4', 'http://timg.bdta.pro/images/bd551e2fc2dc89530237ed614e3ee968.jpg'),
(83, 7, '9-1-1 S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215627.mp4', 'http://timg.bdta.pro/images/a53c9388c98fd44b201dfa2756b3b05a.jpg'),
(84, 7, '9-1-1 S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215628.mp4', 'http://timg.bdta.pro/images/644b2ddc807b4c0b4ab30189af448fd5.jpg'),
(85, 7, '9-1-1 S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215629.mp4', 'http://timg.bdta.pro/images/0b9c7760546ac77824e743a6b53d06fe.jpg'),
(86, 7, '9-1-1 S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215630.mp4', 'http://timg.bdta.pro/images/b5e9002af2a5d841138440c8e59c40f3.jpg'),
(87, 7, '9-1-1 S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215631.mp4', 'http://timg.bdta.pro/images/963b2ec8267df3f751438117602e0988.jpg'),
(88, 7, '9-1-1 S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215632.mp4', 'http://timg.bdta.pro/images/47e41b5b7c5ee568245c61ff00795353.jpg'),
(89, 7, '9-1-1 S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215633.mp4', 'http://timg.bdta.pro/images/ac74aa7389f354deb3601cf72890484a.jpg'),
(90, 7, '9-1-1 S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215634.mp4', 'http://timg.bdta.pro/images/74b4084f5ce173e95f411df94fceca3e.jpg'),
(91, 8, '9-1-1 S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215635.mp4', 'http://timg.bdta.pro/images/3519127a86992f298a007b168d00dff3.jpg'),
(92, 8, '9-1-1 S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215636.mp4', 'http://timg.bdta.pro/images/1206a61657ed8a36fca5b9488ba8cef2.jpg'),
(93, 8, '9-1-1 S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215637.mp4', 'http://timg.bdta.pro/images/7b86f16f58c1e5694dbac1a3eb99e477.jpg'),
(94, 8, '9-1-1 S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215638.mp4', 'http://timg.bdta.pro/images/5880e60227844ba209f1426a297d2a65.jpg'),
(95, 8, '9-1-1 S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215639.mp4', 'http://timg.bdta.pro/images/f0bf243fbb050805200edabfea064dff.jpg'),
(96, 8, '9-1-1 S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215640.mp4', 'http://timg.bdta.pro/images/422bd220f626ce1f4cb6e553c17a2581.jpg'),
(97, 8, '9-1-1 S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215641.mp4', 'http://timg.bdta.pro/images/fb6ea05e5419259d931450262699816f.jpg'),
(98, 8, '9-1-1 S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215642.mp4', 'http://timg.bdta.pro/images/9a01170c4814d1ecf1533aade699fa98.jpg'),
(99, 8, '9-1-1 S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215643.mp4', 'http://timg.bdta.pro/images/ae1818584e9d68250a8edde0ea3e1014.jpg'),
(100, 8, '9-1-1 S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215644.mp4', 'http://timg.bdta.pro/images/4d79f341c4d54be40763d92d4a19dd3d.jpg'),
(101, 8, '9-1-1 S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215645.mp4', 'http://timg.bdta.pro/images/496fa4a7ae07aaaea0abf296e121d6d0.jpg'),
(102, 8, '9-1-1 S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215646.mp4', 'http://timg.bdta.pro/images/442ee352a81999d3cab4aa445bd5d885.jpg'),
(103, 8, '9-1-1 S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215647.mp4', 'http://timg.bdta.pro/images/9e95deedaecdebf0d0a2d60930fd33f8.jpg'),
(104, 8, '9-1-1 S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215648.mp4', 'http://timg.bdta.pro/images/e03b5219620ea7bb56467e4303fef034.jpg'),
(105, 8, '9-1-1 S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215649.mp4', 'http://timg.bdta.pro/images/89ad2b6cd9c00861bc1a921c196bd97a.jpg'),
(106, 8, '9-1-1 S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215650.mp4', 'http://timg.bdta.pro/images/db8b67bb40ce1cca5e6c3b9b7fd4da58.jpg'),
(107, 8, '9-1-1 S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/215651.mp4', 'http://timg.bdta.pro/images/2ab9fa83e8a697e15ee262606df2a0a0.jpg'),
(108, 8, '9-1-1 S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/215652.mp4', 'http://timg.bdta.pro/images/d77680182909dfde049df0ab8a788555.jpg'),
(109, 9, '9-1-1 S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215653.mp4', 'http://image.tmdb.org/t/p/w1280/rMP25V7qpG1ZbRWOzIHKeQzDTtr.jpg'),
(110, 9, '9-1-1 S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbAsEJTc8XAaoTB6cAfNRjMXH42.jpg'),
(111, 9, '9-1-1 S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6LB4eIjFKBcgIdy64EPMuZBfOGn.jpg'),
(112, 9, '9-1-1 S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215656.mp4', 'http://image.tmdb.org/t/p/w1280/u8kVuNwoDHY4zGXZ2wjmjmc1Qbz.jpg'),
(113, 9, '9-1-1 S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215657.mp4', 'http://image.tmdb.org/t/p/w1280/tvi8241Ur06b9yBG6q5jFD1ZrUg.jpg'),
(114, 9, '9-1-1 S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215658.mp4', 'http://image.tmdb.org/t/p/w1280/j9o80cnGBU8L8Iqt39aoVQSNjvX.jpg'),
(115, 9, '9-1-1 S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215659.mp4', 'http://image.tmdb.org/t/p/w1280/8gVlROoChooLrYEG9hnLzinbFLG.jpg'),
(116, 9, '9-1-1 S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215660.mp4', 'http://image.tmdb.org/t/p/w1280/2M8xPERC62PIpP4Ey1aMSgespcP.jpg'),
(117, 9, '9-1-1 S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215661.mp4', 'http://image.tmdb.org/t/p/w1280/5oCMuLiTbXF64zV5xytOKcseClD.jpg'),
(118, 9, '9-1-1 S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215662.mp4', 'http://image.tmdb.org/t/p/w1280/9YwSGyg0GYjrHEWXw91lO67AUsd.jpg'),
(119, 9, '9-1-1 S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215663.mp4', 'http://image.tmdb.org/t/p/w1280/tHaoUAe2PXvLbJp0zhMaTsskiWI.jpg'),
(120, 9, '9-1-1 S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kZyN7Rtg4daCu45haXfq2VBtIDV.jpg'),
(121, 9, '9-1-1 S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fx79g5K1UcpCVT2kT4j360WVt9k.jpg'),
(122, 9, '9-1-1 S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cHYTofTT9Sw6HniQurRsCLsv8nH.jpg'),
(123, 9, '9-1-1 S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wuz3BQ518q71jrGH8KauhtFxrLN.jpg'),
(124, 9, '9-1-1 S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gnxlduw5Ff8SnYz77ev7jgifwdK.jpg'),
(125, 9, '9-1-1 S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/215669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/utSCwRUCvo8mF0HceRrc7XigZMd.jpg'),
(126, 9, '9-1-1 S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/215670.mp4', 'http://image.tmdb.org/t/p/w1280/ydHHnXfMmbAnz06gAznZHkNp1Gz.jpg'),
(127, 10, '9-1-1 S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/339274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(128, 10, '9-1-1 S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/339276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(129, 10, '9-1-1 S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(130, 10, '9-1-1 S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(131, 10, '9-1-1 S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/378861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(132, 10, '9-1-1 S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/385385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(133, 10, '9-1-1 S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/398284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(134, 10, '9-1-1 S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/398285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(135, 10, '9-1-1 S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/403977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(136, 10, '9-1-1 S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/403978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(137, 11, '9-1-1 S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(138, 11, '9-1-1 S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(139, 11, '9-1-1 S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/516642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(140, 11, '9-1-1 S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/516643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(141, 11, '9-1-1 S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(142, 11, '9-1-1 S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/637584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(143, 11, '9-1-1 S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/660001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(144, 11, '9-1-1 S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/660002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(145, 11, '9-1-1 S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/795432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ri2mNiCANtlc7mQuHrG9vgb4EfF.jpg'),
(146, 11, '9-1-1 S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/795433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9r93aOs3ZZwFN82gXrUC9QdER7q.jpg'),
(147, 11, '9-1-1 S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/795434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2dJh0N3TMs27fy4i9bGRjpDESwI.jpg'),
(148, 11, '9-1-1 S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/795435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ywR3tTt3JCKsZ0aMI9MhzZ4qD8.jpg'),
(149, 11, '9-1-1 S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/814586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(150, 11, '9-1-1 S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/814587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(151, 11, '9-1-1 S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/842286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(152, 11, '9-1-1 S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/842287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(153, 11, '9-1-1 S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/842288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(154, 11, '9-1-1 S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/852168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(155, 12, '9-1-1 S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/894240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(156, 12, '9-1-1 S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/895999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(157, 12, '9-1-1 S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/896000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(158, 12, '9-1-1 S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/897546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/89ZV0IBrNa1EFmivRN6jl0sti1n.jpg'),
(159, 13, 'A Bíblia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cqGupIDrTHosdGTm5N0V4qMrZyf.jpg'),
(160, 13, 'A Bíblia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cqGupIDrTHosdGTm5N0V4qMrZyf.jpg'),
(161, 13, 'A Bíblia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cqGupIDrTHosdGTm5N0V4qMrZyf.jpg'),
(162, 13, 'A Bíblia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cqGupIDrTHosdGTm5N0V4qMrZyf.jpg'),
(163, 13, 'A Bíblia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cqGupIDrTHosdGTm5N0V4qMrZyf.jpg'),
(164, 13, 'A Bíblia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cqGupIDrTHosdGTm5N0V4qMrZyf.jpg'),
(165, 13, 'A Bíblia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cqGupIDrTHosdGTm5N0V4qMrZyf.jpg'),
(166, 13, 'A Bíblia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cqGupIDrTHosdGTm5N0V4qMrZyf.jpg'),
(167, 13, 'A Bíblia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cqGupIDrTHosdGTm5N0V4qMrZyf.jpg'),
(168, 13, 'A Bíblia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cqGupIDrTHosdGTm5N0V4qMrZyf.jpg'),
(169, 14, 'Absentia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128160.mp4', 'http://gstaticontent.com/images/uy236cUbjkG0ncSmNeMz2f2OO9Q_big.jpg'),
(170, 14, 'Absentia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128161.mp4', 'http://gstaticontent.com/images/uy236cUbjkG0ncSmNeMz2f2OO9Q_big.jpg'),
(171, 14, 'Absentia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128162.mp4', 'http://gstaticontent.com/images/uy236cUbjkG0ncSmNeMz2f2OO9Q_big.jpg'),
(172, 14, 'Absentia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128163.mp4', 'http://gstaticontent.com/images/uy236cUbjkG0ncSmNeMz2f2OO9Q_big.jpg'),
(173, 14, 'Absentia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128164.mp4', 'http://gstaticontent.com/images/uy236cUbjkG0ncSmNeMz2f2OO9Q_big.jpg'),
(174, 14, 'Absentia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128165.mp4', 'http://gstaticontent.com/images/uy236cUbjkG0ncSmNeMz2f2OO9Q_big.jpg'),
(175, 14, 'Absentia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128166.mp4', 'http://gstaticontent.com/images/uy236cUbjkG0ncSmNeMz2f2OO9Q_big.jpg'),
(176, 14, 'Absentia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128167.mp4', 'http://gstaticontent.com/images/uy236cUbjkG0ncSmNeMz2f2OO9Q_big.jpg'),
(177, 14, 'Absentia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128168.mp4', 'http://gstaticontent.com/images/uy236cUbjkG0ncSmNeMz2f2OO9Q_big.jpg'),
(178, 14, 'Absentia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128169.mp4', 'http://gstaticontent.com/images/uy236cUbjkG0ncSmNeMz2f2OO9Q_big.jpg'),
(179, 15, 'Absentia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128170.mp4', 'http://timg.bdta.pro/images/cd684a125e40f501320611fbf770277a.jpg'),
(180, 15, 'Absentia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128171.mp4', 'http://timg.bdta.pro/images/2f7742a545575c27c04a33f8592398fd.jpg'),
(181, 15, 'Absentia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128172.mp4', 'http://timg.bdta.pro/images/3ec6bbc898e5cd4c333afd3e93644a7d.jpg'),
(182, 15, 'Absentia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128173.mp4', 'http://timg.bdta.pro/images/9e47ac2138e51e46e8d7fdff23f6f595.jpg'),
(183, 15, 'Absentia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128174.mp4', 'http://timg.bdta.pro/images/5bcd9cdd519adc443ab38ea0669c5f31.jpg'),
(184, 15, 'Absentia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128175.mp4', 'http://timg.bdta.pro/images/fdfefff7c653680d191174e95dacbfe7.jpg'),
(185, 15, 'Absentia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128176.mp4', 'http://timg.bdta.pro/images/8905e5d7bd51d66cabf9fb664cf30277.jpg'),
(186, 15, 'Absentia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128177.mp4', 'http://timg.bdta.pro/images/44d645b9a7850851265172b8ca640873.jpg'),
(187, 15, 'Absentia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128178.mp4', 'http://timg.bdta.pro/images/21c6df6838402906bd94b72c492ffb56.jpg'),
(188, 15, 'Absentia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128179.mp4', 'http://timg.bdta.pro/images/a2dc03ef23a1e1430b7826ac87f6f586.jpg'),
(189, 16, 'Absentia S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128180.mp4', 'http://timg.bdta.pro/images/7afdb8b5d163dd7ba69ebb2f3f4c3aa3.jpg'),
(190, 16, 'Absentia S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128181.mp4', 'http://timg.bdta.pro/images/9b389eb6f2795a6e01689360ed8ba9a1.jpg'),
(191, 16, 'Absentia S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128182.mp4', 'http://timg.bdta.pro/images/f2f10b1565520d947076cf4491ed93e8.jpg'),
(192, 16, 'Absentia S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128183.mp4', 'http://timg.bdta.pro/images/96fdf5c60efbe477fde7c6e572c7001b.jpg'),
(193, 16, 'Absentia S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128184.mp4', 'http://timg.bdta.pro/images/6657d3f7d9ce061307528dd562a74f8f.jpg'),
(194, 16, 'Absentia S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128185.mp4', 'http://timg.bdta.pro/images/ea3c84625656a745608cfc34adbba6b8.jpg'),
(195, 16, 'Absentia S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128186.mp4', 'http://timg.bdta.pro/images/9e5a0313b27aa79271832cb17773f302.jpg'),
(196, 16, 'Absentia S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128187.mp4', 'http://timg.bdta.pro/images/11507299a130513edb9a7039646d2754.jpg'),
(197, 16, 'Absentia S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128188.mp4', 'http://timg.bdta.pro/images/88157d7e6eb0cdc603efc06773780672.jpg'),
(198, 16, 'Absentia S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128189.mp4', 'http://timg.bdta.pro/images/93cd58c43d1dd80dea51a3b9fccee2a2.jpg'),
(199, 17, 'Altered Carbon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/95IsiH4p5937YXQHaOS2W2dWYOG.jpg'),
(200, 17, 'Altered Carbon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/95IsiH4p5937YXQHaOS2W2dWYOG.jpg'),
(201, 17, 'Altered Carbon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/95IsiH4p5937YXQHaOS2W2dWYOG.jpg'),
(202, 17, 'Altered Carbon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/95IsiH4p5937YXQHaOS2W2dWYOG.jpg'),
(203, 17, 'Altered Carbon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/95IsiH4p5937YXQHaOS2W2dWYOG.jpg'),
(204, 17, 'Altered Carbon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/111297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/95IsiH4p5937YXQHaOS2W2dWYOG.jpg'),
(205, 17, 'Altered Carbon S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/111298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/95IsiH4p5937YXQHaOS2W2dWYOG.jpg'),
(206, 17, 'Altered Carbon S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/111299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/95IsiH4p5937YXQHaOS2W2dWYOG.jpg'),
(207, 17, 'Altered Carbon S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/111300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/95IsiH4p5937YXQHaOS2W2dWYOG.jpg'),
(208, 17, 'Altered Carbon S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/111301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/95IsiH4p5937YXQHaOS2W2dWYOG.jpg'),
(209, 18, 'Altered Carbon S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111302.mp4', 'http://timg.bdta.pro/images/05ff72bee9502ac196ab8dcdb9b6d9b0.jpg'),
(210, 18, 'Altered Carbon S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111303.mp4', 'http://timg.bdta.pro/images/730b6faa42bf40996da79405ab466132.jpg'),
(211, 18, 'Altered Carbon S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111304.mp4', 'http://timg.bdta.pro/images/88e0ad4af6f5507a3b32885fe4f9f2d3.jpg'),
(212, 18, 'Altered Carbon S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111305.mp4', 'http://timg.bdta.pro/images/02661c8bf5713d9c95e014b8b0fda198.jpg'),
(213, 18, 'Altered Carbon S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111306.mp4', 'http://timg.bdta.pro/images/125dc84d34955ae5b294c81d3a7f38b8.jpg'),
(214, 18, 'Altered Carbon S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/111307.mp4', 'http://timg.bdta.pro/images/8a78e58f0cc9a970e71be1f5972011b1.jpg'),
(215, 18, 'Altered Carbon S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/111308.mp4', 'http://timg.bdta.pro/images/664645df03a306fb7357498bc4a528e1.jpg'),
(216, 18, 'Altered Carbon S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/111309.mp4', 'http://timg.bdta.pro/images/e424ed6880736ddb83efd01b521c9e28.jpg'),
(217, 19, 'A Maldição da Residência Hill S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102097.mp4', 'http://timg.bdta.pro/images/iyQVb3oOihUkOfkm4tPhpDiVpiu_small.jpg'),
(218, 19, 'A Maldição da Residência Hill S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mQQGdDgn4WpUL9PXssHecWkjfi1.jpg'),
(219, 19, 'A Maldição da Residência Hill S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mQQGdDgn4WpUL9PXssHecWkjfi1.jpg'),
(220, 19, 'A Maldição da Residência Hill S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mQQGdDgn4WpUL9PXssHecWkjfi1.jpg'),
(221, 19, 'A Maldição da Residência Hill S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mQQGdDgn4WpUL9PXssHecWkjfi1.jpg'),
(222, 19, 'A Maldição da Residência Hill S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mQQGdDgn4WpUL9PXssHecWkjfi1.jpg'),
(223, 19, 'A Maldição da Residência Hill S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mQQGdDgn4WpUL9PXssHecWkjfi1.jpg'),
(224, 19, 'A Maldição da Residência Hill S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mQQGdDgn4WpUL9PXssHecWkjfi1.jpg'),
(225, 19, 'A Maldição da Residência Hill S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mQQGdDgn4WpUL9PXssHecWkjfi1.jpg'),
(226, 19, 'A Maldição da Residência Hill S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mQQGdDgn4WpUL9PXssHecWkjfi1.jpg'),
(227, 20, 'American Horror Story S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/605650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(228, 20, 'American Horror Story S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/605651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(229, 20, 'American Horror Story S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/605652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(230, 20, 'American Horror Story S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/605653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(231, 20, 'American Horror Story S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/605654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(232, 20, 'American Horror Story S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/605655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(233, 20, 'American Horror Story S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/605656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(234, 20, 'American Horror Story S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/605657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(235, 20, 'American Horror Story S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/605658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(236, 20, 'American Horror Story S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/605659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(237, 20, 'American Horror Story S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/294618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(238, 20, 'American Horror Story S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/294619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(239, 21, 'American Horror Story S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(240, 21, 'American Horror Story S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(241, 21, 'American Horror Story S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(242, 21, 'American Horror Story S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(243, 21, 'American Horror Story S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(244, 21, 'American Horror Story S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(245, 21, 'American Horror Story S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(246, 21, 'American Horror Story S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(247, 21, 'American Horror Story S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/294628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(248, 21, 'American Horror Story S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/294629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(249, 21, 'American Horror Story S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/294630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(250, 21, 'American Horror Story S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/294631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(251, 21, 'American Horror Story S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/294632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(252, 22, 'American Horror Story S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(253, 22, 'American Horror Story S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(254, 22, 'American Horror Story S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(255, 22, 'American Horror Story S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(256, 22, 'American Horror Story S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(257, 22, 'American Horror Story S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(258, 22, 'American Horror Story S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(259, 22, 'American Horror Story S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(260, 22, 'American Horror Story S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/294641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(261, 22, 'American Horror Story S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/294642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(262, 22, 'American Horror Story S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/294643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(263, 22, 'American Horror Story S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/294644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(264, 22, 'American Horror Story S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/294645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(265, 23, 'American Horror Story S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(266, 23, 'American Horror Story S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(267, 23, 'American Horror Story S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(268, 23, 'American Horror Story S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(269, 23, 'American Horror Story S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(270, 23, 'American Horror Story S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(271, 23, 'American Horror Story S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(272, 23, 'American Horror Story S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(273, 23, 'American Horror Story S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/294654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(274, 23, 'American Horror Story S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/294655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(275, 23, 'American Horror Story S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/294656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(276, 23, 'American Horror Story S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/294657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(277, 23, 'American Horror Story S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/294658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(278, 24, 'American Horror Story S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(279, 24, 'American Horror Story S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(280, 24, 'American Horror Story S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(281, 24, 'American Horror Story S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(282, 24, 'American Horror Story S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(283, 24, 'American Horror Story S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(284, 24, 'American Horror Story S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(285, 24, 'American Horror Story S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(286, 24, 'American Horror Story S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/294667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(287, 24, 'American Horror Story S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/294668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(288, 24, 'American Horror Story S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/294669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(289, 24, 'American Horror Story S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/294670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(290, 25, 'American Horror Story S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(291, 25, 'American Horror Story S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(292, 25, 'American Horror Story S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(293, 25, 'American Horror Story S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(294, 25, 'American Horror Story S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(295, 25, 'American Horror Story S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(296, 25, 'American Horror Story S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(297, 25, 'American Horror Story S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(298, 25, 'American Horror Story S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/294679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(299, 25, 'American Horror Story S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/294680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(300, 26, 'American Horror Story S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(301, 26, 'American Horror Story S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(302, 26, 'American Horror Story S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(303, 26, 'American Horror Story S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(304, 26, 'American Horror Story S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(305, 26, 'American Horror Story S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(306, 26, 'American Horror Story S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(307, 26, 'American Horror Story S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(308, 26, 'American Horror Story S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/294689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(309, 26, 'American Horror Story S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/294690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(310, 26, 'American Horror Story S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/294691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(311, 27, 'American Horror Story S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(312, 27, 'American Horror Story S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(313, 27, 'American Horror Story S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(314, 27, 'American Horror Story S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(315, 27, 'American Horror Story S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(316, 27, 'American Horror Story S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(317, 27, 'American Horror Story S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(318, 27, 'American Horror Story S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(319, 27, 'American Horror Story S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/294700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(320, 27, 'American Horror Story S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/294701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(321, 28, 'American Horror Story S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294702.mp4', 'http://timg.bdta.pro/images/42d3d3e3c153b95ffc2f1d63a41c63f1.jpg'),
(322, 28, 'American Horror Story S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294703.mp4', 'http://timg.bdta.pro/images/22e454646ab2ddd895a71fc2e10a5dd9.jpg'),
(323, 28, 'American Horror Story S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294704.mp4', 'http://timg.bdta.pro/images/1fbc0444c3d1bca33aa5f3c41a293bb6.jpg'),
(324, 28, 'American Horror Story S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294705.mp4', 'http://timg.bdta.pro/images/168fc5c9b6a6c16a23d2f3b13234f2d7.jpg'),
(325, 28, 'American Horror Story S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294706.mp4', 'http://timg.bdta.pro/images/e9688dec11ee7912208410c8f92bc506.jpg'),
(326, 28, 'American Horror Story S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294707.mp4', 'http://timg.bdta.pro/images/2934f0c9ad199ca5510f1bb47ac421e7.jpg'),
(327, 28, 'American Horror Story S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294708.mp4', 'http://timg.bdta.pro/images/2011402d0ccb34a9fec2dcf280a71717.jpg'),
(328, 28, 'American Horror Story S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294709.mp4', 'http://timg.bdta.pro/images/5f8c95453809e2984f7678ce7ccacefa.jpg'),
(329, 28, 'American Horror Story S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/294710.mp4', 'http://timg.bdta.pro/images/deec088644f584cb461c6db789bb47e5.jpg'),
(330, 29, 'American Horror Story S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294711.mp4', 'http://timg.bdta.pro/images/a6b402920725a280f063cff7f4e7e43d.jpg'),
(331, 29, 'American Horror Story S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294712.mp4', 'http://timg.bdta.pro/images/2d5df31304b94f8c1c621de663cbe278.jpg'),
(332, 29, 'American Horror Story S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294713.mp4', 'http://timg.bdta.pro/images/09f600adacc34c304e09ea1c02234d66.jpg'),
(333, 29, 'American Horror Story S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294714.mp4', 'http://timg.bdta.pro/images/23fbe445805ccce6fbd5bf461b5ca684.jpg'),
(334, 29, 'American Horror Story S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294715.mp4', 'http://timg.bdta.pro/images/1159615c71a202ead5fd3f65c5a58a5c.jpg'),
(335, 29, 'American Horror Story S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294716.mp4', 'http://timg.bdta.pro/images/d50b855d099e577e8fe321cbc41a8e7d.jpg'),
(336, 29, 'American Horror Story S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294717.mp4', 'http://timg.bdta.pro/images/6ef5638a9b7761d5b2e1a5eb20b93417.jpg'),
(337, 29, 'American Horror Story S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294718.mp4', 'http://timg.bdta.pro/images/db8ce9ade5c26b47c11d68f9ffc5bd55.jpg'),
(338, 29, 'American Horror Story S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/294719.mp4', 'http://timg.bdta.pro/images/81365838866d72873e89574dbd7a0a5b.jpg'),
(339, 29, 'American Horror Story S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/294720.mp4', 'http://timg.bdta.pro/images/7fedc9d4e8566be08094dc89f26a4ad2.jpg'),
(340, 30, 'American Horror Story S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvLAbzPhFDaNzYXjv0rNKD8IxRc.jpg'),
(341, 30, 'American Horror Story S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cEIirwqNDZWQUsa97CHxwhUHIQW.jpg'),
(342, 30, 'American Horror Story S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1DQqu20g95UIwSvd7UGmyDelG55.jpg'),
(343, 30, 'American Horror Story S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wV8ZxhUyekZWtO0LUy627ivUmLm.jpg'),
(344, 30, 'American Horror Story S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Ngum5JUct9jQDPn3ghUx0xPeSj.jpg'),
(345, 30, 'American Horror Story S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7pfEIhkFqWNVA9Brj1G9zZNCfn.jpg'),
(346, 30, 'American Horror Story S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wTRfn12tv7kkgWXi1fcSbe33YSy.jpg'),
(347, 30, 'American Horror Story S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0ecM7PK0d0IdoVkStBevFOM2Oi.jpg'),
(348, 30, 'American Horror Story S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/294729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1UuRxEdyZekLc2z1bhpUsxl6Dzx.jpg'),
(349, 30, 'American Horror Story S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/294730.mp4', 'http://image.tmdb.org/t/p/w1280/hoheloUjc92pbau2rNjVJxMt0Ty.jpg'),
(350, 31, 'American Horror Story S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(351, 31, 'American Horror Story S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(352, 31, 'American Horror Story S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(353, 31, 'American Horror Story S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(354, 31, 'American Horror Story S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(355, 31, 'American Horror Story S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/387867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(356, 31, 'American Horror Story S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/387868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(357, 31, 'American Horror Story S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/387869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(358, 31, 'American Horror Story S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/387870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/boTaNtSzHHb0uSuLko5lZyDSD58.jpg'),
(359, 32, 'Anne com um \"E\" S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xWdSSB1La6FcXZUuuwvcqvB6Kdf.jpg'),
(360, 32, 'Anne com um \"E\" S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xWdSSB1La6FcXZUuuwvcqvB6Kdf.jpg'),
(361, 32, 'Anne com um \"E\" S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xWdSSB1La6FcXZUuuwvcqvB6Kdf.jpg'),
(362, 32, 'Anne com um \"E\" S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xWdSSB1La6FcXZUuuwvcqvB6Kdf.jpg'),
(363, 32, 'Anne com um \"E\" S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xWdSSB1La6FcXZUuuwvcqvB6Kdf.jpg'),
(364, 32, 'Anne com um \"E\" S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xWdSSB1La6FcXZUuuwvcqvB6Kdf.jpg'),
(365, 32, 'Anne com um \"E\" S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xWdSSB1La6FcXZUuuwvcqvB6Kdf.jpg'),
(366, 33, 'Anne com um \"E\" S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xWdSSB1La6FcXZUuuwvcqvB6Kdf.jpg'),
(367, 33, 'Anne com um \"E\" S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xWdSSB1La6FcXZUuuwvcqvB6Kdf.jpg'),
(368, 33, 'Anne com um \"E\" S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xWdSSB1La6FcXZUuuwvcqvB6Kdf.jpg'),
(369, 33, 'Anne com um \"E\" S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xWdSSB1La6FcXZUuuwvcqvB6Kdf.jpg'),
(370, 33, 'Anne com um \"E\" S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xWdSSB1La6FcXZUuuwvcqvB6Kdf.jpg'),
(371, 33, 'Anne com um \"E\" S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xWdSSB1La6FcXZUuuwvcqvB6Kdf.jpg'),
(372, 33, 'Anne com um \"E\" S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xWdSSB1La6FcXZUuuwvcqvB6Kdf.jpg'),
(373, 33, 'Anne com um \"E\" S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xWdSSB1La6FcXZUuuwvcqvB6Kdf.jpg'),
(374, 33, 'Anne com um \"E\" S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/110517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xWdSSB1La6FcXZUuuwvcqvB6Kdf.jpg'),
(375, 33, 'Anne com um \"E\" S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/110518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xWdSSB1La6FcXZUuuwvcqvB6Kdf.jpg'),
(376, 34, 'Anne com um \"E\" S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110519.mp4', 'http://timg.bdta.pro/images/a1574e6f20c0114a20fe28d91682e7eb.jpg'),
(377, 34, 'Anne com um \"E\" S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110520.mp4', 'http://timg.bdta.pro/images/a6d76ef0459f7fff28fb995355d72b39.jpg'),
(378, 34, 'Anne com um \"E\" S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110521.mp4', 'http://timg.bdta.pro/images/ae5fb5191b12a42ceed0fae2fce29f03.jpg'),
(379, 34, 'Anne com um \"E\" S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110522.mp4', 'http://timg.bdta.pro/images/c002bb03391094c0b52d7ba32de4a303.jpg'),
(380, 34, 'Anne com um \"E\" S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110523.mp4', 'http://timg.bdta.pro/images/d87d6150232f96445a1d89289194065c.jpg'),
(381, 34, 'Anne com um \"E\" S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110524.mp4', 'http://timg.bdta.pro/images/e4a1c1faf3110c8da28c92671d72d962.jpg'),
(382, 34, 'Anne com um \"E\" S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110525.mp4', 'http://timg.bdta.pro/images/7909e12d731a887cd1091075e29fcd3a.jpg'),
(383, 34, 'Anne com um \"E\" S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110526.mp4', 'http://timg.bdta.pro/images/cbd1307ae546429a499b7009acf08f73.jpg'),
(384, 34, 'Anne com um \"E\" S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/110527.mp4', 'http://timg.bdta.pro/images/6241ec976006cb11a9668a5cc9a23f5f.jpg'),
(385, 34, 'Anne com um \"E\" S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/110528.mp4', 'http://timg.bdta.pro/images/567b990f1809c8add254adcaf0767cc9.jpg'),
(386, 35, 'Anos Incríveis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132855.mp4', 'http://timg.bdta.pro/images/a1347994256234eb0cd3f3ff51f8bb4d.jpg'),
(387, 35, 'Anos Incríveis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132856.mp4', 'http://timg.bdta.pro/images/f131be888e64f6263550da8fa0ed83f3.jpg'),
(388, 35, 'Anos Incríveis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132857.mp4', 'http://timg.bdta.pro/images/a74bab03d812f36872046a333b284851.jpg'),
(389, 35, 'Anos Incríveis S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132858.mp4', 'http://timg.bdta.pro/images/7a89c7fe814faa75ddc2e708a87df4cf.jpg'),
(390, 35, 'Anos Incríveis S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132859.mp4', 'http://timg.bdta.pro/images/80f8dcbcab27629ea7c5a2b11079231b.jpg'),
(391, 35, 'Anos Incríveis S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132860.mp4', 'http://timg.bdta.pro/images/6ea7119ea95dcee1456953003be9f2c2.jpg'),
(392, 36, 'Anos Incríveis S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132861.mp4', 'http://timg.bdta.pro/images/3ec3556a79ffa57f01bcad51a8b3f3a0.jpg'),
(393, 36, 'Anos Incríveis S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132862.mp4', 'http://timg.bdta.pro/images/d70bfe54f06f037870d8de299587b0e4.jpg'),
(394, 36, 'Anos Incríveis S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132863.mp4', 'http://timg.bdta.pro/images/a2482aa583d7340219981b544270a445.jpg'),
(395, 36, 'Anos Incríveis S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132864.mp4', 'http://timg.bdta.pro/images/a15961f0fc829fad85cc34868f0da0fe.jpg'),
(396, 36, 'Anos Incríveis S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132865.mp4', 'http://timg.bdta.pro/images/e70f212c7252e502dc5fb54372404536.jpg'),
(397, 36, 'Anos Incríveis S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132866.mp4', 'http://timg.bdta.pro/images/f9544e9a68e5a0e43c36540dcf26cdcd.jpg'),
(398, 36, 'Anos Incríveis S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132867.mp4', 'http://timg.bdta.pro/images/a8c4396278f9a002f8f99f79bd0b48a2.jpg'),
(399, 36, 'Anos Incríveis S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132868.mp4', 'http://timg.bdta.pro/images/1fa658db9aad1b665c6d682698932d9e.jpg'),
(400, 36, 'Anos Incríveis S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132869.mp4', 'http://timg.bdta.pro/images/56d5e602479941191a8959f267b45598.jpg'),
(401, 36, 'Anos Incríveis S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132870.mp4', 'http://timg.bdta.pro/images/19b22c5c4d83f70f61ae550284924733.jpg'),
(402, 36, 'Anos Incríveis S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132871.mp4', 'http://timg.bdta.pro/images/70c1f7da1da08a2ed9df649578da3be6.jpg'),
(403, 36, 'Anos Incríveis S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132872.mp4', 'http://timg.bdta.pro/images/adee18e4f52f2a21756a6f1eef936af4.jpg'),
(404, 36, 'Anos Incríveis S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132873.mp4', 'http://timg.bdta.pro/images/53ecd75b2154d71ecce9de3310386bfd.jpg'),
(405, 36, 'Anos Incríveis S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132874.mp4', 'http://timg.bdta.pro/images/9c1d3ddd79abba3445de6b5aabd8aafd.jpg'),
(406, 36, 'Anos Incríveis S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132875.mp4', 'http://timg.bdta.pro/images/19b2c02f4b4ad980abd02023443fc5fa.jpg'),
(407, 36, 'Anos Incríveis S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132876.mp4', 'http://timg.bdta.pro/images/865b1ebd67e54567111b16c46f5ce459.jpg'),
(408, 36, 'Anos Incríveis S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132877.mp4', 'http://timg.bdta.pro/images/0d9acd30ec517352f846f3234c638ed9.jpg'),
(409, 37, 'Anos Incríveis S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132878.mp4', 'http://timg.bdta.pro/images/e9568b0e44e5b68cf8e15e7ee938ecbe.jpg'),
(410, 37, 'Anos Incríveis S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132879.mp4', 'http://timg.bdta.pro/images/bc17b2ee7b570333efe82779c360393d.jpg'),
(411, 37, 'Anos Incríveis S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132880.mp4', 'http://timg.bdta.pro/images/fa19436996c0bd85038468b682e1c200.jpg'),
(412, 37, 'Anos Incríveis S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132881.mp4', 'http://timg.bdta.pro/images/07084c00265cf7de002f63234ee87a62.jpg'),
(413, 37, 'Anos Incríveis S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132882.mp4', 'http://timg.bdta.pro/images/c21f5359870076f9be45ccfd6f7deaae.jpg'),
(414, 37, 'Anos Incríveis S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132883.mp4', 'http://timg.bdta.pro/images/fc94a55299f8be47f56cf7f1c4b0a2c9.jpg'),
(415, 37, 'Anos Incríveis S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132884.mp4', 'http://timg.bdta.pro/images/f617144ccd55c92240a8678173e0c9fe.jpg'),
(416, 37, 'Anos Incríveis S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132885.mp4', 'http://timg.bdta.pro/images/1ab99fe513cd20a9c20ae4602c7094c1.jpg'),
(417, 37, 'Anos Incríveis S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132886.mp4', 'http://timg.bdta.pro/images/b51e1b05e98e47fc2e6e81d27ce7c1c3.jpg'),
(418, 37, 'Anos Incríveis S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132887.mp4', 'http://timg.bdta.pro/images/0bc84f61b91533fcf14824653e69477a.jpg'),
(419, 37, 'Anos Incríveis S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132888.mp4', 'http://timg.bdta.pro/images/c6588b59303a79810eb236a0a4defe26.jpg'),
(420, 37, 'Anos Incríveis S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132889.mp4', 'http://timg.bdta.pro/images/ce460ea3baa0a8fbafa62dcbfa4c05fe.jpg'),
(421, 37, 'Anos Incríveis S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132890.mp4', 'http://timg.bdta.pro/images/84c85a41f69d42f685c56de82fb86f28.jpg'),
(422, 37, 'Anos Incríveis S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132891.mp4', 'http://timg.bdta.pro/images/d1c8f1892b0d6d36a22f87e61c74464d.jpg'),
(423, 37, 'Anos Incríveis S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132892.mp4', 'http://timg.bdta.pro/images/59ecf34fca7c03a8b0320fe2071891b9.jpg'),
(424, 37, 'Anos Incríveis S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132893.mp4', 'http://timg.bdta.pro/images/a55f7055772e5182e7655269ff9814d8.jpg'),
(425, 37, 'Anos Incríveis S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132894.mp4', 'http://timg.bdta.pro/images/5eb74eae0d7aff21d27a9390782fb935.jpg'),
(426, 37, 'Anos Incríveis S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132895.mp4', 'http://timg.bdta.pro/images/d56d381a30d06b8976a3cdaf813c6ff0.jpg'),
(427, 37, 'Anos Incríveis S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132896.mp4', 'http://timg.bdta.pro/images/a389d20da45451c91a84f95693ffd971.jpg'),
(428, 37, 'Anos Incríveis S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132897.mp4', 'http://timg.bdta.pro/images/eefdac2791d0fce00487a953ed235ce5.jpg'),
(429, 37, 'Anos Incríveis S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132898.mp4', 'http://timg.bdta.pro/images/612fe45e029a4b53007c5afdbd9b6f50.jpg'),
(430, 37, 'Anos Incríveis S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132899.mp4', 'http://timg.bdta.pro/images/eab1532b911b19b54ac94d254d91e578.jpg'),
(431, 37, 'Anos Incríveis S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/132900.mp4', 'http://timg.bdta.pro/images/f12dba2bd4aa6d273ec909caf0cbf4ce.jpg'),
(432, 38, 'Anos Incríveis S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132901.mp4', 'http://timg.bdta.pro/images/65f11142a9b9fe9d46156a4b612e4d78.jpg'),
(433, 38, 'Anos Incríveis S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132902.mp4', 'http://timg.bdta.pro/images/9536b49d88e22a9f16bfb689d37f6dab.jpg'),
(434, 38, 'Anos Incríveis S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132903.mp4', 'http://timg.bdta.pro/images/dee00c73270a5c315662fa59328001c6.jpg'),
(435, 38, 'Anos Incríveis S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132904.mp4', 'http://timg.bdta.pro/images/6be789dad13412d4e89853b57da9a30d.jpg'),
(436, 38, 'Anos Incríveis S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132905.mp4', 'http://timg.bdta.pro/images/461f4d5603aa42874c19d58fcdb3440f.jpg'),
(437, 38, 'Anos Incríveis S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132906.mp4', 'http://timg.bdta.pro/images/0b87ad1ca62855bda314dbf51962285e.jpg'),
(438, 38, 'Anos Incríveis S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132907.mp4', 'http://timg.bdta.pro/images/cb83412b5cce3bd23ec0fefd98fb52a4.jpg'),
(439, 38, 'Anos Incríveis S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132908.mp4', 'http://timg.bdta.pro/images/a0badbc271883047f31ac44569084907.jpg'),
(440, 38, 'Anos Incríveis S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132909.mp4', 'http://timg.bdta.pro/images/9a4dc0880ccd86ccc7a0fd1155019c7a.jpg'),
(441, 38, 'Anos Incríveis S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132910.mp4', 'http://timg.bdta.pro/images/3966feeb611cda9ca53230ca792ef63f.jpg'),
(442, 38, 'Anos Incríveis S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132911.mp4', 'http://timg.bdta.pro/images/8e5714570ad5aee5b221b8f54f126a1b.jpg'),
(443, 38, 'Anos Incríveis S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132912.mp4', 'http://timg.bdta.pro/images/e8440954656bfbbb692dc71bda92c0de.jpg'),
(444, 38, 'Anos Incríveis S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132913.mp4', 'http://timg.bdta.pro/images/7bb079a377141710f06970fef0f2840a.jpg'),
(445, 38, 'Anos Incríveis S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132914.mp4', 'http://timg.bdta.pro/images/636cc3e67d062eb159ae8327c6cdcc94.jpg'),
(446, 38, 'Anos Incríveis S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132915.mp4', 'http://timg.bdta.pro/images/c03f91e4fe65677e1b5461e619c1bc0a.jpg'),
(447, 38, 'Anos Incríveis S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132916.mp4', 'http://timg.bdta.pro/images/fe794dd6e2508cbc0766d61fafd08bb6.jpg'),
(448, 38, 'Anos Incríveis S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132917.mp4', 'http://timg.bdta.pro/images/1d3fbac4f5181dbb179a7b83e7decd08.jpg'),
(449, 38, 'Anos Incríveis S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132918.mp4', 'http://timg.bdta.pro/images/aef5c0139f0017590e3d42ad049abacd.jpg'),
(450, 38, 'Anos Incríveis S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132919.mp4', 'http://timg.bdta.pro/images/ffdd470d4194bfabb3de7031c200014a.jpg'),
(451, 38, 'Anos Incríveis S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132920.mp4', 'http://timg.bdta.pro/images/3cccee28e4c65a47b81c695d6bfc46c3.jpg'),
(452, 38, 'Anos Incríveis S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132921.mp4', 'http://timg.bdta.pro/images/505edfff5fd844c21947452a685ee3c0.jpg'),
(453, 38, 'Anos Incríveis S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132922.mp4', 'http://timg.bdta.pro/images/98f635da9ac1acb89b6d2cad30dc6cfb.jpg'),
(454, 38, 'Anos Incríveis S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/132923.mp4', 'http://timg.bdta.pro/images/e1806541ac6fb7e32280185d171df092.jpg'),
(455, 39, 'Anos Incríveis S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132924.mp4', 'http://timg.bdta.pro/images/97c472761700c8862ec5304d7ab89921.jpg'),
(456, 39, 'Anos Incríveis S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132925.mp4', 'http://timg.bdta.pro/images/b8c74771dd2bd3556ba8e13cdd34d681.jpg'),
(457, 39, 'Anos Incríveis S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132926.mp4', 'http://timg.bdta.pro/images/904ca8feeace70f234e1aacc7da18a3e.jpg'),
(458, 39, 'Anos Incríveis S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132927.mp4', 'http://timg.bdta.pro/images/4794d18bf685602fdc5a6446c571c533.jpg'),
(459, 39, 'Anos Incríveis S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132928.mp4', 'http://timg.bdta.pro/images/a6aa97f898efc76c1eb1ae5c99579fc3.jpg'),
(460, 39, 'Anos Incríveis S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132929.mp4', 'http://timg.bdta.pro/images/fc8b2ad717d293a626a24be04d896620.jpg'),
(461, 39, 'Anos Incríveis S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132930.mp4', 'http://timg.bdta.pro/images/c6bd8e304744ab03308e2cd4d0ab8e6c.jpg'),
(462, 39, 'Anos Incríveis S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132931.mp4', 'http://timg.bdta.pro/images/a4797dd690c2d66c4d648100e3b6cc05.jpg'),
(463, 39, 'Anos Incríveis S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132932.mp4', 'http://timg.bdta.pro/images/43a06df2a019f69a0585431e755a279f.jpg'),
(464, 39, 'Anos Incríveis S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132933.mp4', 'http://timg.bdta.pro/images/5f8f1f995316611967e408a09ca5aa34.jpg'),
(465, 39, 'Anos Incríveis S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132934.mp4', 'http://timg.bdta.pro/images/2b552dbae11baaaa673311a0d8dbb73c.jpg'),
(466, 39, 'Anos Incríveis S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132935.mp4', 'http://timg.bdta.pro/images/0ea871ad5c89acc4db9c91cd96858d34.jpg'),
(467, 39, 'Anos Incríveis S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132936.mp4', 'http://timg.bdta.pro/images/4708673763b5456177e9b84973ef220c.jpg'),
(468, 39, 'Anos Incríveis S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132937.mp4', 'http://timg.bdta.pro/images/ea8b19ae98a7cc364ccd0b47f58bcda1.jpg'),
(469, 39, 'Anos Incríveis S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132938.mp4', 'http://timg.bdta.pro/images/24c3259b99fbe7e91e47ea6efbc613fe.jpg'),
(470, 39, 'Anos Incríveis S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132939.mp4', 'http://timg.bdta.pro/images/6857d4e409774b23de7b54ae554e67b0.jpg'),
(471, 39, 'Anos Incríveis S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132940.mp4', 'http://timg.bdta.pro/images/25dd505fd680a7d33dcea7746465defc.jpg'),
(472, 39, 'Anos Incríveis S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132941.mp4', 'http://timg.bdta.pro/images/294c962ad646d81922125236012317a7.jpg'),
(473, 39, 'Anos Incríveis S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132942.mp4', 'http://timg.bdta.pro/images/17c54f9ff718bb27a4cc4b50c6c3840b.jpg'),
(474, 39, 'Anos Incríveis S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132943.mp4', 'http://timg.bdta.pro/images/33bfcb76b8ed19631edcad6b996d2592.jpg'),
(475, 39, 'Anos Incríveis S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132944.mp4', 'http://timg.bdta.pro/images/bc9af6774eec93e6d76c8eb992807126.jpg'),
(476, 39, 'Anos Incríveis S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132945.mp4', 'http://timg.bdta.pro/images/bc2c550c92ec2e51ca4e6fd69e193a82.jpg'),
(477, 39, 'Anos Incríveis S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/132946.mp4', 'http://timg.bdta.pro/images/e2f020658c8f848a45fc981f729ea81a.jpg'),
(478, 39, 'Anos Incríveis S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/132947.mp4', 'http://timg.bdta.pro/images/8d1e7cf0503c2d24bae4e71713d8943b.jpg'),
(479, 40, 'Anos Incríveis S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132948.mp4', 'http://timg.bdta.pro/images/ba8ea7f11411347c6d826e806e930a83.jpg'),
(480, 40, 'Anos Incríveis S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132949.mp4', 'http://timg.bdta.pro/images/94cf363311a91427cd759d88bd4897ab.jpg'),
(481, 40, 'Anos Incríveis S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132950.mp4', 'http://timg.bdta.pro/images/b52a4824ba321426a9c7e08275cb4c3b.jpg'),
(482, 40, 'Anos Incríveis S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132951.mp4', 'http://timg.bdta.pro/images/cf316865f9a9f532e47ebd6a788c2ed2.jpg'),
(483, 40, 'Anos Incríveis S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132952.mp4', 'http://timg.bdta.pro/images/94a276093f2853b978e63473947fe8cb.jpg'),
(484, 40, 'Anos Incríveis S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132953.mp4', 'http://timg.bdta.pro/images/3fa503a94ee96c468a13a2815aaa1447.jpg'),
(485, 40, 'Anos Incríveis S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132954.mp4', 'http://timg.bdta.pro/images/2ac7280a2e665f1d848a70de4a9b4cad.jpg'),
(486, 40, 'Anos Incríveis S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132955.mp4', 'http://timg.bdta.pro/images/aef1f3db0164a6e75a5812e4cba642d6.jpg'),
(487, 40, 'Anos Incríveis S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132956.mp4', 'http://timg.bdta.pro/images/2aeebc5b6a4e2c64a484b073bfb7a1b0.jpg'),
(488, 40, 'Anos Incríveis S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132957.mp4', 'http://timg.bdta.pro/images/6ef97844226065c7615b7c2b771ce139.jpg'),
(489, 40, 'Anos Incríveis S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132958.mp4', 'http://timg.bdta.pro/images/dbcdcacb42b7a09b78986bddfd73f262.jpg'),
(490, 40, 'Anos Incríveis S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132959.mp4', 'http://timg.bdta.pro/images/625bf1ad3fab7b19c4de998fe65ed71c.jpg'),
(491, 40, 'Anos Incríveis S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132960.mp4', 'http://timg.bdta.pro/images/b6a5977e76a7381903c348caa288a9e4.jpg'),
(492, 40, 'Anos Incríveis S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132961.mp4', 'http://timg.bdta.pro/images/5360ba39813d5b7838753908796aef34.jpg'),
(493, 40, 'Anos Incríveis S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132962.mp4', 'http://timg.bdta.pro/images/0f92ba09606fb6ad993fe7cb861280a8.jpg'),
(494, 40, 'Anos Incríveis S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132963.mp4', 'http://timg.bdta.pro/images/8db2dd6b9fd5844011460f4d8cf9d813.jpg'),
(495, 40, 'Anos Incríveis S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132964.mp4', 'http://timg.bdta.pro/images/36cc57ab726943ffb03e487620dad4bc.jpg'),
(496, 40, 'Anos Incríveis S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132965.mp4', 'http://timg.bdta.pro/images/818dc6516a9b3b82d0c223a5dfb62482.jpg'),
(497, 40, 'Anos Incríveis S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132966.mp4', 'http://timg.bdta.pro/images/526591db757f6d5af0d693bf85097b84.jpg'),
(498, 40, 'Anos Incríveis S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132967.mp4', 'http://timg.bdta.pro/images/0544c4411f9a420a7c52d31c67a9ac4f.jpg'),
(499, 40, 'Anos Incríveis S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132968.mp4', 'http://timg.bdta.pro/images/25081408bdd7dcc9044ca4a8d0a69c75.jpg'),
(500, 40, 'Anos Incríveis S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132969.mp4', 'http://timg.bdta.pro/images/f09d4d3cdb2ebc03414c1590ecc86138.jpg'),
(501, 41, 'Arquivo Morto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(502, 41, 'Arquivo Morto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(503, 41, 'Arquivo Morto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(504, 41, 'Arquivo Morto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(505, 41, 'Arquivo Morto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(506, 41, 'Arquivo Morto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(507, 41, 'Arquivo Morto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(508, 41, 'Arquivo Morto S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(509, 41, 'Arquivo Morto S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(510, 41, 'Arquivo Morto S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(511, 41, 'Arquivo Morto S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(512, 41, 'Arquivo Morto S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(513, 41, 'Arquivo Morto S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(514, 41, 'Arquivo Morto S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(515, 41, 'Arquivo Morto S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(516, 41, 'Arquivo Morto S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(517, 41, 'Arquivo Morto S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(518, 41, 'Arquivo Morto S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(519, 41, 'Arquivo Morto S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(520, 41, 'Arquivo Morto S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/101862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(521, 41, 'Arquivo Morto S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/101863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(522, 41, 'Arquivo Morto S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/101864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(523, 41, 'Arquivo Morto S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/101865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(524, 42, 'Arquivo Morto S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(525, 42, 'Arquivo Morto S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(526, 42, 'Arquivo Morto S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(527, 42, 'Arquivo Morto S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(528, 42, 'Arquivo Morto S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(529, 42, 'Arquivo Morto S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(530, 42, 'Arquivo Morto S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(531, 42, 'Arquivo Morto S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(532, 42, 'Arquivo Morto S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(533, 42, 'Arquivo Morto S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(534, 42, 'Arquivo Morto S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(535, 42, 'Arquivo Morto S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(536, 42, 'Arquivo Morto S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(537, 42, 'Arquivo Morto S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(538, 42, 'Arquivo Morto S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(539, 42, 'Arquivo Morto S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(540, 42, 'Arquivo Morto S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(541, 42, 'Arquivo Morto S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(542, 42, 'Arquivo Morto S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(543, 42, 'Arquivo Morto S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/101885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(544, 42, 'Arquivo Morto S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/101886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(545, 42, 'Arquivo Morto S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/101887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(546, 43, 'Arquivo Morto S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(547, 43, 'Arquivo Morto S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(548, 43, 'Arquivo Morto S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(549, 43, 'Arquivo Morto S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(550, 43, 'Arquivo Morto S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(551, 43, 'Arquivo Morto S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(552, 43, 'Arquivo Morto S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(553, 43, 'Arquivo Morto S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(554, 43, 'Arquivo Morto S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(555, 43, 'Arquivo Morto S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(556, 43, 'Arquivo Morto S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(557, 43, 'Arquivo Morto S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(558, 43, 'Arquivo Morto S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(559, 43, 'Arquivo Morto S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(560, 43, 'Arquivo Morto S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(561, 43, 'Arquivo Morto S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(562, 43, 'Arquivo Morto S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(563, 43, 'Arquivo Morto S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(564, 43, 'Arquivo Morto S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(565, 43, 'Arquivo Morto S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/101907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(566, 43, 'Arquivo Morto S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/101908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(567, 43, 'Arquivo Morto S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/101909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(568, 43, 'Arquivo Morto S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/101910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(569, 44, 'Arquivo Morto S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(570, 44, 'Arquivo Morto S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(571, 44, 'Arquivo Morto S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(572, 44, 'Arquivo Morto S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(573, 44, 'Arquivo Morto S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(574, 44, 'Arquivo Morto S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(575, 44, 'Arquivo Morto S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(576, 44, 'Arquivo Morto S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(577, 44, 'Arquivo Morto S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(578, 44, 'Arquivo Morto S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(579, 44, 'Arquivo Morto S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(580, 44, 'Arquivo Morto S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(581, 44, 'Arquivo Morto S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(582, 44, 'Arquivo Morto S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(583, 44, 'Arquivo Morto S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(584, 44, 'Arquivo Morto S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(585, 44, 'Arquivo Morto S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(586, 44, 'Arquivo Morto S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(587, 44, 'Arquivo Morto S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(588, 44, 'Arquivo Morto S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/101930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(589, 44, 'Arquivo Morto S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/101931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(590, 44, 'Arquivo Morto S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/101932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(591, 44, 'Arquivo Morto S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/101933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(592, 44, 'Arquivo Morto S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/101934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(593, 45, 'Arquivo Morto S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(594, 45, 'Arquivo Morto S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(595, 45, 'Arquivo Morto S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(596, 45, 'Arquivo Morto S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(597, 45, 'Arquivo Morto S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(598, 45, 'Arquivo Morto S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(599, 45, 'Arquivo Morto S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(600, 45, 'Arquivo Morto S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(601, 45, 'Arquivo Morto S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(602, 45, 'Arquivo Morto S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(603, 45, 'Arquivo Morto S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(604, 45, 'Arquivo Morto S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(605, 45, 'Arquivo Morto S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(606, 45, 'Arquivo Morto S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(607, 45, 'Arquivo Morto S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(608, 45, 'Arquivo Morto S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(609, 46, 'Arquivo Morto S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(610, 46, 'Arquivo Morto S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(611, 46, 'Arquivo Morto S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(612, 46, 'Arquivo Morto S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(613, 46, 'Arquivo Morto S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(614, 46, 'Arquivo Morto S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(615, 46, 'Arquivo Morto S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(616, 46, 'Arquivo Morto S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(617, 46, 'Arquivo Morto S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(618, 46, 'Arquivo Morto S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(619, 46, 'Arquivo Morto S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(620, 46, 'Arquivo Morto S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(621, 46, 'Arquivo Morto S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(622, 46, 'Arquivo Morto S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(623, 46, 'Arquivo Morto S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(624, 46, 'Arquivo Morto S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(625, 46, 'Arquivo Morto S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(626, 46, 'Arquivo Morto S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(627, 46, 'Arquivo Morto S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(628, 46, 'Arquivo Morto S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/101970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(629, 46, 'Arquivo Morto S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/101971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(630, 46, 'Arquivo Morto S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/101972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(631, 46, 'Arquivo Morto S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/101973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(632, 47, 'Arquivo Morto S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(633, 47, 'Arquivo Morto S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(634, 47, 'Arquivo Morto S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(635, 47, 'Arquivo Morto S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(636, 47, 'Arquivo Morto S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(637, 47, 'Arquivo Morto S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(638, 47, 'Arquivo Morto S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(639, 47, 'Arquivo Morto S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(640, 47, 'Arquivo Morto S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(641, 47, 'Arquivo Morto S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(642, 47, 'Arquivo Morto S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(643, 47, 'Arquivo Morto S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(644, 47, 'Arquivo Morto S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(645, 47, 'Arquivo Morto S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(646, 47, 'Arquivo Morto S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(647, 47, 'Arquivo Morto S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(648, 47, 'Arquivo Morto S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(649, 47, 'Arquivo Morto S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(650, 47, 'Arquivo Morto S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(651, 47, 'Arquivo Morto S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/101993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(652, 47, 'Arquivo Morto S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/101994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(653, 47, 'Arquivo Morto S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/101995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WPgmTXqotx7fhULhKqzPp6DX1k.jpg'),
(654, 48, 'A Sete Palmos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(655, 48, 'A Sete Palmos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(656, 48, 'A Sete Palmos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(657, 48, 'A Sete Palmos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(658, 48, 'A Sete Palmos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(659, 48, 'A Sete Palmos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(660, 48, 'A Sete Palmos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(661, 48, 'A Sete Palmos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(662, 48, 'A Sete Palmos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(663, 48, 'A Sete Palmos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(664, 48, 'A Sete Palmos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(665, 48, 'A Sete Palmos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(666, 48, 'A Sete Palmos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(667, 49, 'A Sete Palmos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(668, 49, 'A Sete Palmos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(669, 49, 'A Sete Palmos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(670, 49, 'A Sete Palmos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(671, 49, 'A Sete Palmos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(672, 49, 'A Sete Palmos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(673, 49, 'A Sete Palmos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(674, 49, 'A Sete Palmos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(675, 49, 'A Sete Palmos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(676, 49, 'A Sete Palmos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(677, 49, 'A Sete Palmos S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(678, 49, 'A Sete Palmos S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(679, 49, 'A Sete Palmos S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(680, 50, 'A Sete Palmos S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(681, 50, 'A Sete Palmos S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(682, 50, 'A Sete Palmos S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(683, 50, 'A Sete Palmos S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(684, 50, 'A Sete Palmos S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(685, 50, 'A Sete Palmos S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(686, 50, 'A Sete Palmos S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(687, 50, 'A Sete Palmos S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(688, 50, 'A Sete Palmos S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(689, 50, 'A Sete Palmos S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(690, 50, 'A Sete Palmos S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(691, 50, 'A Sete Palmos S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(692, 50, 'A Sete Palmos S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(693, 51, 'A Sete Palmos S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(694, 51, 'A Sete Palmos S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(695, 51, 'A Sete Palmos S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(696, 51, 'A Sete Palmos S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(697, 51, 'A Sete Palmos S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(698, 51, 'A Sete Palmos S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(699, 51, 'A Sete Palmos S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(700, 51, 'A Sete Palmos S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(701, 51, 'A Sete Palmos S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(702, 51, 'A Sete Palmos S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(703, 51, 'A Sete Palmos S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(704, 51, 'A Sete Palmos S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(705, 52, 'A Sete Palmos S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(706, 52, 'A Sete Palmos S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(707, 52, 'A Sete Palmos S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(708, 52, 'A Sete Palmos S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(709, 52, 'A Sete Palmos S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(710, 52, 'A Sete Palmos S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(711, 52, 'A Sete Palmos S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(712, 52, 'A Sete Palmos S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(713, 52, 'A Sete Palmos S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(714, 52, 'A Sete Palmos S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(715, 52, 'A Sete Palmos S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(716, 52, 'A Sete Palmos S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnMnw15ZOrCjWLx1ErtX1o7vuC.jpg'),
(717, 53, 'Assédio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/flsnAzBLLV9IZ4tA0aT2QuJorVe.jpg'),
(718, 53, 'Assédio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/flsnAzBLLV9IZ4tA0aT2QuJorVe.jpg'),
(719, 53, 'Assédio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/flsnAzBLLV9IZ4tA0aT2QuJorVe.jpg'),
(720, 53, 'Assédio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/flsnAzBLLV9IZ4tA0aT2QuJorVe.jpg'),
(721, 53, 'Assédio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/flsnAzBLLV9IZ4tA0aT2QuJorVe.jpg'),
(722, 53, 'Assédio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/flsnAzBLLV9IZ4tA0aT2QuJorVe.jpg'),
(723, 53, 'Assédio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/flsnAzBLLV9IZ4tA0aT2QuJorVe.jpg'),
(724, 53, 'Assédio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/flsnAzBLLV9IZ4tA0aT2QuJorVe.jpg'),
(725, 53, 'Assédio S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/flsnAzBLLV9IZ4tA0aT2QuJorVe.jpg'),
(726, 53, 'Assédio S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/flsnAzBLLV9IZ4tA0aT2QuJorVe.jpg'),
(727, 54, 'A Vida Secreta dos Casais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r96MKTqGlX5qEg3CZpx9bMXpDYU.jpg'),
(728, 54, 'A Vida Secreta dos Casais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r96MKTqGlX5qEg3CZpx9bMXpDYU.jpg'),
(729, 54, 'A Vida Secreta dos Casais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r96MKTqGlX5qEg3CZpx9bMXpDYU.jpg'),
(730, 54, 'A Vida Secreta dos Casais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r96MKTqGlX5qEg3CZpx9bMXpDYU.jpg'),
(731, 54, 'A Vida Secreta dos Casais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r96MKTqGlX5qEg3CZpx9bMXpDYU.jpg'),
(732, 54, 'A Vida Secreta dos Casais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r96MKTqGlX5qEg3CZpx9bMXpDYU.jpg'),
(733, 54, 'A Vida Secreta dos Casais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r96MKTqGlX5qEg3CZpx9bMXpDYU.jpg'),
(734, 54, 'A Vida Secreta dos Casais S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r96MKTqGlX5qEg3CZpx9bMXpDYU.jpg'),
(735, 54, 'A Vida Secreta dos Casais S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r96MKTqGlX5qEg3CZpx9bMXpDYU.jpg'),
(736, 54, 'A Vida Secreta dos Casais S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r96MKTqGlX5qEg3CZpx9bMXpDYU.jpg'),
(737, 54, 'A Vida Secreta dos Casais S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r96MKTqGlX5qEg3CZpx9bMXpDYU.jpg'),
(738, 54, 'A Vida Secreta dos Casais S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r96MKTqGlX5qEg3CZpx9bMXpDYU.jpg'),
(739, 55, 'Ballers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/525606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(740, 55, 'Ballers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/525608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(741, 55, 'Ballers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/525610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(742, 55, 'Ballers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/525612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(743, 55, 'Ballers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/525614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(744, 55, 'Ballers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/525616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(745, 55, 'Ballers S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/525618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(746, 55, 'Ballers S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/525620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(747, 55, 'Ballers S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/525622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(748, 55, 'Ballers S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/525624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(749, 56, 'Ballers S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/525626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(750, 56, 'Ballers S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/525628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(751, 56, 'Ballers S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/525630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(752, 56, 'Ballers S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/525632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(753, 56, 'Ballers S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/525634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(754, 56, 'Ballers S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/525636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(755, 56, 'Ballers S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/525638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(756, 56, 'Ballers S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/525640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(757, 56, 'Ballers S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/525642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(758, 56, 'Ballers S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/525644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(759, 57, 'Ballers S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/525646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(760, 57, 'Ballers S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/525648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(761, 57, 'Ballers S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/525650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(762, 57, 'Ballers S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/525652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(763, 57, 'Ballers S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/525654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(764, 57, 'Ballers S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/525656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(765, 57, 'Ballers S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(766, 57, 'Ballers S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(767, 57, 'Ballers S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(768, 57, 'Ballers S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(769, 58, 'Ballers S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(770, 58, 'Ballers S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(771, 58, 'Ballers S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(772, 58, 'Ballers S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(773, 58, 'Ballers S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(774, 58, 'Ballers S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(775, 58, 'Ballers S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(776, 58, 'Ballers S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(777, 58, 'Ballers S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(778, 59, 'Ballers S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(779, 59, 'Ballers S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(780, 59, 'Ballers S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WyIazPyjmcFMC42nWEpI0jr56x.jpg'),
(781, 59, 'Ballers S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107305.mp4', 'http://timg.bdta.pro/images/6933db36a2606bbd796e4d18beacdf1a.jpg'),
(782, 59, 'Ballers S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107306.mp4', 'http://timg.bdta.pro/images/2b767a3edd788defaf536bccb952d4e9.jpg'),
(783, 59, 'Ballers S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107307.mp4', 'http://timg.bdta.pro/images/d0da671a7b97c4f29d604bff3aa9c9c2.jpg'),
(784, 59, 'Ballers S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107308.mp4', 'http://timg.bdta.pro/images/fbba69bcd59c6e1fd7491c09881381ca.jpg'),
(785, 59, 'Ballers S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107309.mp4', 'http://timg.bdta.pro/images/96ede68baa05019268330e7889b779d2.jpg'),
(786, 60, 'Irmãos de Guerra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108774.mp4', 'http://timg.bdta.pro/images/030461e70e61476e84a6780790528038.jpg'),
(787, 60, 'Irmãos de Guerra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108775.mp4', 'http://timg.bdta.pro/images/bbb31a053d454a87c5b0a9cf48280429.jpg'),
(788, 60, 'Irmãos de Guerra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108776.mp4', 'http://timg.bdta.pro/images/eef17f699ce9b90ce28c67545ed235cb.jpg'),
(789, 60, 'Irmãos de Guerra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108777.mp4', 'http://timg.bdta.pro/images/4b3805ba3599df81eafab091315a3378.jpg'),
(790, 60, 'Irmãos de Guerra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aem75qxtYRdeimUCwZh75OvVFZZ.jpg'),
(791, 60, 'Irmãos de Guerra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108779.mp4', 'http://timg.bdta.pro/images/2cbeecfd19a508470aa107c9b52d68a9.jpg'),
(792, 60, 'Irmãos de Guerra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108780.mp4', 'http://timg.bdta.pro/images/dab83eda2fbfda62108dd12c8c76b947.jpg'),
(793, 60, 'Irmãos de Guerra S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108781.mp4', 'http://timg.bdta.pro/images/ccd3d03aaea5f54e5ac84a0559bb522f.jpg'),
(794, 60, 'Irmãos de Guerra S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108782.mp4', 'http://timg.bdta.pro/images/af9e1254ba805314918d0b0d1bfcf3c6.jpg'),
(795, 60, 'Irmãos de Guerra S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108783.mp4', 'http://timg.bdta.pro/images/d2221199f01eea82e857bbd83d5cbd56.jpg'),
(796, 61, 'Motel Bates S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(797, 61, 'Motel Bates S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(798, 61, 'Motel Bates S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(799, 61, 'Motel Bates S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(800, 61, 'Motel Bates S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(801, 61, 'Motel Bates S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(802, 61, 'Motel Bates S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(803, 61, 'Motel Bates S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(804, 61, 'Motel Bates S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(805, 61, 'Motel Bates S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(806, 62, 'Motel Bates S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(807, 62, 'Motel Bates S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(808, 62, 'Motel Bates S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(809, 62, 'Motel Bates S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(810, 62, 'Motel Bates S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(811, 62, 'Motel Bates S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(812, 62, 'Motel Bates S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(813, 62, 'Motel Bates S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(814, 62, 'Motel Bates S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(815, 62, 'Motel Bates S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(816, 63, 'Motel Bates S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(817, 63, 'Motel Bates S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(818, 63, 'Motel Bates S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(819, 63, 'Motel Bates S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(820, 63, 'Motel Bates S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(821, 63, 'Motel Bates S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(822, 63, 'Motel Bates S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(823, 63, 'Motel Bates S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(824, 63, 'Motel Bates S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(825, 63, 'Motel Bates S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(826, 64, 'Motel Bates S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(827, 64, 'Motel Bates S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(828, 64, 'Motel Bates S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(829, 64, 'Motel Bates S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(830, 64, 'Motel Bates S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(831, 64, 'Motel Bates S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(832, 64, 'Motel Bates S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(833, 64, 'Motel Bates S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(834, 64, 'Motel Bates S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(835, 64, 'Motel Bates S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(836, 65, 'Motel Bates S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(837, 65, 'Motel Bates S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(838, 65, 'Motel Bates S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(839, 65, 'Motel Bates S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(840, 65, 'Motel Bates S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(841, 65, 'Motel Bates S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(842, 65, 'Motel Bates S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(843, 65, 'Motel Bates S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(844, 65, 'Motel Bates S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(845, 65, 'Motel Bates S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXKcfZE7ulYxgjjYv51s0zDG69s.jpg'),
(846, 66, 'Better Call Saul S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(847, 66, 'Better Call Saul S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(848, 66, 'Better Call Saul S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(849, 66, 'Better Call Saul S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(850, 66, 'Better Call Saul S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(851, 66, 'Better Call Saul S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(852, 66, 'Better Call Saul S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(853, 66, 'Better Call Saul S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(854, 66, 'Better Call Saul S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(855, 66, 'Better Call Saul S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(856, 67, 'Better Call Saul S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(857, 67, 'Better Call Saul S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(858, 67, 'Better Call Saul S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(859, 67, 'Better Call Saul S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(860, 67, 'Better Call Saul S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(861, 67, 'Better Call Saul S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(862, 67, 'Better Call Saul S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(863, 67, 'Better Call Saul S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(864, 67, 'Better Call Saul S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(865, 67, 'Better Call Saul S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(866, 68, 'Better Call Saul S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(867, 68, 'Better Call Saul S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(868, 68, 'Better Call Saul S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(869, 68, 'Better Call Saul S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(870, 68, 'Better Call Saul S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(871, 68, 'Better Call Saul S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(872, 68, 'Better Call Saul S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(873, 68, 'Better Call Saul S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(874, 68, 'Better Call Saul S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(875, 68, 'Better Call Saul S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(876, 69, 'Better Call Saul S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(877, 69, 'Better Call Saul S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(878, 69, 'Better Call Saul S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(879, 69, 'Better Call Saul S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(880, 69, 'Better Call Saul S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(881, 69, 'Better Call Saul S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(882, 69, 'Better Call Saul S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(883, 69, 'Better Call Saul S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(884, 69, 'Better Call Saul S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(885, 69, 'Better Call Saul S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4g3UBFRKrA3Iq3wilqHhAIpQdTN.jpg'),
(886, 70, 'Better Call Saul S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195606.mp4', 'http://timg.bdta.pro/images/19840ed84bfdbab3e034875317628eba.jpg'),
(887, 70, 'Better Call Saul S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195607.mp4', 'http://timg.bdta.pro/images/ecf1b6befa1d949250c91f330faaa396.jpg'),
(888, 70, 'Better Call Saul S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195608.mp4', 'http://timg.bdta.pro/images/70fabab752da29c30407b9a2b458228a.jpg'),
(889, 70, 'Better Call Saul S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195609.mp4', 'http://timg.bdta.pro/images/e28c8491e7cd1d6cd02d785482bdb478.jpg'),
(890, 70, 'Better Call Saul S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195610.mp4', 'http://timg.bdta.pro/images/291c6b49b1cb272dcb6c4973127fc1d5.jpg'),
(891, 70, 'Better Call Saul S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195611.mp4', 'http://timg.bdta.pro/images/87ad200d35995c576e5d33bd11cf551f.jpg'),
(892, 70, 'Better Call Saul S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195612.mp4', 'http://timg.bdta.pro/images/70b3e2c8ab793cdba28c4125c01e05f4.jpg'),
(893, 70, 'Better Call Saul S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195613.mp4', 'http://timg.bdta.pro/images/6f583c559dd098e7b3a4018016e016bd.jpg'),
(894, 70, 'Better Call Saul S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195614.mp4', 'http://timg.bdta.pro/images/bd6c1778e795382d82bac578294c349d.jpg'),
(895, 70, 'Better Call Saul S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195615.mp4', 'http://timg.bdta.pro/images/92feaedf76414957907e1b0ec89f4983.jpg'),
(896, 71, 'Better Call Saul S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195616.mp4', 'http://timg.bdta.pro/images/cda6d487e649ed75dc1f87d014c956e7.jpg'),
(897, 71, 'Better Call Saul S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195617.mp4', 'http://timg.bdta.pro/images/dee9b65805a87b841d7e28b3bc2c2a20.jpg'),
(898, 71, 'Better Call Saul S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195618.mp4', 'http://timg.bdta.pro/images/1ae1178b594abb7b77a685a67319d37a.jpg'),
(899, 71, 'Better Call Saul S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195619.mp4', 'http://timg.bdta.pro/images/b5ab0dcc873714cbabd03a77a476dc02.jpg'),
(900, 71, 'Better Call Saul S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195620.mp4', 'http://timg.bdta.pro/images/1fbdbfee99c9d13ebdf829c8ef415fcc.jpg'),
(901, 71, 'Better Call Saul S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195621.mp4', 'http://timg.bdta.pro/images/ea65d6db4cf9d0912a94f97de700a68c.jpg'),
(902, 71, 'Better Call Saul S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195622.mp4', 'http://timg.bdta.pro/images/cf857b6194b5afce41e8dc70514ffb53.jpg'),
(903, 71, 'Better Call Saul S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195623.mp4', 'http://timg.bdta.pro/images/685c32724e1c39953e09d8ea56ffaf2b.jpg'),
(904, 71, 'Better Call Saul S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195624.mp4', 'http://timg.bdta.pro/images/1a00b0ef99181679da0b68511f288f6e.jpg'),
(905, 71, 'Better Call Saul S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195625.mp4', 'http://timg.bdta.pro/images/08435742bb5a0fafb730e1d6e0c5448a.jpg'),
(906, 71, 'Better Call Saul S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/195626.mp4', 'http://timg.bdta.pro/images/4dba85b1af59b2ac26ddfadfb95ccf04.jpg'),
(907, 71, 'Better Call Saul S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/195627.mp4', 'http://timg.bdta.pro/images/40131a1c7f3137faf8d52a34ffe817b4.jpg'),
(908, 71, 'Better Call Saul S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/195628.mp4', 'http://timg.bdta.pro/images/f42a4c246f159985aa37b8b4f15b13c6.jpg'),
(909, 72, 'Black Mirror S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221199.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(910, 72, 'Black Mirror S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221200.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(911, 72, 'Black Mirror S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221201.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(912, 73, 'Black Mirror S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221202.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(913, 73, 'Black Mirror S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221203.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(914, 73, 'Black Mirror S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221204.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(915, 73, 'Black Mirror S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221205.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(916, 74, 'Black Mirror S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221206.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(917, 74, 'Black Mirror S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221207.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(918, 74, 'Black Mirror S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221208.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(919, 74, 'Black Mirror S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221209.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(920, 74, 'Black Mirror S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221210.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(921, 74, 'Black Mirror S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221211.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(922, 75, 'Black Mirror S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221212.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(923, 75, 'Black Mirror S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221213.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(924, 75, 'Black Mirror S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221214.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(925, 75, 'Black Mirror S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221215.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(926, 75, 'Black Mirror S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221216.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(927, 75, 'Black Mirror S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221217.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(928, 76, 'Black Mirror S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221218.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(929, 76, 'Black Mirror S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221219.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(930, 76, 'Black Mirror S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221220.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(931, 77, 'Black Mirror S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhAE0pi0EC125Gv3TZUCn5EqxSh.jpg'),
(932, 77, 'Black Mirror S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dA9ZWi2Q172vYUVxhKPTarJeDLj.jpg'),
(933, 77, 'Black Mirror S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1I3oE47FZwSuQWYP02d9rSCaQpq.jpg'),
(934, 77, 'Black Mirror S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xqE7NQ29n02W20bOcMa2daj1Gco.jpg'),
(935, 77, 'Black Mirror S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6lGVCSv4DfQqgjqauSxM4HmfvKS.jpg'),
(936, 78, 'Black Mirror S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/768566.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(937, 78, 'Black Mirror S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/768567.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(938, 78, 'Black Mirror S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/768568.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(939, 78, 'Black Mirror S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/768569.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(940, 78, 'Black Mirror S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/768570.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(941, 78, 'Black Mirror S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/768571.mp4', 'http://gstaticontent.com/images/7PRddO7z7mcPi21nZTCMGShAyy1_big.jpg'),
(942, 79, 'Ponto Cego S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130997.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(943, 79, 'Ponto Cego S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130998.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(944, 79, 'Ponto Cego S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130999.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(945, 79, 'Ponto Cego S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131000.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(946, 79, 'Ponto Cego S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131001.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(947, 79, 'Ponto Cego S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131002.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(948, 79, 'Ponto Cego S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131003.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(949, 79, 'Ponto Cego S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131004.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(950, 79, 'Ponto Cego S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131005.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(951, 79, 'Ponto Cego S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131006.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(952, 79, 'Ponto Cego S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131007.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(953, 79, 'Ponto Cego S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131008.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(954, 79, 'Ponto Cego S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131009.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(955, 79, 'Ponto Cego S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131010.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(956, 79, 'Ponto Cego S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131011.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(957, 79, 'Ponto Cego S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/131012.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(958, 79, 'Ponto Cego S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/131013.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(959, 79, 'Ponto Cego S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/131014.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(960, 79, 'Ponto Cego S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/131015.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(961, 79, 'Ponto Cego S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/131016.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(962, 79, 'Ponto Cego S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/131017.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(963, 79, 'Ponto Cego S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/131018.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(964, 79, 'Ponto Cego S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/131019.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(965, 80, 'Ponto Cego S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131020.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(966, 80, 'Ponto Cego S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131021.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(967, 80, 'Ponto Cego S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131022.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(968, 80, 'Ponto Cego S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131023.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(969, 80, 'Ponto Cego S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131024.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(970, 80, 'Ponto Cego S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131025.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(971, 80, 'Ponto Cego S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131026.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(972, 80, 'Ponto Cego S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131027.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(973, 80, 'Ponto Cego S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131028.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(974, 80, 'Ponto Cego S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131029.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(975, 80, 'Ponto Cego S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131030.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(976, 80, 'Ponto Cego S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131031.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(977, 80, 'Ponto Cego S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131032.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(978, 80, 'Ponto Cego S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131033.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(979, 80, 'Ponto Cego S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131034.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(980, 80, 'Ponto Cego S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/131035.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(981, 80, 'Ponto Cego S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/131036.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(982, 80, 'Ponto Cego S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/131037.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(983, 80, 'Ponto Cego S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/131038.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(984, 80, 'Ponto Cego S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/131039.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(985, 80, 'Ponto Cego S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/131040.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(986, 80, 'Ponto Cego S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/131041.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(987, 81, 'Ponto Cego S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131042.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(988, 81, 'Ponto Cego S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131043.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(989, 81, 'Ponto Cego S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131044.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(990, 81, 'Ponto Cego S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131045.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(991, 81, 'Ponto Cego S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131046.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(992, 81, 'Ponto Cego S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131047.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(993, 81, 'Ponto Cego S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131048.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(994, 81, 'Ponto Cego S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131049.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(995, 81, 'Ponto Cego S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131050.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(996, 81, 'Ponto Cego S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131051.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(997, 81, 'Ponto Cego S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131052.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(998, 81, 'Ponto Cego S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131053.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(999, 81, 'Ponto Cego S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131054.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(1000, 81, 'Ponto Cego S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131055.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(1001, 81, 'Ponto Cego S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131056.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(1002, 81, 'Ponto Cego S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/131057.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(1003, 81, 'Ponto Cego S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/131058.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(1004, 81, 'Ponto Cego S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/131059.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(1005, 81, 'Ponto Cego S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/131060.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(1006, 81, 'Ponto Cego S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/131061.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(1007, 81, 'Ponto Cego S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/131062.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(1008, 81, 'Ponto Cego S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/131063.mp4', 'http://timg.bdta.pro/images/xuhfWK2MsOfSGcVU8FSvjUZ49Ga_small.jpg'),
(1009, 82, 'Ponto Cego S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131064.mp4', 'http://timg.bdta.pro/images/0f71f07591788c132d391e231ff0c98c.jpg'),
(1010, 82, 'Ponto Cego S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131065.mp4', 'http://timg.bdta.pro/images/89e2519c1b3ad441f25e5cdfefa58386.jpg'),
(1011, 82, 'Ponto Cego S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131066.mp4', 'http://timg.bdta.pro/images/1b43263d55c3f086781ac32a3c08e027.jpg'),
(1012, 82, 'Ponto Cego S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131067.mp4', 'http://timg.bdta.pro/images/cd6e0aeafc323e002afd389933ef50c5.jpg'),
(1013, 82, 'Ponto Cego S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131068.mp4', 'http://timg.bdta.pro/images/4971763d4b55c0843a00f0e8306c246a.jpg'),
(1014, 82, 'Ponto Cego S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131069.mp4', 'http://timg.bdta.pro/images/31f421cb3c290074d04ece589481e0cc.jpg'),
(1015, 82, 'Ponto Cego S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131070.mp4', 'http://timg.bdta.pro/images/dc7d905b30fc8b9976d63444dff13581.jpg'),
(1016, 82, 'Ponto Cego S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131071.mp4', 'http://timg.bdta.pro/images/f4c52bbd1dd35b32fb4c0d667d1fe25f.jpg'),
(1017, 82, 'Ponto Cego S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131072.mp4', 'http://timg.bdta.pro/images/8528251c2c28605a1c0c90f71fb5c1ea.jpg'),
(1018, 82, 'Ponto Cego S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131073.mp4', 'http://timg.bdta.pro/images/32e5c06a7a1037ba7a11416f3fc5cc57.jpg'),
(1019, 82, 'Ponto Cego S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131074.mp4', 'http://timg.bdta.pro/images/1f78a225f9cb8445ef176417297ea6e9.jpg'),
(1020, 82, 'Ponto Cego S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131075.mp4', 'http://timg.bdta.pro/images/2bab3e1ebfd50f8c6505e3801d879818.jpg'),
(1021, 82, 'Ponto Cego S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131076.mp4', 'http://timg.bdta.pro/images/c11f399be7cf65a8c855f024bf0ff805.jpg'),
(1022, 82, 'Ponto Cego S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131077.mp4', 'http://timg.bdta.pro/images/66ec37f3aa0257d7b7718bbffb720388.jpg'),
(1023, 82, 'Ponto Cego S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131078.mp4', 'http://timg.bdta.pro/images/cb6e41dcbcf3c9e6e5aa211391c927d8.jpg'),
(1024, 82, 'Ponto Cego S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/131079.mp4', 'http://timg.bdta.pro/images/eae46a3982501e51e278b7500c93d70d.jpg'),
(1025, 82, 'Ponto Cego S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/131080.mp4', 'http://timg.bdta.pro/images/30893f06b5b5dedf14506b71c26b85fa.jpg'),
(1026, 82, 'Ponto Cego S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/131081.mp4', 'http://timg.bdta.pro/images/288a078941ad467df07fbd3f44cf8e69.jpg'),
(1027, 82, 'Ponto Cego S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/131082.mp4', 'http://timg.bdta.pro/images/7c88458c7760c7900d0a065eed835327.jpg'),
(1028, 82, 'Ponto Cego S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/131083.mp4', 'http://timg.bdta.pro/images/d6077e3c32b4c26148621b64993828d4.jpg'),
(1029, 82, 'Ponto Cego S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/131084.mp4', 'http://timg.bdta.pro/images/67c5348c36b5332553b6c83798a30aa2.jpg'),
(1030, 82, 'Ponto Cego S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/131085.mp4', 'http://timg.bdta.pro/images/1d520221c897ff7c08ba059723532e89.jpg'),
(1031, 83, 'Ponto Cego S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131086.mp4', 'http://timg.bdta.pro/images/d7c00fbdd879e410bb04ddf16f83ea37.jpg'),
(1032, 83, 'Ponto Cego S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131087.mp4', 'http://timg.bdta.pro/images/692ff21a87e2c8411e0d42348333409c.jpg'),
(1033, 83, 'Ponto Cego S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131088.mp4', 'http://timg.bdta.pro/images/1dbc0eb27a1fa2cd5bb28dfa2d0b86f1.jpg'),
(1034, 83, 'Ponto Cego S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131089.mp4', 'http://timg.bdta.pro/images/032a599c6651275ecaebc69682bdf7fe.jpg'),
(1035, 83, 'Ponto Cego S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131090.mp4', 'http://timg.bdta.pro/images/b5d0a71d8ee229dc3bc83c308526c56c.jpg'),
(1036, 83, 'Ponto Cego S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131091.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(1037, 83, 'Ponto Cego S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131092.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(1038, 83, 'Ponto Cego S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131093.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(1039, 83, 'Ponto Cego S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131094.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(1040, 83, 'Ponto Cego S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131095.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(1041, 83, 'Ponto Cego S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131096.mp4', 'http://gstaticontent.com/images/pYyKZZlb3nd5ASbiuIxva718bp2_big.jpg'),
(1042, 84, 'Boardwalk Empire: O Império do Contrabando S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1043, 84, 'Boardwalk Empire: O Império do Contrabando S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1044, 84, 'Boardwalk Empire: O Império do Contrabando S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1045, 84, 'Boardwalk Empire: O Império do Contrabando S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1046, 84, 'Boardwalk Empire: O Império do Contrabando S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1047, 84, 'Boardwalk Empire: O Império do Contrabando S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1048, 84, 'Boardwalk Empire: O Império do Contrabando S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1049, 84, 'Boardwalk Empire: O Império do Contrabando S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1050, 84, 'Boardwalk Empire: O Império do Contrabando S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1051, 84, 'Boardwalk Empire: O Império do Contrabando S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1052, 84, 'Boardwalk Empire: O Império do Contrabando S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1053, 84, 'Boardwalk Empire: O Império do Contrabando S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1054, 85, 'Boardwalk Empire: O Império do Contrabando S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1055, 85, 'Boardwalk Empire: O Império do Contrabando S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1056, 85, 'Boardwalk Empire: O Império do Contrabando S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1057, 85, 'Boardwalk Empire: O Império do Contrabando S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1058, 85, 'Boardwalk Empire: O Império do Contrabando S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1059, 85, 'Boardwalk Empire: O Império do Contrabando S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1060, 85, 'Boardwalk Empire: O Império do Contrabando S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1061, 85, 'Boardwalk Empire: O Império do Contrabando S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1062, 85, 'Boardwalk Empire: O Império do Contrabando S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1063, 85, 'Boardwalk Empire: O Império do Contrabando S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1064, 85, 'Boardwalk Empire: O Império do Contrabando S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1065, 85, 'Boardwalk Empire: O Império do Contrabando S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1066, 86, 'Boardwalk Empire: O Império do Contrabando S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1067, 86, 'Boardwalk Empire: O Império do Contrabando S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1068, 86, 'Boardwalk Empire: O Império do Contrabando S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1069, 86, 'Boardwalk Empire: O Império do Contrabando S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1070, 86, 'Boardwalk Empire: O Império do Contrabando S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1071, 86, 'Boardwalk Empire: O Império do Contrabando S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1072, 86, 'Boardwalk Empire: O Império do Contrabando S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1073, 86, 'Boardwalk Empire: O Império do Contrabando S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1074, 86, 'Boardwalk Empire: O Império do Contrabando S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1075, 86, 'Boardwalk Empire: O Império do Contrabando S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1076, 86, 'Boardwalk Empire: O Império do Contrabando S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1077, 86, 'Boardwalk Empire: O Império do Contrabando S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1078, 87, 'Boardwalk Empire: O Império do Contrabando S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1079, 87, 'Boardwalk Empire: O Império do Contrabando S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1080, 87, 'Boardwalk Empire: O Império do Contrabando S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1081, 87, 'Boardwalk Empire: O Império do Contrabando S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1082, 87, 'Boardwalk Empire: O Império do Contrabando S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1083, 87, 'Boardwalk Empire: O Império do Contrabando S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1084, 87, 'Boardwalk Empire: O Império do Contrabando S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1085, 87, 'Boardwalk Empire: O Império do Contrabando S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1086, 87, 'Boardwalk Empire: O Império do Contrabando S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1087, 87, 'Boardwalk Empire: O Império do Contrabando S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1088, 87, 'Boardwalk Empire: O Império do Contrabando S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1089, 87, 'Boardwalk Empire: O Império do Contrabando S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1090, 88, 'Boardwalk Empire: O Império do Contrabando S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1091, 88, 'Boardwalk Empire: O Império do Contrabando S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1092, 88, 'Boardwalk Empire: O Império do Contrabando S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1093, 88, 'Boardwalk Empire: O Império do Contrabando S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1094, 88, 'Boardwalk Empire: O Império do Contrabando S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1095, 88, 'Boardwalk Empire: O Império do Contrabando S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1096, 88, 'Boardwalk Empire: O Império do Contrabando S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1097, 88, 'Boardwalk Empire: O Império do Contrabando S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kL6SqlVPpfAof2nQbh1VxkUuXBQ.jpg'),
(1098, 89, 'Bones S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144435.mp4', 'http://timg.bdta.pro/images/061bb4a50563952b5a6f58e277167461.jpg'),
(1099, 89, 'Bones S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144436.mp4', 'http://timg.bdta.pro/images/d84075da56acba6bde00d0e3d77a917b.jpg'),
(1100, 89, 'Bones S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144437.mp4', 'http://timg.bdta.pro/images/5af0208d9c798096c896acb5f6c546bf.jpg'),
(1101, 89, 'Bones S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144438.mp4', 'http://timg.bdta.pro/images/dd96d918667cb826ab777be3ce4ee571.jpg'),
(1102, 89, 'Bones S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144439.mp4', 'http://timg.bdta.pro/images/4c8ae7118df6a5fd3bb8ad3f0d6eb7c7.jpg'),
(1103, 89, 'Bones S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144440.mp4', 'http://timg.bdta.pro/images/2467b0a63b6d1ee718ba7a89e3e584cd.jpg'),
(1104, 89, 'Bones S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144441.mp4', 'http://timg.bdta.pro/images/7c5cd2fb36717c80ecafe9dad2d6ed1c.jpg'),
(1105, 89, 'Bones S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144442.mp4', 'http://timg.bdta.pro/images/05073ca41c111ef2acb3d60cd02a5bb4.jpg'),
(1106, 89, 'Bones S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144443.mp4', 'http://timg.bdta.pro/images/95eba22d29f2d341f25d7750cc9be581.jpg'),
(1107, 89, 'Bones S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144444.mp4', 'http://timg.bdta.pro/images/dc6f7cbaa2b4653f2218aa17de2c2b30.jpg'),
(1108, 89, 'Bones S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144445.mp4', 'http://timg.bdta.pro/images/30d0008789552a14e513fad1d11c83a2.jpg'),
(1109, 89, 'Bones S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144446.mp4', 'http://timg.bdta.pro/images/7b000a3d7704230501b2cf809efcd3c7.jpg'),
(1110, 89, 'Bones S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144447.mp4', 'http://timg.bdta.pro/images/b3bfab129a902cab3a856effd52d2221.jpg'),
(1111, 89, 'Bones S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144448.mp4', 'http://timg.bdta.pro/images/1e3143c2525ab210951f9b6582515e62.jpg'),
(1112, 89, 'Bones S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144449.mp4', 'http://timg.bdta.pro/images/9ff3645388af37955138c38c2c788632.jpg'),
(1113, 89, 'Bones S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144450.mp4', 'http://timg.bdta.pro/images/9e49f8b2f658b3a64dc43b37a92bb4bb.jpg'),
(1114, 89, 'Bones S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144451.mp4', 'http://timg.bdta.pro/images/eed0543e50b14c12bb61e1bcaab812c9.jpg'),
(1115, 89, 'Bones S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/144452.mp4', 'http://timg.bdta.pro/images/772db8159c636906e709997d76daf702.jpg'),
(1116, 89, 'Bones S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/144453.mp4', 'http://timg.bdta.pro/images/e777fa0d1d2437d6d3cc21eefd603de9.jpg'),
(1117, 89, 'Bones S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144454.mp4', 'http://timg.bdta.pro/images/57dd026690b2ad37a3224654d307b4c7.jpg'),
(1118, 89, 'Bones S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/144455.mp4', 'http://timg.bdta.pro/images/0901a95ece04b643d8aec37c1b5bdab9.jpg'),
(1119, 89, 'Bones S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/144456.mp4', 'http://timg.bdta.pro/images/667d1d6ca442fdce8b71396b4ca4fea3.jpg'),
(1120, 90, 'Bones S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144457.mp4', 'http://timg.bdta.pro/images/6e08bc0ac5abadc0b296df81687c537f.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(1121, 90, 'Bones S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144458.mp4', 'http://timg.bdta.pro/images/89cff8c8a8d4f22b887f05f896f74c98.jpg'),
(1122, 90, 'Bones S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144459.mp4', 'http://timg.bdta.pro/images/5e951ab365a0225472d7d66815e0dac3.jpg'),
(1123, 90, 'Bones S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144460.mp4', 'http://timg.bdta.pro/images/3feb03c400d67924621dd4719b376905.jpg'),
(1124, 90, 'Bones S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144461.mp4', 'http://timg.bdta.pro/images/449536382f1ec9c5dd2e3d14d0d55374.jpg'),
(1125, 90, 'Bones S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144462.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1126, 90, 'Bones S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144463.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1127, 90, 'Bones S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144464.mp4', 'http://timg.bdta.pro/images/7d93c92676f4f80dd669dacb05536e28.jpg'),
(1128, 90, 'Bones S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144465.mp4', 'http://timg.bdta.pro/images/7ce9b472f3afa9c88f587947956f11b4.jpg'),
(1129, 90, 'Bones S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144466.mp4', 'http://timg.bdta.pro/images/6106eb1e156fd5e7ac10f2e40233a623.jpg'),
(1130, 90, 'Bones S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144467.mp4', 'http://timg.bdta.pro/images/cff09f95d7db4895118b46feb36e47c3.jpg'),
(1131, 90, 'Bones S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144468.mp4', 'http://timg.bdta.pro/images/8b4006bdde9271aa7b2ce72d2922b877.jpg'),
(1132, 90, 'Bones S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144469.mp4', 'http://timg.bdta.pro/images/742ca6d4b11bf0ec9feb77d8fac86776.jpg'),
(1133, 90, 'Bones S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144470.mp4', 'http://timg.bdta.pro/images/56510c6112fc2d76e98073af1cd5c56d.jpg'),
(1134, 90, 'Bones S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144471.mp4', 'http://timg.bdta.pro/images/a1efc1efeb2de0a04b2f5c55bd9922a0.jpg'),
(1135, 90, 'Bones S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144472.mp4', 'http://timg.bdta.pro/images/bcba0d29b2dbf2fe16be558b1fb2b528.jpg'),
(1136, 90, 'Bones S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144473.mp4', 'http://timg.bdta.pro/images/e0f12858417db43b6461c5daade77037.jpg'),
(1137, 90, 'Bones S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/144474.mp4', 'http://timg.bdta.pro/images/0381eb96b4e00c450d760f4798f42094.jpg'),
(1138, 90, 'Bones S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/144475.mp4', 'http://timg.bdta.pro/images/c0fe776cbc3f258ea5cda8306b9757df.jpg'),
(1139, 90, 'Bones S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144476.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1140, 90, 'Bones S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/144477.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1141, 91, 'Bones S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144478.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1142, 91, 'Bones S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144479.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1143, 91, 'Bones S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144480.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1144, 91, 'Bones S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144481.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1145, 91, 'Bones S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144482.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1146, 91, 'Bones S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144483.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1147, 91, 'Bones S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144484.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1148, 91, 'Bones S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144485.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1149, 91, 'Bones S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144486.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1150, 91, 'Bones S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144487.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1151, 91, 'Bones S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144488.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1152, 91, 'Bones S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144489.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1153, 91, 'Bones S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144490.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1154, 91, 'Bones S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144491.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1155, 91, 'Bones S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144492.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1156, 92, 'Bones S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144493.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1157, 92, 'Bones S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144494.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1158, 92, 'Bones S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144495.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1159, 92, 'Bones S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144496.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1160, 92, 'Bones S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144497.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1161, 92, 'Bones S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144498.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1162, 92, 'Bones S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144499.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1163, 92, 'Bones S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144500.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1164, 92, 'Bones S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144501.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1165, 92, 'Bones S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144502.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1166, 92, 'Bones S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144503.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1167, 92, 'Bones S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144504.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1168, 92, 'Bones S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144505.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1169, 92, 'Bones S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144506.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1170, 92, 'Bones S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144507.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1171, 92, 'Bones S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144508.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1172, 92, 'Bones S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144509.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1173, 92, 'Bones S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/144510.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1174, 92, 'Bones S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/144511.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1175, 92, 'Bones S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144512.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1176, 92, 'Bones S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/144513.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1177, 92, 'Bones S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/144514.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1178, 92, 'Bones S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/144515.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1179, 92, 'Bones S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/144516.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1180, 92, 'Bones S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/144517.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1181, 92, 'Bones S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/144518.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1182, 93, 'Bones S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144519.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1183, 93, 'Bones S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144520.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1184, 93, 'Bones S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144521.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1185, 93, 'Bones S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144522.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1186, 93, 'Bones S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144523.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1187, 93, 'Bones S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144524.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1188, 93, 'Bones S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144525.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1189, 93, 'Bones S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144526.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1190, 93, 'Bones S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144527.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1191, 93, 'Bones S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144528.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1192, 93, 'Bones S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144529.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1193, 93, 'Bones S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144530.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1194, 93, 'Bones S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144531.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1195, 93, 'Bones S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144532.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1196, 93, 'Bones S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144533.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1197, 93, 'Bones S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144534.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1198, 93, 'Bones S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144535.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1199, 93, 'Bones S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/144536.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1200, 93, 'Bones S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/144537.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1201, 93, 'Bones S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144538.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1202, 93, 'Bones S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/144539.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1203, 93, 'Bones S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/144540.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1204, 94, 'Bones S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144541.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1205, 94, 'Bones S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144542.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1206, 94, 'Bones S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144543.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1207, 94, 'Bones S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144544.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1208, 94, 'Bones S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144545.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1209, 94, 'Bones S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144546.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1210, 94, 'Bones S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144547.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1211, 94, 'Bones S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144548.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1212, 94, 'Bones S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144549.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1213, 94, 'Bones S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144550.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1214, 94, 'Bones S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144551.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1215, 94, 'Bones S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144552.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1216, 94, 'Bones S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144553.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1217, 94, 'Bones S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144554.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1218, 94, 'Bones S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144555.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1219, 94, 'Bones S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144556.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1220, 94, 'Bones S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144557.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1221, 94, 'Bones S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/144558.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1222, 94, 'Bones S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/144559.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1223, 94, 'Bones S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144560.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1224, 94, 'Bones S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/144561.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1225, 94, 'Bones S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/144562.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1226, 94, 'Bones S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/144563.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1227, 95, 'Bones S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144564.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1228, 95, 'Bones S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144565.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1229, 95, 'Bones S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144566.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1230, 95, 'Bones S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144567.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1231, 95, 'Bones S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144568.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1232, 95, 'Bones S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144569.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1233, 95, 'Bones S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144570.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1234, 95, 'Bones S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144571.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1235, 95, 'Bones S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144572.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1236, 95, 'Bones S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144573.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1237, 95, 'Bones S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144574.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1238, 95, 'Bones S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144575.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1239, 95, 'Bones S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144576.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1240, 96, 'Bones S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144577.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1241, 96, 'Bones S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144578.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1242, 96, 'Bones S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144579.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1243, 96, 'Bones S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144580.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1244, 96, 'Bones S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144581.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1245, 96, 'Bones S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144582.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1246, 96, 'Bones S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144583.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1247, 96, 'Bones S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144584.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1248, 96, 'Bones S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144585.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1249, 96, 'Bones S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144586.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1250, 96, 'Bones S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144587.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1251, 96, 'Bones S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144588.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1252, 96, 'Bones S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144589.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1253, 96, 'Bones S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144590.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1254, 96, 'Bones S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144591.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1255, 96, 'Bones S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144592.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1256, 96, 'Bones S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144593.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1257, 96, 'Bones S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/144594.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1258, 96, 'Bones S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/144595.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1259, 96, 'Bones S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144596.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1260, 96, 'Bones S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/144597.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1261, 96, 'Bones S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/144598.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1262, 96, 'Bones S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/144599.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1263, 96, 'Bones S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/144600.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1264, 97, 'Bones S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144601.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1265, 97, 'Bones S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144602.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1266, 97, 'Bones S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144603.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1267, 97, 'Bones S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144604.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1268, 97, 'Bones S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144605.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1269, 97, 'Bones S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144606.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1270, 97, 'Bones S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144607.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1271, 97, 'Bones S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144608.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1272, 97, 'Bones S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144609.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1273, 97, 'Bones S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144610.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1274, 97, 'Bones S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144611.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1275, 97, 'Bones S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144612.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1276, 97, 'Bones S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144613.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1277, 97, 'Bones S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144614.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1278, 97, 'Bones S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144615.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1279, 97, 'Bones S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144616.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1280, 97, 'Bones S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144617.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1281, 97, 'Bones S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/144618.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1282, 97, 'Bones S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/144619.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1283, 97, 'Bones S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144620.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1284, 97, 'Bones S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/144621.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1285, 97, 'Bones S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/144622.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1286, 97, 'Bones S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/144623.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1287, 97, 'Bones S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/144624.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1288, 98, 'Bones S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144625.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1289, 98, 'Bones S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144626.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1290, 98, 'Bones S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144627.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1291, 98, 'Bones S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144628.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1292, 98, 'Bones S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144629.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1293, 98, 'Bones S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144630.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1294, 98, 'Bones S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144631.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1295, 98, 'Bones S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144632.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1296, 98, 'Bones S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144633.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1297, 98, 'Bones S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144634.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1298, 98, 'Bones S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144635.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1299, 98, 'Bones S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144636.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1300, 98, 'Bones S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144637.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1301, 98, 'Bones S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144638.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1302, 98, 'Bones S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144639.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1303, 98, 'Bones S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144640.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1304, 98, 'Bones S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144641.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1305, 98, 'Bones S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/144642.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1306, 98, 'Bones S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/144643.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1307, 98, 'Bones S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144644.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1308, 98, 'Bones S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/144645.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1309, 98, 'Bones S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/144646.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1310, 99, 'Bones S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144647.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1311, 99, 'Bones S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144648.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1312, 99, 'Bones S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144649.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1313, 99, 'Bones S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144650.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1314, 99, 'Bones S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144651.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1315, 99, 'Bones S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144652.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1316, 99, 'Bones S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144653.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1317, 99, 'Bones S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144654.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1318, 99, 'Bones S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144655.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1319, 99, 'Bones S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144656.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1320, 99, 'Bones S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144657.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1321, 99, 'Bones S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144658.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1322, 99, 'Bones S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144659.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1323, 99, 'Bones S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144660.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1324, 99, 'Bones S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144661.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1325, 99, 'Bones S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144662.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1326, 99, 'Bones S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144663.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1327, 99, 'Bones S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/144664.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1328, 99, 'Bones S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/144665.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1329, 99, 'Bones S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144666.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1330, 99, 'Bones S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/144667.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1331, 99, 'Bones S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/144668.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1332, 100, 'Bones S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144669.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1333, 100, 'Bones S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144670.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1334, 100, 'Bones S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144671.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1335, 100, 'Bones S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144672.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1336, 100, 'Bones S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144673.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1337, 100, 'Bones S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144674.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1338, 100, 'Bones S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144675.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1339, 100, 'Bones S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144676.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1340, 100, 'Bones S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144677.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1341, 100, 'Bones S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144678.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1342, 100, 'Bones S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144679.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1343, 100, 'Bones S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144680.mp4', 'http://gstaticontent.com/images/rElaRnNez2dXBCMv1THHdVcroFY_big.jpg'),
(1344, 101, 'Breaking Bad: A Química do Mal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1345, 101, 'Breaking Bad: A Química do Mal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1346, 101, 'Breaking Bad: A Química do Mal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1347, 101, 'Breaking Bad: A Química do Mal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1348, 101, 'Breaking Bad: A Química do Mal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1349, 101, 'Breaking Bad: A Química do Mal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1350, 101, 'Breaking Bad: A Química do Mal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1351, 102, 'Breaking Bad: A Química do Mal S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1352, 102, 'Breaking Bad: A Química do Mal S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1353, 102, 'Breaking Bad: A Química do Mal S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1354, 102, 'Breaking Bad: A Química do Mal S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1355, 102, 'Breaking Bad: A Química do Mal S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1356, 102, 'Breaking Bad: A Química do Mal S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1357, 102, 'Breaking Bad: A Química do Mal S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1358, 102, 'Breaking Bad: A Química do Mal S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1359, 102, 'Breaking Bad: A Química do Mal S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1360, 102, 'Breaking Bad: A Química do Mal S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1361, 102, 'Breaking Bad: A Química do Mal S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1362, 102, 'Breaking Bad: A Química do Mal S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1363, 102, 'Breaking Bad: A Química do Mal S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1364, 103, 'Breaking Bad: A Química do Mal S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1365, 103, 'Breaking Bad: A Química do Mal S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1366, 103, 'Breaking Bad: A Química do Mal S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1367, 103, 'Breaking Bad: A Química do Mal S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1368, 103, 'Breaking Bad: A Química do Mal S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1369, 103, 'Breaking Bad: A Química do Mal S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1370, 103, 'Breaking Bad: A Química do Mal S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1371, 103, 'Breaking Bad: A Química do Mal S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1372, 103, 'Breaking Bad: A Química do Mal S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1373, 103, 'Breaking Bad: A Química do Mal S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1374, 103, 'Breaking Bad: A Química do Mal S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1375, 103, 'Breaking Bad: A Química do Mal S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1376, 103, 'Breaking Bad: A Química do Mal S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1377, 104, 'Breaking Bad: A Química do Mal S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1378, 104, 'Breaking Bad: A Química do Mal S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1379, 104, 'Breaking Bad: A Química do Mal S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1380, 104, 'Breaking Bad: A Química do Mal S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1381, 104, 'Breaking Bad: A Química do Mal S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1382, 104, 'Breaking Bad: A Química do Mal S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1383, 104, 'Breaking Bad: A Química do Mal S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1384, 104, 'Breaking Bad: A Química do Mal S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1385, 104, 'Breaking Bad: A Química do Mal S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1386, 104, 'Breaking Bad: A Química do Mal S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1387, 104, 'Breaking Bad: A Química do Mal S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1388, 104, 'Breaking Bad: A Química do Mal S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1389, 104, 'Breaking Bad: A Química do Mal S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1390, 105, 'Breaking Bad: A Química do Mal S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1391, 105, 'Breaking Bad: A Química do Mal S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1392, 105, 'Breaking Bad: A Química do Mal S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1393, 105, 'Breaking Bad: A Química do Mal S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1394, 105, 'Breaking Bad: A Química do Mal S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1395, 105, 'Breaking Bad: A Química do Mal S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1396, 105, 'Breaking Bad: A Química do Mal S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1397, 105, 'Breaking Bad: A Química do Mal S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1398, 105, 'Breaking Bad: A Química do Mal S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1399, 105, 'Breaking Bad: A Química do Mal S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1400, 105, 'Breaking Bad: A Química do Mal S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1401, 105, 'Breaking Bad: A Química do Mal S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1402, 105, 'Breaking Bad: A Química do Mal S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1403, 105, 'Breaking Bad: A Química do Mal S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1404, 105, 'Breaking Bad: A Química do Mal S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1405, 105, 'Breaking Bad: A Química do Mal S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30erzlzIOtOK3k3T3BAl1GiVMP1.jpg'),
(1406, 106, 'Britannia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108679.mp4', 'http://gstaticontent.com/images/eRn7ZfplxSsIkPoWuW0PgQJo7Px_big.jpg'),
(1407, 106, 'Britannia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108680.mp4', 'http://gstaticontent.com/images/eRn7ZfplxSsIkPoWuW0PgQJo7Px_big.jpg'),
(1408, 106, 'Britannia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108681.mp4', 'http://gstaticontent.com/images/eRn7ZfplxSsIkPoWuW0PgQJo7Px_big.jpg'),
(1409, 106, 'Britannia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108682.mp4', 'http://gstaticontent.com/images/eRn7ZfplxSsIkPoWuW0PgQJo7Px_big.jpg'),
(1410, 106, 'Britannia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108683.mp4', 'http://gstaticontent.com/images/eRn7ZfplxSsIkPoWuW0PgQJo7Px_big.jpg'),
(1411, 106, 'Britannia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108684.mp4', 'http://gstaticontent.com/images/eRn7ZfplxSsIkPoWuW0PgQJo7Px_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(1412, 106, 'Britannia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108685.mp4', 'http://gstaticontent.com/images/eRn7ZfplxSsIkPoWuW0PgQJo7Px_big.jpg'),
(1413, 106, 'Britannia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108686.mp4', 'http://gstaticontent.com/images/eRn7ZfplxSsIkPoWuW0PgQJo7Px_big.jpg'),
(1414, 106, 'Britannia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108687.mp4', 'http://gstaticontent.com/images/eRn7ZfplxSsIkPoWuW0PgQJo7Px_big.jpg'),
(1415, 107, 'Britannia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108688.mp4', 'http://timg.bdta.pro/images/b34d829ff4720ad1ef59a9e338732996.jpg'),
(1416, 107, 'Britannia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108689.mp4', 'http://timg.bdta.pro/images/15e7fe1877abfe1760be846dacf405c2.jpg'),
(1417, 107, 'Britannia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108690.mp4', 'http://timg.bdta.pro/images/cd30b63b16c86fcff7e87268f27739b9.jpg'),
(1418, 107, 'Britannia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108691.mp4', 'http://timg.bdta.pro/images/5b4e86bd272a876c054d193c21ff6187.jpg'),
(1419, 107, 'Britannia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108692.mp4', 'http://timg.bdta.pro/images/37a371fb528ba2d29b9641d4e0ae9d83.jpg'),
(1420, 107, 'Britannia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108693.mp4', 'http://timg.bdta.pro/images/b4b1c549dbed770d58462a7264095716.jpg'),
(1421, 107, 'Britannia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108694.mp4', 'http://timg.bdta.pro/images/3de0541e20fd05ff0cb9bbf6111fd835.jpg'),
(1422, 107, 'Britannia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108695.mp4', 'http://timg.bdta.pro/images/2e1804b1b0e72594d85d3f883be645a9.jpg'),
(1423, 107, 'Britannia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108696.mp4', 'http://timg.bdta.pro/images/88946cf4dd4df0b602ef12392a59b0e9.jpg'),
(1424, 107, 'Britannia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108697.mp4', 'http://timg.bdta.pro/images/85aeee40f907ba1c2bb22e63ff2eed35.jpg'),
(1425, 108, 'Britannia S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/379122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jKXVG1p3oDo9nF97nFNTSiCYONE.jpg'),
(1426, 108, 'Britannia S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/379123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p5VQTCU1Om2E9Hwf0CXr4EGdxjk.jpg'),
(1427, 108, 'Britannia S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/379124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zYqwReYi6QSYsqWIdDLQ5lAzx57.jpg'),
(1428, 108, 'Britannia S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/379125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c6sWItw7RPHXGkfZekdtH3AO5x6.jpg'),
(1429, 108, 'Britannia S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/379126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7b3FVsdcIPSGLMpZgpCtzl38vOE.jpg'),
(1430, 108, 'Britannia S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/379127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZtU3O1PdbK1NwfazWiG64tN69M.jpg'),
(1431, 108, 'Britannia S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/379128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cd3TmsY6CIxtpt5qNZW78ecjmgG.jpg'),
(1432, 108, 'Britannia S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/379129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hODMQOAEz4wBIIiRZ9Lwx2QexS4.jpg'),
(1433, 109, 'Brooklyn Nine Nine S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161778.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1434, 109, 'Brooklyn Nine Nine S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161779.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1435, 109, 'Brooklyn Nine Nine S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161780.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1436, 109, 'Brooklyn Nine Nine S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161781.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1437, 109, 'Brooklyn Nine Nine S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161782.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1438, 109, 'Brooklyn Nine Nine S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161783.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1439, 109, 'Brooklyn Nine Nine S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161784.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1440, 109, 'Brooklyn Nine Nine S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161785.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1441, 109, 'Brooklyn Nine Nine S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161786.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1442, 109, 'Brooklyn Nine Nine S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161787.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1443, 109, 'Brooklyn Nine Nine S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161788.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1444, 109, 'Brooklyn Nine Nine S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161789.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1445, 109, 'Brooklyn Nine Nine S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161790.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1446, 109, 'Brooklyn Nine Nine S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161791.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1447, 109, 'Brooklyn Nine Nine S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161792.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1448, 109, 'Brooklyn Nine Nine S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161793.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1449, 109, 'Brooklyn Nine Nine S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161794.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1450, 109, 'Brooklyn Nine Nine S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161795.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1451, 109, 'Brooklyn Nine Nine S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/161796.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1452, 109, 'Brooklyn Nine Nine S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/161797.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1453, 109, 'Brooklyn Nine Nine S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/161798.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1454, 109, 'Brooklyn Nine Nine S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/161799.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1455, 110, 'Brooklyn Nine Nine S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161800.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1456, 110, 'Brooklyn Nine Nine S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161801.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1457, 110, 'Brooklyn Nine Nine S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161802.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1458, 110, 'Brooklyn Nine Nine S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161803.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1459, 110, 'Brooklyn Nine Nine S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161804.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1460, 110, 'Brooklyn Nine Nine S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161805.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1461, 110, 'Brooklyn Nine Nine S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161806.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1462, 110, 'Brooklyn Nine Nine S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161807.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1463, 110, 'Brooklyn Nine Nine S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161808.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1464, 110, 'Brooklyn Nine Nine S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161809.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1465, 110, 'Brooklyn Nine Nine S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161810.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1466, 110, 'Brooklyn Nine Nine S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161811.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1467, 110, 'Brooklyn Nine Nine S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161812.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1468, 110, 'Brooklyn Nine Nine S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161813.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1469, 110, 'Brooklyn Nine Nine S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161814.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1470, 110, 'Brooklyn Nine Nine S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161815.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1471, 110, 'Brooklyn Nine Nine S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161816.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1472, 110, 'Brooklyn Nine Nine S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161817.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1473, 110, 'Brooklyn Nine Nine S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/161818.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1474, 110, 'Brooklyn Nine Nine S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/161819.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1475, 110, 'Brooklyn Nine Nine S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/161820.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1476, 110, 'Brooklyn Nine Nine S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/161821.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1477, 110, 'Brooklyn Nine Nine S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/161822.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1478, 111, 'Brooklyn Nine Nine S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161823.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1479, 111, 'Brooklyn Nine Nine S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161824.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1480, 111, 'Brooklyn Nine Nine S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161825.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1481, 111, 'Brooklyn Nine Nine S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161826.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1482, 111, 'Brooklyn Nine Nine S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161827.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1483, 111, 'Brooklyn Nine Nine S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161828.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1484, 111, 'Brooklyn Nine Nine S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161829.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1485, 111, 'Brooklyn Nine Nine S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161830.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1486, 111, 'Brooklyn Nine Nine S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161831.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1487, 111, 'Brooklyn Nine Nine S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161832.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1488, 111, 'Brooklyn Nine Nine S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161833.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1489, 111, 'Brooklyn Nine Nine S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161834.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1490, 111, 'Brooklyn Nine Nine S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161835.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1491, 111, 'Brooklyn Nine Nine S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161836.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1492, 111, 'Brooklyn Nine Nine S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161837.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1493, 111, 'Brooklyn Nine Nine S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161838.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1494, 111, 'Brooklyn Nine Nine S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161839.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1495, 111, 'Brooklyn Nine Nine S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161840.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1496, 111, 'Brooklyn Nine Nine S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/161841.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1497, 111, 'Brooklyn Nine Nine S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/161842.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1498, 111, 'Brooklyn Nine Nine S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/161843.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1499, 111, 'Brooklyn Nine Nine S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/161844.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1500, 112, 'Brooklyn Nine Nine S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161845.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1501, 112, 'Brooklyn Nine Nine S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161846.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1502, 112, 'Brooklyn Nine Nine S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161847.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1503, 112, 'Brooklyn Nine Nine S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161848.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1504, 112, 'Brooklyn Nine Nine S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161849.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1505, 112, 'Brooklyn Nine Nine S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161850.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1506, 112, 'Brooklyn Nine Nine S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161851.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1507, 112, 'Brooklyn Nine Nine S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161852.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1508, 112, 'Brooklyn Nine Nine S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161853.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1509, 112, 'Brooklyn Nine Nine S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161854.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1510, 112, 'Brooklyn Nine Nine S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161855.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1511, 112, 'Brooklyn Nine Nine S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161856.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1512, 112, 'Brooklyn Nine Nine S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161857.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1513, 112, 'Brooklyn Nine Nine S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161858.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1514, 112, 'Brooklyn Nine Nine S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161859.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1515, 112, 'Brooklyn Nine Nine S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161860.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1516, 112, 'Brooklyn Nine Nine S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161861.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1517, 113, 'Brooklyn Nine Nine S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161862.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1518, 113, 'Brooklyn Nine Nine S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161863.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1519, 113, 'Brooklyn Nine Nine S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161864.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1520, 113, 'Brooklyn Nine Nine S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161865.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1521, 113, 'Brooklyn Nine Nine S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161866.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1522, 113, 'Brooklyn Nine Nine S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161867.mp4', 'http://timg.bdta.pro/images/kL1PCTiQAcQsZt9hzSirQSb4S23_small.jpg'),
(1523, 113, 'Brooklyn Nine Nine S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161868.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1524, 113, 'Brooklyn Nine Nine S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161869.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1525, 113, 'Brooklyn Nine Nine S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161870.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1526, 113, 'Brooklyn Nine Nine S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161871.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1527, 113, 'Brooklyn Nine Nine S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161872.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1528, 113, 'Brooklyn Nine Nine S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161873.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1529, 113, 'Brooklyn Nine Nine S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161874.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1530, 113, 'Brooklyn Nine Nine S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161875.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1531, 113, 'Brooklyn Nine Nine S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161876.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1532, 113, 'Brooklyn Nine Nine S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161877.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1533, 113, 'Brooklyn Nine Nine S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161878.mp4', 'http://timg.bdta.pro/images/vRUM7NKkbaXh3LcMCW15WLAV4JV_small.jpg'),
(1534, 113, 'Brooklyn Nine Nine S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161879.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1535, 113, 'Brooklyn Nine Nine S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/161880.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1536, 113, 'Brooklyn Nine Nine S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/161881.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1537, 113, 'Brooklyn Nine Nine S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/161882.mp4', 'http://timg.bdta.pro/images/yijgYRLCgo8xunDWU7KhlSDt40u_small.jpg'),
(1538, 113, 'Brooklyn Nine Nine S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/161883.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1539, 114, 'Brooklyn Nine Nine S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161884.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1540, 114, 'Brooklyn Nine Nine S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161885.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1541, 114, 'Brooklyn Nine Nine S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161886.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1542, 114, 'Brooklyn Nine Nine S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161887.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1543, 114, 'Brooklyn Nine Nine S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161888.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1544, 114, 'Brooklyn Nine Nine S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161889.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1545, 114, 'Brooklyn Nine Nine S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161890.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1546, 114, 'Brooklyn Nine Nine S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161891.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1547, 114, 'Brooklyn Nine Nine S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161892.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1548, 114, 'Brooklyn Nine Nine S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161893.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1549, 114, 'Brooklyn Nine Nine S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161894.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1550, 114, 'Brooklyn Nine Nine S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161895.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1551, 114, 'Brooklyn Nine Nine S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161896.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1552, 114, 'Brooklyn Nine Nine S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161897.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1553, 114, 'Brooklyn Nine Nine S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161898.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1554, 115, 'Brooklyn Nine Nine S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161899.mp4', 'http://timg.bdta.pro/images/218c27e6a55818c179ff264c1fe0c0d7.jpg'),
(1555, 115, 'Brooklyn Nine Nine S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161900.mp4', 'http://timg.bdta.pro/images/954c8f5312f105a7f329892cc2d345f4.jpg'),
(1556, 115, 'Brooklyn Nine Nine S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161901.mp4', 'http://timg.bdta.pro/images/5f950f4a314856147a3dea93aa3cbb62.jpg'),
(1557, 115, 'Brooklyn Nine Nine S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161902.mp4', 'http://timg.bdta.pro/images/dbaedb77838f92198166630a5aec27af.jpg'),
(1558, 115, 'Brooklyn Nine Nine S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161903.mp4', 'http://timg.bdta.pro/images/fbfefa3bf4d53b60cd1d2022ef49e4c2.jpg'),
(1559, 115, 'Brooklyn Nine Nine S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161904.mp4', 'http://timg.bdta.pro/images/801b8b1296991b0b75deb336704c3e25.jpg'),
(1560, 115, 'Brooklyn Nine Nine S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161905.mp4', 'http://timg.bdta.pro/images/655d785885facfefa44b61bdee9e20d6.jpg'),
(1561, 115, 'Brooklyn Nine Nine S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161906.mp4', 'http://timg.bdta.pro/images/9cca226244f0ab3b16eec0c048e71d71.jpg'),
(1562, 115, 'Brooklyn Nine Nine S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161907.mp4', 'http://timg.bdta.pro/images/f16301c30eb439e0d6dc3af233c565ae.jpg'),
(1563, 115, 'Brooklyn Nine Nine S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161908.mp4', 'http://timg.bdta.pro/images/47bfefcb498e138679580de9bff0e9e0.jpg'),
(1564, 115, 'Brooklyn Nine Nine S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161909.mp4', 'http://timg.bdta.pro/images/3a88a4c92c2beb1b58362d5cdfba1ca6.jpg'),
(1565, 115, 'Brooklyn Nine Nine S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161910.mp4', 'http://timg.bdta.pro/images/0f66b22c54cc6719530c3189faaf15b7.jpg'),
(1566, 115, 'Brooklyn Nine Nine S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161911.mp4', 'http://timg.bdta.pro/images/63a6ad968e091b606b0d88b85404ea24.jpg'),
(1567, 116, 'Brooklyn Nine Nine S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161912.mp4', 'http://timg.bdta.pro/images/d862abbdf429df5038398cef540b5617.jpg'),
(1568, 116, 'Brooklyn Nine Nine S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161913.mp4', 'http://image.tmdb.org/t/p/w1280/pBRc1yycNs0wusgJddErXSVghy6.jpg'),
(1569, 116, 'Brooklyn Nine Nine S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sULHViN0oeitkqqK1XeddmOdFuJ.jpg'),
(1570, 116, 'Brooklyn Nine Nine S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sT0MO1BppIJ3AYBOiRmWe4G4GtN.jpg'),
(1571, 116, 'Brooklyn Nine Nine S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6m4AcBoVqC67BOXXLktHFmRgh6.jpg'),
(1572, 116, 'Brooklyn Nine Nine S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1n70ydfwSgSPO37fs6XdjjR578B.jpg'),
(1573, 116, 'Brooklyn Nine Nine S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a2vahJvAujrHw3JWOylb6lW3fgw.jpg'),
(1574, 116, 'Brooklyn Nine Nine S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5iiaIz5Eyrp6pRneVJw4P6oUtvE.jpg'),
(1575, 116, 'Brooklyn Nine Nine S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3a2HqGlIU94xdfLdZDoHsX32e9u.jpg'),
(1576, 116, 'Brooklyn Nine Nine S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161921.mp4', 'http://gstaticontent.com/images/yMeyZHAlakxTRGJT0hp96Zz2Xfw_big.jpg'),
(1577, 117, 'Carcereiros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136226.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1578, 117, 'Carcereiros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136227.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1579, 117, 'Carcereiros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136228.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1580, 117, 'Carcereiros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136229.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1581, 117, 'Carcereiros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136230.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1582, 117, 'Carcereiros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136231.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1583, 117, 'Carcereiros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136232.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1584, 117, 'Carcereiros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136233.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1585, 117, 'Carcereiros S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136234.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1586, 117, 'Carcereiros S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136235.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1587, 117, 'Carcereiros S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136236.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1588, 117, 'Carcereiros S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136237.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1589, 118, 'Carcereiros S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136238.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1590, 118, 'Carcereiros S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136239.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1591, 118, 'Carcereiros S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136240.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1592, 118, 'Carcereiros S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136241.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1593, 118, 'Carcereiros S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136242.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1594, 118, 'Carcereiros S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136243.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1595, 118, 'Carcereiros S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136244.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1596, 118, 'Carcereiros S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136245.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1597, 118, 'Carcereiros S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136246.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1598, 118, 'Carcereiros S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136247.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1599, 118, 'Carcereiros S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136248.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1600, 118, 'Carcereiros S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136249.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1601, 118, 'Carcereiros S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136250.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1602, 118, 'Carcereiros S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/136251.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1603, 119, 'Carcereiros S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136252.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1604, 119, 'Carcereiros S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136253.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1605, 119, 'Carcereiros S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136254.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1606, 119, 'Carcereiros S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136255.mp4', 'http://gstaticontent.com/images/mEHSZIyKzyRsirTYORXU92bxuki_big.jpg'),
(1607, 120, 'Castle S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130300.mp4', 'http://timg.bdta.pro/images/9a9772631cb5cd4c09c43111be686fbd.jpg'),
(1608, 120, 'Castle S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130301.mp4', 'http://timg.bdta.pro/images/297ef26073a6c1a8e0e2eae17c093363.jpg'),
(1609, 120, 'Castle S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130302.mp4', 'http://timg.bdta.pro/images/2f7a571d6524bbda9c6eed585edd8361.jpg'),
(1610, 120, 'Castle S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130303.mp4', 'http://timg.bdta.pro/images/d286eaa78665c37c9c4d2623ddd39746.jpg'),
(1611, 120, 'Castle S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130304.mp4', 'http://timg.bdta.pro/images/4d0617bb5ea2efad8640380a2d23cee2.jpg'),
(1612, 120, 'Castle S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130305.mp4', 'http://timg.bdta.pro/images/dc817509eb6d1905d794b46af0fd9641.jpg'),
(1613, 120, 'Castle S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130306.mp4', 'http://timg.bdta.pro/images/91706bcf68b38307b300f596d1a0e641.jpg'),
(1614, 120, 'Castle S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130307.mp4', 'http://timg.bdta.pro/images/45bb364a5e0b12e75dfd506d4bad0740.jpg'),
(1615, 120, 'Castle S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130308.mp4', 'http://timg.bdta.pro/images/3c85c2f4eddf93b632b48660230ceec5.jpg'),
(1616, 120, 'Castle S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130309.mp4', 'http://timg.bdta.pro/images/f4a815321a036dee780de4890c572dbf.jpg'),
(1617, 121, 'Castle S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130310.mp4', 'http://timg.bdta.pro/images/6f585aec8db6f5c368ed6b72b6046d52.jpg'),
(1618, 121, 'Castle S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130311.mp4', 'http://timg.bdta.pro/images/e43ead9653f0e6d57682177b45df7832.jpg'),
(1619, 121, 'Castle S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130312.mp4', 'http://timg.bdta.pro/images/ac087676ad5a42eaf770050440f71a51.jpg'),
(1620, 121, 'Castle S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130313.mp4', 'http://timg.bdta.pro/images/d765a0915161607c059e1092c116bf7b.jpg'),
(1621, 121, 'Castle S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130314.mp4', 'http://timg.bdta.pro/images/2f5361002c18ea702314eda8622774d1.jpg'),
(1622, 121, 'Castle S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130315.mp4', 'http://timg.bdta.pro/images/1521ce4cc358edb14fdd15286fa1d0da.jpg'),
(1623, 121, 'Castle S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130316.mp4', 'http://timg.bdta.pro/images/9dbbdbc103983d61ea9a835256807e6a.jpg'),
(1624, 121, 'Castle S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130317.mp4', 'http://timg.bdta.pro/images/560e90c2e4c58d04e8257c869483ebe4.jpg'),
(1625, 121, 'Castle S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130318.mp4', 'http://timg.bdta.pro/images/6138065e561078826c5b396705117a7e.jpg'),
(1626, 121, 'Castle S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130319.mp4', 'http://timg.bdta.pro/images/0cd0e3bc5906fac9d6e905f34355144c.jpg'),
(1627, 121, 'Castle S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/130320.mp4', 'http://timg.bdta.pro/images/a64c5459a17694421424ee46044a3440.jpg'),
(1628, 121, 'Castle S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/130321.mp4', 'http://timg.bdta.pro/images/ef10c54c04209d64446f0441a40c103f.jpg'),
(1629, 121, 'Castle S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/130322.mp4', 'http://timg.bdta.pro/images/1a0a837e37592bb0138d6912a0edb408.jpg'),
(1630, 121, 'Castle S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/130323.mp4', 'http://timg.bdta.pro/images/4525f47a22d04bffd5469118cb3d7ded.jpg'),
(1631, 121, 'Castle S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/130324.mp4', 'http://timg.bdta.pro/images/e00e529491813778c1f8d14d77620cdc.jpg'),
(1632, 121, 'Castle S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/130325.mp4', 'http://timg.bdta.pro/images/22a1a73dd033b8bb0b6f066b55097bf4.jpg'),
(1633, 121, 'Castle S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/130326.mp4', 'http://timg.bdta.pro/images/cba76ef7b6e0faa639357208ada5959b.jpg'),
(1634, 121, 'Castle S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/130327.mp4', 'http://timg.bdta.pro/images/03edb590e18ba9a32a5ea022e3c799a3.jpg'),
(1635, 121, 'Castle S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/130328.mp4', 'http://timg.bdta.pro/images/95cb11154c74725f0bdc95785ad2d9a7.jpg'),
(1636, 121, 'Castle S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/130329.mp4', 'http://timg.bdta.pro/images/e69cec11e1a7478bd59d6c8cec40ba33.jpg'),
(1637, 121, 'Castle S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/130330.mp4', 'http://timg.bdta.pro/images/58d87e4518525934b7f2ee5e4e5edcd2.jpg'),
(1638, 121, 'Castle S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/130331.mp4', 'http://timg.bdta.pro/images/afdc86f8c46657476192bdd172f73f1d.jpg'),
(1639, 121, 'Castle S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/130332.mp4', 'http://timg.bdta.pro/images/985da23b4e7010f2641bc1b9e350ff47.jpg'),
(1640, 121, 'Castle S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/130333.mp4', 'http://timg.bdta.pro/images/705c42fc04e4644f8510b34aab186aeb.jpg'),
(1641, 122, 'Castle S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130334.mp4', 'http://timg.bdta.pro/images/427e09810263377d09c7d905cb292e6d.jpg'),
(1642, 122, 'Castle S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130335.mp4', 'http://timg.bdta.pro/images/6f2c57e6ed406f95de1c4aecdaf33bd6.jpg'),
(1643, 122, 'Castle S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130336.mp4', 'http://timg.bdta.pro/images/0a294140850d7ea472f4ea16a6929c02.jpg'),
(1644, 122, 'Castle S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130337.mp4', 'http://timg.bdta.pro/images/0dd7d87d91e41ed6efdbcf506158736b.jpg'),
(1645, 122, 'Castle S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130338.mp4', 'http://timg.bdta.pro/images/ff520a4245a3ce8af45f76aa607b057b.jpg'),
(1646, 122, 'Castle S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130339.mp4', 'http://timg.bdta.pro/images/a1a1ee5a1cc1025bacdac780dd96d736.jpg'),
(1647, 122, 'Castle S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130340.mp4', 'http://timg.bdta.pro/images/7996312f0956ba80783d45b1d71e8e82.jpg'),
(1648, 122, 'Castle S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130341.mp4', 'http://timg.bdta.pro/images/9a24cb37d01f006437faad0ef5bd3d59.jpg'),
(1649, 122, 'Castle S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130342.mp4', 'http://timg.bdta.pro/images/4066b64568b3da826cc9e4db35c8c9e8.jpg'),
(1650, 122, 'Castle S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130343.mp4', 'http://timg.bdta.pro/images/73a7ca50062e51b1a29a70ccb30277e0.jpg'),
(1651, 122, 'Castle S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/130344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/diXBeMzvfJb2iJg3G0kCUaMCzEc.jpg'),
(1652, 122, 'Castle S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/130345.mp4', 'http://timg.bdta.pro/images/a08b8b5254eaa88f08f12fd9261a68a3.jpg'),
(1653, 122, 'Castle S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/130346.mp4', 'http://timg.bdta.pro/images/822485e1b9177eb8499a3fa458bb3822.jpg'),
(1654, 122, 'Castle S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/130347.mp4', 'http://timg.bdta.pro/images/0775abbe3c9860ee1c2a570281fa7f12.jpg'),
(1655, 122, 'Castle S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/130348.mp4', 'http://timg.bdta.pro/images/81b62cea58c885d3ab9f2441a339273d.jpg'),
(1656, 122, 'Castle S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/130349.mp4', 'http://timg.bdta.pro/images/13e80c3698c23c2a1ecf171e67b1e5e0.jpg'),
(1657, 122, 'Castle S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/130350.mp4', 'http://timg.bdta.pro/images/8f54a05e0a0d43e3cc4b2441c5dc73f5.jpg'),
(1658, 122, 'Castle S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/130351.mp4', 'http://timg.bdta.pro/images/bde127c1bb1ed9e3bb53e3e0d68fab19.jpg'),
(1659, 122, 'Castle S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/130352.mp4', 'http://timg.bdta.pro/images/531ecc5c55e53d593d615970c89de85f.jpg'),
(1660, 122, 'Castle S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/130353.mp4', 'http://timg.bdta.pro/images/cd7dfe006106ff62182a6927969d80ff.jpg'),
(1661, 122, 'Castle S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/130354.mp4', 'http://timg.bdta.pro/images/1d872e147859c3716de3e1e4fa45fdeb.jpg'),
(1662, 122, 'Castle S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/130355.mp4', 'http://timg.bdta.pro/images/1e9c4f68e2603da4861b543401cd47c0.jpg'),
(1663, 122, 'Castle S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/130356.mp4', 'http://timg.bdta.pro/images/8f7f75180bcebf038d0fb6bb50b01f6a.jpg'),
(1664, 122, 'Castle S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/130357.mp4', 'http://timg.bdta.pro/images/57e5568acd43c5c212099cf0ae8f24c3.jpg'),
(1665, 123, 'Castle S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130358.mp4', 'http://timg.bdta.pro/images/34d125cb10ed4045badb504ea29eb042.jpg'),
(1666, 123, 'Castle S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130359.mp4', 'http://timg.bdta.pro/images/1c4f60f4e19b961081d9079db708e318.jpg'),
(1667, 123, 'Castle S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130360.mp4', 'http://timg.bdta.pro/images/bacc435e61c72bc47b6a7209b51aec5a.jpg'),
(1668, 123, 'Castle S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130361.mp4', 'http://timg.bdta.pro/images/ec20a9fcba0cf533b45b8d23bf18d0b8.jpg'),
(1669, 123, 'Castle S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130362.mp4', 'http://timg.bdta.pro/images/fcb6f76efaf4d539f0a6d5aed32c3ef4.jpg'),
(1670, 123, 'Castle S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130363.mp4', 'http://timg.bdta.pro/images/cdbb74942ffb2bc05db489e97c52afce.jpg'),
(1671, 123, 'Castle S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130364.mp4', 'http://timg.bdta.pro/images/74e946603e7cb9b833d0aa0568a7dc71.jpg'),
(1672, 123, 'Castle S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130365.mp4', 'http://timg.bdta.pro/images/0a76e6419a41be85dd2b9b7e69793e8a.jpg'),
(1673, 123, 'Castle S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130366.mp4', 'http://timg.bdta.pro/images/69ea3f9971de3b2acee18e998dc80aaa.jpg'),
(1674, 123, 'Castle S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130367.mp4', 'http://timg.bdta.pro/images/e385db4a9d648e7cca4a2bc04e36e22b.jpg'),
(1675, 123, 'Castle S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/130368.mp4', 'http://timg.bdta.pro/images/707d894288ac0f8fbec8cf6e98c97571.jpg'),
(1676, 123, 'Castle S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/130369.mp4', 'http://timg.bdta.pro/images/7ea4420beb9cff64ee0c59ca83dce3e2.jpg'),
(1677, 123, 'Castle S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/130370.mp4', 'http://timg.bdta.pro/images/0624d198ab07131b42161aafb78e4e39.jpg'),
(1678, 123, 'Castle S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/130371.mp4', 'http://timg.bdta.pro/images/328e8d8885e5acdba300ac14e58334f5.jpg'),
(1679, 123, 'Castle S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/130372.mp4', 'http://timg.bdta.pro/images/c6b113e0cf4762916b74694387483b3c.jpg'),
(1680, 123, 'Castle S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/130373.mp4', 'http://timg.bdta.pro/images/d2a4218a224048cf5df6b39dccc59adb.jpg'),
(1681, 123, 'Castle S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/130374.mp4', 'http://timg.bdta.pro/images/30fbd08d0ef19441eea907619840816f.jpg'),
(1682, 123, 'Castle S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/130375.mp4', 'http://timg.bdta.pro/images/02d8a047dd3767088976eb380de2e88c.jpg'),
(1683, 123, 'Castle S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/130376.mp4', 'http://timg.bdta.pro/images/e3e17a3a097e3dfe94966c27619859fe.jpg'),
(1684, 123, 'Castle S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/130377.mp4', 'http://timg.bdta.pro/images/de98d3cc8a4b2f170eab527f4121cce0.jpg'),
(1685, 123, 'Castle S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/130378.mp4', 'http://timg.bdta.pro/images/60e94a449250f0e7e2d1a33ae39bab08.jpg'),
(1686, 123, 'Castle S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/130379.mp4', 'http://timg.bdta.pro/images/6486273c897cf606f13826b57a90cd0b.jpg'),
(1687, 123, 'Castle S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/130380.mp4', 'http://timg.bdta.pro/images/58575160f9219853d5da267a5d64e082.jpg'),
(1688, 124, 'Castle S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130381.mp4', 'http://timg.bdta.pro/images/f8a10be6c37106cc69678c626469af4d.jpg'),
(1689, 124, 'Castle S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130382.mp4', 'http://timg.bdta.pro/images/4c4062a9856bd3477a2553ebd7779fb2.jpg'),
(1690, 124, 'Castle S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130383.mp4', 'http://timg.bdta.pro/images/792914e73275515b22b665c587e95e4a.jpg'),
(1691, 124, 'Castle S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130384.mp4', 'http://timg.bdta.pro/images/e23ba5220be5bedf13a8684009f2f736.jpg'),
(1692, 124, 'Castle S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130385.mp4', 'http://timg.bdta.pro/images/a0ac06fb1b25c488523101f89dfeb354.jpg'),
(1693, 124, 'Castle S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130386.mp4', 'http://timg.bdta.pro/images/73a5693e0f32bc98a622b4907adb945d.jpg'),
(1694, 124, 'Castle S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130387.mp4', 'http://timg.bdta.pro/images/7bf21f7ddb7fec41a111104f16ac1f8c.jpg'),
(1695, 124, 'Castle S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130388.mp4', 'http://timg.bdta.pro/images/e201663e423ba1a2022b4c2f9752afa6.jpg'),
(1696, 124, 'Castle S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130389.mp4', 'http://timg.bdta.pro/images/6a5dee74e4cd6825ed437012363bc939.jpg'),
(1697, 124, 'Castle S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130390.mp4', 'http://timg.bdta.pro/images/57713b07e81c8f24016cdde4d7573332.jpg'),
(1698, 124, 'Castle S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/130391.mp4', 'http://timg.bdta.pro/images/614091918a385673c624d745f80d0788.jpg'),
(1699, 124, 'Castle S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/130392.mp4', 'http://timg.bdta.pro/images/f5c0e29267d43e30ff427dec49661a8d.jpg'),
(1700, 124, 'Castle S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/130393.mp4', 'http://timg.bdta.pro/images/e10d6dbf7d72170b150f82cc76281e82.jpg'),
(1701, 124, 'Castle S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/130394.mp4', 'http://timg.bdta.pro/images/fc81944b5ace9f316c5a948b3d0bb602.jpg'),
(1702, 124, 'Castle S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/130395.mp4', 'http://timg.bdta.pro/images/c9cd6486fbd3e13eaf6fa706909222bc.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(1703, 124, 'Castle S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/130396.mp4', 'http://timg.bdta.pro/images/2ba9d75f25e13e97c30be4e79af523dd.jpg'),
(1704, 124, 'Castle S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/130397.mp4', 'http://timg.bdta.pro/images/ba0508864246bf357835e19ba2bc7408.jpg'),
(1705, 124, 'Castle S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/130398.mp4', 'http://timg.bdta.pro/images/ad6f82b7197aa63a47e6e9e2d0eedebb.jpg'),
(1706, 124, 'Castle S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/130399.mp4', 'http://timg.bdta.pro/images/437abd3d15a5a8a22406cf9a4fdcbd1d.jpg'),
(1707, 124, 'Castle S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/130400.mp4', 'http://timg.bdta.pro/images/f8be63ce26ce1f0291494d0ef95b7c60.jpg'),
(1708, 124, 'Castle S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/130401.mp4', 'http://timg.bdta.pro/images/c3c93d26fa94cdfb0e585598ad495974.jpg'),
(1709, 124, 'Castle S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/130402.mp4', 'http://timg.bdta.pro/images/cc5aff7c27a9c05e669ac200907562bf.jpg'),
(1710, 124, 'Castle S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/130403.mp4', 'http://timg.bdta.pro/images/6e1738bf6da270ec18f06a6c9cfa5200.jpg'),
(1711, 124, 'Castle S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/130404.mp4', 'http://timg.bdta.pro/images/8bc02130f982ce01b538a881d63bf1c7.jpg'),
(1712, 125, 'Castle S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130405.mp4', 'http://timg.bdta.pro/images/3ebbfb92e4f5efdb6a101d1d9ec3bc09.jpg'),
(1713, 125, 'Castle S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130406.mp4', 'http://timg.bdta.pro/images/37acf94cb48f98b98647b07a0ddf2bd3.jpg'),
(1714, 125, 'Castle S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130407.mp4', 'http://timg.bdta.pro/images/efdc65831fbbe50d05adb0a8b8b8cd59.jpg'),
(1715, 125, 'Castle S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130408.mp4', 'http://timg.bdta.pro/images/3d1a1c4c0907963d214848220067041e.jpg'),
(1716, 125, 'Castle S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130409.mp4', 'http://timg.bdta.pro/images/339eda0f780c693d95fd11c34ea0a989.jpg'),
(1717, 125, 'Castle S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130410.mp4', 'http://timg.bdta.pro/images/1f891f8a291d5556cf8ec1c62fc6ccec.jpg'),
(1718, 125, 'Castle S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130411.mp4', 'http://timg.bdta.pro/images/72c7cba47cefe5d20c9d98d23a98e75b.jpg'),
(1719, 125, 'Castle S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130412.mp4', 'http://timg.bdta.pro/images/e6816e982b28575c0834cb9ff3b03b4b.jpg'),
(1720, 125, 'Castle S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130413.mp4', 'http://timg.bdta.pro/images/4c5ad8aeb91cec0e83cf41195d6977eb.jpg'),
(1721, 125, 'Castle S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130414.mp4', 'http://timg.bdta.pro/images/f5c0ec9a67d8a01b09da68c7a12af316.jpg'),
(1722, 125, 'Castle S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/130415.mp4', 'http://timg.bdta.pro/images/fd58690f5775632cce474673eb8fdabb.jpg'),
(1723, 125, 'Castle S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/130416.mp4', 'http://timg.bdta.pro/images/0177bec456d1741ff7630439a15f8a9a.jpg'),
(1724, 125, 'Castle S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/130417.mp4', 'http://timg.bdta.pro/images/bf450fc3a9b7ac025cca560b31123f0b.jpg'),
(1725, 125, 'Castle S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/130418.mp4', 'http://timg.bdta.pro/images/22ad9127cd7cd2bf848dd5bb9079a085.jpg'),
(1726, 125, 'Castle S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/130419.mp4', 'http://timg.bdta.pro/images/478e960a13d99b775121bf713477e2c3.jpg'),
(1727, 125, 'Castle S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/130420.mp4', 'http://timg.bdta.pro/images/8dba4ad9de7884ce97fdd64ecbfbeb7f.jpg'),
(1728, 125, 'Castle S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/130421.mp4', 'http://timg.bdta.pro/images/ad962dea4e968a381ed64405e7cbdb12.jpg'),
(1729, 125, 'Castle S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/130422.mp4', 'http://timg.bdta.pro/images/15c7645431d18b5fa2015d4d370b3451.jpg'),
(1730, 125, 'Castle S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/130423.mp4', 'http://timg.bdta.pro/images/72be0f896bc70ada997ac8436b1c6e08.jpg'),
(1731, 125, 'Castle S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/130424.mp4', 'http://timg.bdta.pro/images/72ae9e496c97e64f811cd73da1cae78a.jpg'),
(1732, 125, 'Castle S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/130425.mp4', 'http://timg.bdta.pro/images/c59e097f4bfd9897426b8758f326fc31.jpg'),
(1733, 125, 'Castle S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/130426.mp4', 'http://timg.bdta.pro/images/9aa633a48d02fac529287f4d4652fab0.jpg'),
(1734, 125, 'Castle S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/130427.mp4', 'http://timg.bdta.pro/images/da45fb3d032f7d4a85bb45a5f06cd413.jpg'),
(1735, 126, 'Castle S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130428.mp4', 'http://timg.bdta.pro/images/6856b53e55480200dcabde42eee1981f.jpg'),
(1736, 126, 'Castle S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130429.mp4', 'http://timg.bdta.pro/images/f65170f513269ee088626c5eb8702cdd.jpg'),
(1737, 126, 'Castle S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130430.mp4', 'http://timg.bdta.pro/images/1ef2159a1db83eefa631d8d3d24ff8af.jpg'),
(1738, 126, 'Castle S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130431.mp4', 'http://timg.bdta.pro/images/9c72f8dd9e1aa7b6a06f5c4a91edf8c0.jpg'),
(1739, 126, 'Castle S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130432.mp4', 'http://timg.bdta.pro/images/6342f18872d20406fed467b2f8b5f797.jpg'),
(1740, 126, 'Castle S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130433.mp4', 'http://timg.bdta.pro/images/947feabf3edfab31f995daf4a1069d7b.jpg'),
(1741, 126, 'Castle S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130434.mp4', 'http://timg.bdta.pro/images/8b8dd62f605dbb3727943ad5a5891a9c.jpg'),
(1742, 126, 'Castle S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130435.mp4', 'http://timg.bdta.pro/images/5f165ba99a2499ccc027c77656d65752.jpg'),
(1743, 126, 'Castle S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130436.mp4', 'http://timg.bdta.pro/images/1aabc09cda6cbbc4319d84edc5707408.jpg'),
(1744, 126, 'Castle S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130437.mp4', 'http://timg.bdta.pro/images/805b9b4606abf435ba3463af018040a4.jpg'),
(1745, 126, 'Castle S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/130438.mp4', 'http://timg.bdta.pro/images/625e10655a5d5fef7fc3c3040af6a405.jpg'),
(1746, 126, 'Castle S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/130439.mp4', 'http://timg.bdta.pro/images/245024d6fb39a2876bd5c85b69dd71ec.jpg'),
(1747, 126, 'Castle S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/130440.mp4', 'http://timg.bdta.pro/images/dd0e0becf8155970e6df96265c287272.jpg'),
(1748, 126, 'Castle S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/130441.mp4', 'http://timg.bdta.pro/images/7e371c2166709f9367d8124ef1d3fefc.jpg'),
(1749, 126, 'Castle S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/130442.mp4', 'http://timg.bdta.pro/images/c3168d289b3e2e76293d2aeb05e7063c.jpg'),
(1750, 126, 'Castle S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/130443.mp4', 'http://timg.bdta.pro/images/c51ebaedec596be92c5ae1978c941d32.jpg'),
(1751, 126, 'Castle S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/130444.mp4', 'http://timg.bdta.pro/images/085e8383d382c812818b8248dc6124e1.jpg'),
(1752, 126, 'Castle S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/130445.mp4', 'http://timg.bdta.pro/images/60d4f8344051a5c0d7bc3386f4fe048a.jpg'),
(1753, 126, 'Castle S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/130446.mp4', 'http://timg.bdta.pro/images/4db61dbf53c769e751d88ffd7a2eb8ff.jpg'),
(1754, 126, 'Castle S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/130447.mp4', 'http://timg.bdta.pro/images/e2f7528975813fec11718c625135bc59.jpg'),
(1755, 126, 'Castle S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/130448.mp4', 'http://timg.bdta.pro/images/8b6f23fca7c01727b93d1c9501f2ce3b.jpg'),
(1756, 126, 'Castle S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/130449.mp4', 'http://timg.bdta.pro/images/128cbedea4511070e90f821f55295f8e.jpg'),
(1757, 126, 'Castle S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/130450.mp4', 'http://timg.bdta.pro/images/1306952a5334b71e69818f8112a75ebd.jpg'),
(1758, 127, 'Castle S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130451.mp4', 'http://timg.bdta.pro/images/2e024d4b7ff8006b45426df881c0095e.jpg'),
(1759, 127, 'Castle S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130452.mp4', 'http://timg.bdta.pro/images/34e75846ad1b9126fd34a0b732ab5aad.jpg'),
(1760, 127, 'Castle S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130453.mp4', 'http://timg.bdta.pro/images/7e62f1d0d7cd52447cf09a681e4b5400.jpg'),
(1761, 127, 'Castle S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130454.mp4', 'http://timg.bdta.pro/images/9c76302032f76e465ae7a26c27ba6285.jpg'),
(1762, 127, 'Castle S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130455.mp4', 'http://timg.bdta.pro/images/63b19a7aded31e276f05e53bb996cd38.jpg'),
(1763, 127, 'Castle S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130456.mp4', 'http://timg.bdta.pro/images/fc68bc065ce6099c3ed8eb13f67e0ff3.jpg'),
(1764, 127, 'Castle S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130457.mp4', 'http://timg.bdta.pro/images/02c9f226a0b953821a7530390cd383ab.jpg'),
(1765, 127, 'Castle S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130458.mp4', 'http://timg.bdta.pro/images/2cb870aba06039fda37208d222b3403d.jpg'),
(1766, 127, 'Castle S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130459.mp4', 'http://timg.bdta.pro/images/e6d47e5fa62423da0247e0a1af324fcb.jpg'),
(1767, 127, 'Castle S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130460.mp4', 'http://timg.bdta.pro/images/149d474e3857f590143f775b01e4b590.jpg'),
(1768, 127, 'Castle S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/130461.mp4', 'http://timg.bdta.pro/images/65d9fb1236c6a46960452f6dad411d74.jpg'),
(1769, 127, 'Castle S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/130462.mp4', 'http://timg.bdta.pro/images/e126cc14e3a4408084cc5655a23ddd4a.jpg'),
(1770, 127, 'Castle S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/130463.mp4', 'http://timg.bdta.pro/images/3213957e227227a2a41782b339d97b95.jpg'),
(1771, 127, 'Castle S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/130464.mp4', 'http://timg.bdta.pro/images/f7730e5bbe0f77b1f6b3d208dec5f8b9.jpg'),
(1772, 127, 'Castle S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/130465.mp4', 'http://timg.bdta.pro/images/32f8d5e61a06093293b7479e1f4e640e.jpg'),
(1773, 127, 'Castle S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/130466.mp4', 'http://timg.bdta.pro/images/812553477c5c618ae3d197360bf96425.jpg'),
(1774, 127, 'Castle S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/130467.mp4', 'http://timg.bdta.pro/images/055bb691cdb0d93b546076ea6ba537a1.jpg'),
(1775, 127, 'Castle S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/130468.mp4', 'http://timg.bdta.pro/images/61ada2bbb09dc4608d3cb85e47f95e7e.jpg'),
(1776, 127, 'Castle S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/130469.mp4', 'http://timg.bdta.pro/images/f8c6e75dcc61f5bc54fc46e21f3266b4.jpg'),
(1777, 127, 'Castle S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/130470.mp4', 'http://timg.bdta.pro/images/a89acb51ba82739ed3db5bfbc373a26e.jpg'),
(1778, 127, 'Castle S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/130471.mp4', 'http://timg.bdta.pro/images/aa57c473be836580e6affb7c64a9ee1e.jpg'),
(1779, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1780, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1781, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1782, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1783, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1784, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1785, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1786, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1787, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1788, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1789, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1790, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1791, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1792, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1793, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1794, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1795, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/220976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1796, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/220977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1797, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/220978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1798, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/220979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1799, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/220980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1800, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/220981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1801, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/220982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1802, 128, 'Chicago Fire: Heróis Contra o Fogo S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/220983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1803, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1804, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1805, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1806, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1807, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1808, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1809, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1810, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1811, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1812, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1813, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1814, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1815, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1816, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1817, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1818, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1819, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/221000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1820, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/221001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1821, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/221002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1822, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/221003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1823, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/221004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1824, 129, 'Chicago Fire: Heróis Contra o Fogo S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/221005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1825, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1826, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1827, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1828, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1829, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1830, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1831, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1832, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1833, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1834, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1835, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1836, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1837, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1838, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/221019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1839, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/221020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1840, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/221021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1841, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/221022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1842, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/221023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1843, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/221024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1844, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/221025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1845, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/221026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1846, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/221027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1847, 130, 'Chicago Fire: Heróis Contra o Fogo S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/221028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1848, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1849, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1850, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1851, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1852, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1853, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1854, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1855, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1856, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1857, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1858, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1859, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1860, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1861, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/221042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1862, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/221043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1863, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/221044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1864, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/221045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1865, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/221046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1866, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/221047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1867, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/221048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1868, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/221049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1869, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/221050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1870, 131, 'Chicago Fire: Heróis Contra o Fogo S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/221051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1871, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1872, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1873, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1874, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1875, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1876, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1877, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1878, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1879, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1880, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1881, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1882, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1883, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1884, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/221065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1885, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/221066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1886, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/221067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1887, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/221068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1888, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/221069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1889, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/221070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1890, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/221071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1891, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/221072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1892, 132, 'Chicago Fire: Heróis Contra o Fogo S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/221073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1893, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1894, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1895, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1896, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1897, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1898, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1899, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1900, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1901, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1902, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1903, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1904, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1905, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1906, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/221087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1907, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/221088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1908, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/221089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1909, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/221090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1910, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/221091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1911, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/221092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1912, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/221093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1913, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/221094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1914, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/221095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1915, 133, 'Chicago Fire: Heróis Contra o Fogo S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/221096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1916, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1917, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1918, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1919, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1920, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1921, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1922, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1923, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1924, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1925, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1926, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1927, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1928, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1929, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/221110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1930, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/221111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1931, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/221112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1932, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/221113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1933, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/221114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1934, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/221115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1935, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/221116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1936, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/221117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1937, 134, 'Chicago Fire: Heróis Contra o Fogo S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/221118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1938, 135, 'Chicago Fire: Heróis Contra o Fogo S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221119.mp4', 'http://timg.bdta.pro/images/2d1e0b39385ed9fb5140d7668fd8654c.jpg'),
(1939, 135, 'Chicago Fire: Heróis Contra o Fogo S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221120.mp4', 'http://timg.bdta.pro/images/280dd4114f3ce48ed1250d60aa1e09cc.jpg'),
(1940, 135, 'Chicago Fire: Heróis Contra o Fogo S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221121.mp4', 'http://timg.bdta.pro/images/f01017157c292262f13a782b10291a3f.jpg'),
(1941, 135, 'Chicago Fire: Heróis Contra o Fogo S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221122.mp4', 'http://timg.bdta.pro/images/7db4a72bb506a94f139166b21b6ed8e6.jpg'),
(1942, 135, 'Chicago Fire: Heróis Contra o Fogo S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221123.mp4', 'http://timg.bdta.pro/images/28249c373317d63968aef3969db29a40.jpg'),
(1943, 135, 'Chicago Fire: Heróis Contra o Fogo S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221124.mp4', 'http://timg.bdta.pro/images/4af61f2f7e818eb61fe91641d84628be.jpg'),
(1944, 135, 'Chicago Fire: Heróis Contra o Fogo S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221125.mp4', 'http://timg.bdta.pro/images/214b1b1589b19528112194ef2513d9f2.jpg'),
(1945, 135, 'Chicago Fire: Heróis Contra o Fogo S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221126.mp4', 'http://timg.bdta.pro/images/1bdc4c48c44bc3a194902e47fa1dc71c.jpg'),
(1946, 135, 'Chicago Fire: Heróis Contra o Fogo S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221127.mp4', 'http://timg.bdta.pro/images/8159dc29aeb0a1c3403e4ff2f52615d9.jpg'),
(1947, 135, 'Chicago Fire: Heróis Contra o Fogo S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221128.mp4', 'http://timg.bdta.pro/images/06eed33e12e181d2981c71882187dd60.jpg'),
(1948, 135, 'Chicago Fire: Heróis Contra o Fogo S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221129.mp4', 'http://timg.bdta.pro/images/414bec7f7525b4e6a0ea830083d9c8b5.jpg'),
(1949, 135, 'Chicago Fire: Heróis Contra o Fogo S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221130.mp4', 'http://timg.bdta.pro/images/09dd158bbe1f60e5193e7d44c0b2f6fe.jpg'),
(1950, 135, 'Chicago Fire: Heróis Contra o Fogo S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221131.mp4', 'http://timg.bdta.pro/images/b23c17f9cd6fe98765a37c2be6cc4259.jpg'),
(1951, 135, 'Chicago Fire: Heróis Contra o Fogo S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/221132.mp4', 'http://timg.bdta.pro/images/6878d3b56a8d784ad1dc09a34b554264.jpg'),
(1952, 135, 'Chicago Fire: Heróis Contra o Fogo S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/221133.mp4', 'http://timg.bdta.pro/images/240346258d27199878b6b46d544bd887.jpg'),
(1953, 135, 'Chicago Fire: Heróis Contra o Fogo S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/221134.mp4', 'http://timg.bdta.pro/images/71b1e7d87cf3594672828f03f9fe5e9f.jpg'),
(1954, 135, 'Chicago Fire: Heróis Contra o Fogo S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/221135.mp4', 'http://timg.bdta.pro/images/48b764b2954c4595ec4d65b810cd8c8e.jpg'),
(1955, 135, 'Chicago Fire: Heróis Contra o Fogo S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/221136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1956, 135, 'Chicago Fire: Heróis Contra o Fogo S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/221137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1957, 135, 'Chicago Fire: Heróis Contra o Fogo S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/221138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1958, 136, 'Chicago Fire: Heróis Contra o Fogo S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1959, 136, 'Chicago Fire: Heróis Contra o Fogo S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1960, 136, 'Chicago Fire: Heróis Contra o Fogo S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1961, 136, 'Chicago Fire: Heróis Contra o Fogo S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(1962, 136, 'Chicago Fire: Heróis Contra o Fogo S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1963, 136, 'Chicago Fire: Heróis Contra o Fogo S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1964, 136, 'Chicago Fire: Heróis Contra o Fogo S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1965, 136, 'Chicago Fire: Heróis Contra o Fogo S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1966, 136, 'Chicago Fire: Heróis Contra o Fogo S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1967, 136, 'Chicago Fire: Heróis Contra o Fogo S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1968, 136, 'Chicago Fire: Heróis Contra o Fogo S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1969, 136, 'Chicago Fire: Heróis Contra o Fogo S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1970, 136, 'Chicago Fire: Heróis Contra o Fogo S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1971, 136, 'Chicago Fire: Heróis Contra o Fogo S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/221152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1972, 136, 'Chicago Fire: Heróis Contra o Fogo S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/221153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1973, 136, 'Chicago Fire: Heróis Contra o Fogo S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/221154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(1974, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221155.mp4', 'http://image.tmdb.org/t/p/w1280/4zdAar3wf1uowp79GpLk20Yx9LL.jpg'),
(1975, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221156.mp4', 'http://timg.bdta.pro/images/b777f3974f89c062ede958f3f9b1d49f.jpg'),
(1976, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221157.mp4', 'http://timg.bdta.pro/images/90106360d21b775e0c7de3a15898390b.jpg'),
(1977, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221158.mp4', 'http://timg.bdta.pro/images/67c73eabae9347a0e8eef063664cb7a9.jpg'),
(1978, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221159.mp4', 'http://timg.bdta.pro/images/68e4a501909281f523e8058c33e45353.jpg'),
(1979, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221160.mp4', 'http://timg.bdta.pro/images/0a7e2641749de237e5b1a7e6da7eb964.jpg'),
(1980, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221161.mp4', 'http://timg.bdta.pro/images/4dfa7bf3929790fd5786bb236ad2780c.jpg'),
(1981, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221162.mp4', 'http://timg.bdta.pro/images/ae85037e076af2b2e41b9a31f4894287.jpg'),
(1982, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221163.mp4', 'http://timg.bdta.pro/images/441975d9fce567a068e3c13e1608f383.jpg'),
(1983, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221164.mp4', 'http://timg.bdta.pro/images/c973bacbc8e8b6be2488cf3c21e287aa.jpg'),
(1984, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221165.mp4', 'http://timg.bdta.pro/images/03d3fa8228e92bb67aa93dd6213d071d.jpg'),
(1985, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221166.mp4', 'http://timg.bdta.pro/images/e09a116388ac35e0d736a0b236b17ec1.jpg'),
(1986, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221167.mp4', 'http://timg.bdta.pro/images/73edcab87b2e3601b8e93eeaa97e9181.jpg'),
(1987, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/221168.mp4', 'http://timg.bdta.pro/images/278eb2c33c63652edf05f393f0087a77.jpg'),
(1988, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/221169.mp4', 'http://timg.bdta.pro/images/ce4c9fa7d89a5052df59d773ce62b565.jpg'),
(1989, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/221170.mp4', 'http://timg.bdta.pro/images/9b3f160baad73923003e6ac981078fbe.jpg'),
(1990, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/221171.mp4', 'http://timg.bdta.pro/images/eb28192d300c31f633ea161d11a34036.jpg'),
(1991, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/221172.mp4', 'http://timg.bdta.pro/images/7aaabbfc25abb1c68d6706343690dcc2.jpg'),
(1992, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/221173.mp4', 'http://timg.bdta.pro/images/6037fa9afc5bb404b7dd20bd95025129.jpg'),
(1993, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/221174.mp4', 'http://timg.bdta.pro/images/6607ffbcfbde2b76e4db7fd45f3f78de.jpg'),
(1994, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/221175.mp4', 'http://timg.bdta.pro/images/447868551ec0d6fb769d3f9d7ef28e8a.jpg'),
(1995, 137, 'Chicago Fire: Heróis Contra o Fogo S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/221176.mp4', 'http://timg.bdta.pro/images/9040c60af8821b555a2e691e9d34516b.jpg'),
(1996, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221177.mp4', 'http://image.tmdb.org/t/p/w1280/fDtHKKfcVU1KGsfK3mUGlUjIleT.jpg'),
(1997, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221178.mp4', 'http://image.tmdb.org/t/p/w1280/uVVH5gSBwpYHYtyRowtdVmfj1Fo.jpg'),
(1998, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221179.mp4', 'http://image.tmdb.org/t/p/w1280/r5KpIps8nfETPk5vPzKJXi8doB9.jpg'),
(1999, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221180.mp4', 'http://image.tmdb.org/t/p/w1280/pWqSIKzf6gqaalUx4ad6nE3Puio.jpg'),
(2000, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221181.mp4', 'http://image.tmdb.org/t/p/w1280/k0xYl5dey89xhws9Pc9trT9pMBx.jpg'),
(2001, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221182.mp4', 'http://image.tmdb.org/t/p/w1280/kbvBybyuBcDC9hMDwUMoCo20Vfe.jpg'),
(2002, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221183.mp4', 'http://image.tmdb.org/t/p/w1280/n7l4nHzsWhkHrFCfnMB4lJRPk3H.jpg'),
(2003, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221184.mp4', 'http://image.tmdb.org/t/p/w1280/ltN0Ppt4GJ7oFIWgNGGuqgaLIkf.jpg'),
(2004, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k7ZJqhOJ4uLOx5RJlJQck9rrwF0.jpg'),
(2005, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3FuibbwcXUvpUjoh58LikZtBY1.jpg'),
(2006, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vqbLZ6EUi77GHj3ZRbJJFI682W.jpg'),
(2007, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hErcJV62tQ2SowDEh8UEs3NQv75.jpg'),
(2008, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y5tyLM19L8FtLWsXmvW6z0Uq7MF.jpg'),
(2009, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/221190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xI5aAqxwdYb4RhntCDmvlZdSCQX.jpg'),
(2010, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/221191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8HUCqtcVRCHQJeL0x4c6zCvRV7X.jpg'),
(2011, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/221192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cvqqyPv96DdXF4WR62gKkTKvzdm.jpg'),
(2012, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/221193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gaO4yxRSOs3FrdTdX4ABrAjIMTv.jpg'),
(2013, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/221194.mp4', 'http://image.tmdb.org/t/p/w1280/90TANAihR3nrqJ6rbmItLk3QnNV.jpg'),
(2014, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/221195.mp4', 'http://image.tmdb.org/t/p/w1280/fgXMtpZjEvlWogbxAmtfpv35z7l.jpg'),
(2015, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/221196.mp4', 'http://image.tmdb.org/t/p/w1280/4TOtXbkCTYehIM4YG7FFGcpxoFC.jpg'),
(2016, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/221197.mp4', 'http://image.tmdb.org/t/p/w1280/mQR31T5JzcTGsn49SKJEnqz5kbU.jpg'),
(2017, 138, 'Chicago Fire: Heróis Contra o Fogo S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/221198.mp4', 'http://image.tmdb.org/t/p/w1280/d7bV2YwmMYPRW059BDg1XSw5DFt.jpg'),
(2018, 139, 'Chicago Fire: Heróis Contra o Fogo S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/311516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2019, 139, 'Chicago Fire: Heróis Contra o Fogo S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/318865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2020, 139, 'Chicago Fire: Heróis Contra o Fogo S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2021, 139, 'Chicago Fire: Heróis Contra o Fogo S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/328901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2022, 139, 'Chicago Fire: Heróis Contra o Fogo S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/333850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2023, 139, 'Chicago Fire: Heróis Contra o Fogo S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/341821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2024, 139, 'Chicago Fire: Heróis Contra o Fogo S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2025, 139, 'Chicago Fire: Heróis Contra o Fogo S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2026, 139, 'Chicago Fire: Heróis Contra o Fogo S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/360334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2027, 139, 'Chicago Fire: Heróis Contra o Fogo S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/369680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2028, 139, 'Chicago Fire: Heróis Contra o Fogo S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/375179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2029, 139, 'Chicago Fire: Heróis Contra o Fogo S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/385033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2030, 139, 'Chicago Fire: Heróis Contra o Fogo S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/397821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2031, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/677108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2032, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/680557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2033, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/691505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2034, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/694301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2035, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/707279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2036, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/709951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2037, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/711336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2038, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/725957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2039, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/735468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2040, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/740639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2041, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/755779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2042, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/768367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2043, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/770205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2044, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/781455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2045, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/786024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2046, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/791256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2047, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/803788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2048, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/813951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2049, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/839049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2050, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/839050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2051, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/844073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2052, 140, 'Chicago Fire: Heróis Contra o Fogo S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/852010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2053, 141, 'Chicago Fire: Heróis Contra o Fogo S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/891066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2054, 141, 'Chicago Fire: Heróis Contra o Fogo S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/892481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2055, 141, 'Chicago Fire: Heróis Contra o Fogo S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/892670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2056, 141, 'Chicago Fire: Heróis Contra o Fogo S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/893478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2057, 141, 'Chicago Fire: Heróis Contra o Fogo S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/894235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iD8lx0VgmpCZMhycI0Xw72wCuRS.jpg'),
(2058, 142, 'Chicago Med: Atendimento de Emergência S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220797.mp4', 'http://image.tmdb.org/t/p/w1280/zgO40DcRVc3sh9vg9CpRoaICn0a.jpg'),
(2059, 142, 'Chicago Med: Atendimento de Emergência S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220798.mp4', 'http://image.tmdb.org/t/p/w1280/sTsALfOcSgzuev7DBDYxfqgHIys.jpg'),
(2060, 142, 'Chicago Med: Atendimento de Emergência S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220799.mp4', 'http://image.tmdb.org/t/p/w1280/fepPfWcmxxhUG6YAocvF46z5F4Z.jpg'),
(2061, 142, 'Chicago Med: Atendimento de Emergência S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220800.mp4', 'http://image.tmdb.org/t/p/w1280/m0f2e3PUDSzxWsurEvgJ4zgEOD1.jpg'),
(2062, 142, 'Chicago Med: Atendimento de Emergência S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220801.mp4', 'http://image.tmdb.org/t/p/w1280/tXPSludLRIDMdjnyeYYccUuapZH.jpg'),
(2063, 142, 'Chicago Med: Atendimento de Emergência S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220802.mp4', 'http://image.tmdb.org/t/p/w1280/edmspadQG2JuXfFhybJYHvmRmPp.jpg'),
(2064, 142, 'Chicago Med: Atendimento de Emergência S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220803.mp4', 'http://image.tmdb.org/t/p/w1280/2U9BpVEHmc0eflW1AbzP7WzoeJ2.jpg'),
(2065, 142, 'Chicago Med: Atendimento de Emergência S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220804.mp4', 'http://image.tmdb.org/t/p/w1280/vTIVLRhdPasn9ScpF9VsGIbT8WV.jpg'),
(2066, 142, 'Chicago Med: Atendimento de Emergência S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220805.mp4', 'http://image.tmdb.org/t/p/w1280/8d7prpxtd8GfbbwJ75SNef9yERa.jpg'),
(2067, 142, 'Chicago Med: Atendimento de Emergência S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220806.mp4', 'http://image.tmdb.org/t/p/w1280/mCUfJNIh4zfFZheVR1NAdflxjtL.jpg'),
(2068, 142, 'Chicago Med: Atendimento de Emergência S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220807.mp4', 'http://image.tmdb.org/t/p/w1280/zY3fqztdhXg5wOR9jSGQgoiVAvw.jpg'),
(2069, 142, 'Chicago Med: Atendimento de Emergência S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220808.mp4', 'http://image.tmdb.org/t/p/w1280/gi0e3nVID3AHMflcgTnZDw4nYDi.jpg'),
(2070, 142, 'Chicago Med: Atendimento de Emergência S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220809.mp4', 'http://image.tmdb.org/t/p/w1280/yP2owYh6HhlXPElgLOO9nFnjmoJ.jpg'),
(2071, 142, 'Chicago Med: Atendimento de Emergência S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220810.mp4', 'http://image.tmdb.org/t/p/w1280/kkXtDKwRWDOI5rIPsT8KcamZoRs.jpg'),
(2072, 142, 'Chicago Med: Atendimento de Emergência S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220811.mp4', 'http://image.tmdb.org/t/p/w1280/wkrMMFic0esHP8W6IQbRIclsYlN.jpg'),
(2073, 142, 'Chicago Med: Atendimento de Emergência S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220812.mp4', 'http://image.tmdb.org/t/p/w1280/k003JZvSIk9r0iyYozSXmbWlA1d.jpg'),
(2074, 142, 'Chicago Med: Atendimento de Emergência S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/220813.mp4', 'http://image.tmdb.org/t/p/w1280/ew3dDVsOPhuYdBXuHLmLCP3o64f.jpg'),
(2075, 142, 'Chicago Med: Atendimento de Emergência S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/220814.mp4', 'http://image.tmdb.org/t/p/w1280/zRLUINlG4xSJVXD4SkNaQ0JuaZ0.jpg'),
(2076, 143, 'Chicago Med: Atendimento de Emergência S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220815.mp4', 'http://image.tmdb.org/t/p/w1280/8ibEZlJlpMUv3FneGcRzsdVBwD.jpg'),
(2077, 143, 'Chicago Med: Atendimento de Emergência S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220816.mp4', 'http://image.tmdb.org/t/p/w1280/9W4zvmTLqDXGsOeLSXsKtlcKoRH.jpg'),
(2078, 143, 'Chicago Med: Atendimento de Emergência S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220817.mp4', 'http://image.tmdb.org/t/p/w1280/1kJt6R7FZFjWsZeO3tclOR3gZW.jpg'),
(2079, 143, 'Chicago Med: Atendimento de Emergência S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220818.mp4', 'http://image.tmdb.org/t/p/w1280/jAUFGofrlz5tEiTzToEzch6y24H.jpg'),
(2080, 143, 'Chicago Med: Atendimento de Emergência S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220819.mp4', 'http://image.tmdb.org/t/p/w1280/ufpmvF4mfhMvoJPZBsMsHCPqctR.jpg'),
(2081, 143, 'Chicago Med: Atendimento de Emergência S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220820.mp4', 'http://image.tmdb.org/t/p/w1280/aB7iFtqJptH2NHJqdETIetEIIzc.jpg'),
(2082, 143, 'Chicago Med: Atendimento de Emergência S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220821.mp4', 'http://image.tmdb.org/t/p/w1280/daHzYyvoYj9m7m0wkd7q6OLulB0.jpg'),
(2083, 143, 'Chicago Med: Atendimento de Emergência S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220822.mp4', 'http://image.tmdb.org/t/p/w1280/wceQwzHAdYpin0NRJmekUobFkHg.jpg'),
(2084, 143, 'Chicago Med: Atendimento de Emergência S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220823.mp4', 'http://image.tmdb.org/t/p/w1280/lOet2Sufni16mzROEM05srgTp2w.jpg'),
(2085, 143, 'Chicago Med: Atendimento de Emergência S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220824.mp4', 'http://image.tmdb.org/t/p/w1280/tKlksOJ3qBmvQI0qJ5oVT3CGoJR.jpg'),
(2086, 143, 'Chicago Med: Atendimento de Emergência S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220825.mp4', 'http://image.tmdb.org/t/p/w1280/vB4qh4PQApI2dzFqRRV4uTKAraR.jpg'),
(2087, 143, 'Chicago Med: Atendimento de Emergência S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220826.mp4', 'http://image.tmdb.org/t/p/w1280/t4Q3HM3Nh9mo1h1HJLhWaDaaRBi.jpg'),
(2088, 143, 'Chicago Med: Atendimento de Emergência S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220827.mp4', 'http://image.tmdb.org/t/p/w1280/ccVoPhf9XBpSQXUpR0dD0fh5HYk.jpg'),
(2089, 143, 'Chicago Med: Atendimento de Emergência S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220828.mp4', 'http://image.tmdb.org/t/p/w1280/4OZnOBTSLWfhmS2xHYYU2ZZoeVu.jpg'),
(2090, 143, 'Chicago Med: Atendimento de Emergência S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220829.mp4', 'http://image.tmdb.org/t/p/w1280/pDMoUwnoJHkKjjLV9gTj04kVUNh.jpg'),
(2091, 143, 'Chicago Med: Atendimento de Emergência S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220830.mp4', 'http://image.tmdb.org/t/p/w1280/kdPgZuANTcXhZtpEfYhLJwyDMkF.jpg'),
(2092, 143, 'Chicago Med: Atendimento de Emergência S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/220831.mp4', 'http://image.tmdb.org/t/p/w1280/3qZszmIvpcfmWSDxTU4GNrn3IEv.jpg'),
(2093, 143, 'Chicago Med: Atendimento de Emergência S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/220832.mp4', 'http://image.tmdb.org/t/p/w1280/iMRvarA0H5kj7eBzQsjuvrfdAJ4.jpg'),
(2094, 143, 'Chicago Med: Atendimento de Emergência S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/220833.mp4', 'http://image.tmdb.org/t/p/w1280/eUCGd5R8nRztPoCGD6sDbHhNZXC.jpg'),
(2095, 143, 'Chicago Med: Atendimento de Emergência S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/220834.mp4', 'http://image.tmdb.org/t/p/w1280/ntGPuwmYOwqhIHeJ73cs8TJp7F4.jpg'),
(2096, 143, 'Chicago Med: Atendimento de Emergência S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/220835.mp4', 'http://image.tmdb.org/t/p/w1280/fj3U3MnXj3wP7wYhrDJki6ABIv.jpg'),
(2097, 143, 'Chicago Med: Atendimento de Emergência S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/220836.mp4', 'http://image.tmdb.org/t/p/w1280/wDJv2XKJF9oMcmnExtTOq3CQ4d0.jpg'),
(2098, 143, 'Chicago Med: Atendimento de Emergência S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/220837.mp4', 'http://image.tmdb.org/t/p/w1280/4BoFJ18SZSamxjlPjZuk3DrVujX.jpg'),
(2099, 144, 'Chicago Med: Atendimento de Emergência S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220838.mp4', 'http://image.tmdb.org/t/p/w1280/1o81cTezj9TsVuWjC0uyjLSID9g.jpg'),
(2100, 144, 'Chicago Med: Atendimento de Emergência S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220839.mp4', 'http://image.tmdb.org/t/p/w1280/lnGtRI349MacnWiSswAuUiepg10.jpg'),
(2101, 144, 'Chicago Med: Atendimento de Emergência S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220840.mp4', 'http://image.tmdb.org/t/p/w1280/gnfw8lO2gXBpRHpcAtkejxN9Yl8.jpg'),
(2102, 144, 'Chicago Med: Atendimento de Emergência S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220841.mp4', 'http://image.tmdb.org/t/p/w1280/xBMVuM5LaxJkGdILTvWLZQTd312.jpg'),
(2103, 144, 'Chicago Med: Atendimento de Emergência S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220842.mp4', 'http://image.tmdb.org/t/p/w1280/peBTyOOsTWS3loNZH4ngW0m8DCI.jpg'),
(2104, 144, 'Chicago Med: Atendimento de Emergência S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220843.mp4', 'http://image.tmdb.org/t/p/w1280/3xCHQzE0h1cu9Es9ZNsNlaqRPHo.jpg'),
(2105, 144, 'Chicago Med: Atendimento de Emergência S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220844.mp4', 'http://image.tmdb.org/t/p/w1280/uDBENGEhFMuNtMMc05J2Ft9F35R.jpg'),
(2106, 144, 'Chicago Med: Atendimento de Emergência S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220845.mp4', 'http://image.tmdb.org/t/p/w1280/rkB3EMKwZRdSlVEyBa524hOq6fL.jpg'),
(2107, 144, 'Chicago Med: Atendimento de Emergência S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220846.mp4', 'http://image.tmdb.org/t/p/w1280/pJDHpurNl0iGWZY4hBEsa12c7cz.jpg'),
(2108, 144, 'Chicago Med: Atendimento de Emergência S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220847.mp4', 'http://image.tmdb.org/t/p/w1280/6klGQ9psCgXfRHb3UXiM56AsUtY.jpg'),
(2109, 144, 'Chicago Med: Atendimento de Emergência S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220848.mp4', 'http://image.tmdb.org/t/p/w1280/tQ6YO3Fhes3fIPjtDJpTvxh14qt.jpg'),
(2110, 144, 'Chicago Med: Atendimento de Emergência S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220849.mp4', 'http://image.tmdb.org/t/p/w1280/3G1hBSFtcTwlV1PgFpmSZdiCj9N.jpg'),
(2111, 144, 'Chicago Med: Atendimento de Emergência S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220850.mp4', 'http://image.tmdb.org/t/p/w1280/gzkgOS32yt7voqfWcFU0LZZpLEU.jpg'),
(2112, 144, 'Chicago Med: Atendimento de Emergência S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220851.mp4', 'http://image.tmdb.org/t/p/w1280/hHSU6kgeymjmrFPJCCFWqjXL7L2.jpg'),
(2113, 144, 'Chicago Med: Atendimento de Emergência S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220852.mp4', 'http://image.tmdb.org/t/p/w1280/p4qNF4OQPDixiooWaBtrr7c6lbz.jpg'),
(2114, 144, 'Chicago Med: Atendimento de Emergência S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220853.mp4', 'http://image.tmdb.org/t/p/w1280/lnFfg85pUiHNvxToTHBjr7fVtvG.jpg'),
(2115, 144, 'Chicago Med: Atendimento de Emergência S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/220854.mp4', 'http://image.tmdb.org/t/p/w1280/jy9d0Oh9aWdvdoGKtMpv4O0UTe9.jpg'),
(2116, 144, 'Chicago Med: Atendimento de Emergência S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/220855.mp4', 'http://image.tmdb.org/t/p/w1280/avwMFoZppfV0VBYz8VZamwgasFK.jpg'),
(2117, 144, 'Chicago Med: Atendimento de Emergência S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/220856.mp4', 'http://image.tmdb.org/t/p/w1280/A9qSgANGDFdGLmyZJNj5AsFyb7M.jpg'),
(2118, 144, 'Chicago Med: Atendimento de Emergência S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/220857.mp4', 'http://image.tmdb.org/t/p/w1280/xpz8Dj7EOjh4fVTteFpVOdfbAL2.jpg'),
(2119, 145, 'Chicago Med: Atendimento de Emergência S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220858.mp4', 'http://image.tmdb.org/t/p/w1280/uwS5zxtikpVRHAgPhFjKecx3ErD.jpg'),
(2120, 145, 'Chicago Med: Atendimento de Emergência S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220859.mp4', 'http://image.tmdb.org/t/p/w1280/wEHD8qgeDb5cz3sI86tWziMl5Lt.jpg'),
(2121, 145, 'Chicago Med: Atendimento de Emergência S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220860.mp4', 'http://image.tmdb.org/t/p/w1280/mKSXZLCRYm6SjAUqao0cVwgAfL0.jpg'),
(2122, 145, 'Chicago Med: Atendimento de Emergência S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220861.mp4', 'http://image.tmdb.org/t/p/w1280/v4u9paIUV9GVbxLZGx9a0MTDsfc.jpg'),
(2123, 145, 'Chicago Med: Atendimento de Emergência S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220862.mp4', 'http://image.tmdb.org/t/p/w1280/kqr3UTrrR2KVwgTPafNxMgy3owb.jpg'),
(2124, 145, 'Chicago Med: Atendimento de Emergência S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220863.mp4', 'http://image.tmdb.org/t/p/w1280/6LwqoefPHCP1c5eAT9cKeR1AeD1.jpg'),
(2125, 145, 'Chicago Med: Atendimento de Emergência S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220864.mp4', 'http://image.tmdb.org/t/p/w1280/9MC4FJplPNjw3hf5vrQyi4a3kXz.jpg'),
(2126, 145, 'Chicago Med: Atendimento de Emergência S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220865.mp4', 'http://image.tmdb.org/t/p/w1280/srN51RpnDJWQO517eqMn2wccyrr.jpg'),
(2127, 145, 'Chicago Med: Atendimento de Emergência S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220866.mp4', 'http://image.tmdb.org/t/p/w1280/ryyLzd7sK1IkUB5G6jkL2IWIR1T.jpg'),
(2128, 145, 'Chicago Med: Atendimento de Emergência S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220867.mp4', 'http://image.tmdb.org/t/p/w1280/fls9zoGwnzgLTW19jIMFnmeu2Kd.jpg'),
(2129, 145, 'Chicago Med: Atendimento de Emergência S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220868.mp4', 'http://image.tmdb.org/t/p/w1280/fzdzlQawcoZJdEyAeKNpO7EkcAe.jpg'),
(2130, 145, 'Chicago Med: Atendimento de Emergência S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220869.mp4', 'http://image.tmdb.org/t/p/w1280/yXff7CSCEC9mnecbEpfOjr0Kphl.jpg'),
(2131, 145, 'Chicago Med: Atendimento de Emergência S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220870.mp4', 'http://image.tmdb.org/t/p/w1280/7fbn6mdZ30gzXusXOLmd2RNLW6X.jpg'),
(2132, 145, 'Chicago Med: Atendimento de Emergência S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220871.mp4', 'http://image.tmdb.org/t/p/w1280/rkAoMbXO15LWg3hPCiHItnjfsV8.jpg'),
(2133, 145, 'Chicago Med: Atendimento de Emergência S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220872.mp4', 'http://image.tmdb.org/t/p/w1280/ae159QlfXuV3ax6aYcDoYUnfJVa.jpg'),
(2134, 145, 'Chicago Med: Atendimento de Emergência S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220873.mp4', 'http://image.tmdb.org/t/p/w1280/7oOJRIUFXzI5fu0QniUPfCzIhfe.jpg'),
(2135, 145, 'Chicago Med: Atendimento de Emergência S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/220874.mp4', 'http://image.tmdb.org/t/p/w1280/c7b7NBF6bOcgtMYf3FsU1K0yPRc.jpg'),
(2136, 145, 'Chicago Med: Atendimento de Emergência S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/220875.mp4', 'http://image.tmdb.org/t/p/w1280/otIOkfxJm7bI0aMiayTRRazpfNz.jpg'),
(2137, 145, 'Chicago Med: Atendimento de Emergência S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/220876.mp4', 'http://image.tmdb.org/t/p/w1280/tjknQ8yFluiLQw0e4hYgnD8t705.jpg'),
(2138, 145, 'Chicago Med: Atendimento de Emergência S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/220877.mp4', 'http://image.tmdb.org/t/p/w1280/jhXcqfEzk13UOwp8xiWxXVEGkN2.jpg'),
(2139, 145, 'Chicago Med: Atendimento de Emergência S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/220878.mp4', 'http://image.tmdb.org/t/p/w1280/uT9CmeYDeU56AhoFZyg05WDzumH.jpg'),
(2140, 145, 'Chicago Med: Atendimento de Emergência S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/220879.mp4', 'http://image.tmdb.org/t/p/w1280/1r5ZLjqNB2MU3cYp2zmZBKeEflR.jpg'),
(2141, 146, 'Chicago Med: Atendimento de Emergência S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220880.mp4', 'http://image.tmdb.org/t/p/w1280/11c8wdYzrt7X7OIIGrJP69pKzem.jpg'),
(2142, 146, 'Chicago Med: Atendimento de Emergência S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220881.mp4', 'http://image.tmdb.org/t/p/w1280/q9A0XEiKBfcFnj10BpiASmh6DB8.jpg'),
(2143, 146, 'Chicago Med: Atendimento de Emergência S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220882.mp4', 'http://image.tmdb.org/t/p/w1280/fRt5Vpo3Dii5tb4BYe2fO04pxsN.jpg'),
(2144, 146, 'Chicago Med: Atendimento de Emergência S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220883.mp4', 'http://image.tmdb.org/t/p/w1280/bAdCjy62tm4wFYuIXr5rypt6byS.jpg'),
(2145, 146, 'Chicago Med: Atendimento de Emergência S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220884.mp4', 'http://image.tmdb.org/t/p/w1280/wtWhhXjpKYo4L4vPAYIDmOKlE5P.jpg'),
(2146, 146, 'Chicago Med: Atendimento de Emergência S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220885.mp4', 'http://image.tmdb.org/t/p/w1280/6UMQ4njei4bDWJF9FcHJVJmZOHm.jpg'),
(2147, 146, 'Chicago Med: Atendimento de Emergência S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220886.mp4', 'http://image.tmdb.org/t/p/w1280/c9A9MLNXmheX2jhnGVE3rGxRU0o.jpg'),
(2148, 146, 'Chicago Med: Atendimento de Emergência S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220887.mp4', 'http://image.tmdb.org/t/p/w1280/2TXwwRFRbcwWI4jf9ByNqwyjWUK.jpg'),
(2149, 146, 'Chicago Med: Atendimento de Emergência S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220888.mp4', 'http://image.tmdb.org/t/p/w1280/9b2a5OPe57CN7drtdBa6xSd6YiD.jpg'),
(2150, 146, 'Chicago Med: Atendimento de Emergência S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220889.mp4', 'http://image.tmdb.org/t/p/w1280/oweJmVAuBUil1RfwSMfggVAbFZN.jpg'),
(2151, 146, 'Chicago Med: Atendimento de Emergência S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220890.mp4', 'http://image.tmdb.org/t/p/w1280/hyegwBoDp0X69pck6Ip8i9kRRRj.jpg'),
(2152, 146, 'Chicago Med: Atendimento de Emergência S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220891.mp4', 'http://image.tmdb.org/t/p/w1280/3Vl8UtQ8nutdmH1qYIz31l1wBvL.jpg'),
(2153, 146, 'Chicago Med: Atendimento de Emergência S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220892.mp4', 'http://image.tmdb.org/t/p/w1280/uXIHQRLQ6Gr9T7CIdrjWcXuTyhP.jpg'),
(2154, 146, 'Chicago Med: Atendimento de Emergência S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220893.mp4', 'http://image.tmdb.org/t/p/w1280/gRUFzN18u8L754WKBLsZobMfXQX.jpg'),
(2155, 146, 'Chicago Med: Atendimento de Emergência S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220894.mp4', 'http://image.tmdb.org/t/p/w1280/oAY7X771aknAs7JhB66J6Ufypjg.jpg'),
(2156, 146, 'Chicago Med: Atendimento de Emergência S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220895.mp4', 'http://image.tmdb.org/t/p/w1280/njWuGZysOeKgV1UuK5kxEyoClVE.jpg'),
(2157, 146, 'Chicago Med: Atendimento de Emergência S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/220896.mp4', 'http://image.tmdb.org/t/p/w1280/eYDJkpsh70k3OnkThP6xZiV3LKj.jpg'),
(2158, 146, 'Chicago Med: Atendimento de Emergência S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/220897.mp4', 'http://image.tmdb.org/t/p/w1280/anemITZwK4CldRyBeqjl4Ya9Bax.jpg'),
(2159, 146, 'Chicago Med: Atendimento de Emergência S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/220898.mp4', 'http://image.tmdb.org/t/p/w1280/suK3cRpTFalj6a8IVG15O29f8Hh.jpg'),
(2160, 146, 'Chicago Med: Atendimento de Emergência S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/220899.mp4', 'http://image.tmdb.org/t/p/w1280/pRaqsGYKcRMq1qXXFLImaKjtm7T.jpg'),
(2161, 147, 'Chicago Med: Atendimento de Emergência S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220900.mp4', 'http://image.tmdb.org/t/p/w1280/6OuTtFD1JCrTMZ2vguKMJfh7B9G.jpg'),
(2162, 147, 'Chicago Med: Atendimento de Emergência S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220901.mp4', 'http://image.tmdb.org/t/p/w1280/5GDbgCFC1S5wuAQG8dkXmE9vVXo.jpg'),
(2163, 147, 'Chicago Med: Atendimento de Emergência S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220902.mp4', 'http://image.tmdb.org/t/p/w1280/wYdGhVEtV0y5MsH5mlWxsqLL89R.jpg'),
(2164, 147, 'Chicago Med: Atendimento de Emergência S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220903.mp4', 'http://image.tmdb.org/t/p/w1280/cXWZhVATJTxmKohddzCNjhJuJuh.jpg'),
(2165, 147, 'Chicago Med: Atendimento de Emergência S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220904.mp4', 'http://image.tmdb.org/t/p/w1280/j2HKck049pQzQFgzwejPF2IJxaQ.jpg'),
(2166, 147, 'Chicago Med: Atendimento de Emergência S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220905.mp4', 'http://image.tmdb.org/t/p/w1280/dsm8sZZ4lfWcPYTcNdCPQtM9TIR.jpg'),
(2167, 147, 'Chicago Med: Atendimento de Emergência S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220906.mp4', 'http://image.tmdb.org/t/p/w1280/e05oEmYBWqqyrovmBRXbkVfBaGQ.jpg'),
(2168, 147, 'Chicago Med: Atendimento de Emergência S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220907.mp4', 'http://image.tmdb.org/t/p/w1280/8hZku0KfOzfdOfui9BQQNGZeHXV.jpg'),
(2169, 147, 'Chicago Med: Atendimento de Emergência S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220908.mp4', 'http://image.tmdb.org/t/p/w1280/hRuccRBZbnS0TGUJixCpkRDqF89.jpg'),
(2170, 147, 'Chicago Med: Atendimento de Emergência S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220909.mp4', 'http://image.tmdb.org/t/p/w1280/581kXVntHrvwQkq9MIh2metcoNi.jpg'),
(2171, 147, 'Chicago Med: Atendimento de Emergência S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220910.mp4', 'http://image.tmdb.org/t/p/w1280/id07iuCLXitXoiyof83HvyN11AV.jpg'),
(2172, 147, 'Chicago Med: Atendimento de Emergência S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220911.mp4', 'http://image.tmdb.org/t/p/w1280/uvodyu9EBmCLX5J4OfirxLVx2gk.jpg'),
(2173, 147, 'Chicago Med: Atendimento de Emergência S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220912.mp4', 'http://image.tmdb.org/t/p/w1280/uvwoaXJ62LcRPHroEdZtJBxPNhq.jpg'),
(2174, 147, 'Chicago Med: Atendimento de Emergência S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220913.mp4', 'http://image.tmdb.org/t/p/w1280/nvap5A3TOlnF5ES3hjNQmJSVtmx.jpg'),
(2175, 147, 'Chicago Med: Atendimento de Emergência S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220914.mp4', 'http://image.tmdb.org/t/p/w1280/rjerW6FhaHPnG7LWaiS8XvRTo30.jpg'),
(2176, 147, 'Chicago Med: Atendimento de Emergência S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220915.mp4', 'http://image.tmdb.org/t/p/w1280/eAyoRg6XmunM3IyK49pZSszTOjb.jpg'),
(2177, 148, 'Chicago Med: Atendimento de Emergência S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220916.mp4', 'http://image.tmdb.org/t/p/w1280/fpbYI1kISQKupgcgBtFuk9PEbck.jpg'),
(2178, 148, 'Chicago Med: Atendimento de Emergência S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220917.mp4', 'http://image.tmdb.org/t/p/w1280/7qWJniiTY1sdjH6Dv2CsUx6Ylz8.jpg'),
(2179, 148, 'Chicago Med: Atendimento de Emergência S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220918.mp4', 'http://image.tmdb.org/t/p/w1280/1icWbgQbGVPaFGzWQnezUDfdtUS.jpg'),
(2180, 148, 'Chicago Med: Atendimento de Emergência S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220919.mp4', 'http://timg.bdta.pro/images/93ea6778a942e6dc8b85e82cce5a52c1.jpg'),
(2181, 148, 'Chicago Med: Atendimento de Emergência S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220920.mp4', 'http://timg.bdta.pro/images/ef0e04ff0820fd9341bb6a0b4d6bdea7.jpg'),
(2182, 148, 'Chicago Med: Atendimento de Emergência S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220921.mp4', 'http://timg.bdta.pro/images/ed8dd76b7d1f5c58487ad4243cdcacca.jpg'),
(2183, 148, 'Chicago Med: Atendimento de Emergência S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220922.mp4', 'http://image.tmdb.org/t/p/w1280/wvBnEHlZRyyp8JhXwhuBzwr5sRR.jpg'),
(2184, 148, 'Chicago Med: Atendimento de Emergência S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220923.mp4', 'http://image.tmdb.org/t/p/w1280/lOHRUM3G1XiT9YXRN2mE6n0cyHF.jpg'),
(2185, 148, 'Chicago Med: Atendimento de Emergência S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220924.mp4', 'http://timg.bdta.pro/images/33f4866f4856d15081c3fdfc2e47ec93.jpg'),
(2186, 148, 'Chicago Med: Atendimento de Emergência S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220925.mp4', 'http://timg.bdta.pro/images/ef949e4f37fa6bcc70353c9c69feaf84.jpg'),
(2187, 148, 'Chicago Med: Atendimento de Emergência S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220926.mp4', 'http://timg.bdta.pro/images/ba8995a42e43852defe10f129f8b61ed.jpg'),
(2188, 148, 'Chicago Med: Atendimento de Emergência S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220927.mp4', 'http://timg.bdta.pro/images/c9f13103ab31f18f93bf6b8e6f75dd95.jpg'),
(2189, 148, 'Chicago Med: Atendimento de Emergência S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220928.mp4', 'http://timg.bdta.pro/images/3b85405c2bd58ad96a53c1228c9b79d3.jpg'),
(2190, 148, 'Chicago Med: Atendimento de Emergência S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220929.mp4', 'http://timg.bdta.pro/images/03f0bf154ccda283835c74f03afd8c36.jpg'),
(2191, 148, 'Chicago Med: Atendimento de Emergência S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220930.mp4', 'http://image.tmdb.org/t/p/w1280/2LQGAXsMQ8i1zciTzaSeCf5VeLJ.jpg'),
(2192, 148, 'Chicago Med: Atendimento de Emergência S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220931.mp4', 'http://image.tmdb.org/t/p/w1280/ynRNlCgZajDOFxamwf1zOfAUWZg.jpg'),
(2193, 148, 'Chicago Med: Atendimento de Emergência S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/220932.mp4', 'http://image.tmdb.org/t/p/w1280/1M1zdI2Afp22sa9T0DZwJpvL63B.jpg'),
(2194, 148, 'Chicago Med: Atendimento de Emergência S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/220933.mp4', 'http://image.tmdb.org/t/p/w1280/7ZdQXui8rTLWOdwvisKxXWmoyMb.jpg'),
(2195, 148, 'Chicago Med: Atendimento de Emergência S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/220934.mp4', 'http://timg.bdta.pro/images/10c961be87225b09b32b5de1052a77b5.jpg'),
(2196, 148, 'Chicago Med: Atendimento de Emergência S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/220935.mp4', 'http://timg.bdta.pro/images/653d0942cc5d604631e7afcfb777437f.jpg'),
(2197, 148, 'Chicago Med: Atendimento de Emergência S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/220936.mp4', 'http://timg.bdta.pro/images/175412ee150b0afcf46bf980ff579475.jpg'),
(2198, 148, 'Chicago Med: Atendimento de Emergência S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/220937.mp4', 'http://timg.bdta.pro/images/589d496f51983bb6cbf34568004151cc.jpg'),
(2199, 149, 'Chicago Med: Atendimento de Emergência S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220938.mp4', 'http://image.tmdb.org/t/p/w1280/hwZVDbsTX4LPq05uFmqzZtQOac.jpg'),
(2200, 149, 'Chicago Med: Atendimento de Emergência S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220939.mp4', 'http://image.tmdb.org/t/p/w1280/tW2NEKXWfbY9SRoz8NdYn8ba2VM.jpg'),
(2201, 149, 'Chicago Med: Atendimento de Emergência S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220940.mp4', 'http://image.tmdb.org/t/p/w1280/zKfzAkeoss8D8CQcduAWq9DrKkS.jpg'),
(2202, 149, 'Chicago Med: Atendimento de Emergência S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220941.mp4', 'http://image.tmdb.org/t/p/w1280/1ksD03IQqlHJc7Y59v8OTvU71eh.jpg'),
(2203, 149, 'Chicago Med: Atendimento de Emergência S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220942.mp4', 'http://image.tmdb.org/t/p/w1280/1ffl8vjWhq61blIgiDULlxDjnyP.jpg'),
(2204, 149, 'Chicago Med: Atendimento de Emergência S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220943.mp4', 'http://image.tmdb.org/t/p/w1280/5Q9EF22yEsrWlZ4vtvuJTnIL4gG.jpg'),
(2205, 149, 'Chicago Med: Atendimento de Emergência S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220944.mp4', 'http://image.tmdb.org/t/p/w1280/t00wIBnuNF0SZQb3EzSjdTQ0Z78.jpg'),
(2206, 149, 'Chicago Med: Atendimento de Emergência S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220945.mp4', 'http://image.tmdb.org/t/p/w1280/zWy2fCODyxbSNtY8e0am5KRd31f.jpg'),
(2207, 149, 'Chicago Med: Atendimento de Emergência S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220946.mp4', 'http://image.tmdb.org/t/p/w1280/1fFzezYjGrfVNAHpmwwJ20tjijV.jpg'),
(2208, 149, 'Chicago Med: Atendimento de Emergência S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220947.mp4', 'http://image.tmdb.org/t/p/w1280/riepwGTN0pthBmsIbJRqjGrmVSF.jpg'),
(2209, 149, 'Chicago Med: Atendimento de Emergência S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220948.mp4', 'http://image.tmdb.org/t/p/w1280/bYJmVrD06ZpF3mpzmwk7OHZUO4G.jpg'),
(2210, 149, 'Chicago Med: Atendimento de Emergência S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220949.mp4', 'http://image.tmdb.org/t/p/w1280/ie6WYMU1CaHaAvtUPTXjfFm1hHt.jpg'),
(2211, 149, 'Chicago Med: Atendimento de Emergência S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220950.mp4', 'http://image.tmdb.org/t/p/w1280/ppFsqkFrb6gZyVr5DTPYpUF3cU0.jpg'),
(2212, 149, 'Chicago Med: Atendimento de Emergência S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220951.mp4', 'http://image.tmdb.org/t/p/w1280/inkGktPKmBsiO3hbxgQnCyF0J3Y.jpg'),
(2213, 149, 'Chicago Med: Atendimento de Emergência S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220952.mp4', 'http://image.tmdb.org/t/p/w1280/eizp6THwR1zI5H8DGhJV8acpXro.jpg'),
(2214, 149, 'Chicago Med: Atendimento de Emergência S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220953.mp4', 'http://image.tmdb.org/t/p/w1280/9Pg4XPcJX8YMc4rAndDRNJy1Os3.jpg'),
(2215, 149, 'Chicago Med: Atendimento de Emergência S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/220954.mp4', 'http://image.tmdb.org/t/p/w1280/cIuQ5wsKzxzj3EulSxxAslITXvF.jpg'),
(2216, 149, 'Chicago Med: Atendimento de Emergência S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/220955.mp4', 'http://image.tmdb.org/t/p/w1280/dQ6SLJspr4sGqKdYxCO55AQCXhY.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(2217, 149, 'Chicago Med: Atendimento de Emergência S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/220956.mp4', 'http://image.tmdb.org/t/p/w1280/qL4rVQfle3lCNvIUuh4ZY4o0BUb.jpg'),
(2218, 149, 'Chicago Med: Atendimento de Emergência S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/220957.mp4', 'http://image.tmdb.org/t/p/w1280/k2hBO3ZUk7GArNybR4NVeh825at.jpg'),
(2219, 149, 'Chicago Med: Atendimento de Emergência S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/220958.mp4', 'http://image.tmdb.org/t/p/w1280/mkvTBFPgF1MNKK5p29wk3mXz07c.jpg'),
(2220, 149, 'Chicago Med: Atendimento de Emergência S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/220959.mp4', 'http://image.tmdb.org/t/p/w1280/hIeC9NxKw4z49IhYomjY9mZxefj.jpg'),
(2221, 150, 'Chicago Med: Atendimento de Emergência S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/316469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2222, 150, 'Chicago Med: Atendimento de Emergência S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/318624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2223, 150, 'Chicago Med: Atendimento de Emergência S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/324811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2224, 150, 'Chicago Med: Atendimento de Emergência S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/328658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2225, 150, 'Chicago Med: Atendimento de Emergência S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/333606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2226, 150, 'Chicago Med: Atendimento de Emergência S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/341576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2227, 150, 'Chicago Med: Atendimento de Emergência S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/352976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2228, 150, 'Chicago Med: Atendimento de Emergência S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/352977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2229, 150, 'Chicago Med: Atendimento de Emergência S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/360086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2230, 150, 'Chicago Med: Atendimento de Emergência S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/369431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2231, 150, 'Chicago Med: Atendimento de Emergência S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/374929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2232, 150, 'Chicago Med: Atendimento de Emergência S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/384782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2233, 150, 'Chicago Med: Atendimento de Emergência S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/397569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2234, 151, 'Chicago Med: Atendimento de Emergência S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/676855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2235, 151, 'Chicago Med: Atendimento de Emergência S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/680303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2236, 151, 'Chicago Med: Atendimento de Emergência S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/691250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2237, 151, 'Chicago Med: Atendimento de Emergência S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/694045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2238, 151, 'Chicago Med: Atendimento de Emergência S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/707022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2239, 151, 'Chicago Med: Atendimento de Emergência S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/709693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2240, 151, 'Chicago Med: Atendimento de Emergência S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/711077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2241, 151, 'Chicago Med: Atendimento de Emergência S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/727479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2242, 151, 'Chicago Med: Atendimento de Emergência S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/735207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2243, 151, 'Chicago Med: Atendimento de Emergência S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/740377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2244, 151, 'Chicago Med: Atendimento de Emergência S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/755516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2245, 151, 'Chicago Med: Atendimento de Emergência S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/768103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2246, 151, 'Chicago Med: Atendimento de Emergência S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/769940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2247, 151, 'Chicago Med: Atendimento de Emergência S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/781189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2248, 151, 'Chicago Med: Atendimento de Emergência S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/786215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2249, 151, 'Chicago Med: Atendimento de Emergência S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/790985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2250, 151, 'Chicago Med: Atendimento de Emergência S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/803278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2251, 151, 'Chicago Med: Atendimento de Emergência S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/814146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2252, 151, 'Chicago Med: Atendimento de Emergência S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/838777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2253, 151, 'Chicago Med: Atendimento de Emergência S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/838778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2254, 151, 'Chicago Med: Atendimento de Emergência S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/843800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2255, 151, 'Chicago Med: Atendimento de Emergência S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/852621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2256, 152, 'Chicago Med: Atendimento de Emergência S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/891065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2257, 152, 'Chicago Med: Atendimento de Emergência S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/892480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2258, 152, 'Chicago Med: Atendimento de Emergência S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/892669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2259, 152, 'Chicago Med: Atendimento de Emergência S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/893477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2260, 152, 'Chicago Med: Atendimento de Emergência S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/894234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6RzHO4QahyICKJPkK7xYgUfzM.jpg'),
(2261, 153, 'Chicago P.D.: Distrito 21 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2262, 153, 'Chicago P.D.: Distrito 21 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2263, 153, 'Chicago P.D.: Distrito 21 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2264, 153, 'Chicago P.D.: Distrito 21 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2265, 153, 'Chicago P.D.: Distrito 21 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2266, 153, 'Chicago P.D.: Distrito 21 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2267, 153, 'Chicago P.D.: Distrito 21 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2268, 153, 'Chicago P.D.: Distrito 21 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2269, 153, 'Chicago P.D.: Distrito 21 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2270, 153, 'Chicago P.D.: Distrito 21 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2271, 153, 'Chicago P.D.: Distrito 21 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2272, 153, 'Chicago P.D.: Distrito 21 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2273, 153, 'Chicago P.D.: Distrito 21 S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2274, 153, 'Chicago P.D.: Distrito 21 S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2275, 153, 'Chicago P.D.: Distrito 21 S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2276, 154, 'Chicago P.D.: Distrito 21 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2277, 154, 'Chicago P.D.: Distrito 21 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2278, 154, 'Chicago P.D.: Distrito 21 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2279, 154, 'Chicago P.D.: Distrito 21 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2280, 154, 'Chicago P.D.: Distrito 21 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2281, 154, 'Chicago P.D.: Distrito 21 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2282, 154, 'Chicago P.D.: Distrito 21 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2283, 154, 'Chicago P.D.: Distrito 21 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2284, 154, 'Chicago P.D.: Distrito 21 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2285, 154, 'Chicago P.D.: Distrito 21 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2286, 154, 'Chicago P.D.: Distrito 21 S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2287, 154, 'Chicago P.D.: Distrito 21 S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2288, 154, 'Chicago P.D.: Distrito 21 S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2289, 154, 'Chicago P.D.: Distrito 21 S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2290, 154, 'Chicago P.D.: Distrito 21 S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2291, 154, 'Chicago P.D.: Distrito 21 S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2292, 154, 'Chicago P.D.: Distrito 21 S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/220621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2293, 154, 'Chicago P.D.: Distrito 21 S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/220622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2294, 154, 'Chicago P.D.: Distrito 21 S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/220623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2295, 154, 'Chicago P.D.: Distrito 21 S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/220624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2296, 154, 'Chicago P.D.: Distrito 21 S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/220625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2297, 154, 'Chicago P.D.: Distrito 21 S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/220626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2298, 154, 'Chicago P.D.: Distrito 21 S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/220627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2299, 155, 'Chicago P.D.: Distrito 21 S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2300, 155, 'Chicago P.D.: Distrito 21 S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2301, 155, 'Chicago P.D.: Distrito 21 S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2302, 155, 'Chicago P.D.: Distrito 21 S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2303, 155, 'Chicago P.D.: Distrito 21 S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2304, 155, 'Chicago P.D.: Distrito 21 S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2305, 155, 'Chicago P.D.: Distrito 21 S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2306, 155, 'Chicago P.D.: Distrito 21 S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2307, 155, 'Chicago P.D.: Distrito 21 S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2308, 155, 'Chicago P.D.: Distrito 21 S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2309, 155, 'Chicago P.D.: Distrito 21 S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2310, 155, 'Chicago P.D.: Distrito 21 S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2311, 155, 'Chicago P.D.: Distrito 21 S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2312, 155, 'Chicago P.D.: Distrito 21 S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2313, 155, 'Chicago P.D.: Distrito 21 S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2314, 155, 'Chicago P.D.: Distrito 21 S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2315, 155, 'Chicago P.D.: Distrito 21 S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/220644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2316, 155, 'Chicago P.D.: Distrito 21 S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/220645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2317, 155, 'Chicago P.D.: Distrito 21 S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/220646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2318, 155, 'Chicago P.D.: Distrito 21 S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/220647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2319, 155, 'Chicago P.D.: Distrito 21 S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/220648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2320, 155, 'Chicago P.D.: Distrito 21 S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/220649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2321, 155, 'Chicago P.D.: Distrito 21 S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/220650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2322, 156, 'Chicago P.D.: Distrito 21 S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2323, 156, 'Chicago P.D.: Distrito 21 S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2324, 156, 'Chicago P.D.: Distrito 21 S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2325, 156, 'Chicago P.D.: Distrito 21 S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2326, 156, 'Chicago P.D.: Distrito 21 S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2327, 156, 'Chicago P.D.: Distrito 21 S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2328, 156, 'Chicago P.D.: Distrito 21 S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2329, 156, 'Chicago P.D.: Distrito 21 S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2330, 156, 'Chicago P.D.: Distrito 21 S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2331, 156, 'Chicago P.D.: Distrito 21 S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2332, 156, 'Chicago P.D.: Distrito 21 S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2333, 156, 'Chicago P.D.: Distrito 21 S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2334, 156, 'Chicago P.D.: Distrito 21 S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2335, 156, 'Chicago P.D.: Distrito 21 S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2336, 156, 'Chicago P.D.: Distrito 21 S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2337, 156, 'Chicago P.D.: Distrito 21 S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2338, 156, 'Chicago P.D.: Distrito 21 S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/220667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2339, 156, 'Chicago P.D.: Distrito 21 S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/220668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2340, 156, 'Chicago P.D.: Distrito 21 S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/220669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2341, 156, 'Chicago P.D.: Distrito 21 S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/220670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2342, 156, 'Chicago P.D.: Distrito 21 S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/220671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2343, 156, 'Chicago P.D.: Distrito 21 S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/220672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2344, 156, 'Chicago P.D.: Distrito 21 S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/220673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2345, 157, 'Chicago P.D.: Distrito 21 S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2346, 157, 'Chicago P.D.: Distrito 21 S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2347, 157, 'Chicago P.D.: Distrito 21 S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2348, 157, 'Chicago P.D.: Distrito 21 S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2349, 157, 'Chicago P.D.: Distrito 21 S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2350, 157, 'Chicago P.D.: Distrito 21 S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2351, 157, 'Chicago P.D.: Distrito 21 S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2352, 157, 'Chicago P.D.: Distrito 21 S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2353, 157, 'Chicago P.D.: Distrito 21 S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2354, 157, 'Chicago P.D.: Distrito 21 S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2355, 157, 'Chicago P.D.: Distrito 21 S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2356, 157, 'Chicago P.D.: Distrito 21 S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2357, 157, 'Chicago P.D.: Distrito 21 S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2358, 157, 'Chicago P.D.: Distrito 21 S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2359, 157, 'Chicago P.D.: Distrito 21 S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2360, 157, 'Chicago P.D.: Distrito 21 S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2361, 157, 'Chicago P.D.: Distrito 21 S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/220690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2362, 157, 'Chicago P.D.: Distrito 21 S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/220691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2363, 157, 'Chicago P.D.: Distrito 21 S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/220692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2364, 157, 'Chicago P.D.: Distrito 21 S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/220693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2365, 157, 'Chicago P.D.: Distrito 21 S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/220694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2366, 157, 'Chicago P.D.: Distrito 21 S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/220695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2367, 158, 'Chicago P.D.: Distrito 21 S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2368, 158, 'Chicago P.D.: Distrito 21 S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2369, 158, 'Chicago P.D.: Distrito 21 S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2370, 158, 'Chicago P.D.: Distrito 21 S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2371, 158, 'Chicago P.D.: Distrito 21 S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2372, 158, 'Chicago P.D.: Distrito 21 S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2373, 158, 'Chicago P.D.: Distrito 21 S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2374, 158, 'Chicago P.D.: Distrito 21 S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2375, 158, 'Chicago P.D.: Distrito 21 S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2376, 158, 'Chicago P.D.: Distrito 21 S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2377, 158, 'Chicago P.D.: Distrito 21 S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2378, 158, 'Chicago P.D.: Distrito 21 S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2379, 158, 'Chicago P.D.: Distrito 21 S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2380, 158, 'Chicago P.D.: Distrito 21 S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2381, 158, 'Chicago P.D.: Distrito 21 S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2382, 158, 'Chicago P.D.: Distrito 21 S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2383, 158, 'Chicago P.D.: Distrito 21 S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/220712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2384, 158, 'Chicago P.D.: Distrito 21 S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/220713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2385, 158, 'Chicago P.D.: Distrito 21 S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/220714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2386, 158, 'Chicago P.D.: Distrito 21 S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/220715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2387, 158, 'Chicago P.D.: Distrito 21 S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/220716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2388, 159, 'Chicago P.D.: Distrito 21 S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220717.mp4', 'http://timg.bdta.pro/images/a280bd9c4b1d218afffa75a5146c7e0f.jpg'),
(2389, 159, 'Chicago P.D.: Distrito 21 S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220718.mp4', 'http://timg.bdta.pro/images/d3ef00017b7ed5eed4d0e9d3e1e62b16.jpg'),
(2390, 159, 'Chicago P.D.: Distrito 21 S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220719.mp4', 'http://timg.bdta.pro/images/7b9284e827ac7e2aef6dfd32b8c35581.jpg'),
(2391, 159, 'Chicago P.D.: Distrito 21 S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220720.mp4', 'http://timg.bdta.pro/images/6953a5770f1748f95000168f3b7b380d.jpg'),
(2392, 159, 'Chicago P.D.: Distrito 21 S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220721.mp4', 'http://timg.bdta.pro/images/f393db909a8ccc9a1aa5fea97892bf5f.jpg'),
(2393, 159, 'Chicago P.D.: Distrito 21 S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220722.mp4', 'http://timg.bdta.pro/images/2106dc4d9b6cad9da958c277e2d8cbf6.jpg'),
(2394, 159, 'Chicago P.D.: Distrito 21 S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220723.mp4', 'http://timg.bdta.pro/images/2b27a8d0363bd9e13f8f99bc67cef9c6.jpg'),
(2395, 159, 'Chicago P.D.: Distrito 21 S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220724.mp4', 'http://timg.bdta.pro/images/b8c683ca835e2963d898e71a615f19de.jpg'),
(2396, 159, 'Chicago P.D.: Distrito 21 S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220725.mp4', 'http://timg.bdta.pro/images/43e7559b4bbd4a1eb05084108972f63b.jpg'),
(2397, 159, 'Chicago P.D.: Distrito 21 S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220726.mp4', 'http://timg.bdta.pro/images/5bc54aa5d0ca3abd2352c222e0d9e55a.jpg'),
(2398, 159, 'Chicago P.D.: Distrito 21 S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220727.mp4', 'http://timg.bdta.pro/images/c795bba737be0dd366cd7ebf273e24ab.jpg'),
(2399, 159, 'Chicago P.D.: Distrito 21 S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220728.mp4', 'http://timg.bdta.pro/images/fb67386398aaf0067e162e7ef8e297c1.jpg'),
(2400, 159, 'Chicago P.D.: Distrito 21 S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220729.mp4', 'http://timg.bdta.pro/images/2ef6e9f6f08e3284b7d06e0479ae9e28.jpg'),
(2401, 159, 'Chicago P.D.: Distrito 21 S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220730.mp4', 'http://timg.bdta.pro/images/e6a06136a2b14045355d5b3aa52115c6.jpg'),
(2402, 159, 'Chicago P.D.: Distrito 21 S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220731.mp4', 'http://timg.bdta.pro/images/708c260636d3bbdb707f40cbb725af58.jpg'),
(2403, 159, 'Chicago P.D.: Distrito 21 S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220732.mp4', 'http://timg.bdta.pro/images/7aedd699046c3bac37b8250e924dad40.jpg'),
(2404, 159, 'Chicago P.D.: Distrito 21 S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/220733.mp4', 'http://timg.bdta.pro/images/a666a4cef98606ed77ecb27a0c0fd605.jpg'),
(2405, 159, 'Chicago P.D.: Distrito 21 S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/220734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2406, 159, 'Chicago P.D.: Distrito 21 S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/220735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2407, 159, 'Chicago P.D.: Distrito 21 S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/220736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2408, 160, 'Chicago P.D.: Distrito 21 S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2409, 160, 'Chicago P.D.: Distrito 21 S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2410, 160, 'Chicago P.D.: Distrito 21 S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2411, 160, 'Chicago P.D.: Distrito 21 S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2412, 160, 'Chicago P.D.: Distrito 21 S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2413, 160, 'Chicago P.D.: Distrito 21 S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2414, 160, 'Chicago P.D.: Distrito 21 S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2415, 160, 'Chicago P.D.: Distrito 21 S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2416, 160, 'Chicago P.D.: Distrito 21 S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2417, 160, 'Chicago P.D.: Distrito 21 S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2418, 160, 'Chicago P.D.: Distrito 21 S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2419, 160, 'Chicago P.D.: Distrito 21 S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2420, 160, 'Chicago P.D.: Distrito 21 S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2421, 160, 'Chicago P.D.: Distrito 21 S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2422, 160, 'Chicago P.D.: Distrito 21 S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2423, 160, 'Chicago P.D.: Distrito 21 S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2424, 161, 'Chicago P.D.: Distrito 21 S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220753.mp4', 'http://image.tmdb.org/t/p/w1280/cVP3sCKOZ8FuSC2LLAveQu2zNLw.jpg'),
(2425, 161, 'Chicago P.D.: Distrito 21 S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220754.mp4', 'http://timg.bdta.pro/images/f5c0b0b70d04a07e3660793936477bab.jpg'),
(2426, 161, 'Chicago P.D.: Distrito 21 S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220755.mp4', 'http://timg.bdta.pro/images/91f66fb8c24df135d990552bb024028d.jpg'),
(2427, 161, 'Chicago P.D.: Distrito 21 S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220756.mp4', 'http://timg.bdta.pro/images/8dadd1175858aa3ce514c357b11aac60.jpg'),
(2428, 161, 'Chicago P.D.: Distrito 21 S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220757.mp4', 'http://timg.bdta.pro/images/ae0a59d284f5a1747276975524116457.jpg'),
(2429, 161, 'Chicago P.D.: Distrito 21 S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220758.mp4', 'http://timg.bdta.pro/images/60b0ea6e3e8a51b5e97132a42417686c.jpg'),
(2430, 161, 'Chicago P.D.: Distrito 21 S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220759.mp4', 'http://timg.bdta.pro/images/e58334a6e46cf8a4c365564d311d84ae.jpg'),
(2431, 161, 'Chicago P.D.: Distrito 21 S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220760.mp4', 'http://timg.bdta.pro/images/b81ecb6e7c3dc0f87a5010288aba7e4f.jpg'),
(2432, 161, 'Chicago P.D.: Distrito 21 S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220761.mp4', 'http://timg.bdta.pro/images/991eeea12843b436ac5621bb241d6cc8.jpg'),
(2433, 161, 'Chicago P.D.: Distrito 21 S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220762.mp4', 'http://timg.bdta.pro/images/fd2ea458d13cb1124bfa952f965ac842.jpg'),
(2434, 161, 'Chicago P.D.: Distrito 21 S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220763.mp4', 'http://timg.bdta.pro/images/def951b21ae1b1558a1b02f5b1d93283.jpg'),
(2435, 161, 'Chicago P.D.: Distrito 21 S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220764.mp4', 'http://timg.bdta.pro/images/3b866233634512b7f9684f7f8502b575.jpg'),
(2436, 161, 'Chicago P.D.: Distrito 21 S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220765.mp4', 'http://timg.bdta.pro/images/e384b6a49984b7abf3a345002cb3bab4.jpg'),
(2437, 161, 'Chicago P.D.: Distrito 21 S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220766.mp4', 'http://timg.bdta.pro/images/e65c79236369320e131743cee5ae1480.jpg'),
(2438, 161, 'Chicago P.D.: Distrito 21 S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220767.mp4', 'http://timg.bdta.pro/images/d4516fe0fb77ce5a7dda47aa767e6d66.jpg'),
(2439, 161, 'Chicago P.D.: Distrito 21 S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220768.mp4', 'http://timg.bdta.pro/images/71a0dda5f59a627af9f4d78fda6625c9.jpg'),
(2440, 161, 'Chicago P.D.: Distrito 21 S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/220769.mp4', 'http://timg.bdta.pro/images/259c784b7d626b0fba2b5e61a55cfbc8.jpg'),
(2441, 161, 'Chicago P.D.: Distrito 21 S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/220770.mp4', 'http://timg.bdta.pro/images/aac12b28df964581498d20547e96fa18.jpg'),
(2442, 161, 'Chicago P.D.: Distrito 21 S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/220771.mp4', 'http://timg.bdta.pro/images/d62f17e94568f37177da5bd7a7b31d70.jpg'),
(2443, 161, 'Chicago P.D.: Distrito 21 S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/220772.mp4', 'http://timg.bdta.pro/images/15edfa1278898fe86d56cdd394d87815.jpg'),
(2444, 161, 'Chicago P.D.: Distrito 21 S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/220773.mp4', 'http://timg.bdta.pro/images/90f606bfd0bd3f4a0fd568f928d71269.jpg'),
(2445, 161, 'Chicago P.D.: Distrito 21 S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/220774.mp4', 'http://timg.bdta.pro/images/67d8abd3adeabc245475aa0c5d1bcd87.jpg'),
(2446, 162, 'Chicago P.D.: Distrito 21 S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220775.mp4', 'http://image.tmdb.org/t/p/w1280/dl4AHeGZ3M8DnlAoDgMffUHA4yU.jpg'),
(2447, 162, 'Chicago P.D.: Distrito 21 S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220776.mp4', 'http://image.tmdb.org/t/p/w1280/w52QQfcKcFEoWVGPKhYVfP6OMN2.jpg'),
(2448, 162, 'Chicago P.D.: Distrito 21 S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220777.mp4', 'http://image.tmdb.org/t/p/w1280/vIHIrjKFJynJNidD7rMIqJEBzza.jpg'),
(2449, 162, 'Chicago P.D.: Distrito 21 S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220778.mp4', 'http://image.tmdb.org/t/p/w1280/vtjVxilOOzBeJ4SvikAAR3CwfHY.jpg'),
(2450, 162, 'Chicago P.D.: Distrito 21 S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220779.mp4', 'http://image.tmdb.org/t/p/w1280/i2xxDUhHpN3NxRpMabaUyqDwmJo.jpg'),
(2451, 162, 'Chicago P.D.: Distrito 21 S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220780.mp4', 'http://image.tmdb.org/t/p/w1280/98YxzBAYPxTfzfjVy1jKZ4NX8uW.jpg'),
(2452, 162, 'Chicago P.D.: Distrito 21 S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220781.mp4', 'http://image.tmdb.org/t/p/w1280/iTN1DfIGwUl5hxHBseCypg1wxSK.jpg'),
(2453, 162, 'Chicago P.D.: Distrito 21 S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220782.mp4', 'http://image.tmdb.org/t/p/w1280/gNWUBa26AGXfze683ZrHALryFgt.jpg'),
(2454, 162, 'Chicago P.D.: Distrito 21 S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aVc32q0RprjRDe3giFEFiA6RbmD.jpg'),
(2455, 162, 'Chicago P.D.: Distrito 21 S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hVOyNeAjcMTjxvNkN6ZzNSCb5Ar.jpg'),
(2456, 162, 'Chicago P.D.: Distrito 21 S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zccKSOivzoHHGivNouDROdfQxKj.jpg'),
(2457, 162, 'Chicago P.D.: Distrito 21 S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cUFZ5Fw0utC7E0pJ2t0IpJBFQlg.jpg'),
(2458, 162, 'Chicago P.D.: Distrito 21 S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/QjfRko1qNYK9RLMQv7hgYhIefE.jpg'),
(2459, 162, 'Chicago P.D.: Distrito 21 S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hjoKp8gCH89bURv8UZBGiYF5weN.jpg'),
(2460, 162, 'Chicago P.D.: Distrito 21 S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qM3rKdHeWjie4Q2TqJtWOE3tmf6.jpg'),
(2461, 162, 'Chicago P.D.: Distrito 21 S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sgNGp1GjSKDsXfe5Zx9CiyuK9WS.jpg'),
(2462, 162, 'Chicago P.D.: Distrito 21 S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/220791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2W4LxHnkdmb9grVCDWbg1wA0QG7.jpg'),
(2463, 162, 'Chicago P.D.: Distrito 21 S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/220792.mp4', 'http://image.tmdb.org/t/p/w1280/oMNZhjveYVoNLVXDyrrg6Wtp2Z6.jpg'),
(2464, 162, 'Chicago P.D.: Distrito 21 S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/220793.mp4', 'http://image.tmdb.org/t/p/w1280/tvh0qxe8712N0RST2xoYlnFN2Lu.jpg'),
(2465, 162, 'Chicago P.D.: Distrito 21 S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/220794.mp4', 'http://image.tmdb.org/t/p/w1280/9G13EeclcOsCTSJh8Ax7I9nkxeS.jpg'),
(2466, 162, 'Chicago P.D.: Distrito 21 S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/220795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2467, 162, 'Chicago P.D.: Distrito 21 S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/220796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2468, 163, 'Chicago P.D.: Distrito 21 S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/311276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2469, 163, 'Chicago P.D.: Distrito 21 S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/318459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2470, 163, 'Chicago P.D.: Distrito 21 S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/324645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2471, 163, 'Chicago P.D.: Distrito 21 S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/328491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(2472, 163, 'Chicago P.D.: Distrito 21 S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/333438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2473, 163, 'Chicago P.D.: Distrito 21 S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/341407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2474, 163, 'Chicago P.D.: Distrito 21 S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/352805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2475, 163, 'Chicago P.D.: Distrito 21 S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/352806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2476, 163, 'Chicago P.D.: Distrito 21 S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/359914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2477, 163, 'Chicago P.D.: Distrito 21 S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/369258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2478, 163, 'Chicago P.D.: Distrito 21 S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/374755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2479, 163, 'Chicago P.D.: Distrito 21 S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/384607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2480, 163, 'Chicago P.D.: Distrito 21 S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/397393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2481, 164, 'Chicago P.D.: Distrito 21 S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/676678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2482, 164, 'Chicago P.D.: Distrito 21 S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/680125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2483, 164, 'Chicago P.D.: Distrito 21 S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/691071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2484, 164, 'Chicago P.D.: Distrito 21 S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/693865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2485, 164, 'Chicago P.D.: Distrito 21 S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/706841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2486, 164, 'Chicago P.D.: Distrito 21 S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/709511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2487, 164, 'Chicago P.D.: Distrito 21 S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/710894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2488, 164, 'Chicago P.D.: Distrito 21 S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/727295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2489, 164, 'Chicago P.D.: Distrito 21 S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/735022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2490, 164, 'Chicago P.D.: Distrito 21 S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/740191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2491, 164, 'Chicago P.D.: Distrito 21 S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/755329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2492, 164, 'Chicago P.D.: Distrito 21 S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/767915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2493, 164, 'Chicago P.D.: Distrito 21 S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/769751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2494, 164, 'Chicago P.D.: Distrito 21 S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/780999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2495, 164, 'Chicago P.D.: Distrito 21 S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/785757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2496, 164, 'Chicago P.D.: Distrito 21 S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/790793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2497, 164, 'Chicago P.D.: Distrito 21 S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/803515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2498, 164, 'Chicago P.D.: Distrito 21 S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/813680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2499, 164, 'Chicago P.D.: Distrito 21 S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/838581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2500, 164, 'Chicago P.D.: Distrito 21 S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/838582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2501, 164, 'Chicago P.D.: Distrito 21 S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/843603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2502, 164, 'Chicago P.D.: Distrito 21 S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/851732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2503, 165, 'Chicago P.D.: Distrito 21 S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/891064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2504, 165, 'Chicago P.D.: Distrito 21 S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/892479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2505, 165, 'Chicago P.D.: Distrito 21 S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/892668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2506, 165, 'Chicago P.D.: Distrito 21 S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/893476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2507, 165, 'Chicago P.D.: Distrito 21 S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/894233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k9YHHlENlcIT8g2BqeXsaDI2Hh.jpg'),
(2508, 166, 'Cobra Kai [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143952.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2509, 166, 'Cobra Kai [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143953.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2510, 166, 'Cobra Kai [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143954.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2511, 166, 'Cobra Kai [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143955.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2512, 166, 'Cobra Kai [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143956.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2513, 166, 'Cobra Kai [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143957.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2514, 166, 'Cobra Kai [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143958.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2515, 166, 'Cobra Kai [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143959.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2516, 166, 'Cobra Kai [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143960.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2517, 166, 'Cobra Kai [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143961.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2518, 167, 'Cobra Kai [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143962.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2519, 167, 'Cobra Kai [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143963.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2520, 167, 'Cobra Kai [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143964.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2521, 167, 'Cobra Kai [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143965.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2522, 167, 'Cobra Kai [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143966.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2523, 167, 'Cobra Kai [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143967.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2524, 167, 'Cobra Kai [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143968.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2525, 167, 'Cobra Kai [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143969.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2526, 167, 'Cobra Kai [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143970.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2527, 167, 'Cobra Kai [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143971.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2528, 168, 'Cobra Kai [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143972.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2529, 168, 'Cobra Kai [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143973.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2530, 168, 'Cobra Kai [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143974.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2531, 168, 'Cobra Kai [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143975.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2532, 168, 'Cobra Kai [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143976.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2533, 168, 'Cobra Kai [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143977.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2534, 168, 'Cobra Kai [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143978.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2535, 168, 'Cobra Kai [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143979.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2536, 168, 'Cobra Kai [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143980.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2537, 168, 'Cobra Kai [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143981.mp4', 'http://gstaticontent.com/images/eTMMU2rKpZRbo9ERytyhwatwAjz_big.jpg'),
(2538, 169, 'Colony S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108612.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2539, 169, 'Colony S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108613.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2540, 169, 'Colony S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108614.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2541, 169, 'Colony S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108615.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2542, 169, 'Colony S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108616.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2543, 169, 'Colony S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108617.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2544, 169, 'Colony S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108618.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2545, 169, 'Colony S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108619.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2546, 169, 'Colony S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108620.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2547, 169, 'Colony S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108621.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2548, 170, 'Colony S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108622.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2549, 170, 'Colony S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108623.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2550, 170, 'Colony S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108624.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2551, 170, 'Colony S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108625.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2552, 170, 'Colony S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108626.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2553, 170, 'Colony S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108627.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2554, 170, 'Colony S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108628.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2555, 170, 'Colony S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108629.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2556, 170, 'Colony S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108630.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2557, 170, 'Colony S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108631.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2558, 170, 'Colony S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108632.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2559, 170, 'Colony S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108633.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2560, 170, 'Colony S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108634.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2561, 171, 'Colony S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108635.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2562, 171, 'Colony S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108636.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2563, 171, 'Colony S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108637.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2564, 171, 'Colony S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108638.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2565, 171, 'Colony S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108639.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2566, 171, 'Colony S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108640.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2567, 171, 'Colony S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108641.mp4', 'http://gstaticontent.com/images/qfS0mp22XfTig2EK3jWKiyx7kNy_big.jpg'),
(2568, 171, 'Colony S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108642.mp4', 'http://timg.bdta.pro/images/c0288bcccf76e4122ce465c40e00c248.jpg'),
(2569, 171, 'Colony S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108643.mp4', 'http://timg.bdta.pro/images/d8cb9a7699d093990c6ade6494870079.jpg'),
(2570, 171, 'Colony S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108644.mp4', 'http://timg.bdta.pro/images/e3244b047c3c594225e36adf2a1ee607.jpg'),
(2571, 171, 'Colony S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108645.mp4', 'http://timg.bdta.pro/images/2e065c6d2e8cf4fcc1cb79e8f62d1ee9.jpg'),
(2572, 171, 'Colony S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108646.mp4', 'http://timg.bdta.pro/images/2781704097c8440949b4a5578bd018d5.jpg'),
(2573, 172, 'Mentes Criminosas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2574, 172, 'Mentes Criminosas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2575, 172, 'Mentes Criminosas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2576, 172, 'Mentes Criminosas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2577, 172, 'Mentes Criminosas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2578, 172, 'Mentes Criminosas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2579, 172, 'Mentes Criminosas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2580, 172, 'Mentes Criminosas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2581, 172, 'Mentes Criminosas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2582, 172, 'Mentes Criminosas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2583, 172, 'Mentes Criminosas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2584, 172, 'Mentes Criminosas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2585, 172, 'Mentes Criminosas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2586, 172, 'Mentes Criminosas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2587, 172, 'Mentes Criminosas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2588, 172, 'Mentes Criminosas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2589, 172, 'Mentes Criminosas S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2590, 172, 'Mentes Criminosas S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2591, 172, 'Mentes Criminosas S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2592, 172, 'Mentes Criminosas S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2593, 172, 'Mentes Criminosas S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2594, 172, 'Mentes Criminosas S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2595, 173, 'Mentes Criminosas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2596, 173, 'Mentes Criminosas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2597, 173, 'Mentes Criminosas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2598, 173, 'Mentes Criminosas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2599, 173, 'Mentes Criminosas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2600, 173, 'Mentes Criminosas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2601, 173, 'Mentes Criminosas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2602, 173, 'Mentes Criminosas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2603, 173, 'Mentes Criminosas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2604, 173, 'Mentes Criminosas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2605, 173, 'Mentes Criminosas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2606, 173, 'Mentes Criminosas S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2607, 173, 'Mentes Criminosas S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2608, 173, 'Mentes Criminosas S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2609, 173, 'Mentes Criminosas S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2610, 173, 'Mentes Criminosas S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2611, 173, 'Mentes Criminosas S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2612, 173, 'Mentes Criminosas S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2613, 173, 'Mentes Criminosas S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2614, 173, 'Mentes Criminosas S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2615, 173, 'Mentes Criminosas S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2616, 173, 'Mentes Criminosas S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2617, 174, 'Mentes Criminosas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2618, 174, 'Mentes Criminosas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2619, 174, 'Mentes Criminosas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2620, 174, 'Mentes Criminosas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2621, 174, 'Mentes Criminosas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2622, 174, 'Mentes Criminosas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2623, 174, 'Mentes Criminosas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2624, 174, 'Mentes Criminosas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2625, 174, 'Mentes Criminosas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2626, 174, 'Mentes Criminosas S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2627, 174, 'Mentes Criminosas S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2628, 174, 'Mentes Criminosas S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2629, 174, 'Mentes Criminosas S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2630, 174, 'Mentes Criminosas S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2631, 174, 'Mentes Criminosas S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2632, 174, 'Mentes Criminosas S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2633, 174, 'Mentes Criminosas S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2634, 174, 'Mentes Criminosas S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2635, 174, 'Mentes Criminosas S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2636, 174, 'Mentes Criminosas S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2637, 175, 'Mentes Criminosas S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2638, 175, 'Mentes Criminosas S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2639, 175, 'Mentes Criminosas S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2640, 175, 'Mentes Criminosas S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2641, 175, 'Mentes Criminosas S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2642, 175, 'Mentes Criminosas S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2643, 175, 'Mentes Criminosas S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2644, 175, 'Mentes Criminosas S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2645, 175, 'Mentes Criminosas S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2646, 175, 'Mentes Criminosas S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2647, 175, 'Mentes Criminosas S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2648, 175, 'Mentes Criminosas S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2649, 175, 'Mentes Criminosas S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2650, 175, 'Mentes Criminosas S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2651, 175, 'Mentes Criminosas S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2652, 175, 'Mentes Criminosas S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2653, 175, 'Mentes Criminosas S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2654, 175, 'Mentes Criminosas S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2655, 175, 'Mentes Criminosas S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2656, 175, 'Mentes Criminosas S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2657, 175, 'Mentes Criminosas S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2658, 175, 'Mentes Criminosas S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2659, 175, 'Mentes Criminosas S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/224535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2660, 175, 'Mentes Criminosas S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/224536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2661, 175, 'Mentes Criminosas S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/224537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2662, 175, 'Mentes Criminosas S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/224538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2663, 176, 'Mentes Criminosas S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2664, 176, 'Mentes Criminosas S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2665, 176, 'Mentes Criminosas S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2666, 176, 'Mentes Criminosas S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2667, 176, 'Mentes Criminosas S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2668, 176, 'Mentes Criminosas S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2669, 176, 'Mentes Criminosas S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2670, 176, 'Mentes Criminosas S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2671, 176, 'Mentes Criminosas S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2672, 176, 'Mentes Criminosas S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2673, 176, 'Mentes Criminosas S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2674, 176, 'Mentes Criminosas S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2675, 176, 'Mentes Criminosas S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2676, 176, 'Mentes Criminosas S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2677, 176, 'Mentes Criminosas S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2678, 176, 'Mentes Criminosas S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2679, 176, 'Mentes Criminosas S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2680, 176, 'Mentes Criminosas S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2681, 176, 'Mentes Criminosas S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2682, 176, 'Mentes Criminosas S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2683, 176, 'Mentes Criminosas S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2684, 176, 'Mentes Criminosas S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2685, 176, 'Mentes Criminosas S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/224561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2686, 177, 'Mentes Criminosas S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2687, 177, 'Mentes Criminosas S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2688, 177, 'Mentes Criminosas S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2689, 177, 'Mentes Criminosas S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2690, 177, 'Mentes Criminosas S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2691, 177, 'Mentes Criminosas S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2692, 177, 'Mentes Criminosas S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2693, 177, 'Mentes Criminosas S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2694, 177, 'Mentes Criminosas S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2695, 177, 'Mentes Criminosas S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2696, 177, 'Mentes Criminosas S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2697, 177, 'Mentes Criminosas S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2698, 177, 'Mentes Criminosas S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2699, 177, 'Mentes Criminosas S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2700, 177, 'Mentes Criminosas S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2701, 177, 'Mentes Criminosas S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2702, 177, 'Mentes Criminosas S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2703, 177, 'Mentes Criminosas S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2704, 177, 'Mentes Criminosas S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2705, 177, 'Mentes Criminosas S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2706, 177, 'Mentes Criminosas S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2707, 177, 'Mentes Criminosas S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2708, 177, 'Mentes Criminosas S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/224584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2709, 177, 'Mentes Criminosas S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/224585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2710, 178, 'Mentes Criminosas S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2711, 178, 'Mentes Criminosas S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2712, 178, 'Mentes Criminosas S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2713, 178, 'Mentes Criminosas S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2714, 178, 'Mentes Criminosas S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2715, 178, 'Mentes Criminosas S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2716, 178, 'Mentes Criminosas S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2717, 178, 'Mentes Criminosas S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2718, 178, 'Mentes Criminosas S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2719, 178, 'Mentes Criminosas S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2720, 178, 'Mentes Criminosas S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2721, 178, 'Mentes Criminosas S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2722, 178, 'Mentes Criminosas S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2723, 178, 'Mentes Criminosas S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2724, 178, 'Mentes Criminosas S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2725, 178, 'Mentes Criminosas S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2726, 178, 'Mentes Criminosas S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2727, 178, 'Mentes Criminosas S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2728, 178, 'Mentes Criminosas S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2729, 178, 'Mentes Criminosas S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2730, 178, 'Mentes Criminosas S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2731, 178, 'Mentes Criminosas S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2732, 178, 'Mentes Criminosas S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/224608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2733, 179, 'Mentes Criminosas S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2734, 179, 'Mentes Criminosas S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2735, 179, 'Mentes Criminosas S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2736, 179, 'Mentes Criminosas S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2737, 179, 'Mentes Criminosas S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2738, 179, 'Mentes Criminosas S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2739, 179, 'Mentes Criminosas S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2740, 179, 'Mentes Criminosas S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(2741, 179, 'Mentes Criminosas S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2742, 179, 'Mentes Criminosas S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2743, 179, 'Mentes Criminosas S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2744, 179, 'Mentes Criminosas S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2745, 179, 'Mentes Criminosas S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2746, 179, 'Mentes Criminosas S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2747, 179, 'Mentes Criminosas S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2748, 179, 'Mentes Criminosas S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2749, 179, 'Mentes Criminosas S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2750, 179, 'Mentes Criminosas S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2751, 179, 'Mentes Criminosas S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2752, 179, 'Mentes Criminosas S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2753, 179, 'Mentes Criminosas S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2754, 179, 'Mentes Criminosas S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2755, 179, 'Mentes Criminosas S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/224631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2756, 180, 'Mentes Criminosas S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2757, 180, 'Mentes Criminosas S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2758, 180, 'Mentes Criminosas S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2759, 180, 'Mentes Criminosas S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2760, 180, 'Mentes Criminosas S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2761, 180, 'Mentes Criminosas S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2762, 180, 'Mentes Criminosas S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2763, 180, 'Mentes Criminosas S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2764, 180, 'Mentes Criminosas S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2765, 180, 'Mentes Criminosas S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2766, 180, 'Mentes Criminosas S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2767, 180, 'Mentes Criminosas S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2768, 180, 'Mentes Criminosas S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2769, 180, 'Mentes Criminosas S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2770, 180, 'Mentes Criminosas S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2771, 180, 'Mentes Criminosas S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2772, 180, 'Mentes Criminosas S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2773, 180, 'Mentes Criminosas S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2774, 180, 'Mentes Criminosas S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2775, 180, 'Mentes Criminosas S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2776, 180, 'Mentes Criminosas S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2777, 180, 'Mentes Criminosas S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2778, 180, 'Mentes Criminosas S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/224654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2779, 180, 'Mentes Criminosas S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/224655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2780, 181, 'Mentes Criminosas S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2781, 181, 'Mentes Criminosas S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2782, 181, 'Mentes Criminosas S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2783, 181, 'Mentes Criminosas S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2784, 181, 'Mentes Criminosas S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2785, 181, 'Mentes Criminosas S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2786, 181, 'Mentes Criminosas S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2787, 181, 'Mentes Criminosas S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2788, 181, 'Mentes Criminosas S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2789, 181, 'Mentes Criminosas S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2790, 181, 'Mentes Criminosas S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2791, 181, 'Mentes Criminosas S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2792, 181, 'Mentes Criminosas S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2793, 181, 'Mentes Criminosas S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2794, 181, 'Mentes Criminosas S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2795, 181, 'Mentes Criminosas S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2796, 181, 'Mentes Criminosas S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2797, 181, 'Mentes Criminosas S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2798, 181, 'Mentes Criminosas S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2799, 181, 'Mentes Criminosas S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2800, 181, 'Mentes Criminosas S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2801, 181, 'Mentes Criminosas S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2802, 181, 'Mentes Criminosas S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/224678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2803, 182, 'Mentes Criminosas S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2804, 182, 'Mentes Criminosas S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2805, 182, 'Mentes Criminosas S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2806, 182, 'Mentes Criminosas S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2807, 182, 'Mentes Criminosas S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2808, 182, 'Mentes Criminosas S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2809, 182, 'Mentes Criminosas S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2810, 182, 'Mentes Criminosas S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2811, 182, 'Mentes Criminosas S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2812, 182, 'Mentes Criminosas S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2813, 182, 'Mentes Criminosas S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2814, 182, 'Mentes Criminosas S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2815, 182, 'Mentes Criminosas S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2816, 182, 'Mentes Criminosas S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2817, 182, 'Mentes Criminosas S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2818, 182, 'Mentes Criminosas S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2819, 182, 'Mentes Criminosas S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2820, 182, 'Mentes Criminosas S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2821, 182, 'Mentes Criminosas S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2822, 182, 'Mentes Criminosas S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2823, 182, 'Mentes Criminosas S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2824, 182, 'Mentes Criminosas S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2825, 183, 'Mentes Criminosas S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2826, 183, 'Mentes Criminosas S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2827, 183, 'Mentes Criminosas S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2828, 183, 'Mentes Criminosas S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2829, 183, 'Mentes Criminosas S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2830, 183, 'Mentes Criminosas S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2831, 183, 'Mentes Criminosas S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2832, 183, 'Mentes Criminosas S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2833, 183, 'Mentes Criminosas S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2834, 183, 'Mentes Criminosas S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2835, 183, 'Mentes Criminosas S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2836, 183, 'Mentes Criminosas S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2837, 183, 'Mentes Criminosas S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2838, 183, 'Mentes Criminosas S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2839, 183, 'Mentes Criminosas S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2840, 183, 'Mentes Criminosas S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2841, 183, 'Mentes Criminosas S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2842, 183, 'Mentes Criminosas S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2843, 183, 'Mentes Criminosas S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2844, 183, 'Mentes Criminosas S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2845, 183, 'Mentes Criminosas S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2846, 183, 'Mentes Criminosas S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2847, 184, 'Mentes Criminosas S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2848, 184, 'Mentes Criminosas S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2849, 184, 'Mentes Criminosas S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2850, 184, 'Mentes Criminosas S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2851, 184, 'Mentes Criminosas S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2852, 184, 'Mentes Criminosas S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2853, 184, 'Mentes Criminosas S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2854, 184, 'Mentes Criminosas S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2855, 184, 'Mentes Criminosas S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2856, 184, 'Mentes Criminosas S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2857, 184, 'Mentes Criminosas S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2858, 184, 'Mentes Criminosas S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2859, 184, 'Mentes Criminosas S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2860, 184, 'Mentes Criminosas S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2861, 184, 'Mentes Criminosas S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2862, 184, 'Mentes Criminosas S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2863, 184, 'Mentes Criminosas S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2864, 184, 'Mentes Criminosas S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2865, 184, 'Mentes Criminosas S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2866, 184, 'Mentes Criminosas S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2867, 184, 'Mentes Criminosas S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2868, 184, 'Mentes Criminosas S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2869, 185, 'Mentes Criminosas S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224745.mp4', 'http://timg.bdta.pro/images/0d07f0f8717f9180d76dba2084b489a5.jpg'),
(2870, 185, 'Mentes Criminosas S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224746.mp4', 'http://timg.bdta.pro/images/8eef051def6543fdb9d7cf4180355ffd.jpg'),
(2871, 185, 'Mentes Criminosas S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224747.mp4', 'http://timg.bdta.pro/images/d292d2c203c641a6486ccc815b6aae13.jpg'),
(2872, 185, 'Mentes Criminosas S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224748.mp4', 'http://timg.bdta.pro/images/ba1258552b2aca084ab5c21e3b506f58.jpg'),
(2873, 185, 'Mentes Criminosas S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224749.mp4', 'http://timg.bdta.pro/images/d0bd8a462670c9d7b3789fdfd69e0b1b.jpg'),
(2874, 185, 'Mentes Criminosas S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224750.mp4', 'http://timg.bdta.pro/images/3f2e82b6822678b033d0fe7a717ba83e.jpg'),
(2875, 185, 'Mentes Criminosas S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224751.mp4', 'http://timg.bdta.pro/images/416ec2a7b686678a56b7fe9e27d9164f.jpg'),
(2876, 185, 'Mentes Criminosas S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224752.mp4', 'http://timg.bdta.pro/images/858ca14e61eff3e23c564e50bd0bf5e9.jpg'),
(2877, 185, 'Mentes Criminosas S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224753.mp4', 'http://timg.bdta.pro/images/960c0a5de342cb8dab2a51d134636045.jpg'),
(2878, 185, 'Mentes Criminosas S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224754.mp4', 'http://timg.bdta.pro/images/1f24cc54d4194f439db60d12b0a4e791.jpg'),
(2879, 185, 'Mentes Criminosas S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224755.mp4', 'http://timg.bdta.pro/images/7053238046f69ef7dfbb64cb4221007f.jpg'),
(2880, 185, 'Mentes Criminosas S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224756.mp4', 'http://timg.bdta.pro/images/2d5c11448a771cc432ff93b2ec4f614c.jpg'),
(2881, 185, 'Mentes Criminosas S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224757.mp4', 'http://timg.bdta.pro/images/e0c25a3c7ace1c7ca25802d0e8426b64.jpg'),
(2882, 185, 'Mentes Criminosas S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224758.mp4', 'http://timg.bdta.pro/images/ff94830cbfc34a877e387708611eab84.jpg'),
(2883, 185, 'Mentes Criminosas S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224759.mp4', 'http://timg.bdta.pro/images/6b9d394324246e1484f079f3b1b8b051.jpg'),
(2884, 186, 'Mentes Criminosas S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2885, 186, 'Mentes Criminosas S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2886, 186, 'Mentes Criminosas S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2887, 186, 'Mentes Criminosas S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2888, 186, 'Mentes Criminosas S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2889, 186, 'Mentes Criminosas S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2890, 186, 'Mentes Criminosas S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2891, 186, 'Mentes Criminosas S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2892, 186, 'Mentes Criminosas S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2893, 186, 'Mentes Criminosas S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2894, 187, 'Mentes Criminosas S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rHTod2ovSIn66BXrhFFD7VEz2Zx.jpg'),
(2895, 187, 'Mentes Criminosas S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b4Ve9DekInb8s0OnnwOBGUh9PEY.jpg'),
(2896, 187, 'Mentes Criminosas S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/goLnJZCVyY3eJgWQmIy8xMDvdCj.jpg'),
(2897, 187, 'Mentes Criminosas S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5NfLqrt42lDIClhgVk5TiX4PJv2.jpg'),
(2898, 187, 'Mentes Criminosas S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qx3PHcNP74cieQW3H0Qv0f8USYH.jpg'),
(2899, 187, 'Mentes Criminosas S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9mZa5PYOxAWvzDH141fRVDtL3oe.jpg'),
(2900, 187, 'Mentes Criminosas S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bs7DtrkmN4cZfK2hIyRewNyMerf.jpg'),
(2901, 187, 'Mentes Criminosas S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uY3BgfMBWrevmt23P1BhZ1qrHnm.jpg'),
(2902, 187, 'Mentes Criminosas S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xYOZyK7dmltnatTK8faW0YzwzSw.jpg'),
(2903, 188, 'Mentes Criminosas S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/814918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/71sks91wHDvhkUvsSOgKsHF3sCE.jpg'),
(2904, 188, 'Mentes Criminosas S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/814919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/spzzurSKcQvRYhfnMPRcihfHfnu.jpg'),
(2905, 188, 'Mentes Criminosas S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/814920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n5wahPk33bKMQrgttxFH3qht6L2.jpg'),
(2906, 188, 'Mentes Criminosas S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/814921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rHiRsNI7mkZlGXl3Jy2keIpBW7L.jpg'),
(2907, 188, 'Mentes Criminosas S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/814922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d6JO0TqrA6qh0UDZ5Ei2vVYPLNg.jpg'),
(2908, 188, 'Mentes Criminosas S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/814923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/49lPREy2PTR3Eqo4CcXNnBIuutK.jpg'),
(2909, 188, 'Mentes Criminosas S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/814924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iy9SEEWkalZodEfrBh9iyEue3t1.jpg'),
(2910, 188, 'Mentes Criminosas S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/814925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xcBz04NKYEt1V8GCWkVArRW2OQ3.jpg'),
(2911, 188, 'Mentes Criminosas S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/814926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tsi7Igvio8BcstWDsnb4RGQHuHl.jpg'),
(2912, 188, 'Mentes Criminosas S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/814927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eub3OIy0S03t3xrMBEAVc4GnG6a.jpg'),
(2913, 189, 'Mentes Criminosas S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/821121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2914, 189, 'Mentes Criminosas S18 E02', 'http://sinalprivado.info:80/series/1533784/1533784/821122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2915, 189, 'Mentes Criminosas S18 E03', 'http://sinalprivado.info:80/series/1533784/1533784/821123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2916, 189, 'Mentes Criminosas S18 E04', 'http://sinalprivado.info:80/series/1533784/1533784/821124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2917, 189, 'Mentes Criminosas S18 E05', 'http://sinalprivado.info:80/series/1533784/1533784/828068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2918, 189, 'Mentes Criminosas S18 E06', 'http://sinalprivado.info:80/series/1533784/1533784/841746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2919, 189, 'Mentes Criminosas S18 E07', 'http://sinalprivado.info:80/series/1533784/1533784/856217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2920, 189, 'Mentes Criminosas S18 E08', 'http://sinalprivado.info:80/series/1533784/1533784/854508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2921, 189, 'Mentes Criminosas S18 E09', 'http://sinalprivado.info:80/series/1533784/1533784/856219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2922, 189, 'Mentes Criminosas S18 E10', 'http://sinalprivado.info:80/series/1533784/1533784/865461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trZTeHWcWDn6adkBBuSwfIhxAJn.jpg'),
(2923, 190, 'CSI: Miami S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127657.mp4', 'http://timg.bdta.pro/images/a87d74fbe4a6850ea4b66399427c1345.jpg'),
(2924, 190, 'CSI: Miami S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127658.mp4', 'http://timg.bdta.pro/images/ce1fb94681c4fb2c885f723096e27156.jpg'),
(2925, 190, 'CSI: Miami S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127659.mp4', 'http://timg.bdta.pro/images/8978da4b5767a292cc5e32d0f266ee8d.jpg'),
(2926, 190, 'CSI: Miami S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127660.mp4', 'http://timg.bdta.pro/images/b491e2963814981249919ad5fe3462e0.jpg'),
(2927, 190, 'CSI: Miami S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127661.mp4', 'http://timg.bdta.pro/images/c27e8a3d2e5af3535b379792270ffd51.jpg'),
(2928, 190, 'CSI: Miami S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127662.mp4', 'http://timg.bdta.pro/images/789556cafd1cc81cce735ce9248aadb0.jpg'),
(2929, 190, 'CSI: Miami S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127663.mp4', 'http://timg.bdta.pro/images/cd3c2674494968e79d3a952887b43a8e.jpg'),
(2930, 190, 'CSI: Miami S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127664.mp4', 'http://timg.bdta.pro/images/9d94de99a1a7f787bb6332e14f0b5ea1.jpg'),
(2931, 190, 'CSI: Miami S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127665.mp4', 'http://timg.bdta.pro/images/918ab3e906f04e0f2e5a0344039caba9.jpg'),
(2932, 190, 'CSI: Miami S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127666.mp4', 'http://timg.bdta.pro/images/8fea296686f57adf3cd5f16dab4bdb1c.jpg'),
(2933, 190, 'CSI: Miami S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127667.mp4', 'http://timg.bdta.pro/images/8ab187a5619c61520f3f5b4ad2277195.jpg'),
(2934, 190, 'CSI: Miami S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127668.mp4', 'http://timg.bdta.pro/images/37e61c5f7a6470be819f401c9ccf50b8.jpg'),
(2935, 190, 'CSI: Miami S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127669.mp4', 'http://timg.bdta.pro/images/bf1109233d0aa89f9a96a53d8bc18c08.jpg'),
(2936, 190, 'CSI: Miami S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127670.mp4', 'http://timg.bdta.pro/images/987e783c4c63d12c3851e73573e04171.jpg'),
(2937, 190, 'CSI: Miami S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127671.mp4', 'http://timg.bdta.pro/images/141b622527fc5a08fd1ed9a7376a903a.jpg'),
(2938, 190, 'CSI: Miami S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127672.mp4', 'http://timg.bdta.pro/images/c32bfc02e567e42b48a8450b0dd94360.jpg'),
(2939, 190, 'CSI: Miami S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127673.mp4', 'http://timg.bdta.pro/images/7c7a5b6e824ff308204b8af7c62ef078.jpg'),
(2940, 190, 'CSI: Miami S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127674.mp4', 'http://timg.bdta.pro/images/c4878dc17186dcbd0fbe4ab0d70eaa82.jpg'),
(2941, 190, 'CSI: Miami S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127675.mp4', 'http://timg.bdta.pro/images/ed7309ea8c9623e9508d8c86f5d76fb1.jpg'),
(2942, 190, 'CSI: Miami S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127676.mp4', 'http://timg.bdta.pro/images/9eb25c0d2a5589003e64dc57686cda21.jpg'),
(2943, 190, 'CSI: Miami S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127677.mp4', 'http://timg.bdta.pro/images/155a04d8c5e70c66b16e429d7a433b9f.jpg'),
(2944, 190, 'CSI: Miami S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/127678.mp4', 'http://timg.bdta.pro/images/834da4ad5c56910f8cfd250010ecc77e.jpg'),
(2945, 190, 'CSI: Miami S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/127679.mp4', 'http://timg.bdta.pro/images/53c5d4168131eeeab7fb9f02cefca11b.jpg'),
(2946, 190, 'CSI: Miami S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/127680.mp4', 'http://timg.bdta.pro/images/f726b4528d4c12beae93217ac72ab766.jpg'),
(2947, 191, 'CSI: Miami S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127681.mp4', 'http://timg.bdta.pro/images/d2037fa939d0e7c403f43264d262396a.jpg'),
(2948, 191, 'CSI: Miami S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127682.mp4', 'http://timg.bdta.pro/images/6865f2f8bd0f02a2e35c905977519bb7.jpg'),
(2949, 191, 'CSI: Miami S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127683.mp4', 'http://timg.bdta.pro/images/834b0fcf1b1f61e09eae866bd6dd228c.jpg'),
(2950, 191, 'CSI: Miami S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127684.mp4', 'http://timg.bdta.pro/images/14e5cb085a71ee71e4fe70bf5ea0f8cc.jpg'),
(2951, 191, 'CSI: Miami S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127685.mp4', 'http://timg.bdta.pro/images/d562e81aa4aba7521e7b1a18e5c1b127.jpg'),
(2952, 191, 'CSI: Miami S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127686.mp4', 'http://timg.bdta.pro/images/8f80adbfc20ba39f9b7c9d515c8f1d44.jpg'),
(2953, 191, 'CSI: Miami S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127687.mp4', 'http://timg.bdta.pro/images/725408f3fda8b5b8bce07e1b93b01a21.jpg'),
(2954, 191, 'CSI: Miami S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127688.mp4', 'http://timg.bdta.pro/images/266ca344285255640463d4bec6d373b5.jpg'),
(2955, 191, 'CSI: Miami S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127689.mp4', 'http://timg.bdta.pro/images/95a9f450e3dd456aded3fc1c3f9e4a84.jpg'),
(2956, 191, 'CSI: Miami S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127690.mp4', 'http://timg.bdta.pro/images/df13d49b2932e20211f1754284e86c0e.jpg'),
(2957, 191, 'CSI: Miami S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127691.mp4', 'http://timg.bdta.pro/images/51f75d36037e5727eeb05447848614fb.jpg'),
(2958, 191, 'CSI: Miami S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127692.mp4', 'http://timg.bdta.pro/images/b66847df9e5056805635d126d22962b2.jpg'),
(2959, 191, 'CSI: Miami S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127693.mp4', 'http://timg.bdta.pro/images/77741da18cc9d66d18c514791dc3a281.jpg'),
(2960, 191, 'CSI: Miami S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127694.mp4', 'http://timg.bdta.pro/images/7fe3efcd25c8987a8a01486aa50e0d8f.jpg'),
(2961, 191, 'CSI: Miami S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127695.mp4', 'http://timg.bdta.pro/images/3cb8915e90da3b95b03cd81696e9455a.jpg'),
(2962, 191, 'CSI: Miami S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127696.mp4', 'http://timg.bdta.pro/images/2f0e0b157185674323811d6db7dcda57.jpg'),
(2963, 191, 'CSI: Miami S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127697.mp4', 'http://timg.bdta.pro/images/41cf06c16d2b44637fcd67608187a286.jpg'),
(2964, 191, 'CSI: Miami S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127698.mp4', 'http://timg.bdta.pro/images/4af36b89f325d2b0eae3153460aa7805.jpg'),
(2965, 191, 'CSI: Miami S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127699.mp4', 'http://timg.bdta.pro/images/c416b27ca21c5aef8b906220e3abc3a1.jpg'),
(2966, 191, 'CSI: Miami S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127700.mp4', 'http://timg.bdta.pro/images/eaf1b27a2cae08c769114353b683e351.jpg'),
(2967, 191, 'CSI: Miami S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127701.mp4', 'http://timg.bdta.pro/images/f8479d39046233deaf2d3c4499642e17.jpg'),
(2968, 191, 'CSI: Miami S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/127702.mp4', 'http://timg.bdta.pro/images/b05aa389550e6f0c75fc74004c2512ab.jpg'),
(2969, 191, 'CSI: Miami S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/127703.mp4', 'http://timg.bdta.pro/images/46dc7fc6f6072050bcff5e95c9857e37.jpg'),
(2970, 191, 'CSI: Miami S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/127704.mp4', 'http://timg.bdta.pro/images/ca2e749c1ae4838f6b7f6794d41c7942.jpg'),
(2971, 192, 'CSI: Miami S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127705.mp4', 'http://timg.bdta.pro/images/7d1f9ec1107b2bbe32673b19a3d2ef35.jpg'),
(2972, 192, 'CSI: Miami S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127706.mp4', 'http://timg.bdta.pro/images/d378e6a68eeca58f423120c93fbbee66.jpg'),
(2973, 192, 'CSI: Miami S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127707.mp4', 'http://timg.bdta.pro/images/035b2dcd4d970b19ff586af15b4626bc.jpg'),
(2974, 192, 'CSI: Miami S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127708.mp4', 'http://timg.bdta.pro/images/e344e100df3f2ef52f46c1ecd811e95f.jpg'),
(2975, 192, 'CSI: Miami S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127709.mp4', 'http://timg.bdta.pro/images/e74be54eaa38caf830378e6bd29cc3c8.jpg'),
(2976, 192, 'CSI: Miami S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127710.mp4', 'http://timg.bdta.pro/images/9aa310f18e78dee07479c80f158b9b20.jpg'),
(2977, 192, 'CSI: Miami S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127711.mp4', 'http://timg.bdta.pro/images/b64b1620712d47a43610e786319fe22c.jpg'),
(2978, 192, 'CSI: Miami S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127712.mp4', 'http://timg.bdta.pro/images/223d28d317226fd33e8dd784289aeb3d.jpg'),
(2979, 192, 'CSI: Miami S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127713.mp4', 'http://timg.bdta.pro/images/9a93d0355bb9e8b6d37c6604996dc61b.jpg'),
(2980, 192, 'CSI: Miami S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127714.mp4', 'http://timg.bdta.pro/images/e32200ca30c3b880973d72e63280431e.jpg'),
(2981, 192, 'CSI: Miami S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127715.mp4', 'http://timg.bdta.pro/images/512628d506823371bdf67ad888e4209b.jpg'),
(2982, 192, 'CSI: Miami S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127716.mp4', 'http://timg.bdta.pro/images/8b2b126c9a1254773ea02df58f5c9cb5.jpg'),
(2983, 192, 'CSI: Miami S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127717.mp4', 'http://timg.bdta.pro/images/5980de56d132b180d23b9afe3456f188.jpg'),
(2984, 192, 'CSI: Miami S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127718.mp4', 'http://timg.bdta.pro/images/4571ee07058e84a48e72472d911730d2.jpg'),
(2985, 192, 'CSI: Miami S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127719.mp4', 'http://timg.bdta.pro/images/062e57ee4f95b74bbd5fa068dca2eb08.jpg'),
(2986, 192, 'CSI: Miami S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127720.mp4', 'http://timg.bdta.pro/images/ee416033be0e2afd91f600abe54f7d75.jpg'),
(2987, 192, 'CSI: Miami S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127721.mp4', 'http://timg.bdta.pro/images/2c3e71ca5d5523025c705153978facf7.jpg'),
(2988, 192, 'CSI: Miami S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127722.mp4', 'http://timg.bdta.pro/images/26dfef97c2e321ce94f7bc2ca18f4999.jpg'),
(2989, 192, 'CSI: Miami S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127723.mp4', 'http://timg.bdta.pro/images/33d01edeb02f296388de91866b2008ee.jpg'),
(2990, 192, 'CSI: Miami S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127724.mp4', 'http://timg.bdta.pro/images/39a0e79c38c5c18791b7120231142ce7.jpg'),
(2991, 192, 'CSI: Miami S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127725.mp4', 'http://timg.bdta.pro/images/af89d91805170151a6b3104a6c6f8d34.jpg'),
(2992, 192, 'CSI: Miami S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/127726.mp4', 'http://timg.bdta.pro/images/ca7485f77f7cd9a2f1b296d88c9a53d7.jpg'),
(2993, 192, 'CSI: Miami S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/127727.mp4', 'http://timg.bdta.pro/images/1de1fa1e830a7771c54b7fcbeeeaa7d4.jpg'),
(2994, 192, 'CSI: Miami S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/127728.mp4', 'http://timg.bdta.pro/images/527abf08d252365595f31deeb64e026e.jpg'),
(2995, 193, 'CSI: Miami S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127729.mp4', 'http://timg.bdta.pro/images/2d269a87ce5876a4a8bb6856d5c12cae.jpg'),
(2996, 193, 'CSI: Miami S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127730.mp4', 'http://timg.bdta.pro/images/9eaf346afd905f1556e9baee3b807837.jpg'),
(2997, 193, 'CSI: Miami S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127731.mp4', 'http://timg.bdta.pro/images/e8c5cf3a8b4f1330861f0f1eb6362cbc.jpg'),
(2998, 193, 'CSI: Miami S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127732.mp4', 'http://timg.bdta.pro/images/0c06e29d27cf1694338ffaa2ba51d661.jpg'),
(2999, 193, 'CSI: Miami S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127733.mp4', 'http://timg.bdta.pro/images/21bf9b8f2bc3dfb3e4c86e7e26012100.jpg'),
(3000, 193, 'CSI: Miami S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127734.mp4', 'http://timg.bdta.pro/images/65a066d839df173dd0c8bbfb90ea6744.jpg'),
(3001, 193, 'CSI: Miami S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127735.mp4', 'http://timg.bdta.pro/images/ecc03bf08b5202187e0066b21e9bad43.jpg'),
(3002, 193, 'CSI: Miami S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127736.mp4', 'http://timg.bdta.pro/images/6b87b2e5ef734cb56c40b11636f87a66.jpg'),
(3003, 193, 'CSI: Miami S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127737.mp4', 'http://timg.bdta.pro/images/42420aa1a411505ca498a9a8b108ab04.jpg'),
(3004, 193, 'CSI: Miami S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127738.mp4', 'http://timg.bdta.pro/images/691620ffd3abf59f348244815bf97d03.jpg'),
(3005, 193, 'CSI: Miami S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127739.mp4', 'http://timg.bdta.pro/images/df23ee02bcedc46b90d50aee87f1eae9.jpg'),
(3006, 193, 'CSI: Miami S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127740.mp4', 'http://timg.bdta.pro/images/29657f5c97bad339d6d45774e9c7d07f.jpg'),
(3007, 193, 'CSI: Miami S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127741.mp4', 'http://timg.bdta.pro/images/caba1e40745f4e0d19e8f6063db62a41.jpg'),
(3008, 193, 'CSI: Miami S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127742.mp4', 'http://timg.bdta.pro/images/d41cf35e5cc318c3b5b140388fe5ef2e.jpg'),
(3009, 193, 'CSI: Miami S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127743.mp4', 'http://timg.bdta.pro/images/19c5dfba75839d04935c14323589e51a.jpg'),
(3010, 193, 'CSI: Miami S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127744.mp4', 'http://timg.bdta.pro/images/d23251f4edb09e82e2b3aca2ed7dfd3f.jpg'),
(3011, 193, 'CSI: Miami S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127745.mp4', 'http://timg.bdta.pro/images/f4c1aab42e1003c68fc3b66fa14163ea.jpg'),
(3012, 193, 'CSI: Miami S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127746.mp4', 'http://timg.bdta.pro/images/3faaa966ac363b8d4080b7a683cc3d5a.jpg'),
(3013, 193, 'CSI: Miami S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127747.mp4', 'http://timg.bdta.pro/images/24acc33ad8b6c83b7e13429a3eb5b1cf.jpg'),
(3014, 193, 'CSI: Miami S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127748.mp4', 'http://timg.bdta.pro/images/b813d7354e1e10ebfd08b328d0b1326f.jpg'),
(3015, 193, 'CSI: Miami S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127749.mp4', 'http://timg.bdta.pro/images/4d96c70671213e84fe3fa3ffe1f71661.jpg'),
(3016, 193, 'CSI: Miami S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/127750.mp4', 'http://timg.bdta.pro/images/300586aa12d30b79f553cf82c2f2eac3.jpg'),
(3017, 193, 'CSI: Miami S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/127751.mp4', 'http://timg.bdta.pro/images/3c6de5e3ee4d83b2537d72bc07047895.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(3018, 193, 'CSI: Miami S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/127752.mp4', 'http://timg.bdta.pro/images/51dbd2819ff0d38175cf276f1ca8fe0e.jpg'),
(3019, 193, 'CSI: Miami S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/127753.mp4', 'http://timg.bdta.pro/images/f9c010b03e1009a194ff265be13681e0.jpg'),
(3020, 194, 'CSI: Miami S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127754.mp4', 'http://timg.bdta.pro/images/9760c87455fbc7001ca3f61c7cf8d3d5.jpg'),
(3021, 194, 'CSI: Miami S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127755.mp4', 'http://timg.bdta.pro/images/f58641015eb5bce5eaef73bd6dd0d621.jpg'),
(3022, 194, 'CSI: Miami S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127756.mp4', 'http://timg.bdta.pro/images/1b801462c9dafb022ed5ddeebc74df13.jpg'),
(3023, 194, 'CSI: Miami S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127757.mp4', 'http://timg.bdta.pro/images/94dfdbf870fcd98d687d2d8846cc4bb8.jpg'),
(3024, 194, 'CSI: Miami S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127758.mp4', 'http://timg.bdta.pro/images/029adf975778114856210864345e68f5.jpg'),
(3025, 194, 'CSI: Miami S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127759.mp4', 'http://timg.bdta.pro/images/84b7511e0769a22b409a387683ac4567.jpg'),
(3026, 194, 'CSI: Miami S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127760.mp4', 'http://timg.bdta.pro/images/035edc80d3b05d528024283a563766cd.jpg'),
(3027, 194, 'CSI: Miami S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127761.mp4', 'http://timg.bdta.pro/images/636b4112e43a6e437d2726dfb399aa5c.jpg'),
(3028, 194, 'CSI: Miami S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127762.mp4', 'http://timg.bdta.pro/images/f34378ddaf5328f2fdf393693ff6a72e.jpg'),
(3029, 194, 'CSI: Miami S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127763.mp4', 'http://timg.bdta.pro/images/8df822b86612056f8ffa0ecc00057e35.jpg'),
(3030, 194, 'CSI: Miami S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127764.mp4', 'http://timg.bdta.pro/images/c464136db070f7d0cdeecce1ac934ec7.jpg'),
(3031, 194, 'CSI: Miami S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127765.mp4', 'http://timg.bdta.pro/images/db413e8de3e399ceef1badff277c7bb5.jpg'),
(3032, 194, 'CSI: Miami S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127766.mp4', 'http://timg.bdta.pro/images/851d7a417f45c86cfbcee9d2094cf324.jpg'),
(3033, 194, 'CSI: Miami S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127767.mp4', 'http://timg.bdta.pro/images/a5ca4ad4e193cf08f03cb0904ca033e0.jpg'),
(3034, 194, 'CSI: Miami S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127768.mp4', 'http://timg.bdta.pro/images/e876074fcc6810b835e4744f4c4a0f54.jpg'),
(3035, 194, 'CSI: Miami S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127769.mp4', 'http://timg.bdta.pro/images/5bec9d699b5611f5d9574f036ecda45a.jpg'),
(3036, 194, 'CSI: Miami S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127770.mp4', 'http://timg.bdta.pro/images/9f02d2fc539e51aeeab03c5bd2e2046d.jpg'),
(3037, 194, 'CSI: Miami S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127771.mp4', 'http://timg.bdta.pro/images/049fad9a278062d0d8699d80dd832ac2.jpg'),
(3038, 194, 'CSI: Miami S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127772.mp4', 'http://timg.bdta.pro/images/23140af3f8fe6492b5778e88f9b12123.jpg'),
(3039, 194, 'CSI: Miami S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127773.mp4', 'http://timg.bdta.pro/images/babb94847bbb64b7533332d366e33198.jpg'),
(3040, 194, 'CSI: Miami S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127774.mp4', 'http://timg.bdta.pro/images/74db264b9e1645430c9468b354766215.jpg'),
(3041, 194, 'CSI: Miami S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/127775.mp4', 'http://timg.bdta.pro/images/3ac6eee81bbeae158eedc6b1ff24917c.jpg'),
(3042, 194, 'CSI: Miami S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/127776.mp4', 'http://timg.bdta.pro/images/6430c735b5a08d2fbebe46e40002bce6.jpg'),
(3043, 194, 'CSI: Miami S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/127777.mp4', 'http://timg.bdta.pro/images/1e095cd9bd91b2e58819229cfe3f1765.jpg'),
(3044, 195, 'CSI: Miami S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127778.mp4', 'http://timg.bdta.pro/images/e419d49b3849635e2079526633161236.jpg'),
(3045, 195, 'CSI: Miami S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127779.mp4', 'http://timg.bdta.pro/images/5795aadbfbaa504fedde287b554e95ad.jpg'),
(3046, 195, 'CSI: Miami S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127780.mp4', 'http://timg.bdta.pro/images/2b5b3cb7ca17cb6d7a351bb79584937c.jpg'),
(3047, 195, 'CSI: Miami S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127781.mp4', 'http://timg.bdta.pro/images/17d15d20bdb11552b8e2a90ad75b26c2.jpg'),
(3048, 195, 'CSI: Miami S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127782.mp4', 'http://timg.bdta.pro/images/66ddbc37b64fdaf62f251010ff4ca3eb.jpg'),
(3049, 195, 'CSI: Miami S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127783.mp4', 'http://timg.bdta.pro/images/ea968148aa6e574d34360f0cbb10f9ee.jpg'),
(3050, 195, 'CSI: Miami S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127784.mp4', 'http://timg.bdta.pro/images/2e8668edaa9c5167686c29e342fb20c4.jpg'),
(3051, 195, 'CSI: Miami S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127785.mp4', 'http://timg.bdta.pro/images/a96492b2569b2955253a0391d6fd58e3.jpg'),
(3052, 195, 'CSI: Miami S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127786.mp4', 'http://timg.bdta.pro/images/26d765cd37895eb948ba0672ac709f41.jpg'),
(3053, 195, 'CSI: Miami S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127787.mp4', 'http://timg.bdta.pro/images/80ba085dbbf0f4142d5b452b717d4947.jpg'),
(3054, 195, 'CSI: Miami S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127788.mp4', 'http://timg.bdta.pro/images/e0e4e5589575beb95e38e1bef90a6305.jpg'),
(3055, 195, 'CSI: Miami S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127789.mp4', 'http://timg.bdta.pro/images/43914cdc731b841fb37ad2eac2fa8ad4.jpg'),
(3056, 195, 'CSI: Miami S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127790.mp4', 'http://timg.bdta.pro/images/526355e4011e84c1fcb063d9031b9289.jpg'),
(3057, 195, 'CSI: Miami S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127791.mp4', 'http://timg.bdta.pro/images/882fe49bd3e49c66fccf209b990e4ffd.jpg'),
(3058, 195, 'CSI: Miami S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127792.mp4', 'http://timg.bdta.pro/images/e28135d4c8b70e32c8556ccf5f081d7e.jpg'),
(3059, 195, 'CSI: Miami S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127793.mp4', 'http://timg.bdta.pro/images/f8a111b11e028de1894e7efb71251f3a.jpg'),
(3060, 195, 'CSI: Miami S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127794.mp4', 'http://timg.bdta.pro/images/223bab8b4a7a3606e287141bd62dc4ae.jpg'),
(3061, 195, 'CSI: Miami S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127795.mp4', 'http://timg.bdta.pro/images/25e1a27f946341e7e7c668e1c6012544.jpg'),
(3062, 195, 'CSI: Miami S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127796.mp4', 'http://timg.bdta.pro/images/72c2ba4a3be23a02612ef1c6a633215e.jpg'),
(3063, 195, 'CSI: Miami S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127797.mp4', 'http://timg.bdta.pro/images/9150f0a8f0eebd987f1de38b412ca810.jpg'),
(3064, 195, 'CSI: Miami S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127798.mp4', 'http://timg.bdta.pro/images/30b506137952caa1c4180383f1aba336.jpg'),
(3065, 196, 'CSI: Miami S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127799.mp4', 'http://timg.bdta.pro/images/c4a8d496eee10b2430bdf99054dc49da.jpg'),
(3066, 196, 'CSI: Miami S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127800.mp4', 'http://timg.bdta.pro/images/290185d4876328ed022fb6f4a1d696ec.jpg'),
(3067, 196, 'CSI: Miami S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127801.mp4', 'http://timg.bdta.pro/images/30971fcee752364119d6d2f0475eb3d8.jpg'),
(3068, 196, 'CSI: Miami S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127802.mp4', 'http://timg.bdta.pro/images/7bd18a38861e319013c19b87a26b9ca5.jpg'),
(3069, 196, 'CSI: Miami S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127803.mp4', 'http://timg.bdta.pro/images/871f9bd2729d5a41b905b03b652d29e4.jpg'),
(3070, 196, 'CSI: Miami S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127804.mp4', 'http://timg.bdta.pro/images/a1939377d05b6c49b2b8c01c3debad36.jpg'),
(3071, 196, 'CSI: Miami S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127805.mp4', 'http://timg.bdta.pro/images/584568d7b0f8172394afc6046be20aef.jpg'),
(3072, 196, 'CSI: Miami S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127806.mp4', 'http://timg.bdta.pro/images/953799defa3c3bceef66cdf923d83d7c.jpg'),
(3073, 196, 'CSI: Miami S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127807.mp4', 'http://timg.bdta.pro/images/23d823a35f760d672d62a3a6816c5cd7.jpg'),
(3074, 196, 'CSI: Miami S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127808.mp4', 'http://timg.bdta.pro/images/23a637e01bbda36d4a0e1a15723d3cf9.jpg'),
(3075, 196, 'CSI: Miami S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127809.mp4', 'http://timg.bdta.pro/images/e235e3cc7ffccee73c720b6302677a32.jpg'),
(3076, 196, 'CSI: Miami S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127810.mp4', 'http://timg.bdta.pro/images/395d4fd20f67899712baf497fd556f98.jpg'),
(3077, 196, 'CSI: Miami S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127811.mp4', 'http://timg.bdta.pro/images/14501225f46dc6667126db4390189088.jpg'),
(3078, 196, 'CSI: Miami S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127812.mp4', 'http://timg.bdta.pro/images/9af67a241f7551a1b1b8281e12fc5f35.jpg'),
(3079, 196, 'CSI: Miami S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127813.mp4', 'http://timg.bdta.pro/images/fe89d31b6120ce4b3ac49f51e668fd1b.jpg'),
(3080, 196, 'CSI: Miami S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127814.mp4', 'http://timg.bdta.pro/images/f6e1093699a7fc612fa695657b673374.jpg'),
(3081, 196, 'CSI: Miami S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127815.mp4', 'http://timg.bdta.pro/images/29e43d25428c4f8f9051f18ac9d6e927.jpg'),
(3082, 196, 'CSI: Miami S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127816.mp4', 'http://timg.bdta.pro/images/cf8304e06f43e9dfde2c13dfb807b76d.jpg'),
(3083, 196, 'CSI: Miami S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127817.mp4', 'http://timg.bdta.pro/images/5f1db9a6af40b8b101b3c761bce9317a.jpg'),
(3084, 196, 'CSI: Miami S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127818.mp4', 'http://timg.bdta.pro/images/e268828aff2c8b5937be58053f1f6a2c.jpg'),
(3085, 196, 'CSI: Miami S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127819.mp4', 'http://timg.bdta.pro/images/3c1563ec93ee7c52d7cff33deb07a476.jpg'),
(3086, 196, 'CSI: Miami S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/127820.mp4', 'http://timg.bdta.pro/images/1ac5c705049d8aabdf79f8c6d9e2ce29.jpg'),
(3087, 196, 'CSI: Miami S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/127821.mp4', 'http://timg.bdta.pro/images/50cda21c9c533804302398406502ebb4.jpg'),
(3088, 196, 'CSI: Miami S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/127822.mp4', 'http://timg.bdta.pro/images/b38521e254433b8b59db25318b769c8a.jpg'),
(3089, 196, 'CSI: Miami S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/127823.mp4', 'http://timg.bdta.pro/images/f03d78a373286e15cd21410c0000d064.jpg'),
(3090, 197, 'CSI: Miami S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127824.mp4', 'http://timg.bdta.pro/images/21d5baead4c500ac72be73cbd1729bb1.jpg'),
(3091, 197, 'CSI: Miami S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127825.mp4', 'http://timg.bdta.pro/images/6c336531431823ca4a4f2bd8e9fdcbc3.jpg'),
(3092, 197, 'CSI: Miami S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127826.mp4', 'http://timg.bdta.pro/images/ec8362f860c7ef3ace7ea28e921b70cb.jpg'),
(3093, 197, 'CSI: Miami S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127827.mp4', 'http://timg.bdta.pro/images/82d171bb715c9bc545ac0a96a1462149.jpg'),
(3094, 197, 'CSI: Miami S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127828.mp4', 'http://timg.bdta.pro/images/2991c7091f207ebe905c739f492d75bb.jpg'),
(3095, 197, 'CSI: Miami S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127829.mp4', 'http://timg.bdta.pro/images/b10916185670e85f778e03e02e5c8947.jpg'),
(3096, 197, 'CSI: Miami S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127830.mp4', 'http://timg.bdta.pro/images/b146f80fa11d61ece5cbea0b12470eb9.jpg'),
(3097, 197, 'CSI: Miami S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127831.mp4', 'http://timg.bdta.pro/images/3211bfb75bc42d2efa12088511475b80.jpg'),
(3098, 197, 'CSI: Miami S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127832.mp4', 'http://timg.bdta.pro/images/6738d491dceef8a7c884765ca8dbaf92.jpg'),
(3099, 197, 'CSI: Miami S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127833.mp4', 'http://timg.bdta.pro/images/ec0a03d4b0a2622af4577845c906fe2b.jpg'),
(3100, 197, 'CSI: Miami S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127834.mp4', 'http://timg.bdta.pro/images/44ae2ec5a1bcb532b5fe6fb887448ef5.jpg'),
(3101, 197, 'CSI: Miami S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127835.mp4', 'http://timg.bdta.pro/images/21431c331d02bf79df5ef17cd1aa9a0a.jpg'),
(3102, 197, 'CSI: Miami S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127836.mp4', 'http://timg.bdta.pro/images/1a33215cf4356111764e6bd0e07f47cd.jpg'),
(3103, 197, 'CSI: Miami S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127837.mp4', 'http://timg.bdta.pro/images/2d498d86acf43708e82cb80bfdbd3ddb.jpg'),
(3104, 197, 'CSI: Miami S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127838.mp4', 'http://timg.bdta.pro/images/e961311c98b6dc9e16c559771214e7c8.jpg'),
(3105, 197, 'CSI: Miami S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127839.mp4', 'http://timg.bdta.pro/images/92d24872f4ac9804774c745678c197ab.jpg'),
(3106, 197, 'CSI: Miami S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127840.mp4', 'http://timg.bdta.pro/images/81847685f5af257a468d5e25848fe5c7.jpg'),
(3107, 197, 'CSI: Miami S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127841.mp4', 'http://timg.bdta.pro/images/e230eb5ff0131ba2f201a140fa560bc8.jpg'),
(3108, 197, 'CSI: Miami S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127842.mp4', 'http://timg.bdta.pro/images/080fb22f3b846099ec5b3de646ec100e.jpg'),
(3109, 197, 'CSI: Miami S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127843.mp4', 'http://timg.bdta.pro/images/ea6a6bc6ddce3319e7c5d09780d8a5d5.jpg'),
(3110, 197, 'CSI: Miami S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127844.mp4', 'http://timg.bdta.pro/images/693bd292d5dc3b5d39a30a12e2b17cae.jpg'),
(3111, 197, 'CSI: Miami S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/127845.mp4', 'http://timg.bdta.pro/images/56b87d99ce286b876c01676c1ff0c36c.jpg'),
(3112, 197, 'CSI: Miami S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/127846.mp4', 'http://timg.bdta.pro/images/59359fc74d0332fdb0977356cab8df92.jpg'),
(3113, 197, 'CSI: Miami S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/127847.mp4', 'http://timg.bdta.pro/images/752d25109f47b02191b162fe6957b9e3.jpg'),
(3114, 198, 'CSI: Miami S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127848.mp4', 'http://timg.bdta.pro/images/f1e166aaeb6a4690350e1ab7a8e05f27.jpg'),
(3115, 198, 'CSI: Miami S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127849.mp4', 'http://timg.bdta.pro/images/4adf6577efbde91d1d9049546b465f4e.jpg'),
(3116, 198, 'CSI: Miami S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127850.mp4', 'http://timg.bdta.pro/images/510074e1953e5e880d101820799e4fda.jpg'),
(3117, 198, 'CSI: Miami S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127851.mp4', 'http://timg.bdta.pro/images/58da4ecbc64911bc3ae9ef0e992bbe92.jpg'),
(3118, 198, 'CSI: Miami S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127852.mp4', 'http://timg.bdta.pro/images/e0b2341443c79ffe2abb51fea4c4c366.jpg'),
(3119, 198, 'CSI: Miami S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127853.mp4', 'http://timg.bdta.pro/images/3e8132513bc41e0b71af5af4ddbb28cd.jpg'),
(3120, 198, 'CSI: Miami S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127854.mp4', 'http://timg.bdta.pro/images/d0654384c5d67c91f8b85a8139ea9d87.jpg'),
(3121, 198, 'CSI: Miami S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127855.mp4', 'http://timg.bdta.pro/images/ed57b63f3c18ee02fb217f7a7fbd6617.jpg'),
(3122, 198, 'CSI: Miami S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127856.mp4', 'http://timg.bdta.pro/images/bf04348f97e244050076e9ad9722bcfb.jpg'),
(3123, 198, 'CSI: Miami S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127857.mp4', 'http://timg.bdta.pro/images/4463505d4656e49b83d3125629683f75.jpg'),
(3124, 198, 'CSI: Miami S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127858.mp4', 'http://timg.bdta.pro/images/de10d3a508c95e43178812a787893577.jpg'),
(3125, 198, 'CSI: Miami S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127859.mp4', 'http://timg.bdta.pro/images/75155bd28540607ce948628dc8cbd495.jpg'),
(3126, 198, 'CSI: Miami S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127860.mp4', 'http://timg.bdta.pro/images/cfd362c1e8353bef5f29dba7e9cef5e0.jpg'),
(3127, 198, 'CSI: Miami S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127861.mp4', 'http://timg.bdta.pro/images/5b1ca957f775c99a6ba28cf9afec59ca.jpg'),
(3128, 198, 'CSI: Miami S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127862.mp4', 'http://timg.bdta.pro/images/d0d46cd106aeaf03054b8c6f9201684f.jpg'),
(3129, 198, 'CSI: Miami S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127863.mp4', 'http://timg.bdta.pro/images/fb5830a2c4ed4a26e964535fd52f5210.jpg'),
(3130, 198, 'CSI: Miami S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127864.mp4', 'http://timg.bdta.pro/images/e77e08d05e2870a0c7458d9eb42daa7a.jpg'),
(3131, 198, 'CSI: Miami S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127865.mp4', 'http://timg.bdta.pro/images/135b5a2b69c76a50e3580489a0024366.jpg'),
(3132, 198, 'CSI: Miami S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127866.mp4', 'http://timg.bdta.pro/images/f4b8c966fc5522a77c0df29815f0baad.jpg'),
(3133, 198, 'CSI: Miami S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127867.mp4', 'http://timg.bdta.pro/images/b0d82bb8a2051169dfdc81635b9618cb.jpg'),
(3134, 198, 'CSI: Miami S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127868.mp4', 'http://timg.bdta.pro/images/3925e999fe615843af06631775e2990d.jpg'),
(3135, 198, 'CSI: Miami S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/127869.mp4', 'http://timg.bdta.pro/images/f54453bd2f280164056a236875c44a1b.jpg'),
(3136, 199, 'CSI: Miami S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127870.mp4', 'http://timg.bdta.pro/images/c07c7279b4b50526496bc0f0e1e204f6.jpg'),
(3137, 199, 'CSI: Miami S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127871.mp4', 'http://timg.bdta.pro/images/5423c5a1cc4b1683d2deb56112e3d7cc.jpg'),
(3138, 199, 'CSI: Miami S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127872.mp4', 'http://timg.bdta.pro/images/2a9d83b2bfeced8797884f71f2fefdba.jpg'),
(3139, 199, 'CSI: Miami S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127873.mp4', 'http://timg.bdta.pro/images/1313b2cb98d2af497a86d3fae66260db.jpg'),
(3140, 199, 'CSI: Miami S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127874.mp4', 'http://timg.bdta.pro/images/b0bc6d24ba66ad7186fa9ddcc3513f7a.jpg'),
(3141, 199, 'CSI: Miami S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127875.mp4', 'http://timg.bdta.pro/images/21421e5a2bfb3aafa265d528e2eb57dc.jpg'),
(3142, 199, 'CSI: Miami S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127876.mp4', 'http://timg.bdta.pro/images/1ef952340eacca83d9e72fc98a01eed4.jpg'),
(3143, 199, 'CSI: Miami S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127877.mp4', 'http://timg.bdta.pro/images/85cb021085e6c2eb2da2c4b0b9982228.jpg'),
(3144, 199, 'CSI: Miami S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127878.mp4', 'http://timg.bdta.pro/images/bac266e363ff907269a1d7bc35dbf8ae.jpg'),
(3145, 199, 'CSI: Miami S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127879.mp4', 'http://timg.bdta.pro/images/a29e0ab1308057547cc349bf54d1a63b.jpg'),
(3146, 199, 'CSI: Miami S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127880.mp4', 'http://timg.bdta.pro/images/b48e211e246a2bd4ccf1b878dcd36037.jpg'),
(3147, 199, 'CSI: Miami S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127881.mp4', 'http://timg.bdta.pro/images/1dc454a204c66a6eaf151144acc756cc.jpg'),
(3148, 199, 'CSI: Miami S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127882.mp4', 'http://timg.bdta.pro/images/6285e7f6655485348e144d8bb96e283d.jpg'),
(3149, 199, 'CSI: Miami S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127883.mp4', 'http://timg.bdta.pro/images/2e2d3e2fd54aed3fe5099d7fe989e6e3.jpg'),
(3150, 199, 'CSI: Miami S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127884.mp4', 'http://timg.bdta.pro/images/2c5a03f048200acb78fa4f6ea36804bf.jpg'),
(3151, 199, 'CSI: Miami S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127885.mp4', 'http://timg.bdta.pro/images/9ffac32a7896ea27e850d7aaa5f3fbe3.jpg'),
(3152, 199, 'CSI: Miami S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127886.mp4', 'http://timg.bdta.pro/images/dfadc489bf98d586f17937f7505adc05.jpg'),
(3153, 199, 'CSI: Miami S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127887.mp4', 'http://timg.bdta.pro/images/f54c13a16cf543aa449a773a03ebba90.jpg'),
(3154, 199, 'CSI: Miami S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127888.mp4', 'http://timg.bdta.pro/images/c90a23adba95f8b4af7d48a6b43c6b7c.jpg'),
(3155, 200, 'CSI: Nova York S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127473.mp4', 'http://timg.bdta.pro/images/d08e2bf56d1942a9bd537f4db6ee4055.jpg'),
(3156, 200, 'CSI: Nova York S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127474.mp4', 'http://timg.bdta.pro/images/362a1efd675e9e690764f126f2df26c5.jpg'),
(3157, 200, 'CSI: Nova York S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127475.mp4', 'http://timg.bdta.pro/images/63903794548b723d5cc80d6ce7e57810.jpg'),
(3158, 200, 'CSI: Nova York S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127476.mp4', 'http://timg.bdta.pro/images/6896131889e3b4e3af8bfd18d168b746.jpg'),
(3159, 200, 'CSI: Nova York S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127477.mp4', 'http://timg.bdta.pro/images/59be3642b9c387bf8cc88d9bf0b39260.jpg'),
(3160, 200, 'CSI: Nova York S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127478.mp4', 'http://timg.bdta.pro/images/8d8e542551dd2c95526c3441f40f6262.jpg'),
(3161, 200, 'CSI: Nova York S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127479.mp4', 'http://timg.bdta.pro/images/a99467587bd4d41c819842e17be1b1ca.jpg'),
(3162, 200, 'CSI: Nova York S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127480.mp4', 'http://timg.bdta.pro/images/7082ed1281427792fe11b274213fffe9.jpg'),
(3163, 200, 'CSI: Nova York S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127481.mp4', 'http://timg.bdta.pro/images/be20e39b1802ddc90d42ab47745307fb.jpg'),
(3164, 200, 'CSI: Nova York S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127482.mp4', 'http://timg.bdta.pro/images/45f3b247a4856efbd708917b497322fd.jpg'),
(3165, 200, 'CSI: Nova York S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127483.mp4', 'http://timg.bdta.pro/images/a383e85daecc516cdce9d2b83b0f75bc.jpg'),
(3166, 200, 'CSI: Nova York S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127484.mp4', 'http://timg.bdta.pro/images/6dea7a58fb7a9f06d18e668eabadc506.jpg'),
(3167, 200, 'CSI: Nova York S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127485.mp4', 'http://timg.bdta.pro/images/ad21d8c83a913dfee1f10911c49cc58b.jpg'),
(3168, 200, 'CSI: Nova York S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127486.mp4', 'http://timg.bdta.pro/images/bfd1d8ab2b5afb9858dfe2e1105aea0b.jpg'),
(3169, 200, 'CSI: Nova York S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127487.mp4', 'http://timg.bdta.pro/images/c72d9345e155b8fd52d4356cf3f0e13a.jpg'),
(3170, 200, 'CSI: Nova York S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127488.mp4', 'http://timg.bdta.pro/images/fc5820556d743a104a2f7682d7866fe9.jpg'),
(3171, 200, 'CSI: Nova York S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127489.mp4', 'http://timg.bdta.pro/images/a60e2fd4a4f44c139f833e42b53cbcc2.jpg'),
(3172, 200, 'CSI: Nova York S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127490.mp4', 'http://timg.bdta.pro/images/8b4de013844276c049af8249ee8814f1.jpg'),
(3173, 200, 'CSI: Nova York S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127491.mp4', 'http://timg.bdta.pro/images/11cae552b7048441e7fce6bd938a5a35.jpg'),
(3174, 200, 'CSI: Nova York S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127492.mp4', 'http://timg.bdta.pro/images/19945befb56dc3edf46395cd29ee807e.jpg'),
(3175, 200, 'CSI: Nova York S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127493.mp4', 'http://timg.bdta.pro/images/5ee95d8b1aabce06a4e910fb4022a9ed.jpg'),
(3176, 200, 'CSI: Nova York S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/127494.mp4', 'http://timg.bdta.pro/images/126199ec91575b60fa9b773cb3efe45c.jpg'),
(3177, 200, 'CSI: Nova York S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/127495.mp4', 'http://timg.bdta.pro/images/99d8dac6b0bb130fd75f54793db33162.jpg'),
(3178, 201, 'CSI: Nova York S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127496.mp4', 'http://timg.bdta.pro/images/a68c72bc56c31527af3392206a0d5028.jpg'),
(3179, 201, 'CSI: Nova York S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127497.mp4', 'http://timg.bdta.pro/images/6277ba73e8868e51e7a832eae565f0be.jpg'),
(3180, 201, 'CSI: Nova York S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127498.mp4', 'http://timg.bdta.pro/images/4b33c6937f8bd9b632d11020bdd80830.jpg'),
(3181, 201, 'CSI: Nova York S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127499.mp4', 'http://timg.bdta.pro/images/a3107be4240cc3447dd3d6d13248b0c0.jpg'),
(3182, 201, 'CSI: Nova York S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127500.mp4', 'http://timg.bdta.pro/images/d583ee6518837295f4285d15fdfd80b0.jpg'),
(3183, 201, 'CSI: Nova York S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127501.mp4', 'http://timg.bdta.pro/images/bf36b33efb456a4285cb43aedc63d422.jpg'),
(3184, 201, 'CSI: Nova York S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127502.mp4', 'http://timg.bdta.pro/images/ed7c95ea7e8092cb420e5720d393c9c2.jpg'),
(3185, 201, 'CSI: Nova York S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127503.mp4', 'http://timg.bdta.pro/images/480414b031c35b88d875cf3a7abc6ad6.jpg'),
(3186, 201, 'CSI: Nova York S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127504.mp4', 'http://timg.bdta.pro/images/c00dd9edb730fac88448c52c775de18c.jpg'),
(3187, 201, 'CSI: Nova York S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127505.mp4', 'http://timg.bdta.pro/images/379df333616b1d40081110ba9c66cce3.jpg'),
(3188, 201, 'CSI: Nova York S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127506.mp4', 'http://timg.bdta.pro/images/03f687af3362d8f5d738436bac641203.jpg'),
(3189, 201, 'CSI: Nova York S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127507.mp4', 'http://timg.bdta.pro/images/f18177c948f720c0696c124413a0a93c.jpg'),
(3190, 201, 'CSI: Nova York S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127508.mp4', 'http://timg.bdta.pro/images/d43a30d791c38ac40dc796cea29937d9.jpg'),
(3191, 201, 'CSI: Nova York S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127509.mp4', 'http://timg.bdta.pro/images/d276625874bee37e000cdbca3a51ac42.jpg'),
(3192, 201, 'CSI: Nova York S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127510.mp4', 'http://timg.bdta.pro/images/df3b5aeb45d677dcb86a5318cb9d67f9.jpg'),
(3193, 201, 'CSI: Nova York S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127511.mp4', 'http://timg.bdta.pro/images/bd85d9d9647684f2df392042ec10144e.jpg'),
(3194, 201, 'CSI: Nova York S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127512.mp4', 'http://timg.bdta.pro/images/370b9f98ae58529bf4c24e851d94a494.jpg'),
(3195, 201, 'CSI: Nova York S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127513.mp4', 'http://timg.bdta.pro/images/9faa0ab461412201e7dcdc2970b26a8c.jpg'),
(3196, 201, 'CSI: Nova York S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127514.mp4', 'http://timg.bdta.pro/images/3e7d98614d7593d0786b9042e3ff42ab.jpg'),
(3197, 201, 'CSI: Nova York S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127515.mp4', 'http://timg.bdta.pro/images/82fcfa1c263aa90331a4eb3f76d700a7.jpg'),
(3198, 201, 'CSI: Nova York S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127516.mp4', 'http://timg.bdta.pro/images/7a1a6a01d534a65d59046d4f6fb81e34.jpg'),
(3199, 201, 'CSI: Nova York S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/127517.mp4', 'http://timg.bdta.pro/images/ad28e5f7beaed0fb04ca44a9212bcde9.jpg'),
(3200, 201, 'CSI: Nova York S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/127518.mp4', 'http://timg.bdta.pro/images/9df8723fd42c6f3d9dde251baf1a23bd.jpg'),
(3201, 201, 'CSI: Nova York S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/127519.mp4', 'http://timg.bdta.pro/images/a49ea70cfd3aa92fa823086a042dc253.jpg'),
(3202, 202, 'CSI: Nova York S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127520.mp4', 'http://timg.bdta.pro/images/e931b5acbdeaf791ac13078757273645.jpg'),
(3203, 202, 'CSI: Nova York S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127521.mp4', 'http://timg.bdta.pro/images/316dc8a5b56ca9862f73e6324e86f1c6.jpg'),
(3204, 202, 'CSI: Nova York S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127522.mp4', 'http://timg.bdta.pro/images/8995fdee1e708c70adcee461810e44c8.jpg'),
(3205, 202, 'CSI: Nova York S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127523.mp4', 'http://timg.bdta.pro/images/8eae3725546c59c9a6f2cf49098b6538.jpg'),
(3206, 202, 'CSI: Nova York S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127524.mp4', 'http://timg.bdta.pro/images/f5445ac7c3923e12e5979f3fa2301608.jpg'),
(3207, 202, 'CSI: Nova York S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127525.mp4', 'http://timg.bdta.pro/images/c26288132c8df93df9a98b0de42bec54.jpg'),
(3208, 202, 'CSI: Nova York S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127526.mp4', 'http://timg.bdta.pro/images/335b24eb437c9f19d2e126070bd3fca0.jpg'),
(3209, 202, 'CSI: Nova York S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127527.mp4', 'http://timg.bdta.pro/images/eb59ec451eb428f3e608bd909d3d9067.jpg'),
(3210, 202, 'CSI: Nova York S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127528.mp4', 'http://timg.bdta.pro/images/9d4ba927005ae6068bbaa929b79a6805.jpg'),
(3211, 202, 'CSI: Nova York S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127529.mp4', 'http://timg.bdta.pro/images/25ab1f040333af3fbe143d27e9a22164.jpg'),
(3212, 202, 'CSI: Nova York S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127530.mp4', 'http://timg.bdta.pro/images/f6cd2f46312268f2563f27563efddc19.jpg'),
(3213, 202, 'CSI: Nova York S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127531.mp4', 'http://timg.bdta.pro/images/d22cc7a3bd19d27cf151b9d44935403b.jpg'),
(3214, 202, 'CSI: Nova York S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127532.mp4', 'http://timg.bdta.pro/images/b906babf238ea110d6907e142b2128a3.jpg'),
(3215, 202, 'CSI: Nova York S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127533.mp4', 'http://timg.bdta.pro/images/5e48f96c63394d9c9a1a8092606f5c06.jpg'),
(3216, 202, 'CSI: Nova York S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127534.mp4', 'http://timg.bdta.pro/images/8b327c48c08c0d962f784a0f6c851f86.jpg'),
(3217, 202, 'CSI: Nova York S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127535.mp4', 'http://timg.bdta.pro/images/15d472f0a0bc4119a908937bd9d0a038.jpg'),
(3218, 202, 'CSI: Nova York S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127536.mp4', 'http://timg.bdta.pro/images/e167f619c83ecf2a850111832b6a0014.jpg'),
(3219, 202, 'CSI: Nova York S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127537.mp4', 'http://timg.bdta.pro/images/c1da74bf0a9f6fc77d6c074a7d39b5db.jpg'),
(3220, 202, 'CSI: Nova York S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127538.mp4', 'http://timg.bdta.pro/images/ddb5ac63f9099e834b5d169e52cb1d0f.jpg'),
(3221, 202, 'CSI: Nova York S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127539.mp4', 'http://timg.bdta.pro/images/ab34e18d7ecaecb4fe71250244d61d91.jpg'),
(3222, 202, 'CSI: Nova York S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127540.mp4', 'http://timg.bdta.pro/images/adcb3c9ffa99c6177f2a02600d66ad50.jpg'),
(3223, 202, 'CSI: Nova York S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/127541.mp4', 'http://timg.bdta.pro/images/15e1eb763c012df1f7953a0271087b99.jpg'),
(3224, 202, 'CSI: Nova York S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/127542.mp4', 'http://timg.bdta.pro/images/3c75b56a345b8217672005c0ac91cfb0.jpg'),
(3225, 202, 'CSI: Nova York S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/127543.mp4', 'http://timg.bdta.pro/images/789162f5c8c3b627f8c970e9413b8d52.jpg'),
(3226, 203, 'CSI: Nova York S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127544.mp4', 'http://timg.bdta.pro/images/f6565e2dcb6bc2a131766e8538aeaa1c.jpg'),
(3227, 203, 'CSI: Nova York S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127545.mp4', 'http://timg.bdta.pro/images/05ab7a1223885c7a977fe924acdc66bb.jpg'),
(3228, 203, 'CSI: Nova York S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127546.mp4', 'http://timg.bdta.pro/images/28074b5d0f1a44d24fef74b0db0a3401.jpg'),
(3229, 203, 'CSI: Nova York S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127547.mp4', 'http://timg.bdta.pro/images/9a5cc9be782121afb4e8a4a7938c17ef.jpg'),
(3230, 203, 'CSI: Nova York S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127548.mp4', 'http://timg.bdta.pro/images/6f801aa0f25c9b0ed79fd4af14347711.jpg'),
(3231, 203, 'CSI: Nova York S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127549.mp4', 'http://timg.bdta.pro/images/69cef768f6d92f58420664fae229f001.jpg'),
(3232, 203, 'CSI: Nova York S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127550.mp4', 'http://timg.bdta.pro/images/9d077d8cb9c2a5ba1fb3c518b2fb2cb8.jpg'),
(3233, 203, 'CSI: Nova York S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127551.mp4', 'http://timg.bdta.pro/images/a2572b012e2454e8747f1be7c5a6c88c.jpg'),
(3234, 203, 'CSI: Nova York S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127552.mp4', 'http://timg.bdta.pro/images/a5b6b65f475815d349fc001ec7cbd37b.jpg'),
(3235, 203, 'CSI: Nova York S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127553.mp4', 'http://timg.bdta.pro/images/31c5007eb6e4c5b0f7773639ee937ed6.jpg'),
(3236, 203, 'CSI: Nova York S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127554.mp4', 'http://timg.bdta.pro/images/6a19ff34522275c3335b6f54e0d7f541.jpg'),
(3237, 203, 'CSI: Nova York S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127555.mp4', 'http://timg.bdta.pro/images/c7a15e4ea180fb7bab18bd1f8d57d719.jpg'),
(3238, 203, 'CSI: Nova York S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127556.mp4', 'http://timg.bdta.pro/images/b25f39afd63a7f8b9565630297813269.jpg'),
(3239, 203, 'CSI: Nova York S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127557.mp4', 'http://timg.bdta.pro/images/ef90da50c9547dedf5ea73e0b1b34377.jpg'),
(3240, 203, 'CSI: Nova York S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127558.mp4', 'http://timg.bdta.pro/images/ec66c013975bdf6bcd62dc1c77cd4eab.jpg'),
(3241, 203, 'CSI: Nova York S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127559.mp4', 'http://timg.bdta.pro/images/8068f6590da8950ff8e765bb00ddf7f3.jpg'),
(3242, 203, 'CSI: Nova York S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127560.mp4', 'http://timg.bdta.pro/images/1f840ad618c2efae35edc8a055429af2.jpg'),
(3243, 203, 'CSI: Nova York S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127561.mp4', 'http://timg.bdta.pro/images/3a80b7ad75ff097e8d007e148795dd6a.jpg'),
(3244, 203, 'CSI: Nova York S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127562.mp4', 'http://timg.bdta.pro/images/bf38324a9336fddbcdd6d59ca6539427.jpg'),
(3245, 203, 'CSI: Nova York S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127563.mp4', 'http://timg.bdta.pro/images/1992209a0b22566823f17dc7c80c0501.jpg'),
(3246, 203, 'CSI: Nova York S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127564.mp4', 'http://timg.bdta.pro/images/72eafa24b47e1981f19bd13488c37a9e.jpg'),
(3247, 204, 'CSI: Nova York S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127565.mp4', 'http://timg.bdta.pro/images/807341268fc0be6b30caec0ec4e1a3a1.jpg'),
(3248, 204, 'CSI: Nova York S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127566.mp4', 'http://timg.bdta.pro/images/98f09a1964b8e6f033708be4ebd0b839.jpg'),
(3249, 204, 'CSI: Nova York S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127567.mp4', 'http://timg.bdta.pro/images/b13c8b92bf1ed549ae80a0e6ee2462a0.jpg'),
(3250, 204, 'CSI: Nova York S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127568.mp4', 'http://timg.bdta.pro/images/1b07b9d30faa8dfa08939f90fc06fd9b.jpg'),
(3251, 204, 'CSI: Nova York S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127569.mp4', 'http://timg.bdta.pro/images/1e053b7f15c79323f3e2ceb1281905f3.jpg'),
(3252, 204, 'CSI: Nova York S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127570.mp4', 'http://timg.bdta.pro/images/23d776b823ad4b1d0bbe5afd578618fa.jpg'),
(3253, 204, 'CSI: Nova York S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127571.mp4', 'http://timg.bdta.pro/images/6b4d864f198721acdfa28394862d9d53.jpg'),
(3254, 204, 'CSI: Nova York S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127572.mp4', 'http://timg.bdta.pro/images/1bc3234e6907a9689dd6619dc0de2f98.jpg'),
(3255, 204, 'CSI: Nova York S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127573.mp4', 'http://timg.bdta.pro/images/b064e99a352abc07715b3e9125507a94.jpg'),
(3256, 204, 'CSI: Nova York S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127574.mp4', 'http://timg.bdta.pro/images/877ca5fc410ae26f14b90deb61a5c4e8.jpg'),
(3257, 204, 'CSI: Nova York S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127575.mp4', 'http://timg.bdta.pro/images/6137fac4325cc8e60d111118d394d596.jpg'),
(3258, 204, 'CSI: Nova York S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127576.mp4', 'http://timg.bdta.pro/images/f8054074d1877dccac81c72ecd0750ab.jpg'),
(3259, 204, 'CSI: Nova York S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127577.mp4', 'http://timg.bdta.pro/images/2cfd894c948f7feb3435fb4491cec7ec.jpg'),
(3260, 204, 'CSI: Nova York S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127578.mp4', 'http://timg.bdta.pro/images/7f273af97e43bc6c004a70c591a63af5.jpg'),
(3261, 204, 'CSI: Nova York S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127579.mp4', 'http://timg.bdta.pro/images/395852c752613d53871259c6364dcdee.jpg'),
(3262, 204, 'CSI: Nova York S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127580.mp4', 'http://timg.bdta.pro/images/b394b61294fdee2cad9966f409fee290.jpg'),
(3263, 204, 'CSI: Nova York S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127581.mp4', 'http://timg.bdta.pro/images/c713c92527d70c8eb40b632de1b7a81f.jpg'),
(3264, 204, 'CSI: Nova York S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127582.mp4', 'http://timg.bdta.pro/images/bf66301e798fe8a0dddc4f950c93a80e.jpg'),
(3265, 204, 'CSI: Nova York S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127583.mp4', 'http://timg.bdta.pro/images/baf53017023efe4971ed8efda98106d1.jpg'),
(3266, 204, 'CSI: Nova York S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127584.mp4', 'http://timg.bdta.pro/images/c46ef601ede28f05cbb5d5ef6a708a52.jpg'),
(3267, 204, 'CSI: Nova York S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127585.mp4', 'http://timg.bdta.pro/images/8a4797b21433f1d3d9f09e2c3e06a7ed.jpg'),
(3268, 204, 'CSI: Nova York S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/127586.mp4', 'http://timg.bdta.pro/images/063f868a3d217b59b0687eb84d45f6bc.jpg'),
(3269, 204, 'CSI: Nova York S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/127587.mp4', 'http://timg.bdta.pro/images/300c111d5b3a28754b93f7787808694e.jpg'),
(3270, 204, 'CSI: Nova York S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/127588.mp4', 'http://timg.bdta.pro/images/29d0d217db1e1e9d6af8b87f0740ee37.jpg'),
(3271, 204, 'CSI: Nova York S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/127589.mp4', 'http://timg.bdta.pro/images/b62e3f0941fff759cceea37848790db0.jpg'),
(3272, 205, 'CSI: Nova York S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127590.mp4', 'http://timg.bdta.pro/images/c48085bb31062575fa462dbe5bef4881.jpg'),
(3273, 205, 'CSI: Nova York S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127591.mp4', 'http://timg.bdta.pro/images/fecd6d7eca53b8f24e1037a91e161eed.jpg'),
(3274, 205, 'CSI: Nova York S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127592.mp4', 'http://timg.bdta.pro/images/66f1d41a67e39748ecdf375c8b037e98.jpg'),
(3275, 205, 'CSI: Nova York S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127593.mp4', 'http://timg.bdta.pro/images/bed858d8e4bc8cb7812593444c69c7d8.jpg'),
(3276, 205, 'CSI: Nova York S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127594.mp4', 'http://timg.bdta.pro/images/cec5ac80e9a401092f4853af8b6f30ff.jpg'),
(3277, 205, 'CSI: Nova York S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127595.mp4', 'http://timg.bdta.pro/images/efa31fe68e951e0e9dcc91c074e1061e.jpg'),
(3278, 205, 'CSI: Nova York S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127596.mp4', 'http://timg.bdta.pro/images/f747c42adf05d310ba87014e795d75c9.jpg'),
(3279, 205, 'CSI: Nova York S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127597.mp4', 'http://timg.bdta.pro/images/451e3e190017e751e3ec0c1b48ce2204.jpg'),
(3280, 205, 'CSI: Nova York S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127598.mp4', 'http://timg.bdta.pro/images/54d17bddf8742e46bf88f28f0960088d.jpg'),
(3281, 205, 'CSI: Nova York S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127599.mp4', 'http://timg.bdta.pro/images/e4459f026974d42f54a4dfc1dbc12ba8.jpg'),
(3282, 206, 'CSI: Nova York S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127600.mp4', 'http://timg.bdta.pro/images/2bc519bc1275f9ae78489fffa8c3ed2e.jpg'),
(3283, 206, 'CSI: Nova York S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127601.mp4', 'http://timg.bdta.pro/images/db203c5e7091583efd2473b29c5df68d.jpg'),
(3284, 206, 'CSI: Nova York S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127602.mp4', 'http://timg.bdta.pro/images/407e332b0a6a0dbffe86ce13544fd5a4.jpg'),
(3285, 206, 'CSI: Nova York S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127603.mp4', 'http://timg.bdta.pro/images/5082c7cf5c85dd4aeeb9137cd00c4c3e.jpg'),
(3286, 206, 'CSI: Nova York S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127604.mp4', 'http://timg.bdta.pro/images/bde2e4184ded438a3b250b90cde25ecf.jpg'),
(3287, 206, 'CSI: Nova York S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127605.mp4', 'http://timg.bdta.pro/images/003ba859f8bdf6c97a14f8dbc6e29dfa.jpg'),
(3288, 206, 'CSI: Nova York S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127606.mp4', 'http://timg.bdta.pro/images/69ef11eba3b73270faede3d06a7ae8c5.jpg'),
(3289, 206, 'CSI: Nova York S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127607.mp4', 'http://timg.bdta.pro/images/b7dddd1ed404b0240ffdfb6ab6ac7432.jpg'),
(3290, 206, 'CSI: Nova York S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127608.mp4', 'http://timg.bdta.pro/images/1c8d386a80795205fb66900a8c3d9789.jpg'),
(3291, 206, 'CSI: Nova York S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127609.mp4', 'http://timg.bdta.pro/images/e9a07ef5dda64118414d0dbf5a0c6375.jpg'),
(3292, 206, 'CSI: Nova York S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127610.mp4', 'http://timg.bdta.pro/images/1daf12676fcafd31bb55ca8a4193f429.jpg'),
(3293, 206, 'CSI: Nova York S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127611.mp4', 'http://timg.bdta.pro/images/1f1b3184df5a22a4d407a8bd6fb260c3.jpg'),
(3294, 206, 'CSI: Nova York S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127612.mp4', 'http://timg.bdta.pro/images/5d15ea355328bbb9b1e98e18fc0eab05.jpg'),
(3295, 206, 'CSI: Nova York S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127613.mp4', 'http://timg.bdta.pro/images/29d97eaad20a304c07691eae9f1d78bd.jpg'),
(3296, 206, 'CSI: Nova York S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127614.mp4', 'http://timg.bdta.pro/images/15b95aa36b3ad456058fd431a8d646f1.jpg'),
(3297, 206, 'CSI: Nova York S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127615.mp4', 'http://timg.bdta.pro/images/8fb63b5441b29ec9556bef81c1bf03fd.jpg'),
(3298, 206, 'CSI: Nova York S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127616.mp4', 'http://timg.bdta.pro/images/b5b473477a925bfb6fe4f8a665027a2e.jpg'),
(3299, 206, 'CSI: Nova York S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127617.mp4', 'http://timg.bdta.pro/images/20c5b285ca5beeb47943a82a6c2ec8b8.jpg'),
(3300, 206, 'CSI: Nova York S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127618.mp4', 'http://timg.bdta.pro/images/b25cea7b67ba8092460416cb7a250b2c.jpg'),
(3301, 206, 'CSI: Nova York S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127619.mp4', 'http://timg.bdta.pro/images/f718619870c81e3ca45a297ce7ee5a65.jpg'),
(3302, 206, 'CSI: Nova York S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127620.mp4', 'http://timg.bdta.pro/images/679d8be35ecec3def985cb9db45b0159.jpg'),
(3303, 206, 'CSI: Nova York S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/127621.mp4', 'http://timg.bdta.pro/images/9bc01f385799b108f7d1582769e63599.jpg'),
(3304, 207, 'CSI: Nova York S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127622.mp4', 'http://timg.bdta.pro/images/b0d4cb9b9726207e46b43737a7e9426f.jpg'),
(3305, 207, 'CSI: Nova York S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127623.mp4', 'http://timg.bdta.pro/images/19ff0e737d5706d92a7be686d1afb536.jpg'),
(3306, 207, 'CSI: Nova York S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127624.mp4', 'http://timg.bdta.pro/images/b3b024e1dacad4a66ca601e5ad705fda.jpg'),
(3307, 207, 'CSI: Nova York S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127625.mp4', 'http://timg.bdta.pro/images/5e78662cd9a6768cd02045c217d78b15.jpg'),
(3308, 207, 'CSI: Nova York S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127626.mp4', 'http://timg.bdta.pro/images/7b10912a6a28d264701c3a5f626e6ca9.jpg'),
(3309, 207, 'CSI: Nova York S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127627.mp4', 'http://timg.bdta.pro/images/0a73f5288a5fa3ea38538f83cd8c39a0.jpg'),
(3310, 207, 'CSI: Nova York S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127628.mp4', 'http://timg.bdta.pro/images/25d7a1e2f3c5cc2a44951546cc4cde42.jpg'),
(3311, 207, 'CSI: Nova York S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127629.mp4', 'http://timg.bdta.pro/images/f3eee20dc57b18516c64041ff408046b.jpg'),
(3312, 207, 'CSI: Nova York S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127630.mp4', 'http://timg.bdta.pro/images/a3bea1ffec24e4a4dd9c04f3821636b7.jpg'),
(3313, 207, 'CSI: Nova York S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127631.mp4', 'http://timg.bdta.pro/images/39e6ba0e67379004ea0277e73102e0ef.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(3314, 207, 'CSI: Nova York S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127632.mp4', 'http://timg.bdta.pro/images/20995998ffcbf5cbca577eae3fa02504.jpg'),
(3315, 207, 'CSI: Nova York S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127633.mp4', 'http://timg.bdta.pro/images/0eb06b526b86e49d7781d3e00648a47d.jpg'),
(3316, 207, 'CSI: Nova York S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127634.mp4', 'http://timg.bdta.pro/images/6c5b2b38ff3cc30fc6c2d7e28bcb5e2b.jpg'),
(3317, 207, 'CSI: Nova York S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127635.mp4', 'http://timg.bdta.pro/images/e05faaeec724a71c1196e54abe0d659b.jpg'),
(3318, 207, 'CSI: Nova York S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127636.mp4', 'http://timg.bdta.pro/images/6829bbca2c7dfbd65b119d0ed946ff6f.jpg'),
(3319, 207, 'CSI: Nova York S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127637.mp4', 'http://timg.bdta.pro/images/1d3d6dabd280e2386702b2582991f8eb.jpg'),
(3320, 207, 'CSI: Nova York S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127638.mp4', 'http://timg.bdta.pro/images/77a4068fa6406a61a9b7eeae1e92a174.jpg'),
(3321, 207, 'CSI: Nova York S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127639.mp4', 'http://timg.bdta.pro/images/accdebf60260bb198c7eaafe89b1de90.jpg'),
(3322, 208, 'CSI: Nova York S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127640.mp4', 'http://timg.bdta.pro/images/dea03803c95aa72cc843dd4dd2d55786.jpg'),
(3323, 208, 'CSI: Nova York S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127641.mp4', 'http://timg.bdta.pro/images/c5d853810f6b930de612683ecc375775.jpg'),
(3324, 208, 'CSI: Nova York S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127642.mp4', 'http://timg.bdta.pro/images/d3c7a026004f98a9ab94f1d82760233b.jpg'),
(3325, 208, 'CSI: Nova York S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127643.mp4', 'http://timg.bdta.pro/images/97eee7f3a4e315d27f07b0121eaa8f9e.jpg'),
(3326, 208, 'CSI: Nova York S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127644.mp4', 'http://timg.bdta.pro/images/8feffca5629fb14f33cf76c3ce5c40f1.jpg'),
(3327, 208, 'CSI: Nova York S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127645.mp4', 'http://timg.bdta.pro/images/48dfe097a68d27376d601a12192625ed.jpg'),
(3328, 208, 'CSI: Nova York S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127646.mp4', 'http://timg.bdta.pro/images/c31772cd4ce81baf617d80465997be0a.jpg'),
(3329, 208, 'CSI: Nova York S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127647.mp4', 'http://timg.bdta.pro/images/86b50614639715c3318c5e5a714fea1f.jpg'),
(3330, 208, 'CSI: Nova York S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127648.mp4', 'http://timg.bdta.pro/images/b94f73c02ff8955a5d028517c454973f.jpg'),
(3331, 208, 'CSI: Nova York S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127649.mp4', 'http://timg.bdta.pro/images/5bb941d91e15872307efd07ba775287f.jpg'),
(3332, 208, 'CSI: Nova York S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127650.mp4', 'http://timg.bdta.pro/images/ea287cf3d256c7c18e01d980b6fc7644.jpg'),
(3333, 208, 'CSI: Nova York S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127651.mp4', 'http://timg.bdta.pro/images/f235a35ef1c9f11653b592482b397d5c.jpg'),
(3334, 208, 'CSI: Nova York S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127652.mp4', 'http://timg.bdta.pro/images/44759e8152cbd4ec18da953207bda940.jpg'),
(3335, 208, 'CSI: Nova York S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127653.mp4', 'http://timg.bdta.pro/images/b8fb8e9d28e540d18a44dacdd9e8c162.jpg'),
(3336, 208, 'CSI: Nova York S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127654.mp4', 'http://timg.bdta.pro/images/b9f794795495db0349c944fd2b380cd7.jpg'),
(3337, 208, 'CSI: Nova York S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127655.mp4', 'http://timg.bdta.pro/images/659485768f682a0f545c6e98fa0423d0.jpg'),
(3338, 208, 'CSI: Nova York S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127656.mp4', 'http://timg.bdta.pro/images/df53f90c080ec6ec9c74889ea6bc21d6.jpg'),
(3339, 209, 'Dark S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113070.mp4', 'http://gstaticontent.com/images/5LoHuHWA4H8jElFlZDvsmU2n63b_big.jpg'),
(3340, 209, 'Dark S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113071.mp4', 'http://gstaticontent.com/images/5LoHuHWA4H8jElFlZDvsmU2n63b_big.jpg'),
(3341, 209, 'Dark S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113072.mp4', 'http://gstaticontent.com/images/5LoHuHWA4H8jElFlZDvsmU2n63b_big.jpg'),
(3342, 209, 'Dark S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113073.mp4', 'http://gstaticontent.com/images/5LoHuHWA4H8jElFlZDvsmU2n63b_big.jpg'),
(3343, 209, 'Dark S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113074.mp4', 'http://gstaticontent.com/images/5LoHuHWA4H8jElFlZDvsmU2n63b_big.jpg'),
(3344, 209, 'Dark S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113075.mp4', 'http://gstaticontent.com/images/5LoHuHWA4H8jElFlZDvsmU2n63b_big.jpg'),
(3345, 209, 'Dark S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113076.mp4', 'http://gstaticontent.com/images/5LoHuHWA4H8jElFlZDvsmU2n63b_big.jpg'),
(3346, 209, 'Dark S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113077.mp4', 'http://gstaticontent.com/images/5LoHuHWA4H8jElFlZDvsmU2n63b_big.jpg'),
(3347, 209, 'Dark S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113078.mp4', 'http://gstaticontent.com/images/5LoHuHWA4H8jElFlZDvsmU2n63b_big.jpg'),
(3348, 209, 'Dark S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113079.mp4', 'http://gstaticontent.com/images/5LoHuHWA4H8jElFlZDvsmU2n63b_big.jpg'),
(3349, 210, 'Dark S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113080.mp4', 'http://gstaticontent.com/images/5LoHuHWA4H8jElFlZDvsmU2n63b_big.jpg'),
(3350, 210, 'Dark S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113081.mp4', 'http://gstaticontent.com/images/5LoHuHWA4H8jElFlZDvsmU2n63b_big.jpg'),
(3351, 210, 'Dark S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113082.mp4', 'http://gstaticontent.com/images/5LoHuHWA4H8jElFlZDvsmU2n63b_big.jpg'),
(3352, 210, 'Dark S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113083.mp4', 'http://gstaticontent.com/images/5LoHuHWA4H8jElFlZDvsmU2n63b_big.jpg'),
(3353, 210, 'Dark S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113084.mp4', 'http://gstaticontent.com/images/5LoHuHWA4H8jElFlZDvsmU2n63b_big.jpg'),
(3354, 210, 'Dark S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113085.mp4', 'http://gstaticontent.com/images/5LoHuHWA4H8jElFlZDvsmU2n63b_big.jpg'),
(3355, 210, 'Dark S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113086.mp4', 'http://gstaticontent.com/images/5LoHuHWA4H8jElFlZDvsmU2n63b_big.jpg'),
(3356, 210, 'Dark S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113087.mp4', 'http://gstaticontent.com/images/5LoHuHWA4H8jElFlZDvsmU2n63b_big.jpg'),
(3357, 211, 'Dark S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113088.mp4', 'http://timg.bdta.pro/images/1a776b241d7058f0fe4010a0e4e1c4b0.jpg'),
(3358, 211, 'Dark S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113089.mp4', 'http://timg.bdta.pro/images/7ebe909075c1ec5f08f5bb0f135f9e54.jpg'),
(3359, 211, 'Dark S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113090.mp4', 'http://timg.bdta.pro/images/8001cfc289e219635f45ea07e983c5b3.jpg'),
(3360, 211, 'Dark S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113091.mp4', 'http://timg.bdta.pro/images/ab530d2c13440875adaa14ef7cd9c296.jpg'),
(3361, 211, 'Dark S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113092.mp4', 'http://timg.bdta.pro/images/752fe00bc9a509f5e3050f4469c24639.jpg'),
(3362, 211, 'Dark S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113093.mp4', 'http://timg.bdta.pro/images/b3b248aaf1b19e46bbdccea99096b6e2.jpg'),
(3363, 211, 'Dark S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113094.mp4', 'http://timg.bdta.pro/images/9f4f39ebfef1be870ef25c3ab6b0e1ca.jpg'),
(3364, 211, 'Dark S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113095.mp4', 'http://timg.bdta.pro/images/c3bf5d166a95cd7c7ee36a39a86426e3.jpg'),
(3365, 212, 'Da Vinci\'s Demons S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3366, 212, 'Da Vinci\'s Demons S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3367, 212, 'Da Vinci\'s Demons S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3368, 212, 'Da Vinci\'s Demons S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3369, 212, 'Da Vinci\'s Demons S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3370, 212, 'Da Vinci\'s Demons S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3371, 212, 'Da Vinci\'s Demons S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3372, 212, 'Da Vinci\'s Demons S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3373, 213, 'Da Vinci\'s Demons S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3374, 213, 'Da Vinci\'s Demons S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3375, 213, 'Da Vinci\'s Demons S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3376, 213, 'Da Vinci\'s Demons S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3377, 213, 'Da Vinci\'s Demons S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3378, 213, 'Da Vinci\'s Demons S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3379, 213, 'Da Vinci\'s Demons S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3380, 213, 'Da Vinci\'s Demons S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3381, 213, 'Da Vinci\'s Demons S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3382, 214, 'Da Vinci\'s Demons S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3383, 214, 'Da Vinci\'s Demons S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3384, 214, 'Da Vinci\'s Demons S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3385, 214, 'Da Vinci\'s Demons S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3386, 214, 'Da Vinci\'s Demons S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3387, 214, 'Da Vinci\'s Demons S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3388, 214, 'Da Vinci\'s Demons S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3389, 214, 'Da Vinci\'s Demons S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3390, 214, 'Da Vinci\'s Demons S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3391, 214, 'Da Vinci\'s Demons S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0sNY1lOYAc69VSf6UtOcbzvtT.jpg'),
(3392, 215, 'DC\'s Legends Of Tomorrow S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177836.mp4', 'http://timg.bdta.pro/images/a0fa82142eb2c58066162476d0e8e4d3.jpg'),
(3393, 215, 'DC\'s Legends Of Tomorrow S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177837.mp4', 'http://timg.bdta.pro/images/dea0da524f3ab1f72175eef4caad89bc.jpg'),
(3394, 215, 'DC\'s Legends Of Tomorrow S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177838.mp4', 'http://timg.bdta.pro/images/4b9a34efa6da076559683203c9bd97d3.jpg'),
(3395, 215, 'DC\'s Legends Of Tomorrow S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177839.mp4', 'http://timg.bdta.pro/images/0a94da21dbcbab3bf7b87b7814f81167.jpg'),
(3396, 215, 'DC\'s Legends Of Tomorrow S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177840.mp4', 'http://timg.bdta.pro/images/8296327cde6c84922c442176b20c78c0.jpg'),
(3397, 215, 'DC\'s Legends Of Tomorrow S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177841.mp4', 'http://timg.bdta.pro/images/80d21edc31b9bc6c5272c469d772f6d7.jpg'),
(3398, 215, 'DC\'s Legends Of Tomorrow S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177842.mp4', 'http://timg.bdta.pro/images/c25dd74d6020f1c932f8bcd67461cf7c.jpg'),
(3399, 215, 'DC\'s Legends Of Tomorrow S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177843.mp4', 'http://timg.bdta.pro/images/78f47be52fd30deed963b79387c1095a.jpg'),
(3400, 215, 'DC\'s Legends Of Tomorrow S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177844.mp4', 'http://timg.bdta.pro/images/ee06a7ab7dbe47e583d3a7c9a851bea3.jpg'),
(3401, 215, 'DC\'s Legends Of Tomorrow S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177845.mp4', 'http://timg.bdta.pro/images/a3aa4d4bf7fcbd887718ee888fb7d348.jpg'),
(3402, 215, 'DC\'s Legends Of Tomorrow S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177846.mp4', 'http://timg.bdta.pro/images/f10b1b4afffe3a95d1c92d23dbdad382.jpg'),
(3403, 215, 'DC\'s Legends Of Tomorrow S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177847.mp4', 'http://timg.bdta.pro/images/87720fefdd37152407c52952eb7bc807.jpg'),
(3404, 215, 'DC\'s Legends Of Tomorrow S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/177848.mp4', 'http://timg.bdta.pro/images/d931cc5838cdcfad9e49b0b22522912b.jpg'),
(3405, 215, 'DC\'s Legends Of Tomorrow S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/177849.mp4', 'http://timg.bdta.pro/images/88ab888e6bb165d673169104edfab25f.jpg'),
(3406, 215, 'DC\'s Legends Of Tomorrow S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/177850.mp4', 'http://timg.bdta.pro/images/61524a61f41b048ac9c0c4856d19e6f0.jpg'),
(3407, 215, 'DC\'s Legends Of Tomorrow S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/177851.mp4', 'http://timg.bdta.pro/images/19658ed4e9e4c648de6ec1fca6b357df.jpg'),
(3408, 216, 'DC\'s Legends Of Tomorrow S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177852.mp4', 'http://timg.bdta.pro/images/6b6a605d54f25bc6c03961fe3bda218d.jpg'),
(3409, 216, 'DC\'s Legends Of Tomorrow S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177853.mp4', 'http://timg.bdta.pro/images/4d9128b53bec2686f97b4554f2520add.jpg'),
(3410, 216, 'DC\'s Legends Of Tomorrow S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177854.mp4', 'http://timg.bdta.pro/images/6796b82499168614cd29b92d923d9a63.jpg'),
(3411, 216, 'DC\'s Legends Of Tomorrow S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177855.mp4', 'http://timg.bdta.pro/images/e15814df0792531d9ca7687ece98cd48.jpg'),
(3412, 216, 'DC\'s Legends Of Tomorrow S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177856.mp4', 'http://timg.bdta.pro/images/62c6b568411f926227ee880cb1c1001d.jpg'),
(3413, 216, 'DC\'s Legends Of Tomorrow S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177857.mp4', 'http://timg.bdta.pro/images/67071e764e550571a380fe3ace944712.jpg'),
(3414, 216, 'DC\'s Legends Of Tomorrow S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177858.mp4', 'http://timg.bdta.pro/images/6f44d6ef27a3045fc938ac8fc2015fb2.jpg'),
(3415, 216, 'DC\'s Legends Of Tomorrow S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177859.mp4', 'http://timg.bdta.pro/images/5d3f6b6d90a4df938fbaf33459f06abb.jpg'),
(3416, 216, 'DC\'s Legends Of Tomorrow S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177860.mp4', 'http://timg.bdta.pro/images/92d2db3b1806528096ac3eed1bc6b841.jpg'),
(3417, 216, 'DC\'s Legends Of Tomorrow S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177861.mp4', 'http://timg.bdta.pro/images/e5bc38e372054c1b5b76b90b2d8c8586.jpg'),
(3418, 216, 'DC\'s Legends Of Tomorrow S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177862.mp4', 'http://timg.bdta.pro/images/b95ed6eb7126ce607fe17d5616c0b25b.jpg'),
(3419, 216, 'DC\'s Legends Of Tomorrow S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177863.mp4', 'http://timg.bdta.pro/images/6beb61bf981d4a4ac6b4a1897fefb794.jpg'),
(3420, 216, 'DC\'s Legends Of Tomorrow S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/177864.mp4', 'http://timg.bdta.pro/images/b8bfb951aae45e4a2d24a551f4c207ac.jpg'),
(3421, 216, 'DC\'s Legends Of Tomorrow S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/177865.mp4', 'http://timg.bdta.pro/images/b9437e67e2278b9d75e7d50166127cef.jpg'),
(3422, 216, 'DC\'s Legends Of Tomorrow S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/177866.mp4', 'http://timg.bdta.pro/images/15d427efd0df2be6e644f1384cb9af17.jpg'),
(3423, 216, 'DC\'s Legends Of Tomorrow S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/177867.mp4', 'http://timg.bdta.pro/images/7409349a94d6bf27e68ebc11400387a4.jpg'),
(3424, 216, 'DC\'s Legends Of Tomorrow S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/177868.mp4', 'http://timg.bdta.pro/images/63cb9629860e0b462ea82807c33ad263.jpg'),
(3425, 217, 'DC\'s Legends Of Tomorrow S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177869.mp4', 'http://timg.bdta.pro/images/9bd9b5553e22780aa8210af8d1e56264.jpg'),
(3426, 217, 'DC\'s Legends Of Tomorrow S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177870.mp4', 'http://timg.bdta.pro/images/30e417aa2445547a8ec05e67e79dde30.jpg'),
(3427, 217, 'DC\'s Legends Of Tomorrow S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177871.mp4', 'http://timg.bdta.pro/images/d816df7e33a0d0315abd960d0994273d.jpg'),
(3428, 217, 'DC\'s Legends Of Tomorrow S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177872.mp4', 'http://timg.bdta.pro/images/7fcab634ab37d71235214c4ba7874657.jpg'),
(3429, 217, 'DC\'s Legends Of Tomorrow S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177873.mp4', 'http://timg.bdta.pro/images/e2f08fbea9132ce9bc89bb0f0e7765df.jpg'),
(3430, 217, 'DC\'s Legends Of Tomorrow S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177874.mp4', 'http://timg.bdta.pro/images/091eaccca61d361efdc6b2ae60d7f9c5.jpg'),
(3431, 217, 'DC\'s Legends Of Tomorrow S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177875.mp4', 'http://timg.bdta.pro/images/38b84d47ee8e09811d18876418b977c9.jpg'),
(3432, 217, 'DC\'s Legends Of Tomorrow S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177876.mp4', 'http://timg.bdta.pro/images/ea2517e5a4e88bd9f160e22e19268292.jpg'),
(3433, 217, 'DC\'s Legends Of Tomorrow S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177877.mp4', 'http://timg.bdta.pro/images/96d790968a728fcf7390cc438155701e.jpg'),
(3434, 217, 'DC\'s Legends Of Tomorrow S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177878.mp4', 'http://timg.bdta.pro/images/92e4a71388bce1d9b8290f51c7d0cdd8.jpg'),
(3435, 217, 'DC\'s Legends Of Tomorrow S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177879.mp4', 'http://timg.bdta.pro/images/af425ae66efb1e2d51d4c680f6245947.jpg'),
(3436, 217, 'DC\'s Legends Of Tomorrow S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177880.mp4', 'http://timg.bdta.pro/images/c2808c325413706bb3e08eed892fb4e5.jpg'),
(3437, 217, 'DC\'s Legends Of Tomorrow S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/177881.mp4', 'http://timg.bdta.pro/images/cb4b16cc252747054c3c40b180c20e83.jpg'),
(3438, 217, 'DC\'s Legends Of Tomorrow S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/177882.mp4', 'http://timg.bdta.pro/images/78ed82e7516ab363c1e783e1dca8deae.jpg'),
(3439, 217, 'DC\'s Legends Of Tomorrow S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/177883.mp4', 'http://timg.bdta.pro/images/38f435bde6bb5b8009b1d18f7189454f.jpg'),
(3440, 217, 'DC\'s Legends Of Tomorrow S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/177884.mp4', 'http://timg.bdta.pro/images/7ddc5e5a9fc004c7e2473af46e2edf65.jpg'),
(3441, 217, 'DC\'s Legends Of Tomorrow S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/177885.mp4', 'http://timg.bdta.pro/images/db0c93a55318e838c399ce6542d4b7a7.jpg'),
(3442, 217, 'DC\'s Legends Of Tomorrow S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/177886.mp4', 'http://timg.bdta.pro/images/c271462c03773a0d839c3a75c22db36e.jpg'),
(3443, 218, 'DC\'s Legends Of Tomorrow S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177887.mp4', 'http://timg.bdta.pro/images/e81e013e1aeb132ade3cf81da6c60888.jpg'),
(3444, 218, 'DC\'s Legends Of Tomorrow S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177888.mp4', 'http://timg.bdta.pro/images/53481eaf02832b3c0218d1eb00b1f2c2.jpg'),
(3445, 218, 'DC\'s Legends Of Tomorrow S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177889.mp4', 'http://timg.bdta.pro/images/8dba7d62c41889fc420f5948f64af548.jpg'),
(3446, 218, 'DC\'s Legends Of Tomorrow S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177890.mp4', 'http://timg.bdta.pro/images/0bb8c7308571cda9b16d7726498475f1.jpg'),
(3447, 218, 'DC\'s Legends Of Tomorrow S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177891.mp4', 'http://timg.bdta.pro/images/68c6dd803020caadf0bd518f72191818.jpg'),
(3448, 218, 'DC\'s Legends Of Tomorrow S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177892.mp4', 'http://timg.bdta.pro/images/c128298ecfb21bfdd04c41e068658f86.jpg'),
(3449, 218, 'DC\'s Legends Of Tomorrow S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177893.mp4', 'http://timg.bdta.pro/images/52175b0b4215c719ab9cd829ccb814af.jpg'),
(3450, 218, 'DC\'s Legends Of Tomorrow S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177894.mp4', 'http://timg.bdta.pro/images/3fc20ff1dd045af43d1b514f59f27809.jpg'),
(3451, 218, 'DC\'s Legends Of Tomorrow S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177895.mp4', 'http://timg.bdta.pro/images/f42147da321b46729141dc2932a03358.jpg'),
(3452, 218, 'DC\'s Legends Of Tomorrow S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177896.mp4', 'http://timg.bdta.pro/images/22645ef2497fffda68c9f086f8f6f6db.jpg'),
(3453, 218, 'DC\'s Legends Of Tomorrow S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177897.mp4', 'http://timg.bdta.pro/images/e404d0d628d7efba43889e290cf6a2fd.jpg'),
(3454, 218, 'DC\'s Legends Of Tomorrow S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177898.mp4', 'http://timg.bdta.pro/images/e64f98dd9eb78cb91516fcbe9fa16c47.jpg'),
(3455, 218, 'DC\'s Legends Of Tomorrow S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/177899.mp4', 'http://timg.bdta.pro/images/5211d3ed4c5e19d1dc3c5fc8e535ce0f.jpg'),
(3456, 218, 'DC\'s Legends Of Tomorrow S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/177900.mp4', 'http://timg.bdta.pro/images/e365dcd3af183a1878b17e368188eb5c.jpg'),
(3457, 218, 'DC\'s Legends Of Tomorrow S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/177901.mp4', 'http://timg.bdta.pro/images/2a6d71343ca750c0f24aba748a65951f.jpg'),
(3458, 218, 'DC\'s Legends Of Tomorrow S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/177902.mp4', 'http://timg.bdta.pro/images/33aaabe6da87ef87d4c9f2ba2952bb35.jpg'),
(3459, 219, 'DC\'s Legends Of Tomorrow S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177903.mp4', 'http://timg.bdta.pro/images/261d3ff382992c0d96c3ca9c61fb4e67.jpg'),
(3460, 219, 'DC\'s Legends Of Tomorrow S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177904.mp4', 'http://timg.bdta.pro/images/cf2748b40904d65711d8b435279ceae4.jpg'),
(3461, 219, 'DC\'s Legends Of Tomorrow S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177905.mp4', 'http://timg.bdta.pro/images/ab5323778ca500368edc508d7b7a6502.jpg'),
(3462, 219, 'DC\'s Legends Of Tomorrow S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177906.mp4', 'http://timg.bdta.pro/images/d21cc0451b85d0a5bd6beeb5ebbfead2.jpg'),
(3463, 219, 'DC\'s Legends Of Tomorrow S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177907.mp4', 'http://timg.bdta.pro/images/f9faec1e1c90106728d3f4f81684428e.jpg'),
(3464, 219, 'DC\'s Legends Of Tomorrow S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177908.mp4', 'http://timg.bdta.pro/images/eee5d178fe85525025ffbdfd5efe632e.jpg'),
(3465, 219, 'DC\'s Legends Of Tomorrow S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177909.mp4', 'http://timg.bdta.pro/images/80a9a89c81d09ed5700e1d592106778a.jpg'),
(3466, 219, 'DC\'s Legends Of Tomorrow S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177910.mp4', 'http://timg.bdta.pro/images/8d717c8a352b524cac84b5c191af8cf4.jpg'),
(3467, 219, 'DC\'s Legends Of Tomorrow S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177911.mp4', 'http://timg.bdta.pro/images/31de1e24ad4da5d42a3725ce960313fc.jpg'),
(3468, 219, 'DC\'s Legends Of Tomorrow S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177912.mp4', 'http://timg.bdta.pro/images/e8383c5060320bd21cb69728a4774e44.jpg'),
(3469, 219, 'DC\'s Legends Of Tomorrow S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177913.mp4', 'http://timg.bdta.pro/images/080ed09b212df517605d0cf78dc2b946.jpg'),
(3470, 219, 'DC\'s Legends Of Tomorrow S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177914.mp4', 'http://timg.bdta.pro/images/78eaf5e5c0ffa2621ed6e2ffc24f3ad9.jpg'),
(3471, 219, 'DC\'s Legends Of Tomorrow S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/177915.mp4', 'http://timg.bdta.pro/images/54afb27ba1a2ac5812e176b71efd89b7.jpg'),
(3472, 219, 'DC\'s Legends Of Tomorrow S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/177916.mp4', 'http://timg.bdta.pro/images/84db672c0fa25adfc1ca97179f02a812.jpg'),
(3473, 219, 'DC\'s Legends Of Tomorrow S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/177917.mp4', 'http://timg.bdta.pro/images/6bb26a069d4cdaef1d5aedeafac6de40.jpg'),
(3474, 220, 'DC\'s Legends Of Tomorrow S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177918.mp4', 'http://timg.bdta.pro/images/b9d0b6b5340ad9885555eb23a0f87aff.jpg'),
(3475, 220, 'DC\'s Legends Of Tomorrow S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177919.mp4', 'http://timg.bdta.pro/images/7a3fae0b7e5644cf2f8e019e5fd4deac.jpg'),
(3476, 220, 'DC\'s Legends Of Tomorrow S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177920.mp4', 'http://timg.bdta.pro/images/954a20694f94dbcada0c5284e1ee3577.jpg'),
(3477, 220, 'DC\'s Legends Of Tomorrow S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177921.mp4', 'http://timg.bdta.pro/images/7eb1a8ec24c591af6b84f24c255faf4d.jpg'),
(3478, 220, 'DC\'s Legends Of Tomorrow S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177922.mp4', 'http://timg.bdta.pro/images/27436fb57b0b67cc51d0ad5017e1dba6.jpg'),
(3479, 220, 'DC\'s Legends Of Tomorrow S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177923.mp4', 'http://timg.bdta.pro/images/b53e8a786d9943a7c4f46207c869aafa.jpg'),
(3480, 220, 'DC\'s Legends Of Tomorrow S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177924.mp4', 'http://timg.bdta.pro/images/e5c14bb3287e47ba7fe77fe1e94a9e2b.jpg'),
(3481, 220, 'DC\'s Legends Of Tomorrow S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177925.mp4', 'http://timg.bdta.pro/images/b2755337e8137160e41bbd12a5e50272.jpg'),
(3482, 220, 'DC\'s Legends Of Tomorrow S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177926.mp4', 'http://timg.bdta.pro/images/10d07458d17a2b1a68a599ab0011a457.jpg'),
(3483, 220, 'DC\'s Legends Of Tomorrow S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177927.mp4', 'http://timg.bdta.pro/images/57ff8203053cee566c7f95ab5051184a.jpg'),
(3484, 220, 'DC\'s Legends Of Tomorrow S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177928.mp4', 'http://timg.bdta.pro/images/e5db2fb279a8e0f72c4c9ea63b1d6f1f.jpg'),
(3485, 220, 'DC\'s Legends Of Tomorrow S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177929.mp4', 'http://timg.bdta.pro/images/a7dc75523a68da1d16773a7fadb7fdc1.jpg'),
(3486, 220, 'DC\'s Legends Of Tomorrow S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/177930.mp4', 'http://timg.bdta.pro/images/9ab105838e77a830e69ad0393003f5ac.jpg'),
(3487, 220, 'DC\'s Legends Of Tomorrow S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/177931.mp4', 'http://timg.bdta.pro/images/6df3f67db9caf4d6ac3f17027b92d157.jpg'),
(3488, 221, 'DC\'s Legends Of Tomorrow S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177932.mp4', 'http://image.tmdb.org/t/p/w1280/spLetUuQQCZlMfiimIgwnriRPan.jpg'),
(3489, 221, 'DC\'s Legends Of Tomorrow S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sKYRLoweFyJaXVR1t4EmQfebHRX.jpg'),
(3490, 221, 'DC\'s Legends Of Tomorrow S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tcZaYYJt0KYSa4SLnMhqWJ4QxM.jpg'),
(3491, 221, 'DC\'s Legends Of Tomorrow S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wla3WEgYV9zsr2emeceYqAuy2yV.jpg'),
(3492, 221, 'DC\'s Legends Of Tomorrow S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177936.mp4', 'http://gstaticontent.com/images/61JMWAmLqgbVQrKw86vwNnIGtzB_big.jpg'),
(3493, 221, 'DC\'s Legends Of Tomorrow S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177937.mp4', 'http://image.tmdb.org/t/p/w1280/bQpbzZdTm9PLdZ87ns9c2S1zRee.jpg'),
(3494, 221, 'DC\'s Legends Of Tomorrow S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177938.mp4', 'http://image.tmdb.org/t/p/w1280/a5cbgpFizTwSFsYidxHkDjhgPvN.jpg'),
(3495, 221, 'DC\'s Legends Of Tomorrow S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177939.mp4', 'http://timg.bdta.pro/images/d9dcde82cb07a797e6576d9c19442c94.jpg'),
(3496, 221, 'DC\'s Legends Of Tomorrow S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177940.mp4', 'http://timg.bdta.pro/images/b5f63d3422ce2202715beab4c3207c9a.jpg'),
(3497, 221, 'DC\'s Legends Of Tomorrow S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177941.mp4', 'http://timg.bdta.pro/images/25288273ef63aad5691965ffb45718d7.jpg'),
(3498, 221, 'DC\'s Legends Of Tomorrow S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177942.mp4', 'http://timg.bdta.pro/images/61079d93d23be846d4181351c76f9b1a.jpg'),
(3499, 221, 'DC\'s Legends Of Tomorrow S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177943.mp4', 'http://timg.bdta.pro/images/d91ab70204e99a539c72c918cc14f341.jpg'),
(3500, 221, 'DC\'s Legends Of Tomorrow S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/177944.mp4', 'http://timg.bdta.pro/images/ddc837bcb257af5375ed8b9ad6fd7962.jpg'),
(3501, 222, 'Deadwind S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126637.mp4', 'http://gstaticontent.com/images/lFvTHBf09t4hyT53SNhMWwKPimQ_big.jpg'),
(3502, 222, 'Deadwind S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126638.mp4', 'http://gstaticontent.com/images/lFvTHBf09t4hyT53SNhMWwKPimQ_big.jpg'),
(3503, 222, 'Deadwind S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126639.mp4', 'http://gstaticontent.com/images/lFvTHBf09t4hyT53SNhMWwKPimQ_big.jpg'),
(3504, 222, 'Deadwind S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126640.mp4', 'http://gstaticontent.com/images/lFvTHBf09t4hyT53SNhMWwKPimQ_big.jpg'),
(3505, 222, 'Deadwind S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126641.mp4', 'http://gstaticontent.com/images/lFvTHBf09t4hyT53SNhMWwKPimQ_big.jpg'),
(3506, 222, 'Deadwind S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126642.mp4', 'http://gstaticontent.com/images/lFvTHBf09t4hyT53SNhMWwKPimQ_big.jpg'),
(3507, 222, 'Deadwind S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126643.mp4', 'http://gstaticontent.com/images/lFvTHBf09t4hyT53SNhMWwKPimQ_big.jpg'),
(3508, 222, 'Deadwind S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126644.mp4', 'http://gstaticontent.com/images/lFvTHBf09t4hyT53SNhMWwKPimQ_big.jpg'),
(3509, 222, 'Deadwind S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126645.mp4', 'http://gstaticontent.com/images/lFvTHBf09t4hyT53SNhMWwKPimQ_big.jpg'),
(3510, 222, 'Deadwind S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126646.mp4', 'http://gstaticontent.com/images/lFvTHBf09t4hyT53SNhMWwKPimQ_big.jpg'),
(3511, 222, 'Deadwind S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/126647.mp4', 'http://gstaticontent.com/images/lFvTHBf09t4hyT53SNhMWwKPimQ_big.jpg'),
(3512, 222, 'Deadwind S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/126648.mp4', 'http://gstaticontent.com/images/lFvTHBf09t4hyT53SNhMWwKPimQ_big.jpg'),
(3513, 223, 'Deadwind S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126649.mp4', 'http://timg.bdta.pro/images/a32d24eef412d9a008acd1398ea98390.jpg'),
(3514, 223, 'Deadwind S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126650.mp4', 'http://timg.bdta.pro/images/ba52cbb8873e6df9e6f7a99f524afd0c.jpg'),
(3515, 223, 'Deadwind S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126651.mp4', 'http://timg.bdta.pro/images/b24f99f9492b55af0542e61bdc8db57c.jpg'),
(3516, 223, 'Deadwind S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126652.mp4', 'http://timg.bdta.pro/images/c8161c0ddd0cfa13d25550098b25203b.jpg'),
(3517, 223, 'Deadwind S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126653.mp4', 'http://timg.bdta.pro/images/1907b279fc340c392884105689fb1c0c.jpg'),
(3518, 223, 'Deadwind S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126654.mp4', 'http://timg.bdta.pro/images/19e981e4635e6f108dc60696f262d234.jpg'),
(3519, 223, 'Deadwind S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126655.mp4', 'http://timg.bdta.pro/images/05e79dd0a568982582e4ee77e92d479c.jpg'),
(3520, 223, 'Deadwind S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126656.mp4', 'http://timg.bdta.pro/images/775d63c5549b64341f35401101221f8a.jpg'),
(3521, 224, 'Deadwind S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/271845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mp5R1Onvnlbf0sVYonRjbMSgkvX.jpg'),
(3522, 224, 'Deadwind S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/271846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AcpOLVajECQSRoqqwIYa7Hib4P8.jpg'),
(3523, 224, 'Deadwind S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/271847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4B0hesq9ELw50h115iliVuCsw4d.jpg'),
(3524, 224, 'Deadwind S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/271848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97jL1QlQ7g8PuD9Ppj1V7EHW8mK.jpg'),
(3525, 224, 'Deadwind S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/271849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ljrnMLcbDbjXqV4BWc71X4JeJZO.jpg'),
(3526, 224, 'Deadwind S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/271850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1unnpj5szlkBND2KgfptK9Ios1p.jpg'),
(3527, 224, 'Deadwind S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/271851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dvcgmFUokEVIP5jDuJ0aQ3xFp1.jpg'),
(3528, 224, 'Deadwind S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/271852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dRh3IjbVFSQhmTu8iWKum4ckCFp.jpg'),
(3529, 225, 'Dexter S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100979.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3530, 225, 'Dexter S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100980.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3531, 225, 'Dexter S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100981.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3532, 225, 'Dexter S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100982.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3533, 225, 'Dexter S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100983.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3534, 225, 'Dexter S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100984.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3535, 225, 'Dexter S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100985.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3536, 225, 'Dexter S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100986.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3537, 225, 'Dexter S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100987.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3538, 225, 'Dexter S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100988.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3539, 225, 'Dexter S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100989.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3540, 225, 'Dexter S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100990.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3541, 226, 'Dexter S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100991.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3542, 226, 'Dexter S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100992.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3543, 226, 'Dexter S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100993.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3544, 226, 'Dexter S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100994.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3545, 226, 'Dexter S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100995.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3546, 226, 'Dexter S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100996.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3547, 226, 'Dexter S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100997.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3548, 226, 'Dexter S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100998.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3549, 226, 'Dexter S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100999.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3550, 226, 'Dexter S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101000.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3551, 226, 'Dexter S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101001.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3552, 226, 'Dexter S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101002.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3553, 227, 'Dexter S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101003.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3554, 227, 'Dexter S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101004.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3555, 227, 'Dexter S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101005.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3556, 227, 'Dexter S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101006.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3557, 227, 'Dexter S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101007.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3558, 227, 'Dexter S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101008.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3559, 227, 'Dexter S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101009.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3560, 227, 'Dexter S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101010.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3561, 227, 'Dexter S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101011.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3562, 227, 'Dexter S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101012.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3563, 227, 'Dexter S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101013.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3564, 227, 'Dexter S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101014.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3565, 228, 'Dexter S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101015.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3566, 228, 'Dexter S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101016.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3567, 228, 'Dexter S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101017.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3568, 228, 'Dexter S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101018.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3569, 228, 'Dexter S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101019.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3570, 228, 'Dexter S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101020.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3571, 228, 'Dexter S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101021.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3572, 228, 'Dexter S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101022.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3573, 228, 'Dexter S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101023.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3574, 228, 'Dexter S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101024.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3575, 228, 'Dexter S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101025.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3576, 228, 'Dexter S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101026.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3577, 229, 'Dexter S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101027.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3578, 229, 'Dexter S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101028.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3579, 229, 'Dexter S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101029.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3580, 229, 'Dexter S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101030.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3581, 229, 'Dexter S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101031.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3582, 229, 'Dexter S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101032.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3583, 229, 'Dexter S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101033.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3584, 229, 'Dexter S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101034.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3585, 229, 'Dexter S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101035.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3586, 229, 'Dexter S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101036.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3587, 229, 'Dexter S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101037.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3588, 229, 'Dexter S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101038.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3589, 230, 'Dexter S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101039.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3590, 230, 'Dexter S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101040.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3591, 230, 'Dexter S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101041.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3592, 230, 'Dexter S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101042.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3593, 230, 'Dexter S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101043.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3594, 230, 'Dexter S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101044.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3595, 230, 'Dexter S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101045.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3596, 230, 'Dexter S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101046.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3597, 230, 'Dexter S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101047.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3598, 230, 'Dexter S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101048.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3599, 230, 'Dexter S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101049.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(3600, 230, 'Dexter S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101050.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3601, 231, 'Dexter S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101051.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3602, 231, 'Dexter S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101052.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3603, 231, 'Dexter S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101053.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3604, 231, 'Dexter S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101054.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3605, 231, 'Dexter S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101055.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3606, 231, 'Dexter S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101056.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3607, 231, 'Dexter S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101057.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3608, 231, 'Dexter S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101058.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3609, 231, 'Dexter S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101059.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3610, 231, 'Dexter S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101060.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3611, 231, 'Dexter S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101061.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3612, 231, 'Dexter S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101062.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3613, 232, 'Dexter S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101063.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3614, 232, 'Dexter S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101064.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3615, 232, 'Dexter S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101065.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3616, 232, 'Dexter S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101066.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3617, 232, 'Dexter S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101067.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3618, 232, 'Dexter S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101068.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3619, 232, 'Dexter S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101069.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3620, 232, 'Dexter S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101070.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3621, 232, 'Dexter S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101071.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3622, 232, 'Dexter S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101072.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3623, 232, 'Dexter S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101073.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3624, 232, 'Dexter S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101074.mp4', 'http://gstaticontent.com/images/5DHlhR5WHDFGkM5agZqfrtR7oDX_big.jpg'),
(3625, 233, 'Dinastia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196758.mp4', 'http://timg.bdta.pro/images/f03bc4bf98b39a8c9397e19a53047a80.jpg'),
(3626, 233, 'Dinastia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196759.mp4', 'http://timg.bdta.pro/images/c85b429cd3464ee58f2af104a6defe3b.jpg'),
(3627, 233, 'Dinastia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196760.mp4', 'http://timg.bdta.pro/images/3e8fa125dcd55c532b8e059d67b4d2e5.jpg'),
(3628, 233, 'Dinastia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196761.mp4', 'http://timg.bdta.pro/images/ee339ee935045df87963dbcfcdae2085.jpg'),
(3629, 233, 'Dinastia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196762.mp4', 'http://timg.bdta.pro/images/e947fae6f2fcccb4ea5895163bf04e25.jpg'),
(3630, 233, 'Dinastia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196763.mp4', 'http://timg.bdta.pro/images/46c00d5ea9d114fb35c656583aed619c.jpg'),
(3631, 233, 'Dinastia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196764.mp4', 'http://timg.bdta.pro/images/9847afbb63de62a31cd5ea6d280b0e5d.jpg'),
(3632, 233, 'Dinastia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196765.mp4', 'http://timg.bdta.pro/images/7d3ca5ca74f6391727d4e731b692af1c.jpg'),
(3633, 233, 'Dinastia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196766.mp4', 'http://timg.bdta.pro/images/47710f76e9c79b35a4cf36c62890da8d.jpg'),
(3634, 233, 'Dinastia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196767.mp4', 'http://timg.bdta.pro/images/a6a8c32e432516936eb47845c7e26fe8.jpg'),
(3635, 233, 'Dinastia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196768.mp4', 'http://timg.bdta.pro/images/1c85e0e652a9ea344c03f8eb42c53e35.jpg'),
(3636, 233, 'Dinastia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196769.mp4', 'http://timg.bdta.pro/images/9283ae9f7c7aab30257624a7429a1cf1.jpg'),
(3637, 233, 'Dinastia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196770.mp4', 'http://timg.bdta.pro/images/8c0a49ad76ac35de2fd23cdd40b5fd54.jpg'),
(3638, 233, 'Dinastia S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/196771.mp4', 'http://timg.bdta.pro/images/a7fe5cebbb0ca84a4468169e7aae56d5.jpg'),
(3639, 233, 'Dinastia S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/196772.mp4', 'http://timg.bdta.pro/images/a3f5bfac97d07ee4d0d873d53c5d6a0e.jpg'),
(3640, 233, 'Dinastia S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/196773.mp4', 'http://timg.bdta.pro/images/9478b4121b6d1c07b48b60f4845b81ba.jpg'),
(3641, 233, 'Dinastia S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/196774.mp4', 'http://timg.bdta.pro/images/828dcaa71835f908974dd20c8e98185f.jpg'),
(3642, 233, 'Dinastia S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/196775.mp4', 'http://timg.bdta.pro/images/497353027cbf2334da72c05204f57d61.jpg'),
(3643, 233, 'Dinastia S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/196776.mp4', 'http://timg.bdta.pro/images/ce85436827b35ba36e0d9fa91a6f8df8.jpg'),
(3644, 233, 'Dinastia S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/196777.mp4', 'http://timg.bdta.pro/images/06985283175778cd40873f3f6d1a3e94.jpg'),
(3645, 233, 'Dinastia S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/196778.mp4', 'http://timg.bdta.pro/images/dada289c76bc7634538c9e96086df14b.jpg'),
(3646, 233, 'Dinastia S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/196779.mp4', 'http://timg.bdta.pro/images/c13020a0517c034ad7c9295223b7b298.jpg'),
(3647, 234, 'Dinastia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196780.mp4', 'http://timg.bdta.pro/images/73b08df8c6d61639eb1c58a68b09fe6b.jpg'),
(3648, 234, 'Dinastia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196781.mp4', 'http://timg.bdta.pro/images/403880b0dd05abf7b3a01dbde3bc87b9.jpg'),
(3649, 234, 'Dinastia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196782.mp4', 'http://timg.bdta.pro/images/77d21fcd51aea632ad59848443e44722.jpg'),
(3650, 234, 'Dinastia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196783.mp4', 'http://timg.bdta.pro/images/5a707648af232f107327a1fdd14867f8.jpg'),
(3651, 234, 'Dinastia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196784.mp4', 'http://timg.bdta.pro/images/b1efa4dba69f3c96454e3ec3da974138.jpg'),
(3652, 234, 'Dinastia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196785.mp4', 'http://timg.bdta.pro/images/056822ca8ccd14efc76be224dd98b180.jpg'),
(3653, 234, 'Dinastia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196786.mp4', 'http://timg.bdta.pro/images/07c2756828508c9c1fd6a5a0c3c1787c.jpg'),
(3654, 234, 'Dinastia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196787.mp4', 'http://timg.bdta.pro/images/844f6791ada8b651e1c0d3afa6947762.jpg'),
(3655, 234, 'Dinastia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196788.mp4', 'http://timg.bdta.pro/images/e3e05db391d5b210cc52379276b60950.jpg'),
(3656, 234, 'Dinastia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196789.mp4', 'http://timg.bdta.pro/images/3ec674b4d489bc0122d88b40fec79e4b.jpg'),
(3657, 234, 'Dinastia S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196790.mp4', 'http://timg.bdta.pro/images/215506df8f759c5bb51c2d6ae298caac.jpg'),
(3658, 234, 'Dinastia S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196791.mp4', 'http://timg.bdta.pro/images/01c8349c207d2bd3fec2f8021e2c2831.jpg'),
(3659, 234, 'Dinastia S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196792.mp4', 'http://timg.bdta.pro/images/93f1c0cce7389f7c0543640b435352b1.jpg'),
(3660, 234, 'Dinastia S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/196793.mp4', 'http://timg.bdta.pro/images/c66a957c2e76a99796e741215d0da825.jpg'),
(3661, 234, 'Dinastia S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/196794.mp4', 'http://timg.bdta.pro/images/edde64631a5f75fd4d78b61f34f75392.jpg'),
(3662, 234, 'Dinastia S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/196795.mp4', 'http://timg.bdta.pro/images/481261bd6682fe60061e93ea51a444a2.jpg'),
(3663, 234, 'Dinastia S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/196796.mp4', 'http://timg.bdta.pro/images/55767624668bf6d71edd1980d4fc60d7.jpg'),
(3664, 234, 'Dinastia S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/196797.mp4', 'http://timg.bdta.pro/images/c1ff9776324f4f40353dd0749a93a7b6.jpg'),
(3665, 234, 'Dinastia S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/196798.mp4', 'http://timg.bdta.pro/images/426645871e348db8e2f749b38c84009a.jpg'),
(3666, 234, 'Dinastia S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/196799.mp4', 'http://timg.bdta.pro/images/01f9f32c9cc871d85cea0fbe89f0bd2d.jpg'),
(3667, 234, 'Dinastia S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/196800.mp4', 'http://timg.bdta.pro/images/83428875acf6d951be2bb93b6df14aab.jpg'),
(3668, 234, 'Dinastia S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/196801.mp4', 'http://timg.bdta.pro/images/ad22bf6e20632fc3eb7332537ab96edb.jpg'),
(3669, 235, 'Dinastia S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196802.mp4', 'http://timg.bdta.pro/images/4049e82c9ef6ade81663271c253781b0.jpg'),
(3670, 235, 'Dinastia S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196803.mp4', 'http://timg.bdta.pro/images/43696e0230d64cd5a0c4ceb1d9775eee.jpg'),
(3671, 235, 'Dinastia S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196804.mp4', 'http://timg.bdta.pro/images/bce25e95f506fea405fbd37897ac73ac.jpg'),
(3672, 235, 'Dinastia S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196805.mp4', 'http://timg.bdta.pro/images/c8564cfa496a95dfea987cbc65314a04.jpg'),
(3673, 235, 'Dinastia S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196806.mp4', 'http://timg.bdta.pro/images/1201bfe43f9d8596c3da62b3c623c380.jpg'),
(3674, 235, 'Dinastia S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196807.mp4', 'http://timg.bdta.pro/images/1e4b8a020b25240e2fd385fbeac95eff.jpg'),
(3675, 235, 'Dinastia S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196808.mp4', 'http://timg.bdta.pro/images/eb5fcb7fa777bfabb2f4a028f8ef785b.jpg'),
(3676, 235, 'Dinastia S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196809.mp4', 'http://timg.bdta.pro/images/55416568f3e1426e065c8ad764e8725f.jpg'),
(3677, 235, 'Dinastia S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196810.mp4', 'http://timg.bdta.pro/images/ae249d2e1fa87695b28198b177212edb.jpg'),
(3678, 235, 'Dinastia S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196811.mp4', 'http://timg.bdta.pro/images/4739e5c3bda750c5aba8a0b5d84a26e5.jpg'),
(3679, 235, 'Dinastia S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196812.mp4', 'http://timg.bdta.pro/images/85aae6667c5d027a713abb302091bf05.jpg'),
(3680, 235, 'Dinastia S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196813.mp4', 'http://timg.bdta.pro/images/9ac4e8b7cd7115ce719fa5d5a01c4425.jpg'),
(3681, 235, 'Dinastia S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196814.mp4', 'http://timg.bdta.pro/images/b31913e980adb55a23d93dfdbf0078a5.jpg'),
(3682, 235, 'Dinastia S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/196815.mp4', 'http://timg.bdta.pro/images/992441a17964fe1ae8b2deb7970bec83.jpg'),
(3683, 235, 'Dinastia S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/196816.mp4', 'http://timg.bdta.pro/images/29e8e9eccad0973311ec2d1e9dcb3ee2.jpg'),
(3684, 235, 'Dinastia S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/196817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aPj2qKRkZSn4sVXaOsHQjKO3aiT.jpg'),
(3685, 235, 'Dinastia S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/196818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aPj2qKRkZSn4sVXaOsHQjKO3aiT.jpg'),
(3686, 235, 'Dinastia S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/196819.mp4', 'http://timg.bdta.pro/images/af58d858d2b8a2d4e1e163ff7dd4e50e.jpg'),
(3687, 235, 'Dinastia S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/196820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aPj2qKRkZSn4sVXaOsHQjKO3aiT.jpg'),
(3688, 235, 'Dinastia S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/196821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aPj2qKRkZSn4sVXaOsHQjKO3aiT.jpg'),
(3689, 236, 'Dinastia S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196822.mp4', 'http://timg.bdta.pro/images/62b4787f1b9e4a04a8e6e8f7f22b5ae5.jpg'),
(3690, 236, 'Dinastia S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196823.mp4', 'http://timg.bdta.pro/images/ee84a6b5e0ea93e00da4db7b2ac0de60.jpg'),
(3691, 236, 'Dinastia S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196824.mp4', 'http://timg.bdta.pro/images/94a575f1fc950fb9291ab0f895082d09.jpg'),
(3692, 236, 'Dinastia S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196825.mp4', 'http://timg.bdta.pro/images/c58597c03873e94d34653d4247c38d36.jpg'),
(3693, 236, 'Dinastia S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196826.mp4', 'http://timg.bdta.pro/images/efa3319eaa67e20f05ca227aab39a2d0.jpg'),
(3694, 236, 'Dinastia S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196827.mp4', 'http://timg.bdta.pro/images/df9a926eaae50f4084b7afcfffd4f326.jpg'),
(3695, 236, 'Dinastia S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196828.mp4', 'http://timg.bdta.pro/images/ddb987f93220b037cd6c02bd7c8ef460.jpg'),
(3696, 236, 'Dinastia S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196829.mp4', 'http://timg.bdta.pro/images/e9db80e386c37baceed3b9fce8e8906c.jpg'),
(3697, 236, 'Dinastia S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196830.mp4', 'http://timg.bdta.pro/images/a9af5e140000e144760cd0ccfa7ec080.jpg'),
(3698, 236, 'Dinastia S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196831.mp4', 'http://timg.bdta.pro/images/81397e3353612d313b6e157fd9a9f4e4.jpg'),
(3699, 236, 'Dinastia S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196832.mp4', 'http://timg.bdta.pro/images/171178fe35cd44ba8d6b29de79bf377e.jpg'),
(3700, 236, 'Dinastia S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196833.mp4', 'http://timg.bdta.pro/images/47922d94244427b71b8bb83dbb63f071.jpg'),
(3701, 236, 'Dinastia S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196834.mp4', 'http://timg.bdta.pro/images/d157918252f7973a564c352b5e25698f.jpg'),
(3702, 236, 'Dinastia S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/196835.mp4', 'http://timg.bdta.pro/images/9c05214e6c38fe91327a095bdd5ecc4d.jpg'),
(3703, 236, 'Dinastia S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/196836.mp4', 'http://timg.bdta.pro/images/5042527e3718fbba79d3c1599fe1f994.jpg'),
(3704, 236, 'Dinastia S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/196837.mp4', 'http://timg.bdta.pro/images/0b4163f858458bc17fa2a5770d76dd9b.jpg'),
(3705, 236, 'Dinastia S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/196838.mp4', 'http://timg.bdta.pro/images/3ba7d75f620db001cc731025f4a42513.jpg'),
(3706, 236, 'Dinastia S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/196839.mp4', 'http://timg.bdta.pro/images/cf0a4ffca75c6c803dd1c17152731077.jpg'),
(3707, 236, 'Dinastia S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/196840.mp4', 'http://timg.bdta.pro/images/314f27d3b6f65b14d730ccdc6c7531aa.jpg'),
(3708, 236, 'Dinastia S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/196841.mp4', 'http://timg.bdta.pro/images/29ab13b83fdd5d9b158b1f6d09ce1006.jpg'),
(3709, 236, 'Dinastia S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/196842.mp4', 'http://timg.bdta.pro/images/14370d2d443d446fff6ae1e131468d08.jpg'),
(3710, 236, 'Dinastia S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/196843.mp4', 'http://timg.bdta.pro/images/aecdc9cef9f642ba27c16388b3f760b4.jpg'),
(3711, 237, 'Dinastia S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196844.mp4', 'http://timg.bdta.pro/images/145d939c2bb38c61d5c4643f6fe27613.jpg'),
(3712, 237, 'Dinastia S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196845.mp4', 'http://timg.bdta.pro/images/715de6bca166a523e3c66a0a85b7b1f2.jpg'),
(3713, 237, 'Dinastia S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196846.mp4', 'http://timg.bdta.pro/images/fa7cb5e9adfa9648cddbae72ffc92d5a.jpg'),
(3714, 237, 'Dinastia S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196847.mp4', 'http://timg.bdta.pro/images/e5ac83ad3c91b46e7cbcaf081c0fe150.jpg'),
(3715, 237, 'Dinastia S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196848.mp4', 'http://timg.bdta.pro/images/8abcacabb8514d892f510fcc5a5e4a58.jpg'),
(3716, 237, 'Dinastia S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196849.mp4', 'http://timg.bdta.pro/images/78bcaac492779ff34b8aec90609becc2.jpg'),
(3717, 237, 'Dinastia S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196850.mp4', 'http://timg.bdta.pro/images/de0aac56cecd3c7e056a6b5945c2cb9a.jpg'),
(3718, 237, 'Dinastia S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196851.mp4', 'http://timg.bdta.pro/images/6b8043fe03044a8568db9d34d130c29e.jpg'),
(3719, 237, 'Dinastia S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196852.mp4', 'http://timg.bdta.pro/images/eba84050d06da5fb89f5dbe3613a071f.jpg'),
(3720, 237, 'Dinastia S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196853.mp4', 'http://timg.bdta.pro/images/4baea3ddf9a94c9c35d6ae40d603c530.jpg'),
(3721, 237, 'Dinastia S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196854.mp4', 'http://timg.bdta.pro/images/b1842cfa2270693c347e8b3f226479ed.jpg'),
(3722, 237, 'Dinastia S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196855.mp4', 'http://timg.bdta.pro/images/1b57c7cda80c3ec394bf02dccbc6cd42.jpg'),
(3723, 237, 'Dinastia S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196856.mp4', 'http://timg.bdta.pro/images/64f6b7f3cd7453be7b0aa6093cc1a392.jpg'),
(3724, 237, 'Dinastia S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/196857.mp4', 'http://timg.bdta.pro/images/53d46073fb53d65d9a3dfffcf15d1874.jpg'),
(3725, 237, 'Dinastia S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/196858.mp4', 'http://timg.bdta.pro/images/e529f92794ab00585a48e8800198607a.jpg'),
(3726, 237, 'Dinastia S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/196859.mp4', 'http://timg.bdta.pro/images/33b2d29dfc5b1c6b9e2e0a6b0545a56c.jpg'),
(3727, 237, 'Dinastia S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/196860.mp4', 'http://timg.bdta.pro/images/4204d12eb3c20dd67d643e64b9419f15.jpg'),
(3728, 237, 'Dinastia S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/196861.mp4', 'http://timg.bdta.pro/images/b7c4dbe7e29c966e89879d2d285ee457.jpg'),
(3729, 237, 'Dinastia S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/196862.mp4', 'http://timg.bdta.pro/images/1e3448f6ca540b0326389e70ac1dff98.jpg'),
(3730, 237, 'Dinastia S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/196863.mp4', 'http://timg.bdta.pro/images/e23f54fb506fdf340c699e5c43a58ce5.jpg'),
(3731, 237, 'Dinastia S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/196864.mp4', 'http://timg.bdta.pro/images/51c4012dc448b04f5b936cb72fe2c954.jpg'),
(3732, 237, 'Dinastia S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/196865.mp4', 'http://timg.bdta.pro/images/e34e5e52156b5cb9e512c73401c72f8c.jpg'),
(3733, 238, 'Doctor Who S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3734, 238, 'Doctor Who S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3735, 238, 'Doctor Who S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3736, 238, 'Doctor Who S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3737, 238, 'Doctor Who S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3738, 238, 'Doctor Who S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3739, 238, 'Doctor Who S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3740, 238, 'Doctor Who S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3741, 238, 'Doctor Who S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3742, 238, 'Doctor Who S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3743, 238, 'Doctor Who S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3744, 238, 'Doctor Who S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3745, 238, 'Doctor Who S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3746, 239, 'Doctor Who S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/585020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3747, 239, 'Doctor Who S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3748, 239, 'Doctor Who S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3749, 239, 'Doctor Who S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3750, 239, 'Doctor Who S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3751, 239, 'Doctor Who S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3752, 239, 'Doctor Who S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3753, 239, 'Doctor Who S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3754, 239, 'Doctor Who S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3755, 239, 'Doctor Who S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3756, 239, 'Doctor Who S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3757, 239, 'Doctor Who S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3758, 239, 'Doctor Who S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3759, 240, 'Doctor Who S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3760, 240, 'Doctor Who S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3761, 240, 'Doctor Who S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3762, 240, 'Doctor Who S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3763, 240, 'Doctor Who S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3764, 240, 'Doctor Who S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3765, 240, 'Doctor Who S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3766, 240, 'Doctor Who S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3767, 240, 'Doctor Who S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3768, 240, 'Doctor Who S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3769, 240, 'Doctor Who S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3770, 240, 'Doctor Who S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3771, 241, 'Doctor Who S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3772, 241, 'Doctor Who S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3773, 241, 'Doctor Who S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3774, 241, 'Doctor Who S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3775, 241, 'Doctor Who S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3776, 241, 'Doctor Who S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3777, 241, 'Doctor Who S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3778, 241, 'Doctor Who S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3779, 241, 'Doctor Who S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3780, 241, 'Doctor Who S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3781, 241, 'Doctor Who S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3782, 241, 'Doctor Who S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3783, 241, 'Doctor Who S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3784, 242, 'Doctor Who S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3785, 242, 'Doctor Who S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3786, 242, 'Doctor Who S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3787, 242, 'Doctor Who S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3788, 242, 'Doctor Who S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3789, 242, 'Doctor Who S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3790, 242, 'Doctor Who S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3791, 242, 'Doctor Who S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3792, 242, 'Doctor Who S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3793, 242, 'Doctor Who S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3794, 242, 'Doctor Who S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3795, 242, 'Doctor Who S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3796, 242, 'Doctor Who S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3797, 242, 'Doctor Who S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/248006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3798, 243, 'Doctor Who S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/585073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3799, 243, 'Doctor Who S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3800, 243, 'Doctor Who S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3801, 243, 'Doctor Who S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3802, 243, 'Doctor Who S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3803, 243, 'Doctor Who S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3804, 243, 'Doctor Who S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3805, 243, 'Doctor Who S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3806, 243, 'Doctor Who S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3807, 243, 'Doctor Who S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3808, 243, 'Doctor Who S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3809, 243, 'Doctor Who S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3810, 243, 'Doctor Who S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3811, 244, 'Doctor Who S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3812, 244, 'Doctor Who S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3813, 244, 'Doctor Who S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3814, 244, 'Doctor Who S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3815, 244, 'Doctor Who S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3816, 244, 'Doctor Who S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3817, 244, 'Doctor Who S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3818, 244, 'Doctor Who S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3819, 244, 'Doctor Who S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3820, 244, 'Doctor Who S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3821, 244, 'Doctor Who S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3822, 244, 'Doctor Who S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3823, 244, 'Doctor Who S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3824, 244, 'Doctor Who S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/248034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3825, 244, 'Doctor Who S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/248035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3826, 244, 'Doctor Who S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/248036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3827, 245, 'Doctor Who S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/585103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3828, 245, 'Doctor Who S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/585105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3829, 245, 'Doctor Who S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/585107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3830, 245, 'Doctor Who S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/585109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3831, 245, 'Doctor Who S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/585111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3832, 245, 'Doctor Who S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/585113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3833, 245, 'Doctor Who S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/585115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3834, 245, 'Doctor Who S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/585117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3835, 245, 'Doctor Who S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/585119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3836, 245, 'Doctor Who S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/585121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3837, 245, 'Doctor Who S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/585123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3838, 245, 'Doctor Who S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3839, 246, 'Doctor Who S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3840, 246, 'Doctor Who S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3841, 246, 'Doctor Who S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3842, 246, 'Doctor Who S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3843, 246, 'Doctor Who S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3844, 246, 'Doctor Who S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3845, 246, 'Doctor Who S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3846, 246, 'Doctor Who S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3847, 246, 'Doctor Who S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3848, 246, 'Doctor Who S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3849, 246, 'Doctor Who S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3850, 246, 'Doctor Who S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3851, 247, 'Doctor Who S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3852, 247, 'Doctor Who S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3853, 247, 'Doctor Who S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3854, 247, 'Doctor Who S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3855, 247, 'Doctor Who S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3856, 247, 'Doctor Who S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3857, 247, 'Doctor Who S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3858, 247, 'Doctor Who S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3859, 247, 'Doctor Who S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3860, 247, 'Doctor Who S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3861, 247, 'Doctor Who S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3862, 247, 'Doctor Who S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3863, 248, 'Doctor Who S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/585150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3864, 248, 'Doctor Who S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3865, 248, 'Doctor Who S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3866, 248, 'Doctor Who S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3867, 248, 'Doctor Who S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3868, 248, 'Doctor Who S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3869, 248, 'Doctor Who S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3870, 248, 'Doctor Who S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3871, 248, 'Doctor Who S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3872, 248, 'Doctor Who S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3873, 249, 'Doctor Who S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/585161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3874, 249, 'Doctor Who S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3875, 249, 'Doctor Who S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3876, 249, 'Doctor Who S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3877, 249, 'Doctor Who S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3878, 249, 'Doctor Who S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3879, 249, 'Doctor Who S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3880, 249, 'Doctor Who S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3881, 249, 'Doctor Who S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3882, 249, 'Doctor Who S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3883, 250, 'Doctor Who S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/585172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3884, 250, 'Doctor Who S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lZEmZo4iJqvHLKDxhORT9x9C33d.jpg'),
(3885, 250, 'Doctor Who S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTLrnRKrbRJooWr0kQB6ZE44uzD.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(3886, 250, 'Doctor Who S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z6vZLkObqFesuIbZxTNfroyLVFb.jpg'),
(3887, 250, 'Doctor Who S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jcEyyiqsYMLA2VdiZanEGfg8oQC.jpg'),
(3888, 250, 'Doctor Who S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/20wu1cj5iZWyphnYQvKY1M9yBYQ.jpg'),
(3889, 251, 'Doctor Who S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3890, 251, 'Doctor Who S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3891, 251, 'Doctor Who S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sz4zF5z9zyFh8Z6g5IQPNq91cI7.jpg'),
(3892, 252, 'Dracula S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101075.mp4', 'http://gstaticontent.com/images/5DdFVubdnW3TuoL84cNVZQTGR65_big.jpg'),
(3893, 252, 'Dracula S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101076.mp4', 'http://gstaticontent.com/images/5DdFVubdnW3TuoL84cNVZQTGR65_big.jpg'),
(3894, 252, 'Dracula S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101077.mp4', 'http://gstaticontent.com/images/5DdFVubdnW3TuoL84cNVZQTGR65_big.jpg'),
(3895, 252, 'Dracula S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101078.mp4', 'http://gstaticontent.com/images/5DdFVubdnW3TuoL84cNVZQTGR65_big.jpg'),
(3896, 252, 'Dracula S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101079.mp4', 'http://gstaticontent.com/images/5DdFVubdnW3TuoL84cNVZQTGR65_big.jpg'),
(3897, 252, 'Dracula S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101080.mp4', 'http://gstaticontent.com/images/5DdFVubdnW3TuoL84cNVZQTGR65_big.jpg'),
(3898, 252, 'Dracula S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101081.mp4', 'http://gstaticontent.com/images/5DdFVubdnW3TuoL84cNVZQTGR65_big.jpg'),
(3899, 252, 'Dracula S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101082.mp4', 'http://gstaticontent.com/images/5DdFVubdnW3TuoL84cNVZQTGR65_big.jpg'),
(3900, 252, 'Dracula S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101083.mp4', 'http://gstaticontent.com/images/5DdFVubdnW3TuoL84cNVZQTGR65_big.jpg'),
(3901, 252, 'Dracula S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101084.mp4', 'http://gstaticontent.com/images/5DdFVubdnW3TuoL84cNVZQTGR65_big.jpg'),
(3902, 253, 'Dr. House S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142637.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3903, 253, 'Dr. House S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142638.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3904, 253, 'Dr. House S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142639.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3905, 253, 'Dr. House S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142640.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3906, 253, 'Dr. House S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142641.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3907, 253, 'Dr. House S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142642.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3908, 253, 'Dr. House S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142643.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3909, 253, 'Dr. House S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142644.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3910, 253, 'Dr. House S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142645.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3911, 253, 'Dr. House S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142646.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3912, 253, 'Dr. House S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142647.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3913, 253, 'Dr. House S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142648.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3914, 253, 'Dr. House S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142649.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3915, 253, 'Dr. House S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/142650.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3916, 253, 'Dr. House S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142651.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3917, 253, 'Dr. House S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/142652.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3918, 253, 'Dr. House S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/142653.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3919, 253, 'Dr. House S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/142654.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3920, 253, 'Dr. House S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/142655.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3921, 253, 'Dr. House S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/142656.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3922, 253, 'Dr. House S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/142657.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3923, 253, 'Dr. House S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/142658.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3924, 254, 'Dr. House S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142659.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3925, 254, 'Dr. House S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142660.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3926, 254, 'Dr. House S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142661.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3927, 254, 'Dr. House S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142662.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3928, 254, 'Dr. House S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142663.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3929, 254, 'Dr. House S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142664.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3930, 254, 'Dr. House S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142665.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3931, 254, 'Dr. House S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142666.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3932, 254, 'Dr. House S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142667.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3933, 254, 'Dr. House S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142668.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3934, 254, 'Dr. House S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142669.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3935, 254, 'Dr. House S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142670.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3936, 254, 'Dr. House S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142671.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3937, 254, 'Dr. House S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/142672.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3938, 254, 'Dr. House S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142673.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3939, 254, 'Dr. House S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/142674.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3940, 254, 'Dr. House S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/142675.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3941, 254, 'Dr. House S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/142676.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3942, 254, 'Dr. House S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/142677.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3943, 254, 'Dr. House S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/142678.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3944, 254, 'Dr. House S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/142679.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3945, 254, 'Dr. House S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/142680.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3946, 254, 'Dr. House S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/142681.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3947, 254, 'Dr. House S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/142682.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3948, 255, 'Dr. House S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142683.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3949, 255, 'Dr. House S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142684.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3950, 255, 'Dr. House S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142685.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3951, 255, 'Dr. House S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142686.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3952, 255, 'Dr. House S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142687.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3953, 255, 'Dr. House S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142688.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3954, 255, 'Dr. House S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142689.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3955, 255, 'Dr. House S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142690.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3956, 255, 'Dr. House S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142691.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3957, 255, 'Dr. House S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142692.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3958, 255, 'Dr. House S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142693.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3959, 255, 'Dr. House S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142694.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3960, 255, 'Dr. House S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142695.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3961, 255, 'Dr. House S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/142696.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3962, 255, 'Dr. House S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142697.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3963, 255, 'Dr. House S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/142698.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3964, 255, 'Dr. House S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/142699.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3965, 255, 'Dr. House S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/142700.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3966, 255, 'Dr. House S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/142701.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3967, 255, 'Dr. House S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/142702.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3968, 255, 'Dr. House S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/142703.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3969, 255, 'Dr. House S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/142704.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3970, 255, 'Dr. House S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/142705.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3971, 255, 'Dr. House S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/142706.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3972, 256, 'Dr. House S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142707.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3973, 256, 'Dr. House S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142708.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3974, 256, 'Dr. House S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142709.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3975, 256, 'Dr. House S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142710.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3976, 256, 'Dr. House S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142711.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3977, 256, 'Dr. House S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142712.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3978, 256, 'Dr. House S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142713.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3979, 256, 'Dr. House S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142714.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3980, 256, 'Dr. House S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142715.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3981, 256, 'Dr. House S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142716.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3982, 256, 'Dr. House S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142717.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3983, 256, 'Dr. House S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142718.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3984, 256, 'Dr. House S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142719.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3985, 256, 'Dr. House S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/142720.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3986, 256, 'Dr. House S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142721.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3987, 256, 'Dr. House S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/142722.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3988, 257, 'Dr. House S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142723.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3989, 257, 'Dr. House S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142724.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3990, 257, 'Dr. House S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142725.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3991, 257, 'Dr. House S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142726.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3992, 257, 'Dr. House S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142727.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3993, 257, 'Dr. House S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142728.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3994, 257, 'Dr. House S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142729.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3995, 257, 'Dr. House S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142730.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3996, 257, 'Dr. House S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142731.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3997, 257, 'Dr. House S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142732.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3998, 257, 'Dr. House S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142733.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(3999, 257, 'Dr. House S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142734.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4000, 257, 'Dr. House S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142735.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4001, 257, 'Dr. House S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/142736.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4002, 257, 'Dr. House S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142737.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4003, 257, 'Dr. House S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/142738.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4004, 257, 'Dr. House S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/142739.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4005, 257, 'Dr. House S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/142740.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4006, 257, 'Dr. House S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/142741.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4007, 257, 'Dr. House S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/142742.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4008, 257, 'Dr. House S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/142743.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4009, 257, 'Dr. House S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/142744.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4010, 257, 'Dr. House S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/142745.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4011, 257, 'Dr. House S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/142746.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4012, 258, 'Dr. House S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142747.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4013, 258, 'Dr. House S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142748.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4014, 258, 'Dr. House S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142749.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4015, 258, 'Dr. House S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142750.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4016, 258, 'Dr. House S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142751.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4017, 258, 'Dr. House S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142752.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4018, 258, 'Dr. House S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142753.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4019, 258, 'Dr. House S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142754.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4020, 258, 'Dr. House S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142755.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4021, 258, 'Dr. House S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142756.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4022, 258, 'Dr. House S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142757.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4023, 258, 'Dr. House S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142758.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4024, 258, 'Dr. House S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142759.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4025, 258, 'Dr. House S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/142760.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4026, 258, 'Dr. House S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142761.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4027, 258, 'Dr. House S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/142762.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4028, 258, 'Dr. House S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/142763.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4029, 258, 'Dr. House S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/142764.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4030, 258, 'Dr. House S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/142765.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4031, 258, 'Dr. House S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/142766.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4032, 258, 'Dr. House S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/142767.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4033, 258, 'Dr. House S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/142768.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4034, 259, 'Dr. House S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142769.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4035, 259, 'Dr. House S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142770.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4036, 259, 'Dr. House S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142771.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4037, 259, 'Dr. House S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142772.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4038, 259, 'Dr. House S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142773.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4039, 259, 'Dr. House S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142774.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4040, 259, 'Dr. House S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142775.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4041, 259, 'Dr. House S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142776.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4042, 259, 'Dr. House S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142777.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4043, 259, 'Dr. House S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142778.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4044, 259, 'Dr. House S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142779.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4045, 259, 'Dr. House S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142780.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4046, 259, 'Dr. House S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142781.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4047, 259, 'Dr. House S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/142782.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4048, 259, 'Dr. House S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142783.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4049, 259, 'Dr. House S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/142784.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4050, 259, 'Dr. House S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/142785.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4051, 259, 'Dr. House S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/142786.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4052, 259, 'Dr. House S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/142787.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4053, 259, 'Dr. House S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/142788.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4054, 259, 'Dr. House S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/142789.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4055, 259, 'Dr. House S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/142790.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4056, 259, 'Dr. House S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/142791.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4057, 260, 'Dr. House S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142792.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4058, 260, 'Dr. House S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142793.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4059, 260, 'Dr. House S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142794.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4060, 260, 'Dr. House S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142795.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4061, 260, 'Dr. House S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142796.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4062, 260, 'Dr. House S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142797.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4063, 260, 'Dr. House S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142798.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4064, 260, 'Dr. House S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142799.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4065, 260, 'Dr. House S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142800.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4066, 260, 'Dr. House S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142801.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4067, 260, 'Dr. House S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142802.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4068, 260, 'Dr. House S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142803.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4069, 260, 'Dr. House S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142804.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4070, 260, 'Dr. House S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/142805.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4071, 260, 'Dr. House S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142806.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4072, 260, 'Dr. House S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/142807.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4073, 260, 'Dr. House S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/142808.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4074, 260, 'Dr. House S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/142809.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4075, 260, 'Dr. House S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/142810.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4076, 260, 'Dr. House S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/142811.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4077, 260, 'Dr. House S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/142812.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4078, 260, 'Dr. House S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/142813.mp4', 'http://gstaticontent.com/images/lW7MvZ4m49IUj2UrUu4z0xVVl81_big.jpg'),
(4079, 261, 'Elementary S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124533.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4080, 261, 'Elementary S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124534.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4081, 261, 'Elementary S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124535.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4082, 261, 'Elementary S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124536.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4083, 261, 'Elementary S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124537.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4084, 261, 'Elementary S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124538.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4085, 261, 'Elementary S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124539.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4086, 261, 'Elementary S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124540.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4087, 261, 'Elementary S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124541.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4088, 261, 'Elementary S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124542.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4089, 261, 'Elementary S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124543.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4090, 261, 'Elementary S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124544.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4091, 261, 'Elementary S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124545.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4092, 261, 'Elementary S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/124546.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4093, 261, 'Elementary S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/124547.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4094, 261, 'Elementary S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/124548.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4095, 261, 'Elementary S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/124549.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4096, 261, 'Elementary S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/124550.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4097, 261, 'Elementary S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/124551.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4098, 261, 'Elementary S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/124552.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4099, 261, 'Elementary S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/124553.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4100, 261, 'Elementary S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/124554.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4101, 261, 'Elementary S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/124555.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4102, 262, 'Elementary S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124556.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4103, 262, 'Elementary S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124557.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4104, 262, 'Elementary S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124558.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4105, 262, 'Elementary S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124559.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4106, 262, 'Elementary S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124560.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4107, 262, 'Elementary S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124561.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4108, 262, 'Elementary S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124562.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4109, 262, 'Elementary S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124563.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4110, 262, 'Elementary S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124564.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4111, 262, 'Elementary S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124565.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4112, 262, 'Elementary S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124566.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4113, 262, 'Elementary S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124567.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4114, 262, 'Elementary S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124568.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4115, 262, 'Elementary S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/124569.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4116, 262, 'Elementary S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/124570.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4117, 262, 'Elementary S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/124571.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4118, 262, 'Elementary S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/124572.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4119, 262, 'Elementary S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/124573.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4120, 262, 'Elementary S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/124574.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4121, 262, 'Elementary S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/124575.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4122, 262, 'Elementary S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/124576.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4123, 262, 'Elementary S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/124577.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4124, 262, 'Elementary S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/124578.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4125, 262, 'Elementary S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/124579.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4126, 263, 'Elementary S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124580.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4127, 263, 'Elementary S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124581.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4128, 263, 'Elementary S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124582.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4129, 263, 'Elementary S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124583.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4130, 263, 'Elementary S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124584.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4131, 263, 'Elementary S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124585.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4132, 263, 'Elementary S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124586.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4133, 263, 'Elementary S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124587.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4134, 263, 'Elementary S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124588.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4135, 263, 'Elementary S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124589.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4136, 263, 'Elementary S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124590.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4137, 263, 'Elementary S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124591.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4138, 263, 'Elementary S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124592.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4139, 263, 'Elementary S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/124593.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4140, 263, 'Elementary S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/124594.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4141, 263, 'Elementary S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/124595.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4142, 263, 'Elementary S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/124596.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4143, 263, 'Elementary S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/124597.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4144, 263, 'Elementary S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/124598.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4145, 263, 'Elementary S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/124599.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4146, 263, 'Elementary S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/124600.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4147, 263, 'Elementary S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/124601.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4148, 263, 'Elementary S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/124602.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4149, 263, 'Elementary S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/124603.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4150, 264, 'Elementary S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124604.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4151, 264, 'Elementary S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124605.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4152, 264, 'Elementary S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124606.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4153, 264, 'Elementary S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124607.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4154, 264, 'Elementary S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124608.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4155, 264, 'Elementary S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124609.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4156, 264, 'Elementary S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124610.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4157, 264, 'Elementary S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124611.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4158, 264, 'Elementary S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124612.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4159, 264, 'Elementary S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124613.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4160, 264, 'Elementary S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124614.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4161, 264, 'Elementary S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124615.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4162, 264, 'Elementary S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124616.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4163, 264, 'Elementary S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/124617.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4164, 264, 'Elementary S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/124618.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4165, 264, 'Elementary S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/124619.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4166, 264, 'Elementary S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/124620.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4167, 264, 'Elementary S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/124621.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4168, 264, 'Elementary S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/124622.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4169, 264, 'Elementary S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/124623.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4170, 264, 'Elementary S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/124624.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4171, 264, 'Elementary S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/124625.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4172, 264, 'Elementary S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/124626.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4173, 265, 'Elementary S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124627.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4174, 265, 'Elementary S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124628.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4175, 265, 'Elementary S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124629.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4176, 265, 'Elementary S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124630.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4177, 265, 'Elementary S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124631.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4178, 265, 'Elementary S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124632.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4179, 265, 'Elementary S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124633.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4180, 265, 'Elementary S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124634.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4181, 265, 'Elementary S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124635.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(4182, 265, 'Elementary S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124636.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4183, 265, 'Elementary S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124637.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4184, 265, 'Elementary S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124638.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4185, 265, 'Elementary S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124639.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4186, 265, 'Elementary S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/124640.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4187, 265, 'Elementary S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/124641.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4188, 265, 'Elementary S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/124642.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4189, 265, 'Elementary S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/124643.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4190, 265, 'Elementary S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/124644.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4191, 265, 'Elementary S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/124645.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4192, 265, 'Elementary S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/124646.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4193, 265, 'Elementary S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/124647.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4194, 265, 'Elementary S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/124648.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4195, 265, 'Elementary S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/124649.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4196, 265, 'Elementary S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/124650.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4197, 266, 'Elementary S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124651.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4198, 266, 'Elementary S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124652.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4199, 266, 'Elementary S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124653.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4200, 266, 'Elementary S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124654.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4201, 266, 'Elementary S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124655.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4202, 266, 'Elementary S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124656.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4203, 266, 'Elementary S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124657.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4204, 266, 'Elementary S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124658.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4205, 266, 'Elementary S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124659.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4206, 266, 'Elementary S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124660.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4207, 266, 'Elementary S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124661.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4208, 266, 'Elementary S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124662.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4209, 266, 'Elementary S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124663.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4210, 266, 'Elementary S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/124664.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4211, 266, 'Elementary S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/124665.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4212, 266, 'Elementary S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/124666.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4213, 266, 'Elementary S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/124667.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4214, 266, 'Elementary S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/124668.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4215, 266, 'Elementary S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/124669.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4216, 266, 'Elementary S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/124670.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4217, 266, 'Elementary S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/124671.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4218, 267, 'Elementary S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124672.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4219, 267, 'Elementary S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124673.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4220, 267, 'Elementary S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124674.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4221, 267, 'Elementary S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124675.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4222, 267, 'Elementary S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124676.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4223, 267, 'Elementary S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124677.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4224, 267, 'Elementary S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124678.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4225, 267, 'Elementary S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124679.mp4', 'http://gstaticontent.com/images/gGbrUjMTDFe631eyNRkaKecLeIj_big.jpg'),
(4226, 267, 'Elementary S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124680.mp4', 'http://timg.bdta.pro/images/b76d03d3809ad7341cca28125c6fc515.jpg'),
(4227, 267, 'Elementary S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124681.mp4', 'http://timg.bdta.pro/images/5a34deb20fe2fcf19daee269860860fd.jpg'),
(4228, 267, 'Elementary S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124682.mp4', 'http://timg.bdta.pro/images/c8af133f287c363232b74f44b35cf975.jpg'),
(4229, 267, 'Elementary S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124683.mp4', 'http://timg.bdta.pro/images/6689dd2710f236855176ca81971837fb.jpg'),
(4230, 267, 'Elementary S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124684.mp4', 'http://timg.bdta.pro/images/d876c43409bedd1602ef2645239b1a08.jpg'),
(4231, 268, 'Eu A Patroa E As Criancas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101085.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4232, 268, 'Eu A Patroa E As Criancas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101086.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4233, 268, 'Eu A Patroa E As Criancas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101087.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4234, 268, 'Eu A Patroa E As Criancas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101088.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4235, 268, 'Eu A Patroa E As Criancas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101089.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4236, 268, 'Eu A Patroa E As Criancas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101090.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4237, 268, 'Eu A Patroa E As Criancas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101091.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4238, 268, 'Eu A Patroa E As Criancas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101092.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4239, 268, 'Eu A Patroa E As Criancas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101093.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4240, 268, 'Eu A Patroa E As Criancas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101094.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4241, 268, 'Eu A Patroa E As Criancas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101095.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4242, 269, 'Eu A Patroa E As Criancas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101096.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4243, 269, 'Eu A Patroa E As Criancas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101097.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4244, 269, 'Eu A Patroa E As Criancas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101098.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4245, 269, 'Eu A Patroa E As Criancas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101099.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4246, 269, 'Eu A Patroa E As Criancas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101100.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4247, 269, 'Eu A Patroa E As Criancas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101101.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4248, 269, 'Eu A Patroa E As Criancas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101102.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4249, 269, 'Eu A Patroa E As Criancas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101103.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4250, 269, 'Eu A Patroa E As Criancas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101104.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4251, 269, 'Eu A Patroa E As Criancas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101105.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4252, 269, 'Eu A Patroa E As Criancas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101106.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4253, 269, 'Eu A Patroa E As Criancas S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101107.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4254, 269, 'Eu A Patroa E As Criancas S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101108.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4255, 269, 'Eu A Patroa E As Criancas S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101109.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4256, 269, 'Eu A Patroa E As Criancas S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101110.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4257, 269, 'Eu A Patroa E As Criancas S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101111.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4258, 269, 'Eu A Patroa E As Criancas S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101112.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4259, 269, 'Eu A Patroa E As Criancas S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101113.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4260, 269, 'Eu A Patroa E As Criancas S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101114.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4261, 269, 'Eu A Patroa E As Criancas S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/101115.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4262, 269, 'Eu A Patroa E As Criancas S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/101116.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4263, 269, 'Eu A Patroa E As Criancas S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/101117.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4264, 269, 'Eu A Patroa E As Criancas S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/101118.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4265, 269, 'Eu A Patroa E As Criancas S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/101119.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4266, 269, 'Eu A Patroa E As Criancas S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/101120.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4267, 269, 'Eu A Patroa E As Criancas S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/101121.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4268, 269, 'Eu A Patroa E As Criancas S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/101122.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4269, 269, 'Eu A Patroa E As Criancas S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/101123.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4270, 269, 'Eu A Patroa E As Criancas S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/101124.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4271, 270, 'Eu A Patroa E As Criancas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101125.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4272, 270, 'Eu A Patroa E As Criancas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101126.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4273, 270, 'Eu A Patroa E As Criancas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101127.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4274, 270, 'Eu A Patroa E As Criancas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101128.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4275, 270, 'Eu A Patroa E As Criancas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101129.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4276, 270, 'Eu A Patroa E As Criancas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101130.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4277, 270, 'Eu A Patroa E As Criancas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101131.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4278, 270, 'Eu A Patroa E As Criancas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101132.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4279, 270, 'Eu A Patroa E As Criancas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101133.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4280, 270, 'Eu A Patroa E As Criancas S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101134.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4281, 270, 'Eu A Patroa E As Criancas S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101135.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4282, 270, 'Eu A Patroa E As Criancas S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101136.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4283, 270, 'Eu A Patroa E As Criancas S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101137.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4284, 270, 'Eu A Patroa E As Criancas S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101138.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4285, 270, 'Eu A Patroa E As Criancas S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101139.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4286, 270, 'Eu A Patroa E As Criancas S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101140.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4287, 270, 'Eu A Patroa E As Criancas S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101141.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4288, 270, 'Eu A Patroa E As Criancas S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101142.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4289, 270, 'Eu A Patroa E As Criancas S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101143.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4290, 270, 'Eu A Patroa E As Criancas S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/101144.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4291, 270, 'Eu A Patroa E As Criancas S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/101145.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4292, 270, 'Eu A Patroa E As Criancas S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/101146.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4293, 270, 'Eu A Patroa E As Criancas S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/101147.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4294, 270, 'Eu A Patroa E As Criancas S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/101148.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4295, 270, 'Eu A Patroa E As Criancas S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/101149.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4296, 270, 'Eu A Patroa E As Criancas S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/101150.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4297, 270, 'Eu A Patroa E As Criancas S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/101151.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4298, 271, 'Eu A Patroa E As Criancas S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101152.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4299, 271, 'Eu A Patroa E As Criancas S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101153.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4300, 271, 'Eu A Patroa E As Criancas S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101154.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4301, 271, 'Eu A Patroa E As Criancas S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101155.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4302, 271, 'Eu A Patroa E As Criancas S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101156.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4303, 271, 'Eu A Patroa E As Criancas S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101157.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4304, 271, 'Eu A Patroa E As Criancas S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101158.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4305, 271, 'Eu A Patroa E As Criancas S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101159.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4306, 271, 'Eu A Patroa E As Criancas S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101160.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4307, 271, 'Eu A Patroa E As Criancas S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101161.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4308, 271, 'Eu A Patroa E As Criancas S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101162.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4309, 271, 'Eu A Patroa E As Criancas S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101163.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4310, 271, 'Eu A Patroa E As Criancas S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101164.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4311, 271, 'Eu A Patroa E As Criancas S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101165.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4312, 271, 'Eu A Patroa E As Criancas S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101166.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4313, 271, 'Eu A Patroa E As Criancas S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101167.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4314, 271, 'Eu A Patroa E As Criancas S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101168.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4315, 271, 'Eu A Patroa E As Criancas S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101169.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4316, 271, 'Eu A Patroa E As Criancas S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101170.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4317, 271, 'Eu A Patroa E As Criancas S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/101171.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4318, 271, 'Eu A Patroa E As Criancas S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/101172.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4319, 271, 'Eu A Patroa E As Criancas S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/101173.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4320, 271, 'Eu A Patroa E As Criancas S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/101174.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4321, 271, 'Eu A Patroa E As Criancas S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/101175.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4322, 271, 'Eu A Patroa E As Criancas S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/101176.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4323, 271, 'Eu A Patroa E As Criancas S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/101177.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4324, 271, 'Eu A Patroa E As Criancas S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/101178.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4325, 271, 'Eu A Patroa E As Criancas S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/101179.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4326, 271, 'Eu A Patroa E As Criancas S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/101180.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4327, 271, 'Eu A Patroa E As Criancas S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/101181.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4328, 272, 'Eu A Patroa E As Criancas S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101182.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4329, 272, 'Eu A Patroa E As Criancas S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101183.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4330, 272, 'Eu A Patroa E As Criancas S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101184.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4331, 272, 'Eu A Patroa E As Criancas S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101185.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4332, 272, 'Eu A Patroa E As Criancas S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101186.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4333, 272, 'Eu A Patroa E As Criancas S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101187.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4334, 272, 'Eu A Patroa E As Criancas S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101188.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4335, 272, 'Eu A Patroa E As Criancas S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101189.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4336, 272, 'Eu A Patroa E As Criancas S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101190.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4337, 272, 'Eu A Patroa E As Criancas S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101191.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4338, 272, 'Eu A Patroa E As Criancas S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101192.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4339, 272, 'Eu A Patroa E As Criancas S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101193.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4340, 272, 'Eu A Patroa E As Criancas S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101194.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4341, 272, 'Eu A Patroa E As Criancas S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101195.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4342, 272, 'Eu A Patroa E As Criancas S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101196.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4343, 272, 'Eu A Patroa E As Criancas S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101197.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4344, 272, 'Eu A Patroa E As Criancas S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101198.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4345, 272, 'Eu A Patroa E As Criancas S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101199.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4346, 272, 'Eu A Patroa E As Criancas S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101200.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4347, 272, 'Eu A Patroa E As Criancas S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/101201.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4348, 272, 'Eu A Patroa E As Criancas S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/101202.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4349, 272, 'Eu A Patroa E As Criancas S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/101203.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4350, 272, 'Eu A Patroa E As Criancas S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/101204.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4351, 272, 'Eu A Patroa E As Criancas S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/101205.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4352, 272, 'Eu A Patroa E As Criancas S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/101206.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4353, 272, 'Eu A Patroa E As Criancas S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/101207.mp4', 'http://gstaticontent.com/images/9Bw3ONAR8UdazmyhNdJxyJJ89cY_big.jpg'),
(4354, 273, 'Eu Tu E Ela S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114987.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(4355, 273, 'Eu Tu E Ela S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114988.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(4356, 273, 'Eu Tu E Ela S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114989.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(4357, 273, 'Eu Tu E Ela S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114990.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(4358, 273, 'Eu Tu E Ela S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114991.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(4359, 273, 'Eu Tu E Ela S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114992.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(4360, 273, 'Eu Tu E Ela S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114993.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(4361, 273, 'Eu Tu E Ela S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114994.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(4362, 273, 'Eu Tu E Ela S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114995.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(4363, 273, 'Eu Tu E Ela S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114996.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(4364, 274, 'Eu Tu E Ela S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114997.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(4365, 274, 'Eu Tu E Ela S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114998.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(4366, 274, 'Eu Tu E Ela S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114999.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(4367, 274, 'Eu Tu E Ela S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/115000.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(4368, 274, 'Eu Tu E Ela S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/115001.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(4369, 274, 'Eu Tu E Ela S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/115002.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(4370, 274, 'Eu Tu E Ela S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/115003.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(4371, 274, 'Eu Tu E Ela S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/115004.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(4372, 274, 'Eu Tu E Ela S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/115005.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(4373, 274, 'Eu Tu E Ela S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/115006.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(4374, 275, 'Eu Tu E Ela S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/115007.mp4', 'http://timg.bdta.pro/images/6f52856e456304a9ecb75c56bfd71a9a.jpg'),
(4375, 275, 'Eu Tu E Ela S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/115008.mp4', 'http://timg.bdta.pro/images/944e01e935f9d6f972f9bff9a52f45d2.jpg'),
(4376, 275, 'Eu Tu E Ela S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/115009.mp4', 'http://timg.bdta.pro/images/ef91e673311b7d39ba3c2f9d8b61c31b.jpg'),
(4377, 275, 'Eu Tu E Ela S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/115010.mp4', 'http://timg.bdta.pro/images/4853e16e5756b277ba7222a8f50e6b44.jpg'),
(4378, 275, 'Eu Tu E Ela S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/115011.mp4', 'http://timg.bdta.pro/images/3d3cb004c1256ba45cdf4ade12fef6a8.jpg'),
(4379, 275, 'Eu Tu E Ela S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/115012.mp4', 'http://timg.bdta.pro/images/56746f36b77e545e966750481f78bbce.jpg'),
(4380, 275, 'Eu Tu E Ela S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/115013.mp4', 'http://timg.bdta.pro/images/0c74256554668ffe6cda18ef1eb2aa48.jpg'),
(4381, 275, 'Eu Tu E Ela S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/115014.mp4', 'http://timg.bdta.pro/images/ffa1b3ca2d56c3353ce44c2d07a98a71.jpg'),
(4382, 275, 'Eu Tu E Ela S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/115015.mp4', 'http://timg.bdta.pro/images/2ca88c8845aff2c58002d45ebdef6419.jpg'),
(4383, 276, 'Eu Tu E Ela S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/115016.mp4', 'http://timg.bdta.pro/images/68564288277e553e6a2bfa80b0574a72.jpg'),
(4384, 276, 'Eu Tu E Ela S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/115017.mp4', 'http://timg.bdta.pro/images/f919586e3e91f3c8d46b4b563b42723d.jpg'),
(4385, 276, 'Eu Tu E Ela S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/115018.mp4', 'http://timg.bdta.pro/images/e6e8f7ed524dd66c6a44e8739a64a08a.jpg'),
(4386, 276, 'Eu Tu E Ela S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/115019.mp4', 'http://timg.bdta.pro/images/ecef3f76acf7fed89d3a49104e0b486a.jpg'),
(4387, 276, 'Eu Tu E Ela S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/115020.mp4', 'http://timg.bdta.pro/images/1edffcc96ca7eba6e9c5c7db5e7635f2.jpg'),
(4388, 276, 'Eu Tu E Ela S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/115021.mp4', 'http://timg.bdta.pro/images/7d5aaee08a69a510983b04b2b4f6eb28.jpg'),
(4389, 276, 'Eu Tu E Ela S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/115022.mp4', 'http://timg.bdta.pro/images/d220cdccc3a43597c325c7aa2b5ee8cc.jpg'),
(4390, 276, 'Eu Tu E Ela S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/115023.mp4', 'http://timg.bdta.pro/images/d790cddac8d1ab7fedf486d264ff223a.jpg'),
(4391, 276, 'Eu Tu E Ela S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/115024.mp4', 'http://timg.bdta.pro/images/1c767c50dc97943b3e1ec255b2e6ddca.jpg'),
(4392, 276, 'Eu Tu E Ela S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/115025.mp4', 'http://timg.bdta.pro/images/49b92e02dd76573fdaacd91847c30174.jpg'),
(4393, 277, 'Eu Vi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kGuqHcERMsnHGlVb9NVsqLJtiqM.jpg'),
(4394, 277, 'Eu Vi S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kGuqHcERMsnHGlVb9NVsqLJtiqM.jpg'),
(4395, 277, 'Eu Vi S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kGuqHcERMsnHGlVb9NVsqLJtiqM.jpg'),
(4396, 277, 'Eu Vi S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kGuqHcERMsnHGlVb9NVsqLJtiqM.jpg'),
(4397, 277, 'Eu Vi S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kGuqHcERMsnHGlVb9NVsqLJtiqM.jpg'),
(4398, 277, 'Eu Vi S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kGuqHcERMsnHGlVb9NVsqLJtiqM.jpg'),
(4399, 278, 'Eu Vi S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148464.mp4', 'http://timg.bdta.pro/images/987121198e1451b157284611fb1e03e3.jpg'),
(4400, 278, 'Eu Vi S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148465.mp4', 'http://timg.bdta.pro/images/8a5f6d31b21ce8df4e14326148af8f82.jpg'),
(4401, 278, 'Eu Vi S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148466.mp4', 'http://timg.bdta.pro/images/eeceb36e17a12946855322878d8081a8.jpg'),
(4402, 278, 'Eu Vi S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148467.mp4', 'http://timg.bdta.pro/images/765ef90a014d02646f964523fe6b30e0.jpg'),
(4403, 278, 'Eu Vi S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148468.mp4', 'http://timg.bdta.pro/images/d5f828edb7b2e030a6d1722923d103e7.jpg'),
(4404, 278, 'Eu Vi S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148469.mp4', 'http://timg.bdta.pro/images/2a40b322cb5ab30befc98515153f2795.jpg'),
(4405, 279, 'Eu Vi S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kGuqHcERMsnHGlVb9NVsqLJtiqM.jpg'),
(4406, 279, 'Eu Vi S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kGuqHcERMsnHGlVb9NVsqLJtiqM.jpg'),
(4407, 279, 'Eu Vi S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kGuqHcERMsnHGlVb9NVsqLJtiqM.jpg'),
(4408, 279, 'Eu Vi S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kGuqHcERMsnHGlVb9NVsqLJtiqM.jpg'),
(4409, 279, 'Eu Vi S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kGuqHcERMsnHGlVb9NVsqLJtiqM.jpg'),
(4410, 279, 'Eu Vi S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kGuqHcERMsnHGlVb9NVsqLJtiqM.jpg'),
(4411, 280, 'Friends S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141817.mp4', 'http://timg.bdta.pro/images/ace410fe79260b6f604de17d3f281a17.jpg'),
(4412, 280, 'Friends S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141818.mp4', 'http://timg.bdta.pro/images/a3ec4d99d53485e0370c308608466d85.jpg'),
(4413, 280, 'Friends S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141819.mp4', 'http://timg.bdta.pro/images/bccd4539f750f8557d168399c05f90f0.jpg'),
(4414, 280, 'Friends S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141820.mp4', 'http://timg.bdta.pro/images/5cf14cdad6c35e021e6399dc94ac9add.jpg'),
(4415, 280, 'Friends S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141821.mp4', 'http://timg.bdta.pro/images/acafab7717ee078b77df19d1d1ff98f8.jpg'),
(4416, 280, 'Friends S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141822.mp4', 'http://timg.bdta.pro/images/6a256417ff4fd2e1a7caebd755336ca8.jpg'),
(4417, 280, 'Friends S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141823.mp4', 'http://timg.bdta.pro/images/05d15db4e940f89576579c7dbca3ed09.jpg'),
(4418, 280, 'Friends S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141824.mp4', 'http://timg.bdta.pro/images/3c4e1c1728c7719a7cf2fd07d3bea87d.jpg'),
(4419, 280, 'Friends S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141825.mp4', 'http://timg.bdta.pro/images/7496681070436e9465fecb58225df1b8.jpg'),
(4420, 280, 'Friends S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141826.mp4', 'http://timg.bdta.pro/images/d7791e6473768bc98429f9eaebda7071.jpg'),
(4421, 280, 'Friends S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141827.mp4', 'http://timg.bdta.pro/images/1767e8656f19aa68e8271822f3401505.jpg'),
(4422, 280, 'Friends S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141828.mp4', 'http://timg.bdta.pro/images/874ddf2fb15541db16dcf354282586d7.jpg'),
(4423, 280, 'Friends S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141829.mp4', 'http://timg.bdta.pro/images/662cc72bbeb20a4fe9efdf4a5f3cf78f.jpg'),
(4424, 280, 'Friends S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141830.mp4', 'http://timg.bdta.pro/images/5a49921f393cd216e416893a19340b91.jpg'),
(4425, 280, 'Friends S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141831.mp4', 'http://timg.bdta.pro/images/94a87d9b5bc8afb37d65ca02d5b598e3.jpg'),
(4426, 280, 'Friends S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141832.mp4', 'http://timg.bdta.pro/images/2bdc3555a67498376f57bbec188b30cb.jpg'),
(4427, 280, 'Friends S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141833.mp4', 'http://timg.bdta.pro/images/7012f4b2e4b0c17e29b4841692e9001c.jpg'),
(4428, 280, 'Friends S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141834.mp4', 'http://timg.bdta.pro/images/7e5140cd7ee919308a416366bd737f34.jpg'),
(4429, 280, 'Friends S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141835.mp4', 'http://timg.bdta.pro/images/c559d499461cbe8e1db29ad711a0e6d0.jpg'),
(4430, 280, 'Friends S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141836.mp4', 'http://timg.bdta.pro/images/805948d46a1359ae0dfff80798322f9c.jpg'),
(4431, 280, 'Friends S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/141837.mp4', 'http://timg.bdta.pro/images/10d8cad10e5ce4d3531761ade246cf31.jpg'),
(4432, 280, 'Friends S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/141838.mp4', 'http://timg.bdta.pro/images/5e0a9ddb679d7ca32c53870a2b3c3454.jpg'),
(4433, 280, 'Friends S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/141839.mp4', 'http://timg.bdta.pro/images/6eb088cd8d3eac0f55f4ae85b71e00d9.jpg'),
(4434, 280, 'Friends S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/141840.mp4', 'http://timg.bdta.pro/images/44558782b1edaa9c6300bee8ec0e68e3.jpg'),
(4435, 281, 'Friends S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141841.mp4', 'http://timg.bdta.pro/images/5567e708b262f8bffc4a6f8b86885666.jpg'),
(4436, 281, 'Friends S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141842.mp4', 'http://timg.bdta.pro/images/05e61240c4120ebe396a3ac277ec86e4.jpg'),
(4437, 281, 'Friends S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141843.mp4', 'http://timg.bdta.pro/images/9941388e2b92f1efd7c3b53e8dee753c.jpg'),
(4438, 281, 'Friends S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141844.mp4', 'http://timg.bdta.pro/images/a474455f13957c94197816042fa2b271.jpg'),
(4439, 281, 'Friends S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141845.mp4', 'http://timg.bdta.pro/images/e3e3b096ebacab4f896eb7412b7af496.jpg'),
(4440, 281, 'Friends S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141846.mp4', 'http://timg.bdta.pro/images/7301ae5208a6b7b0c0c5a8f2ed146257.jpg'),
(4441, 281, 'Friends S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141847.mp4', 'http://timg.bdta.pro/images/b10762633a1a842ac5b8f219636cba55.jpg'),
(4442, 281, 'Friends S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141848.mp4', 'http://timg.bdta.pro/images/05d0b1cc53376d199084080c4742adad.jpg'),
(4443, 281, 'Friends S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141849.mp4', 'http://timg.bdta.pro/images/5d09ad3d2ff636099cf5b21f2e5118e7.jpg'),
(4444, 281, 'Friends S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141850.mp4', 'http://timg.bdta.pro/images/83970bf96f2bdfde6ffc2630ea859511.jpg'),
(4445, 281, 'Friends S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141851.mp4', 'http://timg.bdta.pro/images/ff25c588af706998c6376285c6d57949.jpg'),
(4446, 281, 'Friends S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141852.mp4', 'http://timg.bdta.pro/images/22ab32f9e9b11744b623d8e9b7efb1f7.jpg'),
(4447, 281, 'Friends S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141853.mp4', 'http://timg.bdta.pro/images/86e151220b51d98e0caa05adeba04c81.jpg'),
(4448, 281, 'Friends S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141854.mp4', 'http://timg.bdta.pro/images/4b1bbe17835c9c2c84bd5f59d4c014cc.jpg'),
(4449, 281, 'Friends S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141855.mp4', 'http://timg.bdta.pro/images/d3f4daebcb4adbbdb04e785febc4fb67.jpg'),
(4450, 281, 'Friends S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141856.mp4', 'http://timg.bdta.pro/images/646a077b1e155b671ee35d80d178e071.jpg'),
(4451, 281, 'Friends S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141857.mp4', 'http://timg.bdta.pro/images/c8d15807e57fba645c85304f08739d36.jpg'),
(4452, 281, 'Friends S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141858.mp4', 'http://timg.bdta.pro/images/fc242a6abc24bbc61951fe928ebece70.jpg'),
(4453, 281, 'Friends S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141859.mp4', 'http://timg.bdta.pro/images/ea7d67f3f07414e4e1cb314457e31867.jpg'),
(4454, 281, 'Friends S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141860.mp4', 'http://timg.bdta.pro/images/e16177ff433a171401d4a8108c482484.jpg'),
(4455, 281, 'Friends S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/141861.mp4', 'http://timg.bdta.pro/images/549a04d7b660a7334bf4d910da15d406.jpg'),
(4456, 281, 'Friends S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/141862.mp4', 'http://timg.bdta.pro/images/7b79fe63164f3c9ab53cf5b1d256ccc5.jpg'),
(4457, 281, 'Friends S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/141863.mp4', 'http://timg.bdta.pro/images/ebdffce896bf2df7b0082dbabbf6b273.jpg'),
(4458, 281, 'Friends S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/881444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3o85MotMLDmbCPIiIwCfPYzDYgY.jpg'),
(4459, 282, 'Friends S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141864.mp4', 'http://timg.bdta.pro/images/40917c036383c5855fa0daf9d24f0c5e.jpg'),
(4460, 282, 'Friends S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141865.mp4', 'http://timg.bdta.pro/images/729eaa11c02b8d44e60966d803122c3e.jpg'),
(4461, 282, 'Friends S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141866.mp4', 'http://timg.bdta.pro/images/d7c2e0d2e49dceadabdb376761b8bb87.jpg'),
(4462, 282, 'Friends S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141867.mp4', 'http://timg.bdta.pro/images/9b2a8ee4b945970a3cb1cd704efc4637.jpg'),
(4463, 282, 'Friends S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141868.mp4', 'http://timg.bdta.pro/images/c11b853760a60d7192a5aa31db36fc59.jpg'),
(4464, 282, 'Friends S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141869.mp4', 'http://timg.bdta.pro/images/9bbb34dcbd927455e1baec09e2811edd.jpg'),
(4465, 282, 'Friends S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141870.mp4', 'http://timg.bdta.pro/images/a39138998878b25eda4bb63c49417436.jpg'),
(4466, 282, 'Friends S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141871.mp4', 'http://timg.bdta.pro/images/92a89b5bd049da2c7baaea0dccca6322.jpg'),
(4467, 282, 'Friends S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141872.mp4', 'http://timg.bdta.pro/images/cd4d97362af19974cc8d0c783585d438.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(4468, 282, 'Friends S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141873.mp4', 'http://timg.bdta.pro/images/60ca0259cf0c2bf2cdb067f0d0aa3911.jpg'),
(4469, 282, 'Friends S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141874.mp4', 'http://timg.bdta.pro/images/a5af8e4168a4f5ce02b1e924bdc804e4.jpg'),
(4470, 282, 'Friends S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141875.mp4', 'http://timg.bdta.pro/images/9fcf3ac493ccb5ccb8a68dc1e2b16ed3.jpg'),
(4471, 282, 'Friends S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141876.mp4', 'http://timg.bdta.pro/images/88e2c7570917c1ced97df2902dc5454a.jpg'),
(4472, 282, 'Friends S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141877.mp4', 'http://timg.bdta.pro/images/54028cc219e2e0e3605486db3fe43d36.jpg'),
(4473, 282, 'Friends S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141878.mp4', 'http://timg.bdta.pro/images/f874483d3a6445847dd2e932b05ff184.jpg'),
(4474, 282, 'Friends S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141879.mp4', 'http://timg.bdta.pro/images/17e635b6a804474d67df78cedf4b4c87.jpg'),
(4475, 282, 'Friends S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141880.mp4', 'http://timg.bdta.pro/images/76e12d26fed7ada2eca635efcc762d41.jpg'),
(4476, 282, 'Friends S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141881.mp4', 'http://timg.bdta.pro/images/bb89cbacdf4b5befc1f8e4dec172cf48.jpg'),
(4477, 282, 'Friends S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141882.mp4', 'http://timg.bdta.pro/images/a2a492758d3cb3df1a40c8f34e23cd5e.jpg'),
(4478, 282, 'Friends S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141883.mp4', 'http://timg.bdta.pro/images/dc0385e00700915bb112a0e1b6b9207b.jpg'),
(4479, 282, 'Friends S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/141884.mp4', 'http://timg.bdta.pro/images/07547f977a2815419a03be7179329052.jpg'),
(4480, 282, 'Friends S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/141885.mp4', 'http://timg.bdta.pro/images/e8afa911ed63c5f7cddfd0a7130d8d62.jpg'),
(4481, 282, 'Friends S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/141886.mp4', 'http://timg.bdta.pro/images/1e533c5e21693ac1d8f3e924eb7e183b.jpg'),
(4482, 282, 'Friends S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/141887.mp4', 'http://timg.bdta.pro/images/96e00479efeccf6fd5b45bc9f84b5627.jpg'),
(4483, 282, 'Friends S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/141888.mp4', 'http://timg.bdta.pro/images/da5cc7a513660ab57631e8bef1991bcd.jpg'),
(4484, 283, 'Friends S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141889.mp4', 'http://timg.bdta.pro/images/2ff0425614b2820a47311f49869ddf1c.jpg'),
(4485, 283, 'Friends S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141890.mp4', 'http://timg.bdta.pro/images/ef18fca459d53f3a535cf63253e23162.jpg'),
(4486, 283, 'Friends S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141891.mp4', 'http://timg.bdta.pro/images/c7690703f33af349f2f5ce99d59c9539.jpg'),
(4487, 283, 'Friends S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141892.mp4', 'http://timg.bdta.pro/images/b9423dd84855e9e523fe18117aefe39d.jpg'),
(4488, 283, 'Friends S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141893.mp4', 'http://timg.bdta.pro/images/50d22f585b38b32c1edd60a2fdfdc270.jpg'),
(4489, 283, 'Friends S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141894.mp4', 'http://timg.bdta.pro/images/1184fb691c898a568823fe15a2ab5a22.jpg'),
(4490, 283, 'Friends S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141895.mp4', 'http://timg.bdta.pro/images/4386133658db829b7de12dce3c127dfa.jpg'),
(4491, 283, 'Friends S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141896.mp4', 'http://timg.bdta.pro/images/a8da5d7c234f3f7ad6c9dfdc4d44b014.jpg'),
(4492, 283, 'Friends S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141897.mp4', 'http://timg.bdta.pro/images/56d4c71b8d2024bf8197f76ac13718ee.jpg'),
(4493, 283, 'Friends S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141898.mp4', 'http://timg.bdta.pro/images/e09906ce3fdcc89b8b85e393b0192225.jpg'),
(4494, 283, 'Friends S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141899.mp4', 'http://timg.bdta.pro/images/aa7b27b4d24ed090955c7e1a6a0ce43e.jpg'),
(4495, 283, 'Friends S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141900.mp4', 'http://timg.bdta.pro/images/441cbc56b02c49e9c6161b13102c14ca.jpg'),
(4496, 283, 'Friends S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141901.mp4', 'http://timg.bdta.pro/images/59b7e93f6b804b21c70eefd9d4e32f84.jpg'),
(4497, 283, 'Friends S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141902.mp4', 'http://timg.bdta.pro/images/caaccf25bb78f6d1525c44aafcb94c58.jpg'),
(4498, 283, 'Friends S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141903.mp4', 'http://timg.bdta.pro/images/38be5b501b3d1c510c08393257f3d56f.jpg'),
(4499, 283, 'Friends S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141904.mp4', 'http://timg.bdta.pro/images/22a020b8351c00f0c28e2faa96b9acb2.jpg'),
(4500, 283, 'Friends S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141905.mp4', 'http://timg.bdta.pro/images/d2ceaf377bbb7ad021713f05edd548d7.jpg'),
(4501, 283, 'Friends S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141906.mp4', 'http://timg.bdta.pro/images/4c0ccda92ce55bad092648208587ab75.jpg'),
(4502, 283, 'Friends S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141907.mp4', 'http://timg.bdta.pro/images/371d2b28c6fbed061e4becd3d03b8527.jpg'),
(4503, 283, 'Friends S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141908.mp4', 'http://timg.bdta.pro/images/e6cf5678d5e29d9afca131443fffed64.jpg'),
(4504, 283, 'Friends S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/141909.mp4', 'http://timg.bdta.pro/images/e77d42c7df51bee79c1513121bef55c4.jpg'),
(4505, 283, 'Friends S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/141910.mp4', 'http://timg.bdta.pro/images/c0f2534af66fa0b18ba6ffb276b39491.jpg'),
(4506, 283, 'Friends S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/141911.mp4', 'http://timg.bdta.pro/images/a368d41baad2daeee18c3e30be798f72.jpg'),
(4507, 283, 'Friends S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/141912.mp4', 'http://timg.bdta.pro/images/386ca8d18ca1f8f3e3ac975b8d9758de.jpg'),
(4508, 284, 'Friends S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141913.mp4', 'http://timg.bdta.pro/images/620614d6adeb3491ce412d839c5eb673.jpg'),
(4509, 284, 'Friends S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141914.mp4', 'http://timg.bdta.pro/images/a3c876b2e92b805cb8662e682b247e3e.jpg'),
(4510, 284, 'Friends S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141915.mp4', 'http://timg.bdta.pro/images/6094751bc8885e295acb55e55fa8b0d3.jpg'),
(4511, 284, 'Friends S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141916.mp4', 'http://timg.bdta.pro/images/aea118e7de5fb2821d69ab63eadc9152.jpg'),
(4512, 284, 'Friends S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141917.mp4', 'http://timg.bdta.pro/images/86588975fdd59bad3e5abb87a5af7d4e.jpg'),
(4513, 284, 'Friends S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141918.mp4', 'http://timg.bdta.pro/images/b61c56551ed4ce5bec5c115cdc1e6812.jpg'),
(4514, 284, 'Friends S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141919.mp4', 'http://timg.bdta.pro/images/3ee7b39d08da78c3f341be1fb9b06c7d.jpg'),
(4515, 284, 'Friends S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141920.mp4', 'http://timg.bdta.pro/images/c3097bf2909b4cc6b3158e13e1940837.jpg'),
(4516, 284, 'Friends S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141921.mp4', 'http://timg.bdta.pro/images/72e3a7560b43b64a60bc4e5b86026ef8.jpg'),
(4517, 284, 'Friends S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141922.mp4', 'http://timg.bdta.pro/images/72bd04078d4c9e3890cdc0556fc9e8bf.jpg'),
(4518, 284, 'Friends S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141923.mp4', 'http://timg.bdta.pro/images/4b007e1d0af99d1c8491bbb61f21a3d1.jpg'),
(4519, 284, 'Friends S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141924.mp4', 'http://timg.bdta.pro/images/5877e50a4d3d07c88620092c5ee70d4e.jpg'),
(4520, 284, 'Friends S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141925.mp4', 'http://timg.bdta.pro/images/d141e098e109bcef859b3fea2aaf2c27.jpg'),
(4521, 284, 'Friends S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141926.mp4', 'http://timg.bdta.pro/images/ca0596b1fa0336af0cd00c6b94463b63.jpg'),
(4522, 284, 'Friends S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141927.mp4', 'http://timg.bdta.pro/images/e077bf0adb73a2e076d6d25e35cb4583.jpg'),
(4523, 284, 'Friends S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141928.mp4', 'http://timg.bdta.pro/images/c85670c4b3527921cc515d320fcb2f52.jpg'),
(4524, 284, 'Friends S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141929.mp4', 'http://timg.bdta.pro/images/897fc059c46175358b1f75260719600a.jpg'),
(4525, 284, 'Friends S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141930.mp4', 'http://timg.bdta.pro/images/7e37b43ecb7ed285a12346cb2a7488a3.jpg'),
(4526, 284, 'Friends S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141931.mp4', 'http://timg.bdta.pro/images/7bbf847d4a8ebcc9e8388227fa495c1e.jpg'),
(4527, 284, 'Friends S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141932.mp4', 'http://timg.bdta.pro/images/3fbb360fb6f80e45bc105236a402e6e7.jpg'),
(4528, 284, 'Friends S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/141933.mp4', 'http://timg.bdta.pro/images/85ef69233836af9ebc577b3bade9ae70.jpg'),
(4529, 284, 'Friends S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/141934.mp4', 'http://timg.bdta.pro/images/c94535d2dae1f1440ebbabb9c5282e5d.jpg'),
(4530, 284, 'Friends S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/141935.mp4', 'http://timg.bdta.pro/images/b910b57696c30924ab676d9cbfbf883d.jpg'),
(4531, 284, 'Friends S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/141936.mp4', 'http://timg.bdta.pro/images/d80ba025164556a7ac44b734a5ac74c0.jpg'),
(4532, 285, 'Friends S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141937.mp4', 'http://timg.bdta.pro/images/4a0ad7ad22e9e57eddf40ca623a62e5f.jpg'),
(4533, 285, 'Friends S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141938.mp4', 'http://timg.bdta.pro/images/3973a7ec8026ae14cddc40679ee80c8c.jpg'),
(4534, 285, 'Friends S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141939.mp4', 'http://timg.bdta.pro/images/f5062685dc55a8dc9c64ada6e0be5021.jpg'),
(4535, 285, 'Friends S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141940.mp4', 'http://timg.bdta.pro/images/f3958192ba4fe3c3e002f5fb9cfc4191.jpg'),
(4536, 285, 'Friends S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141941.mp4', 'http://timg.bdta.pro/images/1f52302bacfe8df263aa9ee55475c9e5.jpg'),
(4537, 285, 'Friends S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141942.mp4', 'http://timg.bdta.pro/images/ff470555e4ca2438d3f59c132ec3aa23.jpg'),
(4538, 285, 'Friends S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141943.mp4', 'http://timg.bdta.pro/images/7668d024161435996057be8456382ede.jpg'),
(4539, 285, 'Friends S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141944.mp4', 'http://timg.bdta.pro/images/aa5c0352c3af9468bf7169c81aee5b01.jpg'),
(4540, 285, 'Friends S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141945.mp4', 'http://timg.bdta.pro/images/821d1a3c69c3ba67115bc03cd7418f57.jpg'),
(4541, 285, 'Friends S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141946.mp4', 'http://timg.bdta.pro/images/80450a1096299797c2280059c56729c4.jpg'),
(4542, 285, 'Friends S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141947.mp4', 'http://timg.bdta.pro/images/5fc2206bdda6082979e4c6ed8ebac180.jpg'),
(4543, 285, 'Friends S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141948.mp4', 'http://timg.bdta.pro/images/ee1168767c60a8c4bc1e6fd248ff01b1.jpg'),
(4544, 285, 'Friends S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141949.mp4', 'http://timg.bdta.pro/images/83df582e09bcdbf0f414ef0ab43dda2e.jpg'),
(4545, 285, 'Friends S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141950.mp4', 'http://timg.bdta.pro/images/82d4b01f225d3df2ab7e4d6f2afaa725.jpg'),
(4546, 285, 'Friends S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141951.mp4', 'http://timg.bdta.pro/images/9ecd27ee390fcee5bb14c1f034777a57.jpg'),
(4547, 285, 'Friends S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141952.mp4', 'http://timg.bdta.pro/images/e3537815dd542dd5cb01067890201760.jpg'),
(4548, 285, 'Friends S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141953.mp4', 'http://timg.bdta.pro/images/8242cb59c40e43fbca0f2d1ae9a5d5e1.jpg'),
(4549, 285, 'Friends S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141954.mp4', 'http://timg.bdta.pro/images/95752e4564d5cd92f943577cfce73a61.jpg'),
(4550, 285, 'Friends S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141955.mp4', 'http://timg.bdta.pro/images/f85cf9b5e620c140e6516e024573e3bb.jpg'),
(4551, 285, 'Friends S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141956.mp4', 'http://timg.bdta.pro/images/68052a5e2e30c6bdb5dd5f147b7dea93.jpg'),
(4552, 285, 'Friends S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/141957.mp4', 'http://timg.bdta.pro/images/00b2c11c9a7ab274ecbae2d37b4bc1fa.jpg'),
(4553, 285, 'Friends S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/141958.mp4', 'http://timg.bdta.pro/images/bb40d4adca869b22e238e132574d7dce.jpg'),
(4554, 285, 'Friends S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/141959.mp4', 'http://timg.bdta.pro/images/e531befb211334c62eb9adb1db3f5775.jpg'),
(4555, 285, 'Friends S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/141960.mp4', 'http://timg.bdta.pro/images/b1a085fca9f9240e0dd69507bd15cc82.jpg'),
(4556, 285, 'Friends S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/141961.mp4', 'http://timg.bdta.pro/images/cbe6d2fd5cfc497ad4d98c021b97b966.jpg'),
(4557, 286, 'Friends S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141962.mp4', 'http://timg.bdta.pro/images/1a5f9d0fc572cc098931eb2f2d809c2e.jpg'),
(4558, 286, 'Friends S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141963.mp4', 'http://timg.bdta.pro/images/d6e3c948a85fa2d62709f6e5fca84c9e.jpg'),
(4559, 286, 'Friends S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141964.mp4', 'http://timg.bdta.pro/images/158b872b989e51b25d75576204bde263.jpg'),
(4560, 286, 'Friends S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141965.mp4', 'http://timg.bdta.pro/images/f8cca4b38f04f5473b356bae2402633e.jpg'),
(4561, 286, 'Friends S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141966.mp4', 'http://timg.bdta.pro/images/54272d841754686f4f260121b6961f51.jpg'),
(4562, 286, 'Friends S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141967.mp4', 'http://timg.bdta.pro/images/2d27517d83b76d18d81b03181ee3f29a.jpg'),
(4563, 286, 'Friends S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141968.mp4', 'http://timg.bdta.pro/images/a5baac76a55df82e085662d776920255.jpg'),
(4564, 286, 'Friends S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141969.mp4', 'http://timg.bdta.pro/images/fed62d779ba577ad8577db08db2cb09c.jpg'),
(4565, 286, 'Friends S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141970.mp4', 'http://timg.bdta.pro/images/7d1897373e2108a9600ecf10ea650194.jpg'),
(4566, 286, 'Friends S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141971.mp4', 'http://timg.bdta.pro/images/f027bc84b74eca504d81d45f79a884ba.jpg'),
(4567, 286, 'Friends S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141972.mp4', 'http://timg.bdta.pro/images/79f5a1860ed1dfdef66990df5f7b1fec.jpg'),
(4568, 286, 'Friends S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141973.mp4', 'http://timg.bdta.pro/images/5c4bf476c8cc6e9224fab26528ef3aa9.jpg'),
(4569, 286, 'Friends S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141974.mp4', 'http://timg.bdta.pro/images/562db491c03c19f250b5c1fc4597411f.jpg'),
(4570, 286, 'Friends S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141975.mp4', 'http://timg.bdta.pro/images/0077bd7d2108eaff236624435f6647c2.jpg'),
(4571, 286, 'Friends S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141976.mp4', 'http://timg.bdta.pro/images/f5a777fab0cc375f657157f7c0e7fbad.jpg'),
(4572, 286, 'Friends S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141977.mp4', 'http://timg.bdta.pro/images/6a28f1e192111f8ef367d2fc519e0352.jpg'),
(4573, 286, 'Friends S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141978.mp4', 'http://timg.bdta.pro/images/dba3f2ad48b5a80f160a9c53670d263a.jpg'),
(4574, 286, 'Friends S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141979.mp4', 'http://timg.bdta.pro/images/75b3fd14dd81f8bffb2741960429c733.jpg'),
(4575, 286, 'Friends S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141980.mp4', 'http://timg.bdta.pro/images/0c35705bac40b2a7732bb534877c6a67.jpg'),
(4576, 286, 'Friends S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141981.mp4', 'http://timg.bdta.pro/images/86bb3d879bcdf42fab9b190162fb2999.jpg'),
(4577, 286, 'Friends S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/141982.mp4', 'http://timg.bdta.pro/images/be1a61fbbb8ce949b48b6ace3ac7a56e.jpg'),
(4578, 286, 'Friends S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/141983.mp4', 'http://timg.bdta.pro/images/425b6d6bbc1db6152a298fb753cbb3e9.jpg'),
(4579, 286, 'Friends S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/141984.mp4', 'http://timg.bdta.pro/images/cfd0f6e731dbc8bf747f798ddab636a1.jpg'),
(4580, 286, 'Friends S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/141985.mp4', 'http://timg.bdta.pro/images/405773f0798cb0a33b85872e100535cd.jpg'),
(4581, 287, 'Friends S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141986.mp4', 'http://timg.bdta.pro/images/db11102ada01dd93b160f1888c6ad638.jpg'),
(4582, 287, 'Friends S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141987.mp4', 'http://timg.bdta.pro/images/955cc9241d0dc560395b7bb8055128ad.jpg'),
(4583, 287, 'Friends S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141988.mp4', 'http://timg.bdta.pro/images/0d0188506871346b6bf03f4234db954b.jpg'),
(4584, 287, 'Friends S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141989.mp4', 'http://timg.bdta.pro/images/bb33c61ad7dd954a3dee99f196df9fbe.jpg'),
(4585, 287, 'Friends S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141990.mp4', 'http://timg.bdta.pro/images/24e14643da2c3bd8188ba3aab04106c5.jpg'),
(4586, 287, 'Friends S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141991.mp4', 'http://timg.bdta.pro/images/b98d14fc5dc52faf8a4bc033f78ae5a1.jpg'),
(4587, 287, 'Friends S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141992.mp4', 'http://timg.bdta.pro/images/47aaaa3ce651f1ed2e79bff2241aa76f.jpg'),
(4588, 287, 'Friends S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141993.mp4', 'http://timg.bdta.pro/images/48803e7ad6be26f8e2cf01adf0e18be8.jpg'),
(4589, 287, 'Friends S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141994.mp4', 'http://timg.bdta.pro/images/ee00a8388ae6071dd3f1468bf5e137ee.jpg'),
(4590, 287, 'Friends S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141995.mp4', 'http://timg.bdta.pro/images/3bd7987c2acab595e913d0fa27431916.jpg'),
(4591, 287, 'Friends S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141996.mp4', 'http://timg.bdta.pro/images/b35c7a72b918819a48ba8bf97857f6c5.jpg'),
(4592, 287, 'Friends S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141997.mp4', 'http://timg.bdta.pro/images/2c91c04055a14d5e5da7cdfda6be3e18.jpg'),
(4593, 287, 'Friends S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141998.mp4', 'http://timg.bdta.pro/images/ca5cb88d5c36b851caa55af1e9f18f69.jpg'),
(4594, 287, 'Friends S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141999.mp4', 'http://timg.bdta.pro/images/decaf30a757ea79533ad1ef7f5afbf65.jpg'),
(4595, 287, 'Friends S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142000.mp4', 'http://timg.bdta.pro/images/3fe3dfe7034147da3c78e711248909a9.jpg'),
(4596, 287, 'Friends S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/142001.mp4', 'http://timg.bdta.pro/images/5de6f20f62a0a2332a977bc8f4313499.jpg'),
(4597, 287, 'Friends S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/142002.mp4', 'http://timg.bdta.pro/images/844f8936014dabb21b9fe00595e3e8bd.jpg'),
(4598, 287, 'Friends S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/142003.mp4', 'http://timg.bdta.pro/images/d4164497a63d62c14885ebec8ee2c351.jpg'),
(4599, 287, 'Friends S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/142004.mp4', 'http://timg.bdta.pro/images/bab3e24d612b7b0426e601d504e7d314.jpg'),
(4600, 287, 'Friends S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/142005.mp4', 'http://timg.bdta.pro/images/77276784ffc6a12707dae1d67838121a.jpg'),
(4601, 287, 'Friends S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/142006.mp4', 'http://timg.bdta.pro/images/dd9f1989b7d6bc6f636075c208db0c6b.jpg'),
(4602, 287, 'Friends S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/142007.mp4', 'http://timg.bdta.pro/images/9d098da3482698c829eb60246b3c811f.jpg'),
(4603, 287, 'Friends S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/142008.mp4', 'http://timg.bdta.pro/images/f8e3c2931c0ef11362914daafc78a450.jpg'),
(4604, 287, 'Friends S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/142009.mp4', 'http://timg.bdta.pro/images/066f21c933fc87be9ba349a2412832a3.jpg'),
(4605, 288, 'Friends S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142010.mp4', 'http://timg.bdta.pro/images/686b23275a1745d308deec158c2f69e2.jpg'),
(4606, 288, 'Friends S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142011.mp4', 'http://timg.bdta.pro/images/8d49613a25e9f3824963b2480c4de95a.jpg'),
(4607, 288, 'Friends S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142012.mp4', 'http://timg.bdta.pro/images/d5d8a6753aaaf2c85614922127375297.jpg'),
(4608, 288, 'Friends S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142013.mp4', 'http://timg.bdta.pro/images/785ec40d73c655c0add33d0d20f26afe.jpg'),
(4609, 288, 'Friends S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142014.mp4', 'http://timg.bdta.pro/images/8a74811fcafa0f27475892cc4fc98735.jpg'),
(4610, 288, 'Friends S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142015.mp4', 'http://timg.bdta.pro/images/80a226ebc5985b43d5a084aae7abe677.jpg'),
(4611, 288, 'Friends S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142016.mp4', 'http://timg.bdta.pro/images/a9dec0ab8762ceca935d58b33ca34071.jpg'),
(4612, 288, 'Friends S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142017.mp4', 'http://timg.bdta.pro/images/3755a80d74ea80fbc642bd9b7e707524.jpg'),
(4613, 288, 'Friends S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142018.mp4', 'http://timg.bdta.pro/images/2e7680820bfad642805525b246a58c29.jpg'),
(4614, 288, 'Friends S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142019.mp4', 'http://timg.bdta.pro/images/ea9d23b94a5414d227853cef286ed6f9.jpg'),
(4615, 288, 'Friends S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142020.mp4', 'http://timg.bdta.pro/images/6da72001fe390f20c3ed512d3ccaae1f.jpg'),
(4616, 288, 'Friends S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142021.mp4', 'http://timg.bdta.pro/images/51ebe4514ff6572df97e4cd24f8295e9.jpg'),
(4617, 288, 'Friends S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142022.mp4', 'http://timg.bdta.pro/images/f721bd5ec4f231c3468cfd4625c6d6b2.jpg'),
(4618, 288, 'Friends S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/142023.mp4', 'http://timg.bdta.pro/images/a390008e2ea3e1a9c5257efe8a00bac7.jpg'),
(4619, 288, 'Friends S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142024.mp4', 'http://timg.bdta.pro/images/c4c924ac115242f565d113a4bcc73fe6.jpg'),
(4620, 288, 'Friends S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/142025.mp4', 'http://timg.bdta.pro/images/22af655ad8381b37396a9c8d1f67b7c9.jpg'),
(4621, 288, 'Friends S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/142026.mp4', 'http://timg.bdta.pro/images/41230b5e18ad78445ec9d298b608336d.jpg'),
(4622, 288, 'Friends S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/142027.mp4', 'http://timg.bdta.pro/images/967b2c432714e70c2d9dcf6ed7070eff.jpg'),
(4623, 288, 'Friends S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/142028.mp4', 'http://timg.bdta.pro/images/ca994cefe859e9dd7430ab734a3948c1.jpg'),
(4624, 288, 'Friends S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/142029.mp4', 'http://timg.bdta.pro/images/6b857da5125d679147f4213678a93bc6.jpg'),
(4625, 288, 'Friends S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/142030.mp4', 'http://timg.bdta.pro/images/240d3dced26993083a18bd7b14afc169.jpg'),
(4626, 288, 'Friends S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/142031.mp4', 'http://timg.bdta.pro/images/c3603dd7d480581e9ba8e03bc1afc181.jpg'),
(4627, 288, 'Friends S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/142032.mp4', 'http://timg.bdta.pro/images/36cf179ee742a74a01f1201d8c31ac2d.jpg'),
(4628, 289, 'Friends S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f496cm9enuEsZkSPzCwnTESEK5s.jpg'),
(4629, 289, 'Friends S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f496cm9enuEsZkSPzCwnTESEK5s.jpg'),
(4630, 289, 'Friends S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f496cm9enuEsZkSPzCwnTESEK5s.jpg'),
(4631, 289, 'Friends S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f496cm9enuEsZkSPzCwnTESEK5s.jpg'),
(4632, 289, 'Friends S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f496cm9enuEsZkSPzCwnTESEK5s.jpg'),
(4633, 289, 'Friends S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f496cm9enuEsZkSPzCwnTESEK5s.jpg'),
(4634, 289, 'Friends S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f496cm9enuEsZkSPzCwnTESEK5s.jpg'),
(4635, 289, 'Friends S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f496cm9enuEsZkSPzCwnTESEK5s.jpg'),
(4636, 289, 'Friends S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f496cm9enuEsZkSPzCwnTESEK5s.jpg'),
(4637, 289, 'Friends S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f496cm9enuEsZkSPzCwnTESEK5s.jpg'),
(4638, 289, 'Friends S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f496cm9enuEsZkSPzCwnTESEK5s.jpg'),
(4639, 289, 'Friends S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f496cm9enuEsZkSPzCwnTESEK5s.jpg'),
(4640, 289, 'Friends S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f496cm9enuEsZkSPzCwnTESEK5s.jpg'),
(4641, 289, 'Friends S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/142046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f496cm9enuEsZkSPzCwnTESEK5s.jpg'),
(4642, 289, 'Friends S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f496cm9enuEsZkSPzCwnTESEK5s.jpg'),
(4643, 289, 'Friends S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/142048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f496cm9enuEsZkSPzCwnTESEK5s.jpg'),
(4644, 289, 'Friends S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/142049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f496cm9enuEsZkSPzCwnTESEK5s.jpg'),
(4645, 290, 'Fronteiras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132094.mp4', 'http://timg.bdta.pro/images/a5c73f863b45722f369b4e4725a88c44.jpg'),
(4646, 290, 'Fronteiras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132095.mp4', 'http://timg.bdta.pro/images/dbee27b012f696273a963b5cc8b48d0b.jpg'),
(4647, 290, 'Fronteiras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132096.mp4', 'http://timg.bdta.pro/images/2aec4b33d39f4f5bbb327e2b6061890e.jpg'),
(4648, 290, 'Fronteiras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132097.mp4', 'http://timg.bdta.pro/images/066a64cd2627a81cdf3f07ae4b8758a8.jpg'),
(4649, 290, 'Fronteiras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132098.mp4', 'http://timg.bdta.pro/images/8f21c247d63f710534ff30b2b0dc9df7.jpg'),
(4650, 290, 'Fronteiras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132099.mp4', 'http://timg.bdta.pro/images/fa978a967e3fc04557dfb2d40ec3b5be.jpg'),
(4651, 290, 'Fronteiras S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132100.mp4', 'http://timg.bdta.pro/images/9922f089616d827adbf45727e55e6880.jpg'),
(4652, 290, 'Fronteiras S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132101.mp4', 'http://timg.bdta.pro/images/3508c2e32d83cde11e0f810ee3756a0f.jpg'),
(4653, 290, 'Fronteiras S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132102.mp4', 'http://timg.bdta.pro/images/fddbcc0873de416b10eda4a737df770a.jpg'),
(4654, 290, 'Fronteiras S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132103.mp4', 'http://timg.bdta.pro/images/316bb7e8e80198950ac69e588cc60705.jpg'),
(4655, 290, 'Fronteiras S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132104.mp4', 'http://timg.bdta.pro/images/fa494d57ec1461d49aa81868012a0356.jpg'),
(4656, 290, 'Fronteiras S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132105.mp4', 'http://timg.bdta.pro/images/379067be180031398c2e7f1d7311cc2d.jpg'),
(4657, 290, 'Fronteiras S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132106.mp4', 'http://timg.bdta.pro/images/27ad553888aa4478099f766e9b7f540c.jpg'),
(4658, 290, 'Fronteiras S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132107.mp4', 'http://timg.bdta.pro/images/97cae7a25a2ff9873823b08709c7894f.jpg'),
(4659, 290, 'Fronteiras S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132108.mp4', 'http://timg.bdta.pro/images/f1a49ca3b67b66dd9a05daee35cf4d2a.jpg'),
(4660, 290, 'Fronteiras S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132109.mp4', 'http://timg.bdta.pro/images/d481b07d06d086c0ea0c89804338e506.jpg'),
(4661, 290, 'Fronteiras S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132110.mp4', 'http://timg.bdta.pro/images/ba6473b2751fe410aa5a788585edef39.jpg'),
(4662, 290, 'Fronteiras S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132111.mp4', 'http://timg.bdta.pro/images/37920c100fd202c5251a5c6fc0ccb40f.jpg'),
(4663, 290, 'Fronteiras S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132112.mp4', 'http://timg.bdta.pro/images/8d4ab3fb724108ae04acfc713d257f41.jpg'),
(4664, 290, 'Fronteiras S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132113.mp4', 'http://timg.bdta.pro/images/3991876535b7b9bf959145e348362f69.jpg'),
(4665, 291, 'Fronteiras S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132114.mp4', 'http://timg.bdta.pro/images/95188ec0e85ae422e98e651dda66eb7a.jpg'),
(4666, 291, 'Fronteiras S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132115.mp4', 'http://timg.bdta.pro/images/1ded800e44f156f90fa159220baff4e1.jpg'),
(4667, 291, 'Fronteiras S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132116.mp4', 'http://timg.bdta.pro/images/548ddda1167f1a1a4b01978283415254.jpg'),
(4668, 291, 'Fronteiras S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132117.mp4', 'http://timg.bdta.pro/images/524fb04fb050e047aca653efc038acbe.jpg'),
(4669, 291, 'Fronteiras S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132118.mp4', 'http://timg.bdta.pro/images/f89a5a684427be1cec5872ec42c7add4.jpg'),
(4670, 291, 'Fronteiras S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132119.mp4', 'http://timg.bdta.pro/images/7153ce6f5c10ad40f7a2fc3da9f586ec.jpg'),
(4671, 291, 'Fronteiras S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132120.mp4', 'http://timg.bdta.pro/images/821dabd9fc3ace45d5e3bd9128aa2f5c.jpg'),
(4672, 291, 'Fronteiras S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132121.mp4', 'http://timg.bdta.pro/images/55d4a86717d3fb02ea067d60cb60dc81.jpg'),
(4673, 291, 'Fronteiras S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132122.mp4', 'http://timg.bdta.pro/images/33a0588ac9d92ae9163dff4e313b8426.jpg'),
(4674, 291, 'Fronteiras S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132123.mp4', 'http://timg.bdta.pro/images/50fa4509db880afc00f9032195c2df1d.jpg'),
(4675, 291, 'Fronteiras S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132124.mp4', 'http://timg.bdta.pro/images/7bead85a830a851872a6ade8d822fdde.jpg'),
(4676, 291, 'Fronteiras S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132125.mp4', 'http://timg.bdta.pro/images/c8f26fe904186e79e21c105735db9a6a.jpg'),
(4677, 291, 'Fronteiras S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132126.mp4', 'http://timg.bdta.pro/images/68f3a62d75469045f63dabf01a37256b.jpg'),
(4678, 291, 'Fronteiras S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132127.mp4', 'http://timg.bdta.pro/images/e5b4bf49c292af2f5c9437237f80a567.jpg'),
(4679, 291, 'Fronteiras S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132128.mp4', 'http://timg.bdta.pro/images/3c9c1d5a3c21acdd1b451cb012f097a1.jpg'),
(4680, 291, 'Fronteiras S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132129.mp4', 'http://timg.bdta.pro/images/b5d2bf1b73a70f381d77b77eee4a09f8.jpg'),
(4681, 291, 'Fronteiras S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132130.mp4', 'http://timg.bdta.pro/images/d8c786423ba25eec282160864d8d83b2.jpg'),
(4682, 291, 'Fronteiras S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132131.mp4', 'http://timg.bdta.pro/images/2038f2b75c9d3a36796a0d32556c4ed1.jpg'),
(4683, 291, 'Fronteiras S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132132.mp4', 'http://timg.bdta.pro/images/c107de01ff4d5937531b90ec69d8a76b.jpg'),
(4684, 291, 'Fronteiras S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132133.mp4', 'http://timg.bdta.pro/images/aa5333d0bac6a87c5a7926440a825803.jpg'),
(4685, 291, 'Fronteiras S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132134.mp4', 'http://timg.bdta.pro/images/0f3cb41ade899be9750509787d9e445a.jpg'),
(4686, 291, 'Fronteiras S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132135.mp4', 'http://timg.bdta.pro/images/88bb899a2b954deeee2aeb2b2c5d2d0e.jpg'),
(4687, 291, 'Fronteiras S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/132136.mp4', 'http://timg.bdta.pro/images/cb877847cab08f92660261c9120bf378.jpg'),
(4688, 292, 'Fronteiras S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132137.mp4', 'http://timg.bdta.pro/images/928dfec09018a7983a6f6b8e2cdf27d7.jpg'),
(4689, 292, 'Fronteiras S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132138.mp4', 'http://timg.bdta.pro/images/3aa4002dd014ff31c7edd37e6487a3b2.jpg'),
(4690, 292, 'Fronteiras S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132139.mp4', 'http://timg.bdta.pro/images/64fb8ed8b9746c0e53148060a98b2108.jpg'),
(4691, 292, 'Fronteiras S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132140.mp4', 'http://timg.bdta.pro/images/179ce2c952519e32673d3d41458d37e4.jpg'),
(4692, 292, 'Fronteiras S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132141.mp4', 'http://timg.bdta.pro/images/a6cc865caecca93c112eba1d6e624794.jpg'),
(4693, 292, 'Fronteiras S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132142.mp4', 'http://timg.bdta.pro/images/37ba8d84f9ec39f1453598baa79efea7.jpg'),
(4694, 292, 'Fronteiras S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132143.mp4', 'http://timg.bdta.pro/images/3c499b93c0350e41569b4d08112eb10d.jpg'),
(4695, 292, 'Fronteiras S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132144.mp4', 'http://timg.bdta.pro/images/942c47a9c4ce635208e8c49286c2a697.jpg'),
(4696, 292, 'Fronteiras S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132145.mp4', 'http://timg.bdta.pro/images/7183669ba72fb26d19f5f9f28bb223c6.jpg'),
(4697, 292, 'Fronteiras S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132146.mp4', 'http://timg.bdta.pro/images/7d21221f14e50411b346309f5edcef5b.jpg'),
(4698, 292, 'Fronteiras S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132147.mp4', 'http://timg.bdta.pro/images/53dc6a1894004b0667e4369d739cdb57.jpg'),
(4699, 292, 'Fronteiras S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132148.mp4', 'http://timg.bdta.pro/images/87765fddd5386f96944a0c8230d1698e.jpg'),
(4700, 292, 'Fronteiras S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132149.mp4', 'http://timg.bdta.pro/images/33630ce29c66da9ac4fe6bc8e7f95b5b.jpg'),
(4701, 292, 'Fronteiras S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132150.mp4', 'http://timg.bdta.pro/images/0c727871f194fe636c4a058819b74f32.jpg'),
(4702, 292, 'Fronteiras S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132151.mp4', 'http://timg.bdta.pro/images/d572d7b62ac477a201c52dbe67a9099d.jpg'),
(4703, 292, 'Fronteiras S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132152.mp4', 'http://timg.bdta.pro/images/45195e72930ff4f2a7f52361562c0687.jpg'),
(4704, 292, 'Fronteiras S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132153.mp4', 'http://timg.bdta.pro/images/c125f9be0994f0a13dc4ca817a4be3f2.jpg'),
(4705, 292, 'Fronteiras S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132154.mp4', 'http://timg.bdta.pro/images/3a2863277da391559f2c9d735f79a99f.jpg'),
(4706, 292, 'Fronteiras S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132155.mp4', 'http://timg.bdta.pro/images/3a47618890a46f65556bbf2d481a8efa.jpg'),
(4707, 292, 'Fronteiras S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132156.mp4', 'http://timg.bdta.pro/images/9bc9bd5361210468eb7b1d70cf5c1460.jpg'),
(4708, 292, 'Fronteiras S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132157.mp4', 'http://timg.bdta.pro/images/fb4b398fe0d964248b4135d109bf8448.jpg'),
(4709, 292, 'Fronteiras S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132158.mp4', 'http://timg.bdta.pro/images/87866a1191eba4c0f9542303d1b58b2c.jpg'),
(4710, 293, 'Fronteiras S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132159.mp4', 'http://timg.bdta.pro/images/24598462bde0521cf8d5569f21f20d63.jpg'),
(4711, 293, 'Fronteiras S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132160.mp4', 'http://timg.bdta.pro/images/e3abcf7d9ecc89b6eb5c5686761faef2.jpg'),
(4712, 293, 'Fronteiras S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132161.mp4', 'http://timg.bdta.pro/images/76a9c04db65bb4ec6e50961cfdd814e8.jpg'),
(4713, 293, 'Fronteiras S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132162.mp4', 'http://timg.bdta.pro/images/bf3c70f220f6342dbba8b511b2bb9f33.jpg'),
(4714, 293, 'Fronteiras S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132163.mp4', 'http://timg.bdta.pro/images/cb734bed136789af2149ae25184df5cc.jpg'),
(4715, 293, 'Fronteiras S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132164.mp4', 'http://timg.bdta.pro/images/550b97024cc3cdb993b4f6b1c5c2f89c.jpg'),
(4716, 293, 'Fronteiras S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132165.mp4', 'http://timg.bdta.pro/images/a64ce73d508a612c3b74035ae8728cad.jpg'),
(4717, 293, 'Fronteiras S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132166.mp4', 'http://timg.bdta.pro/images/b3d5e9119ab5ca3771c0066d90185977.jpg'),
(4718, 293, 'Fronteiras S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132167.mp4', 'http://timg.bdta.pro/images/784d7fa8774e4ce830f3cfbf8de666f0.jpg'),
(4719, 293, 'Fronteiras S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132168.mp4', 'http://timg.bdta.pro/images/556b3b9ee9fae5f56c4105252ccfecff.jpg'),
(4720, 293, 'Fronteiras S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132169.mp4', 'http://timg.bdta.pro/images/78b3db673dcce81ac162fc9148fe1173.jpg'),
(4721, 293, 'Fronteiras S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132170.mp4', 'http://timg.bdta.pro/images/438673397ea6c00404d59bcdc2b35225.jpg'),
(4722, 293, 'Fronteiras S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132171.mp4', 'http://timg.bdta.pro/images/1b1f5d2e917537afdeace42e17165562.jpg'),
(4723, 293, 'Fronteiras S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132172.mp4', 'http://timg.bdta.pro/images/9874c558b13bc256726bc6f6b88abd14.jpg'),
(4724, 293, 'Fronteiras S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132173.mp4', 'http://timg.bdta.pro/images/b844282478f6c7f2b6064c707a4d1908.jpg'),
(4725, 293, 'Fronteiras S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132174.mp4', 'http://timg.bdta.pro/images/8b48b38ffacf62752e707fc32d082bf8.jpg'),
(4726, 293, 'Fronteiras S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132175.mp4', 'http://timg.bdta.pro/images/34290d43850e2b0c05326654cf4c3172.jpg'),
(4727, 293, 'Fronteiras S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132176.mp4', 'http://timg.bdta.pro/images/f5bb2dabc3ee3efde3afe5554fa2ea63.jpg'),
(4728, 293, 'Fronteiras S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132177.mp4', 'http://timg.bdta.pro/images/82a229bdfc67882f4df0631438f43786.jpg'),
(4729, 293, 'Fronteiras S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132178.mp4', 'http://timg.bdta.pro/images/563a344e4bda420c62c1fc3c5c31eb2c.jpg'),
(4730, 293, 'Fronteiras S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132179.mp4', 'http://timg.bdta.pro/images/f74afd99f3b6f5093b13d8a910625c6d.jpg'),
(4731, 293, 'Fronteiras S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132180.mp4', 'http://timg.bdta.pro/images/78057a9b4065bbc2a3bd1f374785d4b3.jpg'),
(4732, 294, 'Fronteiras S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132181.mp4', 'http://timg.bdta.pro/images/c71959f22e2442d6696ea2bf2eb65997.jpg'),
(4733, 294, 'Fronteiras S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132182.mp4', 'http://timg.bdta.pro/images/41b76c33844c1e39bf876d8d94c49948.jpg'),
(4734, 294, 'Fronteiras S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132183.mp4', 'http://timg.bdta.pro/images/3c0e66219eb9f510b501b28af8d7e473.jpg'),
(4735, 294, 'Fronteiras S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132184.mp4', 'http://timg.bdta.pro/images/24e7f148446fa8b992b012540f239d76.jpg'),
(4736, 294, 'Fronteiras S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132185.mp4', 'http://timg.bdta.pro/images/274b790ab4fcee348782f97b488f1eeb.jpg'),
(4737, 294, 'Fronteiras S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132186.mp4', 'http://timg.bdta.pro/images/181c817d8b5c655941cf311d17c767da.jpg'),
(4738, 294, 'Fronteiras S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132187.mp4', 'http://timg.bdta.pro/images/66e6ab698b9108ff5635cc3e6a71a8f5.jpg'),
(4739, 294, 'Fronteiras S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132188.mp4', 'http://timg.bdta.pro/images/58fa8f041b3db8c99d0c219e4cd2b40c.jpg'),
(4740, 294, 'Fronteiras S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132189.mp4', 'http://timg.bdta.pro/images/3a0eef8852612a6e4464c4403e506284.jpg'),
(4741, 294, 'Fronteiras S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132190.mp4', 'http://timg.bdta.pro/images/f32a6251697df828c3a1f15ce8c2925d.jpg'),
(4742, 294, 'Fronteiras S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132191.mp4', 'http://timg.bdta.pro/images/25efc1e37a877c19e0c982f2f47f686b.jpg'),
(4743, 294, 'Fronteiras S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132192.mp4', 'http://timg.bdta.pro/images/28407ba713e61ea236e8706f22e87eef.jpg'),
(4744, 294, 'Fronteiras S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132193.mp4', 'http://timg.bdta.pro/images/e37be1b4853bde49a00e6b9b729496d5.jpg'),
(4745, 295, 'Guerra Fantasma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hdOWk4uAKXXPBdyLd54ejmbzpVP.jpg'),
(4746, 295, 'Guerra Fantasma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hdOWk4uAKXXPBdyLd54ejmbzpVP.jpg'),
(4747, 295, 'Guerra Fantasma S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hdOWk4uAKXXPBdyLd54ejmbzpVP.jpg'),
(4748, 295, 'Guerra Fantasma S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hdOWk4uAKXXPBdyLd54ejmbzpVP.jpg'),
(4749, 295, 'Guerra Fantasma S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hdOWk4uAKXXPBdyLd54ejmbzpVP.jpg'),
(4750, 295, 'Guerra Fantasma S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hdOWk4uAKXXPBdyLd54ejmbzpVP.jpg'),
(4751, 295, 'Guerra Fantasma S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hdOWk4uAKXXPBdyLd54ejmbzpVP.jpg'),
(4752, 295, 'Guerra Fantasma S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hdOWk4uAKXXPBdyLd54ejmbzpVP.jpg'),
(4753, 295, 'Guerra Fantasma S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hdOWk4uAKXXPBdyLd54ejmbzpVP.jpg'),
(4754, 295, 'Guerra Fantasma S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hdOWk4uAKXXPBdyLd54ejmbzpVP.jpg'),
(4755, 295, 'Guerra Fantasma S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hdOWk4uAKXXPBdyLd54ejmbzpVP.jpg'),
(4756, 295, 'Guerra Fantasma S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hdOWk4uAKXXPBdyLd54ejmbzpVP.jpg'),
(4757, 295, 'Guerra Fantasma S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hdOWk4uAKXXPBdyLd54ejmbzpVP.jpg'),
(4758, 296, 'Glee: Em Busca da Fama S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4759, 296, 'Glee: Em Busca da Fama S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4760, 296, 'Glee: Em Busca da Fama S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4761, 296, 'Glee: Em Busca da Fama S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4762, 296, 'Glee: Em Busca da Fama S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4763, 296, 'Glee: Em Busca da Fama S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4764, 296, 'Glee: Em Busca da Fama S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4765, 296, 'Glee: Em Busca da Fama S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4766, 296, 'Glee: Em Busca da Fama S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(4767, 296, 'Glee: Em Busca da Fama S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4768, 296, 'Glee: Em Busca da Fama S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4769, 296, 'Glee: Em Busca da Fama S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4770, 296, 'Glee: Em Busca da Fama S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4771, 296, 'Glee: Em Busca da Fama S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4772, 296, 'Glee: Em Busca da Fama S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4773, 296, 'Glee: Em Busca da Fama S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4774, 296, 'Glee: Em Busca da Fama S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4775, 296, 'Glee: Em Busca da Fama S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4776, 296, 'Glee: Em Busca da Fama S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4777, 296, 'Glee: Em Busca da Fama S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/101240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4778, 296, 'Glee: Em Busca da Fama S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/101241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4779, 296, 'Glee: Em Busca da Fama S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/101242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4780, 297, 'Glee: Em Busca da Fama S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4781, 297, 'Glee: Em Busca da Fama S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4782, 297, 'Glee: Em Busca da Fama S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4783, 297, 'Glee: Em Busca da Fama S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4784, 297, 'Glee: Em Busca da Fama S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4785, 297, 'Glee: Em Busca da Fama S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4786, 297, 'Glee: Em Busca da Fama S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4787, 297, 'Glee: Em Busca da Fama S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4788, 297, 'Glee: Em Busca da Fama S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4789, 297, 'Glee: Em Busca da Fama S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4790, 297, 'Glee: Em Busca da Fama S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4791, 297, 'Glee: Em Busca da Fama S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4792, 297, 'Glee: Em Busca da Fama S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4793, 297, 'Glee: Em Busca da Fama S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4794, 297, 'Glee: Em Busca da Fama S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4795, 297, 'Glee: Em Busca da Fama S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4796, 297, 'Glee: Em Busca da Fama S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4797, 297, 'Glee: Em Busca da Fama S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4798, 297, 'Glee: Em Busca da Fama S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4799, 297, 'Glee: Em Busca da Fama S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/101262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4800, 297, 'Glee: Em Busca da Fama S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/101263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4801, 297, 'Glee: Em Busca da Fama S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/101264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4802, 298, 'Glee: Em Busca da Fama S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4803, 298, 'Glee: Em Busca da Fama S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4804, 298, 'Glee: Em Busca da Fama S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4805, 298, 'Glee: Em Busca da Fama S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4806, 298, 'Glee: Em Busca da Fama S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4807, 298, 'Glee: Em Busca da Fama S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4808, 298, 'Glee: Em Busca da Fama S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4809, 298, 'Glee: Em Busca da Fama S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4810, 298, 'Glee: Em Busca da Fama S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4811, 298, 'Glee: Em Busca da Fama S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4812, 298, 'Glee: Em Busca da Fama S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4813, 298, 'Glee: Em Busca da Fama S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4814, 298, 'Glee: Em Busca da Fama S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4815, 298, 'Glee: Em Busca da Fama S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4816, 298, 'Glee: Em Busca da Fama S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4817, 298, 'Glee: Em Busca da Fama S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4818, 298, 'Glee: Em Busca da Fama S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4819, 298, 'Glee: Em Busca da Fama S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4820, 298, 'Glee: Em Busca da Fama S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4821, 298, 'Glee: Em Busca da Fama S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/101284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4822, 298, 'Glee: Em Busca da Fama S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/101285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4823, 298, 'Glee: Em Busca da Fama S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/101286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4824, 299, 'Glee: Em Busca da Fama S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4825, 299, 'Glee: Em Busca da Fama S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4826, 299, 'Glee: Em Busca da Fama S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4827, 299, 'Glee: Em Busca da Fama S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4828, 299, 'Glee: Em Busca da Fama S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4829, 299, 'Glee: Em Busca da Fama S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4830, 299, 'Glee: Em Busca da Fama S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4831, 299, 'Glee: Em Busca da Fama S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4832, 299, 'Glee: Em Busca da Fama S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4833, 299, 'Glee: Em Busca da Fama S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4834, 299, 'Glee: Em Busca da Fama S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4835, 299, 'Glee: Em Busca da Fama S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4836, 299, 'Glee: Em Busca da Fama S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4837, 299, 'Glee: Em Busca da Fama S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4838, 299, 'Glee: Em Busca da Fama S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4839, 299, 'Glee: Em Busca da Fama S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4840, 299, 'Glee: Em Busca da Fama S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4841, 299, 'Glee: Em Busca da Fama S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4842, 299, 'Glee: Em Busca da Fama S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4843, 299, 'Glee: Em Busca da Fama S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/101306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4844, 299, 'Glee: Em Busca da Fama S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/101307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4845, 299, 'Glee: Em Busca da Fama S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/101308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4846, 300, 'Glee: Em Busca da Fama S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4847, 300, 'Glee: Em Busca da Fama S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4848, 300, 'Glee: Em Busca da Fama S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4849, 300, 'Glee: Em Busca da Fama S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4850, 300, 'Glee: Em Busca da Fama S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4851, 300, 'Glee: Em Busca da Fama S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4852, 300, 'Glee: Em Busca da Fama S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4853, 300, 'Glee: Em Busca da Fama S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4854, 300, 'Glee: Em Busca da Fama S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4855, 300, 'Glee: Em Busca da Fama S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4856, 300, 'Glee: Em Busca da Fama S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4857, 300, 'Glee: Em Busca da Fama S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4858, 300, 'Glee: Em Busca da Fama S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4859, 300, 'Glee: Em Busca da Fama S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4860, 300, 'Glee: Em Busca da Fama S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4861, 301, 'Glee: Em Busca da Fama S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4862, 301, 'Glee: Em Busca da Fama S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4863, 301, 'Glee: Em Busca da Fama S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4864, 301, 'Glee: Em Busca da Fama S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4865, 301, 'Glee: Em Busca da Fama S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4866, 301, 'Glee: Em Busca da Fama S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4867, 301, 'Glee: Em Busca da Fama S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4868, 301, 'Glee: Em Busca da Fama S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4869, 301, 'Glee: Em Busca da Fama S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4870, 301, 'Glee: Em Busca da Fama S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4871, 301, 'Glee: Em Busca da Fama S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4872, 301, 'Glee: Em Busca da Fama S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4873, 301, 'Glee: Em Busca da Fama S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aKGhKr5ZQLF9YdbEaY9nCBsMsfJ.jpg'),
(4874, 302, 'Godless S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101337.mp4', 'http://gstaticontent.com/images/ePOD0ofGWFDTbZR84QhM7kpYMPX_big.jpg'),
(4875, 302, 'Godless S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101338.mp4', 'http://gstaticontent.com/images/ePOD0ofGWFDTbZR84QhM7kpYMPX_big.jpg'),
(4876, 302, 'Godless S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101339.mp4', 'http://gstaticontent.com/images/ePOD0ofGWFDTbZR84QhM7kpYMPX_big.jpg'),
(4877, 302, 'Godless S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101340.mp4', 'http://gstaticontent.com/images/ePOD0ofGWFDTbZR84QhM7kpYMPX_big.jpg'),
(4878, 302, 'Godless S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101341.mp4', 'http://gstaticontent.com/images/ePOD0ofGWFDTbZR84QhM7kpYMPX_big.jpg'),
(4879, 302, 'Godless S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101342.mp4', 'http://gstaticontent.com/images/ePOD0ofGWFDTbZR84QhM7kpYMPX_big.jpg'),
(4880, 302, 'Godless S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101343.mp4', 'http://gstaticontent.com/images/ePOD0ofGWFDTbZR84QhM7kpYMPX_big.jpg'),
(4881, 303, 'Good Girls S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166110.mp4', 'http://gstaticontent.com/images/d6gA2IHRLqtHcmSqkk91Xw0wtEv_big.jpg'),
(4882, 303, 'Good Girls S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166111.mp4', 'http://gstaticontent.com/images/d6gA2IHRLqtHcmSqkk91Xw0wtEv_big.jpg'),
(4883, 303, 'Good Girls S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166112.mp4', 'http://gstaticontent.com/images/d6gA2IHRLqtHcmSqkk91Xw0wtEv_big.jpg'),
(4884, 303, 'Good Girls S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166113.mp4', 'http://gstaticontent.com/images/d6gA2IHRLqtHcmSqkk91Xw0wtEv_big.jpg'),
(4885, 303, 'Good Girls S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166114.mp4', 'http://gstaticontent.com/images/d6gA2IHRLqtHcmSqkk91Xw0wtEv_big.jpg'),
(4886, 303, 'Good Girls S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166115.mp4', 'http://gstaticontent.com/images/d6gA2IHRLqtHcmSqkk91Xw0wtEv_big.jpg'),
(4887, 303, 'Good Girls S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166116.mp4', 'http://gstaticontent.com/images/d6gA2IHRLqtHcmSqkk91Xw0wtEv_big.jpg'),
(4888, 303, 'Good Girls S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166117.mp4', 'http://gstaticontent.com/images/d6gA2IHRLqtHcmSqkk91Xw0wtEv_big.jpg'),
(4889, 303, 'Good Girls S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166118.mp4', 'http://gstaticontent.com/images/d6gA2IHRLqtHcmSqkk91Xw0wtEv_big.jpg'),
(4890, 303, 'Good Girls S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166119.mp4', 'http://gstaticontent.com/images/d6gA2IHRLqtHcmSqkk91Xw0wtEv_big.jpg'),
(4891, 304, 'Good Girls S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166120.mp4', 'http://timg.bdta.pro/images/f4bfb0f6ca980a7248befa9624a9d891.jpg'),
(4892, 304, 'Good Girls S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166121.mp4', 'http://timg.bdta.pro/images/a91776ebda8ea4aed171938d181c63e2.jpg'),
(4893, 304, 'Good Girls S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166122.mp4', 'http://timg.bdta.pro/images/c4f15c876412cf4453a4372ea4a0274c.jpg'),
(4894, 304, 'Good Girls S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166123.mp4', 'http://timg.bdta.pro/images/3586d9344899fc22435e0ad0241cb6e4.jpg'),
(4895, 304, 'Good Girls S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166124.mp4', 'http://timg.bdta.pro/images/6972b4de43c2a5081c62aaf23aa44517.jpg'),
(4896, 304, 'Good Girls S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166125.mp4', 'http://timg.bdta.pro/images/d8e69960bcb2f99e8985f1f8acb58ba7.jpg'),
(4897, 304, 'Good Girls S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166126.mp4', 'http://timg.bdta.pro/images/e66c2f532eadf3f37f02e70d70104663.jpg'),
(4898, 304, 'Good Girls S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166127.mp4', 'http://timg.bdta.pro/images/6535f6ee02c3e912b3768eda434f2fc2.jpg'),
(4899, 304, 'Good Girls S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166128.mp4', 'http://timg.bdta.pro/images/9041536baa0b42d22030dd207a812c8e.jpg'),
(4900, 304, 'Good Girls S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166129.mp4', 'http://timg.bdta.pro/images/aacdb41ace67e7c11446317f698a7d81.jpg'),
(4901, 304, 'Good Girls S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166130.mp4', 'http://timg.bdta.pro/images/40f0fbe153fddb7b5451b6bfa9895f29.jpg'),
(4902, 304, 'Good Girls S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166131.mp4', 'http://timg.bdta.pro/images/6dd72aa2af136e07886c37bf498a183e.jpg'),
(4903, 304, 'Good Girls S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166132.mp4', 'http://timg.bdta.pro/images/1313c3de33fed2e32c48d6f332c3291e.jpg'),
(4904, 305, 'Good Girls S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166133.mp4', 'http://timg.bdta.pro/images/7021c8401dbc74974575a0f4d3af1066.jpg'),
(4905, 305, 'Good Girls S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166134.mp4', 'http://timg.bdta.pro/images/f40f7fed4b9c210543c2738407198207.jpg'),
(4906, 305, 'Good Girls S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166135.mp4', 'http://timg.bdta.pro/images/060fd7b27ae402619175cea31a53ec94.jpg'),
(4907, 305, 'Good Girls S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166136.mp4', 'http://timg.bdta.pro/images/8afaf1f1bf50ee2b1939b0b69cc1a42e.jpg'),
(4908, 305, 'Good Girls S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166137.mp4', 'http://timg.bdta.pro/images/03318036cfe2b36462e1956433d94959.jpg'),
(4909, 305, 'Good Girls S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166138.mp4', 'http://timg.bdta.pro/images/06a19340b46e77f8b788579be7c201fd.jpg'),
(4910, 305, 'Good Girls S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166139.mp4', 'http://timg.bdta.pro/images/ffa9241bd69474d13827e959721cad92.jpg'),
(4911, 305, 'Good Girls S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166140.mp4', 'http://timg.bdta.pro/images/44e36568c8c64603e4b51eef78ea8b9d.jpg'),
(4912, 305, 'Good Girls S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166141.mp4', 'http://timg.bdta.pro/images/f361e01a9741ad582f51171466268b3e.jpg'),
(4913, 305, 'Good Girls S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166142.mp4', 'http://timg.bdta.pro/images/1f44b66c17224dfa0e53ecc84ed4531a.jpg'),
(4914, 305, 'Good Girls S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166143.mp4', 'http://timg.bdta.pro/images/edc2efff8d37686455c24f60cc036159.jpg'),
(4915, 306, 'Good Girls S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zEclPKAnO2MJ2Lf4Czqov5m6bn5.jpg'),
(4916, 306, 'Good Girls S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a9YGdwVABKlt9pj1dSiQAZTiyUc.jpg'),
(4917, 306, 'Good Girls S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/onnphf5SOX3Qirul5jkEMYXLfjI.jpg'),
(4918, 306, 'Good Girls S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmPXwVn8OCkj7x4D5iSH6tccwlY.jpg'),
(4919, 306, 'Good Girls S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/phSypKVbyrgmmbHhXKvOoxEgdTx.jpg'),
(4920, 306, 'Good Girls S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2LA1NaMALIqSpmPV5X7jtvdtge.jpg'),
(4921, 306, 'Good Girls S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/siSHBgSwAtbLSW8kfDHbXwI86Sf.jpg'),
(4922, 306, 'Good Girls S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r3FZ3auB7hrxyFxoeNhmgJfFg3N.jpg'),
(4923, 306, 'Good Girls S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/obQqW1wI0WgddnEvJgPks2WkR6i.jpg'),
(4924, 306, 'Good Girls S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hN7rJke6XxEYSt3BXd33E579B27.jpg'),
(4925, 306, 'Good Girls S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AoTC1RWHolYIW4Qo9GabpYbmcm7.jpg'),
(4926, 306, 'Good Girls S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/guya5J5vH0r79d0lT7AHDy0yi80.jpg'),
(4927, 306, 'Good Girls S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rxqiU5Xu0j6qzAgvxVwODkOMLBe.jpg'),
(4928, 306, 'Good Girls S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iXn6KuCFrQuw3D6YN2tE0hjGu5T.jpg'),
(4929, 306, 'Good Girls S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rbTUS7U29VHL9J0jecG3uhIiafg.jpg'),
(4930, 306, 'Good Girls S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5WmbqPiVzzAC4LRUdpce9qz8sp8.jpg'),
(4931, 307, 'Gotham S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149344.mp4', 'http://timg.bdta.pro/images/31e8d412c358d6ad575f4e484d4717e1.jpg'),
(4932, 307, 'Gotham S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149345.mp4', 'http://timg.bdta.pro/images/fb8aa10df77c20cdfd6019abdf044251.jpg'),
(4933, 307, 'Gotham S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149346.mp4', 'http://timg.bdta.pro/images/54bd5c18b74d6239348ba7d674ca6052.jpg'),
(4934, 307, 'Gotham S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149347.mp4', 'http://timg.bdta.pro/images/3eae8f7eeead36962136206c670eae90.jpg'),
(4935, 307, 'Gotham S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149348.mp4', 'http://timg.bdta.pro/images/621fcb6f64607f66eedac2f89b84e07e.jpg'),
(4936, 307, 'Gotham S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149349.mp4', 'http://timg.bdta.pro/images/d00262d000d20800f63f04979752a562.jpg'),
(4937, 307, 'Gotham S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149350.mp4', 'http://timg.bdta.pro/images/dfdc0f1cab14db9c8b3b9eb084b13cf8.jpg'),
(4938, 307, 'Gotham S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149351.mp4', 'http://timg.bdta.pro/images/1894717b528052843142d5112a4c1322.jpg'),
(4939, 307, 'Gotham S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149352.mp4', 'http://timg.bdta.pro/images/c100e711b24aa5dea76a4212e88c44d2.jpg'),
(4940, 307, 'Gotham S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149353.mp4', 'http://timg.bdta.pro/images/991a15aa6aca05d257bfe8e2c43cf357.jpg'),
(4941, 307, 'Gotham S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149354.mp4', 'http://timg.bdta.pro/images/12a5dd7d115c3ddfd3fca1da742c6a51.jpg'),
(4942, 307, 'Gotham S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149355.mp4', 'http://timg.bdta.pro/images/7b9a3d055093aab158a56ece10ac9a90.jpg'),
(4943, 307, 'Gotham S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/149356.mp4', 'http://timg.bdta.pro/images/7e3b5392abfb194208857ca6ee7dc311.jpg'),
(4944, 307, 'Gotham S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/149357.mp4', 'http://timg.bdta.pro/images/8717cd7d2280a90d30915e9a0bc3dc4b.jpg'),
(4945, 307, 'Gotham S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/149358.mp4', 'http://timg.bdta.pro/images/083b1234ccdbf962842a67e34d9bc8c6.jpg'),
(4946, 307, 'Gotham S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/149359.mp4', 'http://timg.bdta.pro/images/0e679eaa3891d8863a224c46f3f9fb58.jpg'),
(4947, 307, 'Gotham S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/149360.mp4', 'http://timg.bdta.pro/images/df8027e05d680453c9f516029bdeaac4.jpg'),
(4948, 307, 'Gotham S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/149361.mp4', 'http://timg.bdta.pro/images/9fa065f1d21ab86e3bef3944b2569fd3.jpg'),
(4949, 307, 'Gotham S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/149362.mp4', 'http://timg.bdta.pro/images/a5e7f0bf80dc04fb09b285582c10aca3.jpg'),
(4950, 307, 'Gotham S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/149363.mp4', 'http://timg.bdta.pro/images/8008d1c9b87be98e04972a96254a42e3.jpg'),
(4951, 307, 'Gotham S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/149364.mp4', 'http://timg.bdta.pro/images/7daf5fc7fc4243805ad699160fe85ca2.jpg'),
(4952, 307, 'Gotham S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/149365.mp4', 'http://timg.bdta.pro/images/25c562813de9cd67d11bd9526db8e59f.jpg'),
(4953, 308, 'Gotham S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149366.mp4', 'http://timg.bdta.pro/images/45ad30d192381c1fcd81cfa872601bed.jpg'),
(4954, 308, 'Gotham S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149367.mp4', 'http://timg.bdta.pro/images/715d4413298d98d44cdc55332241b4ab.jpg'),
(4955, 308, 'Gotham S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149368.mp4', 'http://timg.bdta.pro/images/8175c09c351e35fef56ea7f5319fa105.jpg'),
(4956, 308, 'Gotham S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149369.mp4', 'http://timg.bdta.pro/images/2404b304aa8155f8c8109cf3c916d7ec.jpg'),
(4957, 308, 'Gotham S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149370.mp4', 'http://timg.bdta.pro/images/9a55d1d9a01b441de463ebf5c3b1497f.jpg'),
(4958, 308, 'Gotham S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149371.mp4', 'http://timg.bdta.pro/images/4881dad2207f42a021279c2f2fa2a9c3.jpg'),
(4959, 308, 'Gotham S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149372.mp4', 'http://timg.bdta.pro/images/20f34be2e02f0cecdcd476f66f99a70f.jpg'),
(4960, 308, 'Gotham S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149373.mp4', 'http://timg.bdta.pro/images/ec06a4b4dd74ffbc536446403c5f06fd.jpg'),
(4961, 308, 'Gotham S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149374.mp4', 'http://timg.bdta.pro/images/74dc1b36b1a2da128c5d9742a676baa7.jpg'),
(4962, 308, 'Gotham S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149375.mp4', 'http://timg.bdta.pro/images/0736d404664cadd6912e24150afa3824.jpg'),
(4963, 308, 'Gotham S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149376.mp4', 'http://timg.bdta.pro/images/a395daa4459f880dfbbea8fd7a6b40be.jpg'),
(4964, 308, 'Gotham S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149377.mp4', 'http://timg.bdta.pro/images/05f1f15e4a3e75c2a3dbedd8c311d0f4.jpg'),
(4965, 308, 'Gotham S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/149378.mp4', 'http://timg.bdta.pro/images/ec92cf6a26ff5b683beff6cff41e84a2.jpg'),
(4966, 308, 'Gotham S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/149379.mp4', 'http://timg.bdta.pro/images/0326805c608d934ef75d5c6710fd7cc2.jpg'),
(4967, 308, 'Gotham S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/149380.mp4', 'http://timg.bdta.pro/images/d50174f4dd44db1f17a50fe107dd59f8.jpg'),
(4968, 308, 'Gotham S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/149381.mp4', 'http://timg.bdta.pro/images/34d3d0b7fe8cbbd819f233dbd2cd18b7.jpg'),
(4969, 308, 'Gotham S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/149382.mp4', 'http://timg.bdta.pro/images/aa7aac3e17a40124bb786bd66e3e1d8a.jpg'),
(4970, 308, 'Gotham S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/149383.mp4', 'http://timg.bdta.pro/images/81a41174b3d832b8faa064c8a25a8a68.jpg'),
(4971, 308, 'Gotham S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/149384.mp4', 'http://timg.bdta.pro/images/7d24e8aebe28bfc358a606beffdd2dc0.jpg'),
(4972, 308, 'Gotham S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/149385.mp4', 'http://timg.bdta.pro/images/1d3b01680000bdd5ceac62e660a61057.jpg'),
(4973, 308, 'Gotham S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/149386.mp4', 'http://timg.bdta.pro/images/552b8c370ee1a59754754e35ebe59d39.jpg'),
(4974, 308, 'Gotham S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/149387.mp4', 'http://timg.bdta.pro/images/2d66234122523aee8141ccf95e8bba0d.jpg'),
(4975, 309, 'Gotham S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149388.mp4', 'http://timg.bdta.pro/images/96e34c6f3f89aee4fad219bfff2a5f11.jpg'),
(4976, 309, 'Gotham S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149389.mp4', 'http://timg.bdta.pro/images/458c00b2166bdcbb551c44e51ca144ba.jpg'),
(4977, 309, 'Gotham S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149390.mp4', 'http://timg.bdta.pro/images/d02452327eefe131e72af77adaea2d74.jpg'),
(4978, 309, 'Gotham S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149391.mp4', 'http://timg.bdta.pro/images/76f33b9fa52a17c5d61c139380b79c9c.jpg'),
(4979, 309, 'Gotham S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149392.mp4', 'http://timg.bdta.pro/images/38b30ed36750ebf425454699ba737611.jpg'),
(4980, 309, 'Gotham S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149393.mp4', 'http://timg.bdta.pro/images/a9aee3cbc8cec4d1178084253b2042b9.jpg'),
(4981, 309, 'Gotham S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149394.mp4', 'http://timg.bdta.pro/images/316cb61d41c7e9ab5fdee947637c968e.jpg'),
(4982, 309, 'Gotham S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149395.mp4', 'http://timg.bdta.pro/images/6c29bc0f5e23e19740b1c943641ebe35.jpg'),
(4983, 309, 'Gotham S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149396.mp4', 'http://timg.bdta.pro/images/f6400f4c0db6f71cd1464965eb14c24e.jpg'),
(4984, 309, 'Gotham S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149397.mp4', 'http://timg.bdta.pro/images/d3dc703440d49548b6d4700eb3e8503a.jpg'),
(4985, 309, 'Gotham S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149398.mp4', 'http://timg.bdta.pro/images/d6198c7e0d3192eddb1d3302592c13be.jpg'),
(4986, 309, 'Gotham S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149399.mp4', 'http://timg.bdta.pro/images/a0e74e8822a76665f70b1ea2b400a9cd.jpg'),
(4987, 309, 'Gotham S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/149400.mp4', 'http://timg.bdta.pro/images/d04cbb3a247d09d1bd9a37906ea9fa0b.jpg'),
(4988, 309, 'Gotham S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/149401.mp4', 'http://timg.bdta.pro/images/ebe5e7fca315b77606e014232531cab6.jpg'),
(4989, 309, 'Gotham S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/149402.mp4', 'http://timg.bdta.pro/images/f88fca8787f60e3cac2ecfefff022cd4.jpg'),
(4990, 309, 'Gotham S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/149403.mp4', 'http://timg.bdta.pro/images/ac25ea70795635fb7aeb62267b22859a.jpg'),
(4991, 309, 'Gotham S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/149404.mp4', 'http://timg.bdta.pro/images/376164d69ff7c9e0e469b9f346699183.jpg'),
(4992, 309, 'Gotham S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/149405.mp4', 'http://timg.bdta.pro/images/65b9f306ae4e4570af44b6b4bca31e0a.jpg'),
(4993, 309, 'Gotham S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/149406.mp4', 'http://timg.bdta.pro/images/be0994dc5270c3d6c70e078128343d16.jpg'),
(4994, 309, 'Gotham S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/149407.mp4', 'http://timg.bdta.pro/images/ceede0e831fdfb7e5e6dd898deeaa253.jpg'),
(4995, 309, 'Gotham S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/149408.mp4', 'http://timg.bdta.pro/images/05536edf421549669cf4c947dd6eca4e.jpg'),
(4996, 310, 'Gotham S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149409.mp4', 'http://timg.bdta.pro/images/ace02fee48e8c2c2bf334d4a01c91375.jpg'),
(4997, 310, 'Gotham S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149410.mp4', 'http://timg.bdta.pro/images/74ce7608b466c00a290531565310136e.jpg'),
(4998, 310, 'Gotham S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149411.mp4', 'http://timg.bdta.pro/images/ed0f61fdbc5eba1ae2c03d3d9b0a361b.jpg'),
(4999, 310, 'Gotham S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149412.mp4', 'http://timg.bdta.pro/images/6efae260c51229ce569494992189c412.jpg'),
(5000, 310, 'Gotham S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149413.mp4', 'http://timg.bdta.pro/images/bc7f129763ac13eea00cc9711b1f5684.jpg'),
(5001, 310, 'Gotham S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149414.mp4', 'http://timg.bdta.pro/images/286c01efeddc2a342f1b9cd7f6fee579.jpg'),
(5002, 310, 'Gotham S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149415.mp4', 'http://timg.bdta.pro/images/ef7b0fea949b379705b4f6dfc3b6ad48.jpg'),
(5003, 310, 'Gotham S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149416.mp4', 'http://timg.bdta.pro/images/c771596b12a93a7e942710582db80a2e.jpg'),
(5004, 310, 'Gotham S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149417.mp4', 'http://timg.bdta.pro/images/cc3fec8ed37a7290aceae9229f483be6.jpg'),
(5005, 310, 'Gotham S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149418.mp4', 'http://timg.bdta.pro/images/cf2673d8e8817376fd7cf124e01cc890.jpg'),
(5006, 310, 'Gotham S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149419.mp4', 'http://timg.bdta.pro/images/904f585361633b7895380662b27e9d33.jpg'),
(5007, 310, 'Gotham S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149420.mp4', 'http://timg.bdta.pro/images/9d120ea8c610234cb110ff751544515d.jpg'),
(5008, 310, 'Gotham S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/149421.mp4', 'http://timg.bdta.pro/images/6a92003c0073a806f4cb7fe4b5c577f6.jpg'),
(5009, 310, 'Gotham S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/149422.mp4', 'http://timg.bdta.pro/images/a5d4901bbb7cdb21b47de65c9efd648d.jpg'),
(5010, 310, 'Gotham S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/149423.mp4', 'http://timg.bdta.pro/images/0a47f1ac474f7401a413abd1615a1229.jpg'),
(5011, 310, 'Gotham S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/149424.mp4', 'http://timg.bdta.pro/images/240da3b1bf3574abe266eac725bf53fa.jpg'),
(5012, 310, 'Gotham S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/149425.mp4', 'http://timg.bdta.pro/images/2ae1c8c1262968cbff0273023d8176c1.jpg'),
(5013, 310, 'Gotham S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/149426.mp4', 'http://timg.bdta.pro/images/3cbe45c942eabc5685dcf7302a3fb1ff.jpg'),
(5014, 310, 'Gotham S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/149427.mp4', 'http://timg.bdta.pro/images/e7bbfd3c19c937932199ad4d1e13916c.jpg'),
(5015, 310, 'Gotham S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/149428.mp4', 'http://timg.bdta.pro/images/03789b7ecd4d7d5dd2faa2146ad37bf1.jpg'),
(5016, 310, 'Gotham S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/149429.mp4', 'http://timg.bdta.pro/images/95fa79efe5d0e289ca3238b593193da7.jpg'),
(5017, 310, 'Gotham S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/149430.mp4', 'http://timg.bdta.pro/images/156eebb4be5576874bb5ef1d31224142.jpg'),
(5018, 311, 'Gotham S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149431.mp4', 'http://timg.bdta.pro/images/5d18dcf63fa8157251ced2e8a3004d64.jpg'),
(5019, 311, 'Gotham S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149432.mp4', 'http://timg.bdta.pro/images/059febff9e0c7692fd43a425dc8a80d5.jpg'),
(5020, 311, 'Gotham S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149433.mp4', 'http://timg.bdta.pro/images/2b7b99e55164c9d246dba1d0fe9e6ead.jpg'),
(5021, 311, 'Gotham S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149434.mp4', 'http://timg.bdta.pro/images/182d854660c91873a12e20855f33842b.jpg'),
(5022, 311, 'Gotham S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149435.mp4', 'http://timg.bdta.pro/images/d9af5ab0f9378454441fb834fbc3671b.jpg'),
(5023, 311, 'Gotham S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149436.mp4', 'http://timg.bdta.pro/images/3aa632144804885858f2fae10940accc.jpg'),
(5024, 311, 'Gotham S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149437.mp4', 'http://timg.bdta.pro/images/6468d8856429f7e185e8deaaa0e7bc6b.jpg'),
(5025, 311, 'Gotham S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149438.mp4', 'http://timg.bdta.pro/images/4019f1f51c605c73bbdce24c40fe7e54.jpg'),
(5026, 311, 'Gotham S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149439.mp4', 'http://timg.bdta.pro/images/5ed47d2bf008dfc51965f68f4e3f2c30.jpg'),
(5027, 311, 'Gotham S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149440.mp4', 'http://timg.bdta.pro/images/561c7ea2957986a6cc8c13ffcc60ac1f.jpg'),
(5028, 311, 'Gotham S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149441.mp4', 'http://timg.bdta.pro/images/c70a1bcfca8a4094adf6b7afff4aae38.jpg'),
(5029, 311, 'Gotham S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149442.mp4', 'http://timg.bdta.pro/images/7e93233ab381f7dd5dd75bc81b661a4b.jpg'),
(5030, 312, 'Grey\'s Anatomy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218605.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5031, 312, 'Grey\'s Anatomy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218606.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5032, 312, 'Grey\'s Anatomy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218607.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5033, 312, 'Grey\'s Anatomy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218608.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5034, 312, 'Grey\'s Anatomy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218609.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5035, 312, 'Grey\'s Anatomy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218610.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5036, 312, 'Grey\'s Anatomy S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218611.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5037, 312, 'Grey\'s Anatomy S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218612.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5038, 312, 'Grey\'s Anatomy S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218613.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5039, 313, 'Grey\'s Anatomy S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218614.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5040, 313, 'Grey\'s Anatomy S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218615.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5041, 313, 'Grey\'s Anatomy S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218616.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5042, 313, 'Grey\'s Anatomy S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218617.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5043, 313, 'Grey\'s Anatomy S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218618.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5044, 313, 'Grey\'s Anatomy S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218619.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5045, 313, 'Grey\'s Anatomy S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218620.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5046, 313, 'Grey\'s Anatomy S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218621.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5047, 313, 'Grey\'s Anatomy S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218622.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5048, 313, 'Grey\'s Anatomy S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218623.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(5049, 313, 'Grey\'s Anatomy S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218624.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5050, 313, 'Grey\'s Anatomy S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218625.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5051, 313, 'Grey\'s Anatomy S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218626.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5052, 313, 'Grey\'s Anatomy S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218627.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5053, 313, 'Grey\'s Anatomy S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218628.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5054, 313, 'Grey\'s Anatomy S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218629.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5055, 313, 'Grey\'s Anatomy S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218630.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5056, 313, 'Grey\'s Anatomy S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218631.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5057, 313, 'Grey\'s Anatomy S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218632.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5058, 313, 'Grey\'s Anatomy S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218633.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5059, 313, 'Grey\'s Anatomy S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218634.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5060, 313, 'Grey\'s Anatomy S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/218635.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5061, 313, 'Grey\'s Anatomy S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/218636.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5062, 313, 'Grey\'s Anatomy S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/218637.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5063, 313, 'Grey\'s Anatomy S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/218638.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5064, 313, 'Grey\'s Anatomy S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/218639.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5065, 313, 'Grey\'s Anatomy S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/218640.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5066, 314, 'Grey\'s Anatomy S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218641.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5067, 314, 'Grey\'s Anatomy S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218642.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5068, 314, 'Grey\'s Anatomy S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218643.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5069, 314, 'Grey\'s Anatomy S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218644.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5070, 314, 'Grey\'s Anatomy S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218645.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5071, 314, 'Grey\'s Anatomy S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218646.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5072, 314, 'Grey\'s Anatomy S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218647.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5073, 314, 'Grey\'s Anatomy S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218648.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5074, 314, 'Grey\'s Anatomy S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218649.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5075, 314, 'Grey\'s Anatomy S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218650.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5076, 314, 'Grey\'s Anatomy S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218651.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5077, 314, 'Grey\'s Anatomy S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218652.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5078, 314, 'Grey\'s Anatomy S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218653.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5079, 314, 'Grey\'s Anatomy S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218654.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5080, 314, 'Grey\'s Anatomy S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218655.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5081, 314, 'Grey\'s Anatomy S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218656.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5082, 314, 'Grey\'s Anatomy S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218657.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5083, 314, 'Grey\'s Anatomy S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218658.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5084, 314, 'Grey\'s Anatomy S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218659.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5085, 314, 'Grey\'s Anatomy S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218660.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5086, 314, 'Grey\'s Anatomy S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218661.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5087, 314, 'Grey\'s Anatomy S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/218662.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5088, 314, 'Grey\'s Anatomy S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/218663.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5089, 314, 'Grey\'s Anatomy S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/218664.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5090, 314, 'Grey\'s Anatomy S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/218665.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5091, 315, 'Grey\'s Anatomy S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218666.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5092, 315, 'Grey\'s Anatomy S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218667.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5093, 315, 'Grey\'s Anatomy S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218668.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5094, 315, 'Grey\'s Anatomy S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218669.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5095, 315, 'Grey\'s Anatomy S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218670.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5096, 315, 'Grey\'s Anatomy S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218671.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5097, 315, 'Grey\'s Anatomy S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218672.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5098, 315, 'Grey\'s Anatomy S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218673.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5099, 315, 'Grey\'s Anatomy S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218674.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5100, 315, 'Grey\'s Anatomy S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218675.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5101, 315, 'Grey\'s Anatomy S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218676.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5102, 315, 'Grey\'s Anatomy S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218677.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5103, 315, 'Grey\'s Anatomy S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218678.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5104, 315, 'Grey\'s Anatomy S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218679.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5105, 315, 'Grey\'s Anatomy S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218680.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5106, 315, 'Grey\'s Anatomy S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218681.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5107, 315, 'Grey\'s Anatomy S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218682.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5108, 316, 'Grey\'s Anatomy S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218683.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5109, 316, 'Grey\'s Anatomy S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218684.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5110, 316, 'Grey\'s Anatomy S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218685.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5111, 316, 'Grey\'s Anatomy S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218686.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5112, 316, 'Grey\'s Anatomy S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218687.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5113, 316, 'Grey\'s Anatomy S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218688.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5114, 316, 'Grey\'s Anatomy S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218689.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5115, 316, 'Grey\'s Anatomy S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218690.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5116, 316, 'Grey\'s Anatomy S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218691.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5117, 316, 'Grey\'s Anatomy S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218692.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5118, 316, 'Grey\'s Anatomy S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218693.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5119, 316, 'Grey\'s Anatomy S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218694.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5120, 316, 'Grey\'s Anatomy S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218695.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5121, 316, 'Grey\'s Anatomy S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218696.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5122, 316, 'Grey\'s Anatomy S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218697.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5123, 316, 'Grey\'s Anatomy S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218698.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5124, 316, 'Grey\'s Anatomy S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218699.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5125, 316, 'Grey\'s Anatomy S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218700.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5126, 316, 'Grey\'s Anatomy S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218701.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5127, 316, 'Grey\'s Anatomy S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218702.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5128, 316, 'Grey\'s Anatomy S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218703.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5129, 316, 'Grey\'s Anatomy S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/218704.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5130, 316, 'Grey\'s Anatomy S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/218705.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5131, 316, 'Grey\'s Anatomy S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/218706.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5132, 317, 'Grey\'s Anatomy S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218707.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5133, 317, 'Grey\'s Anatomy S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218708.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5134, 317, 'Grey\'s Anatomy S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218709.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5135, 317, 'Grey\'s Anatomy S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218710.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5136, 317, 'Grey\'s Anatomy S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218711.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5137, 317, 'Grey\'s Anatomy S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218712.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5138, 317, 'Grey\'s Anatomy S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218713.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5139, 317, 'Grey\'s Anatomy S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218714.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5140, 317, 'Grey\'s Anatomy S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218715.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5141, 317, 'Grey\'s Anatomy S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218716.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5142, 317, 'Grey\'s Anatomy S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218717.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5143, 317, 'Grey\'s Anatomy S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218718.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5144, 317, 'Grey\'s Anatomy S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218719.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5145, 317, 'Grey\'s Anatomy S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218720.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5146, 317, 'Grey\'s Anatomy S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218721.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5147, 317, 'Grey\'s Anatomy S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218722.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5148, 317, 'Grey\'s Anatomy S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218723.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5149, 317, 'Grey\'s Anatomy S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218724.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5150, 317, 'Grey\'s Anatomy S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218725.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5151, 317, 'Grey\'s Anatomy S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218726.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5152, 317, 'Grey\'s Anatomy S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218727.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5153, 317, 'Grey\'s Anatomy S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/218728.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5154, 317, 'Grey\'s Anatomy S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/218729.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5155, 317, 'Grey\'s Anatomy S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/218730.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5156, 318, 'Grey\'s Anatomy S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218731.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5157, 318, 'Grey\'s Anatomy S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218732.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5158, 318, 'Grey\'s Anatomy S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218733.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5159, 318, 'Grey\'s Anatomy S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218734.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5160, 318, 'Grey\'s Anatomy S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218735.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5161, 318, 'Grey\'s Anatomy S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218736.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5162, 318, 'Grey\'s Anatomy S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218737.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5163, 318, 'Grey\'s Anatomy S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218738.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5164, 318, 'Grey\'s Anatomy S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218739.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5165, 318, 'Grey\'s Anatomy S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218740.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5166, 318, 'Grey\'s Anatomy S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218741.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5167, 318, 'Grey\'s Anatomy S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218742.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5168, 318, 'Grey\'s Anatomy S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218743.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5169, 318, 'Grey\'s Anatomy S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218744.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5170, 318, 'Grey\'s Anatomy S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218745.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5171, 318, 'Grey\'s Anatomy S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218746.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5172, 318, 'Grey\'s Anatomy S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218747.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5173, 318, 'Grey\'s Anatomy S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218748.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5174, 318, 'Grey\'s Anatomy S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218749.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5175, 318, 'Grey\'s Anatomy S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218750.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5176, 318, 'Grey\'s Anatomy S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218751.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5177, 318, 'Grey\'s Anatomy S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/218752.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5178, 319, 'Grey\'s Anatomy S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218753.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5179, 319, 'Grey\'s Anatomy S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218754.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5180, 319, 'Grey\'s Anatomy S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218755.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5181, 319, 'Grey\'s Anatomy S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218756.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5182, 319, 'Grey\'s Anatomy S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218757.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5183, 319, 'Grey\'s Anatomy S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218758.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5184, 319, 'Grey\'s Anatomy S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218759.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5185, 319, 'Grey\'s Anatomy S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218760.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5186, 319, 'Grey\'s Anatomy S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218761.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5187, 319, 'Grey\'s Anatomy S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218762.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5188, 319, 'Grey\'s Anatomy S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218763.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5189, 319, 'Grey\'s Anatomy S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218764.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5190, 319, 'Grey\'s Anatomy S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218765.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5191, 319, 'Grey\'s Anatomy S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218766.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5192, 319, 'Grey\'s Anatomy S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218767.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5193, 319, 'Grey\'s Anatomy S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218768.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5194, 319, 'Grey\'s Anatomy S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218769.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5195, 319, 'Grey\'s Anatomy S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218770.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5196, 319, 'Grey\'s Anatomy S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218771.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5197, 319, 'Grey\'s Anatomy S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218772.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5198, 319, 'Grey\'s Anatomy S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218773.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5199, 319, 'Grey\'s Anatomy S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/218774.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5200, 319, 'Grey\'s Anatomy S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/218775.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5201, 319, 'Grey\'s Anatomy S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/218776.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5202, 320, 'Grey\'s Anatomy S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218777.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5203, 320, 'Grey\'s Anatomy S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218778.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5204, 320, 'Grey\'s Anatomy S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218779.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5205, 320, 'Grey\'s Anatomy S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218780.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5206, 320, 'Grey\'s Anatomy S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218781.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5207, 320, 'Grey\'s Anatomy S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218782.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5208, 320, 'Grey\'s Anatomy S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218783.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5209, 320, 'Grey\'s Anatomy S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218784.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5210, 320, 'Grey\'s Anatomy S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218785.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5211, 320, 'Grey\'s Anatomy S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218786.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5212, 320, 'Grey\'s Anatomy S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218787.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5213, 320, 'Grey\'s Anatomy S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218788.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5214, 320, 'Grey\'s Anatomy S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218789.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5215, 320, 'Grey\'s Anatomy S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218790.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5216, 320, 'Grey\'s Anatomy S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218791.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5217, 320, 'Grey\'s Anatomy S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218792.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5218, 320, 'Grey\'s Anatomy S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218793.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5219, 320, 'Grey\'s Anatomy S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218794.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5220, 320, 'Grey\'s Anatomy S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218795.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5221, 320, 'Grey\'s Anatomy S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218796.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5222, 320, 'Grey\'s Anatomy S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218797.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5223, 320, 'Grey\'s Anatomy S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/218798.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5224, 320, 'Grey\'s Anatomy S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/218799.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5225, 320, 'Grey\'s Anatomy S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/218800.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5226, 321, 'Grey\'s Anatomy S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218801.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5227, 321, 'Grey\'s Anatomy S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218802.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5228, 321, 'Grey\'s Anatomy S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218803.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5229, 321, 'Grey\'s Anatomy S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218804.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5230, 321, 'Grey\'s Anatomy S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218805.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5231, 321, 'Grey\'s Anatomy S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218806.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5232, 321, 'Grey\'s Anatomy S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218807.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5233, 321, 'Grey\'s Anatomy S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218808.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5234, 321, 'Grey\'s Anatomy S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218809.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5235, 321, 'Grey\'s Anatomy S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218810.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5236, 321, 'Grey\'s Anatomy S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218811.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5237, 321, 'Grey\'s Anatomy S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218812.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5238, 321, 'Grey\'s Anatomy S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218813.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5239, 321, 'Grey\'s Anatomy S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218814.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5240, 321, 'Grey\'s Anatomy S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218815.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5241, 321, 'Grey\'s Anatomy S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218816.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5242, 321, 'Grey\'s Anatomy S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218817.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5243, 321, 'Grey\'s Anatomy S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218818.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5244, 321, 'Grey\'s Anatomy S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218819.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5245, 321, 'Grey\'s Anatomy S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218820.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5246, 321, 'Grey\'s Anatomy S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218821.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5247, 321, 'Grey\'s Anatomy S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/218822.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5248, 321, 'Grey\'s Anatomy S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/218823.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5249, 321, 'Grey\'s Anatomy S10 E24', 'http://sinalprivado.info:80/series/1533784/1533784/218824.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5250, 322, 'Grey\'s Anatomy S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218825.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5251, 322, 'Grey\'s Anatomy S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218826.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5252, 322, 'Grey\'s Anatomy S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218827.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5253, 322, 'Grey\'s Anatomy S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218828.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5254, 322, 'Grey\'s Anatomy S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218829.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5255, 322, 'Grey\'s Anatomy S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218830.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5256, 322, 'Grey\'s Anatomy S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218831.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5257, 322, 'Grey\'s Anatomy S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218832.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5258, 322, 'Grey\'s Anatomy S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218833.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5259, 322, 'Grey\'s Anatomy S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218834.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5260, 322, 'Grey\'s Anatomy S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218835.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5261, 322, 'Grey\'s Anatomy S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218836.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5262, 322, 'Grey\'s Anatomy S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218837.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5263, 322, 'Grey\'s Anatomy S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218838.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5264, 322, 'Grey\'s Anatomy S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218839.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5265, 322, 'Grey\'s Anatomy S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218840.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5266, 322, 'Grey\'s Anatomy S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218841.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5267, 322, 'Grey\'s Anatomy S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218842.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5268, 322, 'Grey\'s Anatomy S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218843.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5269, 322, 'Grey\'s Anatomy S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218844.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5270, 322, 'Grey\'s Anatomy S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218845.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5271, 322, 'Grey\'s Anatomy S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/218846.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5272, 322, 'Grey\'s Anatomy S11 E23', 'http://sinalprivado.info:80/series/1533784/1533784/218847.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5273, 322, 'Grey\'s Anatomy S11 E24', 'http://sinalprivado.info:80/series/1533784/1533784/218848.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5274, 322, 'Grey\'s Anatomy S11 E25', 'http://sinalprivado.info:80/series/1533784/1533784/282258.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5275, 323, 'Grey\'s Anatomy S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218849.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5276, 323, 'Grey\'s Anatomy S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218850.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5277, 323, 'Grey\'s Anatomy S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218851.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5278, 323, 'Grey\'s Anatomy S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218852.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5279, 323, 'Grey\'s Anatomy S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218853.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5280, 323, 'Grey\'s Anatomy S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218854.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5281, 323, 'Grey\'s Anatomy S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218855.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5282, 323, 'Grey\'s Anatomy S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218856.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5283, 323, 'Grey\'s Anatomy S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218857.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5284, 323, 'Grey\'s Anatomy S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218858.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5285, 323, 'Grey\'s Anatomy S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218859.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5286, 323, 'Grey\'s Anatomy S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218860.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5287, 323, 'Grey\'s Anatomy S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218861.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5288, 323, 'Grey\'s Anatomy S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218862.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5289, 323, 'Grey\'s Anatomy S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218863.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5290, 323, 'Grey\'s Anatomy S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218864.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5291, 323, 'Grey\'s Anatomy S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218865.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5292, 323, 'Grey\'s Anatomy S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218866.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5293, 323, 'Grey\'s Anatomy S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218867.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5294, 323, 'Grey\'s Anatomy S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218868.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5295, 323, 'Grey\'s Anatomy S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218869.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5296, 323, 'Grey\'s Anatomy S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/218870.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5297, 323, 'Grey\'s Anatomy S12 E23', 'http://sinalprivado.info:80/series/1533784/1533784/218871.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5298, 323, 'Grey\'s Anatomy S12 E24', 'http://sinalprivado.info:80/series/1533784/1533784/218872.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5299, 324, 'Grey\'s Anatomy S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218873.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5300, 324, 'Grey\'s Anatomy S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218874.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5301, 324, 'Grey\'s Anatomy S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218875.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5302, 324, 'Grey\'s Anatomy S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218876.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5303, 324, 'Grey\'s Anatomy S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218877.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5304, 324, 'Grey\'s Anatomy S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218878.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5305, 324, 'Grey\'s Anatomy S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218879.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5306, 324, 'Grey\'s Anatomy S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218880.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5307, 324, 'Grey\'s Anatomy S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218881.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5308, 324, 'Grey\'s Anatomy S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218882.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5309, 324, 'Grey\'s Anatomy S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218883.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5310, 324, 'Grey\'s Anatomy S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218884.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5311, 324, 'Grey\'s Anatomy S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218885.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5312, 324, 'Grey\'s Anatomy S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218886.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5313, 324, 'Grey\'s Anatomy S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218887.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5314, 324, 'Grey\'s Anatomy S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218888.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5315, 324, 'Grey\'s Anatomy S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218889.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5316, 324, 'Grey\'s Anatomy S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218890.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5317, 324, 'Grey\'s Anatomy S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218891.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5318, 324, 'Grey\'s Anatomy S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218892.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5319, 324, 'Grey\'s Anatomy S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218893.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5320, 324, 'Grey\'s Anatomy S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/218894.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5321, 324, 'Grey\'s Anatomy S13 E23', 'http://sinalprivado.info:80/series/1533784/1533784/218895.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5322, 324, 'Grey\'s Anatomy S13 E24', 'http://sinalprivado.info:80/series/1533784/1533784/218896.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5323, 325, 'Grey\'s Anatomy S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218897.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5324, 325, 'Grey\'s Anatomy S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218898.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5325, 325, 'Grey\'s Anatomy S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218899.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5326, 325, 'Grey\'s Anatomy S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218900.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5327, 325, 'Grey\'s Anatomy S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218901.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5328, 325, 'Grey\'s Anatomy S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218902.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5329, 325, 'Grey\'s Anatomy S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218903.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5330, 325, 'Grey\'s Anatomy S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218904.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5331, 325, 'Grey\'s Anatomy S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218905.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5332, 325, 'Grey\'s Anatomy S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218906.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5333, 325, 'Grey\'s Anatomy S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218907.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5334, 325, 'Grey\'s Anatomy S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218908.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(5335, 325, 'Grey\'s Anatomy S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218909.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5336, 325, 'Grey\'s Anatomy S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218910.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5337, 325, 'Grey\'s Anatomy S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218911.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5338, 325, 'Grey\'s Anatomy S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218912.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5339, 325, 'Grey\'s Anatomy S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218913.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5340, 325, 'Grey\'s Anatomy S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218914.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5341, 325, 'Grey\'s Anatomy S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218915.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5342, 325, 'Grey\'s Anatomy S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218916.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5343, 325, 'Grey\'s Anatomy S14 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218917.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5344, 325, 'Grey\'s Anatomy S14 E22', 'http://sinalprivado.info:80/series/1533784/1533784/218918.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5345, 325, 'Grey\'s Anatomy S14 E23', 'http://sinalprivado.info:80/series/1533784/1533784/218919.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5346, 325, 'Grey\'s Anatomy S14 E24', 'http://sinalprivado.info:80/series/1533784/1533784/218920.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5347, 325, 'Grey\'s Anatomy S14 E25', 'http://sinalprivado.info:80/series/1533784/1533784/218921.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5348, 326, 'Grey\'s Anatomy S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218922.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5349, 326, 'Grey\'s Anatomy S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218923.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5350, 326, 'Grey\'s Anatomy S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218924.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5351, 326, 'Grey\'s Anatomy S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218925.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5352, 326, 'Grey\'s Anatomy S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218926.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5353, 326, 'Grey\'s Anatomy S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218927.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5354, 326, 'Grey\'s Anatomy S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218928.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5355, 326, 'Grey\'s Anatomy S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218929.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5356, 326, 'Grey\'s Anatomy S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218930.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5357, 326, 'Grey\'s Anatomy S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218931.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5358, 326, 'Grey\'s Anatomy S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218932.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5359, 326, 'Grey\'s Anatomy S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218933.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5360, 326, 'Grey\'s Anatomy S15 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218934.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5361, 326, 'Grey\'s Anatomy S15 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218935.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5362, 326, 'Grey\'s Anatomy S15 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218936.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5363, 326, 'Grey\'s Anatomy S15 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218937.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5364, 326, 'Grey\'s Anatomy S15 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218938.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5365, 326, 'Grey\'s Anatomy S15 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218939.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5366, 326, 'Grey\'s Anatomy S15 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218940.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5367, 326, 'Grey\'s Anatomy S15 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218941.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5368, 326, 'Grey\'s Anatomy S15 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218942.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5369, 326, 'Grey\'s Anatomy S15 E22', 'http://sinalprivado.info:80/series/1533784/1533784/218943.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5370, 326, 'Grey\'s Anatomy S15 E23', 'http://sinalprivado.info:80/series/1533784/1533784/218944.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5371, 326, 'Grey\'s Anatomy S15 E24', 'http://sinalprivado.info:80/series/1533784/1533784/218945.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5372, 326, 'Grey\'s Anatomy S15 E25', 'http://sinalprivado.info:80/series/1533784/1533784/218946.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5373, 327, 'Grey\'s Anatomy S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218947.mp4', 'http://timg.bdta.pro/images/1026cf9f0500bbed091f76b4617350b0.jpg'),
(5374, 327, 'Grey\'s Anatomy S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218948.mp4', 'http://timg.bdta.pro/images/a227bc97d850934093528ba27f67a704.jpg'),
(5375, 327, 'Grey\'s Anatomy S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218949.mp4', 'http://timg.bdta.pro/images/3428cf70da34c11bae65ade45fc54894.jpg'),
(5376, 327, 'Grey\'s Anatomy S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218950.mp4', 'http://timg.bdta.pro/images/322ae1e69be380558e10241e83469e3c.jpg'),
(5377, 327, 'Grey\'s Anatomy S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218951.mp4', 'http://timg.bdta.pro/images/889414009ca04b94fc4994a83470f37a.jpg'),
(5378, 327, 'Grey\'s Anatomy S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218952.mp4', 'http://timg.bdta.pro/images/81701819b2b8906668d8bad690182239.jpg'),
(5379, 327, 'Grey\'s Anatomy S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218953.mp4', 'http://timg.bdta.pro/images/6a1cd2775352eb746ceca0b327055241.jpg'),
(5380, 327, 'Grey\'s Anatomy S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218954.mp4', 'http://timg.bdta.pro/images/205beaf1abe85eb2a3d7cf13048d3a73.jpg'),
(5381, 327, 'Grey\'s Anatomy S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218955.mp4', 'http://timg.bdta.pro/images/a341b5c448c05cdfaacc6bda2f76a3fc.jpg'),
(5382, 327, 'Grey\'s Anatomy S16 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218956.mp4', 'http://timg.bdta.pro/images/8cb631904a753dc6c6e90cc44f79896c.jpg'),
(5383, 327, 'Grey\'s Anatomy S16 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218957.mp4', 'http://timg.bdta.pro/images/e018b91aab4273ff62b8668b36059a58.jpg'),
(5384, 327, 'Grey\'s Anatomy S16 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218958.mp4', 'http://timg.bdta.pro/images/287abedb5acd7ebae01f05b02a662094.jpg'),
(5385, 327, 'Grey\'s Anatomy S16 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218959.mp4', 'http://timg.bdta.pro/images/b414365a2b1d4dc6d7e6aa57b013c761.jpg'),
(5386, 327, 'Grey\'s Anatomy S16 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218960.mp4', 'http://timg.bdta.pro/images/7e0f1da13f4cb6dc180ef55ec548a15f.jpg'),
(5387, 327, 'Grey\'s Anatomy S16 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218961.mp4', 'http://timg.bdta.pro/images/67a2d7e0bd5f3e7546fbc8380e3bbfea.jpg'),
(5388, 327, 'Grey\'s Anatomy S16 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218962.mp4', 'http://timg.bdta.pro/images/ab4128c8cdc31ce516c459960014b717.jpg'),
(5389, 327, 'Grey\'s Anatomy S16 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218963.mp4', 'http://timg.bdta.pro/images/92cfce745dec121ec81c64a0d8b884ca.jpg'),
(5390, 327, 'Grey\'s Anatomy S16 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218964.mp4', 'http://timg.bdta.pro/images/84a2ac8b6b5a923d6b662ee3ab6d5ab9.jpg'),
(5391, 327, 'Grey\'s Anatomy S16 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218965.mp4', 'http://timg.bdta.pro/images/fbefc5fdfa97d6148b35d524db5837e9.jpg'),
(5392, 327, 'Grey\'s Anatomy S16 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218966.mp4', 'http://timg.bdta.pro/images/f4682673464f200089fa1a2e6d066ee2.jpg'),
(5393, 327, 'Grey\'s Anatomy S16 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218967.mp4', 'http://timg.bdta.pro/images/cb2a21ba9840f2e233a739d7bb92a41c.jpg'),
(5394, 328, 'Grey\'s Anatomy S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218968.mp4', 'http://timg.bdta.pro/images/fbe931222e3fc294a367aa0fe5b980ef.jpg'),
(5395, 328, 'Grey\'s Anatomy S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218969.mp4', 'http://timg.bdta.pro/images/b4c58c6e60cc30513e797ca2392580fe.jpg'),
(5396, 328, 'Grey\'s Anatomy S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218970.mp4', 'http://timg.bdta.pro/images/732fa8e8354fcde6131190c095bb601b.jpg'),
(5397, 328, 'Grey\'s Anatomy S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218971.mp4', 'http://timg.bdta.pro/images/c9b2ba16f731053af7b480dc63bca98e.jpg'),
(5398, 328, 'Grey\'s Anatomy S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218972.mp4', 'http://timg.bdta.pro/images/33fd24e7254e89e59d14d56c85394ade.jpg'),
(5399, 328, 'Grey\'s Anatomy S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218973.mp4', 'http://timg.bdta.pro/images/5d5b4c482866d89a3467251f54b77111.jpg'),
(5400, 328, 'Grey\'s Anatomy S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218974.mp4', 'http://timg.bdta.pro/images/1a33ebd73f61ecded16df25c8d2f28a4.jpg'),
(5401, 328, 'Grey\'s Anatomy S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218975.mp4', 'http://timg.bdta.pro/images/074755d7b04bbcc8e4ab610f3f7745b4.jpg'),
(5402, 328, 'Grey\'s Anatomy S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218976.mp4', 'http://timg.bdta.pro/images/25b4d80280d35dfab4ce6c611edaf615.jpg'),
(5403, 328, 'Grey\'s Anatomy S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218977.mp4', 'http://timg.bdta.pro/images/b6e772d9f5a224e8b98283e1aae538ea.jpg'),
(5404, 328, 'Grey\'s Anatomy S17 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218978.mp4', 'http://timg.bdta.pro/images/aa04fb62f35bf44d3981bcbcff134cb7.jpg'),
(5405, 328, 'Grey\'s Anatomy S17 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218979.mp4', 'http://timg.bdta.pro/images/4e397cdc1e9d524bac4bd0d4975cc9f8.jpg'),
(5406, 328, 'Grey\'s Anatomy S17 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218980.mp4', 'http://timg.bdta.pro/images/ade44fd07ab66fd7c8a11c22c7312871.jpg'),
(5407, 328, 'Grey\'s Anatomy S17 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218981.mp4', 'http://timg.bdta.pro/images/ca7e1622f1211c36624726812b03d0ad.jpg'),
(5408, 328, 'Grey\'s Anatomy S17 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218982.mp4', 'http://timg.bdta.pro/images/e8891a75a47886f4c8c2f7ddcbdba83c.jpg'),
(5409, 328, 'Grey\'s Anatomy S17 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218983.mp4', 'http://timg.bdta.pro/images/3f54de03fc886440499f2dbbd4578c84.jpg'),
(5410, 328, 'Grey\'s Anatomy S17 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218984.mp4', 'http://timg.bdta.pro/images/1de38a34aa22e0d3aee67af3f2ff4531.jpg'),
(5411, 329, 'Grey\'s Anatomy S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218985.mp4', 'http://timg.bdta.pro/images/449179012a389db857d3047db56aba26.jpg'),
(5412, 329, 'Grey\'s Anatomy S18 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218986.mp4', 'http://timg.bdta.pro/images/a30ef19ce18213beb36573c3f97e9f18.jpg'),
(5413, 329, 'Grey\'s Anatomy S18 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218987.mp4', 'http://timg.bdta.pro/images/5b13a7892673aee98ecfbe4b0595d9a4.jpg'),
(5414, 329, 'Grey\'s Anatomy S18 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218988.mp4', 'http://timg.bdta.pro/images/c4c0bc8137bdc65dc246436dfcd82f3f.jpg'),
(5415, 329, 'Grey\'s Anatomy S18 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218989.mp4', 'http://timg.bdta.pro/images/96f79c8c68fe4f3672febd6369bd1de5.jpg'),
(5416, 329, 'Grey\'s Anatomy S18 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218990.mp4', 'http://timg.bdta.pro/images/1e71079edd89cf61a49a1e98c4e7ff6d.jpg'),
(5417, 329, 'Grey\'s Anatomy S18 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218991.mp4', 'http://timg.bdta.pro/images/6fce4136a6035a0f10b3f44d81887c56.jpg'),
(5418, 329, 'Grey\'s Anatomy S18 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218992.mp4', 'http://timg.bdta.pro/images/ee3874e91fcbaca855035a51bfbd935c.jpg'),
(5419, 329, 'Grey\'s Anatomy S18 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218993.mp4', 'http://timg.bdta.pro/images/bd8979fefab49d5e4a252eaa146145fb.jpg'),
(5420, 329, 'Grey\'s Anatomy S18 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218994.mp4', 'http://timg.bdta.pro/images/d3dd0250cc1912ffa314accb9c73666c.jpg'),
(5421, 329, 'Grey\'s Anatomy S18 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218995.mp4', 'http://timg.bdta.pro/images/1649fadab5f2cc18067c4471e0a5a88e.jpg'),
(5422, 329, 'Grey\'s Anatomy S18 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218996.mp4', 'http://timg.bdta.pro/images/71425ec7b3be8ed1b8a69f825af23bb6.jpg'),
(5423, 329, 'Grey\'s Anatomy S18 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218997.mp4', 'http://timg.bdta.pro/images/0d9e82264c8210f477885d45aa53d2e0.jpg'),
(5424, 329, 'Grey\'s Anatomy S18 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218998.mp4', 'http://timg.bdta.pro/images/eca5f9e94cae2239cca49208b198a516.jpg'),
(5425, 329, 'Grey\'s Anatomy S18 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218999.mp4', 'http://timg.bdta.pro/images/65cb1b48650e77c5f46701f659413bca.jpg'),
(5426, 329, 'Grey\'s Anatomy S18 E16', 'http://sinalprivado.info:80/series/1533784/1533784/219000.mp4', 'http://timg.bdta.pro/images/2b78a73744f3cacd08f08963e44f547b.jpg'),
(5427, 329, 'Grey\'s Anatomy S18 E17', 'http://sinalprivado.info:80/series/1533784/1533784/219001.mp4', 'http://timg.bdta.pro/images/3c94c8cbe9e34d1b3a229642ed550558.jpg'),
(5428, 329, 'Grey\'s Anatomy S18 E18', 'http://sinalprivado.info:80/series/1533784/1533784/219002.mp4', 'http://timg.bdta.pro/images/ea79c0261b3fdd77d3ab31cc6a745a72.jpg'),
(5429, 329, 'Grey\'s Anatomy S18 E19', 'http://sinalprivado.info:80/series/1533784/1533784/219003.mp4', 'http://timg.bdta.pro/images/9d8e3f86e36c613fd4f46944ef0a3b44.jpg'),
(5430, 329, 'Grey\'s Anatomy S18 E20', 'http://sinalprivado.info:80/series/1533784/1533784/219004.mp4', 'http://timg.bdta.pro/images/6df8861c93ff70f52441524d88ffa6b3.jpg'),
(5431, 330, 'Grey\'s Anatomy S19 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219005.mp4', 'http://image.tmdb.org/t/p/w1280/a7deg23WAE99WLlDYE9hpyvuCSR.jpg'),
(5432, 330, 'Grey\'s Anatomy S19 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p02hKRrMMVyL5Sg6mG7kJGbMnk7.jpg'),
(5433, 330, 'Grey\'s Anatomy S19 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xv7drHpT02Jkk9RZtKT3CfiC2zT.jpg'),
(5434, 330, 'Grey\'s Anatomy S19 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/thVaFrFJpxO3dbDUbuHbXxg7z6j.jpg'),
(5435, 330, 'Grey\'s Anatomy S19 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x55gjOxoXn0IgpbdjNpa1aLpa1K.jpg'),
(5436, 330, 'Grey\'s Anatomy S19 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oyGDaoPPEonZSlzelj8SckcHj9H.jpg'),
(5437, 330, 'Grey\'s Anatomy S19 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219011.mp4', 'http://image.tmdb.org/t/p/w1280/AbqRJkZp6pm8WBVDiDdQytHvJun.jpg'),
(5438, 330, 'Grey\'s Anatomy S19 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219012.mp4', 'http://image.tmdb.org/t/p/w1280/brlOlcKwFDpWPG81Ue1CGM0l1PD.jpg'),
(5439, 330, 'Grey\'s Anatomy S19 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219013.mp4', 'http://image.tmdb.org/t/p/w1280/AonG13YR85sGsRFBg4ehAjG8wQx.jpg'),
(5440, 330, 'Grey\'s Anatomy S19 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219014.mp4', 'http://image.tmdb.org/t/p/w1280/qhRVuhB7eg3j3BhSxRR1rTrlj3m.jpg'),
(5441, 330, 'Grey\'s Anatomy S19 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219015.mp4', 'http://image.tmdb.org/t/p/w1280/fKK70ZxQajQPIyPxvJft7pwzXW3.jpg'),
(5442, 330, 'Grey\'s Anatomy S19 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219016.mp4', 'http://image.tmdb.org/t/p/w1280/jan3dhLPgkcqL2NHhAQbQ7aYQYd.jpg'),
(5443, 330, 'Grey\'s Anatomy S19 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219017.mp4', 'http://image.tmdb.org/t/p/w1280/dJZX5SZK6eCW4VWbbH0xvAquIDD.jpg'),
(5444, 330, 'Grey\'s Anatomy S19 E14', 'http://sinalprivado.info:80/series/1533784/1533784/219018.mp4', 'http://image.tmdb.org/t/p/w1280/3ZSqvHec7PndR0Jik80xVUjTVmE.jpg'),
(5445, 330, 'Grey\'s Anatomy S19 E15', 'http://sinalprivado.info:80/series/1533784/1533784/219019.mp4', 'http://image.tmdb.org/t/p/w1280/dlMKuxd0ox0rLm8XmceSUiVNRfK.jpg'),
(5446, 330, 'Grey\'s Anatomy S19 E16', 'http://sinalprivado.info:80/series/1533784/1533784/219020.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5447, 330, 'Grey\'s Anatomy S19 E17', 'http://sinalprivado.info:80/series/1533784/1533784/219021.mp4', 'http://image.tmdb.org/t/p/w1280/cT30I8qYp24TzZq31XXPgDv4e7j.jpg'),
(5448, 330, 'Grey\'s Anatomy S19 E18', 'http://sinalprivado.info:80/series/1533784/1533784/219022.mp4', 'http://image.tmdb.org/t/p/w1280/bfgko2PtURa9mkKlWQCaIywK50S.jpg'),
(5449, 330, 'Grey\'s Anatomy S19 E19', 'http://sinalprivado.info:80/series/1533784/1533784/219023.mp4', 'http://image.tmdb.org/t/p/w1280/s2Pn5OjSCRuCno1nTa5YabvhS2c.jpg'),
(5450, 330, 'Grey\'s Anatomy S19 E20', 'http://sinalprivado.info:80/series/1533784/1533784/219024.mp4', 'http://image.tmdb.org/t/p/w1280/jIEW8zoRQMV8cRsz3kz6C9Ieze1.jpg'),
(5451, 331, 'Grey\'s Anatomy S20 E01', 'http://sinalprivado.info:80/series/1533784/1533784/374422.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5452, 331, 'Grey\'s Anatomy S20 E02', 'http://sinalprivado.info:80/series/1533784/1533784/374423.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5453, 331, 'Grey\'s Anatomy S20 E03', 'http://sinalprivado.info:80/series/1533784/1533784/383018.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5454, 331, 'Grey\'s Anatomy S20 E04', 'http://sinalprivado.info:80/series/1533784/1533784/383019.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5455, 331, 'Grey\'s Anatomy S20 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390059.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5456, 331, 'Grey\'s Anatomy S20 E06', 'http://sinalprivado.info:80/series/1533784/1533784/412706.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5457, 331, 'Grey\'s Anatomy S20 E07', 'http://sinalprivado.info:80/series/1533784/1533784/408974.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5458, 331, 'Grey\'s Anatomy S20 E08', 'http://sinalprivado.info:80/series/1533784/1533784/422106.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5459, 331, 'Grey\'s Anatomy S20 E09', 'http://sinalprivado.info:80/series/1533784/1533784/422107.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5460, 331, 'Grey\'s Anatomy S20 E10', 'http://sinalprivado.info:80/series/1533784/1533784/422108.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5461, 332, 'Grey\'s Anatomy S21 E01', 'http://sinalprivado.info:80/series/1533784/1533784/512330.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5462, 332, 'Grey\'s Anatomy S21 E02', 'http://sinalprivado.info:80/series/1533784/1533784/512331.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5463, 332, 'Grey\'s Anatomy S21 E03', 'http://sinalprivado.info:80/series/1533784/1533784/512332.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5464, 332, 'Grey\'s Anatomy S21 E04', 'http://sinalprivado.info:80/series/1533784/1533784/518468.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5465, 332, 'Grey\'s Anatomy S21 E05', 'http://sinalprivado.info:80/series/1533784/1533784/521200.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5466, 332, 'Grey\'s Anatomy S21 E06', 'http://sinalprivado.info:80/series/1533784/1533784/521201.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5467, 332, 'Grey\'s Anatomy S21 E07', 'http://sinalprivado.info:80/series/1533784/1533784/659594.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5468, 332, 'Grey\'s Anatomy S21 E08', 'http://sinalprivado.info:80/series/1533784/1533784/662710.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5469, 332, 'Grey\'s Anatomy S21 E09', 'http://sinalprivado.info:80/series/1533784/1533784/760592.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5470, 332, 'Grey\'s Anatomy S21 E10', 'http://sinalprivado.info:80/series/1533784/1533784/776238.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5471, 332, 'Grey\'s Anatomy S21 E11', 'http://sinalprivado.info:80/series/1533784/1533784/780600.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5472, 332, 'Grey\'s Anatomy S21 E12', 'http://sinalprivado.info:80/series/1533784/1533784/780601.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5473, 332, 'Grey\'s Anatomy S21 E13', 'http://sinalprivado.info:80/series/1533784/1533784/803084.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5474, 332, 'Grey\'s Anatomy S21 E14', 'http://sinalprivado.info:80/series/1533784/1533784/803085.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5475, 332, 'Grey\'s Anatomy S21 E15', 'http://sinalprivado.info:80/series/1533784/1533784/833702.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5476, 332, 'Grey\'s Anatomy S21 E16', 'http://sinalprivado.info:80/series/1533784/1533784/833703.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5477, 332, 'Grey\'s Anatomy S21 E17', 'http://sinalprivado.info:80/series/1533784/1533784/833704.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5478, 332, 'Grey\'s Anatomy S21 E18', 'http://sinalprivado.info:80/series/1533784/1533784/851182.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5479, 333, 'Grey\'s Anatomy S22 E01', 'http://sinalprivado.info:80/series/1533784/1533784/893468.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5480, 333, 'Grey\'s Anatomy S22 E02', 'http://sinalprivado.info:80/series/1533784/1533784/894219.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5481, 333, 'Grey\'s Anatomy S22 E03', 'http://sinalprivado.info:80/series/1533784/1533784/895889.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5482, 333, 'Grey\'s Anatomy S22 E04', 'http://sinalprivado.info:80/series/1533784/1533784/896486.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5483, 333, 'Grey\'s Anatomy S22 E05', 'http://sinalprivado.info:80/series/1533784/1533784/896710.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5484, 333, 'Grey\'s Anatomy S22 E06', 'http://sinalprivado.info:80/series/1533784/1533784/897447.mp4', 'http://gstaticontent.com/images/1HAm7sxXu9eGVvs8BIAlkCKGaTd_big.jpg'),
(5485, 334, 'Grimm S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101344.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5486, 334, 'Grimm S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101345.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5487, 334, 'Grimm S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101346.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5488, 334, 'Grimm S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101347.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5489, 334, 'Grimm S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101348.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5490, 334, 'Grimm S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101349.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5491, 334, 'Grimm S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101350.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5492, 334, 'Grimm S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101351.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5493, 334, 'Grimm S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101352.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5494, 334, 'Grimm S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101353.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5495, 334, 'Grimm S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101354.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5496, 334, 'Grimm S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101355.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5497, 334, 'Grimm S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101356.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5498, 334, 'Grimm S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101357.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5499, 334, 'Grimm S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101358.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5500, 334, 'Grimm S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101359.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5501, 334, 'Grimm S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101360.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5502, 334, 'Grimm S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101361.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5503, 334, 'Grimm S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101362.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5504, 334, 'Grimm S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/101363.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5505, 334, 'Grimm S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/101364.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5506, 334, 'Grimm S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/101365.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5507, 335, 'Grimm S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101366.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5508, 335, 'Grimm S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101367.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5509, 335, 'Grimm S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101368.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5510, 335, 'Grimm S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101369.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5511, 335, 'Grimm S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101370.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5512, 335, 'Grimm S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101371.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5513, 335, 'Grimm S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101372.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5514, 335, 'Grimm S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101373.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5515, 335, 'Grimm S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101374.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5516, 335, 'Grimm S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101375.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5517, 335, 'Grimm S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101376.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5518, 335, 'Grimm S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101377.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5519, 335, 'Grimm S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101378.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5520, 335, 'Grimm S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101379.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5521, 335, 'Grimm S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101380.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5522, 335, 'Grimm S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101381.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5523, 335, 'Grimm S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101382.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5524, 335, 'Grimm S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101383.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5525, 335, 'Grimm S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101384.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5526, 335, 'Grimm S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/101385.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5527, 335, 'Grimm S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/101386.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5528, 335, 'Grimm S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/101387.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5529, 336, 'Grimm S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101388.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5530, 336, 'Grimm S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101389.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5531, 336, 'Grimm S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101390.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5532, 336, 'Grimm S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101391.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5533, 336, 'Grimm S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101392.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5534, 336, 'Grimm S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101393.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5535, 336, 'Grimm S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101394.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5536, 336, 'Grimm S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101395.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5537, 336, 'Grimm S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101396.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5538, 336, 'Grimm S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101397.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5539, 336, 'Grimm S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101398.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5540, 336, 'Grimm S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101399.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5541, 336, 'Grimm S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101400.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5542, 336, 'Grimm S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101401.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5543, 336, 'Grimm S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101402.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5544, 336, 'Grimm S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101403.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5545, 336, 'Grimm S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101404.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5546, 336, 'Grimm S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101405.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5547, 336, 'Grimm S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101406.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5548, 336, 'Grimm S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/101407.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5549, 336, 'Grimm S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/101408.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5550, 336, 'Grimm S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/101409.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5551, 337, 'Grimm S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101410.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5552, 337, 'Grimm S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101411.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5553, 337, 'Grimm S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101412.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5554, 337, 'Grimm S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101413.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5555, 337, 'Grimm S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101414.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5556, 337, 'Grimm S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101415.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5557, 337, 'Grimm S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101416.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5558, 337, 'Grimm S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101417.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5559, 337, 'Grimm S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101418.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5560, 337, 'Grimm S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101419.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5561, 337, 'Grimm S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101420.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5562, 337, 'Grimm S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101421.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5563, 337, 'Grimm S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101422.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5564, 337, 'Grimm S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101423.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5565, 337, 'Grimm S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101424.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5566, 337, 'Grimm S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101425.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5567, 337, 'Grimm S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101426.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5568, 337, 'Grimm S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101427.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5569, 337, 'Grimm S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101428.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5570, 337, 'Grimm S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/101429.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5571, 337, 'Grimm S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/101430.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5572, 337, 'Grimm S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/101431.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5573, 338, 'Grimm S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101432.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5574, 338, 'Grimm S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101433.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5575, 338, 'Grimm S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101434.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5576, 338, 'Grimm S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101435.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5577, 338, 'Grimm S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101436.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5578, 338, 'Grimm S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101437.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5579, 338, 'Grimm S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101438.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5580, 338, 'Grimm S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101439.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5581, 338, 'Grimm S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101440.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5582, 338, 'Grimm S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101441.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5583, 338, 'Grimm S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101442.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5584, 338, 'Grimm S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101443.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5585, 338, 'Grimm S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101444.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5586, 338, 'Grimm S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101445.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5587, 338, 'Grimm S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101446.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5588, 338, 'Grimm S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101447.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5589, 338, 'Grimm S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101448.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5590, 338, 'Grimm S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101449.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5591, 338, 'Grimm S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101450.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5592, 338, 'Grimm S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/101451.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5593, 338, 'Grimm S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/101452.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5594, 338, 'Grimm S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/101453.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5595, 339, 'Grimm S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101454.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5596, 339, 'Grimm S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101455.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5597, 339, 'Grimm S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101456.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5598, 339, 'Grimm S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101457.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5599, 339, 'Grimm S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101458.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5600, 339, 'Grimm S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101459.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5601, 339, 'Grimm S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101460.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5602, 339, 'Grimm S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101461.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5603, 339, 'Grimm S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101462.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5604, 339, 'Grimm S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101463.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5605, 339, 'Grimm S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101464.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5606, 339, 'Grimm S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101465.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5607, 339, 'Grimm S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101466.mp4', 'http://gstaticontent.com/images/5hC8CertBqHbXNPcfm1LZ18VcjD_big.jpg'),
(5608, 340, 'Havaí Cinco-0 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/543215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5609, 340, 'Havaí Cinco-0 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/543217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5610, 340, 'Havaí Cinco-0 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/543219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5611, 340, 'Havaí Cinco-0 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/543221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5612, 340, 'Havaí Cinco-0 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/543223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5613, 340, 'Havaí Cinco-0 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/543225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5614, 340, 'Havaí Cinco-0 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/543227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5615, 340, 'Havaí Cinco-0 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/543229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5616, 340, 'Havaí Cinco-0 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/543231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5617, 340, 'Havaí Cinco-0 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/543233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5618, 340, 'Havaí Cinco-0 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/543235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5619, 340, 'Havaí Cinco-0 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/543237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5620, 340, 'Havaí Cinco-0 S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/543239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5621, 340, 'Havaí Cinco-0 S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/543241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5622, 340, 'Havaí Cinco-0 S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/543243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5623, 340, 'Havaí Cinco-0 S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/543245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5624, 340, 'Havaí Cinco-0 S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/543247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5625, 340, 'Havaí Cinco-0 S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/543249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5626, 340, 'Havaí Cinco-0 S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/543251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5627, 340, 'Havaí Cinco-0 S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/543253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(5628, 340, 'Havaí Cinco-0 S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/543255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5629, 340, 'Havaí Cinco-0 S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/543257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5630, 340, 'Havaí Cinco-0 S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/543259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5631, 340, 'Havaí Cinco-0 S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/543261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5632, 341, 'Havaí Cinco-0 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/543263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5633, 341, 'Havaí Cinco-0 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/543265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5634, 341, 'Havaí Cinco-0 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/543267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5635, 341, 'Havaí Cinco-0 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/543269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5636, 341, 'Havaí Cinco-0 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/543271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5637, 341, 'Havaí Cinco-0 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/543273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5638, 341, 'Havaí Cinco-0 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/543275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5639, 341, 'Havaí Cinco-0 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/543277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5640, 341, 'Havaí Cinco-0 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/543279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5641, 341, 'Havaí Cinco-0 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/543281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5642, 341, 'Havaí Cinco-0 S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/543283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5643, 341, 'Havaí Cinco-0 S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/543285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5644, 341, 'Havaí Cinco-0 S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/543287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5645, 341, 'Havaí Cinco-0 S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/543289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5646, 341, 'Havaí Cinco-0 S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/543291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5647, 341, 'Havaí Cinco-0 S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/543293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5648, 341, 'Havaí Cinco-0 S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/543295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5649, 341, 'Havaí Cinco-0 S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/543297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5650, 341, 'Havaí Cinco-0 S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/543299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5651, 341, 'Havaí Cinco-0 S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/543301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5652, 341, 'Havaí Cinco-0 S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/543303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5653, 341, 'Havaí Cinco-0 S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/543305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5654, 341, 'Havaí Cinco-0 S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/543307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5655, 342, 'Havaí Cinco-0 S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5656, 342, 'Havaí Cinco-0 S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5657, 342, 'Havaí Cinco-0 S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5658, 342, 'Havaí Cinco-0 S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5659, 342, 'Havaí Cinco-0 S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5660, 342, 'Havaí Cinco-0 S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5661, 342, 'Havaí Cinco-0 S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5662, 342, 'Havaí Cinco-0 S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5663, 342, 'Havaí Cinco-0 S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5664, 342, 'Havaí Cinco-0 S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5665, 342, 'Havaí Cinco-0 S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/130814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5666, 342, 'Havaí Cinco-0 S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/130815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5667, 342, 'Havaí Cinco-0 S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/130816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5668, 342, 'Havaí Cinco-0 S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/130817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5669, 342, 'Havaí Cinco-0 S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/130818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5670, 342, 'Havaí Cinco-0 S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/130819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5671, 342, 'Havaí Cinco-0 S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/130820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5672, 342, 'Havaí Cinco-0 S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/130821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5673, 342, 'Havaí Cinco-0 S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/130822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5674, 342, 'Havaí Cinco-0 S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/130823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5675, 342, 'Havaí Cinco-0 S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/130824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5676, 342, 'Havaí Cinco-0 S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/130825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5677, 342, 'Havaí Cinco-0 S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/130826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5678, 342, 'Havaí Cinco-0 S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/130827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5679, 343, 'Havaí Cinco-0 S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5680, 343, 'Havaí Cinco-0 S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5681, 343, 'Havaí Cinco-0 S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5682, 343, 'Havaí Cinco-0 S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5683, 343, 'Havaí Cinco-0 S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5684, 343, 'Havaí Cinco-0 S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5685, 343, 'Havaí Cinco-0 S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5686, 343, 'Havaí Cinco-0 S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5687, 343, 'Havaí Cinco-0 S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5688, 343, 'Havaí Cinco-0 S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5689, 343, 'Havaí Cinco-0 S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/130838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5690, 343, 'Havaí Cinco-0 S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/130839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5691, 343, 'Havaí Cinco-0 S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/130840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5692, 343, 'Havaí Cinco-0 S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/130841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5693, 343, 'Havaí Cinco-0 S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/130842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5694, 343, 'Havaí Cinco-0 S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/130843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5695, 343, 'Havaí Cinco-0 S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/130844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5696, 343, 'Havaí Cinco-0 S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/130845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5697, 343, 'Havaí Cinco-0 S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/130846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5698, 343, 'Havaí Cinco-0 S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/130847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5699, 343, 'Havaí Cinco-0 S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/130848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5700, 343, 'Havaí Cinco-0 S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/130849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5701, 344, 'Havaí Cinco-0 S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5702, 344, 'Havaí Cinco-0 S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5703, 344, 'Havaí Cinco-0 S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5704, 344, 'Havaí Cinco-0 S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5705, 344, 'Havaí Cinco-0 S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5706, 344, 'Havaí Cinco-0 S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5707, 344, 'Havaí Cinco-0 S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5708, 344, 'Havaí Cinco-0 S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5709, 344, 'Havaí Cinco-0 S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5710, 344, 'Havaí Cinco-0 S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5711, 344, 'Havaí Cinco-0 S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/130860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5712, 344, 'Havaí Cinco-0 S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/130861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5713, 344, 'Havaí Cinco-0 S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/130862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5714, 344, 'Havaí Cinco-0 S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/130863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5715, 344, 'Havaí Cinco-0 S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/130864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5716, 344, 'Havaí Cinco-0 S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/130865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5717, 344, 'Havaí Cinco-0 S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/130866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5718, 344, 'Havaí Cinco-0 S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/130867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5719, 344, 'Havaí Cinco-0 S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/130868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5720, 344, 'Havaí Cinco-0 S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/130869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5721, 344, 'Havaí Cinco-0 S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/130870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5722, 344, 'Havaí Cinco-0 S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/130871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5723, 344, 'Havaí Cinco-0 S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/130872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5724, 344, 'Havaí Cinco-0 S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/130873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5725, 344, 'Havaí Cinco-0 S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/130874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5726, 345, 'Havaí Cinco-0 S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5727, 345, 'Havaí Cinco-0 S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5728, 345, 'Havaí Cinco-0 S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5729, 345, 'Havaí Cinco-0 S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5730, 345, 'Havaí Cinco-0 S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5731, 345, 'Havaí Cinco-0 S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5732, 345, 'Havaí Cinco-0 S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5733, 345, 'Havaí Cinco-0 S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5734, 345, 'Havaí Cinco-0 S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5735, 345, 'Havaí Cinco-0 S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5736, 345, 'Havaí Cinco-0 S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/130885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5737, 345, 'Havaí Cinco-0 S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/130886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5738, 345, 'Havaí Cinco-0 S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/130887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5739, 345, 'Havaí Cinco-0 S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/130888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5740, 345, 'Havaí Cinco-0 S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/130889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5741, 345, 'Havaí Cinco-0 S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/130890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5742, 345, 'Havaí Cinco-0 S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/130891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5743, 345, 'Havaí Cinco-0 S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/130892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5744, 345, 'Havaí Cinco-0 S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/130893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5745, 345, 'Havaí Cinco-0 S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/130894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5746, 345, 'Havaí Cinco-0 S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/130895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5747, 345, 'Havaí Cinco-0 S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/130896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5748, 345, 'Havaí Cinco-0 S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/130897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5749, 345, 'Havaí Cinco-0 S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/130898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5750, 345, 'Havaí Cinco-0 S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/130899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5751, 346, 'Havaí Cinco-0 S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5752, 346, 'Havaí Cinco-0 S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5753, 346, 'Havaí Cinco-0 S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5754, 346, 'Havaí Cinco-0 S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5755, 346, 'Havaí Cinco-0 S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5756, 346, 'Havaí Cinco-0 S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5757, 346, 'Havaí Cinco-0 S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5758, 346, 'Havaí Cinco-0 S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5759, 346, 'Havaí Cinco-0 S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5760, 346, 'Havaí Cinco-0 S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5761, 346, 'Havaí Cinco-0 S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/130910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5762, 346, 'Havaí Cinco-0 S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/130911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5763, 346, 'Havaí Cinco-0 S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/130912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5764, 346, 'Havaí Cinco-0 S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/130913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5765, 346, 'Havaí Cinco-0 S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/130914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5766, 346, 'Havaí Cinco-0 S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/130915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5767, 346, 'Havaí Cinco-0 S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/130916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5768, 346, 'Havaí Cinco-0 S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/130917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5769, 346, 'Havaí Cinco-0 S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/130918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5770, 346, 'Havaí Cinco-0 S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/130919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5771, 346, 'Havaí Cinco-0 S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/130920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5772, 346, 'Havaí Cinco-0 S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/130921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5773, 346, 'Havaí Cinco-0 S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/130922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5774, 346, 'Havaí Cinco-0 S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/130923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5775, 346, 'Havaí Cinco-0 S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/130924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5776, 347, 'Havaí Cinco-0 S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5777, 347, 'Havaí Cinco-0 S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5778, 347, 'Havaí Cinco-0 S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5779, 347, 'Havaí Cinco-0 S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5780, 347, 'Havaí Cinco-0 S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5781, 347, 'Havaí Cinco-0 S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5782, 347, 'Havaí Cinco-0 S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5783, 347, 'Havaí Cinco-0 S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5784, 347, 'Havaí Cinco-0 S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5785, 347, 'Havaí Cinco-0 S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5786, 347, 'Havaí Cinco-0 S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/130935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5787, 347, 'Havaí Cinco-0 S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/130936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5788, 347, 'Havaí Cinco-0 S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/130937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5789, 347, 'Havaí Cinco-0 S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/130938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5790, 347, 'Havaí Cinco-0 S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/130939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5791, 347, 'Havaí Cinco-0 S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/130940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5792, 347, 'Havaí Cinco-0 S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/130941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5793, 347, 'Havaí Cinco-0 S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/130942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5794, 347, 'Havaí Cinco-0 S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/130943.mp4', 'http://timg.bdta.pro/images/27c2f5f9d7ee09f48163dd1a52c8f80a.jpg'),
(5795, 347, 'Havaí Cinco-0 S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/130944.mp4', 'http://timg.bdta.pro/images/a1e0ba4f08d9f69d9c985af33cca0112.jpg'),
(5796, 347, 'Havaí Cinco-0 S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/130945.mp4', 'http://timg.bdta.pro/images/8a4769c262e366d8c66a0175684497b1.jpg'),
(5797, 347, 'Havaí Cinco-0 S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/130946.mp4', 'http://timg.bdta.pro/images/b35694b1b8b41117a50244a2d3a28fd5.jpg'),
(5798, 347, 'Havaí Cinco-0 S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/130947.mp4', 'http://timg.bdta.pro/images/77a9e727a940465b15c609eed4664efe.jpg'),
(5799, 347, 'Havaí Cinco-0 S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/130948.mp4', 'http://timg.bdta.pro/images/675fa2a926e322357c295f8ea14003c7.jpg'),
(5800, 347, 'Havaí Cinco-0 S08 E25', 'http://sinalprivado.info:80/series/1533784/1533784/130949.mp4', 'http://timg.bdta.pro/images/2edb771b43ef2905d3a3447909d5a8cc.jpg'),
(5801, 348, 'Havaí Cinco-0 S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130950.mp4', 'http://timg.bdta.pro/images/1976aae6ef7d0fd4ee8c9e6f6f78dccd.jpg'),
(5802, 348, 'Havaí Cinco-0 S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130951.mp4', 'http://timg.bdta.pro/images/5c859605a039999b772b08c6b15a9f68.jpg'),
(5803, 348, 'Havaí Cinco-0 S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130952.mp4', 'http://timg.bdta.pro/images/189433a861795ada7f977f18e4aa7cc9.jpg'),
(5804, 348, 'Havaí Cinco-0 S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130953.mp4', 'http://timg.bdta.pro/images/6e69ff39ab9e3618c46d672ac2112947.jpg'),
(5805, 348, 'Havaí Cinco-0 S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130954.mp4', 'http://timg.bdta.pro/images/5805a7a0d4b0d50cff62478f9b4f23f7.jpg'),
(5806, 348, 'Havaí Cinco-0 S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130955.mp4', 'http://timg.bdta.pro/images/d570b99e9276a7ac6972ded4b111c5cc.jpg'),
(5807, 348, 'Havaí Cinco-0 S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130956.mp4', 'http://timg.bdta.pro/images/29844fefa84e83b3d4f1aef5ddfaacfe.jpg'),
(5808, 348, 'Havaí Cinco-0 S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130957.mp4', 'http://timg.bdta.pro/images/2477809d610c6b5fd30bfdea093b1f07.jpg'),
(5809, 348, 'Havaí Cinco-0 S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130958.mp4', 'http://timg.bdta.pro/images/0cfc5a0329f8b2e51fcf075597e0dea2.jpg'),
(5810, 348, 'Havaí Cinco-0 S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130959.mp4', 'http://timg.bdta.pro/images/7b45b3af7970daf914f4f05ab3d6e0cd.jpg'),
(5811, 348, 'Havaí Cinco-0 S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/130960.mp4', 'http://timg.bdta.pro/images/74fe451ac19b406e42354ca7bf9bf572.jpg'),
(5812, 348, 'Havaí Cinco-0 S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/130961.mp4', 'http://timg.bdta.pro/images/0713ba4cdeb7463ef6b96e1eee26757a.jpg'),
(5813, 348, 'Havaí Cinco-0 S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/130962.mp4', 'http://timg.bdta.pro/images/00dcda457deea15571b3278702f75925.jpg'),
(5814, 348, 'Havaí Cinco-0 S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/130963.mp4', 'http://timg.bdta.pro/images/438f490239553b148ce77039d69c2019.jpg'),
(5815, 348, 'Havaí Cinco-0 S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/130964.mp4', 'http://timg.bdta.pro/images/6a8bbb153155f74d576fb6a51a68bd1f.jpg'),
(5816, 348, 'Havaí Cinco-0 S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/130965.mp4', 'http://timg.bdta.pro/images/3149c206357dcb94878e820d0b3acd27.jpg'),
(5817, 348, 'Havaí Cinco-0 S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/130966.mp4', 'http://timg.bdta.pro/images/98999d98f74ae1c1fed3505a15aaf322.jpg'),
(5818, 348, 'Havaí Cinco-0 S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/130967.mp4', 'http://timg.bdta.pro/images/60a3c0f77b4875a3436d300c8789c3ad.jpg'),
(5819, 348, 'Havaí Cinco-0 S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/130968.mp4', 'http://timg.bdta.pro/images/5eaffb5c4c24fd5bb4953b2e3e77c799.jpg'),
(5820, 348, 'Havaí Cinco-0 S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/130969.mp4', 'http://timg.bdta.pro/images/b88f04bbd07b67eb44d2915aa4caed44.jpg'),
(5821, 348, 'Havaí Cinco-0 S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/130970.mp4', 'http://timg.bdta.pro/images/ff60763625a17c6955c13913b0a28c23.jpg'),
(5822, 348, 'Havaí Cinco-0 S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/130971.mp4', 'http://timg.bdta.pro/images/e060255f0f7274cab8afd636f4f0c39f.jpg'),
(5823, 348, 'Havaí Cinco-0 S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/130972.mp4', 'http://timg.bdta.pro/images/8ad213f6755ec1072616bef258e01daa.jpg'),
(5824, 348, 'Havaí Cinco-0 S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/130973.mp4', 'http://timg.bdta.pro/images/77dc354bde152620bc543b41bb16a527.jpg'),
(5825, 348, 'Havaí Cinco-0 S09 E25', 'http://sinalprivado.info:80/series/1533784/1533784/130974.mp4', 'http://timg.bdta.pro/images/beb24ec788ad7f8613067bcddcedd451.jpg'),
(5826, 349, 'Havaí Cinco-0 S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130975.mp4', 'http://timg.bdta.pro/images/802f1426073aeb15664a7923c0afec0a.jpg'),
(5827, 349, 'Havaí Cinco-0 S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130976.mp4', 'http://timg.bdta.pro/images/5fdcabf41bec04fceb4e3406479661f7.jpg'),
(5828, 349, 'Havaí Cinco-0 S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130977.mp4', 'http://timg.bdta.pro/images/9311713ae81a57c83eeea81e9e637d85.jpg'),
(5829, 349, 'Havaí Cinco-0 S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130978.mp4', 'http://timg.bdta.pro/images/26af53db7570327395249c6b0f603106.jpg'),
(5830, 349, 'Havaí Cinco-0 S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130979.mp4', 'http://timg.bdta.pro/images/f06132c55dd7f616205f074a5a1db131.jpg'),
(5831, 349, 'Havaí Cinco-0 S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130980.mp4', 'http://timg.bdta.pro/images/683915868554363924b856e9790f0a89.jpg'),
(5832, 349, 'Havaí Cinco-0 S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130981.mp4', 'http://timg.bdta.pro/images/902b42adcb0654cdf73a62524c9ca98e.jpg'),
(5833, 349, 'Havaí Cinco-0 S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130982.mp4', 'http://timg.bdta.pro/images/d0d917f123abaa7c6b8fd5711acbcbb3.jpg'),
(5834, 349, 'Havaí Cinco-0 S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130983.mp4', 'http://timg.bdta.pro/images/50c445da94007f989d3f8a9cb3068ebf.jpg'),
(5835, 349, 'Havaí Cinco-0 S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5836, 349, 'Havaí Cinco-0 S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/130985.mp4', 'http://timg.bdta.pro/images/86aecb7a3e54c3c3a6e25f6605dd0e5d.jpg'),
(5837, 349, 'Havaí Cinco-0 S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/130986.mp4', 'http://timg.bdta.pro/images/e76d2c1600a461783e91c35a347626bb.jpg'),
(5838, 349, 'Havaí Cinco-0 S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/130987.mp4', 'http://timg.bdta.pro/images/bce9a8bcaa86497f2e44bb01bf16bb79.jpg'),
(5839, 349, 'Havaí Cinco-0 S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/130988.mp4', 'http://timg.bdta.pro/images/3dad056a4ae775dd2054fd2b76b1ebae.jpg'),
(5840, 349, 'Havaí Cinco-0 S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/130989.mp4', 'http://timg.bdta.pro/images/a67d6fc41cd53ade026995c2bdc659ef.jpg'),
(5841, 349, 'Havaí Cinco-0 S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/130990.mp4', 'http://timg.bdta.pro/images/5622419bcab700d43077bc6526bcd0db.jpg'),
(5842, 349, 'Havaí Cinco-0 S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/130991.mp4', 'http://timg.bdta.pro/images/c53d96424db37c5dff47cdf7ead50518.jpg'),
(5843, 349, 'Havaí Cinco-0 S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/130992.mp4', 'http://timg.bdta.pro/images/a6447f23f0e152b3884fdfac9e43262a.jpg'),
(5844, 349, 'Havaí Cinco-0 S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/130993.mp4', 'http://timg.bdta.pro/images/fec7e5f81d73cf4d7a3f0d4aa984cba0.jpg'),
(5845, 349, 'Havaí Cinco-0 S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/130994.mp4', 'http://timg.bdta.pro/images/e07f8910697efe945de8e5d387dad0bc.jpg'),
(5846, 349, 'Havaí Cinco-0 S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/130995.mp4', 'http://timg.bdta.pro/images/47e5c7b5d598255a7b9f6ad753abb87e.jpg'),
(5847, 349, 'Havaí Cinco-0 S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/130996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(5848, 350, 'Heartland S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214731.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5849, 350, 'Heartland S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214732.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5850, 350, 'Heartland S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214733.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5851, 350, 'Heartland S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214734.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5852, 350, 'Heartland S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214735.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5853, 350, 'Heartland S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214736.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5854, 350, 'Heartland S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214737.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5855, 350, 'Heartland S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214738.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5856, 350, 'Heartland S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214739.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5857, 350, 'Heartland S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214740.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5858, 350, 'Heartland S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214741.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5859, 350, 'Heartland S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214742.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5860, 350, 'Heartland S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214743.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5861, 351, 'Heartland S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214744.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5862, 351, 'Heartland S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214745.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5863, 351, 'Heartland S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214746.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5864, 351, 'Heartland S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214747.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5865, 351, 'Heartland S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214748.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5866, 351, 'Heartland S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214749.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5867, 351, 'Heartland S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214750.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5868, 351, 'Heartland S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214751.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5869, 351, 'Heartland S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214752.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5870, 351, 'Heartland S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214753.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5871, 351, 'Heartland S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214754.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5872, 351, 'Heartland S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214755.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5873, 351, 'Heartland S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214756.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5874, 351, 'Heartland S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214757.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5875, 351, 'Heartland S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214758.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5876, 351, 'Heartland S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214759.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5877, 351, 'Heartland S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214760.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5878, 351, 'Heartland S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214761.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5879, 352, 'Heartland S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214762.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5880, 352, 'Heartland S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214763.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5881, 352, 'Heartland S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214764.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5882, 352, 'Heartland S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214765.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5883, 352, 'Heartland S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214766.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5884, 352, 'Heartland S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214767.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5885, 352, 'Heartland S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214768.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5886, 352, 'Heartland S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214769.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5887, 352, 'Heartland S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214770.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5888, 352, 'Heartland S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214771.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5889, 352, 'Heartland S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214772.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5890, 352, 'Heartland S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214773.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5891, 352, 'Heartland S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214774.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5892, 352, 'Heartland S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214775.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5893, 352, 'Heartland S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214776.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5894, 352, 'Heartland S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214777.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5895, 352, 'Heartland S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214778.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5896, 353, 'Heartland S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214779.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5897, 353, 'Heartland S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214780.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5898, 353, 'Heartland S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214781.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5899, 353, 'Heartland S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214782.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5900, 353, 'Heartland S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214783.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5901, 353, 'Heartland S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214784.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5902, 353, 'Heartland S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214785.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5903, 353, 'Heartland S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214786.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5904, 353, 'Heartland S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214787.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5905, 353, 'Heartland S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214788.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5906, 353, 'Heartland S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214789.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(5907, 353, 'Heartland S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214790.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5908, 353, 'Heartland S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214791.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5909, 353, 'Heartland S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214792.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5910, 353, 'Heartland S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214793.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5911, 353, 'Heartland S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214794.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5912, 353, 'Heartland S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214795.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5913, 353, 'Heartland S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214796.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5914, 354, 'Heartland S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214797.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5915, 354, 'Heartland S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214798.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5916, 354, 'Heartland S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214799.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5917, 354, 'Heartland S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214800.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5918, 354, 'Heartland S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214801.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5919, 354, 'Heartland S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214802.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5920, 354, 'Heartland S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214803.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5921, 354, 'Heartland S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214804.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5922, 354, 'Heartland S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214805.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5923, 354, 'Heartland S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214806.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5924, 354, 'Heartland S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214807.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5925, 354, 'Heartland S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214808.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5926, 354, 'Heartland S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214809.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5927, 354, 'Heartland S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214810.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5928, 354, 'Heartland S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214811.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5929, 354, 'Heartland S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214812.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5930, 354, 'Heartland S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214813.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5931, 354, 'Heartland S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214814.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5932, 355, 'Heartland S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214815.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5933, 355, 'Heartland S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214816.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5934, 355, 'Heartland S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214817.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5935, 355, 'Heartland S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214818.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5936, 355, 'Heartland S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214819.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5937, 355, 'Heartland S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214820.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5938, 355, 'Heartland S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214821.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5939, 355, 'Heartland S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214822.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5940, 355, 'Heartland S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214823.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5941, 355, 'Heartland S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214824.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5942, 355, 'Heartland S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214825.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5943, 355, 'Heartland S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214826.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5944, 355, 'Heartland S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214827.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5945, 355, 'Heartland S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214828.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5946, 355, 'Heartland S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214829.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5947, 355, 'Heartland S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214830.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5948, 355, 'Heartland S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214831.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5949, 355, 'Heartland S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214832.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5950, 356, 'Heartland S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214833.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5951, 356, 'Heartland S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214834.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5952, 356, 'Heartland S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214835.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5953, 356, 'Heartland S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214836.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5954, 356, 'Heartland S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214837.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5955, 356, 'Heartland S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214838.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5956, 356, 'Heartland S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214839.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5957, 356, 'Heartland S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214840.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5958, 356, 'Heartland S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214841.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5959, 356, 'Heartland S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214842.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5960, 356, 'Heartland S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214843.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5961, 356, 'Heartland S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214844.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5962, 356, 'Heartland S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214845.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5963, 356, 'Heartland S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214846.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5964, 356, 'Heartland S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214847.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5965, 356, 'Heartland S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214848.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5966, 356, 'Heartland S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214849.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5967, 356, 'Heartland S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214850.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5968, 357, 'Heartland S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214851.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5969, 357, 'Heartland S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214852.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5970, 357, 'Heartland S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214853.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5971, 357, 'Heartland S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214854.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5972, 357, 'Heartland S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214855.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5973, 357, 'Heartland S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214856.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5974, 357, 'Heartland S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214857.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5975, 357, 'Heartland S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214858.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5976, 357, 'Heartland S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214859.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5977, 357, 'Heartland S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214860.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5978, 357, 'Heartland S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214861.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5979, 357, 'Heartland S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214862.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5980, 357, 'Heartland S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214863.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5981, 357, 'Heartland S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214864.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5982, 357, 'Heartland S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214865.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5983, 357, 'Heartland S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214866.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5984, 357, 'Heartland S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214867.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5985, 357, 'Heartland S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214868.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5986, 358, 'Heartland S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214869.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5987, 358, 'Heartland S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214870.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5988, 358, 'Heartland S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214871.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5989, 358, 'Heartland S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214872.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5990, 358, 'Heartland S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214873.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5991, 358, 'Heartland S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214874.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5992, 358, 'Heartland S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214875.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5993, 358, 'Heartland S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214876.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5994, 358, 'Heartland S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214877.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5995, 358, 'Heartland S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214878.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5996, 358, 'Heartland S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214879.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5997, 358, 'Heartland S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214880.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5998, 358, 'Heartland S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214881.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(5999, 358, 'Heartland S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214882.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6000, 358, 'Heartland S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214883.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6001, 358, 'Heartland S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214884.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6002, 358, 'Heartland S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214885.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6003, 358, 'Heartland S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214886.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6004, 359, 'Heartland S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214887.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6005, 359, 'Heartland S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214888.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6006, 359, 'Heartland S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214889.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6007, 359, 'Heartland S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214890.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6008, 359, 'Heartland S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214891.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6009, 359, 'Heartland S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214892.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6010, 359, 'Heartland S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214893.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6011, 359, 'Heartland S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214894.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6012, 359, 'Heartland S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214895.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6013, 359, 'Heartland S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214896.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6014, 359, 'Heartland S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214897.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6015, 359, 'Heartland S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214898.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6016, 359, 'Heartland S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214899.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6017, 359, 'Heartland S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214900.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6018, 359, 'Heartland S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214901.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6019, 359, 'Heartland S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214902.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6020, 359, 'Heartland S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214903.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6021, 359, 'Heartland S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214904.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6022, 360, 'Heartland S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214905.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6023, 360, 'Heartland S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214906.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6024, 360, 'Heartland S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214907.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6025, 360, 'Heartland S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214908.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6026, 360, 'Heartland S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214909.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6027, 360, 'Heartland S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214910.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6028, 360, 'Heartland S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214911.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6029, 360, 'Heartland S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214912.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6030, 360, 'Heartland S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214913.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6031, 360, 'Heartland S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214914.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6032, 360, 'Heartland S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214915.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6033, 360, 'Heartland S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214916.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6034, 360, 'Heartland S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214917.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6035, 360, 'Heartland S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214918.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6036, 360, 'Heartland S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214919.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6037, 360, 'Heartland S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214920.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6038, 360, 'Heartland S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214921.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6039, 360, 'Heartland S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214922.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6040, 361, 'Heartland S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214923.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6041, 361, 'Heartland S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214924.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6042, 361, 'Heartland S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214925.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6043, 361, 'Heartland S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214926.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6044, 361, 'Heartland S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214927.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6045, 361, 'Heartland S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214928.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6046, 361, 'Heartland S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214929.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6047, 361, 'Heartland S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214930.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6048, 361, 'Heartland S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214931.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6049, 361, 'Heartland S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214932.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6050, 361, 'Heartland S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214933.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6051, 362, 'Heartland S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214934.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6052, 362, 'Heartland S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214935.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6053, 362, 'Heartland S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214936.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6054, 362, 'Heartland S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214937.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6055, 362, 'Heartland S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214938.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6056, 362, 'Heartland S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214939.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6057, 362, 'Heartland S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214940.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6058, 362, 'Heartland S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214941.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6059, 362, 'Heartland S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214942.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6060, 362, 'Heartland S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214943.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6061, 363, 'Heartland S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214944.mp4', 'http://timg.bdta.pro/images/86b271fea7af741ff37c1900ecfb3cb0.jpg'),
(6062, 363, 'Heartland S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214945.mp4', 'http://timg.bdta.pro/images/97a1c1c4a1faa7f4f33625447b83aebf.jpg'),
(6063, 363, 'Heartland S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214946.mp4', 'http://timg.bdta.pro/images/c89a8180c2103726ddb9571691d960a4.jpg'),
(6064, 363, 'Heartland S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214947.mp4', 'http://timg.bdta.pro/images/1bc739bf8acad08ac64852770add6c91.jpg'),
(6065, 363, 'Heartland S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214948.mp4', 'http://timg.bdta.pro/images/295d8e879f1f79050c73ec54fb70d378.jpg'),
(6066, 363, 'Heartland S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214949.mp4', 'http://timg.bdta.pro/images/fc599ef533ff3e470eabd123e27b14b5.jpg'),
(6067, 363, 'Heartland S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214950.mp4', 'http://timg.bdta.pro/images/46e494de7772b45704b08746d3a98ab2.jpg'),
(6068, 363, 'Heartland S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214951.mp4', 'http://timg.bdta.pro/images/68c0a41416e259dc7864a8db5097e2ff.jpg'),
(6069, 363, 'Heartland S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214952.mp4', 'http://timg.bdta.pro/images/d70b52ef25fa863da5dc6bd0c69e98af.jpg'),
(6070, 363, 'Heartland S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214953.mp4', 'http://timg.bdta.pro/images/3a467b70fc1e088a338850a503f9f06b.jpg'),
(6071, 364, 'Heartland S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214954.mp4', 'http://timg.bdta.pro/images/5fa08a77dc325381dda62e133712edfb.jpg'),
(6072, 364, 'Heartland S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214955.mp4', 'http://timg.bdta.pro/images/b3cc0c45a02bf2328500c41e30b01196.jpg'),
(6073, 364, 'Heartland S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214956.mp4', 'http://timg.bdta.pro/images/4cc95d89c949df97b70f737adca749ec.jpg'),
(6074, 364, 'Heartland S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214957.mp4', 'http://timg.bdta.pro/images/505c7e622e01e22bccd808d84b19f3ec.jpg'),
(6075, 364, 'Heartland S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214958.mp4', 'http://timg.bdta.pro/images/6816b0e0accb5f74c171c31065caf1f9.jpg'),
(6076, 364, 'Heartland S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214959.mp4', 'http://timg.bdta.pro/images/04cc60a1ce89377012ea7107a1ca5c87.jpg'),
(6077, 364, 'Heartland S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214960.mp4', 'http://timg.bdta.pro/images/515792dbc11b936e403234590c972853.jpg'),
(6078, 364, 'Heartland S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214961.mp4', 'http://timg.bdta.pro/images/cc4ba0601f3fdf98924478228bfaade0.jpg'),
(6079, 364, 'Heartland S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214962.mp4', 'http://timg.bdta.pro/images/d6616edab02a69461ee6f7336bfb0d3a.jpg'),
(6080, 364, 'Heartland S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214963.mp4', 'http://timg.bdta.pro/images/6b837fa24135925e3866cfa549c46b6e.jpg'),
(6081, 365, 'Heartland S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7wpFHDnB6iVmWgUKsfkn5J3m9B5.jpg'),
(6082, 365, 'Heartland S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cTlMD7Gtl7jiJ4MmRuECLRQ8Y5U.jpg'),
(6083, 365, 'Heartland S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glELTkFYeu3ZhjH7BdfyDeTIfVr.jpg'),
(6084, 365, 'Heartland S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s0F00R1jT6z8wUXO2TnIT8o2JKF.jpg'),
(6085, 365, 'Heartland S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/abKoCLT4PSvrTLx3qNuqy95fWhv.jpg'),
(6086, 365, 'Heartland S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g4r9iWYEXgt8D5v0OnLUYo2H3ug.jpg'),
(6087, 365, 'Heartland S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p5v3ErtwAqkpRvVS6ZOeK8gHjWn.jpg'),
(6088, 365, 'Heartland S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6cEarV6UrXY8FBUhElfYQPib7Wq.jpg'),
(6089, 365, 'Heartland S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w7Mfqibj3uZvmYphQ9kRhYpSitu.jpg'),
(6090, 365, 'Heartland S16 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/om6nvzIRH4XHEZbeTCBMrMYfAh5.jpg'),
(6091, 365, 'Heartland S16 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ixh3H3gxPecbRQ3MKnYYJkfUfpW.jpg'),
(6092, 365, 'Heartland S16 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4nlSaWhsi2T41RjQRBb7NqMvnQn.jpg'),
(6093, 365, 'Heartland S16 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1mDlyBc8i50yjRzs7zWW4SAh7bj.jpg'),
(6094, 365, 'Heartland S16 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k8fMgz9zAj11cZxWVBEjUXJKNFW.jpg'),
(6095, 365, 'Heartland S16 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t87uOdSVDhqGmPbgsKy80P9MPNV.jpg'),
(6096, 366, 'Heartland S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347469.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6097, 366, 'Heartland S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347470.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6098, 366, 'Heartland S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347471.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6099, 366, 'Heartland S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347472.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6100, 366, 'Heartland S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347473.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6101, 366, 'Heartland S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347474.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6102, 366, 'Heartland S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347475.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6103, 366, 'Heartland S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347476.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6104, 366, 'Heartland S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347477.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6105, 366, 'Heartland S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347478.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6106, 367, 'Heartland S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/885317.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6107, 367, 'Heartland S18 E02', 'http://sinalprivado.info:80/series/1533784/1533784/885318.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6108, 367, 'Heartland S18 E03', 'http://sinalprivado.info:80/series/1533784/1533784/885319.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6109, 367, 'Heartland S18 E04', 'http://sinalprivado.info:80/series/1533784/1533784/885320.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6110, 367, 'Heartland S18 E05', 'http://sinalprivado.info:80/series/1533784/1533784/885321.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6111, 367, 'Heartland S18 E06', 'http://sinalprivado.info:80/series/1533784/1533784/885322.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6112, 367, 'Heartland S18 E07', 'http://sinalprivado.info:80/series/1533784/1533784/885323.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6113, 367, 'Heartland S18 E08', 'http://sinalprivado.info:80/series/1533784/1533784/885324.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6114, 367, 'Heartland S18 E09', 'http://sinalprivado.info:80/series/1533784/1533784/885325.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6115, 367, 'Heartland S18 E10', 'http://sinalprivado.info:80/series/1533784/1533784/885326.mp4', 'http://gstaticontent.com/images/3238521bb3949f8cbb5454d980710c2d.jpg'),
(6116, 368, 'Heroes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101497.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6117, 368, 'Heroes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101498.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6118, 368, 'Heroes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101499.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6119, 368, 'Heroes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101500.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6120, 368, 'Heroes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101501.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6121, 368, 'Heroes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101502.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6122, 368, 'Heroes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101503.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6123, 368, 'Heroes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101504.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6124, 368, 'Heroes S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101505.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6125, 368, 'Heroes S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101506.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6126, 368, 'Heroes S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101507.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6127, 368, 'Heroes S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101508.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6128, 368, 'Heroes S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101509.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6129, 368, 'Heroes S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101510.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6130, 368, 'Heroes S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101511.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6131, 368, 'Heroes S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101512.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6132, 368, 'Heroes S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101513.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6133, 368, 'Heroes S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101514.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6134, 368, 'Heroes S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101515.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6135, 368, 'Heroes S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/101516.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6136, 368, 'Heroes S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/101517.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6137, 368, 'Heroes S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/101518.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6138, 368, 'Heroes S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/101519.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6139, 369, 'Heroes S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101520.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6140, 369, 'Heroes S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101521.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6141, 369, 'Heroes S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101522.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6142, 369, 'Heroes S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101523.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6143, 369, 'Heroes S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101524.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6144, 369, 'Heroes S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101525.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6145, 369, 'Heroes S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101526.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6146, 369, 'Heroes S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101527.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6147, 369, 'Heroes S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101528.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6148, 369, 'Heroes S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101529.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6149, 369, 'Heroes S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101530.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6150, 370, 'Heroes S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101531.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6151, 370, 'Heroes S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101532.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6152, 370, 'Heroes S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101533.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6153, 370, 'Heroes S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101534.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6154, 370, 'Heroes S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101535.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6155, 370, 'Heroes S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101536.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6156, 370, 'Heroes S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101537.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6157, 370, 'Heroes S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101538.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6158, 370, 'Heroes S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101539.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6159, 370, 'Heroes S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101540.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6160, 370, 'Heroes S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101541.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6161, 370, 'Heroes S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101542.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6162, 370, 'Heroes S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101543.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6163, 370, 'Heroes S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101544.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6164, 370, 'Heroes S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101545.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6165, 370, 'Heroes S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101546.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6166, 370, 'Heroes S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101547.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6167, 370, 'Heroes S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101548.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6168, 370, 'Heroes S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101549.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6169, 370, 'Heroes S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/101550.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6170, 370, 'Heroes S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/101551.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6171, 370, 'Heroes S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/101552.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6172, 370, 'Heroes S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/101553.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6173, 370, 'Heroes S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/101554.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6174, 370, 'Heroes S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/101555.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6175, 371, 'Heroes S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101556.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6176, 371, 'Heroes S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101557.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6177, 371, 'Heroes S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101558.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6178, 371, 'Heroes S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101559.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6179, 371, 'Heroes S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101560.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6180, 371, 'Heroes S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101561.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6181, 371, 'Heroes S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101562.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6182, 371, 'Heroes S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101563.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6183, 371, 'Heroes S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101564.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6184, 371, 'Heroes S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101565.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6185, 371, 'Heroes S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101566.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6186, 371, 'Heroes S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101567.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6187, 371, 'Heroes S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101568.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6188, 371, 'Heroes S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101569.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6189, 371, 'Heroes S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/101570.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6190, 371, 'Heroes S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/101571.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6191, 371, 'Heroes S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/101572.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6192, 371, 'Heroes S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/101573.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6193, 371, 'Heroes S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/101574.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6194, 372, 'Heroes S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101575.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6195, 372, 'Heroes S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101576.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6196, 372, 'Heroes S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101577.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6197, 372, 'Heroes S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101578.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6198, 372, 'Heroes S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101579.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6199, 372, 'Heroes S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101580.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6200, 372, 'Heroes S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101581.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6201, 372, 'Heroes S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101582.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6202, 372, 'Heroes S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101583.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6203, 372, 'Heroes S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101584.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(6204, 372, 'Heroes S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101585.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6205, 372, 'Heroes S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101586.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6206, 372, 'Heroes S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101587.mp4', 'http://gstaticontent.com/images/7Cn1Sj5yipu7tBX14BbaXuBHbL1_big.jpg'),
(6207, 373, 'Homeland S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143563.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6208, 373, 'Homeland S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143564.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6209, 373, 'Homeland S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143565.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6210, 373, 'Homeland S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143566.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6211, 373, 'Homeland S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143567.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6212, 373, 'Homeland S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143568.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6213, 373, 'Homeland S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143569.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6214, 373, 'Homeland S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143570.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6215, 373, 'Homeland S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143571.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6216, 373, 'Homeland S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143572.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6217, 373, 'Homeland S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143573.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6218, 373, 'Homeland S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143574.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6219, 374, 'Homeland S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143575.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6220, 374, 'Homeland S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143576.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6221, 374, 'Homeland S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143577.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6222, 374, 'Homeland S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143578.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6223, 374, 'Homeland S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143579.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6224, 374, 'Homeland S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143580.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6225, 374, 'Homeland S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143581.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6226, 374, 'Homeland S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143582.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6227, 374, 'Homeland S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143583.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6228, 374, 'Homeland S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143584.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6229, 374, 'Homeland S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143585.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6230, 374, 'Homeland S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143586.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6231, 375, 'Homeland S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143587.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6232, 375, 'Homeland S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143588.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6233, 375, 'Homeland S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143589.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6234, 375, 'Homeland S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143590.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6235, 375, 'Homeland S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143591.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6236, 375, 'Homeland S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143592.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6237, 375, 'Homeland S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143593.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6238, 375, 'Homeland S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143594.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6239, 375, 'Homeland S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143595.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6240, 375, 'Homeland S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143596.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6241, 375, 'Homeland S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143597.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6242, 375, 'Homeland S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143598.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6243, 376, 'Homeland S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143599.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6244, 376, 'Homeland S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143600.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6245, 376, 'Homeland S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143601.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6246, 376, 'Homeland S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143602.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6247, 376, 'Homeland S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143603.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6248, 376, 'Homeland S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143604.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6249, 376, 'Homeland S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143605.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6250, 376, 'Homeland S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143606.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6251, 376, 'Homeland S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143607.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6252, 376, 'Homeland S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143608.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6253, 376, 'Homeland S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143609.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6254, 376, 'Homeland S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143610.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6255, 377, 'Homeland S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143611.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6256, 377, 'Homeland S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143612.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6257, 377, 'Homeland S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143613.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6258, 377, 'Homeland S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143614.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6259, 377, 'Homeland S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143615.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6260, 377, 'Homeland S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143616.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6261, 377, 'Homeland S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143617.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6262, 377, 'Homeland S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143618.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6263, 377, 'Homeland S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143619.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6264, 377, 'Homeland S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143620.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6265, 377, 'Homeland S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143621.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6266, 377, 'Homeland S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143622.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6267, 378, 'Homeland S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143623.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6268, 378, 'Homeland S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143624.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6269, 378, 'Homeland S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143625.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6270, 378, 'Homeland S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143626.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6271, 378, 'Homeland S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143627.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6272, 378, 'Homeland S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143628.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6273, 378, 'Homeland S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143629.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6274, 378, 'Homeland S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143630.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6275, 378, 'Homeland S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143631.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6276, 378, 'Homeland S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143632.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6277, 378, 'Homeland S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143633.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6278, 378, 'Homeland S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143634.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6279, 379, 'Homeland S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143635.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6280, 379, 'Homeland S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143636.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6281, 379, 'Homeland S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143637.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6282, 379, 'Homeland S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143638.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6283, 379, 'Homeland S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143639.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6284, 379, 'Homeland S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143640.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6285, 379, 'Homeland S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143641.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6286, 379, 'Homeland S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143642.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6287, 379, 'Homeland S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143643.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6288, 379, 'Homeland S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143644.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6289, 379, 'Homeland S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143645.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6290, 379, 'Homeland S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143646.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6291, 380, 'Homeland S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143647.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6292, 380, 'Homeland S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143648.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6293, 380, 'Homeland S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143649.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6294, 380, 'Homeland S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143650.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6295, 380, 'Homeland S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143651.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6296, 380, 'Homeland S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143652.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6297, 380, 'Homeland S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143653.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6298, 380, 'Homeland S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143654.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6299, 380, 'Homeland S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143655.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6300, 380, 'Homeland S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143656.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6301, 380, 'Homeland S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143657.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6302, 380, 'Homeland S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143658.mp4', 'http://gstaticontent.com/images/kmZTqevNRhyxvIyXWvnbQEY69ab_big.jpg'),
(6303, 381, 'House Of Cards S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101588.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6304, 381, 'House Of Cards S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101589.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6305, 381, 'House Of Cards S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101590.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6306, 381, 'House Of Cards S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101591.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6307, 381, 'House Of Cards S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101592.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6308, 381, 'House Of Cards S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101593.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6309, 381, 'House Of Cards S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101594.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6310, 381, 'House Of Cards S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101595.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6311, 381, 'House Of Cards S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101596.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6312, 381, 'House Of Cards S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101597.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6313, 381, 'House Of Cards S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101598.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6314, 381, 'House Of Cards S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101599.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6315, 381, 'House Of Cards S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101600.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6316, 382, 'House Of Cards S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101601.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6317, 382, 'House Of Cards S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101602.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6318, 382, 'House Of Cards S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101603.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6319, 382, 'House Of Cards S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101604.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6320, 382, 'House Of Cards S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101605.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6321, 382, 'House Of Cards S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101606.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6322, 382, 'House Of Cards S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101607.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6323, 382, 'House Of Cards S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101608.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6324, 382, 'House Of Cards S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101609.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6325, 382, 'House Of Cards S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101610.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6326, 382, 'House Of Cards S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101611.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6327, 382, 'House Of Cards S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101612.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6328, 382, 'House Of Cards S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101613.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6329, 383, 'House Of Cards S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101614.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6330, 383, 'House Of Cards S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101615.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6331, 383, 'House Of Cards S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101616.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6332, 383, 'House Of Cards S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101617.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6333, 383, 'House Of Cards S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101618.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6334, 383, 'House Of Cards S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101619.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6335, 383, 'House Of Cards S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101620.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6336, 383, 'House Of Cards S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101621.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6337, 383, 'House Of Cards S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101622.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6338, 383, 'House Of Cards S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101623.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6339, 383, 'House Of Cards S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101624.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6340, 383, 'House Of Cards S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101625.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6341, 383, 'House Of Cards S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101626.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6342, 384, 'House Of Cards S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101627.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6343, 384, 'House Of Cards S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101628.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6344, 384, 'House Of Cards S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101629.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6345, 384, 'House Of Cards S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101630.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6346, 384, 'House Of Cards S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101631.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6347, 384, 'House Of Cards S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101632.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6348, 384, 'House Of Cards S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101633.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6349, 384, 'House Of Cards S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101634.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6350, 384, 'House Of Cards S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101635.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6351, 384, 'House Of Cards S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101636.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6352, 384, 'House Of Cards S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101637.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6353, 384, 'House Of Cards S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101638.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6354, 384, 'House Of Cards S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101639.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6355, 385, 'House Of Cards S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101640.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6356, 385, 'House Of Cards S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101641.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6357, 385, 'House Of Cards S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101642.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6358, 385, 'House Of Cards S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101643.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6359, 385, 'House Of Cards S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101644.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6360, 385, 'House Of Cards S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101645.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6361, 385, 'House Of Cards S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101646.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6362, 385, 'House Of Cards S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101647.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6363, 385, 'House Of Cards S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101648.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6364, 385, 'House Of Cards S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101649.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6365, 385, 'House Of Cards S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101650.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6366, 385, 'House Of Cards S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101651.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6367, 385, 'House Of Cards S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101652.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6368, 385, 'House Of Cards S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/101653.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6369, 386, 'House Of Cards S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101654.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6370, 386, 'House Of Cards S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101655.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6371, 386, 'House Of Cards S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101656.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6372, 386, 'House Of Cards S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101657.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6373, 386, 'House Of Cards S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101658.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6374, 386, 'House Of Cards S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101659.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6375, 386, 'House Of Cards S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101660.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6376, 386, 'House Of Cards S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101661.mp4', 'http://gstaticontent.com/images/hKWxWjFwnMvkWQawbhvC0Y7ygQ8_big.jpg'),
(6377, 387, 'How To Get Away With Murder S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136062.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6378, 387, 'How To Get Away With Murder S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136063.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6379, 387, 'How To Get Away With Murder S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136064.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6380, 387, 'How To Get Away With Murder S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136065.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6381, 387, 'How To Get Away With Murder S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136066.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6382, 387, 'How To Get Away With Murder S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136067.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6383, 387, 'How To Get Away With Murder S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136068.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6384, 387, 'How To Get Away With Murder S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136069.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6385, 387, 'How To Get Away With Murder S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136070.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6386, 387, 'How To Get Away With Murder S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136071.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6387, 387, 'How To Get Away With Murder S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136072.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6388, 387, 'How To Get Away With Murder S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136073.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6389, 387, 'How To Get Away With Murder S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136074.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6390, 387, 'How To Get Away With Murder S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/136075.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6391, 387, 'How To Get Away With Murder S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/136076.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6392, 388, 'How To Get Away With Murder S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136077.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6393, 388, 'How To Get Away With Murder S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136078.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6394, 388, 'How To Get Away With Murder S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136079.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6395, 388, 'How To Get Away With Murder S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136080.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6396, 388, 'How To Get Away With Murder S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136081.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6397, 388, 'How To Get Away With Murder S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136082.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6398, 388, 'How To Get Away With Murder S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136083.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6399, 388, 'How To Get Away With Murder S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136084.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6400, 388, 'How To Get Away With Murder S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136085.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6401, 388, 'How To Get Away With Murder S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136086.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6402, 388, 'How To Get Away With Murder S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136087.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6403, 388, 'How To Get Away With Murder S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136088.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6404, 388, 'How To Get Away With Murder S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136089.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6405, 388, 'How To Get Away With Murder S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/136090.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6406, 388, 'How To Get Away With Murder S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/136091.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6407, 389, 'How To Get Away With Murder S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136092.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6408, 389, 'How To Get Away With Murder S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136093.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6409, 389, 'How To Get Away With Murder S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136094.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6410, 389, 'How To Get Away With Murder S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136095.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6411, 389, 'How To Get Away With Murder S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136096.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6412, 389, 'How To Get Away With Murder S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136097.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6413, 389, 'How To Get Away With Murder S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136098.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6414, 389, 'How To Get Away With Murder S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136099.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6415, 389, 'How To Get Away With Murder S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136100.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6416, 389, 'How To Get Away With Murder S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136101.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6417, 389, 'How To Get Away With Murder S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136102.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6418, 389, 'How To Get Away With Murder S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136103.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6419, 389, 'How To Get Away With Murder S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136104.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6420, 389, 'How To Get Away With Murder S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/136105.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6421, 389, 'How To Get Away With Murder S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/136106.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6422, 390, 'How To Get Away With Murder S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136107.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6423, 390, 'How To Get Away With Murder S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136108.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6424, 390, 'How To Get Away With Murder S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136109.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6425, 390, 'How To Get Away With Murder S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136110.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6426, 390, 'How To Get Away With Murder S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136111.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6427, 390, 'How To Get Away With Murder S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136112.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6428, 390, 'How To Get Away With Murder S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136113.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6429, 390, 'How To Get Away With Murder S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136114.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6430, 390, 'How To Get Away With Murder S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136115.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6431, 390, 'How To Get Away With Murder S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136116.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6432, 390, 'How To Get Away With Murder S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136117.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6433, 390, 'How To Get Away With Murder S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136118.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6434, 390, 'How To Get Away With Murder S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136119.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6435, 390, 'How To Get Away With Murder S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/136120.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6436, 390, 'How To Get Away With Murder S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/136121.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6437, 391, 'How To Get Away With Murder S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136122.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6438, 391, 'How To Get Away With Murder S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136123.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6439, 391, 'How To Get Away With Murder S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136124.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6440, 391, 'How To Get Away With Murder S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136125.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6441, 391, 'How To Get Away With Murder S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136126.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6442, 391, 'How To Get Away With Murder S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136127.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6443, 391, 'How To Get Away With Murder S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136128.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6444, 391, 'How To Get Away With Murder S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136129.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6445, 391, 'How To Get Away With Murder S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136130.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6446, 391, 'How To Get Away With Murder S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136131.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6447, 391, 'How To Get Away With Murder S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136132.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6448, 391, 'How To Get Away With Murder S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136133.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6449, 391, 'How To Get Away With Murder S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136134.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6450, 391, 'How To Get Away With Murder S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/136135.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6451, 391, 'How To Get Away With Murder S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/136136.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6452, 392, 'How To Get Away With Murder S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136137.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6453, 392, 'How To Get Away With Murder S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136138.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6454, 392, 'How To Get Away With Murder S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136139.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6455, 392, 'How To Get Away With Murder S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136140.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6456, 392, 'How To Get Away With Murder S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136141.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6457, 392, 'How To Get Away With Murder S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136142.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6458, 392, 'How To Get Away With Murder S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136143.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6459, 392, 'How To Get Away With Murder S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136144.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6460, 392, 'How To Get Away With Murder S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136145.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6461, 392, 'How To Get Away With Murder S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136146.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6462, 392, 'How To Get Away With Murder S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136147.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6463, 392, 'How To Get Away With Murder S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136148.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6464, 392, 'How To Get Away With Murder S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136149.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6465, 392, 'How To Get Away With Murder S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/136150.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6466, 392, 'How To Get Away With Murder S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/136151.mp4', 'http://gstaticontent.com/images/sohKB3pnzq6iWOgLVxk8mpCFgTO_big.jpg'),
(6467, 393, 'Ilha de Ferro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg'),
(6468, 393, 'Ilha de Ferro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg'),
(6469, 393, 'Ilha de Ferro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg'),
(6470, 393, 'Ilha de Ferro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg'),
(6471, 393, 'Ilha de Ferro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg'),
(6472, 393, 'Ilha de Ferro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg'),
(6473, 393, 'Ilha de Ferro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg'),
(6474, 393, 'Ilha de Ferro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg'),
(6475, 393, 'Ilha de Ferro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg'),
(6476, 393, 'Ilha de Ferro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg'),
(6477, 393, 'Ilha de Ferro S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg'),
(6478, 393, 'Ilha de Ferro S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/106655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg'),
(6479, 394, 'Ilha de Ferro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg'),
(6480, 394, 'Ilha de Ferro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg'),
(6481, 394, 'Ilha de Ferro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg'),
(6482, 394, 'Ilha de Ferro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg'),
(6483, 394, 'Ilha de Ferro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg'),
(6484, 394, 'Ilha de Ferro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg'),
(6485, 394, 'Ilha de Ferro S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg'),
(6486, 394, 'Ilha de Ferro S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(6487, 394, 'Ilha de Ferro S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg'),
(6488, 394, 'Ilha de Ferro S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jN03YxeJ4eylVbUuavYUdL84N4T.jpg'),
(6489, 395, 'Impuros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233469.mp4', 'http://timg.bdta.pro/images/7b9a72ef6ff0f8fb8424d24dc8e2c59c.jpg'),
(6490, 395, 'Impuros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233470.mp4', 'http://timg.bdta.pro/images/9c4ab7ee314b66cff1f74ac95cb00b07.jpg'),
(6491, 395, 'Impuros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233471.mp4', 'http://timg.bdta.pro/images/ebb2877b1ed4da734a6e0d0dd27c4145.jpg'),
(6492, 395, 'Impuros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233472.mp4', 'http://timg.bdta.pro/images/c5a38a66c15f8be85577fe213d85bc5d.jpg'),
(6493, 395, 'Impuros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233473.mp4', 'http://timg.bdta.pro/images/3ee696cdb1cb19ceb5bc112fdca925aa.jpg'),
(6494, 395, 'Impuros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233474.mp4', 'http://timg.bdta.pro/images/02daafd0ff5b97a8d19900d875223f54.jpg'),
(6495, 395, 'Impuros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233475.mp4', 'http://timg.bdta.pro/images/b22ce575723cc6b929e292a8231768d3.jpg'),
(6496, 395, 'Impuros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233476.mp4', 'http://timg.bdta.pro/images/cd799578ccef1da19cc36ccb4c9d8695.jpg'),
(6497, 395, 'Impuros S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233477.mp4', 'http://timg.bdta.pro/images/932ec3feef22ae370e4b2d82fac258fd.jpg'),
(6498, 395, 'Impuros S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233478.mp4', 'http://timg.bdta.pro/images/09c2897e9109779f1e3b01cec4f30723.jpg'),
(6499, 396, 'Impuros S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233479.mp4', 'http://timg.bdta.pro/images/c87e21d0308b0067317141d091283d89.jpg'),
(6500, 396, 'Impuros S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233480.mp4', 'http://timg.bdta.pro/images/7392a59d0a025684bc6b44a842efc2eb.jpg'),
(6501, 396, 'Impuros S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233481.mp4', 'http://timg.bdta.pro/images/19feee5d55990a5a79f2d3c543a5b35b.jpg'),
(6502, 396, 'Impuros S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233482.mp4', 'http://timg.bdta.pro/images/eef84d6acf418010c4fe158055d851e7.jpg'),
(6503, 396, 'Impuros S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233483.mp4', 'http://timg.bdta.pro/images/76051cb6a82834884b16352a46d3ceb4.jpg'),
(6504, 396, 'Impuros S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233484.mp4', 'http://timg.bdta.pro/images/067a91c29acdaccf9fb1f4b81608dbaf.jpg'),
(6505, 396, 'Impuros S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233485.mp4', 'http://timg.bdta.pro/images/c5623d2e5e2df4ac1459907804b5d8a4.jpg'),
(6506, 396, 'Impuros S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233486.mp4', 'http://timg.bdta.pro/images/ad917eeb4231acbea5d3bd0554c80971.jpg'),
(6507, 396, 'Impuros S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233487.mp4', 'http://timg.bdta.pro/images/551a29892e20a23fdd19e151be5bebbd.jpg'),
(6508, 396, 'Impuros S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233488.mp4', 'http://timg.bdta.pro/images/1ac5870bf9267e752c85c17d018859e6.jpg'),
(6509, 397, 'Impuros S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6510, 397, 'Impuros S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6511, 397, 'Impuros S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6512, 397, 'Impuros S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6513, 397, 'Impuros S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6514, 397, 'Impuros S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6515, 397, 'Impuros S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6516, 397, 'Impuros S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6517, 397, 'Impuros S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6518, 397, 'Impuros S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6519, 398, 'Impuros S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6520, 398, 'Impuros S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6521, 398, 'Impuros S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6522, 398, 'Impuros S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6523, 398, 'Impuros S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6524, 398, 'Impuros S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6525, 398, 'Impuros S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6526, 398, 'Impuros S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6527, 398, 'Impuros S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6528, 398, 'Impuros S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6529, 399, 'Impuros S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/415007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6530, 399, 'Impuros S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/415008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6531, 399, 'Impuros S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/415009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6532, 399, 'Impuros S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/415010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6533, 399, 'Impuros S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/415011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6534, 399, 'Impuros S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/415012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6535, 399, 'Impuros S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/415013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6536, 399, 'Impuros S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/415014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6537, 399, 'Impuros S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/415015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6538, 399, 'Impuros S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/415016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSZD9pa16JkeCTqnZFERBgZOg9y.jpg'),
(6539, 400, 'Insatiable S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101662.mp4', 'http://gstaticontent.com/images/lHZ4xqGQlmyiFTOVtwnNpTcZgkd_big.jpg'),
(6540, 400, 'Insatiable S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101663.mp4', 'http://gstaticontent.com/images/lHZ4xqGQlmyiFTOVtwnNpTcZgkd_big.jpg'),
(6541, 400, 'Insatiable S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101664.mp4', 'http://gstaticontent.com/images/lHZ4xqGQlmyiFTOVtwnNpTcZgkd_big.jpg'),
(6542, 400, 'Insatiable S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101665.mp4', 'http://gstaticontent.com/images/lHZ4xqGQlmyiFTOVtwnNpTcZgkd_big.jpg'),
(6543, 400, 'Insatiable S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101666.mp4', 'http://gstaticontent.com/images/lHZ4xqGQlmyiFTOVtwnNpTcZgkd_big.jpg'),
(6544, 400, 'Insatiable S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101667.mp4', 'http://gstaticontent.com/images/lHZ4xqGQlmyiFTOVtwnNpTcZgkd_big.jpg'),
(6545, 400, 'Insatiable S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101668.mp4', 'http://gstaticontent.com/images/lHZ4xqGQlmyiFTOVtwnNpTcZgkd_big.jpg'),
(6546, 400, 'Insatiable S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101669.mp4', 'http://gstaticontent.com/images/lHZ4xqGQlmyiFTOVtwnNpTcZgkd_big.jpg'),
(6547, 400, 'Insatiable S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101670.mp4', 'http://gstaticontent.com/images/lHZ4xqGQlmyiFTOVtwnNpTcZgkd_big.jpg'),
(6548, 400, 'Insatiable S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101671.mp4', 'http://gstaticontent.com/images/lHZ4xqGQlmyiFTOVtwnNpTcZgkd_big.jpg'),
(6549, 400, 'Insatiable S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101672.mp4', 'http://gstaticontent.com/images/lHZ4xqGQlmyiFTOVtwnNpTcZgkd_big.jpg'),
(6550, 400, 'Insatiable S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101673.mp4', 'http://gstaticontent.com/images/lHZ4xqGQlmyiFTOVtwnNpTcZgkd_big.jpg'),
(6551, 401, 'Into The Badlands S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140419.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6552, 401, 'Into The Badlands S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140420.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6553, 401, 'Into The Badlands S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140421.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6554, 401, 'Into The Badlands S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140422.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6555, 401, 'Into The Badlands S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140423.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6556, 401, 'Into The Badlands S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140424.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6557, 402, 'Into The Badlands S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140425.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6558, 402, 'Into The Badlands S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140426.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6559, 402, 'Into The Badlands S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140427.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6560, 402, 'Into The Badlands S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140428.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6561, 402, 'Into The Badlands S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140429.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6562, 402, 'Into The Badlands S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140430.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6563, 402, 'Into The Badlands S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140431.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6564, 402, 'Into The Badlands S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140432.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6565, 402, 'Into The Badlands S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140433.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6566, 402, 'Into The Badlands S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140434.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6567, 403, 'Into The Badlands S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140435.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6568, 403, 'Into The Badlands S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140436.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6569, 403, 'Into The Badlands S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140437.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6570, 403, 'Into The Badlands S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140438.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6571, 403, 'Into The Badlands S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140439.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6572, 403, 'Into The Badlands S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140440.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6573, 403, 'Into The Badlands S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140441.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6574, 403, 'Into The Badlands S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140442.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6575, 403, 'Into The Badlands S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140443.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6576, 403, 'Into The Badlands S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140444.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6577, 403, 'Into The Badlands S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140445.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6578, 403, 'Into The Badlands S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140446.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6579, 403, 'Into The Badlands S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140447.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6580, 403, 'Into The Badlands S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/140448.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6581, 403, 'Into The Badlands S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/140449.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6582, 403, 'Into The Badlands S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/140450.mp4', 'http://gstaticontent.com/images/nRU4wIxuVGVZYTqtWVIf5A5fokT_big.jpg'),
(6583, 404, 'IZombie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142243.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6584, 404, 'IZombie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142244.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6585, 404, 'IZombie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142245.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6586, 404, 'IZombie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142246.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6587, 404, 'IZombie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142247.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6588, 404, 'IZombie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142248.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6589, 404, 'IZombie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142249.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6590, 404, 'IZombie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142250.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6591, 404, 'IZombie S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142251.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6592, 404, 'IZombie S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142252.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6593, 404, 'IZombie S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142253.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6594, 404, 'IZombie S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142254.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6595, 404, 'IZombie S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142255.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6596, 405, 'IZombie S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142256.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6597, 405, 'IZombie S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142257.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6598, 405, 'IZombie S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142258.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6599, 405, 'IZombie S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142259.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6600, 405, 'IZombie S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142260.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6601, 405, 'IZombie S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142261.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6602, 405, 'IZombie S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142262.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6603, 405, 'IZombie S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142263.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6604, 405, 'IZombie S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142264.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6605, 405, 'IZombie S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142265.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6606, 405, 'IZombie S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142266.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6607, 405, 'IZombie S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142267.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6608, 405, 'IZombie S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142268.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6609, 405, 'IZombie S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/142269.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6610, 405, 'IZombie S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142270.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6611, 405, 'IZombie S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/142271.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6612, 405, 'IZombie S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/142272.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6613, 405, 'IZombie S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/142273.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6614, 405, 'IZombie S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/142274.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6615, 406, 'IZombie S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/549186.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6616, 406, 'IZombie S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/549188.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6617, 406, 'IZombie S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/549190.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6618, 406, 'IZombie S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/549192.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6619, 406, 'IZombie S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/549194.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6620, 406, 'IZombie S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/549196.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6621, 406, 'IZombie S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/549198.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6622, 406, 'IZombie S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/549200.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6623, 406, 'IZombie S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/549202.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6624, 406, 'IZombie S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142293.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6625, 406, 'IZombie S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/549205.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6626, 406, 'IZombie S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/549207.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6627, 406, 'IZombie S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142298.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6628, 407, 'IZombie S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142299.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6629, 407, 'IZombie S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142300.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6630, 407, 'IZombie S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142301.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6631, 407, 'IZombie S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142302.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6632, 407, 'IZombie S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142303.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6633, 407, 'IZombie S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142304.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6634, 407, 'IZombie S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142305.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6635, 407, 'IZombie S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142306.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6636, 407, 'IZombie S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142307.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6637, 407, 'IZombie S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142308.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6638, 407, 'IZombie S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142309.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6639, 407, 'IZombie S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142310.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6640, 407, 'IZombie S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142311.mp4', 'http://gstaticontent.com/images/q4nqNwAhzVR7JuYctrWJvUWz3xR_big.jpg'),
(6641, 408, 'IZombie S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/885942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jiAPF6r0CNyrq2Pjs3FU12cRLbb.jpg'),
(6642, 408, 'IZombie S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/885943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cI0XeewMsFB3uIVy1wwC64NHN28.jpg'),
(6643, 408, 'IZombie S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/885944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eQ4Rdq9hiomJ7pqGpURSoCuhUAa.jpg'),
(6644, 408, 'IZombie S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/885945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qwtJvQQraCH8Z9M9cWxHfcpmUFm.jpg'),
(6645, 408, 'IZombie S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/885946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f9umJSrN0aKDfqSxMTBXqfxtapP.jpg'),
(6646, 408, 'IZombie S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/885947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3TxVDQoVPCxx8y3y1VbtidWHp2D.jpg'),
(6647, 408, 'IZombie S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/885948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guNSWQ6VxmEmL0kQSJiATFQfkjk.jpg'),
(6648, 408, 'IZombie S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/885949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fpWPUdi2yMD9mloCsMu4fQbChJk.jpg'),
(6649, 408, 'IZombie S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/885950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gmTXmMms7btJuqFxaLlfE5GmdQX.jpg'),
(6650, 408, 'IZombie S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/885951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3zO6SRzWNbe03imtrkAEHP7XQoh.jpg'),
(6651, 408, 'IZombie S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/885952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AtQmAcguRM4CU2rX8VtVuURLs8T.jpg'),
(6652, 408, 'IZombie S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/885953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmOO5Lp6rwg6D2IUD1NQWNKcjhH.jpg'),
(6653, 409, 'Jack Ryan de Tom Clancy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBzl9aR9HeOmvvHyZgF72rZjnqN.jpg'),
(6654, 409, 'Jack Ryan de Tom Clancy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBzl9aR9HeOmvvHyZgF72rZjnqN.jpg'),
(6655, 409, 'Jack Ryan de Tom Clancy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBzl9aR9HeOmvvHyZgF72rZjnqN.jpg'),
(6656, 409, 'Jack Ryan de Tom Clancy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBzl9aR9HeOmvvHyZgF72rZjnqN.jpg'),
(6657, 409, 'Jack Ryan de Tom Clancy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBzl9aR9HeOmvvHyZgF72rZjnqN.jpg'),
(6658, 409, 'Jack Ryan de Tom Clancy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBzl9aR9HeOmvvHyZgF72rZjnqN.jpg'),
(6659, 409, 'Jack Ryan de Tom Clancy S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBzl9aR9HeOmvvHyZgF72rZjnqN.jpg'),
(6660, 409, 'Jack Ryan de Tom Clancy S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBzl9aR9HeOmvvHyZgF72rZjnqN.jpg'),
(6661, 410, 'Jack Ryan de Tom Clancy S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBzl9aR9HeOmvvHyZgF72rZjnqN.jpg'),
(6662, 410, 'Jack Ryan de Tom Clancy S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBzl9aR9HeOmvvHyZgF72rZjnqN.jpg'),
(6663, 410, 'Jack Ryan de Tom Clancy S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBzl9aR9HeOmvvHyZgF72rZjnqN.jpg'),
(6664, 410, 'Jack Ryan de Tom Clancy S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBzl9aR9HeOmvvHyZgF72rZjnqN.jpg'),
(6665, 410, 'Jack Ryan de Tom Clancy S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBzl9aR9HeOmvvHyZgF72rZjnqN.jpg'),
(6666, 410, 'Jack Ryan de Tom Clancy S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBzl9aR9HeOmvvHyZgF72rZjnqN.jpg'),
(6667, 410, 'Jack Ryan de Tom Clancy S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBzl9aR9HeOmvvHyZgF72rZjnqN.jpg'),
(6668, 410, 'Jack Ryan de Tom Clancy S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBzl9aR9HeOmvvHyZgF72rZjnqN.jpg'),
(6669, 411, 'Jack Ryan de Tom Clancy S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/agv8p3zq5earx2kaIGzV7nk8iFX.jpg'),
(6670, 411, 'Jack Ryan de Tom Clancy S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ojSDbVIg2SvlBguormA5UFCCkre.jpg'),
(6671, 411, 'Jack Ryan de Tom Clancy S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBbTeDkKbJu8eYhY47JvNMQoyjX.jpg'),
(6672, 411, 'Jack Ryan de Tom Clancy S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fA3Psij0BaZYk6Tdk1S5C1x3AKO.jpg'),
(6673, 411, 'Jack Ryan de Tom Clancy S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9X5twcnBctW0BiD4yShmQMBHjm8.jpg'),
(6674, 411, 'Jack Ryan de Tom Clancy S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lVfJfJCaL8diIXsvMAfmNFrEEn1.jpg'),
(6675, 411, 'Jack Ryan de Tom Clancy S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Alg1L7ozoptirVHGgDKELL73Np2.jpg'),
(6676, 411, 'Jack Ryan de Tom Clancy S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m5yni6xcHOHgYlc0PPrgGbXRLDw.jpg'),
(6677, 412, 'Jack Ryan de Tom Clancy S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/67I8vAUH7VdCyQ7vKVtgWoXEiYS.jpg'),
(6678, 412, 'Jack Ryan de Tom Clancy S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9B2RmFRtppkiBDst7bUpHhQOnc.jpg'),
(6679, 412, 'Jack Ryan de Tom Clancy S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223369.mp4', 'http://image.tmdb.org/t/p/w1280/1t90MgoLaaGnK0rOUdgcp5hfO2N.jpg'),
(6680, 412, 'Jack Ryan de Tom Clancy S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223370.mp4', 'http://image.tmdb.org/t/p/w1280/oEcYkAPQaZphG7T1SwOWdGva909.jpg'),
(6681, 412, 'Jack Ryan de Tom Clancy S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223371.mp4', 'http://image.tmdb.org/t/p/w1280/3km3VS7seDKJ9uhpRKRDUT1r85w.jpg'),
(6682, 412, 'Jack Ryan de Tom Clancy S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223372.mp4', 'http://image.tmdb.org/t/p/w1280/ccuT8l42kGTjSGY4CChWHReYBzk.jpg'),
(6683, 413, 'Jane A Virgem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105670.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6684, 413, 'Jane A Virgem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105671.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6685, 413, 'Jane A Virgem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105672.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6686, 413, 'Jane A Virgem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105673.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6687, 413, 'Jane A Virgem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105674.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6688, 413, 'Jane A Virgem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105675.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6689, 413, 'Jane A Virgem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105676.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6690, 413, 'Jane A Virgem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105677.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6691, 413, 'Jane A Virgem S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105678.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6692, 413, 'Jane A Virgem S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105679.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6693, 413, 'Jane A Virgem S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105680.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6694, 413, 'Jane A Virgem S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105681.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6695, 413, 'Jane A Virgem S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/105682.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6696, 413, 'Jane A Virgem S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/105683.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6697, 413, 'Jane A Virgem S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/105684.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6698, 413, 'Jane A Virgem S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/105685.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6699, 413, 'Jane A Virgem S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/105686.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6700, 413, 'Jane A Virgem S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/105687.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6701, 413, 'Jane A Virgem S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/105688.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6702, 413, 'Jane A Virgem S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/105689.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6703, 413, 'Jane A Virgem S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/105690.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6704, 413, 'Jane A Virgem S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/105691.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6705, 414, 'Jane A Virgem S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105692.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6706, 414, 'Jane A Virgem S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105693.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6707, 414, 'Jane A Virgem S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105694.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6708, 414, 'Jane A Virgem S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105695.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6709, 414, 'Jane A Virgem S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105696.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6710, 414, 'Jane A Virgem S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105697.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6711, 414, 'Jane A Virgem S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105698.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6712, 414, 'Jane A Virgem S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105699.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6713, 414, 'Jane A Virgem S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105700.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6714, 414, 'Jane A Virgem S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105701.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6715, 414, 'Jane A Virgem S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105702.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6716, 414, 'Jane A Virgem S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105703.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6717, 414, 'Jane A Virgem S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/105704.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6718, 414, 'Jane A Virgem S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/105705.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6719, 414, 'Jane A Virgem S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/105706.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6720, 414, 'Jane A Virgem S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/105707.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6721, 414, 'Jane A Virgem S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/105708.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6722, 414, 'Jane A Virgem S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/105709.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6723, 414, 'Jane A Virgem S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/105710.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6724, 414, 'Jane A Virgem S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/105711.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6725, 414, 'Jane A Virgem S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/105712.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6726, 414, 'Jane A Virgem S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/105713.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6727, 415, 'Jane A Virgem S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105714.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6728, 415, 'Jane A Virgem S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105715.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6729, 415, 'Jane A Virgem S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105716.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6730, 415, 'Jane A Virgem S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105717.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6731, 415, 'Jane A Virgem S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105718.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6732, 415, 'Jane A Virgem S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105719.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6733, 415, 'Jane A Virgem S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105720.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6734, 415, 'Jane A Virgem S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105721.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6735, 415, 'Jane A Virgem S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105722.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6736, 415, 'Jane A Virgem S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105723.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6737, 415, 'Jane A Virgem S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105724.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6738, 415, 'Jane A Virgem S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105725.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6739, 415, 'Jane A Virgem S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/105726.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6740, 415, 'Jane A Virgem S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/105727.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6741, 415, 'Jane A Virgem S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/105728.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6742, 415, 'Jane A Virgem S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/105729.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6743, 415, 'Jane A Virgem S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/105730.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6744, 415, 'Jane A Virgem S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/105731.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6745, 415, 'Jane A Virgem S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/105732.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6746, 415, 'Jane A Virgem S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/105733.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6747, 416, 'Jane A Virgem S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105734.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6748, 416, 'Jane A Virgem S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105735.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6749, 416, 'Jane A Virgem S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105736.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6750, 416, 'Jane A Virgem S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105737.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6751, 416, 'Jane A Virgem S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105738.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6752, 416, 'Jane A Virgem S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105739.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6753, 416, 'Jane A Virgem S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105740.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6754, 416, 'Jane A Virgem S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105741.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6755, 416, 'Jane A Virgem S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105742.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6756, 416, 'Jane A Virgem S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105743.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6757, 416, 'Jane A Virgem S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105744.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6758, 416, 'Jane A Virgem S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105745.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6759, 416, 'Jane A Virgem S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/105746.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6760, 416, 'Jane A Virgem S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/105747.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6761, 416, 'Jane A Virgem S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/105748.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6762, 416, 'Jane A Virgem S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/105749.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6763, 416, 'Jane A Virgem S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/105750.mp4', 'http://gstaticontent.com/images/ql8t0HGhSPeiyy8ZZIMbjqJmRS6_big.jpg'),
(6764, 417, 'Jane A Virgem S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105751.mp4', 'http://timg.bdta.pro/images/09fb0d5cebc87ba1373e65d42660c8b5.jpg'),
(6765, 417, 'Jane A Virgem S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105752.mp4', 'http://timg.bdta.pro/images/16a39ff8363892f9dd2d55c68afb4e03.jpg'),
(6766, 417, 'Jane A Virgem S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105753.mp4', 'http://timg.bdta.pro/images/e4042c7cebf5a1b0bf3ccac8ff03d6ca.jpg'),
(6767, 417, 'Jane A Virgem S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105754.mp4', 'http://timg.bdta.pro/images/9c3bb7badfab424f9586a85f893e88c1.jpg'),
(6768, 417, 'Jane A Virgem S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105755.mp4', 'http://timg.bdta.pro/images/3bc306def931c001e8236631dbe81c99.jpg'),
(6769, 417, 'Jane A Virgem S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105756.mp4', 'http://timg.bdta.pro/images/c2c26a176db654865284410a1725fd31.jpg'),
(6770, 417, 'Jane A Virgem S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105757.mp4', 'http://timg.bdta.pro/images/72bb2bfd8bcaf92bf27f37ed9156e7b3.jpg'),
(6771, 417, 'Jane A Virgem S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105758.mp4', 'http://timg.bdta.pro/images/2754aec7f4d148818454a763b63e3bbb.jpg'),
(6772, 417, 'Jane A Virgem S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105759.mp4', 'http://timg.bdta.pro/images/33221dc7414b16a2ef53cd5924ac2e42.jpg'),
(6773, 417, 'Jane A Virgem S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105760.mp4', 'http://timg.bdta.pro/images/e8b108874239c68a1262bd8d074ef2a4.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(6774, 417, 'Jane A Virgem S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105761.mp4', 'http://timg.bdta.pro/images/5c518deed26c66803e0d1fc478d3cd1b.jpg'),
(6775, 417, 'Jane A Virgem S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105762.mp4', 'http://timg.bdta.pro/images/2278f5701a26462ef44d7339a4f344b0.jpg'),
(6776, 417, 'Jane A Virgem S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/105763.mp4', 'http://timg.bdta.pro/images/2bab66fd75f73be2c13dfaa4478e0295.jpg'),
(6777, 417, 'Jane A Virgem S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/105764.mp4', 'http://timg.bdta.pro/images/bf2b21121e9d6158f6dff6b3a90da326.jpg'),
(6778, 417, 'Jane A Virgem S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/105765.mp4', 'http://timg.bdta.pro/images/1d2ddd709804543811ef88b2d6d51180.jpg'),
(6779, 417, 'Jane A Virgem S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/105766.mp4', 'http://timg.bdta.pro/images/8bfe8a5a740471ef0da720fff8091951.jpg'),
(6780, 417, 'Jane A Virgem S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/105767.mp4', 'http://timg.bdta.pro/images/051008090df664728f494ea2f118ae89.jpg'),
(6781, 417, 'Jane A Virgem S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/105768.mp4', 'http://timg.bdta.pro/images/2d8c24261deee985d7187e4641358d94.jpg'),
(6782, 417, 'Jane A Virgem S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/105769.mp4', 'http://timg.bdta.pro/images/749d5de64c0a174e59dc262996555d98.jpg'),
(6783, 418, 'Marvel - Jessica Jones S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6784, 418, 'Marvel - Jessica Jones S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6785, 418, 'Marvel - Jessica Jones S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6786, 418, 'Marvel - Jessica Jones S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6787, 418, 'Marvel - Jessica Jones S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6788, 418, 'Marvel - Jessica Jones S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6789, 418, 'Marvel - Jessica Jones S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6790, 418, 'Marvel - Jessica Jones S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6791, 418, 'Marvel - Jessica Jones S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6792, 418, 'Marvel - Jessica Jones S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6793, 418, 'Marvel - Jessica Jones S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/104836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6794, 418, 'Marvel - Jessica Jones S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/104837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6795, 418, 'Marvel - Jessica Jones S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/104838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6796, 419, 'Marvel - Jessica Jones S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6797, 419, 'Marvel - Jessica Jones S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6798, 419, 'Marvel - Jessica Jones S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6799, 419, 'Marvel - Jessica Jones S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6800, 419, 'Marvel - Jessica Jones S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6801, 419, 'Marvel - Jessica Jones S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6802, 419, 'Marvel - Jessica Jones S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6803, 419, 'Marvel - Jessica Jones S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6804, 419, 'Marvel - Jessica Jones S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6805, 419, 'Marvel - Jessica Jones S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6806, 419, 'Marvel - Jessica Jones S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/104849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6807, 419, 'Marvel - Jessica Jones S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/104850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6808, 419, 'Marvel - Jessica Jones S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/104851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6809, 420, 'Marvel - Jessica Jones S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6810, 420, 'Marvel - Jessica Jones S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6811, 420, 'Marvel - Jessica Jones S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6812, 420, 'Marvel - Jessica Jones S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6813, 420, 'Marvel - Jessica Jones S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6814, 420, 'Marvel - Jessica Jones S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6815, 420, 'Marvel - Jessica Jones S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6816, 420, 'Marvel - Jessica Jones S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6817, 420, 'Marvel - Jessica Jones S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6818, 420, 'Marvel - Jessica Jones S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6819, 420, 'Marvel - Jessica Jones S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/104862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6820, 420, 'Marvel - Jessica Jones S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/104863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6821, 420, 'Marvel - Jessica Jones S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/104864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oxnWofiE9fHOgUfs9NJa6nG6NTR.jpg'),
(6822, 421, 'Kingdom S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110427.mp4', 'http://gstaticontent.com/images/xkRyopANOnO60KWm6DjozXlq9w4_big.jpg'),
(6823, 421, 'Kingdom S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110428.mp4', 'http://gstaticontent.com/images/xkRyopANOnO60KWm6DjozXlq9w4_big.jpg'),
(6824, 421, 'Kingdom S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110429.mp4', 'http://gstaticontent.com/images/xkRyopANOnO60KWm6DjozXlq9w4_big.jpg'),
(6825, 421, 'Kingdom S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110430.mp4', 'http://gstaticontent.com/images/xkRyopANOnO60KWm6DjozXlq9w4_big.jpg'),
(6826, 421, 'Kingdom S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110431.mp4', 'http://gstaticontent.com/images/xkRyopANOnO60KWm6DjozXlq9w4_big.jpg'),
(6827, 421, 'Kingdom S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110432.mp4', 'http://gstaticontent.com/images/xkRyopANOnO60KWm6DjozXlq9w4_big.jpg'),
(6828, 422, 'Kingdom S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110433.mp4', 'http://timg.bdta.pro/images/a07c2041f1928753c1d09310447751af.jpg'),
(6829, 422, 'Kingdom S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110434.mp4', 'http://timg.bdta.pro/images/62b5750d3f7643b99ed5a6d77e7b3320.jpg'),
(6830, 422, 'Kingdom S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110435.mp4', 'http://timg.bdta.pro/images/3fce50f13b3884e52b46fb58a4dd01ff.jpg'),
(6831, 422, 'Kingdom S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110436.mp4', 'http://timg.bdta.pro/images/6848adf0fbe12fd8e567f6afed35a324.jpg'),
(6832, 422, 'Kingdom S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110437.mp4', 'http://timg.bdta.pro/images/ee97f0833e2ab9a4200ffbd302ad925f.jpg'),
(6833, 422, 'Kingdom S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110438.mp4', 'http://timg.bdta.pro/images/e74f56c1a6614d0b147710e712de009e.jpg'),
(6834, 423, 'Knightfall S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106586.mp4', 'http://gstaticontent.com/images/7IgCqCZ0rZwvMg88rIS0bknUYWR_big.jpg'),
(6835, 423, 'Knightfall S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106587.mp4', 'http://gstaticontent.com/images/7IgCqCZ0rZwvMg88rIS0bknUYWR_big.jpg'),
(6836, 423, 'Knightfall S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106588.mp4', 'http://gstaticontent.com/images/7IgCqCZ0rZwvMg88rIS0bknUYWR_big.jpg'),
(6837, 423, 'Knightfall S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106589.mp4', 'http://gstaticontent.com/images/7IgCqCZ0rZwvMg88rIS0bknUYWR_big.jpg'),
(6838, 423, 'Knightfall S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106590.mp4', 'http://gstaticontent.com/images/7IgCqCZ0rZwvMg88rIS0bknUYWR_big.jpg'),
(6839, 423, 'Knightfall S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106591.mp4', 'http://gstaticontent.com/images/7IgCqCZ0rZwvMg88rIS0bknUYWR_big.jpg'),
(6840, 423, 'Knightfall S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106592.mp4', 'http://gstaticontent.com/images/7IgCqCZ0rZwvMg88rIS0bknUYWR_big.jpg'),
(6841, 423, 'Knightfall S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106593.mp4', 'http://gstaticontent.com/images/7IgCqCZ0rZwvMg88rIS0bknUYWR_big.jpg'),
(6842, 423, 'Knightfall S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106594.mp4', 'http://gstaticontent.com/images/7IgCqCZ0rZwvMg88rIS0bknUYWR_big.jpg'),
(6843, 423, 'Knightfall S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106595.mp4', 'http://gstaticontent.com/images/7IgCqCZ0rZwvMg88rIS0bknUYWR_big.jpg'),
(6844, 424, 'Knightfall S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106596.mp4', 'http://gstaticontent.com/images/7IgCqCZ0rZwvMg88rIS0bknUYWR_big.jpg'),
(6845, 424, 'Knightfall S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106597.mp4', 'http://gstaticontent.com/images/7IgCqCZ0rZwvMg88rIS0bknUYWR_big.jpg'),
(6846, 424, 'Knightfall S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106598.mp4', 'http://gstaticontent.com/images/7IgCqCZ0rZwvMg88rIS0bknUYWR_big.jpg'),
(6847, 424, 'Knightfall S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106599.mp4', 'http://gstaticontent.com/images/7IgCqCZ0rZwvMg88rIS0bknUYWR_big.jpg'),
(6848, 424, 'Knightfall S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106600.mp4', 'http://gstaticontent.com/images/7IgCqCZ0rZwvMg88rIS0bknUYWR_big.jpg'),
(6849, 424, 'Knightfall S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106601.mp4', 'http://timg.bdta.pro/images/30bc3d2495b670d66d892510ae2951ed.jpg'),
(6850, 424, 'Knightfall S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106602.mp4', 'http://timg.bdta.pro/images/8cdcf7e1e5d57fb021e1476935ce030a.jpg'),
(6851, 424, 'Knightfall S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106603.mp4', 'http://timg.bdta.pro/images/8a49ffb5013621403bbb45cdc3b36f04.jpg'),
(6852, 425, 'Krypton [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101674.mp4', 'http://gstaticontent.com/images/79b930aa82457ff8bec9e4d552f8fe3d.jpg'),
(6853, 425, 'Krypton [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101675.mp4', 'http://gstaticontent.com/images/79b930aa82457ff8bec9e4d552f8fe3d.jpg'),
(6854, 425, 'Krypton [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101676.mp4', 'http://gstaticontent.com/images/79b930aa82457ff8bec9e4d552f8fe3d.jpg'),
(6855, 425, 'Krypton [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101677.mp4', 'http://gstaticontent.com/images/79b930aa82457ff8bec9e4d552f8fe3d.jpg'),
(6856, 425, 'Krypton [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101678.mp4', 'http://gstaticontent.com/images/79b930aa82457ff8bec9e4d552f8fe3d.jpg'),
(6857, 425, 'Krypton [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101679.mp4', 'http://gstaticontent.com/images/79b930aa82457ff8bec9e4d552f8fe3d.jpg'),
(6858, 425, 'Krypton [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101680.mp4', 'http://gstaticontent.com/images/79b930aa82457ff8bec9e4d552f8fe3d.jpg'),
(6859, 425, 'Krypton [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101681.mp4', 'http://gstaticontent.com/images/79b930aa82457ff8bec9e4d552f8fe3d.jpg'),
(6860, 425, 'Krypton [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101682.mp4', 'http://gstaticontent.com/images/79b930aa82457ff8bec9e4d552f8fe3d.jpg'),
(6861, 425, 'Krypton [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101683.mp4', 'http://gstaticontent.com/images/79b930aa82457ff8bec9e4d552f8fe3d.jpg'),
(6862, 426, 'La Casa de Papel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170682.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/wKpQvdfzsOf7hKWwU0H8sSXZh1T.jpg'),
(6863, 426, 'La Casa de Papel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170683.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/bxrCLKigYre6WfR8GyNJ4u0FBlX.jpg'),
(6864, 426, 'La Casa de Papel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170684.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/mS4EuitwU6QJuZZcy9ndDGDmgEp.jpg'),
(6865, 426, 'La Casa de Papel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170685.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/h1Jt1XUkSdUGf2NM4PK1yN463tN.jpg'),
(6866, 426, 'La Casa de Papel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170686.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/w0IbY3aetrS01ZV0YySsLK1ypIA.jpg'),
(6867, 426, 'La Casa de Papel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170687.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/rGfZXEba8shIyNViwSuPbGwHenw.jpg'),
(6868, 426, 'La Casa de Papel S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170688.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/mTcAokdfaHN7DNvU9BrBKQmuEf0.jpg'),
(6869, 426, 'La Casa de Papel S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170689.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/1q5agV2ROKY4nIHD0Sv5PyLONyW.jpg'),
(6870, 426, 'La Casa de Papel S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170690.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/l4ctte6pCdonsB4AW3wAR0Lt7Bg.jpg'),
(6871, 426, 'La Casa de Papel S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170691.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/o2ohwlIbzDRVP5XFLTF2VFpDiYD.jpg'),
(6872, 426, 'La Casa de Papel S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170692.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ixduWz2wsNmxJ7gocG5xWkyDjJd.jpg'),
(6873, 426, 'La Casa de Papel S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170693.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/AbABGEWs2IkvStrqyeBxbwmMlUV.jpg'),
(6874, 426, 'La Casa de Papel S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/170694.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/oy19Zieotq2GK5gjTM7gyYl24wu.jpg'),
(6875, 427, 'La Casa de Papel S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170695.mp4', 'http://timg.bdta.pro/images/376a8fbd1d96930f973e397d7fe5d627.jpg'),
(6876, 427, 'La Casa de Papel S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170696.mp4', 'http://timg.bdta.pro/images/cbf337ed633d15283ae4469ac22b1708.jpg'),
(6877, 427, 'La Casa de Papel S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170697.mp4', 'http://timg.bdta.pro/images/11265803fb30f7f474fee0a51acb289e.jpg'),
(6878, 427, 'La Casa de Papel S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170698.mp4', 'http://timg.bdta.pro/images/b83059a58c4b6cf6881d2aa9f89b6b15.jpg'),
(6879, 427, 'La Casa de Papel S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170699.mp4', 'http://timg.bdta.pro/images/b52fb60e41518292b5e91d8c9120ed5c.jpg'),
(6880, 427, 'La Casa de Papel S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170700.mp4', 'http://timg.bdta.pro/images/a8eab28ac238543a4580cb90726b11b6.jpg'),
(6881, 427, 'La Casa de Papel S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170701.mp4', 'http://timg.bdta.pro/images/5318018693841a755fd0b28cc28711b6.jpg'),
(6882, 427, 'La Casa de Papel S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170702.mp4', 'http://timg.bdta.pro/images/403353a6b7a0a7effc73d56bf093940f.jpg'),
(6883, 427, 'La Casa de Papel S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170703.mp4', 'http://timg.bdta.pro/images/c1046e6646f59600708a198ca8053e99.jpg'),
(6884, 428, 'La Casa de Papel S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170704.mp4', 'http://timg.bdta.pro/images/27cd284bd6b87168c526a32a9e476212.jpg'),
(6885, 428, 'La Casa de Papel S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170705.mp4', 'http://timg.bdta.pro/images/d760c9656b1a831004558fe4e51f730b.jpg'),
(6886, 428, 'La Casa de Papel S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170706.mp4', 'http://timg.bdta.pro/images/c87b61250dd85c71813db823ba68adb7.jpg'),
(6887, 428, 'La Casa de Papel S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170707.mp4', 'http://timg.bdta.pro/images/80f8a77f424f1a96aa1b4c6b12dc89bb.jpg'),
(6888, 428, 'La Casa de Papel S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170708.mp4', 'http://timg.bdta.pro/images/54939ccbe77db489630a489c4104f237.jpg'),
(6889, 428, 'La Casa de Papel S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170709.mp4', 'http://gstaticontent.com/images/8a8041fc115a0b2ba9f92d964a270930.jpg'),
(6890, 428, 'La Casa de Papel S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170710.mp4', 'http://gstaticontent.com/images/8a8041fc115a0b2ba9f92d964a270930.jpg'),
(6891, 428, 'La Casa de Papel S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170711.mp4', 'http://gstaticontent.com/images/8a8041fc115a0b2ba9f92d964a270930.jpg'),
(6892, 429, 'La Casa de Papel S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170712.mp4', 'http://gstaticontent.com/images/8a8041fc115a0b2ba9f92d964a270930.jpg'),
(6893, 429, 'La Casa de Papel S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170713.mp4', 'http://gstaticontent.com/images/8a8041fc115a0b2ba9f92d964a270930.jpg'),
(6894, 429, 'La Casa de Papel S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170714.mp4', 'http://gstaticontent.com/images/8a8041fc115a0b2ba9f92d964a270930.jpg'),
(6895, 429, 'La Casa de Papel S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170715.mp4', 'http://gstaticontent.com/images/8a8041fc115a0b2ba9f92d964a270930.jpg'),
(6896, 429, 'La Casa de Papel S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170716.mp4', 'http://gstaticontent.com/images/8a8041fc115a0b2ba9f92d964a270930.jpg'),
(6897, 429, 'La Casa de Papel S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170717.mp4', 'http://gstaticontent.com/images/8a8041fc115a0b2ba9f92d964a270930.jpg'),
(6898, 429, 'La Casa de Papel S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170718.mp4', 'http://gstaticontent.com/images/8a8041fc115a0b2ba9f92d964a270930.jpg'),
(6899, 429, 'La Casa de Papel S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170719.mp4', 'http://gstaticontent.com/images/8a8041fc115a0b2ba9f92d964a270930.jpg'),
(6900, 430, 'La Casa de Papel S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170720.mp4', 'http://gstaticontent.com/images/8a8041fc115a0b2ba9f92d964a270930.jpg'),
(6901, 430, 'La Casa de Papel S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170721.mp4', 'http://gstaticontent.com/images/8a8041fc115a0b2ba9f92d964a270930.jpg'),
(6902, 430, 'La Casa de Papel S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170722.mp4', 'http://gstaticontent.com/images/8a8041fc115a0b2ba9f92d964a270930.jpg'),
(6903, 430, 'La Casa de Papel S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170723.mp4', 'http://gstaticontent.com/images/8a8041fc115a0b2ba9f92d964a270930.jpg'),
(6904, 430, 'La Casa de Papel S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170724.mp4', 'http://timg.bdta.pro/images/8a8041fc115a0b2ba9f92d964a270930.jpg'),
(6905, 431, 'La Casa de Papel S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170725.mp4', 'http://gstaticontent.com/images/8a8041fc115a0b2ba9f92d964a270930.jpg'),
(6906, 431, 'La Casa de Papel S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170726.mp4', 'http://gstaticontent.com/images/8a8041fc115a0b2ba9f92d964a270930.jpg'),
(6907, 431, 'La Casa de Papel S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170727.mp4', 'http://gstaticontent.com/images/8a8041fc115a0b2ba9f92d964a270930.jpg'),
(6908, 431, 'La Casa de Papel S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170728.mp4', 'http://gstaticontent.com/images/8a8041fc115a0b2ba9f92d964a270930.jpg'),
(6909, 431, 'La Casa de Papel S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170729.mp4', 'http://gstaticontent.com/images/8a8041fc115a0b2ba9f92d964a270930.jpg'),
(6910, 432, 'Engana-me Se Puder S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/seAQRBMFblCEp5MHK8QBHex81Ip.jpg'),
(6911, 432, 'Engana-me Se Puder S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fCXjskI78YmdH5tuYTmbUnRTrMV.jpg'),
(6912, 432, 'Engana-me Se Puder S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLmpKrKml6RDD3Y8vLrEpbIfSh5.jpg'),
(6913, 432, 'Engana-me Se Puder S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iLQC8Y9ygdTN4NNp4PJN5pE257R.jpg'),
(6914, 432, 'Engana-me Se Puder S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iimy05HpQNieqema7eueKd0v3pR.jpg'),
(6915, 432, 'Engana-me Se Puder S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o0CZihjC2DBlz03i1Gf2RSWeT0r.jpg'),
(6916, 432, 'Engana-me Se Puder S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7umQCauXD8r96W2tofIcLwqDWa.jpg'),
(6917, 432, 'Engana-me Se Puder S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ujVTTvAtD2OgtvtUcnKXXCCFAFB.jpg'),
(6918, 432, 'Engana-me Se Puder S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jRLCwToZGS5UaX4a7X1fGjXW47f.jpg'),
(6919, 432, 'Engana-me Se Puder S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dmz8aVXoBR5Qy7s5UlndrupRmYJ.jpg'),
(6920, 432, 'Engana-me Se Puder S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8IobntA5pikxvi23h7jWLGwr9uF.jpg'),
(6921, 432, 'Engana-me Se Puder S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pIXY2enLeftM24ACm3LmrPgLPCr.jpg'),
(6922, 432, 'Engana-me Se Puder S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/208860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s38cCwW8ZD2UmOCmCV8Ct8LIioo.jpg'),
(6923, 433, 'Engana-me Se Puder S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCyQxy5Fl1cBljxy3yhqeWWrHj7.jpg'),
(6924, 433, 'Engana-me Se Puder S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qwCi8IsuZvn9BWKJidcJnJwol4w.jpg'),
(6925, 433, 'Engana-me Se Puder S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hA24Zl3DY0EJl7hHFhLY9irux6w.jpg'),
(6926, 433, 'Engana-me Se Puder S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nedcY4HZttqucb4cY7CElU5cN6w.jpg'),
(6927, 433, 'Engana-me Se Puder S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oPkuuQCP52hv6OqZAW0spVcGgLD.jpg'),
(6928, 433, 'Engana-me Se Puder S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCxfFRP1guQJTKG8K4wiIDayzqm.jpg'),
(6929, 433, 'Engana-me Se Puder S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fO9uI5DgHauGDp9CziBL8BQtc1Z.jpg'),
(6930, 433, 'Engana-me Se Puder S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vfjyqJ7uOCxngZlIfO4xtU59zPf.jpg'),
(6931, 433, 'Engana-me Se Puder S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kfnCqwyD9OQn01reyyztVby1Uho.jpg'),
(6932, 433, 'Engana-me Se Puder S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cZ2zaGycMoVMVsMNZNKhK5WJMUO.jpg'),
(6933, 433, 'Engana-me Se Puder S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tRd1aexEVzri8fj0zKNK8htNTkx.jpg'),
(6934, 433, 'Engana-me Se Puder S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zNYPQFN52STBK6PbN2FlYt8Wy6X.jpg'),
(6935, 433, 'Engana-me Se Puder S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/208873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/90fZbGVc9Yr9euzGzDdQYQeHyvy.jpg'),
(6936, 433, 'Engana-me Se Puder S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/208874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xXNgNOVYYKUBkGyeigrc04Jd6Iy.jpg'),
(6937, 433, 'Engana-me Se Puder S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/208875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oQ69NRDBu9UDImJIhURkqI1UOQX.jpg'),
(6938, 433, 'Engana-me Se Puder S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/208876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vqIE0TATBMdnmd7wM8Bf5Y7fBub.jpg'),
(6939, 433, 'Engana-me Se Puder S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/208877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7vATVZqUdaIP9u2gV5OGh39pWhw.jpg'),
(6940, 433, 'Engana-me Se Puder S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/208878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hPhNuqayCVZ5hlcHwbPDc3wzpF9.jpg'),
(6941, 433, 'Engana-me Se Puder S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/208879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rBSInitMqKAWLDVy2xc6ulQlyPL.jpg'),
(6942, 433, 'Engana-me Se Puder S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/208880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzWyNS9JRjFml4pl3FzDpszsibI.jpg'),
(6943, 433, 'Engana-me Se Puder S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/208881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pKGrnQyrmvH5uUnby9UyExcfYW8.jpg'),
(6944, 433, 'Engana-me Se Puder S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/208882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2UPkje1tDUHy9a7ngBH94psGpPT.jpg'),
(6945, 434, 'Engana-me Se Puder S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZRAvHdfsOHq9JGhDoSR9YApRgm.jpg'),
(6946, 434, 'Engana-me Se Puder S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qiNaUECb6GjEQlV4QkAiNCWqBS1.jpg'),
(6947, 434, 'Engana-me Se Puder S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6IO6jUzXIp9J0ybzDO1KiHJSd3Q.jpg'),
(6948, 434, 'Engana-me Se Puder S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v5mJfYCcF5lFHCnSBn1ebE6DWCV.jpg'),
(6949, 434, 'Engana-me Se Puder S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qXfuG5EW5bY6fLjqJ6NnQ5qseDX.jpg'),
(6950, 434, 'Engana-me Se Puder S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTYsKvmqobNp1rKQd8pYfyKUsnx.jpg'),
(6951, 434, 'Engana-me Se Puder S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhCir6cOM0fNwmIdDzkJdihSl5R.jpg'),
(6952, 434, 'Engana-me Se Puder S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hNcmwG6pfo4GG2L7AcyfaF8CvnR.jpg'),
(6953, 434, 'Engana-me Se Puder S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6utL7Ouxert8j2DNtERE4fRydsk.jpg'),
(6954, 434, 'Engana-me Se Puder S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rWOKqdZtA0HyCZTiFOP1OLfH6br.jpg'),
(6955, 434, 'Engana-me Se Puder S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wgdJpxJsnjsRJQboMH3ot7V4es5.jpg'),
(6956, 434, 'Engana-me Se Puder S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWlGn85hxNSJPZ9sTXk1HjMkRjd.jpg'),
(6957, 434, 'Engana-me Se Puder S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/208895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xthbVtzll3yaYK0atXdXTX5jYDY.jpg'),
(6958, 435, 'Lucifer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155179.mp4', 'http://timg.bdta.pro/images/5f30a0f26eadcf0a8539c3387d71b2f9.jpg'),
(6959, 435, 'Lucifer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155180.mp4', 'http://timg.bdta.pro/images/10fb73765f5e35ff1d5ed2c6c92c7e97.jpg'),
(6960, 435, 'Lucifer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155181.mp4', 'http://timg.bdta.pro/images/98fada28780cb7bed36ea1e2909b2ae9.jpg'),
(6961, 435, 'Lucifer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155182.mp4', 'http://timg.bdta.pro/images/aee0a097d262dbb86e9d759f6ed00735.jpg'),
(6962, 435, 'Lucifer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155183.mp4', 'http://timg.bdta.pro/images/58dea0acaa64cfa23f33e3324a08ab93.jpg'),
(6963, 435, 'Lucifer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155184.mp4', 'http://timg.bdta.pro/images/6147f0ac05ed0417b3d8c6b01a0ccc8c.jpg'),
(6964, 435, 'Lucifer S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/155185.mp4', 'http://timg.bdta.pro/images/f87c2ba7b9362f239186ba80b507b287.jpg'),
(6965, 435, 'Lucifer S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/155186.mp4', 'http://timg.bdta.pro/images/ba6e8e1501d210c1f0ce60eb8d86c397.jpg'),
(6966, 435, 'Lucifer S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/155187.mp4', 'http://timg.bdta.pro/images/edec472486547f5518af30593ef5f67d.jpg'),
(6967, 435, 'Lucifer S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/155188.mp4', 'http://timg.bdta.pro/images/4ff6ade0903140af974626eda85cfbda.jpg'),
(6968, 435, 'Lucifer S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/155189.mp4', 'http://timg.bdta.pro/images/88bbb91faf20a0642874a2f70e60f274.jpg'),
(6969, 435, 'Lucifer S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/155190.mp4', 'http://timg.bdta.pro/images/4fcde394454c4fa6c0e3a52b7b7112b6.jpg'),
(6970, 435, 'Lucifer S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/155191.mp4', 'http://timg.bdta.pro/images/921e9509d7153c204b99f8a0d4e1232c.jpg'),
(6971, 436, 'Lucifer S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155192.mp4', 'http://timg.bdta.pro/images/5d0a2453cfb5a419a28bc8584926db44.jpg'),
(6972, 436, 'Lucifer S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155193.mp4', 'http://timg.bdta.pro/images/8bdea15bef3101f5304b78673c146f57.jpg'),
(6973, 436, 'Lucifer S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155194.mp4', 'http://timg.bdta.pro/images/ec1b6f36d665107753657308889be82c.jpg'),
(6974, 436, 'Lucifer S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155195.mp4', 'http://timg.bdta.pro/images/cdbec3bd056165e8724655b3d56c89e3.jpg'),
(6975, 436, 'Lucifer S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155196.mp4', 'http://timg.bdta.pro/images/ff8231030af578ad3f21837b68aab06d.jpg'),
(6976, 436, 'Lucifer S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155197.mp4', 'http://timg.bdta.pro/images/f67cae11c5c0529445aa93cc9ef6670e.jpg'),
(6977, 436, 'Lucifer S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/155198.mp4', 'http://timg.bdta.pro/images/5aaf8651681e351f95190e7cedc5b42f.jpg'),
(6978, 436, 'Lucifer S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/155199.mp4', 'http://timg.bdta.pro/images/1824e235d652ef92e0548dad25987d54.jpg'),
(6979, 436, 'Lucifer S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/155200.mp4', 'http://timg.bdta.pro/images/c6bb72dcc416d9d53316e1bfa30bec79.jpg'),
(6980, 436, 'Lucifer S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/155201.mp4', 'http://timg.bdta.pro/images/14465e0f69d7dd59a43a131c62239673.jpg'),
(6981, 436, 'Lucifer S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/155202.mp4', 'http://timg.bdta.pro/images/f90ed56c747fc48c75088661e5fc7ebc.jpg'),
(6982, 436, 'Lucifer S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/155203.mp4', 'http://timg.bdta.pro/images/9578923e7874b576a7a8f0d38b3915c0.jpg'),
(6983, 436, 'Lucifer S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/155204.mp4', 'http://timg.bdta.pro/images/29fa2464b881340ad02bcfe57829adcc.jpg'),
(6984, 436, 'Lucifer S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/155205.mp4', 'http://timg.bdta.pro/images/4878b2f0aa885cc42ed12eb7bd307c0e.jpg'),
(6985, 436, 'Lucifer S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/155206.mp4', 'http://timg.bdta.pro/images/f0aaea6f84033337d3a4a1579d0a314e.jpg'),
(6986, 436, 'Lucifer S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/155207.mp4', 'http://timg.bdta.pro/images/cd389c67f6644260102e50965d7bf824.jpg'),
(6987, 436, 'Lucifer S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/155208.mp4', 'http://timg.bdta.pro/images/0c9e07e12216cbb44941774478a9200b.jpg'),
(6988, 436, 'Lucifer S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/155209.mp4', 'http://timg.bdta.pro/images/57788eaad2000dfd9092e04d3c68e483.jpg'),
(6989, 437, 'Lucifer S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155210.mp4', 'http://timg.bdta.pro/images/7fdce3e7403309362a4c16dfc383dbcf.jpg'),
(6990, 437, 'Lucifer S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155211.mp4', 'http://timg.bdta.pro/images/9ee8e93d320dc59d8589420300c68a2b.jpg'),
(6991, 437, 'Lucifer S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155212.mp4', 'http://timg.bdta.pro/images/a0d05e3e1a086f9abf4c590cfeff8243.jpg'),
(6992, 437, 'Lucifer S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155213.mp4', 'http://timg.bdta.pro/images/2490c7c20a63d4287a4914efdf48a021.jpg'),
(6993, 437, 'Lucifer S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155214.mp4', 'http://timg.bdta.pro/images/87a2260bd0881cca6a9e715d7da93426.jpg'),
(6994, 437, 'Lucifer S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155215.mp4', 'http://timg.bdta.pro/images/38e54a25882e646fdc82d381c0f02109.jpg'),
(6995, 437, 'Lucifer S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/155216.mp4', 'http://timg.bdta.pro/images/7fbe3914571e1230d5f0b982a6732f7e.jpg'),
(6996, 437, 'Lucifer S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/155217.mp4', 'http://timg.bdta.pro/images/054fe38975d92dc1798791f36847c562.jpg'),
(6997, 437, 'Lucifer S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/155218.mp4', 'http://timg.bdta.pro/images/09f6752e39bcbc5446d8337264c624d0.jpg'),
(6998, 437, 'Lucifer S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/155219.mp4', 'http://timg.bdta.pro/images/d02c5f99c6f9d0ff28c35dedf2a6e1be.jpg'),
(6999, 437, 'Lucifer S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/155220.mp4', 'http://timg.bdta.pro/images/108bdaaef807f424be993fdd39f2b2cf.jpg'),
(7000, 437, 'Lucifer S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/155221.mp4', 'http://timg.bdta.pro/images/86659b3850f21b82c27c23310fa11b89.jpg'),
(7001, 437, 'Lucifer S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/155222.mp4', 'http://timg.bdta.pro/images/49fe65a739f6fb4115c57ec017cecab6.jpg'),
(7002, 437, 'Lucifer S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/155223.mp4', 'http://timg.bdta.pro/images/5d54ba1bc9c14334666ed4f2ad1be887.jpg'),
(7003, 437, 'Lucifer S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/550152.mp4', 'http://gstaticontent.com/images/25074c0136994fe9b6b591437f100da1.jpg'),
(7004, 437, 'Lucifer S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/155226.mp4', 'http://timg.bdta.pro/images/d586c798700df265e57d28319977308b.jpg'),
(7005, 437, 'Lucifer S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/155227.mp4', 'http://timg.bdta.pro/images/81a0a3c8348d3b5d87713206671aa6e4.jpg'),
(7006, 437, 'Lucifer S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/155228.mp4', 'http://timg.bdta.pro/images/c94d5fabe782803675a92d1c240eb3de.jpg'),
(7007, 437, 'Lucifer S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/155229.mp4', 'http://timg.bdta.pro/images/8c4f5ecf3834743ad81a5cac9edb3619.jpg'),
(7008, 437, 'Lucifer S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/155230.mp4', 'http://timg.bdta.pro/images/703958e66bc1e6aaeaee99b03edc5e1d.jpg'),
(7009, 437, 'Lucifer S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/155231.mp4', 'http://timg.bdta.pro/images/9b714e02b3e2ca3c7a46d72e390bfe57.jpg'),
(7010, 437, 'Lucifer S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/155232.mp4', 'http://timg.bdta.pro/images/5f75839b24e6658636016cf0255dcdb6.jpg'),
(7011, 437, 'Lucifer S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/155233.mp4', 'http://timg.bdta.pro/images/412b27f25e3a80f6b302945cb7402922.jpg'),
(7012, 437, 'Lucifer S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/155234.mp4', 'http://timg.bdta.pro/images/3dcb6409f289e60e44ce9b459fd34ba3.jpg'),
(7013, 437, 'Lucifer S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/155235.mp4', 'http://timg.bdta.pro/images/1543aaba0649261959c93820a5bb5adc.jpg'),
(7014, 437, 'Lucifer S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/155236.mp4', 'http://timg.bdta.pro/images/5fc7ee66c69e0bde33f422416f8f3439.jpg'),
(7015, 438, 'Lucifer S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155237.mp4', 'http://timg.bdta.pro/images/ca6d6234335e38ae4af1b54020f53976.jpg'),
(7016, 438, 'Lucifer S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155238.mp4', 'http://timg.bdta.pro/images/8da6746f8fba6c9bb311b99f8e85ee60.jpg'),
(7017, 438, 'Lucifer S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155239.mp4', 'http://timg.bdta.pro/images/35f818c9545c8910b4b05ccea5717113.jpg'),
(7018, 438, 'Lucifer S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155240.mp4', 'http://timg.bdta.pro/images/b20ee115d6a538ccc10677307e119ce8.jpg'),
(7019, 438, 'Lucifer S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155241.mp4', 'http://timg.bdta.pro/images/a28ef4dacb01071a3a3c6d3b810c15af.jpg'),
(7020, 438, 'Lucifer S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155242.mp4', 'http://timg.bdta.pro/images/d616153866304710c69a05ead42dfa57.jpg'),
(7021, 438, 'Lucifer S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/155243.mp4', 'http://timg.bdta.pro/images/0b038b5505eb81e71b75f82dc42203b0.jpg'),
(7022, 438, 'Lucifer S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/155244.mp4', 'http://timg.bdta.pro/images/38c6c065ead49af544001805ff7ad9a7.jpg'),
(7023, 438, 'Lucifer S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/155245.mp4', 'http://timg.bdta.pro/images/7cab372e377581ea4457ecdf9ada8fec.jpg'),
(7024, 438, 'Lucifer S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/155246.mp4', 'http://timg.bdta.pro/images/dbf930668620c0383c7f1cfbef964f17.jpg'),
(7025, 439, 'Lucifer S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155247.mp4', 'http://timg.bdta.pro/images/1baf04a20387a7140d48fb30c3810450.jpg'),
(7026, 439, 'Lucifer S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155248.mp4', 'http://timg.bdta.pro/images/d5d63a8da8a9039a8a86e52898e36a0d.jpg'),
(7027, 439, 'Lucifer S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155249.mp4', 'http://timg.bdta.pro/images/693209e803a1dc29f2d6bb17e6a359ea.jpg'),
(7028, 439, 'Lucifer S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155250.mp4', 'http://timg.bdta.pro/images/79ac8480e208070a454187e0fce11786.jpg'),
(7029, 439, 'Lucifer S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155251.mp4', 'http://timg.bdta.pro/images/97c8dbafa1012520f20600a095553736.jpg'),
(7030, 439, 'Lucifer S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155252.mp4', 'http://timg.bdta.pro/images/de6d089b5a9b0f1618140540ec20481f.jpg'),
(7031, 439, 'Lucifer S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/155253.mp4', 'http://timg.bdta.pro/images/ae9f09d80376da6f3bf55ce33d261e68.jpg'),
(7032, 439, 'Lucifer S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/155254.mp4', 'http://timg.bdta.pro/images/0c66151fde7a34950dec69452818233b.jpg'),
(7033, 439, 'Lucifer S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/155255.mp4', 'http://gstaticontent.com/images/1sBx2Ew4WFsa1YY32vlHt079O03_big.jpg'),
(7034, 439, 'Lucifer S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/155256.mp4', 'http://gstaticontent.com/images/1sBx2Ew4WFsa1YY32vlHt079O03_big.jpg'),
(7035, 439, 'Lucifer S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/155257.mp4', 'http://gstaticontent.com/images/1sBx2Ew4WFsa1YY32vlHt079O03_big.jpg'),
(7036, 439, 'Lucifer S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/155258.mp4', 'http://gstaticontent.com/images/1sBx2Ew4WFsa1YY32vlHt079O03_big.jpg'),
(7037, 439, 'Lucifer S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/155259.mp4', 'http://gstaticontent.com/images/1sBx2Ew4WFsa1YY32vlHt079O03_big.jpg'),
(7038, 439, 'Lucifer S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/155260.mp4', 'http://gstaticontent.com/images/1sBx2Ew4WFsa1YY32vlHt079O03_big.jpg'),
(7039, 439, 'Lucifer S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/155261.mp4', 'http://gstaticontent.com/images/1sBx2Ew4WFsa1YY32vlHt079O03_big.jpg'),
(7040, 439, 'Lucifer S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/155262.mp4', 'http://gstaticontent.com/images/1sBx2Ew4WFsa1YY32vlHt079O03_big.jpg'),
(7041, 440, 'Lucifer S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155263.mp4', 'http://timg.bdta.pro/images/3d799ac7dc583a08d9d708bb209b232a.jpg'),
(7042, 440, 'Lucifer S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155264.mp4', 'http://timg.bdta.pro/images/135fd714941cc17bb453dde0e8a181c4.jpg'),
(7043, 440, 'Lucifer S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155265.mp4', 'http://timg.bdta.pro/images/ea63eab8295502c0ee674e1dcf3ba249.jpg'),
(7044, 440, 'Lucifer S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155266.mp4', 'http://timg.bdta.pro/images/f9ebdabb2bf346ba7262c478a9297996.jpg'),
(7045, 440, 'Lucifer S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155267.mp4', 'http://timg.bdta.pro/images/d1c1ebd3565826ac0bad88f8c4c099e1.jpg'),
(7046, 440, 'Lucifer S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155268.mp4', 'http://timg.bdta.pro/images/a83fb223d036cce1a7e8e50a85d6828a.jpg'),
(7047, 440, 'Lucifer S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/155269.mp4', 'http://timg.bdta.pro/images/462ebd3dc86002b8a3a43dee8ea5eb41.jpg'),
(7048, 440, 'Lucifer S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/155270.mp4', 'http://timg.bdta.pro/images/07129e1bdc505828ad6611feec53f510.jpg'),
(7049, 440, 'Lucifer S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/155271.mp4', 'http://timg.bdta.pro/images/04df81a56d61a7d1fc0d9dec31561037.jpg'),
(7050, 440, 'Lucifer S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/155272.mp4', 'http://timg.bdta.pro/images/05f120eaf5ab0903f74eae5c6dea84fd.jpg'),
(7051, 441, 'Luke Cage S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7052, 441, 'Luke Cage S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7053, 441, 'Luke Cage S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7054, 441, 'Luke Cage S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7055, 441, 'Luke Cage S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7056, 441, 'Luke Cage S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7057, 441, 'Luke Cage S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(7058, 441, 'Luke Cage S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7059, 441, 'Luke Cage S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7060, 441, 'Luke Cage S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7061, 441, 'Luke Cage S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7062, 441, 'Luke Cage S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7063, 441, 'Luke Cage S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7064, 442, 'Luke Cage S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7065, 442, 'Luke Cage S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7066, 442, 'Luke Cage S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7067, 442, 'Luke Cage S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7068, 442, 'Luke Cage S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7069, 442, 'Luke Cage S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7070, 442, 'Luke Cage S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7071, 442, 'Luke Cage S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7072, 442, 'Luke Cage S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7073, 442, 'Luke Cage S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7074, 442, 'Luke Cage S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7075, 442, 'Luke Cage S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7076, 442, 'Luke Cage S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quTfV803fGaSADzTeEqCbIZnt9d.jpg'),
(7077, 443, 'MacGyver S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7078, 443, 'MacGyver S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7079, 443, 'MacGyver S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7080, 443, 'MacGyver S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7081, 443, 'MacGyver S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7082, 443, 'MacGyver S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7083, 443, 'MacGyver S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7084, 443, 'MacGyver S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7085, 443, 'MacGyver S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7086, 443, 'MacGyver S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7087, 443, 'MacGyver S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/209051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7088, 443, 'MacGyver S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/209052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7089, 443, 'MacGyver S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/209053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7090, 443, 'MacGyver S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/209054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7091, 443, 'MacGyver S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/209055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7092, 443, 'MacGyver S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/209056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7093, 443, 'MacGyver S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/209057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7094, 443, 'MacGyver S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/209058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7095, 443, 'MacGyver S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/209059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7096, 443, 'MacGyver S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/209060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7097, 443, 'MacGyver S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/209061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7098, 444, 'MacGyver S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7099, 444, 'MacGyver S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7100, 444, 'MacGyver S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7101, 444, 'MacGyver S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7102, 444, 'MacGyver S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7103, 444, 'MacGyver S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7104, 444, 'MacGyver S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7105, 444, 'MacGyver S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7106, 444, 'MacGyver S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7107, 444, 'MacGyver S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7108, 444, 'MacGyver S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/209072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7109, 444, 'MacGyver S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/209073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7110, 444, 'MacGyver S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/209074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7111, 444, 'MacGyver S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/209075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7112, 444, 'MacGyver S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/209076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7113, 444, 'MacGyver S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/209077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7114, 444, 'MacGyver S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/209078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7115, 444, 'MacGyver S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/209079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7116, 444, 'MacGyver S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/209080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7117, 444, 'MacGyver S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/209081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7118, 444, 'MacGyver S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/209082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7119, 444, 'MacGyver S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/209083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7120, 444, 'MacGyver S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/209084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7121, 445, 'MacGyver S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7122, 445, 'MacGyver S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7123, 445, 'MacGyver S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7124, 445, 'MacGyver S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7125, 445, 'MacGyver S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7126, 445, 'MacGyver S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7127, 445, 'MacGyver S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7128, 445, 'MacGyver S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7129, 445, 'MacGyver S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7130, 445, 'MacGyver S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7131, 445, 'MacGyver S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/209095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7132, 445, 'MacGyver S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/209096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7133, 445, 'MacGyver S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/209097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7134, 445, 'MacGyver S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/209098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7135, 445, 'MacGyver S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/209099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7136, 445, 'MacGyver S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/209100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7137, 445, 'MacGyver S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/209101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7138, 445, 'MacGyver S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/209102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7139, 445, 'MacGyver S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/209103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7140, 445, 'MacGyver S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/209104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7141, 445, 'MacGyver S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/209105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7142, 445, 'MacGyver S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/209106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2zAogx9dmSAu2HYxbWzHe4ZaNY5.jpg'),
(7143, 446, 'MacGyver S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7p2yZlFX82Y1AKXAd1SHO8jIiTH.jpg'),
(7144, 446, 'MacGyver S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4kPDQpxtZRqU3s4sRKxhloM7nt1.jpg'),
(7145, 446, 'MacGyver S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wrSvoFiRly7Uxf37tHTHV48uZkm.jpg'),
(7146, 446, 'MacGyver S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/onY6aO4AoAu4tR0tVUzrQAMaMsV.jpg'),
(7147, 446, 'MacGyver S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2H80LROQxx9Li0168qoGjP9pZf1.jpg'),
(7148, 446, 'MacGyver S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tQByUiM6vVsyXF4fov5cNiPm1Xq.jpg'),
(7149, 446, 'MacGyver S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fwFXOOmYrIP8BJogQ53k38CogsV.jpg'),
(7150, 446, 'MacGyver S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2kuTBMRaK3NxXfpzmJy7nophTlt.jpg'),
(7151, 446, 'MacGyver S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/urDAth8MFLst7WfB19bfNWRCzum.jpg'),
(7152, 446, 'MacGyver S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nIK0M1Uvywvp3SsiRQXW5nMo59X.jpg'),
(7153, 446, 'MacGyver S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/209117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jNSbEp1cGLMk0OfzeCA0TeY0oUU.jpg'),
(7154, 446, 'MacGyver S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/209118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xGKzkKY7bpa1nuvWgRNyEhdhqt9.jpg'),
(7155, 446, 'MacGyver S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/209119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oSgJj30AuWp8DieecvfimB078i4.jpg'),
(7156, 447, 'MacGyver S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qDj45ggEdMuzPiktwH3oLCIuEjM.jpg'),
(7157, 447, 'MacGyver S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a7mRVcas8RSghLKCFgdbq0gnnwi.jpg'),
(7158, 447, 'MacGyver S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5VktEIJjxVczUPmlhtpWMLFFqQX.jpg'),
(7159, 447, 'MacGyver S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xD1U0sRkmwgR7IbQiCXfiAxo7y4.jpg'),
(7160, 447, 'MacGyver S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y7UHOL2pwKub2bsJqlAVHj4C2Yg.jpg'),
(7161, 447, 'MacGyver S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1NWYrurqWemBooUsslc8yVwoKyq.jpg'),
(7162, 447, 'MacGyver S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2tTYDOnjb9CI72ls12qUIxR4eds.jpg'),
(7163, 447, 'MacGyver S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mlzj20TAiN3NgzA8LGz6gDNzESj.jpg'),
(7164, 447, 'MacGyver S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9s0d5EUMe31TMWK2VpuyCXibTr1.jpg'),
(7165, 447, 'MacGyver S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oKRWrbOP4D2tIJ55kzy4lJaf2MV.jpg'),
(7166, 447, 'MacGyver S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/209130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hCqYSUtLbXxYLQ6E6eyekRWwLDI.jpg'),
(7167, 447, 'MacGyver S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/209131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qUt2fPlUkmN3vsyjqDVdIOuRFry.jpg'),
(7168, 447, 'MacGyver S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/209132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rIJifsAraLeOk1k7Ja51dtAJBcz.jpg'),
(7169, 447, 'MacGyver S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/209133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ejWbwF1WbzAlJVuUgGrmFbE3dKo.jpg'),
(7170, 447, 'MacGyver S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/209134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8pRlQvt87nsFn5lOUevO4MUR5dU.jpg'),
(7171, 448, 'Maniac S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101710.mp4', 'http://gstaticontent.com/images/kCNl4QPstAqChFD0NnLpbDFG8ul_big.jpg'),
(7172, 448, 'Maniac S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101711.mp4', 'http://gstaticontent.com/images/kCNl4QPstAqChFD0NnLpbDFG8ul_big.jpg'),
(7173, 448, 'Maniac S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101712.mp4', 'http://gstaticontent.com/images/kCNl4QPstAqChFD0NnLpbDFG8ul_big.jpg'),
(7174, 448, 'Maniac S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101713.mp4', 'http://gstaticontent.com/images/kCNl4QPstAqChFD0NnLpbDFG8ul_big.jpg'),
(7175, 448, 'Maniac S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101714.mp4', 'http://gstaticontent.com/images/kCNl4QPstAqChFD0NnLpbDFG8ul_big.jpg'),
(7176, 448, 'Maniac S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101715.mp4', 'http://gstaticontent.com/images/kCNl4QPstAqChFD0NnLpbDFG8ul_big.jpg'),
(7177, 448, 'Maniac S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101716.mp4', 'http://gstaticontent.com/images/kCNl4QPstAqChFD0NnLpbDFG8ul_big.jpg'),
(7178, 448, 'Maniac S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101717.mp4', 'http://gstaticontent.com/images/kCNl4QPstAqChFD0NnLpbDFG8ul_big.jpg'),
(7179, 448, 'Maniac S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101718.mp4', 'http://gstaticontent.com/images/kCNl4QPstAqChFD0NnLpbDFG8ul_big.jpg'),
(7180, 448, 'Maniac S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101719.mp4', 'http://gstaticontent.com/images/kCNl4QPstAqChFD0NnLpbDFG8ul_big.jpg'),
(7181, 449, 'Maquina Mortifera S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100061.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7182, 449, 'Maquina Mortifera S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100062.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7183, 449, 'Maquina Mortifera S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100063.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7184, 449, 'Maquina Mortifera S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100064.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7185, 449, 'Maquina Mortifera S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100065.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7186, 449, 'Maquina Mortifera S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100066.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7187, 449, 'Maquina Mortifera S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100067.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7188, 449, 'Maquina Mortifera S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100068.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7189, 449, 'Maquina Mortifera S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100069.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7190, 449, 'Maquina Mortifera S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100070.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7191, 449, 'Maquina Mortifera S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100071.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7192, 449, 'Maquina Mortifera S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100072.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7193, 449, 'Maquina Mortifera S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100073.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7194, 449, 'Maquina Mortifera S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100074.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7195, 449, 'Maquina Mortifera S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100075.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7196, 449, 'Maquina Mortifera S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100076.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7197, 449, 'Maquina Mortifera S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100077.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7198, 449, 'Maquina Mortifera S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100078.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7199, 450, 'Maquina Mortifera S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100079.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7200, 450, 'Maquina Mortifera S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100080.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7201, 450, 'Maquina Mortifera S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100081.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7202, 450, 'Maquina Mortifera S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100082.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7203, 450, 'Maquina Mortifera S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100083.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7204, 450, 'Maquina Mortifera S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100084.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7205, 450, 'Maquina Mortifera S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100085.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7206, 450, 'Maquina Mortifera S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100086.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7207, 450, 'Maquina Mortifera S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100087.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7208, 450, 'Maquina Mortifera S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100088.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7209, 450, 'Maquina Mortifera S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100089.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7210, 450, 'Maquina Mortifera S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100090.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7211, 450, 'Maquina Mortifera S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100091.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7212, 450, 'Maquina Mortifera S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100092.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7213, 450, 'Maquina Mortifera S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100093.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7214, 450, 'Maquina Mortifera S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100094.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7215, 450, 'Maquina Mortifera S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100095.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7216, 450, 'Maquina Mortifera S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100096.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7217, 450, 'Maquina Mortifera S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/100097.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7218, 450, 'Maquina Mortifera S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/100098.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7219, 450, 'Maquina Mortifera S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/100099.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7220, 450, 'Maquina Mortifera S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/100100.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7221, 451, 'Maquina Mortifera S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100101.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7222, 451, 'Maquina Mortifera S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100102.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7223, 451, 'Maquina Mortifera S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100103.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7224, 451, 'Maquina Mortifera S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100104.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7225, 451, 'Maquina Mortifera S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100105.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7226, 451, 'Maquina Mortifera S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100106.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7227, 451, 'Maquina Mortifera S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100107.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7228, 451, 'Maquina Mortifera S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100108.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7229, 451, 'Maquina Mortifera S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100109.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7230, 451, 'Maquina Mortifera S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100110.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7231, 451, 'Maquina Mortifera S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100111.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7232, 451, 'Maquina Mortifera S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100112.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7233, 451, 'Maquina Mortifera S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100113.mp4', 'http://gstaticontent.com/images/vB4UdkQlk07PuxJomJgLUrYmrio_big.jpg'),
(7234, 452, 'Marlon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101720.mp4', 'http://gstaticontent.com/images/7jCZupMTSyS3SohvE14T3xVT36n_big.jpg'),
(7235, 452, 'Marlon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101721.mp4', 'http://gstaticontent.com/images/7jCZupMTSyS3SohvE14T3xVT36n_big.jpg'),
(7236, 452, 'Marlon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101722.mp4', 'http://gstaticontent.com/images/7jCZupMTSyS3SohvE14T3xVT36n_big.jpg'),
(7237, 452, 'Marlon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101723.mp4', 'http://gstaticontent.com/images/7jCZupMTSyS3SohvE14T3xVT36n_big.jpg'),
(7238, 452, 'Marlon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101724.mp4', 'http://gstaticontent.com/images/7jCZupMTSyS3SohvE14T3xVT36n_big.jpg'),
(7239, 452, 'Marlon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101725.mp4', 'http://gstaticontent.com/images/7jCZupMTSyS3SohvE14T3xVT36n_big.jpg'),
(7240, 452, 'Marlon S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101726.mp4', 'http://gstaticontent.com/images/7jCZupMTSyS3SohvE14T3xVT36n_big.jpg'),
(7241, 452, 'Marlon S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101727.mp4', 'http://gstaticontent.com/images/7jCZupMTSyS3SohvE14T3xVT36n_big.jpg'),
(7242, 452, 'Marlon S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101728.mp4', 'http://gstaticontent.com/images/7jCZupMTSyS3SohvE14T3xVT36n_big.jpg'),
(7243, 452, 'Marlon S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101729.mp4', 'http://gstaticontent.com/images/7jCZupMTSyS3SohvE14T3xVT36n_big.jpg'),
(7244, 453, 'Marlon S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101730.mp4', 'http://gstaticontent.com/images/7jCZupMTSyS3SohvE14T3xVT36n_big.jpg'),
(7245, 453, 'Marlon S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101731.mp4', 'http://gstaticontent.com/images/7jCZupMTSyS3SohvE14T3xVT36n_big.jpg'),
(7246, 453, 'Marlon S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101732.mp4', 'http://gstaticontent.com/images/7jCZupMTSyS3SohvE14T3xVT36n_big.jpg'),
(7247, 453, 'Marlon S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101733.mp4', 'http://gstaticontent.com/images/7jCZupMTSyS3SohvE14T3xVT36n_big.jpg'),
(7248, 453, 'Marlon S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101734.mp4', 'http://gstaticontent.com/images/7jCZupMTSyS3SohvE14T3xVT36n_big.jpg'),
(7249, 453, 'Marlon S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101735.mp4', 'http://gstaticontent.com/images/7jCZupMTSyS3SohvE14T3xVT36n_big.jpg'),
(7250, 453, 'Marlon S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101736.mp4', 'http://gstaticontent.com/images/7jCZupMTSyS3SohvE14T3xVT36n_big.jpg'),
(7251, 453, 'Marlon S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101737.mp4', 'http://gstaticontent.com/images/7jCZupMTSyS3SohvE14T3xVT36n_big.jpg'),
(7252, 453, 'Marlon S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101738.mp4', 'http://gstaticontent.com/images/7jCZupMTSyS3SohvE14T3xVT36n_big.jpg'),
(7253, 453, 'Marlon S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101739.mp4', 'http://gstaticontent.com/images/7jCZupMTSyS3SohvE14T3xVT36n_big.jpg'),
(7254, 454, 'Marvel - Agente Carter S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fpeMeA3b54TuPVSsnk03ZxlYCDF.jpg'),
(7255, 454, 'Marvel - Agente Carter S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fpeMeA3b54TuPVSsnk03ZxlYCDF.jpg'),
(7256, 454, 'Marvel - Agente Carter S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fpeMeA3b54TuPVSsnk03ZxlYCDF.jpg'),
(7257, 454, 'Marvel - Agente Carter S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fpeMeA3b54TuPVSsnk03ZxlYCDF.jpg'),
(7258, 454, 'Marvel - Agente Carter S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fpeMeA3b54TuPVSsnk03ZxlYCDF.jpg'),
(7259, 454, 'Marvel - Agente Carter S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fpeMeA3b54TuPVSsnk03ZxlYCDF.jpg'),
(7260, 454, 'Marvel - Agente Carter S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fpeMeA3b54TuPVSsnk03ZxlYCDF.jpg'),
(7261, 454, 'Marvel - Agente Carter S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fpeMeA3b54TuPVSsnk03ZxlYCDF.jpg'),
(7262, 455, 'Marvel - Agente Carter S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fpeMeA3b54TuPVSsnk03ZxlYCDF.jpg'),
(7263, 455, 'Marvel - Agente Carter S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fpeMeA3b54TuPVSsnk03ZxlYCDF.jpg'),
(7264, 455, 'Marvel - Agente Carter S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fpeMeA3b54TuPVSsnk03ZxlYCDF.jpg'),
(7265, 455, 'Marvel - Agente Carter S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fpeMeA3b54TuPVSsnk03ZxlYCDF.jpg'),
(7266, 455, 'Marvel - Agente Carter S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fpeMeA3b54TuPVSsnk03ZxlYCDF.jpg'),
(7267, 455, 'Marvel - Agente Carter S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fpeMeA3b54TuPVSsnk03ZxlYCDF.jpg'),
(7268, 455, 'Marvel - Agente Carter S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fpeMeA3b54TuPVSsnk03ZxlYCDF.jpg'),
(7269, 455, 'Marvel - Agente Carter S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fpeMeA3b54TuPVSsnk03ZxlYCDF.jpg'),
(7270, 455, 'Marvel - Agente Carter S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fpeMeA3b54TuPVSsnk03ZxlYCDF.jpg'),
(7271, 455, 'Marvel - Agente Carter S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fpeMeA3b54TuPVSsnk03ZxlYCDF.jpg'),
(7272, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7273, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7274, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7275, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7276, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7277, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7278, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7279, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7280, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7281, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7282, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7283, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7284, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7285, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7286, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7287, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7288, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7289, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7290, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7291, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7292, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/137362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7293, 456, 'Agentes da S.H.I.E.L.D. da Marvel S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/137363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7294, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7295, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7296, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7297, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7298, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7299, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7300, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7301, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7302, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7303, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7304, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7305, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7306, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7307, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7308, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7309, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7310, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7311, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7312, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7313, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7314, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/137384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7315, 457, 'Agentes da S.H.I.E.L.D. da Marvel S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/137385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7316, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7317, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7318, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7319, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7320, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7321, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7322, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7323, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7324, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7325, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7326, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7327, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7328, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(7329, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7330, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7331, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7332, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7333, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7334, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7335, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7336, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/137406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7337, 458, 'Agentes da S.H.I.E.L.D. da Marvel S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/137407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7338, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7339, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7340, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7341, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7342, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7343, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7344, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7345, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7346, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7347, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7348, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7349, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7350, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7351, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7352, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7353, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7354, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7355, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7356, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7357, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7358, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/137428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7359, 459, 'Agentes da S.H.I.E.L.D. da Marvel S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/137429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7360, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7361, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7362, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7363, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7364, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7365, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7366, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7367, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7368, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7369, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7370, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7371, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7372, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7373, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7374, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7375, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7376, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7377, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7378, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7379, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7380, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/137450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7381, 460, 'Agentes da S.H.I.E.L.D. da Marvel S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/137451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7382, 461, 'Agentes da S.H.I.E.L.D. da Marvel S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137452.mp4', 'http://timg.bdta.pro/images/a787d7f86b5d0fcb68e843cc103cc800.jpg'),
(7383, 461, 'Agentes da S.H.I.E.L.D. da Marvel S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137453.mp4', 'http://timg.bdta.pro/images/a3ea243bb8e7285776474dce581e5293.jpg'),
(7384, 461, 'Agentes da S.H.I.E.L.D. da Marvel S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137454.mp4', 'http://timg.bdta.pro/images/e6c690beeaa9ee64429cfd37665951f3.jpg'),
(7385, 461, 'Agentes da S.H.I.E.L.D. da Marvel S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137455.mp4', 'http://timg.bdta.pro/images/dc6c520d11a2de934fb22811dd8fe197.jpg'),
(7386, 461, 'Agentes da S.H.I.E.L.D. da Marvel S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137456.mp4', 'http://timg.bdta.pro/images/b1e502ceb82d9dfe6d6230d4159f97c4.jpg'),
(7387, 461, 'Agentes da S.H.I.E.L.D. da Marvel S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137457.mp4', 'http://timg.bdta.pro/images/a2451753ed309f236f2703a0915abad0.jpg'),
(7388, 461, 'Agentes da S.H.I.E.L.D. da Marvel S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137458.mp4', 'http://timg.bdta.pro/images/9f2fbd9db5b0b823b685ac46947493c3.jpg'),
(7389, 461, 'Agentes da S.H.I.E.L.D. da Marvel S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137459.mp4', 'http://timg.bdta.pro/images/44b0c72062edf281b56f626ad59fcedf.jpg'),
(7390, 461, 'Agentes da S.H.I.E.L.D. da Marvel S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137460.mp4', 'http://timg.bdta.pro/images/057307aee15071fd99c17764500aff2f.jpg'),
(7391, 461, 'Agentes da S.H.I.E.L.D. da Marvel S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137461.mp4', 'http://timg.bdta.pro/images/9bbf6298ff01535326c056b2919d2b9d.jpg'),
(7392, 461, 'Agentes da S.H.I.E.L.D. da Marvel S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137462.mp4', 'http://timg.bdta.pro/images/cfbece5bb734f9bc9740f807b02cd51e.jpg'),
(7393, 461, 'Agentes da S.H.I.E.L.D. da Marvel S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137463.mp4', 'http://timg.bdta.pro/images/e01ff20970794ed92167382ecce555da.jpg'),
(7394, 461, 'Agentes da S.H.I.E.L.D. da Marvel S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137464.mp4', 'http://timg.bdta.pro/images/7b6e91bcd00d5ceb64dd05ce3f1a123f.jpg'),
(7395, 462, 'Agentes da S.H.I.E.L.D. da Marvel S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7396, 462, 'Agentes da S.H.I.E.L.D. da Marvel S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7397, 462, 'Agentes da S.H.I.E.L.D. da Marvel S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7398, 462, 'Agentes da S.H.I.E.L.D. da Marvel S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7399, 462, 'Agentes da S.H.I.E.L.D. da Marvel S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7400, 462, 'Agentes da S.H.I.E.L.D. da Marvel S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7401, 462, 'Agentes da S.H.I.E.L.D. da Marvel S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7402, 462, 'Agentes da S.H.I.E.L.D. da Marvel S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7403, 462, 'Agentes da S.H.I.E.L.D. da Marvel S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7404, 462, 'Agentes da S.H.I.E.L.D. da Marvel S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7405, 462, 'Agentes da S.H.I.E.L.D. da Marvel S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7406, 462, 'Agentes da S.H.I.E.L.D. da Marvel S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7407, 462, 'Agentes da S.H.I.E.L.D. da Marvel S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WwFZ5oOirY3JrfmRXlgnlYfanD.jpg'),
(7408, 463, 'Marvel\'s Cloak & Dagger S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102901.mp4', 'http://gstaticontent.com/images/dkXCcbhVXbIqXXdms9ylVy6kJzJ_big.jpg'),
(7409, 463, 'Marvel\'s Cloak & Dagger S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102902.mp4', 'http://gstaticontent.com/images/dkXCcbhVXbIqXXdms9ylVy6kJzJ_big.jpg'),
(7410, 463, 'Marvel\'s Cloak & Dagger S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102903.mp4', 'http://gstaticontent.com/images/dkXCcbhVXbIqXXdms9ylVy6kJzJ_big.jpg'),
(7411, 463, 'Marvel\'s Cloak & Dagger S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102904.mp4', 'http://gstaticontent.com/images/dkXCcbhVXbIqXXdms9ylVy6kJzJ_big.jpg'),
(7412, 463, 'Marvel\'s Cloak & Dagger S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102905.mp4', 'http://gstaticontent.com/images/dkXCcbhVXbIqXXdms9ylVy6kJzJ_big.jpg'),
(7413, 463, 'Marvel\'s Cloak & Dagger S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102906.mp4', 'http://gstaticontent.com/images/dkXCcbhVXbIqXXdms9ylVy6kJzJ_big.jpg'),
(7414, 463, 'Marvel\'s Cloak & Dagger S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102907.mp4', 'http://gstaticontent.com/images/dkXCcbhVXbIqXXdms9ylVy6kJzJ_big.jpg'),
(7415, 463, 'Marvel\'s Cloak & Dagger S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102908.mp4', 'http://gstaticontent.com/images/dkXCcbhVXbIqXXdms9ylVy6kJzJ_big.jpg'),
(7416, 463, 'Marvel\'s Cloak & Dagger S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102909.mp4', 'http://gstaticontent.com/images/dkXCcbhVXbIqXXdms9ylVy6kJzJ_big.jpg'),
(7417, 463, 'Marvel\'s Cloak & Dagger S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102910.mp4', 'http://gstaticontent.com/images/dkXCcbhVXbIqXXdms9ylVy6kJzJ_big.jpg'),
(7418, 464, 'Marvel\'s Cloak & Dagger S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102911.mp4', 'http://gstaticontent.com/images/dkXCcbhVXbIqXXdms9ylVy6kJzJ_big.jpg'),
(7419, 464, 'Marvel\'s Cloak & Dagger S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102912.mp4', 'http://gstaticontent.com/images/dkXCcbhVXbIqXXdms9ylVy6kJzJ_big.jpg'),
(7420, 464, 'Marvel\'s Cloak & Dagger S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102913.mp4', 'http://gstaticontent.com/images/dkXCcbhVXbIqXXdms9ylVy6kJzJ_big.jpg'),
(7421, 464, 'Marvel\'s Cloak & Dagger S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102914.mp4', 'http://gstaticontent.com/images/dkXCcbhVXbIqXXdms9ylVy6kJzJ_big.jpg'),
(7422, 464, 'Marvel\'s Cloak & Dagger S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102915.mp4', 'http://gstaticontent.com/images/dkXCcbhVXbIqXXdms9ylVy6kJzJ_big.jpg'),
(7423, 464, 'Marvel\'s Cloak & Dagger S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102916.mp4', 'http://gstaticontent.com/images/dkXCcbhVXbIqXXdms9ylVy6kJzJ_big.jpg'),
(7424, 464, 'Marvel\'s Cloak & Dagger S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102917.mp4', 'http://gstaticontent.com/images/dkXCcbhVXbIqXXdms9ylVy6kJzJ_big.jpg'),
(7425, 464, 'Marvel\'s Cloak & Dagger S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102918.mp4', 'http://gstaticontent.com/images/dkXCcbhVXbIqXXdms9ylVy6kJzJ_big.jpg'),
(7426, 464, 'Marvel\'s Cloak & Dagger S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102919.mp4', 'http://gstaticontent.com/images/dkXCcbhVXbIqXXdms9ylVy6kJzJ_big.jpg'),
(7427, 464, 'Marvel\'s Cloak & Dagger S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102920.mp4', 'http://gstaticontent.com/images/dkXCcbhVXbIqXXdms9ylVy6kJzJ_big.jpg'),
(7428, 465, 'Marvel - Demolidor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7429, 465, 'Marvel - Demolidor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7430, 465, 'Marvel - Demolidor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7431, 465, 'Marvel - Demolidor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7432, 465, 'Marvel - Demolidor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7433, 465, 'Marvel - Demolidor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7434, 465, 'Marvel - Demolidor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7435, 465, 'Marvel - Demolidor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7436, 465, 'Marvel - Demolidor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7437, 465, 'Marvel - Demolidor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7438, 465, 'Marvel - Demolidor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7439, 465, 'Marvel - Demolidor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7440, 465, 'Marvel - Demolidor S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7441, 466, 'Marvel - Demolidor S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7442, 466, 'Marvel - Demolidor S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7443, 466, 'Marvel - Demolidor S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7444, 466, 'Marvel - Demolidor S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7445, 466, 'Marvel - Demolidor S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7446, 466, 'Marvel - Demolidor S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7447, 466, 'Marvel - Demolidor S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7448, 466, 'Marvel - Demolidor S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7449, 466, 'Marvel - Demolidor S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7450, 466, 'Marvel - Demolidor S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7451, 466, 'Marvel - Demolidor S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7452, 466, 'Marvel - Demolidor S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7453, 466, 'Marvel - Demolidor S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7454, 467, 'Marvel - Demolidor S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7455, 467, 'Marvel - Demolidor S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7456, 467, 'Marvel - Demolidor S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7457, 467, 'Marvel - Demolidor S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7458, 467, 'Marvel - Demolidor S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7459, 467, 'Marvel - Demolidor S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7460, 467, 'Marvel - Demolidor S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7461, 467, 'Marvel - Demolidor S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7462, 467, 'Marvel - Demolidor S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7463, 467, 'Marvel - Demolidor S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7464, 467, 'Marvel - Demolidor S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7465, 467, 'Marvel - Demolidor S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7466, 467, 'Marvel - Demolidor S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x7zUHG5cko4ZXQO2209Qc2aoyrc.jpg'),
(7467, 468, 'Inumanos da Marvel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6MfdrtyKKlGnG3XQgbq7x7V1YMl.jpg'),
(7468, 468, 'Inumanos da Marvel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6MfdrtyKKlGnG3XQgbq7x7V1YMl.jpg'),
(7469, 468, 'Inumanos da Marvel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6MfdrtyKKlGnG3XQgbq7x7V1YMl.jpg'),
(7470, 468, 'Inumanos da Marvel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6MfdrtyKKlGnG3XQgbq7x7V1YMl.jpg'),
(7471, 468, 'Inumanos da Marvel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6MfdrtyKKlGnG3XQgbq7x7V1YMl.jpg'),
(7472, 468, 'Inumanos da Marvel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6MfdrtyKKlGnG3XQgbq7x7V1YMl.jpg'),
(7473, 468, 'Inumanos da Marvel S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6MfdrtyKKlGnG3XQgbq7x7V1YMl.jpg'),
(7474, 468, 'Inumanos da Marvel S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6MfdrtyKKlGnG3XQgbq7x7V1YMl.jpg'),
(7475, 469, 'Marvel - Os Defensores S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g0dcX4hYQY0yjuXPMA9oWQs1jBh.jpg'),
(7476, 469, 'Marvel - Os Defensores S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g0dcX4hYQY0yjuXPMA9oWQs1jBh.jpg'),
(7477, 469, 'Marvel - Os Defensores S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g0dcX4hYQY0yjuXPMA9oWQs1jBh.jpg'),
(7478, 469, 'Marvel - Os Defensores S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g0dcX4hYQY0yjuXPMA9oWQs1jBh.jpg'),
(7479, 469, 'Marvel - Os Defensores S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g0dcX4hYQY0yjuXPMA9oWQs1jBh.jpg'),
(7480, 469, 'Marvel - Os Defensores S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g0dcX4hYQY0yjuXPMA9oWQs1jBh.jpg'),
(7481, 469, 'Marvel - Os Defensores S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g0dcX4hYQY0yjuXPMA9oWQs1jBh.jpg'),
(7482, 469, 'Marvel - Os Defensores S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g0dcX4hYQY0yjuXPMA9oWQs1jBh.jpg'),
(7483, 470, 'da Marvel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7484, 470, 'da Marvel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7485, 470, 'da Marvel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7486, 470, 'da Marvel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7487, 470, 'da Marvel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7488, 470, 'da Marvel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7489, 470, 'da Marvel S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7490, 470, 'da Marvel S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7491, 470, 'da Marvel S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7492, 470, 'da Marvel S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7493, 471, 'da Marvel S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7494, 471, 'da Marvel S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7495, 471, 'da Marvel S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7496, 471, 'da Marvel S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7497, 471, 'da Marvel S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7498, 471, 'da Marvel S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7499, 471, 'da Marvel S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7500, 471, 'da Marvel S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7501, 471, 'da Marvel S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7502, 471, 'da Marvel S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7503, 471, 'da Marvel S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7504, 471, 'da Marvel S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7505, 471, 'da Marvel S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iixkIE4sjRGmskHAgMb2tPJofZE.jpg'),
(7506, 472, 'da Marvel S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tBKp3ZoPqfzUDgMA6PwVS3mYR15.jpg'),
(7507, 472, 'da Marvel S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhKQmU2dTBxqXvuQxCTYqc6yg0D.jpg'),
(7508, 472, 'da Marvel S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jESrZWkZnp6PX9Pc4UcCpQlz0m6.jpg'),
(7509, 472, 'da Marvel S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Rzczy99Il8F3QAwt890dKYiLqp.jpg'),
(7510, 472, 'da Marvel S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xv6xbFy8Ll4YSHYLcem5TbtLfTX.jpg'),
(7511, 472, 'da Marvel S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQHQYntfbp1OG3IeSzBrZo1rjsD.jpg'),
(7512, 472, 'da Marvel S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lv7RpntqInHdnj46x8fnuyaDbRA.jpg'),
(7513, 472, 'da Marvel S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iN91AoqvJkDnZ7iMSucQvQUyM3d.jpg'),
(7514, 472, 'da Marvel S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5BfDfB6qKJ5Faj32hyJSNiWIj8k.jpg'),
(7515, 472, 'da Marvel S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7l9UUQvcNLsK2E6cFoqx1jtalL8.jpg'),
(7516, 473, 'Me Chama de Bruna S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7517, 473, 'Me Chama de Bruna S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7518, 473, 'Me Chama de Bruna S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7519, 473, 'Me Chama de Bruna S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7520, 473, 'Me Chama de Bruna S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7521, 473, 'Me Chama de Bruna S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7522, 473, 'Me Chama de Bruna S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7523, 473, 'Me Chama de Bruna S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7524, 474, 'Me Chama de Bruna S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7525, 474, 'Me Chama de Bruna S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7526, 474, 'Me Chama de Bruna S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7527, 474, 'Me Chama de Bruna S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7528, 474, 'Me Chama de Bruna S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7529, 474, 'Me Chama de Bruna S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7530, 474, 'Me Chama de Bruna S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7531, 474, 'Me Chama de Bruna S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106538.mp4', 'http://timg.bdta.pro/images/49f83b2733d9c8ecf0e8c683a2cfb847.jpg'),
(7532, 475, 'Me Chama de Bruna S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7533, 475, 'Me Chama de Bruna S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7534, 475, 'Me Chama de Bruna S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7535, 475, 'Me Chama de Bruna S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7536, 475, 'Me Chama de Bruna S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7537, 475, 'Me Chama de Bruna S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7538, 475, 'Me Chama de Bruna S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7539, 475, 'Me Chama de Bruna S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFEtIlr97xkYRTNhRXUCgR2PvUa.jpg'),
(7540, 476, 'Me Chama de Bruna S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106547.mp4', 'http://timg.bdta.pro/images/851196a691e50581c4257dc7af7c2bde.jpg'),
(7541, 476, 'Me Chama de Bruna S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106548.mp4', 'http://timg.bdta.pro/images/72bf027f4cb8e8e526c0b160283daa74.jpg'),
(7542, 476, 'Me Chama de Bruna S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106549.mp4', 'http://timg.bdta.pro/images/e65492666e0e40c827fcac3c0afa217e.jpg'),
(7543, 476, 'Me Chama de Bruna S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106550.mp4', 'http://timg.bdta.pro/images/bced8636d7920df54dd80f5ee769fa0a.jpg'),
(7544, 476, 'Me Chama de Bruna S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106551.mp4', 'http://timg.bdta.pro/images/aa9f76937bbe2beaef44510ef1895545.jpg'),
(7545, 476, 'Me Chama de Bruna S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106552.mp4', 'http://timg.bdta.pro/images/5e9b9ee6f052e4b1547ab41995934735.jpg'),
(7546, 476, 'Me Chama de Bruna S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106553.mp4', 'http://timg.bdta.pro/images/78c90a1bb1d21a50304e9b94ec12a0f3.jpg'),
(7547, 476, 'Me Chama de Bruna S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106554.mp4', 'http://timg.bdta.pro/images/c8856541e5e85266f5e4f9cd381ed571.jpg'),
(7548, 477, 'Mr. Robot S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7549, 477, 'Mr. Robot S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7550, 477, 'Mr. Robot S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7551, 477, 'Mr. Robot S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7552, 477, 'Mr. Robot S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7553, 477, 'Mr. Robot S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7554, 477, 'Mr. Robot S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7555, 477, 'Mr. Robot S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7556, 477, 'Mr. Robot S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7557, 477, 'Mr. Robot S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7558, 478, 'Mr. Robot S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7559, 478, 'Mr. Robot S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7560, 478, 'Mr. Robot S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7561, 478, 'Mr. Robot S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7562, 478, 'Mr. Robot S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7563, 478, 'Mr. Robot S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7564, 478, 'Mr. Robot S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7565, 478, 'Mr. Robot S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7566, 478, 'Mr. Robot S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7567, 478, 'Mr. Robot S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7568, 478, 'Mr. Robot S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7569, 478, 'Mr. Robot S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7570, 479, 'Mr. Robot S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7571, 479, 'Mr. Robot S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7572, 479, 'Mr. Robot S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7573, 479, 'Mr. Robot S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7574, 479, 'Mr. Robot S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7575, 479, 'Mr. Robot S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7576, 479, 'Mr. Robot S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7577, 479, 'Mr. Robot S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7578, 479, 'Mr. Robot S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7579, 479, 'Mr. Robot S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7580, 480, 'Mr. Robot S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7581, 480, 'Mr. Robot S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7582, 480, 'Mr. Robot S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7583, 480, 'Mr. Robot S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7584, 480, 'Mr. Robot S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7585, 480, 'Mr. Robot S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7586, 480, 'Mr. Robot S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7587, 480, 'Mr. Robot S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7588, 480, 'Mr. Robot S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7589, 480, 'Mr. Robot S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7590, 480, 'Mr. Robot S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(7591, 480, 'Mr. Robot S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7592, 480, 'Mr. Robot S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uS9tYSYXU5jshLx2WlnOLZrMgD.jpg'),
(7593, 481, 'Narcos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101740.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7594, 481, 'Narcos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101741.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7595, 481, 'Narcos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101742.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7596, 481, 'Narcos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101743.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7597, 481, 'Narcos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101744.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7598, 481, 'Narcos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101745.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7599, 481, 'Narcos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101746.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7600, 481, 'Narcos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101747.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7601, 481, 'Narcos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101748.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7602, 481, 'Narcos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101749.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7603, 482, 'Narcos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101750.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7604, 482, 'Narcos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101751.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7605, 482, 'Narcos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101752.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7606, 482, 'Narcos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101753.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7607, 482, 'Narcos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101754.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7608, 482, 'Narcos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101755.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7609, 482, 'Narcos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101756.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7610, 482, 'Narcos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101757.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7611, 482, 'Narcos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101758.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7612, 482, 'Narcos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101759.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7613, 483, 'Narcos S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101760.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7614, 483, 'Narcos S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101761.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7615, 483, 'Narcos S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101762.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7616, 483, 'Narcos S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101763.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7617, 483, 'Narcos S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101764.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7618, 483, 'Narcos S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101765.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7619, 483, 'Narcos S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101766.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7620, 483, 'Narcos S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101767.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7621, 483, 'Narcos S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101768.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7622, 483, 'Narcos S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101769.mp4', 'http://gstaticontent.com/images/iTxNuSp5JEKLf4rLVz5aFulJD3k_big.jpg'),
(7623, 484, 'Nightflyers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101770.mp4', 'http://gstaticontent.com/images/faQ5NoMN7q72itGYkSTpUPsp3JN_big.jpg'),
(7624, 484, 'Nightflyers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101771.mp4', 'http://gstaticontent.com/images/faQ5NoMN7q72itGYkSTpUPsp3JN_big.jpg'),
(7625, 484, 'Nightflyers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101772.mp4', 'http://gstaticontent.com/images/faQ5NoMN7q72itGYkSTpUPsp3JN_big.jpg'),
(7626, 484, 'Nightflyers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101773.mp4', 'http://gstaticontent.com/images/faQ5NoMN7q72itGYkSTpUPsp3JN_big.jpg'),
(7627, 484, 'Nightflyers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101774.mp4', 'http://gstaticontent.com/images/faQ5NoMN7q72itGYkSTpUPsp3JN_big.jpg'),
(7628, 484, 'Nightflyers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101775.mp4', 'http://gstaticontent.com/images/faQ5NoMN7q72itGYkSTpUPsp3JN_big.jpg'),
(7629, 484, 'Nightflyers S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101776.mp4', 'http://gstaticontent.com/images/faQ5NoMN7q72itGYkSTpUPsp3JN_big.jpg'),
(7630, 484, 'Nightflyers S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101777.mp4', 'http://gstaticontent.com/images/faQ5NoMN7q72itGYkSTpUPsp3JN_big.jpg'),
(7631, 484, 'Nightflyers S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101778.mp4', 'http://gstaticontent.com/images/faQ5NoMN7q72itGYkSTpUPsp3JN_big.jpg'),
(7632, 484, 'Nightflyers S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101779.mp4', 'http://gstaticontent.com/images/faQ5NoMN7q72itGYkSTpUPsp3JN_big.jpg'),
(7633, 485, 'O Atirador S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101780.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7634, 485, 'O Atirador S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101781.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7635, 485, 'O Atirador S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101782.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7636, 485, 'O Atirador S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101783.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7637, 485, 'O Atirador S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101784.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7638, 485, 'O Atirador S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101785.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7639, 485, 'O Atirador S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101786.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7640, 485, 'O Atirador S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101787.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7641, 485, 'O Atirador S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101788.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7642, 485, 'O Atirador S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101789.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7643, 486, 'O Atirador S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101790.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7644, 486, 'O Atirador S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101791.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7645, 486, 'O Atirador S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101792.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7646, 486, 'O Atirador S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101793.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7647, 486, 'O Atirador S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101794.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7648, 486, 'O Atirador S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101795.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7649, 486, 'O Atirador S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101796.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7650, 486, 'O Atirador S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101797.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7651, 487, 'O Atirador S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101798.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7652, 487, 'O Atirador S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101799.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7653, 487, 'O Atirador S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101800.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7654, 487, 'O Atirador S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101801.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7655, 487, 'O Atirador S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101802.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7656, 487, 'O Atirador S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101803.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7657, 487, 'O Atirador S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101804.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7658, 487, 'O Atirador S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101805.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7659, 487, 'O Atirador S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101806.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7660, 487, 'O Atirador S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101807.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7661, 487, 'O Atirador S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/101808.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7662, 487, 'O Atirador S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/101809.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7663, 487, 'O Atirador S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/101810.mp4', 'http://gstaticontent.com/images/a4QGjhHUYh2wqHgD8Y6OWEkaRVI_big.jpg'),
(7664, 488, 'O Bosque S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101811.mp4', 'http://gstaticontent.com/images/4aVkC85KIWcJT6C3oSLp3pkwHKL_big.jpg'),
(7665, 488, 'O Bosque S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101812.mp4', 'http://gstaticontent.com/images/4aVkC85KIWcJT6C3oSLp3pkwHKL_big.jpg'),
(7666, 488, 'O Bosque S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101813.mp4', 'http://gstaticontent.com/images/4aVkC85KIWcJT6C3oSLp3pkwHKL_big.jpg'),
(7667, 488, 'O Bosque S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101814.mp4', 'http://gstaticontent.com/images/4aVkC85KIWcJT6C3oSLp3pkwHKL_big.jpg'),
(7668, 488, 'O Bosque S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101815.mp4', 'http://gstaticontent.com/images/4aVkC85KIWcJT6C3oSLp3pkwHKL_big.jpg'),
(7669, 488, 'O Bosque S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101816.mp4', 'http://gstaticontent.com/images/4aVkC85KIWcJT6C3oSLp3pkwHKL_big.jpg'),
(7670, 489, 'O Conto Da Aia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201215.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7671, 489, 'O Conto Da Aia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201216.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7672, 489, 'O Conto Da Aia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201217.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7673, 489, 'O Conto Da Aia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201218.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7674, 489, 'O Conto Da Aia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201219.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7675, 489, 'O Conto Da Aia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201220.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7676, 489, 'O Conto Da Aia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201221.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7677, 489, 'O Conto Da Aia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201222.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7678, 489, 'O Conto Da Aia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201223.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7679, 489, 'O Conto Da Aia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201224.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7680, 490, 'O Conto Da Aia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201225.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7681, 490, 'O Conto Da Aia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201226.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7682, 490, 'O Conto Da Aia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201227.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7683, 490, 'O Conto Da Aia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201228.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7684, 490, 'O Conto Da Aia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201229.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7685, 490, 'O Conto Da Aia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201230.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7686, 490, 'O Conto Da Aia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201231.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7687, 490, 'O Conto Da Aia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201232.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7688, 490, 'O Conto Da Aia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201233.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7689, 490, 'O Conto Da Aia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201234.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7690, 490, 'O Conto Da Aia S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201235.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7691, 490, 'O Conto Da Aia S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201236.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7692, 490, 'O Conto Da Aia S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201237.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7693, 491, 'O Conto Da Aia S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201238.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7694, 491, 'O Conto Da Aia S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201239.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7695, 491, 'O Conto Da Aia S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201240.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7696, 491, 'O Conto Da Aia S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201241.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7697, 491, 'O Conto Da Aia S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201242.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7698, 491, 'O Conto Da Aia S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201243.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7699, 491, 'O Conto Da Aia S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201244.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7700, 491, 'O Conto Da Aia S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201245.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7701, 491, 'O Conto Da Aia S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201246.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7702, 491, 'O Conto Da Aia S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201247.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7703, 491, 'O Conto Da Aia S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201248.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7704, 491, 'O Conto Da Aia S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201249.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7705, 491, 'O Conto Da Aia S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201250.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7706, 492, 'O Conto Da Aia S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201251.mp4', 'http://timg.bdta.pro/images/4379f76eb27c34e9ff05d102e1b7ee49.jpg'),
(7707, 492, 'O Conto Da Aia S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201252.mp4', 'http://timg.bdta.pro/images/3134d5cd1a99ac756ab20221116e7769.jpg'),
(7708, 492, 'O Conto Da Aia S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201253.mp4', 'http://timg.bdta.pro/images/9cc08223b72c041daa0d3f65a5f787ba.jpg'),
(7709, 492, 'O Conto Da Aia S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201254.mp4', 'http://timg.bdta.pro/images/2ed47dd67d1f7fdee88ed89870707156.jpg'),
(7710, 492, 'O Conto Da Aia S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201255.mp4', 'http://timg.bdta.pro/images/e32e40b3af53037c2b5fc0fd479000bf.jpg'),
(7711, 492, 'O Conto Da Aia S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201256.mp4', 'http://timg.bdta.pro/images/9d05b0a35bdcb778e1abffa5907dcbb2.jpg'),
(7712, 492, 'O Conto Da Aia S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201257.mp4', 'http://timg.bdta.pro/images/7367ffdb0e24605d21a8d3e92259356b.jpg'),
(7713, 492, 'O Conto Da Aia S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201258.mp4', 'http://timg.bdta.pro/images/3e525f11c444fceb30362f9985672ddd.jpg'),
(7714, 492, 'O Conto Da Aia S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201259.mp4', 'http://timg.bdta.pro/images/4835fff0e9616bbfb52991ab663389d4.jpg'),
(7715, 492, 'O Conto Da Aia S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201260.mp4', 'http://timg.bdta.pro/images/b648141c10d87808d66e511714a917b6.jpg'),
(7716, 493, 'O Conto Da Aia S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201261.mp4', 'http://timg.bdta.pro/images/ef923b0ee6406bd414b8bdc2cef3f03a.jpg'),
(7717, 493, 'O Conto Da Aia S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201262.mp4', 'http://timg.bdta.pro/images/151f9ca1b0f4d5a3b8f0a02623413f00.jpg'),
(7718, 493, 'O Conto Da Aia S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201263.mp4', 'http://timg.bdta.pro/images/343d72853ae1840812597bc81cc15455.jpg'),
(7719, 493, 'O Conto Da Aia S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201264.mp4', 'http://timg.bdta.pro/images/371010b6c98c174a40e63f74328033f6.jpg'),
(7720, 493, 'O Conto Da Aia S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201265.mp4', 'http://timg.bdta.pro/images/0a0dcc46f14ffcc298e1e1edbd83d914.jpg'),
(7721, 493, 'O Conto Da Aia S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201266.mp4', 'http://timg.bdta.pro/images/98dc54be0ddc9b64e323aac09437c3e2.jpg'),
(7722, 493, 'O Conto Da Aia S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fBVgLAPnCP8Tb7SigWCAJcy9rlF.jpg'),
(7723, 493, 'O Conto Da Aia S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gpZ4PnkgfVwdrr01SK4Feo8oEIh.jpg'),
(7724, 493, 'O Conto Da Aia S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2fVcMy0zZkyzurJhPUTjbD3X20S.jpg'),
(7725, 493, 'O Conto Da Aia S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9GpfGyc9m7EZfvSXn9Y5o8ZvVaR.jpg'),
(7726, 494, 'O Conto Da Aia S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/765629.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7727, 494, 'O Conto Da Aia S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/765630.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7728, 494, 'O Conto Da Aia S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/774028.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7729, 494, 'O Conto Da Aia S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/779188.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7730, 494, 'O Conto Da Aia S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/787441.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7731, 494, 'O Conto Da Aia S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/789600.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7732, 494, 'O Conto Da Aia S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/802278.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7733, 494, 'O Conto Da Aia S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/812451.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7734, 494, 'O Conto Da Aia S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/816394.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7735, 494, 'O Conto Da Aia S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/824669.mp4', 'http://gstaticontent.com/images/17cRboikG0xwKroMoTZLFUMmplS_big.jpg'),
(7736, 495, 'O Exorcista S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101817.mp4', 'http://gstaticontent.com/images/gcXOCWdv0ulNxEqV6jvZcUdZZRa_big.jpg'),
(7737, 495, 'O Exorcista S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101818.mp4', 'http://gstaticontent.com/images/gcXOCWdv0ulNxEqV6jvZcUdZZRa_big.jpg'),
(7738, 495, 'O Exorcista S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101819.mp4', 'http://gstaticontent.com/images/gcXOCWdv0ulNxEqV6jvZcUdZZRa_big.jpg'),
(7739, 495, 'O Exorcista S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101820.mp4', 'http://gstaticontent.com/images/gcXOCWdv0ulNxEqV6jvZcUdZZRa_big.jpg'),
(7740, 495, 'O Exorcista S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101821.mp4', 'http://gstaticontent.com/images/gcXOCWdv0ulNxEqV6jvZcUdZZRa_big.jpg'),
(7741, 495, 'O Exorcista S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101822.mp4', 'http://gstaticontent.com/images/gcXOCWdv0ulNxEqV6jvZcUdZZRa_big.jpg'),
(7742, 495, 'O Exorcista S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101823.mp4', 'http://gstaticontent.com/images/gcXOCWdv0ulNxEqV6jvZcUdZZRa_big.jpg'),
(7743, 495, 'O Exorcista S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101824.mp4', 'http://gstaticontent.com/images/gcXOCWdv0ulNxEqV6jvZcUdZZRa_big.jpg'),
(7744, 495, 'O Exorcista S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101825.mp4', 'http://gstaticontent.com/images/gcXOCWdv0ulNxEqV6jvZcUdZZRa_big.jpg'),
(7745, 495, 'O Exorcista S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101826.mp4', 'http://gstaticontent.com/images/gcXOCWdv0ulNxEqV6jvZcUdZZRa_big.jpg'),
(7746, 496, 'O Exorcista S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101827.mp4', 'http://gstaticontent.com/images/gcXOCWdv0ulNxEqV6jvZcUdZZRa_big.jpg'),
(7747, 496, 'O Exorcista S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101828.mp4', 'http://gstaticontent.com/images/gcXOCWdv0ulNxEqV6jvZcUdZZRa_big.jpg'),
(7748, 496, 'O Exorcista S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101829.mp4', 'http://gstaticontent.com/images/gcXOCWdv0ulNxEqV6jvZcUdZZRa_big.jpg'),
(7749, 496, 'O Exorcista S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101830.mp4', 'http://gstaticontent.com/images/gcXOCWdv0ulNxEqV6jvZcUdZZRa_big.jpg'),
(7750, 496, 'O Exorcista S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101831.mp4', 'http://gstaticontent.com/images/gcXOCWdv0ulNxEqV6jvZcUdZZRa_big.jpg'),
(7751, 496, 'O Exorcista S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101832.mp4', 'http://gstaticontent.com/images/gcXOCWdv0ulNxEqV6jvZcUdZZRa_big.jpg'),
(7752, 496, 'O Exorcista S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/101833.mp4', 'http://gstaticontent.com/images/gcXOCWdv0ulNxEqV6jvZcUdZZRa_big.jpg'),
(7753, 496, 'O Exorcista S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/101834.mp4', 'http://gstaticontent.com/images/gcXOCWdv0ulNxEqV6jvZcUdZZRa_big.jpg'),
(7754, 496, 'O Exorcista S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/101835.mp4', 'http://gstaticontent.com/images/gcXOCWdv0ulNxEqV6jvZcUdZZRa_big.jpg'),
(7755, 496, 'O Exorcista S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/101836.mp4', 'http://gstaticontent.com/images/gcXOCWdv0ulNxEqV6jvZcUdZZRa_big.jpg'),
(7756, 497, 'O Gerente Noturno S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101837.mp4', 'http://gstaticontent.com/images/iUTzJeO6IzieSG7RD2z0CUo3DDw_big.jpg'),
(7757, 497, 'O Gerente Noturno S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101838.mp4', 'http://gstaticontent.com/images/iUTzJeO6IzieSG7RD2z0CUo3DDw_big.jpg'),
(7758, 497, 'O Gerente Noturno S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101839.mp4', 'http://gstaticontent.com/images/iUTzJeO6IzieSG7RD2z0CUo3DDw_big.jpg'),
(7759, 497, 'O Gerente Noturno S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101840.mp4', 'http://gstaticontent.com/images/iUTzJeO6IzieSG7RD2z0CUo3DDw_big.jpg'),
(7760, 497, 'O Gerente Noturno S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/101841.mp4', 'http://gstaticontent.com/images/iUTzJeO6IzieSG7RD2z0CUo3DDw_big.jpg'),
(7761, 497, 'O Gerente Noturno S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/101842.mp4', 'http://gstaticontent.com/images/iUTzJeO6IzieSG7RD2z0CUo3DDw_big.jpg'),
(7762, 498, 'Marvel - O Justiceiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/101996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7763, 498, 'Marvel - O Justiceiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/101997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7764, 498, 'Marvel - O Justiceiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/101998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7765, 498, 'Marvel - O Justiceiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/101999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7766, 498, 'Marvel - O Justiceiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7767, 498, 'Marvel - O Justiceiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7768, 498, 'Marvel - O Justiceiro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7769, 498, 'Marvel - O Justiceiro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7770, 498, 'Marvel - O Justiceiro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7771, 498, 'Marvel - O Justiceiro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7772, 498, 'Marvel - O Justiceiro S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7773, 498, 'Marvel - O Justiceiro S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7774, 498, 'Marvel - O Justiceiro S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7775, 499, 'Marvel - O Justiceiro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7776, 499, 'Marvel - O Justiceiro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7777, 499, 'Marvel - O Justiceiro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7778, 499, 'Marvel - O Justiceiro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7779, 499, 'Marvel - O Justiceiro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7780, 499, 'Marvel - O Justiceiro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7781, 499, 'Marvel - O Justiceiro S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7782, 499, 'Marvel - O Justiceiro S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102016.mp4', 'http://timg.bdta.pro/images/ztxaSJfPbB2fZ0asHnIs1VWTOWb_small.jpg'),
(7783, 499, 'Marvel - O Justiceiro S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7784, 499, 'Marvel - O Justiceiro S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7785, 499, 'Marvel - O Justiceiro S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7786, 499, 'Marvel - O Justiceiro S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7787, 499, 'Marvel - O Justiceiro S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddiQriqWxnEDhy4ufjc18HDI98.jpg'),
(7788, 500, 'O Lobista S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLOtgMInPl3CVXpJIgB9VRx1Re9.jpg'),
(7789, 500, 'O Lobista S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLOtgMInPl3CVXpJIgB9VRx1Re9.jpg'),
(7790, 500, 'O Lobista S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLOtgMInPl3CVXpJIgB9VRx1Re9.jpg'),
(7791, 500, 'O Lobista S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLOtgMInPl3CVXpJIgB9VRx1Re9.jpg'),
(7792, 500, 'O Lobista S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLOtgMInPl3CVXpJIgB9VRx1Re9.jpg'),
(7793, 500, 'O Lobista S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLOtgMInPl3CVXpJIgB9VRx1Re9.jpg'),
(7794, 500, 'O Lobista S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLOtgMInPl3CVXpJIgB9VRx1Re9.jpg'),
(7795, 500, 'O Lobista S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLOtgMInPl3CVXpJIgB9VRx1Re9.jpg'),
(7796, 500, 'O Lobista S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLOtgMInPl3CVXpJIgB9VRx1Re9.jpg'),
(7797, 500, 'O Lobista S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLOtgMInPl3CVXpJIgB9VRx1Re9.jpg'),
(7798, 501, 'O Mecanismo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100001.mp4', 'http://gstaticontent.com/images/y0ZfBvOG99xqlPUDWqAdGfcdj1R_big.jpg'),
(7799, 501, 'O Mecanismo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100002.mp4', 'http://gstaticontent.com/images/y0ZfBvOG99xqlPUDWqAdGfcdj1R_big.jpg'),
(7800, 501, 'O Mecanismo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100003.mp4', 'http://gstaticontent.com/images/y0ZfBvOG99xqlPUDWqAdGfcdj1R_big.jpg'),
(7801, 501, 'O Mecanismo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100004.mp4', 'http://gstaticontent.com/images/y0ZfBvOG99xqlPUDWqAdGfcdj1R_big.jpg'),
(7802, 501, 'O Mecanismo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100005.mp4', 'http://gstaticontent.com/images/y0ZfBvOG99xqlPUDWqAdGfcdj1R_big.jpg'),
(7803, 501, 'O Mecanismo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100006.mp4', 'http://gstaticontent.com/images/y0ZfBvOG99xqlPUDWqAdGfcdj1R_big.jpg'),
(7804, 501, 'O Mecanismo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100007.mp4', 'http://gstaticontent.com/images/y0ZfBvOG99xqlPUDWqAdGfcdj1R_big.jpg'),
(7805, 501, 'O Mecanismo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100008.mp4', 'http://gstaticontent.com/images/y0ZfBvOG99xqlPUDWqAdGfcdj1R_big.jpg'),
(7806, 502, 'O Mecanismo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100009.mp4', 'http://gstaticontent.com/images/y0ZfBvOG99xqlPUDWqAdGfcdj1R_big.jpg'),
(7807, 502, 'O Mecanismo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100010.mp4', 'http://gstaticontent.com/images/y0ZfBvOG99xqlPUDWqAdGfcdj1R_big.jpg'),
(7808, 502, 'O Mecanismo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100011.mp4', 'http://gstaticontent.com/images/y0ZfBvOG99xqlPUDWqAdGfcdj1R_big.jpg'),
(7809, 502, 'O Mecanismo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100012.mp4', 'http://gstaticontent.com/images/y0ZfBvOG99xqlPUDWqAdGfcdj1R_big.jpg'),
(7810, 502, 'O Mecanismo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100013.mp4', 'http://gstaticontent.com/images/y0ZfBvOG99xqlPUDWqAdGfcdj1R_big.jpg'),
(7811, 502, 'O Mecanismo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100014.mp4', 'http://gstaticontent.com/images/y0ZfBvOG99xqlPUDWqAdGfcdj1R_big.jpg'),
(7812, 502, 'O Mecanismo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100015.mp4', 'http://gstaticontent.com/images/y0ZfBvOG99xqlPUDWqAdGfcdj1R_big.jpg'),
(7813, 502, 'O Mecanismo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100016.mp4', 'http://gstaticontent.com/images/y0ZfBvOG99xqlPUDWqAdGfcdj1R_big.jpg'),
(7814, 503, 'O Mentalista S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128887.mp4', 'http://timg.bdta.pro/images/110d23b4e91bde0799def3ba3ba8c4d2.jpg'),
(7815, 503, 'O Mentalista S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128888.mp4', 'http://timg.bdta.pro/images/a5e575233954350096fac959ec9ba355.jpg'),
(7816, 503, 'O Mentalista S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128889.mp4', 'http://timg.bdta.pro/images/71779cd32e6cda48e226afa0d1ddeda6.jpg'),
(7817, 503, 'O Mentalista S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128890.mp4', 'http://timg.bdta.pro/images/8fb886c28030d93e561b157d91dee907.jpg'),
(7818, 503, 'O Mentalista S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128891.mp4', 'http://timg.bdta.pro/images/acc6c4b96078e8059966dc870f8e755c.jpg'),
(7819, 503, 'O Mentalista S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128892.mp4', 'http://timg.bdta.pro/images/7991f7c23483b1e93b556540455af1a2.jpg'),
(7820, 503, 'O Mentalista S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128893.mp4', 'http://timg.bdta.pro/images/7ee29c7dcf81f128d77e0754306ceb0f.jpg'),
(7821, 503, 'O Mentalista S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128894.mp4', 'http://timg.bdta.pro/images/f62aa55049775cd251979dff398b4683.jpg'),
(7822, 503, 'O Mentalista S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128895.mp4', 'http://timg.bdta.pro/images/241e9afe3184ff55720251fb5803c94b.jpg'),
(7823, 503, 'O Mentalista S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128896.mp4', 'http://timg.bdta.pro/images/621800c857f3f1ac6d89df1c3b76edbe.jpg'),
(7824, 503, 'O Mentalista S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/128897.mp4', 'http://timg.bdta.pro/images/2f431df3caca54283d17b690e9e4f258.jpg'),
(7825, 503, 'O Mentalista S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/128898.mp4', 'http://timg.bdta.pro/images/dbb291b99f29f4d410cedd909a325948.jpg'),
(7826, 503, 'O Mentalista S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/128899.mp4', 'http://timg.bdta.pro/images/2832ee9fa5c75e7a6ecb1261d39077cc.jpg'),
(7827, 503, 'O Mentalista S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/128900.mp4', 'http://timg.bdta.pro/images/8fa83aea42712051d2de228dfa2b7390.jpg'),
(7828, 503, 'O Mentalista S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/128901.mp4', 'http://timg.bdta.pro/images/9d9d3e56b3f4d0496fb053fd5a3cad52.jpg'),
(7829, 503, 'O Mentalista S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/128902.mp4', 'http://timg.bdta.pro/images/d0b6deb97bfcd107b23cfe89645a9ef6.jpg'),
(7830, 503, 'O Mentalista S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/128903.mp4', 'http://timg.bdta.pro/images/2412a09b2355438ccb2d86d63b263bf3.jpg'),
(7831, 503, 'O Mentalista S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/128904.mp4', 'http://timg.bdta.pro/images/c7aba6e69a7fde17901ffa5b6316fc97.jpg'),
(7832, 503, 'O Mentalista S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/128905.mp4', 'http://timg.bdta.pro/images/d566159f841849a9a07a8bdfbd8d0e96.jpg'),
(7833, 503, 'O Mentalista S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/128906.mp4', 'http://timg.bdta.pro/images/11560085a23b6803487c68dcdac94422.jpg'),
(7834, 503, 'O Mentalista S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/128907.mp4', 'http://timg.bdta.pro/images/03c96ebf53b8ddc45ac098f2a0a5cc49.jpg'),
(7835, 503, 'O Mentalista S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/128908.mp4', 'http://timg.bdta.pro/images/0e397a902bc4f8693c2130e14855f50f.jpg'),
(7836, 503, 'O Mentalista S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/128909.mp4', 'http://timg.bdta.pro/images/512eff72497be1e44e15d173dbaf4734.jpg'),
(7837, 504, 'O Mentalista S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128910.mp4', 'http://timg.bdta.pro/images/9e2032bc737a9ebb93a26513034138d0.jpg'),
(7838, 504, 'O Mentalista S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128911.mp4', 'http://timg.bdta.pro/images/3b1bd132132fc4870d93938e3922abf4.jpg'),
(7839, 504, 'O Mentalista S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128912.mp4', 'http://timg.bdta.pro/images/7c2a971337c9ddede9fc1a969c15e41a.jpg'),
(7840, 504, 'O Mentalista S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128913.mp4', 'http://timg.bdta.pro/images/2ddeb0977571de33c3c87659e8825cc6.jpg'),
(7841, 504, 'O Mentalista S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128914.mp4', 'http://timg.bdta.pro/images/35110edf65028f289a913efc63a2cbb2.jpg'),
(7842, 504, 'O Mentalista S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128915.mp4', 'http://timg.bdta.pro/images/d82dc4641b8e792586ea7ed7fc0e8518.jpg'),
(7843, 504, 'O Mentalista S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128916.mp4', 'http://timg.bdta.pro/images/3245fbb0f044794fcdbb542d0054bc27.jpg'),
(7844, 504, 'O Mentalista S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128917.mp4', 'http://timg.bdta.pro/images/938665ea2aa6c1d3678de9645736180f.jpg'),
(7845, 504, 'O Mentalista S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128918.mp4', 'http://timg.bdta.pro/images/57a1502c6dee73f2de2ee2abaf57da41.jpg'),
(7846, 504, 'O Mentalista S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128919.mp4', 'http://timg.bdta.pro/images/8c877e2465449bef4c22a6c76dcbe125.jpg'),
(7847, 504, 'O Mentalista S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/128920.mp4', 'http://timg.bdta.pro/images/2c7dde4659977ae4a17379c5a8c44fc6.jpg'),
(7848, 504, 'O Mentalista S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/128921.mp4', 'http://timg.bdta.pro/images/8f03c8eb420961c8fa06d84f7fab377e.jpg'),
(7849, 504, 'O Mentalista S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/128922.mp4', 'http://timg.bdta.pro/images/98843901ccab68aeec12a6aa794a7175.jpg'),
(7850, 504, 'O Mentalista S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/128923.mp4', 'http://timg.bdta.pro/images/0d0f83facb6ae60f93d93cc58343db42.jpg'),
(7851, 504, 'O Mentalista S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/128924.mp4', 'http://timg.bdta.pro/images/5faed2a616a8b9faf241db050f2b5ae5.jpg'),
(7852, 504, 'O Mentalista S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/128925.mp4', 'http://timg.bdta.pro/images/92cd97e56781695546e813b8af26ab68.jpg'),
(7853, 504, 'O Mentalista S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/128926.mp4', 'http://timg.bdta.pro/images/948c673fea0c91b47c37f73b3aaba326.jpg'),
(7854, 504, 'O Mentalista S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/128927.mp4', 'http://timg.bdta.pro/images/f55b6ffca9bb4f4ee741a9d3985beb0a.jpg'),
(7855, 504, 'O Mentalista S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/128928.mp4', 'http://timg.bdta.pro/images/877210119ed0aba89538f085ebd98ee9.jpg'),
(7856, 504, 'O Mentalista S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/128929.mp4', 'http://timg.bdta.pro/images/9fdd427cbb81c5bdba5932e429ef82ea.jpg'),
(7857, 504, 'O Mentalista S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/128930.mp4', 'http://timg.bdta.pro/images/e8141fa5e399a14d7b1604649dc983fe.jpg'),
(7858, 504, 'O Mentalista S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/128931.mp4', 'http://timg.bdta.pro/images/cf8476e84fd3742295ea67e7f861a8bf.jpg'),
(7859, 504, 'O Mentalista S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/128932.mp4', 'http://timg.bdta.pro/images/9b6d329a44145be3738b81ad461de771.jpg'),
(7860, 505, 'O Mentalista S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128933.mp4', 'http://timg.bdta.pro/images/0c28172a6469ed475df254f27eb33842.jpg'),
(7861, 505, 'O Mentalista S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128934.mp4', 'http://timg.bdta.pro/images/10f2564f4c8e0e90ad9c0b8fa5e00738.jpg'),
(7862, 505, 'O Mentalista S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128935.mp4', 'http://timg.bdta.pro/images/8fd6f7bb667724abb9d83ef4f1c61d74.jpg'),
(7863, 505, 'O Mentalista S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128936.mp4', 'http://timg.bdta.pro/images/95b5bc3841a02022ce08e91991100077.jpg'),
(7864, 505, 'O Mentalista S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128937.mp4', 'http://timg.bdta.pro/images/724a8d331e335ef466a01d1cd0aa3f3d.jpg'),
(7865, 505, 'O Mentalista S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128938.mp4', 'http://timg.bdta.pro/images/d4fe97258c76094865fade923d6ad9d3.jpg'),
(7866, 505, 'O Mentalista S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128939.mp4', 'http://timg.bdta.pro/images/a49dc730426f5baae193ac657f892399.jpg'),
(7867, 505, 'O Mentalista S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128940.mp4', 'http://timg.bdta.pro/images/c17f426402232807ae01bd2504e18452.jpg'),
(7868, 505, 'O Mentalista S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128941.mp4', 'http://timg.bdta.pro/images/2bb2ecd0aa47340f91f12932aebdb425.jpg'),
(7869, 505, 'O Mentalista S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128942.mp4', 'http://timg.bdta.pro/images/076577ad2d3bf1935e587d28bf1338d0.jpg'),
(7870, 505, 'O Mentalista S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/128943.mp4', 'http://timg.bdta.pro/images/22ac6f0fc940fa4b08ed976424896434.jpg'),
(7871, 505, 'O Mentalista S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/128944.mp4', 'http://timg.bdta.pro/images/fe239b49f6b74f7287570c2de7c13155.jpg'),
(7872, 505, 'O Mentalista S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/128945.mp4', 'http://timg.bdta.pro/images/bb43a6c0a6952228782bd5cdb495aa95.jpg'),
(7873, 505, 'O Mentalista S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/128946.mp4', 'http://timg.bdta.pro/images/123cf46b6688315086fcfd5d2d1ec378.jpg'),
(7874, 505, 'O Mentalista S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/128947.mp4', 'http://timg.bdta.pro/images/af60aaea1dc259e8b3e99b9bc5818c80.jpg'),
(7875, 505, 'O Mentalista S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/128948.mp4', 'http://timg.bdta.pro/images/28661992129f2b6afd0db067636fcbb8.jpg'),
(7876, 505, 'O Mentalista S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/128949.mp4', 'http://timg.bdta.pro/images/f75cf6a869a1575521155d27a82c5e2f.jpg'),
(7877, 505, 'O Mentalista S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/128950.mp4', 'http://timg.bdta.pro/images/62b1f2bdc7691ee97e092196b55423e1.jpg'),
(7878, 505, 'O Mentalista S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/128951.mp4', 'http://timg.bdta.pro/images/3190b87365a00a804cdac3f8642fcd3f.jpg'),
(7879, 505, 'O Mentalista S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/128952.mp4', 'http://timg.bdta.pro/images/46061e3bfec7429ccd52bb647482d9b4.jpg'),
(7880, 505, 'O Mentalista S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/128953.mp4', 'http://timg.bdta.pro/images/511fa01ae0e7928f17395f581a548008.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(7881, 505, 'O Mentalista S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/128954.mp4', 'http://timg.bdta.pro/images/046d5ef99119185a7952049fd29e0c95.jpg'),
(7882, 505, 'O Mentalista S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/128955.mp4', 'http://timg.bdta.pro/images/e59ffd5a4d7136b6c0b37f060cf78a7c.jpg'),
(7883, 505, 'O Mentalista S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/128956.mp4', 'http://timg.bdta.pro/images/edbf129a2e29c892e93ce886a1de2f0f.jpg'),
(7884, 506, 'O Mentalista S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128957.mp4', 'http://timg.bdta.pro/images/c71f111de3f063ad6c78353cf80d1bb1.jpg'),
(7885, 506, 'O Mentalista S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128958.mp4', 'http://timg.bdta.pro/images/a088aff4a46dc351b9c3f85775442391.jpg'),
(7886, 506, 'O Mentalista S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128959.mp4', 'http://timg.bdta.pro/images/efd1356ca9fbca84db0769c09cd2efe1.jpg'),
(7887, 506, 'O Mentalista S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128960.mp4', 'http://timg.bdta.pro/images/c58487d56bf93b4915a61cb2d70ca6a0.jpg'),
(7888, 506, 'O Mentalista S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128961.mp4', 'http://timg.bdta.pro/images/28cb8d37b94160ca1b063b21cfa57a0c.jpg'),
(7889, 506, 'O Mentalista S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128962.mp4', 'http://timg.bdta.pro/images/e4206bc97ee1b33b52fdc6ca3432a97b.jpg'),
(7890, 506, 'O Mentalista S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128963.mp4', 'http://timg.bdta.pro/images/2b030396b6de8de460b5f579b62f6e26.jpg'),
(7891, 506, 'O Mentalista S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128964.mp4', 'http://timg.bdta.pro/images/b86d91cac687b983fb58d7f4dbbd9e43.jpg'),
(7892, 506, 'O Mentalista S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128965.mp4', 'http://timg.bdta.pro/images/f6551d0aa6ca0cc8dd9ea26e38c7c95c.jpg'),
(7893, 506, 'O Mentalista S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128966.mp4', 'http://timg.bdta.pro/images/a55558477069342409450c1753b9a31d.jpg'),
(7894, 506, 'O Mentalista S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/128967.mp4', 'http://timg.bdta.pro/images/3fb0edb1626d50cee3bc96cc3284c558.jpg'),
(7895, 506, 'O Mentalista S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/128968.mp4', 'http://timg.bdta.pro/images/44ddcea74130d25a2c8a36cb8e1ddbbb.jpg'),
(7896, 506, 'O Mentalista S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/128969.mp4', 'http://timg.bdta.pro/images/751d53f731cf74cf84d76df46466dea2.jpg'),
(7897, 506, 'O Mentalista S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/128970.mp4', 'http://timg.bdta.pro/images/dd8ec2141f0c42bfb287d8df97782168.jpg'),
(7898, 506, 'O Mentalista S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/128971.mp4', 'http://timg.bdta.pro/images/51f5cfab9225324b2248134a0971c98a.jpg'),
(7899, 506, 'O Mentalista S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/128972.mp4', 'http://timg.bdta.pro/images/8374042738d55d74d5fb59939bca87ef.jpg'),
(7900, 506, 'O Mentalista S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/128973.mp4', 'http://timg.bdta.pro/images/2fa6488a890f641728f50320b496c1cc.jpg'),
(7901, 506, 'O Mentalista S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/128974.mp4', 'http://timg.bdta.pro/images/54b12802e73ad0ca784d21c5b0f97383.jpg'),
(7902, 506, 'O Mentalista S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/128975.mp4', 'http://timg.bdta.pro/images/052b8d9bd313628cfc59e01f5608385a.jpg'),
(7903, 506, 'O Mentalista S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/128976.mp4', 'http://timg.bdta.pro/images/1acae0fb709a7b109b9118f449dbd640.jpg'),
(7904, 506, 'O Mentalista S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/128977.mp4', 'http://timg.bdta.pro/images/7ea1d2a2e22ed29b4eee043d4b49bcea.jpg'),
(7905, 506, 'O Mentalista S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/128978.mp4', 'http://timg.bdta.pro/images/d509c8e561d8b22513991d21226d6e96.jpg'),
(7906, 506, 'O Mentalista S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/128979.mp4', 'http://timg.bdta.pro/images/94d948110a62cfb62b35322aec393c63.jpg'),
(7907, 506, 'O Mentalista S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/128980.mp4', 'http://timg.bdta.pro/images/4e559d71fe0e9f28efa764b27bd99b13.jpg'),
(7908, 507, 'O Mentalista S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128981.mp4', 'http://timg.bdta.pro/images/0a42d2ba9db7830907386c68db39a9d5.jpg'),
(7909, 507, 'O Mentalista S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128982.mp4', 'http://timg.bdta.pro/images/1623d234c93e003263ebb949179aa436.jpg'),
(7910, 507, 'O Mentalista S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128983.mp4', 'http://timg.bdta.pro/images/ae33a0663b027031bccb12542b0a64cf.jpg'),
(7911, 507, 'O Mentalista S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128984.mp4', 'http://timg.bdta.pro/images/861971ae83448c2d18bc0490c56dbac9.jpg'),
(7912, 507, 'O Mentalista S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128985.mp4', 'http://timg.bdta.pro/images/89c8e5bebd603059d6fc8640464d514d.jpg'),
(7913, 507, 'O Mentalista S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128986.mp4', 'http://timg.bdta.pro/images/a36bd93a98921549876daaafda8ff484.jpg'),
(7914, 507, 'O Mentalista S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128987.mp4', 'http://timg.bdta.pro/images/8e6d93f50728aad64ff10c5613ce73e3.jpg'),
(7915, 507, 'O Mentalista S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128988.mp4', 'http://timg.bdta.pro/images/5e1e97388beb17981329aa8584673997.jpg'),
(7916, 507, 'O Mentalista S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128989.mp4', 'http://timg.bdta.pro/images/81dab2c6a38357cc40fdbc626110665f.jpg'),
(7917, 507, 'O Mentalista S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128990.mp4', 'http://timg.bdta.pro/images/d328419f71174ff87e429af2a4267b79.jpg'),
(7918, 507, 'O Mentalista S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/128991.mp4', 'http://timg.bdta.pro/images/e6c7c3b09666c1407f5822f87c9a31fb.jpg'),
(7919, 507, 'O Mentalista S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/128992.mp4', 'http://timg.bdta.pro/images/6d25196059a5900a4790f02dcc9ba932.jpg'),
(7920, 507, 'O Mentalista S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/128993.mp4', 'http://timg.bdta.pro/images/c2a139b1d29e69e3d5d6dbff8e87bcdf.jpg'),
(7921, 507, 'O Mentalista S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/128994.mp4', 'http://timg.bdta.pro/images/a9b15f1e30e13dc60213acb3caed4dbc.jpg'),
(7922, 507, 'O Mentalista S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/128995.mp4', 'http://timg.bdta.pro/images/a9f1ed13f4c8e9df92ce7c6d89bcffd9.jpg'),
(7923, 507, 'O Mentalista S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/128996.mp4', 'http://timg.bdta.pro/images/b536007aabc556eb41951463c3766320.jpg'),
(7924, 507, 'O Mentalista S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/128997.mp4', 'http://timg.bdta.pro/images/633f66fdf439577cede9b4d63ce570c9.jpg'),
(7925, 507, 'O Mentalista S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/128998.mp4', 'http://timg.bdta.pro/images/1add44417184f47b1caafcd411a1a047.jpg'),
(7926, 507, 'O Mentalista S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/128999.mp4', 'http://timg.bdta.pro/images/b7fdeb178f35e479d00dda9cdd0ed429.jpg'),
(7927, 507, 'O Mentalista S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129000.mp4', 'http://timg.bdta.pro/images/1ad6d5beea8259a19a694126f87e07a8.jpg'),
(7928, 507, 'O Mentalista S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129001.mp4', 'http://timg.bdta.pro/images/1f6373f314f720f8d966ae62ea39b15c.jpg'),
(7929, 507, 'O Mentalista S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129002.mp4', 'http://timg.bdta.pro/images/334e5650d669569dd133390348516ee5.jpg'),
(7930, 508, 'O Mentalista S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129003.mp4', 'http://timg.bdta.pro/images/30b90cd563b86ce9c44a93029b262daf.jpg'),
(7931, 508, 'O Mentalista S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129004.mp4', 'http://timg.bdta.pro/images/5e11eef0e17de0082a9a580fcff92cbe.jpg'),
(7932, 508, 'O Mentalista S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129005.mp4', 'http://timg.bdta.pro/images/a46306c9ad11f25aec4947c54604792c.jpg'),
(7933, 508, 'O Mentalista S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129006.mp4', 'http://timg.bdta.pro/images/7b9f094ea0fc3cddfa6cb22ac38d57db.jpg'),
(7934, 508, 'O Mentalista S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129007.mp4', 'http://timg.bdta.pro/images/c3fcbe3c5a747f912192188d00499915.jpg'),
(7935, 508, 'O Mentalista S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129008.mp4', 'http://timg.bdta.pro/images/2f4f4d19630884a69a6924f688f0b042.jpg'),
(7936, 508, 'O Mentalista S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129009.mp4', 'http://timg.bdta.pro/images/b0039aa79a4cb06f2bbe7a9d6166c08e.jpg'),
(7937, 508, 'O Mentalista S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129010.mp4', 'http://timg.bdta.pro/images/2e723123ede0ae5067ff8720dba4e7d7.jpg'),
(7938, 508, 'O Mentalista S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129011.mp4', 'http://timg.bdta.pro/images/a515af0863ec3a82d598ba2b0df29bd9.jpg'),
(7939, 508, 'O Mentalista S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129012.mp4', 'http://timg.bdta.pro/images/30e0271c5e66dc804e6de751c731b5f5.jpg'),
(7940, 508, 'O Mentalista S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129013.mp4', 'http://timg.bdta.pro/images/dcf93ce0306b3da4d35127f2349ea0c7.jpg'),
(7941, 508, 'O Mentalista S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129014.mp4', 'http://timg.bdta.pro/images/c3ff6c07609f80c644b4bb2e7ff766fd.jpg'),
(7942, 508, 'O Mentalista S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129015.mp4', 'http://timg.bdta.pro/images/c94a397333feb682cc6e8bf01683d424.jpg'),
(7943, 508, 'O Mentalista S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129016.mp4', 'http://timg.bdta.pro/images/d24a8fa4e552684addd03d26508c6d0a.jpg'),
(7944, 508, 'O Mentalista S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129017.mp4', 'http://timg.bdta.pro/images/af22bd789a650534a6c045b244bd1e98.jpg'),
(7945, 508, 'O Mentalista S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129018.mp4', 'http://timg.bdta.pro/images/1c1c9e354093479946164e7d9d35d9df.jpg'),
(7946, 508, 'O Mentalista S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129019.mp4', 'http://timg.bdta.pro/images/368df3231910bff8cbf5b686ed8b6ef2.jpg'),
(7947, 508, 'O Mentalista S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129020.mp4', 'http://timg.bdta.pro/images/91a607afc8777eb5e3cc40eff688a58b.jpg'),
(7948, 508, 'O Mentalista S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129021.mp4', 'http://timg.bdta.pro/images/6d3204afcc541c78d88f3b7375a85ff6.jpg'),
(7949, 508, 'O Mentalista S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129022.mp4', 'http://timg.bdta.pro/images/16d225695f6a6dd378dbb43581152c2b.jpg'),
(7950, 508, 'O Mentalista S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129023.mp4', 'http://timg.bdta.pro/images/5148d00636fe26066a0804d208f438ed.jpg'),
(7951, 508, 'O Mentalista S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129024.mp4', 'http://timg.bdta.pro/images/14713131a01733d5071ba9eef20e4cb7.jpg'),
(7952, 509, 'O Mentalista S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129025.mp4', 'http://timg.bdta.pro/images/78788302ef1e3ff4cc693108864320a5.jpg'),
(7953, 509, 'O Mentalista S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129026.mp4', 'http://timg.bdta.pro/images/d74611a130dfc75f67afb0fddcbeed4e.jpg'),
(7954, 509, 'O Mentalista S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129027.mp4', 'http://timg.bdta.pro/images/1661d328edb4808e6f06b577491b99b2.jpg'),
(7955, 509, 'O Mentalista S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129028.mp4', 'http://timg.bdta.pro/images/e659c5417af5cbb3f1e6cdc69ea349a3.jpg'),
(7956, 509, 'O Mentalista S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129029.mp4', 'http://timg.bdta.pro/images/5426b4ee79a67aed1ff2ee66bb130116.jpg'),
(7957, 509, 'O Mentalista S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129030.mp4', 'http://timg.bdta.pro/images/1a7cc6c73c2e25bf3393d2143816f200.jpg'),
(7958, 509, 'O Mentalista S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129031.mp4', 'http://timg.bdta.pro/images/b7f5f3144c4aabe0cdd47ec9f55ead96.jpg'),
(7959, 509, 'O Mentalista S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129032.mp4', 'http://timg.bdta.pro/images/e462582a78500c59835b100acbb06170.jpg'),
(7960, 509, 'O Mentalista S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129033.mp4', 'http://timg.bdta.pro/images/6b4c63b6d2d89cdcfd482cbf1199ce3d.jpg'),
(7961, 509, 'O Mentalista S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129034.mp4', 'http://timg.bdta.pro/images/2bda1d44922bf52ee07dbac2ed8938e2.jpg'),
(7962, 509, 'O Mentalista S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129035.mp4', 'http://timg.bdta.pro/images/f6a62cd68e797f5b9400365103661b6d.jpg'),
(7963, 509, 'O Mentalista S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129036.mp4', 'http://timg.bdta.pro/images/347ed381827158474bda78eb9e036f7e.jpg'),
(7964, 509, 'O Mentalista S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129037.mp4', 'http://timg.bdta.pro/images/b5f49916ba740be0b9c127e779db01e1.jpg'),
(7965, 510, 'O Mundo Perdido S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102022.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7966, 510, 'O Mundo Perdido S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102023.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7967, 510, 'O Mundo Perdido S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102024.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7968, 510, 'O Mundo Perdido S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102025.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7969, 510, 'O Mundo Perdido S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102026.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7970, 510, 'O Mundo Perdido S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102027.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7971, 510, 'O Mundo Perdido S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102028.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7972, 510, 'O Mundo Perdido S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102029.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7973, 510, 'O Mundo Perdido S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102030.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7974, 510, 'O Mundo Perdido S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102031.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7975, 510, 'O Mundo Perdido S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102032.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7976, 510, 'O Mundo Perdido S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102033.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7977, 510, 'O Mundo Perdido S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102034.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7978, 510, 'O Mundo Perdido S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/102035.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7979, 510, 'O Mundo Perdido S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/102036.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7980, 510, 'O Mundo Perdido S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/102037.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7981, 510, 'O Mundo Perdido S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/102038.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7982, 510, 'O Mundo Perdido S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/102039.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7983, 510, 'O Mundo Perdido S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/102040.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7984, 510, 'O Mundo Perdido S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/102041.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7985, 510, 'O Mundo Perdido S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/102042.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7986, 511, 'O Mundo Perdido S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102043.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7987, 511, 'O Mundo Perdido S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102044.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7988, 511, 'O Mundo Perdido S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102045.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7989, 511, 'O Mundo Perdido S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102046.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7990, 511, 'O Mundo Perdido S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102047.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7991, 511, 'O Mundo Perdido S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102048.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7992, 511, 'O Mundo Perdido S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102049.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7993, 511, 'O Mundo Perdido S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102050.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7994, 511, 'O Mundo Perdido S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102051.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7995, 511, 'O Mundo Perdido S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102052.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7996, 511, 'O Mundo Perdido S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102053.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7997, 511, 'O Mundo Perdido S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102054.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7998, 511, 'O Mundo Perdido S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102055.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(7999, 511, 'O Mundo Perdido S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/102056.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8000, 511, 'O Mundo Perdido S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/102057.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8001, 511, 'O Mundo Perdido S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/102058.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8002, 511, 'O Mundo Perdido S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/102059.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8003, 511, 'O Mundo Perdido S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/102060.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8004, 511, 'O Mundo Perdido S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/102061.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8005, 511, 'O Mundo Perdido S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/102062.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8006, 511, 'O Mundo Perdido S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/102063.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8007, 511, 'O Mundo Perdido S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/102064.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8008, 512, 'O Mundo Perdido S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102065.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8009, 512, 'O Mundo Perdido S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102066.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8010, 512, 'O Mundo Perdido S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102067.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8011, 512, 'O Mundo Perdido S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102068.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8012, 512, 'O Mundo Perdido S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102069.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8013, 512, 'O Mundo Perdido S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102070.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8014, 512, 'O Mundo Perdido S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102071.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8015, 512, 'O Mundo Perdido S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102072.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8016, 512, 'O Mundo Perdido S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102073.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8017, 512, 'O Mundo Perdido S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102074.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8018, 512, 'O Mundo Perdido S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102075.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8019, 512, 'O Mundo Perdido S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102076.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8020, 512, 'O Mundo Perdido S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102077.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8021, 512, 'O Mundo Perdido S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/102078.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8022, 512, 'O Mundo Perdido S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/102079.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8023, 512, 'O Mundo Perdido S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/102080.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8024, 512, 'O Mundo Perdido S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/102081.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8025, 512, 'O Mundo Perdido S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/102082.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8026, 512, 'O Mundo Perdido S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/102083.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8027, 512, 'O Mundo Perdido S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/102084.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8028, 512, 'O Mundo Perdido S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/102085.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8029, 512, 'O Mundo Perdido S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/102086.mp4', 'http://gstaticontent.com/images/whA1PLf8nslT3R7kSvCssTCCUba_big.jpg'),
(8030, 513, 'O Mundo Sombrio De Sabrina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137279.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8031, 513, 'O Mundo Sombrio De Sabrina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137280.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8032, 513, 'O Mundo Sombrio De Sabrina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137281.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8033, 513, 'O Mundo Sombrio De Sabrina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137282.mp4', 'http://image.tmdb.org/t/p/w1280/zXHRZ5wT1scwp9qxlBryTG08OiT.jpg'),
(8034, 513, 'O Mundo Sombrio De Sabrina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137283.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8035, 513, 'O Mundo Sombrio De Sabrina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137284.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8036, 513, 'O Mundo Sombrio De Sabrina S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137285.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8037, 513, 'O Mundo Sombrio De Sabrina S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137286.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8038, 513, 'O Mundo Sombrio De Sabrina S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137287.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8039, 513, 'O Mundo Sombrio De Sabrina S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137288.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8040, 514, 'O Mundo Sombrio De Sabrina S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137289.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8041, 514, 'O Mundo Sombrio De Sabrina S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137290.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8042, 514, 'O Mundo Sombrio De Sabrina S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137291.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8043, 514, 'O Mundo Sombrio De Sabrina S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137292.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8044, 514, 'O Mundo Sombrio De Sabrina S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137293.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8045, 514, 'O Mundo Sombrio De Sabrina S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137294.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8046, 514, 'O Mundo Sombrio De Sabrina S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137295.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8047, 514, 'O Mundo Sombrio De Sabrina S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137296.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8048, 514, 'O Mundo Sombrio De Sabrina S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137297.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8049, 515, 'O Mundo Sombrio De Sabrina S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137298.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8050, 515, 'O Mundo Sombrio De Sabrina S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137299.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8051, 515, 'O Mundo Sombrio De Sabrina S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137300.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8052, 515, 'O Mundo Sombrio De Sabrina S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137301.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8053, 515, 'O Mundo Sombrio De Sabrina S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137302.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8054, 515, 'O Mundo Sombrio De Sabrina S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137303.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8055, 515, 'O Mundo Sombrio De Sabrina S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137304.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8056, 515, 'O Mundo Sombrio De Sabrina S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137305.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8057, 516, 'O Mundo Sombrio De Sabrina S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137306.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8058, 516, 'O Mundo Sombrio De Sabrina S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137307.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8059, 516, 'O Mundo Sombrio De Sabrina S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137308.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8060, 516, 'O Mundo Sombrio De Sabrina S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137309.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8061, 516, 'O Mundo Sombrio De Sabrina S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137310.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8062, 516, 'O Mundo Sombrio De Sabrina S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137311.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8063, 516, 'O Mundo Sombrio De Sabrina S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137312.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8064, 516, 'O Mundo Sombrio De Sabrina S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137313.mp4', 'http://gstaticontent.com/images/3XNUMEnHzCKvCYvYpnFgoZa7QQL_big.jpg'),
(8065, 517, 'Era uma Vez S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8066, 517, 'Era uma Vez S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8067, 517, 'Era uma Vez S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8068, 517, 'Era uma Vez S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8069, 517, 'Era uma Vez S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8070, 517, 'Era uma Vez S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8071, 517, 'Era uma Vez S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8072, 517, 'Era uma Vez S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8073, 517, 'Era uma Vez S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8074, 517, 'Era uma Vez S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8075, 517, 'Era uma Vez S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8076, 517, 'Era uma Vez S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8077, 517, 'Era uma Vez S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8078, 517, 'Era uma Vez S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8079, 517, 'Era uma Vez S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8080, 517, 'Era uma Vez S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8081, 517, 'Era uma Vez S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/143225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8082, 517, 'Era uma Vez S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/143226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8083, 517, 'Era uma Vez S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/143227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8084, 517, 'Era uma Vez S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/143228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8085, 517, 'Era uma Vez S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/143229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8086, 517, 'Era uma Vez S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/143230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8087, 518, 'Era uma Vez S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8088, 518, 'Era uma Vez S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8089, 518, 'Era uma Vez S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8090, 518, 'Era uma Vez S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8091, 518, 'Era uma Vez S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8092, 518, 'Era uma Vez S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8093, 518, 'Era uma Vez S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8094, 518, 'Era uma Vez S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8095, 518, 'Era uma Vez S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8096, 518, 'Era uma Vez S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8097, 518, 'Era uma Vez S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8098, 518, 'Era uma Vez S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8099, 518, 'Era uma Vez S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8100, 518, 'Era uma Vez S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8101, 518, 'Era uma Vez S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8102, 518, 'Era uma Vez S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8103, 518, 'Era uma Vez S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/143247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8104, 518, 'Era uma Vez S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/143248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8105, 518, 'Era uma Vez S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/143249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8106, 518, 'Era uma Vez S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/143250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8107, 518, 'Era uma Vez S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/143251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8108, 518, 'Era uma Vez S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/143252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8109, 519, 'Era uma Vez S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8110, 519, 'Era uma Vez S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8111, 519, 'Era uma Vez S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8112, 519, 'Era uma Vez S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8113, 519, 'Era uma Vez S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8114, 519, 'Era uma Vez S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8115, 519, 'Era uma Vez S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8116, 519, 'Era uma Vez S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8117, 519, 'Era uma Vez S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8118, 519, 'Era uma Vez S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8119, 519, 'Era uma Vez S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8120, 519, 'Era uma Vez S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8121, 519, 'Era uma Vez S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8122, 519, 'Era uma Vez S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8123, 519, 'Era uma Vez S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8124, 519, 'Era uma Vez S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8125, 519, 'Era uma Vez S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/143269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8126, 519, 'Era uma Vez S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/143270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8127, 519, 'Era uma Vez S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/143271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8128, 519, 'Era uma Vez S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/143272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8129, 519, 'Era uma Vez S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/143273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8130, 519, 'Era uma Vez S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/143274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8131, 520, 'Era uma Vez S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8132, 520, 'Era uma Vez S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8133, 520, 'Era uma Vez S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8134, 520, 'Era uma Vez S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8135, 520, 'Era uma Vez S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8136, 520, 'Era uma Vez S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8137, 520, 'Era uma Vez S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8138, 520, 'Era uma Vez S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8139, 520, 'Era uma Vez S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8140, 520, 'Era uma Vez S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8141, 520, 'Era uma Vez S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8142, 520, 'Era uma Vez S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8143, 520, 'Era uma Vez S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8144, 520, 'Era uma Vez S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8145, 520, 'Era uma Vez S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8146, 520, 'Era uma Vez S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8147, 520, 'Era uma Vez S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/143291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8148, 520, 'Era uma Vez S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/143292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8149, 520, 'Era uma Vez S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/143293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8150, 520, 'Era uma Vez S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/143294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8151, 520, 'Era uma Vez S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/143295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8152, 520, 'Era uma Vez S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/143296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8153, 520, 'Era uma Vez S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/143297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8154, 521, 'Era uma Vez S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8155, 521, 'Era uma Vez S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8156, 521, 'Era uma Vez S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8157, 521, 'Era uma Vez S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8158, 521, 'Era uma Vez S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8159, 521, 'Era uma Vez S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8160, 521, 'Era uma Vez S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8161, 521, 'Era uma Vez S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8162, 521, 'Era uma Vez S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(8163, 521, 'Era uma Vez S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8164, 521, 'Era uma Vez S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8165, 521, 'Era uma Vez S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8166, 521, 'Era uma Vez S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8167, 521, 'Era uma Vez S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8168, 521, 'Era uma Vez S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8169, 521, 'Era uma Vez S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8170, 521, 'Era uma Vez S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/143314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8171, 521, 'Era uma Vez S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/143315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8172, 521, 'Era uma Vez S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/143316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8173, 521, 'Era uma Vez S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/143317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8174, 521, 'Era uma Vez S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/143318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8175, 521, 'Era uma Vez S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/143319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8176, 521, 'Era uma Vez S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/143320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8177, 522, 'Era uma Vez S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8178, 522, 'Era uma Vez S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8179, 522, 'Era uma Vez S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8180, 522, 'Era uma Vez S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8181, 522, 'Era uma Vez S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8182, 522, 'Era uma Vez S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8183, 522, 'Era uma Vez S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8184, 522, 'Era uma Vez S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8185, 522, 'Era uma Vez S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8186, 522, 'Era uma Vez S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8187, 522, 'Era uma Vez S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8188, 522, 'Era uma Vez S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8189, 522, 'Era uma Vez S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8190, 522, 'Era uma Vez S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8191, 522, 'Era uma Vez S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8192, 522, 'Era uma Vez S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8193, 522, 'Era uma Vez S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/143337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8194, 522, 'Era uma Vez S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/143338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8195, 522, 'Era uma Vez S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/143339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8196, 522, 'Era uma Vez S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/143340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8197, 522, 'Era uma Vez S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/143341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8198, 522, 'Era uma Vez S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/143342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8199, 522, 'Era uma Vez S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/143343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8200, 523, 'Era uma Vez S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8201, 523, 'Era uma Vez S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8202, 523, 'Era uma Vez S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8203, 523, 'Era uma Vez S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8204, 523, 'Era uma Vez S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8205, 523, 'Era uma Vez S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8206, 523, 'Era uma Vez S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8207, 523, 'Era uma Vez S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8208, 523, 'Era uma Vez S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8209, 523, 'Era uma Vez S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8210, 523, 'Era uma Vez S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8211, 523, 'Era uma Vez S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8212, 523, 'Era uma Vez S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8213, 523, 'Era uma Vez S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8214, 523, 'Era uma Vez S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8215, 523, 'Era uma Vez S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8216, 523, 'Era uma Vez S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/143360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8217, 523, 'Era uma Vez S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/143361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8218, 523, 'Era uma Vez S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/143362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8219, 523, 'Era uma Vez S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/143363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8220, 523, 'Era uma Vez S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/143364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wbsG9jUs9FkYwggrJLGquuYMihF.jpg'),
(8221, 524, 'O Negócio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgPG7iWLy3IFUNj4BSLqxB1D6JH.jpg'),
(8222, 524, 'O Negócio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgPG7iWLy3IFUNj4BSLqxB1D6JH.jpg'),
(8223, 524, 'O Negócio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgPG7iWLy3IFUNj4BSLqxB1D6JH.jpg'),
(8224, 524, 'O Negócio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgPG7iWLy3IFUNj4BSLqxB1D6JH.jpg'),
(8225, 524, 'O Negócio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgPG7iWLy3IFUNj4BSLqxB1D6JH.jpg'),
(8226, 524, 'O Negócio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgPG7iWLy3IFUNj4BSLqxB1D6JH.jpg'),
(8227, 524, 'O Negócio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgPG7iWLy3IFUNj4BSLqxB1D6JH.jpg'),
(8228, 524, 'O Negócio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgPG7iWLy3IFUNj4BSLqxB1D6JH.jpg'),
(8229, 524, 'O Negócio S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgPG7iWLy3IFUNj4BSLqxB1D6JH.jpg'),
(8230, 524, 'O Negócio S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgPG7iWLy3IFUNj4BSLqxB1D6JH.jpg'),
(8231, 524, 'O Negócio S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgPG7iWLy3IFUNj4BSLqxB1D6JH.jpg'),
(8232, 524, 'O Negócio S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgPG7iWLy3IFUNj4BSLqxB1D6JH.jpg'),
(8233, 524, 'O Negócio S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgPG7iWLy3IFUNj4BSLqxB1D6JH.jpg'),
(8234, 525, 'O Negócio S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eAuAsYK088gcWhPX4hKmUhvDzKd.jpg'),
(8235, 525, 'O Negócio S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2iY6qDWIGbOuKO1Tv2PrGBWGgAJ.jpg'),
(8236, 525, 'O Negócio S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ymP3pSyDjGaY1oAM3bmgVEinks4.jpg'),
(8237, 525, 'O Negócio S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wWQ0vDDuj0sYcS4dUBMi6lQb4WX.jpg'),
(8238, 525, 'O Negócio S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5NU96BxZyGv2rKR2JTeQ9LnPvLk.jpg'),
(8239, 525, 'O Negócio S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBxvKrbL0O82G8PCYJxmELXTRWs.jpg'),
(8240, 525, 'O Negócio S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c9QfCz7hbsJkE61xTKK5IK7v965.jpg'),
(8241, 525, 'O Negócio S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qYLQz7HtST2t95K0oz74ra5Ivdl.jpg'),
(8242, 525, 'O Negócio S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hlEqEFVkl2AcL6hajUOHWBBiPef.jpg'),
(8243, 525, 'O Negócio S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qcsZEpzEHfT60gWAY0SEv3uGK9T.jpg'),
(8244, 525, 'O Negócio S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJagU2DyahlfJW40Da42ES0H4Ud.jpg'),
(8245, 525, 'O Negócio S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jrwtg8mLXLeg0LZCIWGQFC5bJx3.jpg'),
(8246, 525, 'O Negócio S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCfzvPr7iecwLIdegHj3xSMIU0t.jpg'),
(8247, 526, 'O Negócio S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6wB7ewqVRMCSCZTLDmrIexX9VlE.jpg'),
(8248, 526, 'O Negócio S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wjiybJ7h9kndtJlIwPGrQDsoWoj.jpg'),
(8249, 526, 'O Negócio S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t3XSgqYNu731yND8lvd5lqzDN0T.jpg'),
(8250, 526, 'O Negócio S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qdokheKpPbLDkHBpN5nrbSs2i1b.jpg'),
(8251, 526, 'O Negócio S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGfAYa9MtShgdNscdHQOUkfKXf0.jpg'),
(8252, 526, 'O Negócio S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uGgNoHiIKWyCWYVKCKipY88e0Xk.jpg'),
(8253, 526, 'O Negócio S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mqzJPw00jtfbxRuv3HvXRc3gNF3.jpg'),
(8254, 526, 'O Negócio S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kjqa17HAgikml0ZICda8AGeXUCE.jpg'),
(8255, 526, 'O Negócio S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gypfJCrA0mXN1SRtr04WU0PyAuM.jpg'),
(8256, 526, 'O Negócio S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ImUngRjKXz1usxgva2Rn4jrtJ0.jpg'),
(8257, 526, 'O Negócio S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zHSJjfhS33I7WwXZQtQ3fFCwg0g.jpg'),
(8258, 526, 'O Negócio S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQFSCWiODsrLrVRmNMLwv58XiPM.jpg'),
(8259, 526, 'O Negócio S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yCEdG4Clc7zbOyk12X2SoH1vkii.jpg'),
(8260, 527, 'O Negócio S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lvKFo8lr7K75B70PSLZJ2sRTxrQ.jpg'),
(8261, 527, 'O Negócio S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/isH8sIJ8dJiNZBtdtxpGIOtLwFD.jpg'),
(8262, 527, 'O Negócio S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/phxIhDR84aDWuq2U3OBqXRM1b8f.jpg'),
(8263, 527, 'O Negócio S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pqBtHOFPJKn1OpXluNMlx5wsOXG.jpg'),
(8264, 527, 'O Negócio S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7OmrYsWrZpKMW9SERTZ5X2ALOg.jpg'),
(8265, 527, 'O Negócio S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zsmLogPTaWRtivGkXR1c4xKoOt8.jpg'),
(8266, 527, 'O Negócio S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o6N7Z4pMUNaAT8NYogBfmVEpXrx.jpg'),
(8267, 527, 'O Negócio S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yGuStlz4eKzUlFOf3GcLEBnS9Op.jpg'),
(8268, 527, 'O Negócio S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qYLZDjyRSJkjrPdesrtCbt5Dvwp.jpg'),
(8269, 527, 'O Negócio S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vGw5PgVyCMJZEwlfndGW6syLI8U.jpg'),
(8270, 527, 'O Negócio S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bu8piKHLO2wEwz0AB4RixHUCQBQ.jpg'),
(8271, 527, 'O Negócio S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cpaQrS02aApYO2UQVbBB6Y1EQyb.jpg'),
(8272, 528, 'Lances da Vida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8273, 528, 'Lances da Vida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8274, 528, 'Lances da Vida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8275, 528, 'Lances da Vida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8276, 528, 'Lances da Vida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8277, 528, 'Lances da Vida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8278, 528, 'Lances da Vida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8279, 528, 'Lances da Vida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8280, 528, 'Lances da Vida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8281, 528, 'Lances da Vida S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8282, 528, 'Lances da Vida S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8283, 528, 'Lances da Vida S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8284, 528, 'Lances da Vida S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8285, 528, 'Lances da Vida S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8286, 528, 'Lances da Vida S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8287, 528, 'Lances da Vida S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8288, 528, 'Lances da Vida S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8289, 528, 'Lances da Vida S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8290, 528, 'Lances da Vida S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/100421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8291, 528, 'Lances da Vida S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/100422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8292, 528, 'Lances da Vida S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/100423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8293, 528, 'Lances da Vida S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/100424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8294, 529, 'Lances da Vida S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8295, 529, 'Lances da Vida S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8296, 529, 'Lances da Vida S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8297, 529, 'Lances da Vida S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8298, 529, 'Lances da Vida S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8299, 529, 'Lances da Vida S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8300, 529, 'Lances da Vida S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8301, 529, 'Lances da Vida S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8302, 529, 'Lances da Vida S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8303, 529, 'Lances da Vida S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8304, 529, 'Lances da Vida S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8305, 529, 'Lances da Vida S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8306, 529, 'Lances da Vida S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8307, 529, 'Lances da Vida S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8308, 529, 'Lances da Vida S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8309, 529, 'Lances da Vida S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8310, 529, 'Lances da Vida S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8311, 529, 'Lances da Vida S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8312, 529, 'Lances da Vida S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/100443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8313, 529, 'Lances da Vida S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/100444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8314, 529, 'Lances da Vida S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/100445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8315, 529, 'Lances da Vida S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/100446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8316, 530, 'Lances da Vida S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8317, 530, 'Lances da Vida S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8318, 530, 'Lances da Vida S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8319, 530, 'Lances da Vida S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8320, 530, 'Lances da Vida S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8321, 530, 'Lances da Vida S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8322, 530, 'Lances da Vida S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8323, 530, 'Lances da Vida S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8324, 530, 'Lances da Vida S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8325, 530, 'Lances da Vida S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8326, 530, 'Lances da Vida S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8327, 530, 'Lances da Vida S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8328, 530, 'Lances da Vida S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8329, 530, 'Lances da Vida S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8330, 530, 'Lances da Vida S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8331, 530, 'Lances da Vida S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8332, 530, 'Lances da Vida S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8333, 530, 'Lances da Vida S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8334, 530, 'Lances da Vida S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/100465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8335, 530, 'Lances da Vida S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/100466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8336, 530, 'Lances da Vida S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/100467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8337, 530, 'Lances da Vida S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/100468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8338, 531, 'Lances da Vida S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8339, 531, 'Lances da Vida S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8340, 531, 'Lances da Vida S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8341, 531, 'Lances da Vida S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8342, 531, 'Lances da Vida S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8343, 531, 'Lances da Vida S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8344, 531, 'Lances da Vida S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8345, 531, 'Lances da Vida S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8346, 531, 'Lances da Vida S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8347, 531, 'Lances da Vida S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8348, 531, 'Lances da Vida S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8349, 531, 'Lances da Vida S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8350, 531, 'Lances da Vida S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8351, 531, 'Lances da Vida S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8352, 531, 'Lances da Vida S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8353, 531, 'Lances da Vida S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8354, 531, 'Lances da Vida S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8355, 531, 'Lances da Vida S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8356, 531, 'Lances da Vida S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/100487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8357, 531, 'Lances da Vida S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/100488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8358, 531, 'Lances da Vida S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/100489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8359, 532, 'Lances da Vida S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8360, 532, 'Lances da Vida S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8361, 532, 'Lances da Vida S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8362, 532, 'Lances da Vida S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8363, 532, 'Lances da Vida S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8364, 532, 'Lances da Vida S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8365, 532, 'Lances da Vida S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8366, 532, 'Lances da Vida S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8367, 532, 'Lances da Vida S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8368, 532, 'Lances da Vida S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8369, 532, 'Lances da Vida S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8370, 532, 'Lances da Vida S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8371, 532, 'Lances da Vida S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8372, 532, 'Lances da Vida S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8373, 532, 'Lances da Vida S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8374, 532, 'Lances da Vida S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8375, 532, 'Lances da Vida S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8376, 532, 'Lances da Vida S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8377, 533, 'Lances da Vida S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8378, 533, 'Lances da Vida S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8379, 533, 'Lances da Vida S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8380, 533, 'Lances da Vida S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8381, 533, 'Lances da Vida S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8382, 533, 'Lances da Vida S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8383, 533, 'Lances da Vida S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8384, 533, 'Lances da Vida S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8385, 533, 'Lances da Vida S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8386, 533, 'Lances da Vida S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8387, 533, 'Lances da Vida S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8388, 533, 'Lances da Vida S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8389, 533, 'Lances da Vida S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8390, 533, 'Lances da Vida S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8391, 533, 'Lances da Vida S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8392, 533, 'Lances da Vida S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8393, 533, 'Lances da Vida S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8394, 533, 'Lances da Vida S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8395, 533, 'Lances da Vida S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/100526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8396, 533, 'Lances da Vida S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/100527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8397, 533, 'Lances da Vida S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/100528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8398, 533, 'Lances da Vida S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/100529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8399, 533, 'Lances da Vida S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/100530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8400, 533, 'Lances da Vida S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/100531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8401, 534, 'Lances da Vida S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8402, 534, 'Lances da Vida S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8403, 534, 'Lances da Vida S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8404, 534, 'Lances da Vida S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8405, 534, 'Lances da Vida S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8406, 534, 'Lances da Vida S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8407, 534, 'Lances da Vida S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8408, 534, 'Lances da Vida S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8409, 534, 'Lances da Vida S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8410, 534, 'Lances da Vida S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8411, 534, 'Lances da Vida S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8412, 534, 'Lances da Vida S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8413, 534, 'Lances da Vida S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8414, 534, 'Lances da Vida S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8415, 534, 'Lances da Vida S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8416, 534, 'Lances da Vida S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8417, 534, 'Lances da Vida S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8418, 534, 'Lances da Vida S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8419, 534, 'Lances da Vida S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/100550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8420, 534, 'Lances da Vida S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/100551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8421, 534, 'Lances da Vida S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/100552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8422, 534, 'Lances da Vida S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/100553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8423, 535, 'Lances da Vida S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8424, 535, 'Lances da Vida S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8425, 535, 'Lances da Vida S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8426, 535, 'Lances da Vida S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8427, 535, 'Lances da Vida S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8428, 535, 'Lances da Vida S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8429, 535, 'Lances da Vida S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8430, 535, 'Lances da Vida S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8431, 535, 'Lances da Vida S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8432, 535, 'Lances da Vida S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8433, 535, 'Lances da Vida S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(8434, 535, 'Lances da Vida S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8435, 535, 'Lances da Vida S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8436, 535, 'Lances da Vida S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8437, 535, 'Lances da Vida S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8438, 535, 'Lances da Vida S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8439, 535, 'Lances da Vida S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8440, 535, 'Lances da Vida S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8441, 535, 'Lances da Vida S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/100572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8442, 535, 'Lances da Vida S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/100573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8443, 535, 'Lances da Vida S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/100574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8444, 535, 'Lances da Vida S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/100575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8445, 536, 'Lances da Vida S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8446, 536, 'Lances da Vida S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8447, 536, 'Lances da Vida S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8448, 536, 'Lances da Vida S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8449, 536, 'Lances da Vida S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8450, 536, 'Lances da Vida S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8451, 536, 'Lances da Vida S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8452, 536, 'Lances da Vida S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8453, 536, 'Lances da Vida S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8454, 536, 'Lances da Vida S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8455, 536, 'Lances da Vida S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8456, 536, 'Lances da Vida S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f3xlt0dt1B1g3LZdjIQunUjXc6l.jpg'),
(8457, 537, 'O Nevoeiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102087.mp4', 'http://gstaticontent.com/images/iwDmsffJ5qYBxiGTPdwgIKTscKu_big.jpg'),
(8458, 537, 'O Nevoeiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102088.mp4', 'http://gstaticontent.com/images/iwDmsffJ5qYBxiGTPdwgIKTscKu_big.jpg'),
(8459, 537, 'O Nevoeiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102089.mp4', 'http://gstaticontent.com/images/iwDmsffJ5qYBxiGTPdwgIKTscKu_big.jpg'),
(8460, 537, 'O Nevoeiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102090.mp4', 'http://gstaticontent.com/images/iwDmsffJ5qYBxiGTPdwgIKTscKu_big.jpg'),
(8461, 537, 'O Nevoeiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102091.mp4', 'http://gstaticontent.com/images/iwDmsffJ5qYBxiGTPdwgIKTscKu_big.jpg'),
(8462, 537, 'O Nevoeiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102092.mp4', 'http://gstaticontent.com/images/iwDmsffJ5qYBxiGTPdwgIKTscKu_big.jpg'),
(8463, 537, 'O Nevoeiro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102093.mp4', 'http://gstaticontent.com/images/iwDmsffJ5qYBxiGTPdwgIKTscKu_big.jpg'),
(8464, 537, 'O Nevoeiro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102094.mp4', 'http://gstaticontent.com/images/iwDmsffJ5qYBxiGTPdwgIKTscKu_big.jpg'),
(8465, 537, 'O Nevoeiro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102095.mp4', 'http://gstaticontent.com/images/iwDmsffJ5qYBxiGTPdwgIKTscKu_big.jpg'),
(8466, 537, 'O Nevoeiro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102096.mp4', 'http://gstaticontent.com/images/iwDmsffJ5qYBxiGTPdwgIKTscKu_big.jpg'),
(8467, 538, 'O Chefinho: De Volta aos Negócios S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110369.mp4', 'http://gstaticontent.com/images/vbMwQXDGhdFdE4BT6FUhtLyEWSj_big.jpg'),
(8468, 538, 'O Chefinho: De Volta aos Negócios S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110370.mp4', 'http://gstaticontent.com/images/vbMwQXDGhdFdE4BT6FUhtLyEWSj_big.jpg'),
(8469, 538, 'O Chefinho: De Volta aos Negócios S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110371.mp4', 'http://gstaticontent.com/images/vbMwQXDGhdFdE4BT6FUhtLyEWSj_big.jpg'),
(8470, 538, 'O Chefinho: De Volta aos Negócios S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110372.mp4', 'http://gstaticontent.com/images/vbMwQXDGhdFdE4BT6FUhtLyEWSj_big.jpg'),
(8471, 538, 'O Chefinho: De Volta aos Negócios S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110373.mp4', 'http://gstaticontent.com/images/vbMwQXDGhdFdE4BT6FUhtLyEWSj_big.jpg'),
(8472, 538, 'O Chefinho: De Volta aos Negócios S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110374.mp4', 'http://gstaticontent.com/images/vbMwQXDGhdFdE4BT6FUhtLyEWSj_big.jpg'),
(8473, 538, 'O Chefinho: De Volta aos Negócios S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110375.mp4', 'http://gstaticontent.com/images/vbMwQXDGhdFdE4BT6FUhtLyEWSj_big.jpg'),
(8474, 538, 'O Chefinho: De Volta aos Negócios S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110376.mp4', 'http://gstaticontent.com/images/vbMwQXDGhdFdE4BT6FUhtLyEWSj_big.jpg'),
(8475, 538, 'O Chefinho: De Volta aos Negócios S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/110377.mp4', 'http://gstaticontent.com/images/vbMwQXDGhdFdE4BT6FUhtLyEWSj_big.jpg'),
(8476, 538, 'O Chefinho: De Volta aos Negócios S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/110378.mp4', 'http://gstaticontent.com/images/vbMwQXDGhdFdE4BT6FUhtLyEWSj_big.jpg'),
(8477, 538, 'O Chefinho: De Volta aos Negócios S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/110379.mp4', 'http://gstaticontent.com/images/vbMwQXDGhdFdE4BT6FUhtLyEWSj_big.jpg'),
(8478, 538, 'O Chefinho: De Volta aos Negócios S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/110380.mp4', 'http://gstaticontent.com/images/vbMwQXDGhdFdE4BT6FUhtLyEWSj_big.jpg'),
(8479, 538, 'O Chefinho: De Volta aos Negócios S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/110381.mp4', 'http://gstaticontent.com/images/vbMwQXDGhdFdE4BT6FUhtLyEWSj_big.jpg'),
(8480, 539, 'O Chefinho: De Volta aos Negócios S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110382.mp4', 'http://timg.bdta.pro/images/3b5aeffedaf6dabe4680f827fc6d8bdf.jpg'),
(8481, 539, 'O Chefinho: De Volta aos Negócios S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110383.mp4', 'http://timg.bdta.pro/images/a42a582f160cbda8a412dfe1280bee52.jpg'),
(8482, 539, 'O Chefinho: De Volta aos Negócios S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110384.mp4', 'http://timg.bdta.pro/images/c51257b159438c83ea30708db18a7033.jpg'),
(8483, 539, 'O Chefinho: De Volta aos Negócios S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110385.mp4', 'http://timg.bdta.pro/images/d9ea2c42e33addc7f5aa235e7015bfb5.jpg'),
(8484, 539, 'O Chefinho: De Volta aos Negócios S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110386.mp4', 'http://timg.bdta.pro/images/3b10f3bcd44081ba5214e7a8f3d37398.jpg'),
(8485, 539, 'O Chefinho: De Volta aos Negócios S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110387.mp4', 'http://timg.bdta.pro/images/0b5da6766f6dbc7c2a83e03d4f0348f9.jpg'),
(8486, 539, 'O Chefinho: De Volta aos Negócios S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110388.mp4', 'http://timg.bdta.pro/images/ed8b75758bcab65401d8faccca80f2f6.jpg'),
(8487, 539, 'O Chefinho: De Volta aos Negócios S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110389.mp4', 'http://timg.bdta.pro/images/a3ab4925f721fd2c047fb099472ce483.jpg'),
(8488, 539, 'O Chefinho: De Volta aos Negócios S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/110390.mp4', 'http://timg.bdta.pro/images/96b05023d582751ebf9481c24225cd23.jpg'),
(8489, 539, 'O Chefinho: De Volta aos Negócios S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/110391.mp4', 'http://timg.bdta.pro/images/3037a6804a5ae66eb1ef993fe8dd766a.jpg'),
(8490, 539, 'O Chefinho: De Volta aos Negócios S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/110392.mp4', 'http://timg.bdta.pro/images/6e59ee640d37ccbbba32cab69e621ca7.jpg'),
(8491, 539, 'O Chefinho: De Volta aos Negócios S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/110393.mp4', 'http://timg.bdta.pro/images/2087805f6c4f183ac02d19843a89c645.jpg'),
(8492, 539, 'O Chefinho: De Volta aos Negócios S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/110394.mp4', 'http://timg.bdta.pro/images/8e164454f132dcb4a7ec784af4f863be.jpg'),
(8493, 540, 'O Chefinho: De Volta aos Negócios S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110395.mp4', 'http://timg.bdta.pro/images/50a1d1ad92b98ddb86a470f0dd837376.jpg'),
(8494, 540, 'O Chefinho: De Volta aos Negócios S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110396.mp4', 'http://timg.bdta.pro/images/330ab10eace3d4349fbf3864ea607bf8.jpg'),
(8495, 540, 'O Chefinho: De Volta aos Negócios S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110397.mp4', 'http://timg.bdta.pro/images/12a1e371c8235439595c8796c2b945fb.jpg'),
(8496, 540, 'O Chefinho: De Volta aos Negócios S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110398.mp4', 'http://timg.bdta.pro/images/e90444485c29ea4cb92a6d3e29d81647.jpg'),
(8497, 540, 'O Chefinho: De Volta aos Negócios S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110399.mp4', 'http://timg.bdta.pro/images/795843c316b8e2b6756349db5cdcd60e.jpg'),
(8498, 540, 'O Chefinho: De Volta aos Negócios S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110400.mp4', 'http://timg.bdta.pro/images/90e792f82f223f435defd7e79e849b71.jpg'),
(8499, 540, 'O Chefinho: De Volta aos Negócios S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110401.mp4', 'http://timg.bdta.pro/images/ae1f373c35ec8374514fb3391206e238.jpg'),
(8500, 540, 'O Chefinho: De Volta aos Negócios S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110402.mp4', 'http://timg.bdta.pro/images/75acca24039a21148a9daa1c5189f8e2.jpg'),
(8501, 540, 'O Chefinho: De Volta aos Negócios S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/110403.mp4', 'http://timg.bdta.pro/images/f2c8101be30f71f9be74cc5eaa6a7656.jpg'),
(8502, 540, 'O Chefinho: De Volta aos Negócios S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/110404.mp4', 'http://timg.bdta.pro/images/eba253297f628fc3dff0f3144bc19b69.jpg'),
(8503, 540, 'O Chefinho: De Volta aos Negócios S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/110405.mp4', 'http://timg.bdta.pro/images/d53639dbe9d6881fa38fd790d519b032.jpg'),
(8504, 541, 'Orange Is The New Black S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103673.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8505, 541, 'Orange Is The New Black S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103674.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8506, 541, 'Orange Is The New Black S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103675.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8507, 541, 'Orange Is The New Black S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103676.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8508, 541, 'Orange Is The New Black S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103677.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8509, 541, 'Orange Is The New Black S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103678.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8510, 541, 'Orange Is The New Black S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103679.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8511, 541, 'Orange Is The New Black S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103680.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8512, 541, 'Orange Is The New Black S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103681.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8513, 541, 'Orange Is The New Black S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103682.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8514, 541, 'Orange Is The New Black S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103683.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8515, 541, 'Orange Is The New Black S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103684.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8516, 541, 'Orange Is The New Black S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/103685.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8517, 542, 'Orange Is The New Black S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103686.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8518, 542, 'Orange Is The New Black S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103687.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8519, 542, 'Orange Is The New Black S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103688.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8520, 542, 'Orange Is The New Black S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103689.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8521, 542, 'Orange Is The New Black S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103690.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8522, 542, 'Orange Is The New Black S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103691.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8523, 542, 'Orange Is The New Black S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103692.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8524, 542, 'Orange Is The New Black S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103693.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8525, 542, 'Orange Is The New Black S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103694.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8526, 542, 'Orange Is The New Black S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103695.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8527, 542, 'Orange Is The New Black S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103696.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8528, 542, 'Orange Is The New Black S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103697.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8529, 542, 'Orange Is The New Black S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/103698.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8530, 543, 'Orange Is The New Black S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103699.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8531, 543, 'Orange Is The New Black S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103700.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8532, 543, 'Orange Is The New Black S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103701.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8533, 543, 'Orange Is The New Black S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103702.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8534, 543, 'Orange Is The New Black S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103703.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8535, 543, 'Orange Is The New Black S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103704.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8536, 543, 'Orange Is The New Black S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103705.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8537, 543, 'Orange Is The New Black S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103706.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8538, 543, 'Orange Is The New Black S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103707.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8539, 543, 'Orange Is The New Black S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103708.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8540, 543, 'Orange Is The New Black S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103709.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8541, 543, 'Orange Is The New Black S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103710.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8542, 543, 'Orange Is The New Black S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/103711.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8543, 544, 'Orange Is The New Black S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103712.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8544, 544, 'Orange Is The New Black S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103713.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8545, 544, 'Orange Is The New Black S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103714.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8546, 544, 'Orange Is The New Black S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103715.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8547, 544, 'Orange Is The New Black S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103716.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8548, 544, 'Orange Is The New Black S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103717.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8549, 544, 'Orange Is The New Black S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103718.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8550, 544, 'Orange Is The New Black S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103719.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8551, 544, 'Orange Is The New Black S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103720.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8552, 544, 'Orange Is The New Black S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103721.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8553, 544, 'Orange Is The New Black S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103722.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8554, 544, 'Orange Is The New Black S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103723.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8555, 544, 'Orange Is The New Black S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/103724.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8556, 545, 'Orange Is The New Black S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103725.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8557, 545, 'Orange Is The New Black S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103726.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8558, 545, 'Orange Is The New Black S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103727.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8559, 545, 'Orange Is The New Black S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103728.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8560, 545, 'Orange Is The New Black S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103729.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8561, 545, 'Orange Is The New Black S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103730.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8562, 545, 'Orange Is The New Black S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103731.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8563, 545, 'Orange Is The New Black S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103732.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8564, 545, 'Orange Is The New Black S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103733.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8565, 545, 'Orange Is The New Black S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103734.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8566, 545, 'Orange Is The New Black S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103735.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8567, 545, 'Orange Is The New Black S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103736.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8568, 545, 'Orange Is The New Black S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/103737.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8569, 546, 'Orange Is The New Black S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103738.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8570, 546, 'Orange Is The New Black S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103739.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8571, 546, 'Orange Is The New Black S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103740.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8572, 546, 'Orange Is The New Black S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103741.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8573, 546, 'Orange Is The New Black S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103742.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8574, 546, 'Orange Is The New Black S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103743.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8575, 546, 'Orange Is The New Black S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103744.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8576, 546, 'Orange Is The New Black S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103745.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8577, 546, 'Orange Is The New Black S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103746.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8578, 546, 'Orange Is The New Black S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103747.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8579, 546, 'Orange Is The New Black S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103748.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8580, 546, 'Orange Is The New Black S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103749.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8581, 546, 'Orange Is The New Black S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/103750.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8582, 547, 'Orange Is The New Black S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103751.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8583, 547, 'Orange Is The New Black S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103752.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8584, 547, 'Orange Is The New Black S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103753.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8585, 547, 'Orange Is The New Black S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103754.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8586, 547, 'Orange Is The New Black S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103755.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8587, 547, 'Orange Is The New Black S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103756.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8588, 547, 'Orange Is The New Black S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103757.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8589, 547, 'Orange Is The New Black S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103758.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8590, 547, 'Orange Is The New Black S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103759.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8591, 547, 'Orange Is The New Black S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103760.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8592, 547, 'Orange Is The New Black S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103761.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8593, 547, 'Orange Is The New Black S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103762.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8594, 547, 'Orange Is The New Black S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/103763.mp4', 'http://gstaticontent.com/images/enI85hAm51txs8jUY7PWQXR1Xm5_big.jpg'),
(8595, 548, 'Orphan Black S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142814.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8596, 548, 'Orphan Black S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142815.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8597, 548, 'Orphan Black S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142816.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8598, 548, 'Orphan Black S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142817.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8599, 548, 'Orphan Black S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142818.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8600, 548, 'Orphan Black S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142819.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8601, 548, 'Orphan Black S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142820.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8602, 548, 'Orphan Black S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142821.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8603, 548, 'Orphan Black S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142822.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8604, 548, 'Orphan Black S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142823.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8605, 549, 'Orphan Black S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142824.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8606, 549, 'Orphan Black S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142825.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8607, 549, 'Orphan Black S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142826.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8608, 549, 'Orphan Black S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142827.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8609, 549, 'Orphan Black S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142828.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8610, 549, 'Orphan Black S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142829.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8611, 549, 'Orphan Black S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142830.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8612, 549, 'Orphan Black S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142831.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8613, 549, 'Orphan Black S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142832.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8614, 549, 'Orphan Black S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142833.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8615, 550, 'Orphan Black S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142834.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8616, 550, 'Orphan Black S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142835.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8617, 550, 'Orphan Black S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142836.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8618, 550, 'Orphan Black S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142837.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8619, 550, 'Orphan Black S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142838.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8620, 550, 'Orphan Black S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142839.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8621, 550, 'Orphan Black S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142840.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8622, 550, 'Orphan Black S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142841.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8623, 550, 'Orphan Black S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142842.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8624, 550, 'Orphan Black S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142843.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8625, 551, 'Orphan Black S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142844.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8626, 551, 'Orphan Black S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142845.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8627, 551, 'Orphan Black S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142846.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8628, 551, 'Orphan Black S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142847.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8629, 551, 'Orphan Black S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142848.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8630, 551, 'Orphan Black S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142849.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8631, 551, 'Orphan Black S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142850.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8632, 551, 'Orphan Black S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142851.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8633, 551, 'Orphan Black S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142852.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8634, 551, 'Orphan Black S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142853.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8635, 552, 'Orphan Black S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142854.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8636, 552, 'Orphan Black S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142855.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8637, 552, 'Orphan Black S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142856.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8638, 552, 'Orphan Black S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142857.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8639, 552, 'Orphan Black S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142858.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8640, 552, 'Orphan Black S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142859.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8641, 552, 'Orphan Black S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142860.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8642, 552, 'Orphan Black S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142861.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8643, 552, 'Orphan Black S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142862.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8644, 552, 'Orphan Black S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142863.mp4', 'http://gstaticontent.com/images/fWkomTMLdxAQscfvgWJVvNOTKgA_big.jpg'),
(8645, 553, 'Os Inocentes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102107.mp4', 'http://timg.bdta.pro/images/7LcQBEMMF2VB7PgBblwoICKAue4_small.jpg'),
(8646, 553, 'Os Inocentes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102108.mp4', 'http://timg.bdta.pro/images/88eaCDKQE4QrtDHlHVeXelewExY_small.jpg'),
(8647, 553, 'Os Inocentes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102109.mp4', 'http://timg.bdta.pro/images/p9alaXgXkiFPzXdEciNjLJrAiaO_small.jpg'),
(8648, 553, 'Os Inocentes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102110.mp4', 'http://timg.bdta.pro/images/sqD4w0Mn2Ji2wPBmm7E6tow6Cy4_small.jpg'),
(8649, 553, 'Os Inocentes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102111.mp4', 'http://timg.bdta.pro/images/coK2IWbqzCwfAueAzru0fnez0E0_small.jpg'),
(8650, 553, 'Os Inocentes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102112.mp4', 'http://timg.bdta.pro/images/pSCwaEhxnUzViZ5WrQ5PfVINHoA_small.jpg'),
(8651, 553, 'Os Inocentes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102113.mp4', 'http://timg.bdta.pro/images/9ID1wjkfOKuHcX7GE53cqZM6nHJ_small.jpg'),
(8652, 553, 'Os Inocentes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102114.mp4', 'http://timg.bdta.pro/images/muIcTTR3WYGC2eCLshR1eYCHiq3_small.jpg'),
(8653, 554, 'O Socio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146917.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8654, 554, 'O Socio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146918.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8655, 554, 'O Socio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146919.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8656, 554, 'O Socio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146920.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8657, 554, 'O Socio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146921.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8658, 554, 'O Socio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146922.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8659, 555, 'O Socio S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146923.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8660, 555, 'O Socio S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146924.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8661, 555, 'O Socio S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146925.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8662, 555, 'O Socio S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146926.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8663, 555, 'O Socio S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146927.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8664, 555, 'O Socio S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146928.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8665, 555, 'O Socio S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146929.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8666, 555, 'O Socio S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146930.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8667, 555, 'O Socio S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146931.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8668, 555, 'O Socio S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146932.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8669, 555, 'O Socio S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146933.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8670, 555, 'O Socio S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146934.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8671, 555, 'O Socio S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146935.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8672, 555, 'O Socio S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146936.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8673, 555, 'O Socio S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146937.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8674, 555, 'O Socio S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146938.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8675, 555, 'O Socio S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146939.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8676, 555, 'O Socio S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146940.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8677, 556, 'O Socio S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146941.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8678, 556, 'O Socio S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146942.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8679, 556, 'O Socio S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146943.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8680, 556, 'O Socio S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146944.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8681, 556, 'O Socio S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146945.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8682, 556, 'O Socio S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146946.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8683, 556, 'O Socio S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146947.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8684, 556, 'O Socio S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146948.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8685, 556, 'O Socio S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146949.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8686, 556, 'O Socio S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146950.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8687, 556, 'O Socio S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146951.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8688, 556, 'O Socio S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146952.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8689, 556, 'O Socio S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146953.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8690, 556, 'O Socio S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146954.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8691, 556, 'O Socio S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146955.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8692, 556, 'O Socio S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146956.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8693, 556, 'O Socio S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146957.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8694, 556, 'O Socio S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146958.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8695, 556, 'O Socio S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/146959.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8696, 556, 'O Socio S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/146960.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8697, 556, 'O Socio S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/146961.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8698, 556, 'O Socio S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/146962.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8699, 557, 'O Socio S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146963.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8700, 557, 'O Socio S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146964.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8701, 557, 'O Socio S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146965.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8702, 557, 'O Socio S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146966.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8703, 557, 'O Socio S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146967.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8704, 557, 'O Socio S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146968.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8705, 557, 'O Socio S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146969.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8706, 557, 'O Socio S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146970.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8707, 557, 'O Socio S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146971.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8708, 557, 'O Socio S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146972.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8709, 557, 'O Socio S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146973.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8710, 557, 'O Socio S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146974.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8711, 557, 'O Socio S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146975.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8712, 557, 'O Socio S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146976.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8713, 557, 'O Socio S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146977.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8714, 557, 'O Socio S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146978.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(8715, 557, 'O Socio S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146979.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8716, 557, 'O Socio S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146980.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8717, 557, 'O Socio S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/146981.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8718, 558, 'O Socio S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146982.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8719, 558, 'O Socio S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146983.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8720, 558, 'O Socio S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146984.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8721, 558, 'O Socio S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146985.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8722, 558, 'O Socio S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146986.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8723, 558, 'O Socio S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146987.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8724, 558, 'O Socio S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146988.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8725, 558, 'O Socio S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146989.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8726, 558, 'O Socio S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146990.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8727, 558, 'O Socio S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146991.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8728, 558, 'O Socio S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146992.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8729, 558, 'O Socio S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146993.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8730, 558, 'O Socio S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146994.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8731, 558, 'O Socio S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146995.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8732, 558, 'O Socio S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146996.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8733, 558, 'O Socio S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146997.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8734, 558, 'O Socio S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146998.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8735, 558, 'O Socio S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146999.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8736, 559, 'O Socio S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147000.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8737, 559, 'O Socio S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147001.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8738, 559, 'O Socio S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147002.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8739, 559, 'O Socio S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147003.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8740, 559, 'O Socio S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147004.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8741, 559, 'O Socio S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147005.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8742, 559, 'O Socio S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147006.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8743, 559, 'O Socio S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147007.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8744, 559, 'O Socio S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147008.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8745, 559, 'O Socio S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147009.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8746, 559, 'O Socio S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147010.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8747, 560, 'O Socio S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147011.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8748, 560, 'O Socio S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147012.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8749, 560, 'O Socio S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147013.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8750, 560, 'O Socio S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147014.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8751, 560, 'O Socio S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147015.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8752, 560, 'O Socio S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147016.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8753, 560, 'O Socio S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147017.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8754, 560, 'O Socio S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147018.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8755, 560, 'O Socio S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147019.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8756, 560, 'O Socio S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147020.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8757, 560, 'O Socio S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147021.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8758, 560, 'O Socio S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147022.mp4', 'http://gstaticontent.com/images/iAsQ0f9ckFqE8OUax3p8UvpOEU6_big.jpg'),
(8759, 561, 'O Ultimo Guardiao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111007.mp4', 'http://timg.bdta.pro/images/b6aca79b302b6b5155a037073997974d.jpg'),
(8760, 561, 'O Ultimo Guardiao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111008.mp4', 'http://timg.bdta.pro/images/5aeeaa49d1dbd09b80681e3995bd2d26.jpg'),
(8761, 561, 'O Ultimo Guardiao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111009.mp4', 'http://timg.bdta.pro/images/5a4b0039a0fae699811862411b2c443e.jpg'),
(8762, 561, 'O Ultimo Guardiao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111010.mp4', 'http://timg.bdta.pro/images/f8abf2fc66cb376488a96adf90477e1d.jpg'),
(8763, 561, 'O Ultimo Guardiao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111011.mp4', 'http://timg.bdta.pro/images/b6c0fa80e2f8f4a257e2287fe1438c62.jpg'),
(8764, 561, 'O Ultimo Guardiao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/111012.mp4', 'http://timg.bdta.pro/images/ee5e99bdb910a45068532eaeeed64d4a.jpg'),
(8765, 561, 'O Ultimo Guardiao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/111013.mp4', 'http://timg.bdta.pro/images/91b1b05636b18dea900d17f2bcd125c3.jpg'),
(8766, 561, 'O Ultimo Guardiao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/111014.mp4', 'http://timg.bdta.pro/images/d7ca3f29221e3159dc0cea6a6c8cee90.jpg'),
(8767, 561, 'O Ultimo Guardiao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/111015.mp4', 'http://timg.bdta.pro/images/c9602cabc790ca5a5187b770a311e8f9.jpg'),
(8768, 561, 'O Ultimo Guardiao S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/111016.mp4', 'http://timg.bdta.pro/images/e4f654f26712869de4deacd71111c174.jpg'),
(8769, 562, 'O Ultimo Guardiao S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111017.mp4', 'http://timg.bdta.pro/images/a2f226b4c226e61ee4800e2117bd31e9.jpg'),
(8770, 562, 'O Ultimo Guardiao S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111018.mp4', 'http://timg.bdta.pro/images/f6c969166048ca255ac85ab0d168cb56.jpg'),
(8771, 562, 'O Ultimo Guardiao S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111019.mp4', 'http://timg.bdta.pro/images/638a7327b6dad87b33c50b68a6f6ed04.jpg'),
(8772, 562, 'O Ultimo Guardiao S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111020.mp4', 'http://timg.bdta.pro/images/788572d8ef32076ad4e040239ace0c6a.jpg'),
(8773, 562, 'O Ultimo Guardiao S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111021.mp4', 'http://timg.bdta.pro/images/197067b39b145834c158594dd6b56551.jpg'),
(8774, 562, 'O Ultimo Guardiao S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/111022.mp4', 'http://timg.bdta.pro/images/25e2a8aa5892ce268a68ab5db6c66559.jpg'),
(8775, 562, 'O Ultimo Guardiao S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/111023.mp4', 'http://timg.bdta.pro/images/09bb7f968b0898ca3c8328ae258fb80a.jpg'),
(8776, 562, 'O Ultimo Guardiao S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/111024.mp4', 'http://timg.bdta.pro/images/22d6988dbb58612a9742396eb7c991ab.jpg'),
(8777, 563, 'O Ultimo Guardiao S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111025.mp4', 'http://timg.bdta.pro/images/22d6988dbb58612a9742396eb7c991ab.jpg'),
(8778, 563, 'O Ultimo Guardiao S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111026.mp4', 'http://timg.bdta.pro/images/22d6988dbb58612a9742396eb7c991ab.jpg'),
(8779, 563, 'O Ultimo Guardiao S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111027.mp4', 'http://timg.bdta.pro/images/22d6988dbb58612a9742396eb7c991ab.jpg'),
(8780, 563, 'O Ultimo Guardiao S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111028.mp4', 'http://timg.bdta.pro/images/22d6988dbb58612a9742396eb7c991ab.jpg'),
(8781, 563, 'O Ultimo Guardiao S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111029.mp4', 'http://timg.bdta.pro/images/22d6988dbb58612a9742396eb7c991ab.jpg'),
(8782, 563, 'O Ultimo Guardiao S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/111030.mp4', 'http://timg.bdta.pro/images/22d6988dbb58612a9742396eb7c991ab.jpg'),
(8783, 563, 'O Ultimo Guardiao S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/111031.mp4', 'http://timg.bdta.pro/images/22d6988dbb58612a9742396eb7c991ab.jpg'),
(8784, 564, 'Outcast S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102115.mp4', 'http://gstaticontent.com/images/x6ZCpAPDTAHuNxBGq5nU4nqpfYA_big.jpg'),
(8785, 564, 'Outcast S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102116.mp4', 'http://gstaticontent.com/images/x6ZCpAPDTAHuNxBGq5nU4nqpfYA_big.jpg'),
(8786, 564, 'Outcast S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102117.mp4', 'http://gstaticontent.com/images/x6ZCpAPDTAHuNxBGq5nU4nqpfYA_big.jpg'),
(8787, 564, 'Outcast S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102118.mp4', 'http://gstaticontent.com/images/x6ZCpAPDTAHuNxBGq5nU4nqpfYA_big.jpg'),
(8788, 564, 'Outcast S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102119.mp4', 'http://gstaticontent.com/images/x6ZCpAPDTAHuNxBGq5nU4nqpfYA_big.jpg'),
(8789, 564, 'Outcast S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102120.mp4', 'http://gstaticontent.com/images/x6ZCpAPDTAHuNxBGq5nU4nqpfYA_big.jpg'),
(8790, 564, 'Outcast S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102121.mp4', 'http://gstaticontent.com/images/x6ZCpAPDTAHuNxBGq5nU4nqpfYA_big.jpg'),
(8791, 564, 'Outcast S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102122.mp4', 'http://gstaticontent.com/images/x6ZCpAPDTAHuNxBGq5nU4nqpfYA_big.jpg'),
(8792, 564, 'Outcast S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102123.mp4', 'http://gstaticontent.com/images/x6ZCpAPDTAHuNxBGq5nU4nqpfYA_big.jpg'),
(8793, 564, 'Outcast S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102124.mp4', 'http://gstaticontent.com/images/x6ZCpAPDTAHuNxBGq5nU4nqpfYA_big.jpg'),
(8794, 565, 'Outcast S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102125.mp4', 'http://gstaticontent.com/images/x6ZCpAPDTAHuNxBGq5nU4nqpfYA_big.jpg'),
(8795, 565, 'Outcast S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102126.mp4', 'http://gstaticontent.com/images/x6ZCpAPDTAHuNxBGq5nU4nqpfYA_big.jpg'),
(8796, 565, 'Outcast S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102127.mp4', 'http://gstaticontent.com/images/x6ZCpAPDTAHuNxBGq5nU4nqpfYA_big.jpg'),
(8797, 565, 'Outcast S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102128.mp4', 'http://gstaticontent.com/images/x6ZCpAPDTAHuNxBGq5nU4nqpfYA_big.jpg'),
(8798, 565, 'Outcast S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102129.mp4', 'http://gstaticontent.com/images/x6ZCpAPDTAHuNxBGq5nU4nqpfYA_big.jpg'),
(8799, 565, 'Outcast S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102130.mp4', 'http://gstaticontent.com/images/x6ZCpAPDTAHuNxBGq5nU4nqpfYA_big.jpg'),
(8800, 565, 'Outcast S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102131.mp4', 'http://gstaticontent.com/images/x6ZCpAPDTAHuNxBGq5nU4nqpfYA_big.jpg'),
(8801, 565, 'Outcast S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102132.mp4', 'http://gstaticontent.com/images/x6ZCpAPDTAHuNxBGq5nU4nqpfYA_big.jpg'),
(8802, 565, 'Outcast S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102133.mp4', 'http://gstaticontent.com/images/x6ZCpAPDTAHuNxBGq5nU4nqpfYA_big.jpg'),
(8803, 565, 'Outcast S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102134.mp4', 'http://gstaticontent.com/images/x6ZCpAPDTAHuNxBGq5nU4nqpfYA_big.jpg'),
(8804, 566, 'Ozark S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178624.mp4', 'http://gstaticontent.com/images/epUO5w9nRmozR0iWCFwChT3ha6j_big.jpg'),
(8805, 566, 'Ozark S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178625.mp4', 'http://gstaticontent.com/images/epUO5w9nRmozR0iWCFwChT3ha6j_big.jpg'),
(8806, 566, 'Ozark S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178626.mp4', 'http://gstaticontent.com/images/epUO5w9nRmozR0iWCFwChT3ha6j_big.jpg'),
(8807, 566, 'Ozark S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178627.mp4', 'http://gstaticontent.com/images/epUO5w9nRmozR0iWCFwChT3ha6j_big.jpg'),
(8808, 566, 'Ozark S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178628.mp4', 'http://gstaticontent.com/images/epUO5w9nRmozR0iWCFwChT3ha6j_big.jpg'),
(8809, 566, 'Ozark S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178629.mp4', 'http://gstaticontent.com/images/epUO5w9nRmozR0iWCFwChT3ha6j_big.jpg'),
(8810, 566, 'Ozark S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178630.mp4', 'http://gstaticontent.com/images/epUO5w9nRmozR0iWCFwChT3ha6j_big.jpg'),
(8811, 566, 'Ozark S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178631.mp4', 'http://gstaticontent.com/images/epUO5w9nRmozR0iWCFwChT3ha6j_big.jpg'),
(8812, 566, 'Ozark S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178632.mp4', 'http://gstaticontent.com/images/epUO5w9nRmozR0iWCFwChT3ha6j_big.jpg'),
(8813, 566, 'Ozark S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178633.mp4', 'http://gstaticontent.com/images/epUO5w9nRmozR0iWCFwChT3ha6j_big.jpg'),
(8814, 567, 'Ozark S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178634.mp4', 'http://gstaticontent.com/images/epUO5w9nRmozR0iWCFwChT3ha6j_big.jpg'),
(8815, 567, 'Ozark S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178635.mp4', 'http://gstaticontent.com/images/epUO5w9nRmozR0iWCFwChT3ha6j_big.jpg'),
(8816, 567, 'Ozark S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178636.mp4', 'http://gstaticontent.com/images/epUO5w9nRmozR0iWCFwChT3ha6j_big.jpg'),
(8817, 567, 'Ozark S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178637.mp4', 'http://gstaticontent.com/images/epUO5w9nRmozR0iWCFwChT3ha6j_big.jpg'),
(8818, 567, 'Ozark S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178638.mp4', 'http://gstaticontent.com/images/epUO5w9nRmozR0iWCFwChT3ha6j_big.jpg'),
(8819, 567, 'Ozark S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178639.mp4', 'http://gstaticontent.com/images/epUO5w9nRmozR0iWCFwChT3ha6j_big.jpg'),
(8820, 567, 'Ozark S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178640.mp4', 'http://gstaticontent.com/images/epUO5w9nRmozR0iWCFwChT3ha6j_big.jpg'),
(8821, 567, 'Ozark S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178641.mp4', 'http://gstaticontent.com/images/epUO5w9nRmozR0iWCFwChT3ha6j_big.jpg'),
(8822, 567, 'Ozark S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178642.mp4', 'http://gstaticontent.com/images/epUO5w9nRmozR0iWCFwChT3ha6j_big.jpg'),
(8823, 567, 'Ozark S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178643.mp4', 'http://gstaticontent.com/images/epUO5w9nRmozR0iWCFwChT3ha6j_big.jpg'),
(8824, 568, 'Ozark S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178644.mp4', 'http://timg.bdta.pro/images/2d2a9cc44ccc79db14ca3a269d7559ae.jpg'),
(8825, 568, 'Ozark S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178645.mp4', 'http://timg.bdta.pro/images/a1e88d9afd653b289e29b357a35c01fe.jpg'),
(8826, 568, 'Ozark S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178646.mp4', 'http://timg.bdta.pro/images/d147b19ff017afbf5ef80b8626e1612b.jpg'),
(8827, 568, 'Ozark S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178647.mp4', 'http://timg.bdta.pro/images/977c0bbdd166312895f327d8596c169c.jpg'),
(8828, 568, 'Ozark S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178648.mp4', 'http://timg.bdta.pro/images/58a4138441dc9f058b93129208978752.jpg'),
(8829, 568, 'Ozark S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178649.mp4', 'http://timg.bdta.pro/images/27dd7bdead6d4e20c4c93eb7a7285143.jpg'),
(8830, 568, 'Ozark S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178650.mp4', 'http://timg.bdta.pro/images/bbec1ad69aa536c6a1c21e0ab59c1862.jpg'),
(8831, 568, 'Ozark S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178651.mp4', 'http://timg.bdta.pro/images/aeeeac20c9d871ba460817eaa47e03bc.jpg'),
(8832, 568, 'Ozark S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178652.mp4', 'http://timg.bdta.pro/images/4e16081dcd3a6ffec307c77c42d73d80.jpg'),
(8833, 568, 'Ozark S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178653.mp4', 'http://timg.bdta.pro/images/d76ae5e456117520c9904662a93ab814.jpg'),
(8834, 569, 'Ozark S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178654.mp4', 'http://timg.bdta.pro/images/932bfd606f7938d84f7070ef8e7fa5ef.jpg'),
(8835, 569, 'Ozark S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178655.mp4', 'http://timg.bdta.pro/images/ef45e25ce3fa3e37ba79391a699b99fc.jpg'),
(8836, 569, 'Ozark S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178656.mp4', 'http://timg.bdta.pro/images/86c2efd6fc7e065ab84cc4bd678d9bba.jpg'),
(8837, 569, 'Ozark S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178657.mp4', 'http://timg.bdta.pro/images/4076cb53050652dcd67d12e08e252764.jpg'),
(8838, 569, 'Ozark S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178658.mp4', 'http://timg.bdta.pro/images/e8544021dedaf0f56954cabb7d0aa354.jpg'),
(8839, 569, 'Ozark S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178659.mp4', 'http://timg.bdta.pro/images/7082ca6402bcdfa7f23ceb31cb0e634e.jpg'),
(8840, 569, 'Ozark S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178660.mp4', 'http://timg.bdta.pro/images/10e583d3f6195468b4bc76caf311d4c3.jpg'),
(8841, 569, 'Ozark S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178661.mp4', 'http://timg.bdta.pro/images/636b67b45a11cccf1e65a8d28ae81ce3.jpg'),
(8842, 569, 'Ozark S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178662.mp4', 'http://timg.bdta.pro/images/05681633f824d7fac790cd9935a59d58.jpg'),
(8843, 569, 'Ozark S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178663.mp4', 'http://timg.bdta.pro/images/1b896beec554b74732fb3e4ea595ed98.jpg'),
(8844, 569, 'Ozark S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/178664.mp4', 'http://timg.bdta.pro/images/dcbfad04ef98d38019bb9b620b1719b8.jpg'),
(8845, 569, 'Ozark S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/178665.mp4', 'http://timg.bdta.pro/images/44952211793f42d5c83be30ea21385d9.jpg'),
(8846, 569, 'Ozark S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/178666.mp4', 'http://timg.bdta.pro/images/7ac016ec0066749f7a261d66e8dc5b5d.jpg'),
(8847, 569, 'Ozark S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/178667.mp4', 'http://timg.bdta.pro/images/fbbb98cdeaad33595015d23df3a1b463.jpg'),
(8848, 570, 'Penny Dreadful S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100588.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8849, 570, 'Penny Dreadful S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100589.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8850, 570, 'Penny Dreadful S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100590.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8851, 570, 'Penny Dreadful S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100591.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8852, 570, 'Penny Dreadful S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100592.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8853, 570, 'Penny Dreadful S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100593.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8854, 570, 'Penny Dreadful S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100594.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8855, 570, 'Penny Dreadful S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100595.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8856, 571, 'Penny Dreadful S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100596.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8857, 571, 'Penny Dreadful S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100597.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8858, 571, 'Penny Dreadful S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100598.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8859, 571, 'Penny Dreadful S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100599.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8860, 571, 'Penny Dreadful S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100600.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8861, 571, 'Penny Dreadful S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100601.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8862, 571, 'Penny Dreadful S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100602.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8863, 571, 'Penny Dreadful S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100603.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8864, 571, 'Penny Dreadful S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100604.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8865, 571, 'Penny Dreadful S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100605.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8866, 572, 'Penny Dreadful S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100606.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8867, 572, 'Penny Dreadful S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100607.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8868, 572, 'Penny Dreadful S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100608.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8869, 572, 'Penny Dreadful S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100609.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8870, 572, 'Penny Dreadful S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100610.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8871, 572, 'Penny Dreadful S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100611.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8872, 572, 'Penny Dreadful S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100612.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8873, 572, 'Penny Dreadful S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100613.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8874, 572, 'Penny Dreadful S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100614.mp4', 'http://gstaticontent.com/images/uNcmVroHdW835vGD0XdKr25ZNyY_big.jpg'),
(8875, 573, 'Perdidos no Espaco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170638.mp4', 'http://gstaticontent.com/images/90e1fa1ef52b041d60363f90658a7e8c.jpg'),
(8876, 573, 'Perdidos no Espaco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170639.mp4', 'http://gstaticontent.com/images/90e1fa1ef52b041d60363f90658a7e8c.jpg'),
(8877, 573, 'Perdidos no Espaco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170640.mp4', 'http://gstaticontent.com/images/90e1fa1ef52b041d60363f90658a7e8c.jpg'),
(8878, 573, 'Perdidos no Espaco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170641.mp4', 'http://gstaticontent.com/images/90e1fa1ef52b041d60363f90658a7e8c.jpg'),
(8879, 573, 'Perdidos no Espaco S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170642.mp4', 'http://gstaticontent.com/images/90e1fa1ef52b041d60363f90658a7e8c.jpg'),
(8880, 573, 'Perdidos no Espaco S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170643.mp4', 'http://gstaticontent.com/images/90e1fa1ef52b041d60363f90658a7e8c.jpg'),
(8881, 573, 'Perdidos no Espaco S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170644.mp4', 'http://gstaticontent.com/images/90e1fa1ef52b041d60363f90658a7e8c.jpg'),
(8882, 573, 'Perdidos no Espaco S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170645.mp4', 'http://gstaticontent.com/images/90e1fa1ef52b041d60363f90658a7e8c.jpg'),
(8883, 573, 'Perdidos no Espaco S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170646.mp4', 'http://gstaticontent.com/images/90e1fa1ef52b041d60363f90658a7e8c.jpg'),
(8884, 573, 'Perdidos no Espaco S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170647.mp4', 'http://gstaticontent.com/images/90e1fa1ef52b041d60363f90658a7e8c.jpg'),
(8885, 574, 'Perdidos no Espaco S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170648.mp4', 'http://timg.bdta.pro/images/a9673b1f3bd0d5f4ea7b935d432ddf6d.jpg'),
(8886, 574, 'Perdidos no Espaco S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170649.mp4', 'http://timg.bdta.pro/images/7745445167026629ba9507f1c1f757ed.jpg'),
(8887, 574, 'Perdidos no Espaco S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170650.mp4', 'http://timg.bdta.pro/images/f0903dc9382b9f79dcb03e137672a4b9.jpg'),
(8888, 574, 'Perdidos no Espaco S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170651.mp4', 'http://timg.bdta.pro/images/154139daae4f4fbfe0b08de821d9e836.jpg'),
(8889, 574, 'Perdidos no Espaco S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170652.mp4', 'http://timg.bdta.pro/images/b96bb303f657d0590d8a10d59c97f7af.jpg'),
(8890, 574, 'Perdidos no Espaco S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170653.mp4', 'http://timg.bdta.pro/images/ad55e6d2192d226b5265df2148f3ded4.jpg'),
(8891, 574, 'Perdidos no Espaco S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170654.mp4', 'http://timg.bdta.pro/images/8a3c964939bb7059f58a5d49923f8d41.jpg'),
(8892, 574, 'Perdidos no Espaco S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170655.mp4', 'http://timg.bdta.pro/images/321557b8c4e21c87c57fe652860a56a7.jpg'),
(8893, 574, 'Perdidos no Espaco S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170656.mp4', 'http://timg.bdta.pro/images/4869b380729586e1680801087c18412d.jpg'),
(8894, 574, 'Perdidos no Espaco S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170657.mp4', 'http://timg.bdta.pro/images/417a1893c8ee6dda33b191bc149566a0.jpg'),
(8895, 575, 'Perdidos no Espaco S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g4rHVYWtwSS625EICKM1tkk8e.jpg'),
(8896, 575, 'Perdidos no Espaco S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gqnjRyFdIpdVtDBMS3VsqpdF2ZZ.jpg'),
(8897, 575, 'Perdidos no Espaco S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMgSEtAjo6hez0xZ2NNzbsITdFH.jpg'),
(8898, 575, 'Perdidos no Espaco S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m7N7wvXh8y8TaLois2FGNfZR7NN.jpg'),
(8899, 575, 'Perdidos no Espaco S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Ttfu2Lf95iK0i9P2XQ6BaDZXa8.jpg'),
(8900, 575, 'Perdidos no Espaco S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lQxrJrV2Bzf52CwHmzqUryrlD78.jpg'),
(8901, 575, 'Perdidos no Espaco S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gk9ZAwF0sOMhEfmxlzYHJpcBuTM.jpg'),
(8902, 575, 'Perdidos no Espaco S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Kr1KQdWxWIvbhuoKRXv1pKVpSs.jpg'),
(8903, 576, 'Preacher S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107033.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8904, 576, 'Preacher S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107034.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8905, 576, 'Preacher S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107035.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8906, 576, 'Preacher S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107036.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8907, 576, 'Preacher S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107037.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8908, 576, 'Preacher S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107038.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8909, 576, 'Preacher S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107039.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8910, 576, 'Preacher S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107040.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8911, 576, 'Preacher S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107041.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8912, 576, 'Preacher S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107042.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8913, 577, 'Preacher S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107043.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8914, 577, 'Preacher S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107044.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8915, 577, 'Preacher S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107045.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8916, 577, 'Preacher S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107046.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8917, 577, 'Preacher S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107047.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8918, 577, 'Preacher S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107048.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8919, 577, 'Preacher S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107049.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8920, 577, 'Preacher S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107050.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8921, 577, 'Preacher S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107051.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8922, 577, 'Preacher S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107052.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8923, 577, 'Preacher S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107053.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8924, 577, 'Preacher S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107054.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8925, 577, 'Preacher S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107055.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8926, 578, 'Preacher S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107056.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8927, 578, 'Preacher S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107057.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8928, 578, 'Preacher S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107058.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8929, 578, 'Preacher S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107059.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8930, 578, 'Preacher S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107060.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8931, 578, 'Preacher S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107061.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8932, 578, 'Preacher S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107062.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8933, 578, 'Preacher S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107063.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8934, 578, 'Preacher S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107064.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8935, 578, 'Preacher S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107065.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8936, 579, 'Preacher S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107066.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8937, 579, 'Preacher S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107067.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8938, 579, 'Preacher S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107068.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8939, 579, 'Preacher S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107069.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8940, 579, 'Preacher S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107070.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8941, 579, 'Preacher S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107071.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8942, 579, 'Preacher S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107072.mp4', 'http://gstaticontent.com/images/k5gEOkrFecMHCMlJe4eOZpYBHpD_big.jpg'),
(8943, 579, 'Preacher S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107073.mp4', 'http://timg.bdta.pro/images/298f311d52c43712e45e05b7535ae7ff.jpg'),
(8944, 579, 'Preacher S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107074.mp4', 'http://timg.bdta.pro/images/573cd7af2f0aa91d0ef804b14c871096.jpg'),
(8945, 579, 'Preacher S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107075.mp4', 'http://timg.bdta.pro/images/943959a9673fa168787ab5a9526ee261.jpg'),
(8946, 580, 'Pretty Little Liars S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146228.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8947, 580, 'Pretty Little Liars S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146229.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8948, 580, 'Pretty Little Liars S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146230.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8949, 580, 'Pretty Little Liars S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146231.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8950, 580, 'Pretty Little Liars S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146232.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8951, 580, 'Pretty Little Liars S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146233.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8952, 580, 'Pretty Little Liars S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146234.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8953, 580, 'Pretty Little Liars S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146235.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8954, 580, 'Pretty Little Liars S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146236.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8955, 580, 'Pretty Little Liars S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146237.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8956, 580, 'Pretty Little Liars S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146238.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8957, 580, 'Pretty Little Liars S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146239.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8958, 580, 'Pretty Little Liars S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146240.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8959, 580, 'Pretty Little Liars S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146241.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8960, 580, 'Pretty Little Liars S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146242.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8961, 580, 'Pretty Little Liars S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146243.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8962, 580, 'Pretty Little Liars S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146244.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8963, 580, 'Pretty Little Liars S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146245.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8964, 580, 'Pretty Little Liars S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/146246.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8965, 580, 'Pretty Little Liars S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/146247.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8966, 580, 'Pretty Little Liars S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/146248.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8967, 580, 'Pretty Little Liars S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/146249.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8968, 581, 'Pretty Little Liars S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146250.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8969, 581, 'Pretty Little Liars S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146251.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8970, 581, 'Pretty Little Liars S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146252.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8971, 581, 'Pretty Little Liars S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146253.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8972, 581, 'Pretty Little Liars S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146254.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8973, 581, 'Pretty Little Liars S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146255.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8974, 581, 'Pretty Little Liars S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146256.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8975, 581, 'Pretty Little Liars S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146257.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8976, 581, 'Pretty Little Liars S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146258.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8977, 581, 'Pretty Little Liars S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146259.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8978, 581, 'Pretty Little Liars S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146260.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8979, 581, 'Pretty Little Liars S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146261.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8980, 581, 'Pretty Little Liars S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146262.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8981, 581, 'Pretty Little Liars S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146263.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8982, 581, 'Pretty Little Liars S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146264.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8983, 581, 'Pretty Little Liars S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146265.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8984, 581, 'Pretty Little Liars S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146266.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8985, 581, 'Pretty Little Liars S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146267.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8986, 581, 'Pretty Little Liars S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/146268.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8987, 581, 'Pretty Little Liars S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/146269.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8988, 581, 'Pretty Little Liars S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/146270.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8989, 581, 'Pretty Little Liars S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/146271.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8990, 581, 'Pretty Little Liars S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/146272.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8991, 581, 'Pretty Little Liars S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/146273.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8992, 581, 'Pretty Little Liars S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/146274.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8993, 582, 'Pretty Little Liars S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146275.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8994, 582, 'Pretty Little Liars S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146276.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8995, 582, 'Pretty Little Liars S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146277.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8996, 582, 'Pretty Little Liars S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146278.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8997, 582, 'Pretty Little Liars S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146279.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8998, 582, 'Pretty Little Liars S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146280.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(8999, 582, 'Pretty Little Liars S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146281.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9000, 582, 'Pretty Little Liars S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146282.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9001, 582, 'Pretty Little Liars S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146283.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9002, 582, 'Pretty Little Liars S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146284.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9003, 582, 'Pretty Little Liars S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146285.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9004, 582, 'Pretty Little Liars S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146286.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9005, 582, 'Pretty Little Liars S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146287.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9006, 582, 'Pretty Little Liars S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146288.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(9007, 582, 'Pretty Little Liars S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146289.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9008, 582, 'Pretty Little Liars S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146290.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9009, 582, 'Pretty Little Liars S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146291.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9010, 582, 'Pretty Little Liars S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146292.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9011, 582, 'Pretty Little Liars S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/146293.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9012, 582, 'Pretty Little Liars S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/146294.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9013, 582, 'Pretty Little Liars S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/146295.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9014, 582, 'Pretty Little Liars S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/146296.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9015, 582, 'Pretty Little Liars S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/146297.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9016, 582, 'Pretty Little Liars S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/146298.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9017, 583, 'Pretty Little Liars S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146299.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9018, 583, 'Pretty Little Liars S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146300.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9019, 583, 'Pretty Little Liars S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146301.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9020, 583, 'Pretty Little Liars S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146302.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9021, 583, 'Pretty Little Liars S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146303.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9022, 583, 'Pretty Little Liars S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146304.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9023, 583, 'Pretty Little Liars S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146305.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9024, 583, 'Pretty Little Liars S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146306.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9025, 583, 'Pretty Little Liars S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146307.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9026, 583, 'Pretty Little Liars S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146308.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9027, 583, 'Pretty Little Liars S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146309.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9028, 583, 'Pretty Little Liars S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146310.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9029, 583, 'Pretty Little Liars S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146311.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9030, 583, 'Pretty Little Liars S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146312.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9031, 583, 'Pretty Little Liars S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146313.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9032, 583, 'Pretty Little Liars S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146314.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9033, 583, 'Pretty Little Liars S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146315.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9034, 583, 'Pretty Little Liars S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146316.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9035, 583, 'Pretty Little Liars S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/146317.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9036, 583, 'Pretty Little Liars S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/146318.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9037, 583, 'Pretty Little Liars S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/146319.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9038, 583, 'Pretty Little Liars S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/146320.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9039, 583, 'Pretty Little Liars S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/146321.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9040, 583, 'Pretty Little Liars S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/146322.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9041, 583, 'Pretty Little Liars S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/146323.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9042, 584, 'Pretty Little Liars S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146324.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9043, 584, 'Pretty Little Liars S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146325.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9044, 584, 'Pretty Little Liars S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146326.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9045, 584, 'Pretty Little Liars S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146327.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9046, 584, 'Pretty Little Liars S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146328.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9047, 584, 'Pretty Little Liars S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146329.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9048, 584, 'Pretty Little Liars S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146330.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9049, 584, 'Pretty Little Liars S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146331.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9050, 584, 'Pretty Little Liars S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146332.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9051, 584, 'Pretty Little Liars S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146333.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9052, 584, 'Pretty Little Liars S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146334.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9053, 584, 'Pretty Little Liars S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146335.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9054, 584, 'Pretty Little Liars S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146336.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9055, 584, 'Pretty Little Liars S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146337.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9056, 584, 'Pretty Little Liars S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146338.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9057, 584, 'Pretty Little Liars S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146339.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9058, 584, 'Pretty Little Liars S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146340.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9059, 584, 'Pretty Little Liars S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146341.mp4', 'http://timg.bdta.pro/images/qkLpS0cBUvkoIE4Cu9x0CR15Mxg_small.jpg'),
(9060, 584, 'Pretty Little Liars S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/146342.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9061, 584, 'Pretty Little Liars S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/146343.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9062, 584, 'Pretty Little Liars S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/146344.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9063, 584, 'Pretty Little Liars S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/146345.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9064, 584, 'Pretty Little Liars S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/146346.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9065, 584, 'Pretty Little Liars S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/146347.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9066, 584, 'Pretty Little Liars S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/146348.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9067, 585, 'Pretty Little Liars S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146349.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9068, 585, 'Pretty Little Liars S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146350.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9069, 585, 'Pretty Little Liars S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146351.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9070, 585, 'Pretty Little Liars S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146352.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9071, 585, 'Pretty Little Liars S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146353.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9072, 585, 'Pretty Little Liars S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146354.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9073, 585, 'Pretty Little Liars S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146355.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9074, 585, 'Pretty Little Liars S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146356.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9075, 585, 'Pretty Little Liars S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146357.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9076, 585, 'Pretty Little Liars S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146358.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9077, 585, 'Pretty Little Liars S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146359.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9078, 585, 'Pretty Little Liars S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146360.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9079, 585, 'Pretty Little Liars S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146361.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9080, 585, 'Pretty Little Liars S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146362.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9081, 585, 'Pretty Little Liars S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146363.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9082, 585, 'Pretty Little Liars S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146364.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9083, 585, 'Pretty Little Liars S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146365.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9084, 585, 'Pretty Little Liars S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146366.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9085, 585, 'Pretty Little Liars S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/146367.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9086, 585, 'Pretty Little Liars S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/146368.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9087, 586, 'Pretty Little Liars S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146369.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9088, 586, 'Pretty Little Liars S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146370.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9089, 586, 'Pretty Little Liars S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146371.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9090, 586, 'Pretty Little Liars S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146372.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9091, 586, 'Pretty Little Liars S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146373.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9092, 586, 'Pretty Little Liars S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146374.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9093, 586, 'Pretty Little Liars S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146375.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9094, 586, 'Pretty Little Liars S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146376.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9095, 586, 'Pretty Little Liars S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146377.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9096, 586, 'Pretty Little Liars S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146378.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9097, 586, 'Pretty Little Liars S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146379.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9098, 586, 'Pretty Little Liars S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146380.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9099, 586, 'Pretty Little Liars S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146381.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9100, 586, 'Pretty Little Liars S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146382.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9101, 586, 'Pretty Little Liars S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146383.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9102, 586, 'Pretty Little Liars S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146384.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9103, 586, 'Pretty Little Liars S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146385.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9104, 586, 'Pretty Little Liars S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146386.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9105, 586, 'Pretty Little Liars S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/146387.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9106, 586, 'Pretty Little Liars S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/146388.mp4', 'http://gstaticontent.com/images/lntOFDrvVPBAULcrE8NoUlExa11_big.jpg'),
(9107, 587, 'Prison Break S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124402.mp4', 'http://timg.bdta.pro/images/ecd914d8bd768bf62dadfe2d1c1d5a8e.jpg'),
(9108, 587, 'Prison Break S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124403.mp4', 'http://timg.bdta.pro/images/a3a255ca31e75839f8f2de9e90c90bbd.jpg'),
(9109, 587, 'Prison Break S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124404.mp4', 'http://timg.bdta.pro/images/25b796b6f69ab8829e97ce55a83e4a5e.jpg'),
(9110, 587, 'Prison Break S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124405.mp4', 'http://timg.bdta.pro/images/cbad417afe610a566f424344aa3f6b08.jpg'),
(9111, 587, 'Prison Break S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124406.mp4', 'http://timg.bdta.pro/images/dc986cfaa6756571d25ebb62dfa8b8d7.jpg'),
(9112, 587, 'Prison Break S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124407.mp4', 'http://timg.bdta.pro/images/99fd20c4e58516f5dbc8cf5aaa2e6573.jpg'),
(9113, 587, 'Prison Break S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124408.mp4', 'http://timg.bdta.pro/images/86f3b29b0b9e12080399318a742c40d4.jpg'),
(9114, 587, 'Prison Break S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124409.mp4', 'http://timg.bdta.pro/images/274960045ebacede2cb396f2b5e44394.jpg'),
(9115, 587, 'Prison Break S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124410.mp4', 'http://timg.bdta.pro/images/65ffab7abb48d1cae29731fd22d0ef72.jpg'),
(9116, 587, 'Prison Break S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124411.mp4', 'http://timg.bdta.pro/images/99b1ca021497191ea8ef82d107e3c599.jpg'),
(9117, 587, 'Prison Break S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124412.mp4', 'http://timg.bdta.pro/images/a98de7d4ef1e5ec0df27e3b1685fce48.jpg'),
(9118, 587, 'Prison Break S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124413.mp4', 'http://timg.bdta.pro/images/4b554f62f5b200644460bdeb08f07236.jpg'),
(9119, 587, 'Prison Break S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124414.mp4', 'http://timg.bdta.pro/images/1ee8f954878c460d93b2a8444ae0350f.jpg'),
(9120, 587, 'Prison Break S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/124415.mp4', 'http://timg.bdta.pro/images/724230179b5197dc4c4446b0985615c8.jpg'),
(9121, 587, 'Prison Break S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/124416.mp4', 'http://timg.bdta.pro/images/1c267763a8066e4231e6a26f82b0a772.jpg'),
(9122, 587, 'Prison Break S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/124417.mp4', 'http://timg.bdta.pro/images/2e55fb21988ddcfe9f61cd6b50e8ad8c.jpg'),
(9123, 587, 'Prison Break S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/124418.mp4', 'http://timg.bdta.pro/images/373c196911ce406e17498c899caf04d4.jpg'),
(9124, 587, 'Prison Break S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/124419.mp4', 'http://timg.bdta.pro/images/4df69c1c00b8edeab16c17ce86b52ecd.jpg'),
(9125, 587, 'Prison Break S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/124420.mp4', 'http://timg.bdta.pro/images/3cf5e4d1b3c3bbde087fed84e018ba55.jpg'),
(9126, 587, 'Prison Break S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/124421.mp4', 'http://timg.bdta.pro/images/3560dd278f0c4c23daf189d420c447fe.jpg'),
(9127, 587, 'Prison Break S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/124422.mp4', 'http://timg.bdta.pro/images/e2ba542df618d571f7b31822f390872a.jpg'),
(9128, 587, 'Prison Break S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/124423.mp4', 'http://timg.bdta.pro/images/12dc3fea4b3a022e3e946a1d8a286584.jpg'),
(9129, 588, 'Prison Break S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124424.mp4', 'http://timg.bdta.pro/images/1f05958981839709e3f71aa06019347c.jpg'),
(9130, 588, 'Prison Break S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124425.mp4', 'http://timg.bdta.pro/images/5824ceacf48b625638b5fa9ced1aee77.jpg'),
(9131, 588, 'Prison Break S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124426.mp4', 'http://timg.bdta.pro/images/b2899a14982b420442d29675fff48574.jpg'),
(9132, 588, 'Prison Break S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124427.mp4', 'http://timg.bdta.pro/images/3184aa2300ca18dcb6bf361341c8375f.jpg'),
(9133, 588, 'Prison Break S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124428.mp4', 'http://timg.bdta.pro/images/1d11f0e1f9fc0fbb71439783f5ee55f5.jpg'),
(9134, 588, 'Prison Break S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124429.mp4', 'http://timg.bdta.pro/images/7ff1c255645f8e1c737f1352976c525a.jpg'),
(9135, 588, 'Prison Break S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124430.mp4', 'http://timg.bdta.pro/images/7b98d9a54e834e449fcecee87c7827af.jpg'),
(9136, 588, 'Prison Break S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124431.mp4', 'http://timg.bdta.pro/images/4199e9c56dec1bfd9401c85222b25a1c.jpg'),
(9137, 588, 'Prison Break S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124432.mp4', 'http://timg.bdta.pro/images/18ce08433581265ead88102380eaf330.jpg'),
(9138, 588, 'Prison Break S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124433.mp4', 'http://timg.bdta.pro/images/afb2177fd95dd96afb764a97752f06a4.jpg'),
(9139, 588, 'Prison Break S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124434.mp4', 'http://timg.bdta.pro/images/808f12890786136fa7657d5663ceb03c.jpg'),
(9140, 588, 'Prison Break S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124435.mp4', 'http://timg.bdta.pro/images/fd96915298cd03525ab29909365461a3.jpg'),
(9141, 588, 'Prison Break S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124436.mp4', 'http://timg.bdta.pro/images/3a81801352e2f23e7b9726f9f5cd1d7c.jpg'),
(9142, 588, 'Prison Break S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/124437.mp4', 'http://timg.bdta.pro/images/2e3092bf1a4b2549d7ee3bbde0f177ae.jpg'),
(9143, 588, 'Prison Break S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/124438.mp4', 'http://timg.bdta.pro/images/651faa8dac1b42031589f373dec10135.jpg'),
(9144, 588, 'Prison Break S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/124439.mp4', 'http://timg.bdta.pro/images/e9e502db1b792169045c60f59347ba32.jpg'),
(9145, 588, 'Prison Break S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/124440.mp4', 'http://timg.bdta.pro/images/92f3fda3e83b6607f1815a560090795e.jpg'),
(9146, 588, 'Prison Break S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/124441.mp4', 'http://timg.bdta.pro/images/cf109c3ce29c7f8de19c74f95f780d66.jpg'),
(9147, 588, 'Prison Break S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/124442.mp4', 'http://timg.bdta.pro/images/e15973d4316ff72bd5970add9d865cbe.jpg'),
(9148, 588, 'Prison Break S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/124443.mp4', 'http://timg.bdta.pro/images/73153531e4e1f2286dabdbe8237e5c76.jpg'),
(9149, 588, 'Prison Break S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/124444.mp4', 'http://timg.bdta.pro/images/47890d05b1931b8ae19e49942b410c05.jpg'),
(9150, 588, 'Prison Break S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/124445.mp4', 'http://timg.bdta.pro/images/d553c6de780bd8d98d58021bb159c9d1.jpg'),
(9151, 589, 'Prison Break S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124446.mp4', 'http://timg.bdta.pro/images/461d9d72e7b9798245132a848a2cd115.jpg'),
(9152, 589, 'Prison Break S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124447.mp4', 'http://timg.bdta.pro/images/107a9b27a405009851452a8529cf5556.jpg'),
(9153, 589, 'Prison Break S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124448.mp4', 'http://timg.bdta.pro/images/3628f9da7e17c5e35168ad517fe55366.jpg'),
(9154, 589, 'Prison Break S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124449.mp4', 'http://timg.bdta.pro/images/a278560756a8f2b704c772ca186243c1.jpg'),
(9155, 589, 'Prison Break S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124450.mp4', 'http://timg.bdta.pro/images/34f4d1ecee6d0046fbe4e82446158691.jpg'),
(9156, 589, 'Prison Break S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124451.mp4', 'http://timg.bdta.pro/images/0b186274fda6a45736207ca501869db7.jpg'),
(9157, 589, 'Prison Break S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124452.mp4', 'http://timg.bdta.pro/images/856648873e8de256f31e7369e29c8156.jpg'),
(9158, 589, 'Prison Break S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124453.mp4', 'http://timg.bdta.pro/images/400ba1fe81004916efe8bd82ee0b059d.jpg'),
(9159, 589, 'Prison Break S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124454.mp4', 'http://timg.bdta.pro/images/f1cddae7cfa0944ab0d42ea10de689e2.jpg'),
(9160, 589, 'Prison Break S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124455.mp4', 'http://timg.bdta.pro/images/cc6ca78ff62d5037e4905e345d5c1bf5.jpg'),
(9161, 589, 'Prison Break S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124456.mp4', 'http://timg.bdta.pro/images/ea66ccdff8b2d43f54d1104a444e7a41.jpg'),
(9162, 589, 'Prison Break S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124457.mp4', 'http://timg.bdta.pro/images/206df2942e5c14a42be361a294a9cbb9.jpg'),
(9163, 589, 'Prison Break S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124458.mp4', 'http://timg.bdta.pro/images/4dcb6a0d9a87ef470bb15ee083867adf.jpg'),
(9164, 590, 'Prison Break S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124459.mp4', 'http://timg.bdta.pro/images/c8859944888b8d3bf8ea4fae33ec4c57.jpg'),
(9165, 590, 'Prison Break S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124460.mp4', 'http://timg.bdta.pro/images/05e8853f6d5accf873d2885f45b70776.jpg'),
(9166, 590, 'Prison Break S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124461.mp4', 'http://timg.bdta.pro/images/b6c860f78d848983d78ee24779299464.jpg'),
(9167, 590, 'Prison Break S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124462.mp4', 'http://timg.bdta.pro/images/b2af2f403485e9043d631841413a383b.jpg'),
(9168, 590, 'Prison Break S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124463.mp4', 'http://timg.bdta.pro/images/ed53559f833b8c5debd85b1e943aad45.jpg'),
(9169, 590, 'Prison Break S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124464.mp4', 'http://timg.bdta.pro/images/3e4bb80e445af10004473229193cef9e.jpg'),
(9170, 590, 'Prison Break S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124465.mp4', 'http://timg.bdta.pro/images/b1e3140902df2845926931d154420a96.jpg'),
(9171, 590, 'Prison Break S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124466.mp4', 'http://timg.bdta.pro/images/b5d5ee5655c6a0f654d3e458fd4a1fac.jpg'),
(9172, 590, 'Prison Break S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124467.mp4', 'http://timg.bdta.pro/images/d0371df355327491e45b84917ced8ce9.jpg'),
(9173, 590, 'Prison Break S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124468.mp4', 'http://timg.bdta.pro/images/f4a66bdd1e113a81db07bbed8f944775.jpg'),
(9174, 590, 'Prison Break S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124469.mp4', 'http://timg.bdta.pro/images/c23d45a91c6b8d805c54b2bc2fa2db67.jpg'),
(9175, 590, 'Prison Break S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124470.mp4', 'http://timg.bdta.pro/images/b88bd38fc5673f444d45327a19fa3418.jpg'),
(9176, 590, 'Prison Break S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124471.mp4', 'http://timg.bdta.pro/images/b7ea57570c02c3508e1b7b1bd9ac6d45.jpg'),
(9177, 590, 'Prison Break S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/124472.mp4', 'http://timg.bdta.pro/images/a1e070550994184a04389d82d3797549.jpg'),
(9178, 590, 'Prison Break S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/124473.mp4', 'http://timg.bdta.pro/images/6fcb1382acfce51f59a0057c6560f68b.jpg'),
(9179, 590, 'Prison Break S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/124474.mp4', 'http://timg.bdta.pro/images/f23d268523c92f817b6f0947ea0bb0f5.jpg'),
(9180, 590, 'Prison Break S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/124475.mp4', 'http://timg.bdta.pro/images/189e677411d25d515808cde4cf345412.jpg'),
(9181, 590, 'Prison Break S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/124476.mp4', 'http://timg.bdta.pro/images/e96150d9f75a64faf4f4c0bcd66aa187.jpg'),
(9182, 590, 'Prison Break S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/124477.mp4', 'http://timg.bdta.pro/images/23002a46435dbc9f619bfc5efa1e59e3.jpg'),
(9183, 590, 'Prison Break S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/124478.mp4', 'http://timg.bdta.pro/images/5e051e26d4c88476348a4ef443262208.jpg'),
(9184, 590, 'Prison Break S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/124479.mp4', 'http://timg.bdta.pro/images/ad402cdab5a2f98f58fb3349f30b4cdc.jpg'),
(9185, 590, 'Prison Break S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/124480.mp4', 'http://gstaticontent.com/images/pXRZFEY6yixK7kGNtB5c3JOcCWD_big.jpg'),
(9186, 591, 'Prison Break S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124481.mp4', 'http://timg.bdta.pro/images/70cb8603750d27f5e1b87542be916fdf.jpg'),
(9187, 591, 'Prison Break S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124482.mp4', 'http://timg.bdta.pro/images/01b55a9e00a9440736378b238cb6d3e6.jpg'),
(9188, 591, 'Prison Break S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124483.mp4', 'http://timg.bdta.pro/images/2605053e6277ea52858675065a283e1b.jpg'),
(9189, 591, 'Prison Break S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124484.mp4', 'http://timg.bdta.pro/images/f5b6f9d63a3a356f3145a242bd51e185.jpg'),
(9190, 591, 'Prison Break S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124485.mp4', 'http://timg.bdta.pro/images/9e0a8e183a5c0041b1d0a75539f4d789.jpg'),
(9191, 591, 'Prison Break S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124486.mp4', 'http://timg.bdta.pro/images/f55b674dc1a78900c36898f92fbfabdc.jpg'),
(9192, 591, 'Prison Break S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124487.mp4', 'http://timg.bdta.pro/images/96f7382e64ef0d7ce26e6a8a1dc1ec57.jpg'),
(9193, 591, 'Prison Break S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124488.mp4', 'http://timg.bdta.pro/images/7f3e009eb8c87072f70440b3c02deb1c.jpg'),
(9194, 591, 'Prison Break S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124489.mp4', 'http://timg.bdta.pro/images/805abc040a244dcccaaad00b3197d09b.jpg'),
(9195, 592, 'Psi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147157.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9196, 592, 'Psi S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147158.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9197, 592, 'Psi S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147159.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9198, 592, 'Psi S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147160.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9199, 592, 'Psi S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147161.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9200, 592, 'Psi S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147162.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9201, 592, 'Psi S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147163.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9202, 592, 'Psi S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147164.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9203, 592, 'Psi S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147165.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9204, 592, 'Psi S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147166.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9205, 592, 'Psi S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147167.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9206, 592, 'Psi S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147168.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9207, 593, 'Psi S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147169.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9208, 593, 'Psi S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147170.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9209, 593, 'Psi S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147171.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9210, 593, 'Psi S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147172.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9211, 593, 'Psi S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147173.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9212, 593, 'Psi S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147174.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9213, 593, 'Psi S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147175.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9214, 593, 'Psi S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147176.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9215, 593, 'Psi S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147177.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9216, 593, 'Psi S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147178.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9217, 594, 'Psi S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147179.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9218, 594, 'Psi S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147180.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9219, 594, 'Psi S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147181.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9220, 594, 'Psi S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147182.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9221, 594, 'Psi S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147183.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9222, 594, 'Psi S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147184.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9223, 594, 'Psi S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147185.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9224, 594, 'Psi S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147186.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9225, 594, 'Psi S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147187.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9226, 594, 'Psi S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147188.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9227, 595, 'Psi S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147189.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9228, 595, 'Psi S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147190.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9229, 595, 'Psi S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147191.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9230, 595, 'Psi S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147192.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9231, 595, 'Psi S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147193.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9232, 595, 'Psi S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147194.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9233, 595, 'Psi S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147195.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9234, 595, 'Psi S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147196.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9235, 595, 'Psi S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147197.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9236, 595, 'Psi S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147198.mp4', 'http://gstaticontent.com/images/7ZRHxUgtaO8rBKj3BfjXanZesy5_big.jpg'),
(9237, 596, 'Marvel - Punho de Ferro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9238, 596, 'Marvel - Punho de Ferro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9239, 596, 'Marvel - Punho de Ferro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9240, 596, 'Marvel - Punho de Ferro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9241, 596, 'Marvel - Punho de Ferro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9242, 596, 'Marvel - Punho de Ferro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9243, 596, 'Marvel - Punho de Ferro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9244, 596, 'Marvel - Punho de Ferro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9245, 596, 'Marvel - Punho de Ferro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9246, 596, 'Marvel - Punho de Ferro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9247, 596, 'Marvel - Punho de Ferro S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9248, 596, 'Marvel - Punho de Ferro S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9249, 596, 'Marvel - Punho de Ferro S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9250, 597, 'Marvel - Punho de Ferro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9251, 597, 'Marvel - Punho de Ferro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9252, 597, 'Marvel - Punho de Ferro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9253, 597, 'Marvel - Punho de Ferro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9254, 597, 'Marvel - Punho de Ferro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9255, 597, 'Marvel - Punho de Ferro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9256, 597, 'Marvel - Punho de Ferro S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9257, 597, 'Marvel - Punho de Ferro S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9258, 597, 'Marvel - Punho de Ferro S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9259, 597, 'Marvel - Punho de Ferro S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uCpMX3ktMdztlezDBRiMstmapC.jpg'),
(9260, 598, 'Quantico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109421.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9261, 598, 'Quantico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109422.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9262, 598, 'Quantico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109423.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9263, 598, 'Quantico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109424.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9264, 598, 'Quantico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109425.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9265, 598, 'Quantico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109426.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9266, 598, 'Quantico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109427.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9267, 598, 'Quantico S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109428.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9268, 598, 'Quantico S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109429.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9269, 598, 'Quantico S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109430.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9270, 598, 'Quantico S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109431.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9271, 598, 'Quantico S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109432.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9272, 598, 'Quantico S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109433.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9273, 598, 'Quantico S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109434.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9274, 598, 'Quantico S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109435.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9275, 598, 'Quantico S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109436.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9276, 598, 'Quantico S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/109437.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9277, 598, 'Quantico S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/109438.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9278, 598, 'Quantico S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/109439.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9279, 598, 'Quantico S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/109440.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9280, 598, 'Quantico S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/109441.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9281, 598, 'Quantico S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/109442.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9282, 599, 'Quantico S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109443.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9283, 599, 'Quantico S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109444.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9284, 599, 'Quantico S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109445.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9285, 599, 'Quantico S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109446.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9286, 599, 'Quantico S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109447.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9287, 599, 'Quantico S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109448.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9288, 599, 'Quantico S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109449.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9289, 599, 'Quantico S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109450.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9290, 599, 'Quantico S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109451.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9291, 599, 'Quantico S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109452.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9292, 599, 'Quantico S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109453.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9293, 599, 'Quantico S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109454.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9294, 599, 'Quantico S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109455.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9295, 599, 'Quantico S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109456.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(9296, 599, 'Quantico S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109457.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9297, 599, 'Quantico S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109458.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9298, 599, 'Quantico S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/109459.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9299, 599, 'Quantico S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/109460.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9300, 599, 'Quantico S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/109461.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9301, 599, 'Quantico S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/109462.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9302, 599, 'Quantico S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/109463.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9303, 599, 'Quantico S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/109464.mp4', 'http://gstaticontent.com/images/eukbwKZSDY7Nbp97ecR5hTkNJVo_big.jpg'),
(9304, 600, 'Quantico S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109465.mp4', 'http://timg.bdta.pro/images/b09b3e71030b55e6fd1dfe601c96637f.jpg'),
(9305, 600, 'Quantico S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109466.mp4', 'http://timg.bdta.pro/images/dc7c50e1fc0b25fbe82d2371c94c221d.jpg'),
(9306, 600, 'Quantico S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109467.mp4', 'http://timg.bdta.pro/images/66e3a74ec1dc26f399245cb4f4811ea0.jpg'),
(9307, 600, 'Quantico S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109468.mp4', 'http://timg.bdta.pro/images/5b30a99d1fabb2d722503789ee901d78.jpg'),
(9308, 600, 'Quantico S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109469.mp4', 'http://timg.bdta.pro/images/6e26aa06cf633efe8b192b574700a0b2.jpg'),
(9309, 600, 'Quantico S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109470.mp4', 'http://timg.bdta.pro/images/4b8dd43de5b518d1f997c0b4901fe98b.jpg'),
(9310, 600, 'Quantico S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109471.mp4', 'http://timg.bdta.pro/images/235e3c3f27275337d14b3e7294c65e29.jpg'),
(9311, 600, 'Quantico S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109472.mp4', 'http://timg.bdta.pro/images/ff637b2741db296e60a827b4dc98b642.jpg'),
(9312, 600, 'Quantico S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109473.mp4', 'http://timg.bdta.pro/images/9c1198461241e5c72d4c60ddcaba32c8.jpg'),
(9313, 600, 'Quantico S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109474.mp4', 'http://timg.bdta.pro/images/0b0be10b1dcbc0034cee2ae80700ab11.jpg'),
(9314, 600, 'Quantico S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109475.mp4', 'http://timg.bdta.pro/images/4f3fb44b85059f35f008511fdd9ae256.jpg'),
(9315, 600, 'Quantico S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109476.mp4', 'http://timg.bdta.pro/images/9f73ddd9c885d1d0dda8c7603109afdf.jpg'),
(9316, 600, 'Quantico S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109477.mp4', 'http://timg.bdta.pro/images/6262276f213b4eebc0c5b5bfe2dfc441.jpg'),
(9317, 601, 'A Rainha do Sul S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9318, 601, 'A Rainha do Sul S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9319, 601, 'A Rainha do Sul S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9320, 601, 'A Rainha do Sul S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9321, 601, 'A Rainha do Sul S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9322, 601, 'A Rainha do Sul S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9323, 601, 'A Rainha do Sul S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9324, 601, 'A Rainha do Sul S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9325, 601, 'A Rainha do Sul S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9326, 601, 'A Rainha do Sul S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9327, 601, 'A Rainha do Sul S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9328, 601, 'A Rainha do Sul S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9329, 601, 'A Rainha do Sul S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/194760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9330, 602, 'A Rainha do Sul S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9331, 602, 'A Rainha do Sul S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9332, 602, 'A Rainha do Sul S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9333, 602, 'A Rainha do Sul S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9334, 602, 'A Rainha do Sul S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9335, 602, 'A Rainha do Sul S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9336, 602, 'A Rainha do Sul S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9337, 602, 'A Rainha do Sul S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9338, 602, 'A Rainha do Sul S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9339, 602, 'A Rainha do Sul S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9340, 602, 'A Rainha do Sul S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9341, 602, 'A Rainha do Sul S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9342, 602, 'A Rainha do Sul S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/194773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9343, 603, 'A Rainha do Sul S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194774.mp4', 'http://timg.bdta.pro/images/3a0c3aaf6151951ac83648583c534a3f.jpg'),
(9344, 603, 'A Rainha do Sul S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194775.mp4', 'http://timg.bdta.pro/images/b0abbd2586ad740096c279cc23d04783.jpg'),
(9345, 603, 'A Rainha do Sul S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194776.mp4', 'http://timg.bdta.pro/images/ae3095bf79e4039420527f242b355c64.jpg'),
(9346, 603, 'A Rainha do Sul S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194777.mp4', 'http://timg.bdta.pro/images/afe18334bd23e07ac4eeccbac9cb6531.jpg'),
(9347, 603, 'A Rainha do Sul S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9348, 603, 'A Rainha do Sul S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194779.mp4', 'http://timg.bdta.pro/images/d6d1bbbf8f8d277453ac94a053fb824c.jpg'),
(9349, 603, 'A Rainha do Sul S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9350, 603, 'A Rainha do Sul S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194781.mp4', 'http://timg.bdta.pro/images/1b32f15b28c408a2424447da335b4425.jpg'),
(9351, 603, 'A Rainha do Sul S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194782.mp4', 'http://timg.bdta.pro/images/c55bb4375cd5102ca14d03a248f9af80.jpg'),
(9352, 603, 'A Rainha do Sul S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9353, 603, 'A Rainha do Sul S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9354, 603, 'A Rainha do Sul S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9355, 603, 'A Rainha do Sul S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/194786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gHYPaYiBBGYlMBjPCL4SLUkq3Di.jpg'),
(9356, 604, 'A Rainha do Sul S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194787.mp4', 'http://timg.bdta.pro/images/ef06f3485f5f34147a3baecc78302540.jpg'),
(9357, 604, 'A Rainha do Sul S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194788.mp4', 'http://timg.bdta.pro/images/3989d5695ecf3c746b7b90cae968c085.jpg'),
(9358, 604, 'A Rainha do Sul S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194789.mp4', 'http://timg.bdta.pro/images/e6cf34d014608861abc69a49edb1d153.jpg'),
(9359, 604, 'A Rainha do Sul S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194790.mp4', 'http://timg.bdta.pro/images/82fe518cf5f2975a58bb9f93f70e6f5a.jpg'),
(9360, 604, 'A Rainha do Sul S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194791.mp4', 'http://timg.bdta.pro/images/2f39663add90fec1d3d2d2f271f56035.jpg'),
(9361, 604, 'A Rainha do Sul S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194792.mp4', 'http://timg.bdta.pro/images/ac8a08e0f955a5a379837ca644b850bf.jpg'),
(9362, 604, 'A Rainha do Sul S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194793.mp4', 'http://timg.bdta.pro/images/ce2c71ed2a442b2277b2446967843a64.jpg'),
(9363, 604, 'A Rainha do Sul S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194794.mp4', 'http://timg.bdta.pro/images/ab80a9ab48e04ff3d0a5d2e4eb6f1b51.jpg'),
(9364, 604, 'A Rainha do Sul S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194795.mp4', 'http://timg.bdta.pro/images/9c1203243de7cccbd7f8d44b2259f79b.jpg'),
(9365, 604, 'A Rainha do Sul S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194796.mp4', 'http://timg.bdta.pro/images/bc0998f9abc88b3913636e3405e43298.jpg'),
(9366, 604, 'A Rainha do Sul S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194797.mp4', 'http://timg.bdta.pro/images/f6fd2590312223e94b8f753eedd2f020.jpg'),
(9367, 604, 'A Rainha do Sul S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194798.mp4', 'http://timg.bdta.pro/images/55296cd7b6c0d5028080b1d66e9723c8.jpg'),
(9368, 604, 'A Rainha do Sul S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/194799.mp4', 'http://timg.bdta.pro/images/27c9b2a47448113cad576cd8133c8bdb.jpg'),
(9369, 605, 'A Rainha do Sul S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194800.mp4', 'http://timg.bdta.pro/images/f42cd54896fc7ae78ee8f31fd07a6022.jpg'),
(9370, 605, 'A Rainha do Sul S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194801.mp4', 'http://timg.bdta.pro/images/2990926d76c771497f8cebe9942ddca9.jpg'),
(9371, 605, 'A Rainha do Sul S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194802.mp4', 'http://timg.bdta.pro/images/5985641e98ed2b66b187968c6fe91043.jpg'),
(9372, 605, 'A Rainha do Sul S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194803.mp4', 'http://timg.bdta.pro/images/ef569769cdc21de6f1f941e56e5d73ed.jpg'),
(9373, 605, 'A Rainha do Sul S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194804.mp4', 'http://timg.bdta.pro/images/c029a914ca139bd6286c425b694c04f0.jpg'),
(9374, 605, 'A Rainha do Sul S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194805.mp4', 'http://timg.bdta.pro/images/55780e92b918f17fe852b60ff9e7f53c.jpg'),
(9375, 605, 'A Rainha do Sul S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194806.mp4', 'http://timg.bdta.pro/images/522dbd3f41d2f52ce58ce1029e0d5440.jpg'),
(9376, 605, 'A Rainha do Sul S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194807.mp4', 'http://timg.bdta.pro/images/227be5092d8673710cf726b445de4e32.jpg'),
(9377, 605, 'A Rainha do Sul S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194808.mp4', 'http://timg.bdta.pro/images/e200f8f223d42a21306a5900d887c044.jpg'),
(9378, 605, 'A Rainha do Sul S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194809.mp4', 'http://timg.bdta.pro/images/7190ff1e01143d8278e53ab38f652094.jpg'),
(9379, 606, 'Raio Negro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109965.mp4', 'http://gstaticontent.com/images/or0STNIyvwQXFPX811uTMB1nS3J_big.jpg'),
(9380, 606, 'Raio Negro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109966.mp4', 'http://gstaticontent.com/images/or0STNIyvwQXFPX811uTMB1nS3J_big.jpg'),
(9381, 606, 'Raio Negro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109967.mp4', 'http://gstaticontent.com/images/or0STNIyvwQXFPX811uTMB1nS3J_big.jpg'),
(9382, 606, 'Raio Negro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109968.mp4', 'http://gstaticontent.com/images/or0STNIyvwQXFPX811uTMB1nS3J_big.jpg'),
(9383, 606, 'Raio Negro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109969.mp4', 'http://gstaticontent.com/images/or0STNIyvwQXFPX811uTMB1nS3J_big.jpg'),
(9384, 606, 'Raio Negro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109970.mp4', 'http://gstaticontent.com/images/or0STNIyvwQXFPX811uTMB1nS3J_big.jpg'),
(9385, 606, 'Raio Negro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109971.mp4', 'http://gstaticontent.com/images/or0STNIyvwQXFPX811uTMB1nS3J_big.jpg'),
(9386, 606, 'Raio Negro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109972.mp4', 'http://gstaticontent.com/images/or0STNIyvwQXFPX811uTMB1nS3J_big.jpg'),
(9387, 606, 'Raio Negro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109973.mp4', 'http://gstaticontent.com/images/or0STNIyvwQXFPX811uTMB1nS3J_big.jpg'),
(9388, 606, 'Raio Negro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109974.mp4', 'http://gstaticontent.com/images/or0STNIyvwQXFPX811uTMB1nS3J_big.jpg'),
(9389, 606, 'Raio Negro S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109975.mp4', 'http://gstaticontent.com/images/or0STNIyvwQXFPX811uTMB1nS3J_big.jpg'),
(9390, 606, 'Raio Negro S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109976.mp4', 'http://gstaticontent.com/images/or0STNIyvwQXFPX811uTMB1nS3J_big.jpg'),
(9391, 606, 'Raio Negro S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109977.mp4', 'http://gstaticontent.com/images/or0STNIyvwQXFPX811uTMB1nS3J_big.jpg'),
(9392, 607, 'Raio Negro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109978.mp4', 'http://gstaticontent.com/images/or0STNIyvwQXFPX811uTMB1nS3J_big.jpg'),
(9393, 607, 'Raio Negro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109979.mp4', 'http://gstaticontent.com/images/or0STNIyvwQXFPX811uTMB1nS3J_big.jpg'),
(9394, 607, 'Raio Negro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109980.mp4', 'http://gstaticontent.com/images/or0STNIyvwQXFPX811uTMB1nS3J_big.jpg'),
(9395, 607, 'Raio Negro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109981.mp4', 'http://gstaticontent.com/images/or0STNIyvwQXFPX811uTMB1nS3J_big.jpg'),
(9396, 607, 'Raio Negro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109982.mp4', 'http://gstaticontent.com/images/or0STNIyvwQXFPX811uTMB1nS3J_big.jpg'),
(9397, 607, 'Raio Negro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109983.mp4', 'http://timg.bdta.pro/images/89050e04d3dc5ee2739413c7ced24a5b.jpg'),
(9398, 607, 'Raio Negro S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109984.mp4', 'http://timg.bdta.pro/images/449b8eb3a52601d440fdd6faa58b51ad.jpg'),
(9399, 607, 'Raio Negro S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109985.mp4', 'http://timg.bdta.pro/images/0a0001cc04669fa2dc659d86a412ad23.jpg'),
(9400, 607, 'Raio Negro S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109986.mp4', 'http://timg.bdta.pro/images/6ba18d0546271e18d21a92b60540724f.jpg'),
(9401, 607, 'Raio Negro S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109987.mp4', 'http://timg.bdta.pro/images/244e82d9c70048c15602370014550e25.jpg'),
(9402, 607, 'Raio Negro S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109988.mp4', 'http://timg.bdta.pro/images/8bdb44ac9abcea0114b4bae488498dd2.jpg'),
(9403, 607, 'Raio Negro S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109989.mp4', 'http://timg.bdta.pro/images/1cf00f9ff562146a9f14add758d1a78f.jpg'),
(9404, 607, 'Raio Negro S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109990.mp4', 'http://timg.bdta.pro/images/cf47045761467e166fa0a1ee35d29855.jpg'),
(9405, 607, 'Raio Negro S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109991.mp4', 'http://timg.bdta.pro/images/5cbf003204a384c0f60d33fe5eb738bd.jpg'),
(9406, 607, 'Raio Negro S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109992.mp4', 'http://timg.bdta.pro/images/906982bfe0f49a54990e9d8fa2f4c8fd.jpg'),
(9407, 607, 'Raio Negro S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109993.mp4', 'http://timg.bdta.pro/images/6fc992ea3fcc18ad4a7936c8c1a2bfa9.jpg'),
(9408, 608, 'Raio Negro S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109994.mp4', 'http://timg.bdta.pro/images/7411536ab4aa73dfdb6bb953ccd5e0ef.jpg'),
(9409, 608, 'Raio Negro S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109995.mp4', 'http://timg.bdta.pro/images/5d897dfadb5e15cea97a59e512b18000.jpg'),
(9410, 608, 'Raio Negro S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109996.mp4', 'http://timg.bdta.pro/images/4509bdd691f48640f604bf0728b8f556.jpg'),
(9411, 608, 'Raio Negro S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109997.mp4', 'http://timg.bdta.pro/images/0f938e4c497e1a8409064e1274ced67d.jpg'),
(9412, 608, 'Raio Negro S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109998.mp4', 'http://timg.bdta.pro/images/29bbfb5b835832337609c283f1c232ce.jpg'),
(9413, 608, 'Raio Negro S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109999.mp4', 'http://timg.bdta.pro/images/a3bf661acc7f72f7175d06ddaa173801.jpg'),
(9414, 608, 'Raio Negro S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110000.mp4', 'http://timg.bdta.pro/images/9769e9cc5a5a89b7ebb90570370ae1ea.jpg'),
(9415, 608, 'Raio Negro S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110001.mp4', 'http://timg.bdta.pro/images/35e7a9212d9ee677f55d825983737354.jpg'),
(9416, 608, 'Raio Negro S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/110002.mp4', 'http://timg.bdta.pro/images/efad6fdd32910d5b1f5ede6b6db515b7.jpg'),
(9417, 608, 'Raio Negro S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/110003.mp4', 'http://timg.bdta.pro/images/7bad0955a347e548209ecb11e856029e.jpg'),
(9418, 608, 'Raio Negro S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/110004.mp4', 'http://timg.bdta.pro/images/3780f83e08996b5aef27eed5011c60d3.jpg'),
(9419, 608, 'Raio Negro S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/110005.mp4', 'http://timg.bdta.pro/images/aac8e4e8a5a585e7526d59a4ea816089.jpg'),
(9420, 608, 'Raio Negro S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/110006.mp4', 'http://timg.bdta.pro/images/674a139681472809e9a710a4f04749e5.jpg'),
(9421, 608, 'Raio Negro S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/110007.mp4', 'http://timg.bdta.pro/images/45bde42fece404f164e6fbb822e78304.jpg'),
(9422, 608, 'Raio Negro S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/110008.mp4', 'http://timg.bdta.pro/images/741c215963f22d8e9e2116205bf501af.jpg'),
(9423, 608, 'Raio Negro S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/110009.mp4', 'http://timg.bdta.pro/images/fa68bebb73745e8c84b1c16c8a79c35d.jpg'),
(9424, 609, 'Raio Negro S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/339125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hfZct5mRfebQtNSccLv42JTSywK.jpg'),
(9425, 609, 'Raio Negro S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/339126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lbvKfh8QbCcOWWjwofbqKwezRCS.jpg'),
(9426, 609, 'Raio Negro S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/339127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3QFNO8Lbn9toNYnhpPQacd3xZj8.jpg'),
(9427, 609, 'Raio Negro S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/339128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Fu1NlLORmunj3fDvFSOE38hpP.jpg'),
(9428, 609, 'Raio Negro S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/339129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jMz3X8EsuzQWz6q9Kn27shU4CIL.jpg'),
(9429, 609, 'Raio Negro S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/339130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJeQSHBSrjv7uG5RQgVhHXev1gR.jpg'),
(9430, 609, 'Raio Negro S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/339131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybod4jCGlF0UmtsJ7DEOiV3ZtuA.jpg'),
(9431, 609, 'Raio Negro S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/339132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2i8SlcmmRyRwW1n4jL8dYeISTNn.jpg'),
(9432, 609, 'Raio Negro S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/339133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZE4ernkJpXN62Q3KIlNBIcdvov.jpg'),
(9433, 609, 'Raio Negro S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/339134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rv5DM4QafGPxOyGXMgIKjQBUapj.jpg'),
(9434, 609, 'Raio Negro S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/339135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fU7Ypx9HYIvDV9qLOjMW7ogE5dS.jpg'),
(9435, 609, 'Raio Negro S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/339136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/96qT7jWBLIKF5l8adIWUGUnEf0i.jpg'),
(9436, 609, 'Raio Negro S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/339137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uXTe4wwdaZSlCZRe8u7CM2Dl88S.jpg'),
(9437, 610, 'Reign S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143126.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9438, 610, 'Reign S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143127.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9439, 610, 'Reign S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143128.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9440, 610, 'Reign S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143129.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9441, 610, 'Reign S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143130.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9442, 610, 'Reign S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143131.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9443, 610, 'Reign S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143132.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9444, 610, 'Reign S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143133.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9445, 610, 'Reign S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143134.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9446, 610, 'Reign S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143135.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9447, 610, 'Reign S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143136.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9448, 610, 'Reign S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143137.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9449, 610, 'Reign S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143138.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9450, 610, 'Reign S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143139.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9451, 610, 'Reign S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143140.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9452, 610, 'Reign S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143141.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9453, 610, 'Reign S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/143142.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9454, 610, 'Reign S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/143143.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9455, 610, 'Reign S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/143144.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9456, 610, 'Reign S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/143145.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9457, 610, 'Reign S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/143146.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9458, 610, 'Reign S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/143147.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9459, 611, 'Reign S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143148.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9460, 611, 'Reign S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143149.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9461, 611, 'Reign S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143150.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9462, 611, 'Reign S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143151.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9463, 611, 'Reign S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143152.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9464, 611, 'Reign S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143153.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9465, 611, 'Reign S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143154.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9466, 611, 'Reign S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143155.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9467, 611, 'Reign S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143156.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9468, 611, 'Reign S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143157.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9469, 611, 'Reign S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143158.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9470, 611, 'Reign S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143159.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9471, 611, 'Reign S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143160.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9472, 611, 'Reign S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143161.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9473, 611, 'Reign S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143162.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9474, 611, 'Reign S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143163.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9475, 611, 'Reign S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/143164.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9476, 611, 'Reign S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/143165.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9477, 611, 'Reign S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/143166.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9478, 611, 'Reign S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/143167.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9479, 611, 'Reign S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/143168.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9480, 611, 'Reign S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/143169.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9481, 612, 'Reign S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143170.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9482, 612, 'Reign S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143171.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9483, 612, 'Reign S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143172.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9484, 612, 'Reign S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143173.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9485, 612, 'Reign S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143174.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9486, 612, 'Reign S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143175.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9487, 612, 'Reign S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143176.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9488, 612, 'Reign S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143177.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9489, 612, 'Reign S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143178.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9490, 612, 'Reign S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143179.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9491, 612, 'Reign S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143180.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9492, 612, 'Reign S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143181.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9493, 612, 'Reign S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143182.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9494, 612, 'Reign S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143183.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9495, 612, 'Reign S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143184.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9496, 612, 'Reign S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143185.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9497, 612, 'Reign S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/143186.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9498, 612, 'Reign S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/143187.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9499, 613, 'Reign S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143188.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9500, 613, 'Reign S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143189.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9501, 613, 'Reign S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143190.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9502, 613, 'Reign S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143191.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9503, 613, 'Reign S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143192.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9504, 613, 'Reign S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143193.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9505, 613, 'Reign S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143194.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9506, 613, 'Reign S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143195.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9507, 613, 'Reign S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143196.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9508, 613, 'Reign S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143197.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9509, 613, 'Reign S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143198.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9510, 613, 'Reign S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143199.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9511, 613, 'Reign S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143200.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9512, 613, 'Reign S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143201.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9513, 613, 'Reign S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143202.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9514, 613, 'Reign S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143203.mp4', 'http://gstaticontent.com/images/ytnyYZ2dcY7y75jtYu3gCdsUV7_big.jpg'),
(9515, 614, 'Revenge S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102170.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9516, 614, 'Revenge S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102171.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9517, 614, 'Revenge S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102172.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9518, 614, 'Revenge S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102173.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9519, 614, 'Revenge S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102174.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9520, 614, 'Revenge S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102175.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9521, 614, 'Revenge S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102176.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9522, 614, 'Revenge S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102177.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9523, 614, 'Revenge S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102178.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9524, 614, 'Revenge S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102179.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9525, 614, 'Revenge S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102180.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9526, 614, 'Revenge S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102181.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9527, 614, 'Revenge S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102182.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9528, 614, 'Revenge S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/102183.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9529, 614, 'Revenge S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/102184.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9530, 614, 'Revenge S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/102185.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9531, 614, 'Revenge S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/102186.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9532, 614, 'Revenge S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/102187.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9533, 614, 'Revenge S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/102188.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9534, 614, 'Revenge S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/102189.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9535, 614, 'Revenge S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/102190.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9536, 614, 'Revenge S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/102191.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9537, 614, 'Revenge S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/102192.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9538, 615, 'Revenge S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102193.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9539, 615, 'Revenge S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102194.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9540, 615, 'Revenge S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102195.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9541, 615, 'Revenge S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102196.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9542, 615, 'Revenge S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102197.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9543, 615, 'Revenge S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102198.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9544, 615, 'Revenge S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102199.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9545, 615, 'Revenge S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102200.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9546, 615, 'Revenge S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102201.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9547, 615, 'Revenge S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102202.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9548, 615, 'Revenge S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102203.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9549, 615, 'Revenge S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102204.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9550, 615, 'Revenge S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102205.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9551, 615, 'Revenge S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/102206.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9552, 615, 'Revenge S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/102207.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9553, 615, 'Revenge S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/102208.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9554, 615, 'Revenge S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/102209.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9555, 615, 'Revenge S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/102210.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9556, 615, 'Revenge S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/102211.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9557, 615, 'Revenge S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/102212.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9558, 615, 'Revenge S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/102213.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9559, 615, 'Revenge S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/102214.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9560, 616, 'Revenge S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102215.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9561, 616, 'Revenge S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102216.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9562, 616, 'Revenge S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102217.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9563, 616, 'Revenge S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102218.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9564, 616, 'Revenge S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102219.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9565, 616, 'Revenge S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102220.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9566, 616, 'Revenge S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102221.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9567, 616, 'Revenge S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102222.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9568, 616, 'Revenge S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102223.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9569, 616, 'Revenge S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102224.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9570, 616, 'Revenge S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102225.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9571, 616, 'Revenge S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102226.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9572, 616, 'Revenge S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102227.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9573, 616, 'Revenge S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/102228.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9574, 616, 'Revenge S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/102229.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9575, 616, 'Revenge S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/102230.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9576, 616, 'Revenge S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/102231.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9577, 616, 'Revenge S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/102232.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9578, 616, 'Revenge S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/102233.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9579, 616, 'Revenge S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/102234.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9580, 616, 'Revenge S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/102235.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9581, 616, 'Revenge S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/102236.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9582, 617, 'Revenge S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102237.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9583, 617, 'Revenge S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102238.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9584, 617, 'Revenge S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102239.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9585, 617, 'Revenge S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102240.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9586, 617, 'Revenge S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102241.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9587, 617, 'Revenge S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102242.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9588, 617, 'Revenge S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102243.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9589, 617, 'Revenge S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102244.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9590, 617, 'Revenge S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102245.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(9591, 617, 'Revenge S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102246.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9592, 617, 'Revenge S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102247.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9593, 617, 'Revenge S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102248.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9594, 617, 'Revenge S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102249.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9595, 617, 'Revenge S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/102250.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9596, 617, 'Revenge S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/102251.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9597, 617, 'Revenge S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/102252.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9598, 617, 'Revenge S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/102253.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9599, 617, 'Revenge S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/102254.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9600, 617, 'Revenge S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/102255.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9601, 617, 'Revenge S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/102256.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9602, 617, 'Revenge S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/102257.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9603, 617, 'Revenge S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/102258.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9604, 617, 'Revenge S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/102259.mp4', 'http://gstaticontent.com/images/qx7XytRgg1F03NN5BoK8jx3Cyft_big.jpg'),
(9605, 618, 'Riviera S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137314.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9606, 618, 'Riviera S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137315.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9607, 618, 'Riviera S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137316.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9608, 618, 'Riviera S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137317.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9609, 618, 'Riviera S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137318.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9610, 618, 'Riviera S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137319.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9611, 618, 'Riviera S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137320.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9612, 618, 'Riviera S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137321.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9613, 618, 'Riviera S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137322.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9614, 618, 'Riviera S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137323.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9615, 619, 'Riviera S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137324.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9616, 619, 'Riviera S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137325.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9617, 619, 'Riviera S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137326.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9618, 619, 'Riviera S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137327.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9619, 619, 'Riviera S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137328.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9620, 619, 'Riviera S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137329.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9621, 619, 'Riviera S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137330.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9622, 619, 'Riviera S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137331.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9623, 619, 'Riviera S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137332.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9624, 619, 'Riviera S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137333.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9625, 620, 'Riviera S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137334.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9626, 620, 'Riviera S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137335.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9627, 620, 'Riviera S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137336.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9628, 620, 'Riviera S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137337.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9629, 620, 'Riviera S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137338.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9630, 620, 'Riviera S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137339.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9631, 620, 'Riviera S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137340.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9632, 620, 'Riviera S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137341.mp4', 'http://gstaticontent.com/images/bU2takQX91s4XRh3YQEYJKPNsKo_big.jpg'),
(9633, 621, 'Rua Augusta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Akzcwv9fsQzA9y8l2zkNL2GhWqv.jpg'),
(9634, 621, 'Rua Augusta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Akzcwv9fsQzA9y8l2zkNL2GhWqv.jpg'),
(9635, 621, 'Rua Augusta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Akzcwv9fsQzA9y8l2zkNL2GhWqv.jpg'),
(9636, 621, 'Rua Augusta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Akzcwv9fsQzA9y8l2zkNL2GhWqv.jpg'),
(9637, 621, 'Rua Augusta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Akzcwv9fsQzA9y8l2zkNL2GhWqv.jpg'),
(9638, 621, 'Rua Augusta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Akzcwv9fsQzA9y8l2zkNL2GhWqv.jpg'),
(9639, 621, 'Rua Augusta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Akzcwv9fsQzA9y8l2zkNL2GhWqv.jpg'),
(9640, 621, 'Rua Augusta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Akzcwv9fsQzA9y8l2zkNL2GhWqv.jpg'),
(9641, 621, 'Rua Augusta S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Akzcwv9fsQzA9y8l2zkNL2GhWqv.jpg'),
(9642, 621, 'Rua Augusta S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Akzcwv9fsQzA9y8l2zkNL2GhWqv.jpg'),
(9643, 621, 'Rua Augusta S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Akzcwv9fsQzA9y8l2zkNL2GhWqv.jpg'),
(9644, 621, 'Rua Augusta S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Akzcwv9fsQzA9y8l2zkNL2GhWqv.jpg'),
(9645, 622, 'Safe S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102272.mp4', 'http://gstaticontent.com/images/nsElLmgjEFbelkI4bseXSVs4A7L_big.jpg'),
(9646, 622, 'Safe S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102273.mp4', 'http://gstaticontent.com/images/nsElLmgjEFbelkI4bseXSVs4A7L_big.jpg'),
(9647, 622, 'Safe S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102274.mp4', 'http://gstaticontent.com/images/nsElLmgjEFbelkI4bseXSVs4A7L_big.jpg'),
(9648, 622, 'Safe S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102275.mp4', 'http://gstaticontent.com/images/nsElLmgjEFbelkI4bseXSVs4A7L_big.jpg'),
(9649, 622, 'Safe S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102276.mp4', 'http://gstaticontent.com/images/nsElLmgjEFbelkI4bseXSVs4A7L_big.jpg'),
(9650, 622, 'Safe S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102277.mp4', 'http://gstaticontent.com/images/nsElLmgjEFbelkI4bseXSVs4A7L_big.jpg'),
(9651, 622, 'Safe S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102278.mp4', 'http://gstaticontent.com/images/nsElLmgjEFbelkI4bseXSVs4A7L_big.jpg'),
(9652, 622, 'Safe S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102279.mp4', 'http://gstaticontent.com/images/nsElLmgjEFbelkI4bseXSVs4A7L_big.jpg'),
(9653, 623, 'Salvation S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102280.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9654, 623, 'Salvation S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102281.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9655, 623, 'Salvation S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102282.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9656, 623, 'Salvation S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102283.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9657, 623, 'Salvation S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102284.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9658, 623, 'Salvation S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102285.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9659, 623, 'Salvation S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102286.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9660, 623, 'Salvation S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102287.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9661, 623, 'Salvation S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102288.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9662, 623, 'Salvation S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102289.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9663, 623, 'Salvation S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102290.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9664, 623, 'Salvation S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102291.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9665, 624, 'Salvation S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102292.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9666, 624, 'Salvation S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102293.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9667, 624, 'Salvation S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102294.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9668, 624, 'Salvation S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102295.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9669, 624, 'Salvation S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102296.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9670, 624, 'Salvation S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102297.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9671, 624, 'Salvation S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102298.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9672, 624, 'Salvation S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102299.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9673, 624, 'Salvation S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102300.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9674, 624, 'Salvation S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102301.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9675, 624, 'Salvation S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102302.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9676, 624, 'Salvation S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102303.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9677, 624, 'Salvation S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102304.mp4', 'http://gstaticontent.com/images/hXCd9FUT7ZjoB390cGioVhEiXOB_big.jpg'),
(9678, 625, 'Santa Clarita Diet S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102305.mp4', 'http://gstaticontent.com/images/o8tffkHggo6Qa089NfjtNtpLVmv_big.jpg'),
(9679, 625, 'Santa Clarita Diet S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102306.mp4', 'http://gstaticontent.com/images/o8tffkHggo6Qa089NfjtNtpLVmv_big.jpg'),
(9680, 625, 'Santa Clarita Diet S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102307.mp4', 'http://gstaticontent.com/images/o8tffkHggo6Qa089NfjtNtpLVmv_big.jpg'),
(9681, 625, 'Santa Clarita Diet S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102308.mp4', 'http://gstaticontent.com/images/o8tffkHggo6Qa089NfjtNtpLVmv_big.jpg'),
(9682, 625, 'Santa Clarita Diet S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102309.mp4', 'http://gstaticontent.com/images/o8tffkHggo6Qa089NfjtNtpLVmv_big.jpg'),
(9683, 625, 'Santa Clarita Diet S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102310.mp4', 'http://gstaticontent.com/images/o8tffkHggo6Qa089NfjtNtpLVmv_big.jpg'),
(9684, 625, 'Santa Clarita Diet S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102311.mp4', 'http://gstaticontent.com/images/o8tffkHggo6Qa089NfjtNtpLVmv_big.jpg'),
(9685, 625, 'Santa Clarita Diet S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102312.mp4', 'http://gstaticontent.com/images/o8tffkHggo6Qa089NfjtNtpLVmv_big.jpg'),
(9686, 625, 'Santa Clarita Diet S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102313.mp4', 'http://gstaticontent.com/images/o8tffkHggo6Qa089NfjtNtpLVmv_big.jpg'),
(9687, 625, 'Santa Clarita Diet S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102314.mp4', 'http://gstaticontent.com/images/o8tffkHggo6Qa089NfjtNtpLVmv_big.jpg'),
(9688, 626, 'Santa Clarita Diet S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102315.mp4', 'http://gstaticontent.com/images/o8tffkHggo6Qa089NfjtNtpLVmv_big.jpg'),
(9689, 626, 'Santa Clarita Diet S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102316.mp4', 'http://gstaticontent.com/images/o8tffkHggo6Qa089NfjtNtpLVmv_big.jpg'),
(9690, 626, 'Santa Clarita Diet S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102317.mp4', 'http://gstaticontent.com/images/o8tffkHggo6Qa089NfjtNtpLVmv_big.jpg'),
(9691, 626, 'Santa Clarita Diet S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102318.mp4', 'http://gstaticontent.com/images/o8tffkHggo6Qa089NfjtNtpLVmv_big.jpg'),
(9692, 626, 'Santa Clarita Diet S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102319.mp4', 'http://gstaticontent.com/images/o8tffkHggo6Qa089NfjtNtpLVmv_big.jpg'),
(9693, 626, 'Santa Clarita Diet S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102320.mp4', 'http://gstaticontent.com/images/o8tffkHggo6Qa089NfjtNtpLVmv_big.jpg'),
(9694, 626, 'Santa Clarita Diet S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102321.mp4', 'http://gstaticontent.com/images/o8tffkHggo6Qa089NfjtNtpLVmv_big.jpg'),
(9695, 626, 'Santa Clarita Diet S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102322.mp4', 'http://gstaticontent.com/images/o8tffkHggo6Qa089NfjtNtpLVmv_big.jpg'),
(9696, 626, 'Santa Clarita Diet S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102323.mp4', 'http://gstaticontent.com/images/o8tffkHggo6Qa089NfjtNtpLVmv_big.jpg'),
(9697, 626, 'Santa Clarita Diet S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102324.mp4', 'http://gstaticontent.com/images/o8tffkHggo6Qa089NfjtNtpLVmv_big.jpg'),
(9698, 627, 'Scandal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100615.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9699, 627, 'Scandal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100616.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9700, 627, 'Scandal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100617.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9701, 627, 'Scandal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100618.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9702, 627, 'Scandal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100619.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9703, 627, 'Scandal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100620.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9704, 627, 'Scandal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100621.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9705, 628, 'Scandal S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100622.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9706, 628, 'Scandal S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100623.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9707, 628, 'Scandal S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100624.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9708, 628, 'Scandal S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100625.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9709, 628, 'Scandal S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100626.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9710, 628, 'Scandal S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100627.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9711, 628, 'Scandal S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100628.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9712, 628, 'Scandal S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100629.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9713, 628, 'Scandal S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100630.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9714, 628, 'Scandal S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100631.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9715, 628, 'Scandal S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100632.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9716, 628, 'Scandal S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100633.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9717, 628, 'Scandal S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100634.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9718, 628, 'Scandal S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100635.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9719, 628, 'Scandal S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100636.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9720, 628, 'Scandal S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100637.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9721, 628, 'Scandal S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100638.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9722, 628, 'Scandal S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100639.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9723, 628, 'Scandal S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/100640.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9724, 628, 'Scandal S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/100641.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9725, 628, 'Scandal S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/100642.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9726, 628, 'Scandal S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/100643.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9727, 629, 'Scandal S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100644.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9728, 629, 'Scandal S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100645.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9729, 629, 'Scandal S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100646.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9730, 629, 'Scandal S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100647.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9731, 629, 'Scandal S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100648.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9732, 629, 'Scandal S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100649.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9733, 629, 'Scandal S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100650.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9734, 629, 'Scandal S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100651.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9735, 629, 'Scandal S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100652.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9736, 629, 'Scandal S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100653.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9737, 629, 'Scandal S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100654.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9738, 629, 'Scandal S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100655.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9739, 629, 'Scandal S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100656.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9740, 629, 'Scandal S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100657.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9741, 629, 'Scandal S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100658.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9742, 629, 'Scandal S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100659.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9743, 629, 'Scandal S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100660.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9744, 629, 'Scandal S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100661.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9745, 630, 'Scandal S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100662.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9746, 630, 'Scandal S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100663.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9747, 630, 'Scandal S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100664.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9748, 630, 'Scandal S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100665.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9749, 630, 'Scandal S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100666.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9750, 630, 'Scandal S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100667.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9751, 630, 'Scandal S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100668.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9752, 630, 'Scandal S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100669.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9753, 630, 'Scandal S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100670.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9754, 630, 'Scandal S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100671.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9755, 630, 'Scandal S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100672.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9756, 630, 'Scandal S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100673.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9757, 630, 'Scandal S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100674.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9758, 630, 'Scandal S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100675.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9759, 630, 'Scandal S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100676.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9760, 630, 'Scandal S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100677.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9761, 630, 'Scandal S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100678.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9762, 630, 'Scandal S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100679.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9763, 630, 'Scandal S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/100680.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9764, 630, 'Scandal S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/100681.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9765, 630, 'Scandal S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/100682.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9766, 630, 'Scandal S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/100683.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9767, 631, 'Scandal S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100684.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9768, 631, 'Scandal S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100685.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9769, 631, 'Scandal S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100686.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9770, 631, 'Scandal S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100687.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9771, 631, 'Scandal S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100688.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9772, 631, 'Scandal S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100689.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9773, 631, 'Scandal S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100690.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9774, 631, 'Scandal S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100691.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9775, 631, 'Scandal S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100692.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9776, 631, 'Scandal S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100693.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9777, 631, 'Scandal S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100694.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9778, 631, 'Scandal S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100695.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9779, 631, 'Scandal S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100696.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9780, 631, 'Scandal S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100697.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9781, 631, 'Scandal S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100698.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9782, 631, 'Scandal S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100699.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9783, 631, 'Scandal S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100700.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9784, 631, 'Scandal S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100701.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9785, 631, 'Scandal S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/100702.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9786, 631, 'Scandal S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/100703.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9787, 631, 'Scandal S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/100704.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9788, 632, 'Scandal S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100705.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9789, 632, 'Scandal S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100706.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9790, 632, 'Scandal S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100707.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9791, 632, 'Scandal S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100708.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9792, 632, 'Scandal S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100709.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9793, 632, 'Scandal S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100710.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9794, 632, 'Scandal S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100711.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9795, 632, 'Scandal S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100712.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9796, 632, 'Scandal S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100713.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9797, 632, 'Scandal S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100714.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9798, 632, 'Scandal S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100715.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9799, 632, 'Scandal S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100716.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9800, 632, 'Scandal S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100717.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9801, 632, 'Scandal S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100718.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9802, 632, 'Scandal S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100719.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9803, 633, 'Scandal S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100721.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9804, 633, 'Scandal S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100722.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9805, 633, 'Scandal S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100723.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9806, 633, 'Scandal S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100724.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9807, 633, 'Scandal S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100725.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9808, 633, 'Scandal S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100726.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9809, 633, 'Scandal S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100727.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9810, 633, 'Scandal S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100728.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9811, 633, 'Scandal S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100729.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9812, 633, 'Scandal S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100730.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9813, 633, 'Scandal S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100731.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9814, 633, 'Scandal S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100732.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9815, 633, 'Scandal S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100733.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9816, 633, 'Scandal S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100734.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9817, 633, 'Scandal S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100735.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9818, 633, 'Scandal S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100736.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9819, 633, 'Scandal S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100737.mp4', 'http://gstaticontent.com/images/hpCfurq993jPJ24jxuXrPxUugSw_big.jpg'),
(9820, 634, 'Scorpion: Serviço de Inteligência S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9821, 634, 'Scorpion: Serviço de Inteligência S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9822, 634, 'Scorpion: Serviço de Inteligência S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9823, 634, 'Scorpion: Serviço de Inteligência S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9824, 634, 'Scorpion: Serviço de Inteligência S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9825, 634, 'Scorpion: Serviço de Inteligência S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9826, 634, 'Scorpion: Serviço de Inteligência S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9827, 634, 'Scorpion: Serviço de Inteligência S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9828, 634, 'Scorpion: Serviço de Inteligência S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9829, 634, 'Scorpion: Serviço de Inteligência S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9830, 634, 'Scorpion: Serviço de Inteligência S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9831, 634, 'Scorpion: Serviço de Inteligência S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9832, 634, 'Scorpion: Serviço de Inteligência S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9833, 634, 'Scorpion: Serviço de Inteligência S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/102338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9834, 634, 'Scorpion: Serviço de Inteligência S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/102339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9835, 634, 'Scorpion: Serviço de Inteligência S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/102340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9836, 634, 'Scorpion: Serviço de Inteligência S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/102341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9837, 634, 'Scorpion: Serviço de Inteligência S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/102342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9838, 634, 'Scorpion: Serviço de Inteligência S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/102343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9839, 634, 'Scorpion: Serviço de Inteligência S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/102344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9840, 634, 'Scorpion: Serviço de Inteligência S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/102345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9841, 634, 'Scorpion: Serviço de Inteligência S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/102346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9842, 635, 'Scorpion: Serviço de Inteligência S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9843, 635, 'Scorpion: Serviço de Inteligência S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9844, 635, 'Scorpion: Serviço de Inteligência S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9845, 635, 'Scorpion: Serviço de Inteligência S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9846, 635, 'Scorpion: Serviço de Inteligência S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9847, 635, 'Scorpion: Serviço de Inteligência S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9848, 635, 'Scorpion: Serviço de Inteligência S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9849, 635, 'Scorpion: Serviço de Inteligência S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9850, 635, 'Scorpion: Serviço de Inteligência S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9851, 635, 'Scorpion: Serviço de Inteligência S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9852, 635, 'Scorpion: Serviço de Inteligência S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9853, 635, 'Scorpion: Serviço de Inteligência S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9854, 635, 'Scorpion: Serviço de Inteligência S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9855, 635, 'Scorpion: Serviço de Inteligência S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/102360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9856, 635, 'Scorpion: Serviço de Inteligência S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/102361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9857, 635, 'Scorpion: Serviço de Inteligência S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/102362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9858, 635, 'Scorpion: Serviço de Inteligência S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/102363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9859, 635, 'Scorpion: Serviço de Inteligência S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/102364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9860, 635, 'Scorpion: Serviço de Inteligência S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/102365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9861, 635, 'Scorpion: Serviço de Inteligência S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/102366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9862, 635, 'Scorpion: Serviço de Inteligência S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/102367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9863, 635, 'Scorpion: Serviço de Inteligência S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/102368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9864, 636, 'Scorpion: Serviço de Inteligência S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9865, 636, 'Scorpion: Serviço de Inteligência S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9866, 636, 'Scorpion: Serviço de Inteligência S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9867, 636, 'Scorpion: Serviço de Inteligência S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9868, 636, 'Scorpion: Serviço de Inteligência S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9869, 636, 'Scorpion: Serviço de Inteligência S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9870, 636, 'Scorpion: Serviço de Inteligência S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9871, 636, 'Scorpion: Serviço de Inteligência S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9872, 636, 'Scorpion: Serviço de Inteligência S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9873, 636, 'Scorpion: Serviço de Inteligência S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9874, 636, 'Scorpion: Serviço de Inteligência S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(9875, 636, 'Scorpion: Serviço de Inteligência S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9876, 636, 'Scorpion: Serviço de Inteligência S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9877, 636, 'Scorpion: Serviço de Inteligência S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/102382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9878, 636, 'Scorpion: Serviço de Inteligência S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/102383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9879, 636, 'Scorpion: Serviço de Inteligência S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/102384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9880, 636, 'Scorpion: Serviço de Inteligência S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/102385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9881, 636, 'Scorpion: Serviço de Inteligência S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/102386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9882, 636, 'Scorpion: Serviço de Inteligência S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/102387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9883, 636, 'Scorpion: Serviço de Inteligência S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/102388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9884, 636, 'Scorpion: Serviço de Inteligência S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/102389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9885, 636, 'Scorpion: Serviço de Inteligência S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/102390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9886, 636, 'Scorpion: Serviço de Inteligência S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/102391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9887, 636, 'Scorpion: Serviço de Inteligência S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/102392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9888, 637, 'Scorpion: Serviço de Inteligência S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9889, 637, 'Scorpion: Serviço de Inteligência S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9890, 637, 'Scorpion: Serviço de Inteligência S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9891, 637, 'Scorpion: Serviço de Inteligência S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9892, 637, 'Scorpion: Serviço de Inteligência S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9893, 637, 'Scorpion: Serviço de Inteligência S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9894, 637, 'Scorpion: Serviço de Inteligência S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9895, 637, 'Scorpion: Serviço de Inteligência S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9896, 637, 'Scorpion: Serviço de Inteligência S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9897, 637, 'Scorpion: Serviço de Inteligência S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9898, 637, 'Scorpion: Serviço de Inteligência S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9899, 637, 'Scorpion: Serviço de Inteligência S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9900, 637, 'Scorpion: Serviço de Inteligência S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9901, 637, 'Scorpion: Serviço de Inteligência S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/102406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(9902, 638, 'Seal Team S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205342.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9903, 638, 'Seal Team S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205343.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9904, 638, 'Seal Team S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205344.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9905, 638, 'Seal Team S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205345.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9906, 638, 'Seal Team S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205346.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9907, 638, 'Seal Team S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205347.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9908, 638, 'Seal Team S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205348.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9909, 638, 'Seal Team S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205349.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9910, 638, 'Seal Team S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205350.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9911, 638, 'Seal Team S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205351.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9912, 638, 'Seal Team S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205352.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9913, 638, 'Seal Team S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205353.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9914, 638, 'Seal Team S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205354.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9915, 638, 'Seal Team S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/205355.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9916, 638, 'Seal Team S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/205356.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9917, 638, 'Seal Team S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/205357.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9918, 638, 'Seal Team S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/205358.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9919, 638, 'Seal Team S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/205359.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9920, 638, 'Seal Team S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/205360.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9921, 638, 'Seal Team S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/205361.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9922, 638, 'Seal Team S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/205362.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9923, 638, 'Seal Team S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/205363.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9924, 639, 'Seal Team S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205364.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9925, 639, 'Seal Team S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205365.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9926, 639, 'Seal Team S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205366.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9927, 639, 'Seal Team S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205367.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9928, 639, 'Seal Team S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205368.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9929, 639, 'Seal Team S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205369.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9930, 639, 'Seal Team S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205370.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9931, 639, 'Seal Team S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205371.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9932, 639, 'Seal Team S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205372.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9933, 639, 'Seal Team S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205373.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9934, 639, 'Seal Team S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205374.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9935, 639, 'Seal Team S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205375.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9936, 639, 'Seal Team S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205376.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9937, 639, 'Seal Team S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/205377.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9938, 639, 'Seal Team S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/205378.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9939, 639, 'Seal Team S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/205379.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9940, 639, 'Seal Team S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/205380.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9941, 639, 'Seal Team S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/205381.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9942, 639, 'Seal Team S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/205382.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9943, 639, 'Seal Team S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/205383.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9944, 639, 'Seal Team S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/205384.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9945, 639, 'Seal Team S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/205385.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9946, 640, 'Seal Team S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205386.mp4', 'http://timg.bdta.pro/images/6f8935db6ffa202369c137418f1da83d.jpg'),
(9947, 640, 'Seal Team S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205387.mp4', 'http://timg.bdta.pro/images/d6865798f5fb187e05eb2314a26c06d4.jpg'),
(9948, 640, 'Seal Team S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205388.mp4', 'http://timg.bdta.pro/images/d09bfef8f3cf1f103651c46979a6791a.jpg'),
(9949, 640, 'Seal Team S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205389.mp4', 'http://timg.bdta.pro/images/16299f2c43370a7bbb4c5b1e1c42f365.jpg'),
(9950, 640, 'Seal Team S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205390.mp4', 'http://timg.bdta.pro/images/b0bacc73a7a52546ff5437d1af2ee6a4.jpg'),
(9951, 640, 'Seal Team S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205391.mp4', 'http://image.tmdb.org/t/p/w1280/ebNgqSIxkGhrJrADWfA7ifvYOZO.jpg'),
(9952, 640, 'Seal Team S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205392.mp4', 'http://image.tmdb.org/t/p/w1280/cRpVQG5cdbfHaSkBEPG0g0NKVcz.jpg'),
(9953, 640, 'Seal Team S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205393.mp4', 'http://image.tmdb.org/t/p/w1280/49RzDsEBdQ8ebom50ntS8hHKDNY.jpg'),
(9954, 640, 'Seal Team S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205394.mp4', 'http://image.tmdb.org/t/p/w1280/vTb3lMxwLMhuWry3s3rZrkQtzhM.jpg'),
(9955, 640, 'Seal Team S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205395.mp4', 'http://image.tmdb.org/t/p/w1280/x2xduE8ps0uSRO72gNuKbAA3CXf.jpg'),
(9956, 640, 'Seal Team S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205396.mp4', 'http://image.tmdb.org/t/p/w1280/zopMDLdygUcu0a2HgBhwmKKBU66.jpg'),
(9957, 640, 'Seal Team S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205397.mp4', 'http://image.tmdb.org/t/p/w1280/sW4S0bVQPNX6vXqWgcjNgQbSRmf.jpg'),
(9958, 640, 'Seal Team S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205398.mp4', 'http://image.tmdb.org/t/p/w1280/swXLbnD4rnOGEOqatpaV6tl9n26.jpg'),
(9959, 640, 'Seal Team S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/205399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/am87EoBevYOeEkal6mFwKSVEYAQ.jpg'),
(9960, 640, 'Seal Team S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/205400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6G87yUclTDStX3ewxQbI9g7j7LP.jpg'),
(9961, 640, 'Seal Team S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/205401.mp4', 'http://image.tmdb.org/t/p/w1280/aypBSGW1b33zbBgz9vNMurE14Xe.jpg'),
(9962, 640, 'Seal Team S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/205402.mp4', 'http://image.tmdb.org/t/p/w1280/7rI9Noqnzo0BvrkYXZqqueS9xW6.jpg'),
(9963, 640, 'Seal Team S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/205403.mp4', 'http://timg.bdta.pro/images/2c078e2a28b308b2c4b805b58ca2b935.jpg'),
(9964, 640, 'Seal Team S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/205404.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9965, 641, 'Seal Team S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g8raKTaiYxk9440Q1y0HQ3YV8ZY.jpg'),
(9966, 641, 'Seal Team S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3LuFiDXxxAlsCofrnfQQ3dsYG9w.jpg'),
(9967, 641, 'Seal Team S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e9wgFlMls1d8POz46rnazNMY1y1.jpg'),
(9968, 641, 'Seal Team S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7T9ETRkvlOAAM5NemTAi0rqSKQF.jpg'),
(9969, 641, 'Seal Team S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3nvv0hK3rzAMqocrGHqWKSGQRQD.jpg'),
(9970, 641, 'Seal Team S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lWpOckG7uOB9FAkCrzsnVz6v9BC.jpg'),
(9971, 641, 'Seal Team S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ieaAxcQmS0kNLSBPe4dO8qPWsHX.jpg'),
(9972, 641, 'Seal Team S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hqlljqhaJY0MAeltc46jSP91sb3.jpg'),
(9973, 641, 'Seal Team S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vPOCJj9G8u3KZuO379esXZjqfa.jpg'),
(9974, 641, 'Seal Team S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJ1SV4lmJqfFNXjKukFnrMN2293.jpg'),
(9975, 641, 'Seal Team S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4iOayZTaPT0Fe33d5E4e4JBaWJ2.jpg'),
(9976, 641, 'Seal Team S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Agy2DwfWSCGwmmgjTHqGlF2Yg1U.jpg'),
(9977, 641, 'Seal Team S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7AeNRE9Ro7cjklpt9Pi2Vxmrfsh.jpg'),
(9978, 641, 'Seal Team S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/205418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6aje0XBbzJeZEu72Gwqekh0BUkj.jpg'),
(9979, 641, 'Seal Team S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/205419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xHjTGksfRHTh35cWIfKSEIYoCLq.jpg'),
(9980, 641, 'Seal Team S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/205420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i55tbRvjzQ75SIwl7XHUmZpEKVc.jpg'),
(9981, 642, 'Seal Team S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/797450.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9982, 642, 'Seal Team S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/797451.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9983, 642, 'Seal Team S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/797452.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9984, 642, 'Seal Team S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/797453.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9985, 642, 'Seal Team S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/797454.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9986, 642, 'Seal Team S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/797455.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9987, 642, 'Seal Team S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/797456.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9988, 642, 'Seal Team S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/797457.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9989, 642, 'Seal Team S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/797458.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9990, 642, 'Seal Team S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/797459.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9991, 642, 'Seal Team S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/797460.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9992, 642, 'Seal Team S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/797461.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9993, 642, 'Seal Team S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/797462.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9994, 642, 'Seal Team S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/797463.mp4', 'http://gstaticontent.com/images/5yuIJip8YJQ2rkLs7b7JlR38WY7_big.jpg'),
(9995, 643, 'Sense 8 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100036.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(9996, 643, 'Sense 8 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100037.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(9997, 643, 'Sense 8 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100038.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(9998, 643, 'Sense 8 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100039.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(9999, 643, 'Sense 8 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100040.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(10000, 643, 'Sense 8 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100041.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(10001, 643, 'Sense 8 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100042.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(10002, 643, 'Sense 8 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100043.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(10003, 643, 'Sense 8 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100044.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(10004, 643, 'Sense 8 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100045.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(10005, 643, 'Sense 8 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100046.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(10006, 643, 'Sense 8 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100047.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(10007, 644, 'Sense 8 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100048.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(10008, 644, 'Sense 8 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100049.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(10009, 644, 'Sense 8 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100050.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(10010, 644, 'Sense 8 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100051.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(10011, 644, 'Sense 8 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100052.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(10012, 644, 'Sense 8 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100053.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(10013, 644, 'Sense 8 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100054.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(10014, 644, 'Sense 8 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100055.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(10015, 644, 'Sense 8 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100056.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(10016, 644, 'Sense 8 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100057.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(10017, 644, 'Sense 8 S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100058.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(10018, 644, 'Sense 8 S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100059.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(10019, 644, 'Sense 8 S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100060.mp4', 'http://gstaticontent.com/images/kmyvlQ9QKzgdZY31rXaUlgCnzrB_big.jpg'),
(10020, 645, 'Shadowhunters: Instrumentos Mortais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10021, 645, 'Shadowhunters: Instrumentos Mortais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10022, 645, 'Shadowhunters: Instrumentos Mortais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10023, 645, 'Shadowhunters: Instrumentos Mortais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10024, 645, 'Shadowhunters: Instrumentos Mortais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10025, 645, 'Shadowhunters: Instrumentos Mortais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10026, 645, 'Shadowhunters: Instrumentos Mortais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10027, 645, 'Shadowhunters: Instrumentos Mortais S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10028, 645, 'Shadowhunters: Instrumentos Mortais S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10029, 645, 'Shadowhunters: Instrumentos Mortais S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10030, 645, 'Shadowhunters: Instrumentos Mortais S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10031, 645, 'Shadowhunters: Instrumentos Mortais S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10032, 645, 'Shadowhunters: Instrumentos Mortais S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10033, 646, 'Shadowhunters: Instrumentos Mortais S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10034, 646, 'Shadowhunters: Instrumentos Mortais S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10035, 646, 'Shadowhunters: Instrumentos Mortais S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10036, 646, 'Shadowhunters: Instrumentos Mortais S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10037, 646, 'Shadowhunters: Instrumentos Mortais S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10038, 646, 'Shadowhunters: Instrumentos Mortais S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10039, 646, 'Shadowhunters: Instrumentos Mortais S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10040, 646, 'Shadowhunters: Instrumentos Mortais S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10041, 646, 'Shadowhunters: Instrumentos Mortais S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10042, 646, 'Shadowhunters: Instrumentos Mortais S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10043, 646, 'Shadowhunters: Instrumentos Mortais S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10044, 646, 'Shadowhunters: Instrumentos Mortais S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10045, 646, 'Shadowhunters: Instrumentos Mortais S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10046, 646, 'Shadowhunters: Instrumentos Mortais S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/204974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10047, 646, 'Shadowhunters: Instrumentos Mortais S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/204975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10048, 646, 'Shadowhunters: Instrumentos Mortais S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/204976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10049, 646, 'Shadowhunters: Instrumentos Mortais S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/204977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10050, 646, 'Shadowhunters: Instrumentos Mortais S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/204978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10051, 646, 'Shadowhunters: Instrumentos Mortais S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/204979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10052, 646, 'Shadowhunters: Instrumentos Mortais S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/204980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10053, 647, 'Shadowhunters: Instrumentos Mortais S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10054, 647, 'Shadowhunters: Instrumentos Mortais S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10055, 647, 'Shadowhunters: Instrumentos Mortais S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10056, 647, 'Shadowhunters: Instrumentos Mortais S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10057, 647, 'Shadowhunters: Instrumentos Mortais S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10058, 647, 'Shadowhunters: Instrumentos Mortais S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10059, 647, 'Shadowhunters: Instrumentos Mortais S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10060, 647, 'Shadowhunters: Instrumentos Mortais S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10061, 647, 'Shadowhunters: Instrumentos Mortais S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10062, 647, 'Shadowhunters: Instrumentos Mortais S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10063, 647, 'Shadowhunters: Instrumentos Mortais S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10064, 647, 'Shadowhunters: Instrumentos Mortais S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10065, 647, 'Shadowhunters: Instrumentos Mortais S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10066, 647, 'Shadowhunters: Instrumentos Mortais S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/204994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10067, 647, 'Shadowhunters: Instrumentos Mortais S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/204995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10068, 647, 'Shadowhunters: Instrumentos Mortais S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/204996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10069, 647, 'Shadowhunters: Instrumentos Mortais S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/204997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10070, 647, 'Shadowhunters: Instrumentos Mortais S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/204998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10071, 647, 'Shadowhunters: Instrumentos Mortais S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/204999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10072, 647, 'Shadowhunters: Instrumentos Mortais S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/205000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10073, 647, 'Shadowhunters: Instrumentos Mortais S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/205001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10074, 647, 'Shadowhunters: Instrumentos Mortais S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/205002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66YHvvVduC21xcMXPpBBF0ywyVZ.jpg'),
(10075, 648, 'Objetos Cortantes (2018) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Yipm8X7jp2BJ84jlYL07IsvUHj.jpg'),
(10076, 648, 'Objetos Cortantes (2018) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Yipm8X7jp2BJ84jlYL07IsvUHj.jpg'),
(10077, 648, 'Objetos Cortantes (2018) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Yipm8X7jp2BJ84jlYL07IsvUHj.jpg'),
(10078, 648, 'Objetos Cortantes (2018) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Yipm8X7jp2BJ84jlYL07IsvUHj.jpg'),
(10079, 648, 'Objetos Cortantes (2018) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Yipm8X7jp2BJ84jlYL07IsvUHj.jpg'),
(10080, 648, 'Objetos Cortantes (2018) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Yipm8X7jp2BJ84jlYL07IsvUHj.jpg'),
(10081, 649, 'Siren S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131544.mp4', 'http://gstaticontent.com/images/tIesNvDR3T49BotIxLBqaSIdOu8_big.jpg'),
(10082, 649, 'Siren S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131545.mp4', 'http://gstaticontent.com/images/tIesNvDR3T49BotIxLBqaSIdOu8_big.jpg'),
(10083, 649, 'Siren S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131546.mp4', 'http://gstaticontent.com/images/tIesNvDR3T49BotIxLBqaSIdOu8_big.jpg'),
(10084, 649, 'Siren S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131547.mp4', 'http://gstaticontent.com/images/tIesNvDR3T49BotIxLBqaSIdOu8_big.jpg'),
(10085, 649, 'Siren S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131548.mp4', 'http://gstaticontent.com/images/tIesNvDR3T49BotIxLBqaSIdOu8_big.jpg'),
(10086, 649, 'Siren S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131549.mp4', 'http://gstaticontent.com/images/tIesNvDR3T49BotIxLBqaSIdOu8_big.jpg'),
(10087, 649, 'Siren S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131550.mp4', 'http://gstaticontent.com/images/tIesNvDR3T49BotIxLBqaSIdOu8_big.jpg'),
(10088, 649, 'Siren S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131551.mp4', 'http://gstaticontent.com/images/tIesNvDR3T49BotIxLBqaSIdOu8_big.jpg'),
(10089, 649, 'Siren S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131552.mp4', 'http://gstaticontent.com/images/tIesNvDR3T49BotIxLBqaSIdOu8_big.jpg'),
(10090, 649, 'Siren S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131553.mp4', 'http://gstaticontent.com/images/tIesNvDR3T49BotIxLBqaSIdOu8_big.jpg'),
(10091, 650, 'Siren S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131554.mp4', 'http://gstaticontent.com/images/tIesNvDR3T49BotIxLBqaSIdOu8_big.jpg'),
(10092, 650, 'Siren S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131555.mp4', 'http://gstaticontent.com/images/tIesNvDR3T49BotIxLBqaSIdOu8_big.jpg'),
(10093, 650, 'Siren S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131556.mp4', 'http://gstaticontent.com/images/tIesNvDR3T49BotIxLBqaSIdOu8_big.jpg'),
(10094, 650, 'Siren S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131557.mp4', 'http://gstaticontent.com/images/tIesNvDR3T49BotIxLBqaSIdOu8_big.jpg'),
(10095, 650, 'Siren S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131558.mp4', 'http://gstaticontent.com/images/tIesNvDR3T49BotIxLBqaSIdOu8_big.jpg'),
(10096, 650, 'Siren S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131559.mp4', 'http://gstaticontent.com/images/tIesNvDR3T49BotIxLBqaSIdOu8_big.jpg'),
(10097, 650, 'Siren S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131560.mp4', 'http://gstaticontent.com/images/tIesNvDR3T49BotIxLBqaSIdOu8_big.jpg'),
(10098, 650, 'Siren S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131561.mp4', 'http://gstaticontent.com/images/tIesNvDR3T49BotIxLBqaSIdOu8_big.jpg'),
(10099, 650, 'Siren S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131562.mp4', 'http://gstaticontent.com/images/tIesNvDR3T49BotIxLBqaSIdOu8_big.jpg'),
(10100, 650, 'Siren S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131563.mp4', 'http://gstaticontent.com/images/tIesNvDR3T49BotIxLBqaSIdOu8_big.jpg'),
(10101, 650, 'Siren S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/413824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBCxRFxbfOs37sUHSRbNzfCGCGk.jpg'),
(10102, 650, 'Siren S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/413825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fHNsYbrNWdkkLmG24bCH4ThVtn0.jpg'),
(10103, 650, 'Siren S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/413826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2oo1jZBPnHEmRr7XoiayKXD663A.jpg'),
(10104, 650, 'Siren S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/413827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfTMmZqCCEIeyqZzpjcTqfNFJ2v.jpg'),
(10105, 650, 'Siren S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/413828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGFYhCBu24yGMMLKBpDVKtClvBh.jpg'),
(10106, 650, 'Siren S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/413829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dCDg2z6oh71H3yQc4xLGx6CPedv.jpg'),
(10107, 651, 'Siren S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131564.mp4', 'http://timg.bdta.pro/images/b41e564bdf7750290b9d57974b13ff88.jpg'),
(10108, 651, 'Siren S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131565.mp4', 'http://timg.bdta.pro/images/52a8bdc61b71082870a2d03c1712e223.jpg'),
(10109, 651, 'Siren S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131566.mp4', 'http://timg.bdta.pro/images/c3a2e11d34a283d485a97d6ccffd9397.jpg'),
(10110, 651, 'Siren S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131567.mp4', 'http://timg.bdta.pro/images/83b48884f6e4a8287df6a57bd462857d.jpg'),
(10111, 651, 'Siren S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131568.mp4', 'http://timg.bdta.pro/images/19e558eeafa8b480456da6702375afe8.jpg'),
(10112, 651, 'Siren S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131569.mp4', 'http://timg.bdta.pro/images/22bd704d53c0d0d43bd3c5ae7bfbf911.jpg'),
(10113, 651, 'Siren S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131570.mp4', 'http://timg.bdta.pro/images/38f84eebe04d2e48f6113f218c95c574.jpg'),
(10114, 651, 'Siren S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131571.mp4', 'http://timg.bdta.pro/images/6100600b4564cd2a502eb965ced77fe1.jpg'),
(10115, 651, 'Siren S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ioCodxZUVKPTX7SxCJiUga2BDix.jpg'),
(10116, 651, 'Siren S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVS8nyUImvrLc67h5P33phCyW6J.jpg'),
(10117, 652, 'Six S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102413.mp4', 'http://gstaticontent.com/images/doqvfJojBwtprn3qPxb4ndO3lom_big.jpg'),
(10118, 652, 'Six S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102414.mp4', 'http://gstaticontent.com/images/doqvfJojBwtprn3qPxb4ndO3lom_big.jpg'),
(10119, 652, 'Six S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102415.mp4', 'http://gstaticontent.com/images/doqvfJojBwtprn3qPxb4ndO3lom_big.jpg'),
(10120, 652, 'Six S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102416.mp4', 'http://gstaticontent.com/images/doqvfJojBwtprn3qPxb4ndO3lom_big.jpg'),
(10121, 652, 'Six S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102417.mp4', 'http://gstaticontent.com/images/doqvfJojBwtprn3qPxb4ndO3lom_big.jpg'),
(10122, 652, 'Six S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102418.mp4', 'http://gstaticontent.com/images/doqvfJojBwtprn3qPxb4ndO3lom_big.jpg'),
(10123, 652, 'Six S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102419.mp4', 'http://gstaticontent.com/images/doqvfJojBwtprn3qPxb4ndO3lom_big.jpg'),
(10124, 652, 'Six S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102420.mp4', 'http://gstaticontent.com/images/doqvfJojBwtprn3qPxb4ndO3lom_big.jpg'),
(10125, 653, 'Six S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102421.mp4', 'http://gstaticontent.com/images/doqvfJojBwtprn3qPxb4ndO3lom_big.jpg'),
(10126, 653, 'Six S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102422.mp4', 'http://gstaticontent.com/images/doqvfJojBwtprn3qPxb4ndO3lom_big.jpg'),
(10127, 653, 'Six S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102423.mp4', 'http://gstaticontent.com/images/doqvfJojBwtprn3qPxb4ndO3lom_big.jpg'),
(10128, 653, 'Six S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102424.mp4', 'http://gstaticontent.com/images/doqvfJojBwtprn3qPxb4ndO3lom_big.jpg'),
(10129, 653, 'Six S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102425.mp4', 'http://gstaticontent.com/images/doqvfJojBwtprn3qPxb4ndO3lom_big.jpg'),
(10130, 653, 'Six S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102426.mp4', 'http://gstaticontent.com/images/doqvfJojBwtprn3qPxb4ndO3lom_big.jpg'),
(10131, 653, 'Six S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102427.mp4', 'http://gstaticontent.com/images/doqvfJojBwtprn3qPxb4ndO3lom_big.jpg'),
(10132, 653, 'Six S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102428.mp4', 'http://gstaticontent.com/images/doqvfJojBwtprn3qPxb4ndO3lom_big.jpg'),
(10133, 653, 'Six S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102429.mp4', 'http://gstaticontent.com/images/doqvfJojBwtprn3qPxb4ndO3lom_big.jpg'),
(10134, 653, 'Six S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102430.mp4', 'http://gstaticontent.com/images/doqvfJojBwtprn3qPxb4ndO3lom_big.jpg'),
(10135, 654, 'Slasher S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105227.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10136, 654, 'Slasher S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105228.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10137, 654, 'Slasher S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105229.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10138, 654, 'Slasher S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105230.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10139, 654, 'Slasher S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105231.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10140, 654, 'Slasher S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105232.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10141, 654, 'Slasher S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105233.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10142, 654, 'Slasher S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105234.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10143, 655, 'Slasher S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105235.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10144, 655, 'Slasher S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105236.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10145, 655, 'Slasher S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105237.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10146, 655, 'Slasher S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105238.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10147, 655, 'Slasher S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105239.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10148, 655, 'Slasher S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105240.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10149, 655, 'Slasher S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105241.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10150, 655, 'Slasher S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105242.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10151, 656, 'Slasher S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105243.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(10152, 656, 'Slasher S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105244.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10153, 656, 'Slasher S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105245.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10154, 656, 'Slasher S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105246.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10155, 656, 'Slasher S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105247.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10156, 656, 'Slasher S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105248.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10157, 656, 'Slasher S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105249.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10158, 656, 'Slasher S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105250.mp4', 'http://gstaticontent.com/images/ySFDBMgVwAGZ8dw2Z9ols4Qulyt_big.jpg'),
(10159, 657, 'Smallville: As Aventuras do Superboy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10160, 657, 'Smallville: As Aventuras do Superboy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10161, 657, 'Smallville: As Aventuras do Superboy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10162, 657, 'Smallville: As Aventuras do Superboy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10163, 657, 'Smallville: As Aventuras do Superboy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10164, 657, 'Smallville: As Aventuras do Superboy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10165, 657, 'Smallville: As Aventuras do Superboy S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10166, 657, 'Smallville: As Aventuras do Superboy S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10167, 657, 'Smallville: As Aventuras do Superboy S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10168, 657, 'Smallville: As Aventuras do Superboy S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10169, 657, 'Smallville: As Aventuras do Superboy S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10170, 657, 'Smallville: As Aventuras do Superboy S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10171, 657, 'Smallville: As Aventuras do Superboy S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10172, 657, 'Smallville: As Aventuras do Superboy S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10173, 657, 'Smallville: As Aventuras do Superboy S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10174, 657, 'Smallville: As Aventuras do Superboy S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10175, 657, 'Smallville: As Aventuras do Superboy S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10176, 657, 'Smallville: As Aventuras do Superboy S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10177, 657, 'Smallville: As Aventuras do Superboy S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/100205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10178, 657, 'Smallville: As Aventuras do Superboy S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/100206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10179, 657, 'Smallville: As Aventuras do Superboy S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/100207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10180, 658, 'Smallville: As Aventuras do Superboy S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10181, 658, 'Smallville: As Aventuras do Superboy S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10182, 658, 'Smallville: As Aventuras do Superboy S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10183, 658, 'Smallville: As Aventuras do Superboy S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10184, 658, 'Smallville: As Aventuras do Superboy S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10185, 658, 'Smallville: As Aventuras do Superboy S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10186, 658, 'Smallville: As Aventuras do Superboy S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10187, 658, 'Smallville: As Aventuras do Superboy S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10188, 658, 'Smallville: As Aventuras do Superboy S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10189, 658, 'Smallville: As Aventuras do Superboy S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10190, 658, 'Smallville: As Aventuras do Superboy S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10191, 658, 'Smallville: As Aventuras do Superboy S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10192, 658, 'Smallville: As Aventuras do Superboy S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10193, 658, 'Smallville: As Aventuras do Superboy S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10194, 658, 'Smallville: As Aventuras do Superboy S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10195, 658, 'Smallville: As Aventuras do Superboy S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10196, 658, 'Smallville: As Aventuras do Superboy S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10197, 658, 'Smallville: As Aventuras do Superboy S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10198, 658, 'Smallville: As Aventuras do Superboy S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/100226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10199, 658, 'Smallville: As Aventuras do Superboy S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/100227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10200, 658, 'Smallville: As Aventuras do Superboy S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/100228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10201, 658, 'Smallville: As Aventuras do Superboy S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/100229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10202, 658, 'Smallville: As Aventuras do Superboy S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/100230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10203, 659, 'Smallville: As Aventuras do Superboy S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10204, 659, 'Smallville: As Aventuras do Superboy S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10205, 659, 'Smallville: As Aventuras do Superboy S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10206, 659, 'Smallville: As Aventuras do Superboy S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10207, 659, 'Smallville: As Aventuras do Superboy S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10208, 659, 'Smallville: As Aventuras do Superboy S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10209, 659, 'Smallville: As Aventuras do Superboy S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10210, 659, 'Smallville: As Aventuras do Superboy S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10211, 659, 'Smallville: As Aventuras do Superboy S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10212, 659, 'Smallville: As Aventuras do Superboy S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10213, 659, 'Smallville: As Aventuras do Superboy S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10214, 659, 'Smallville: As Aventuras do Superboy S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10215, 659, 'Smallville: As Aventuras do Superboy S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10216, 659, 'Smallville: As Aventuras do Superboy S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10217, 659, 'Smallville: As Aventuras do Superboy S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10218, 659, 'Smallville: As Aventuras do Superboy S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10219, 659, 'Smallville: As Aventuras do Superboy S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10220, 659, 'Smallville: As Aventuras do Superboy S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10221, 659, 'Smallville: As Aventuras do Superboy S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/100249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10222, 659, 'Smallville: As Aventuras do Superboy S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/100250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10223, 659, 'Smallville: As Aventuras do Superboy S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/100251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10224, 659, 'Smallville: As Aventuras do Superboy S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/100252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10225, 660, 'Smallville: As Aventuras do Superboy S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10226, 660, 'Smallville: As Aventuras do Superboy S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10227, 660, 'Smallville: As Aventuras do Superboy S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10228, 660, 'Smallville: As Aventuras do Superboy S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10229, 660, 'Smallville: As Aventuras do Superboy S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10230, 660, 'Smallville: As Aventuras do Superboy S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10231, 660, 'Smallville: As Aventuras do Superboy S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10232, 660, 'Smallville: As Aventuras do Superboy S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10233, 660, 'Smallville: As Aventuras do Superboy S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10234, 660, 'Smallville: As Aventuras do Superboy S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10235, 660, 'Smallville: As Aventuras do Superboy S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10236, 660, 'Smallville: As Aventuras do Superboy S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10237, 660, 'Smallville: As Aventuras do Superboy S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10238, 660, 'Smallville: As Aventuras do Superboy S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10239, 660, 'Smallville: As Aventuras do Superboy S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10240, 660, 'Smallville: As Aventuras do Superboy S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10241, 660, 'Smallville: As Aventuras do Superboy S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10242, 660, 'Smallville: As Aventuras do Superboy S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10243, 660, 'Smallville: As Aventuras do Superboy S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/100271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10244, 660, 'Smallville: As Aventuras do Superboy S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/100272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10245, 660, 'Smallville: As Aventuras do Superboy S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/100273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10246, 660, 'Smallville: As Aventuras do Superboy S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/100274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10247, 661, 'Smallville: As Aventuras do Superboy S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10248, 661, 'Smallville: As Aventuras do Superboy S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10249, 661, 'Smallville: As Aventuras do Superboy S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10250, 661, 'Smallville: As Aventuras do Superboy S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10251, 661, 'Smallville: As Aventuras do Superboy S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10252, 661, 'Smallville: As Aventuras do Superboy S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10253, 661, 'Smallville: As Aventuras do Superboy S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10254, 661, 'Smallville: As Aventuras do Superboy S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10255, 661, 'Smallville: As Aventuras do Superboy S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10256, 661, 'Smallville: As Aventuras do Superboy S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10257, 661, 'Smallville: As Aventuras do Superboy S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10258, 661, 'Smallville: As Aventuras do Superboy S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10259, 661, 'Smallville: As Aventuras do Superboy S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10260, 661, 'Smallville: As Aventuras do Superboy S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10261, 661, 'Smallville: As Aventuras do Superboy S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10262, 661, 'Smallville: As Aventuras do Superboy S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10263, 661, 'Smallville: As Aventuras do Superboy S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10264, 661, 'Smallville: As Aventuras do Superboy S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10265, 661, 'Smallville: As Aventuras do Superboy S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/100293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10266, 661, 'Smallville: As Aventuras do Superboy S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/100294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10267, 661, 'Smallville: As Aventuras do Superboy S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/100295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10268, 661, 'Smallville: As Aventuras do Superboy S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/100296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10269, 662, 'Smallville: As Aventuras do Superboy S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10270, 662, 'Smallville: As Aventuras do Superboy S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10271, 662, 'Smallville: As Aventuras do Superboy S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10272, 662, 'Smallville: As Aventuras do Superboy S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10273, 662, 'Smallville: As Aventuras do Superboy S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10274, 662, 'Smallville: As Aventuras do Superboy S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10275, 662, 'Smallville: As Aventuras do Superboy S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10276, 662, 'Smallville: As Aventuras do Superboy S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10277, 662, 'Smallville: As Aventuras do Superboy S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10278, 662, 'Smallville: As Aventuras do Superboy S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10279, 662, 'Smallville: As Aventuras do Superboy S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10280, 662, 'Smallville: As Aventuras do Superboy S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10281, 662, 'Smallville: As Aventuras do Superboy S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10282, 662, 'Smallville: As Aventuras do Superboy S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10283, 662, 'Smallville: As Aventuras do Superboy S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10284, 662, 'Smallville: As Aventuras do Superboy S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10285, 662, 'Smallville: As Aventuras do Superboy S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10286, 662, 'Smallville: As Aventuras do Superboy S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10287, 662, 'Smallville: As Aventuras do Superboy S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/100315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10288, 662, 'Smallville: As Aventuras do Superboy S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/100316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10289, 662, 'Smallville: As Aventuras do Superboy S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/100317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10290, 662, 'Smallville: As Aventuras do Superboy S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/100318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10291, 663, 'Smallville: As Aventuras do Superboy S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10292, 663, 'Smallville: As Aventuras do Superboy S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10293, 663, 'Smallville: As Aventuras do Superboy S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10294, 663, 'Smallville: As Aventuras do Superboy S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10295, 663, 'Smallville: As Aventuras do Superboy S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10296, 663, 'Smallville: As Aventuras do Superboy S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10297, 663, 'Smallville: As Aventuras do Superboy S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10298, 663, 'Smallville: As Aventuras do Superboy S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10299, 663, 'Smallville: As Aventuras do Superboy S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10300, 663, 'Smallville: As Aventuras do Superboy S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10301, 663, 'Smallville: As Aventuras do Superboy S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10302, 663, 'Smallville: As Aventuras do Superboy S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10303, 663, 'Smallville: As Aventuras do Superboy S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10304, 663, 'Smallville: As Aventuras do Superboy S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10305, 663, 'Smallville: As Aventuras do Superboy S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10306, 663, 'Smallville: As Aventuras do Superboy S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10307, 663, 'Smallville: As Aventuras do Superboy S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10308, 663, 'Smallville: As Aventuras do Superboy S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10309, 663, 'Smallville: As Aventuras do Superboy S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/100337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10310, 663, 'Smallville: As Aventuras do Superboy S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/100338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10311, 664, 'Smallville: As Aventuras do Superboy S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10312, 664, 'Smallville: As Aventuras do Superboy S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10313, 664, 'Smallville: As Aventuras do Superboy S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10314, 664, 'Smallville: As Aventuras do Superboy S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10315, 664, 'Smallville: As Aventuras do Superboy S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10316, 664, 'Smallville: As Aventuras do Superboy S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10317, 664, 'Smallville: As Aventuras do Superboy S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10318, 664, 'Smallville: As Aventuras do Superboy S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10319, 664, 'Smallville: As Aventuras do Superboy S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10320, 664, 'Smallville: As Aventuras do Superboy S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10321, 664, 'Smallville: As Aventuras do Superboy S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10322, 664, 'Smallville: As Aventuras do Superboy S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10323, 664, 'Smallville: As Aventuras do Superboy S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10324, 664, 'Smallville: As Aventuras do Superboy S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10325, 664, 'Smallville: As Aventuras do Superboy S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10326, 664, 'Smallville: As Aventuras do Superboy S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10327, 664, 'Smallville: As Aventuras do Superboy S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10328, 664, 'Smallville: As Aventuras do Superboy S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10329, 664, 'Smallville: As Aventuras do Superboy S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/100357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10330, 664, 'Smallville: As Aventuras do Superboy S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/100358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10331, 664, 'Smallville: As Aventuras do Superboy S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/100359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10332, 664, 'Smallville: As Aventuras do Superboy S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/100360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10333, 665, 'Smallville: As Aventuras do Superboy S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10334, 665, 'Smallville: As Aventuras do Superboy S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10335, 665, 'Smallville: As Aventuras do Superboy S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10336, 665, 'Smallville: As Aventuras do Superboy S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10337, 665, 'Smallville: As Aventuras do Superboy S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10338, 665, 'Smallville: As Aventuras do Superboy S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10339, 665, 'Smallville: As Aventuras do Superboy S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10340, 665, 'Smallville: As Aventuras do Superboy S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10341, 665, 'Smallville: As Aventuras do Superboy S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10342, 665, 'Smallville: As Aventuras do Superboy S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10343, 665, 'Smallville: As Aventuras do Superboy S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10344, 665, 'Smallville: As Aventuras do Superboy S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10345, 665, 'Smallville: As Aventuras do Superboy S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10346, 665, 'Smallville: As Aventuras do Superboy S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10347, 665, 'Smallville: As Aventuras do Superboy S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10348, 665, 'Smallville: As Aventuras do Superboy S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10349, 665, 'Smallville: As Aventuras do Superboy S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10350, 665, 'Smallville: As Aventuras do Superboy S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10351, 665, 'Smallville: As Aventuras do Superboy S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/100379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10352, 665, 'Smallville: As Aventuras do Superboy S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/100380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10353, 665, 'Smallville: As Aventuras do Superboy S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/100381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10354, 666, 'Smallville: As Aventuras do Superboy S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10355, 666, 'Smallville: As Aventuras do Superboy S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10356, 666, 'Smallville: As Aventuras do Superboy S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10357, 666, 'Smallville: As Aventuras do Superboy S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10358, 666, 'Smallville: As Aventuras do Superboy S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10359, 666, 'Smallville: As Aventuras do Superboy S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10360, 666, 'Smallville: As Aventuras do Superboy S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10361, 666, 'Smallville: As Aventuras do Superboy S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10362, 666, 'Smallville: As Aventuras do Superboy S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10363, 666, 'Smallville: As Aventuras do Superboy S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10364, 666, 'Smallville: As Aventuras do Superboy S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/100392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10365, 666, 'Smallville: As Aventuras do Superboy S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/100393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10366, 666, 'Smallville: As Aventuras do Superboy S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/100394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10367, 666, 'Smallville: As Aventuras do Superboy S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/100395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10368, 666, 'Smallville: As Aventuras do Superboy S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/100396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10369, 666, 'Smallville: As Aventuras do Superboy S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/100397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10370, 666, 'Smallville: As Aventuras do Superboy S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/100398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10371, 666, 'Smallville: As Aventuras do Superboy S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/100399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10372, 666, 'Smallville: As Aventuras do Superboy S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/100400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10373, 666, 'Smallville: As Aventuras do Superboy S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/100401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10374, 666, 'Smallville: As Aventuras do Superboy S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/100402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(10375, 667, 'Sob Pressão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10376, 667, 'Sob Pressão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10377, 667, 'Sob Pressão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10378, 667, 'Sob Pressão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10379, 667, 'Sob Pressão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10380, 667, 'Sob Pressão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10381, 667, 'Sob Pressão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10382, 667, 'Sob Pressão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10383, 667, 'Sob Pressão S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/197904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10384, 668, 'Sob Pressão S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10385, 668, 'Sob Pressão S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10386, 668, 'Sob Pressão S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10387, 668, 'Sob Pressão S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10388, 668, 'Sob Pressão S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10389, 668, 'Sob Pressão S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10390, 668, 'Sob Pressão S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10391, 668, 'Sob Pressão S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10392, 668, 'Sob Pressão S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/197913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10393, 668, 'Sob Pressão S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/197914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(10394, 668, 'Sob Pressão S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/197915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10395, 669, 'Sob Pressão S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10396, 669, 'Sob Pressão S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10397, 669, 'Sob Pressão S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10398, 669, 'Sob Pressão S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10399, 669, 'Sob Pressão S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10400, 669, 'Sob Pressão S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10401, 669, 'Sob Pressão S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10402, 669, 'Sob Pressão S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10403, 669, 'Sob Pressão S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/197924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10404, 669, 'Sob Pressão S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/197925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10405, 669, 'Sob Pressão S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/197926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10406, 669, 'Sob Pressão S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/197927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10407, 669, 'Sob Pressão S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/197928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10408, 669, 'Sob Pressão S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/197929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10409, 670, 'Sob Pressão S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197930.mp4', 'http://timg.bdta.pro/images/ea67878feaaccc05ba088c4ebe4a4fec.jpg'),
(10410, 670, 'Sob Pressão S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10411, 670, 'Sob Pressão S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197932.mp4', 'http://timg.bdta.pro/images/66bbf957395db2855b0d65132c381dbf.jpg'),
(10412, 670, 'Sob Pressão S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10413, 670, 'Sob Pressão S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10414, 670, 'Sob Pressão S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10415, 670, 'Sob Pressão S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10416, 670, 'Sob Pressão S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10417, 670, 'Sob Pressão S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/197938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10418, 670, 'Sob Pressão S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/197939.mp4', 'http://image.tmdb.org/t/p/w1280/uD9HgzbWo8iWMw98JhgfWit4Ir.jpg'),
(10419, 670, 'Sob Pressão S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/197940.mp4', 'http://timg.bdta.pro/images/f7363f716c5904e60ddb4d3cf36cc078.jpg'),
(10420, 671, 'Sob Pressão S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197941.mp4', 'http://timg.bdta.pro/images/dfb0baead65a6e8e9f03529cceee1d55.jpg'),
(10421, 671, 'Sob Pressão S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197942.mp4', 'http://timg.bdta.pro/images/ea638b932e22309bc28c331840b07af0.jpg'),
(10422, 671, 'Sob Pressão S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10423, 671, 'Sob Pressão S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10424, 671, 'Sob Pressão S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10425, 671, 'Sob Pressão S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10426, 671, 'Sob Pressão S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10427, 671, 'Sob Pressão S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10428, 671, 'Sob Pressão S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/197949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10429, 671, 'Sob Pressão S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/197950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10430, 671, 'Sob Pressão S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/197951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10431, 671, 'Sob Pressão S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/197952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGWf1lqeHOhuKZX9bQPeAKttxnb.jpg'),
(10432, 672, 'Somewhere Between S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123145.mkv', 'http://timg.bdta.pro/images/358668f535a50b265705ac82ab638f2e.jpg'),
(10433, 672, 'Somewhere Between S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123146.mkv', 'http://timg.bdta.pro/images/f67fece842e13e50f465db0dc1775666.jpg'),
(10434, 672, 'Somewhere Between S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123147.mkv', 'http://timg.bdta.pro/images/c5c91d209a1208b638981cd81d83b94e.jpg'),
(10435, 672, 'Somewhere Between S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123148.mkv', 'http://timg.bdta.pro/images/781030686aec23acff5a52dd5f81b7d4.jpg'),
(10436, 672, 'Somewhere Between S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123149.mkv', 'http://timg.bdta.pro/images/98c5534a1cc9a14dc23600d14ad4e092.jpg'),
(10437, 672, 'Somewhere Between S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123150.mkv', 'http://timg.bdta.pro/images/309553adb1b2c700ede6b16eb6198216.jpg'),
(10438, 673, 'Sons Of Anarchy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217554.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10439, 673, 'Sons Of Anarchy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217555.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10440, 673, 'Sons Of Anarchy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217556.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10441, 673, 'Sons Of Anarchy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217557.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10442, 673, 'Sons Of Anarchy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217558.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10443, 673, 'Sons Of Anarchy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217559.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10444, 673, 'Sons Of Anarchy S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217560.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10445, 673, 'Sons Of Anarchy S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217561.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10446, 673, 'Sons Of Anarchy S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217562.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10447, 673, 'Sons Of Anarchy S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217563.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10448, 673, 'Sons Of Anarchy S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217564.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10449, 673, 'Sons Of Anarchy S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217565.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10450, 673, 'Sons Of Anarchy S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217566.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10451, 674, 'Sons Of Anarchy S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217567.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10452, 674, 'Sons Of Anarchy S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217568.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10453, 674, 'Sons Of Anarchy S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217569.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10454, 674, 'Sons Of Anarchy S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217570.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10455, 674, 'Sons Of Anarchy S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217571.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10456, 674, 'Sons Of Anarchy S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217572.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10457, 674, 'Sons Of Anarchy S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217573.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10458, 674, 'Sons Of Anarchy S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217574.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10459, 674, 'Sons Of Anarchy S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217575.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10460, 674, 'Sons Of Anarchy S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217576.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10461, 674, 'Sons Of Anarchy S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217577.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10462, 674, 'Sons Of Anarchy S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217578.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10463, 674, 'Sons Of Anarchy S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217579.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10464, 675, 'Sons Of Anarchy S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217580.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10465, 675, 'Sons Of Anarchy S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217581.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10466, 675, 'Sons Of Anarchy S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217582.mp4', 'http://timg.bdta.pro/images/eV1v7ptT9QSRIMYZ9pB3X5Q4jBJ_small.jpg'),
(10467, 675, 'Sons Of Anarchy S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217583.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10468, 675, 'Sons Of Anarchy S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217584.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10469, 675, 'Sons Of Anarchy S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217585.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10470, 675, 'Sons Of Anarchy S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217586.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10471, 675, 'Sons Of Anarchy S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217587.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10472, 675, 'Sons Of Anarchy S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217588.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10473, 675, 'Sons Of Anarchy S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217589.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10474, 675, 'Sons Of Anarchy S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217590.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10475, 675, 'Sons Of Anarchy S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217591.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10476, 675, 'Sons Of Anarchy S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217592.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10477, 676, 'Sons Of Anarchy S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217593.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10478, 676, 'Sons Of Anarchy S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217594.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10479, 676, 'Sons Of Anarchy S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217595.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10480, 676, 'Sons Of Anarchy S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217596.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10481, 676, 'Sons Of Anarchy S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217597.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10482, 676, 'Sons Of Anarchy S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217598.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10483, 676, 'Sons Of Anarchy S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217599.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10484, 676, 'Sons Of Anarchy S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217600.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10485, 676, 'Sons Of Anarchy S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217601.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10486, 676, 'Sons Of Anarchy S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217602.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10487, 676, 'Sons Of Anarchy S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217603.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10488, 676, 'Sons Of Anarchy S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217604.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10489, 676, 'Sons Of Anarchy S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217605.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10490, 676, 'Sons Of Anarchy S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/217606.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10491, 677, 'Sons Of Anarchy S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217607.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10492, 677, 'Sons Of Anarchy S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217608.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10493, 677, 'Sons Of Anarchy S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217609.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10494, 677, 'Sons Of Anarchy S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217610.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10495, 677, 'Sons Of Anarchy S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217611.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10496, 677, 'Sons Of Anarchy S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217612.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10497, 677, 'Sons Of Anarchy S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217613.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10498, 677, 'Sons Of Anarchy S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217614.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10499, 677, 'Sons Of Anarchy S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217615.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10500, 677, 'Sons Of Anarchy S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217616.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10501, 677, 'Sons Of Anarchy S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217617.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10502, 677, 'Sons Of Anarchy S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217618.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10503, 677, 'Sons Of Anarchy S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217619.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10504, 678, 'Sons Of Anarchy S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217620.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10505, 678, 'Sons Of Anarchy S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217621.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10506, 678, 'Sons Of Anarchy S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217622.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10507, 678, 'Sons Of Anarchy S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217623.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10508, 678, 'Sons Of Anarchy S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217624.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10509, 678, 'Sons Of Anarchy S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217625.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10510, 678, 'Sons Of Anarchy S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217626.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10511, 678, 'Sons Of Anarchy S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217627.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10512, 678, 'Sons Of Anarchy S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217628.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10513, 678, 'Sons Of Anarchy S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217629.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10514, 678, 'Sons Of Anarchy S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217630.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10515, 678, 'Sons Of Anarchy S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217631.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10516, 678, 'Sons Of Anarchy S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217632.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10517, 679, 'Sons Of Anarchy S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217633.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10518, 679, 'Sons Of Anarchy S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217634.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10519, 679, 'Sons Of Anarchy S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217635.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10520, 679, 'Sons Of Anarchy S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217636.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10521, 679, 'Sons Of Anarchy S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217637.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10522, 679, 'Sons Of Anarchy S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217638.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10523, 679, 'Sons Of Anarchy S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217639.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10524, 679, 'Sons Of Anarchy S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217640.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10525, 679, 'Sons Of Anarchy S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217641.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10526, 679, 'Sons Of Anarchy S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217642.mp4', 'http://gstaticontent.com/images/c2zvmoBPssldx09krOANGwn1thl_big.jpg'),
(10527, 679, 'Sons Of Anarchy S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8L6F49XHg0PyKviXG8USvM9uQsN.jpg'),
(10528, 679, 'Sons Of Anarchy S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5b4IZAMn8agTnhJTW0so9upRRZk.jpg'),
(10529, 679, 'Sons Of Anarchy S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbHsHNKHfc8xIq1naQ6rxXIaSdo.jpg'),
(10530, 680, 'Spartacus S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10531, 680, 'Spartacus S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10532, 680, 'Spartacus S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10533, 680, 'Spartacus S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10534, 680, 'Spartacus S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10535, 680, 'Spartacus S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10536, 680, 'Spartacus S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10537, 680, 'Spartacus S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10538, 680, 'Spartacus S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10539, 680, 'Spartacus S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10540, 680, 'Spartacus S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10541, 680, 'Spartacus S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10542, 680, 'Spartacus S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10543, 681, 'Spartacus S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10544, 681, 'Spartacus S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10545, 681, 'Spartacus S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10546, 681, 'Spartacus S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10547, 681, 'Spartacus S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10548, 681, 'Spartacus S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10549, 681, 'Spartacus S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10550, 681, 'Spartacus S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10551, 681, 'Spartacus S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10552, 681, 'Spartacus S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10553, 682, 'Spartacus S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10554, 682, 'Spartacus S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10555, 682, 'Spartacus S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10556, 682, 'Spartacus S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10557, 682, 'Spartacus S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10558, 682, 'Spartacus S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10559, 682, 'Spartacus S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10560, 682, 'Spartacus S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10561, 682, 'Spartacus S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10562, 682, 'Spartacus S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10563, 683, 'Spartacus S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10564, 683, 'Spartacus S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10565, 683, 'Spartacus S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10566, 683, 'Spartacus S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10567, 683, 'Spartacus S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10568, 683, 'Spartacus S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2GKN4VHCj1dnjFMANRpGkCVBae.jpg'),
(10569, 684, 'Star Trek: Discovery S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177766.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10570, 684, 'Star Trek: Discovery S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177767.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10571, 684, 'Star Trek: Discovery S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177768.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10572, 684, 'Star Trek: Discovery S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177769.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10573, 684, 'Star Trek: Discovery S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177770.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10574, 684, 'Star Trek: Discovery S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177771.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10575, 684, 'Star Trek: Discovery S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177772.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10576, 684, 'Star Trek: Discovery S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177773.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10577, 684, 'Star Trek: Discovery S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177774.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10578, 684, 'Star Trek: Discovery S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177775.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10579, 684, 'Star Trek: Discovery S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177776.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10580, 684, 'Star Trek: Discovery S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177777.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10581, 684, 'Star Trek: Discovery S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/880839.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10582, 684, 'Star Trek: Discovery S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/880840.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10583, 684, 'Star Trek: Discovery S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/880841.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10584, 685, 'Star Trek: Discovery S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177778.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10585, 685, 'Star Trek: Discovery S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177779.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10586, 685, 'Star Trek: Discovery S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177780.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10587, 685, 'Star Trek: Discovery S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177781.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10588, 685, 'Star Trek: Discovery S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177782.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10589, 685, 'Star Trek: Discovery S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177783.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10590, 685, 'Star Trek: Discovery S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177784.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10591, 685, 'Star Trek: Discovery S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177785.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10592, 685, 'Star Trek: Discovery S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177786.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10593, 685, 'Star Trek: Discovery S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177787.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10594, 685, 'Star Trek: Discovery S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177788.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10595, 685, 'Star Trek: Discovery S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177789.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10596, 685, 'Star Trek: Discovery S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/177790.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10597, 685, 'Star Trek: Discovery S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/177791.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10598, 686, 'Star Trek: Discovery S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177792.mp4', 'http://timg.bdta.pro/images/bfa9b07cc61d53392fc62f0703c136c0.jpg'),
(10599, 686, 'Star Trek: Discovery S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177793.mp4', 'http://timg.bdta.pro/images/c4ba1a88ac185a05ceec1f5ca7689486.jpg'),
(10600, 686, 'Star Trek: Discovery S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177794.mp4', 'http://timg.bdta.pro/images/2caeb0867844d59ae3e5e40bead02e7f.jpg'),
(10601, 686, 'Star Trek: Discovery S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kHFW5kbcrOpB8WmmuN6qyxNaeA5.jpg'),
(10602, 686, 'Star Trek: Discovery S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iBWxUt568Te1J24u6CPGXguDeFv.jpg'),
(10603, 686, 'Star Trek: Discovery S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177797.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10604, 686, 'Star Trek: Discovery S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177798.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10605, 686, 'Star Trek: Discovery S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177799.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10606, 686, 'Star Trek: Discovery S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177800.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10607, 686, 'Star Trek: Discovery S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177801.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10608, 686, 'Star Trek: Discovery S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177802.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10609, 686, 'Star Trek: Discovery S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177803.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10610, 686, 'Star Trek: Discovery S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/177804.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10611, 687, 'Star Trek: Discovery S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6RsRTvxI2Sv6mNmBOOLuEmiAEcy.jpg'),
(10612, 687, 'Star Trek: Discovery S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3FZ6ZAKxQaVS84uymVdYzwOGUOa.jpg'),
(10613, 687, 'Star Trek: Discovery S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177807.mp4', 'http://image.tmdb.org/t/p/w1280/8tx3avvVJHrXFDIeCafbXn0H2gB.jpg'),
(10614, 687, 'Star Trek: Discovery S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177808.mp4', 'http://image.tmdb.org/t/p/w1280/dkAcumWO5pwsinph7vdSwrKvc7g.jpg'),
(10615, 687, 'Star Trek: Discovery S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b6x4x2z2XflPcmh3iRGr37CdsxS.jpg'),
(10616, 687, 'Star Trek: Discovery S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vOaVmVveQjU5EbSHlNFIr3HxsVQ.jpg'),
(10617, 687, 'Star Trek: Discovery S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177811.mp4', 'http://image.tmdb.org/t/p/w1280/n7Yc5nn00Fo0dJ8d9uD2v6lIhfh.jpg'),
(10618, 687, 'Star Trek: Discovery S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177812.mp4', 'http://timg.bdta.pro/images/afb26cfadc401b067b4a46a1367dac98.jpg'),
(10619, 687, 'Star Trek: Discovery S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177813.mp4', 'http://timg.bdta.pro/images/8cc2798702bad0081a956363edd03229.jpg'),
(10620, 687, 'Star Trek: Discovery S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177814.mp4', 'http://timg.bdta.pro/images/ea21c7a07d494d3e7a31204967f9c31d.jpg'),
(10621, 687, 'Star Trek: Discovery S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177815.mp4', 'http://timg.bdta.pro/images/897f28c41f51bf1a39732dfc296e8161.jpg'),
(10622, 687, 'Star Trek: Discovery S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177816.mp4', 'http://timg.bdta.pro/images/91ecd9694dc36d63b20b1fd38f1335fb.jpg'),
(10623, 687, 'Star Trek: Discovery S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/177817.mp4', 'http://timg.bdta.pro/images/ba8bfba37560dd37c49422ca1b73ee8c.jpg'),
(10624, 688, 'Star Trek: Discovery S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/319358.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10625, 688, 'Star Trek: Discovery S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/319359.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10626, 688, 'Star Trek: Discovery S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/327190.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10627, 688, 'Star Trek: Discovery S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331059.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10628, 688, 'Star Trek: Discovery S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/335948.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10629, 688, 'Star Trek: Discovery S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/340104.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10630, 688, 'Star Trek: Discovery S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/351387.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10631, 688, 'Star Trek: Discovery S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/351388.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10632, 688, 'Star Trek: Discovery S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/358717.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10633, 688, 'Star Trek: Discovery S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/607336.mp4', 'http://gstaticontent.com/images/52f5e385dbfea53d4fa3ad4ef9c937d0.jpg'),
(10634, 689, 'Estação 19 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10635, 689, 'Estação 19 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10636, 689, 'Estação 19 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10637, 689, 'Estação 19 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10638, 689, 'Estação 19 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10639, 689, 'Estação 19 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10640, 689, 'Estação 19 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10641, 689, 'Estação 19 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10642, 689, 'Estação 19 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10643, 689, 'Estação 19 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10644, 690, 'Estação 19 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10645, 690, 'Estação 19 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10646, 690, 'Estação 19 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10647, 690, 'Estação 19 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10648, 690, 'Estação 19 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10649, 690, 'Estação 19 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10650, 690, 'Estação 19 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10651, 690, 'Estação 19 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10652, 690, 'Estação 19 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10653, 690, 'Estação 19 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10654, 690, 'Estação 19 S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10655, 690, 'Estação 19 S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7KUsdawI4PTgOtMXtSSFlO9RBXu.jpg'),
(10656, 690, 'Estação 19 S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/emooy6StkhUlqRgXYD5gdvPqLGl.jpg'),
(10657, 690, 'Estação 19 S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2JeAx50VWq6MSpXjPrFzNUEX6CN.jpg'),
(10658, 690, 'Estação 19 S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gleEQr1rfjDy4U3YkYrt2862ebE.jpg'),
(10659, 690, 'Estação 19 S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzRqQywo7yrrDiq3RQqLaSqp3cS.jpg'),
(10660, 690, 'Estação 19 S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mxPbZwuXCw8EENDTXO5VAnvzDVy.jpg'),
(10661, 691, 'Estação 19 S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0B96wXgF5iBhDQySM3Cj1TrGlZ.jpg'),
(10662, 691, 'Estação 19 S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/FvLTZz6iKoZDM7w5EIt2czZreK.jpg'),
(10663, 691, 'Estação 19 S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rXQmISB34i4SuMotpISdfp4CWwu.jpg'),
(10664, 691, 'Estação 19 S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l6QsZSrhqRDx58XowvQNs0GMlCI.jpg'),
(10665, 691, 'Estação 19 S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d5dyc41IiWEjgNb92VTqAitxo0A.jpg'),
(10666, 691, 'Estação 19 S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tB2mNCowmd9XcZSw2NpY8EQANXQ.jpg'),
(10667, 691, 'Estação 19 S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sx9PH2RRXZaDuovJMpsSZZg4aI4.jpg'),
(10668, 691, 'Estação 19 S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cVNOt3k0BgmkZ3PcGsqZOe3EwDv.jpg'),
(10669, 691, 'Estação 19 S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f5wUuDVwEOJtJAgox6TTnBc3LTJ.jpg'),
(10670, 691, 'Estação 19 S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/WUw72eH8hdUkpIKZBRmQa1jh7.jpg'),
(10671, 691, 'Estação 19 S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ostV6CWK600mhOjdNv8Fe7T0REv.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(10672, 691, 'Estação 19 S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kpVE2UM8NStDzx8NqjAS1h8vgSx.jpg'),
(10673, 691, 'Estação 19 S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pCs8Cr1y8LmaA8F51h35MQsce9C.jpg'),
(10674, 691, 'Estação 19 S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6XFGm6YXD80Il8DzBGvkFOf2o0v.jpg'),
(10675, 691, 'Estação 19 S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hZ0MhTpNFKz2fKee40SHAxrtPcw.jpg'),
(10676, 691, 'Estação 19 S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zNz2rRoc5pkwdXSoYJZMKmF3WCY.jpg'),
(10677, 692, 'Estação 19 S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kUYG2gMfAxy9ObAApw5uqJIOcb8.jpg'),
(10678, 692, 'Estação 19 S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6NMFYwssOD4uf05kiCQMip7oKOD.jpg'),
(10679, 692, 'Estação 19 S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uyaDlGdteB0q2pSZ9RVtMLQOCkm.jpg'),
(10680, 692, 'Estação 19 S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fF2M4hpicNrLLB3u0dVgADU8Kci.jpg'),
(10681, 692, 'Estação 19 S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g4wkUOMzfq6Jj8wnosXwGybbSS7.jpg'),
(10682, 692, 'Estação 19 S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x22xXDm2yPYuafZZCTvVAZk8g5r.jpg'),
(10683, 692, 'Estação 19 S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtuMrjLaBkzIMnJfzWD7I6ZzZqu.jpg'),
(10684, 692, 'Estação 19 S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/M5Xx8pugbD3kUBJP9R5PqIUu9R.jpg'),
(10685, 692, 'Estação 19 S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ztC3DFSSjMzJdKF6x3grtM0u44O.jpg'),
(10686, 692, 'Estação 19 S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wfdTzZ7dteZ1slv32j8WD2zzl5F.jpg'),
(10687, 692, 'Estação 19 S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iy5r5iQt3v2Hx2oc9rHfv4ni6ST.jpg'),
(10688, 692, 'Estação 19 S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhA5qBp7lP7uGkH00NlqxKTMTyK.jpg'),
(10689, 692, 'Estação 19 S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/avFhOFomxVsGAhAAXmF9pVFujBU.jpg'),
(10690, 692, 'Estação 19 S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bFjYoj1vMk3qtcCnYsX0YOmvpuj.jpg'),
(10691, 692, 'Estação 19 S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fW2TIsFGICjsU1SfHV4JkVAUwPV.jpg'),
(10692, 692, 'Estação 19 S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5sP2XsHXx8ITJ7uCRFKlqbKufkE.jpg'),
(10693, 693, 'Estação 19 S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224048.mp4', 'http://timg.bdta.pro/images/6a63fc9c138cdb1aaf477ae753a48839.jpg'),
(10694, 693, 'Estação 19 S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224049.mp4', 'http://timg.bdta.pro/images/c980c20c1097cc88140c59cfe0131626.jpg'),
(10695, 693, 'Estação 19 S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224050.mp4', 'http://timg.bdta.pro/images/e92209a920c0b643f7bc09e303f74795.jpg'),
(10696, 693, 'Estação 19 S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224051.mp4', 'http://timg.bdta.pro/images/299d0989b117f4bcd0ddff932c8fab51.jpg'),
(10697, 693, 'Estação 19 S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224052.mp4', 'http://timg.bdta.pro/images/8e55526df93c439eddb3dc2d341f93b5.jpg'),
(10698, 693, 'Estação 19 S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224053.mp4', 'http://timg.bdta.pro/images/e3b2477ee7489ac21921ea6be416e590.jpg'),
(10699, 693, 'Estação 19 S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224054.mp4', 'http://timg.bdta.pro/images/2ac18835a612f6fe74db77f7b5cbe670.jpg'),
(10700, 693, 'Estação 19 S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224055.mp4', 'http://timg.bdta.pro/images/a13143ea904f6ae47dbe8167b2020ea4.jpg'),
(10701, 693, 'Estação 19 S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224056.mp4', 'http://timg.bdta.pro/images/0d3735b4253b56c2e34d8b10a51c4682.jpg'),
(10702, 693, 'Estação 19 S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224057.mp4', 'http://timg.bdta.pro/images/e54ef5eed67638c700a1cccf6b57138e.jpg'),
(10703, 693, 'Estação 19 S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224058.mp4', 'http://timg.bdta.pro/images/e24f5b1fd349459b9153f22eaa26fe91.jpg'),
(10704, 693, 'Estação 19 S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224059.mp4', 'http://timg.bdta.pro/images/36fba391b329c6c03dcf7fbcb8e9bd87.jpg'),
(10705, 693, 'Estação 19 S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224060.mp4', 'http://timg.bdta.pro/images/00ea827bfa21c9fce9fe07ee9f69056a.jpg'),
(10706, 693, 'Estação 19 S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224061.mp4', 'http://timg.bdta.pro/images/30f4265a0315c8e5a86bb40db1df8b5a.jpg'),
(10707, 693, 'Estação 19 S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224062.mp4', 'http://timg.bdta.pro/images/6f0ce4229eb620d4f26523ebdb31e86d.jpg'),
(10708, 693, 'Estação 19 S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224063.mp4', 'http://timg.bdta.pro/images/a42ea9af7fb934b877d7c617bdbb586b.jpg'),
(10709, 693, 'Estação 19 S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224064.mp4', 'http://timg.bdta.pro/images/338320ef017c1a60229bb2baa16a0aa9.jpg'),
(10710, 693, 'Estação 19 S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224065.mp4', 'http://timg.bdta.pro/images/b2b6a91eb0d60886e9837830893cd5bd.jpg'),
(10711, 694, 'Estação 19 S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/irOLkWF2Apdn8js2mGDJRlvFXMb.jpg'),
(10712, 694, 'Estação 19 S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8bkmBU9ft45jJX0VdqnAm3bMZH8.jpg'),
(10713, 694, 'Estação 19 S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qcbVzcqIpFZb1KnJQfCfotXYnl7.jpg'),
(10714, 694, 'Estação 19 S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224069.mp4', 'http://image.tmdb.org/t/p/w1280/kMEVqLFxc09c2oG1OTdvVRurodx.jpg'),
(10715, 694, 'Estação 19 S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224070.mp4', 'http://image.tmdb.org/t/p/w1280/bqIs64wCRV4GBExcOgXKYvM5I9g.jpg'),
(10716, 694, 'Estação 19 S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224071.mp4', 'http://image.tmdb.org/t/p/w1280/mdd46tsXxytj1IM2RZ9W8U383W2.jpg'),
(10717, 694, 'Estação 19 S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224072.mp4', 'http://image.tmdb.org/t/p/w1280/oSBWovhIaAH9fnhDV29Lo0EWZ0U.jpg'),
(10718, 694, 'Estação 19 S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224073.mp4', 'http://image.tmdb.org/t/p/w1280/hcRxbOqd421zOvUjR1DpQMw2PQM.jpg'),
(10719, 694, 'Estação 19 S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224074.mp4', 'http://image.tmdb.org/t/p/w1280/4vFUAJP1eJKlLn7VcjvOsozNt1C.jpg'),
(10720, 694, 'Estação 19 S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224075.mp4', 'http://image.tmdb.org/t/p/w1280/1YfAWTfZ4792TiuCcwzGA4YTf86.jpg'),
(10721, 694, 'Estação 19 S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s4LwGyyO45j0Gsz6RtCkTrMDkz2.jpg'),
(10722, 694, 'Estação 19 S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mneYoA1n1yxUxJvDNrrfL6OIBHM.jpg'),
(10723, 694, 'Estação 19 S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/embarfGJj8gSJjOhSKWNKR6NWBo.jpg'),
(10724, 694, 'Estação 19 S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224079.mp4', 'http://image.tmdb.org/t/p/w1280/mrLtb4kaZWtDG4BePQWFYkeUFZu.jpg'),
(10725, 694, 'Estação 19 S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224080.mp4', 'http://image.tmdb.org/t/p/w1280/5m2J2i7uYKrVoy0EUlmIZpEdyV9.jpg'),
(10726, 694, 'Estação 19 S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224081.mp4', 'http://image.tmdb.org/t/p/w1280/o8EL63euyGzuHjcc5apuype6mI3.jpg'),
(10727, 694, 'Estação 19 S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224082.mp4', 'http://image.tmdb.org/t/p/w1280/7MBU2y1ZwSOM9FslI8axE4jStCu.jpg'),
(10728, 694, 'Estação 19 S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224083.mp4', 'http://image.tmdb.org/t/p/w1280/fushVPNURPruKfILn0WUNs2lGY2.jpg'),
(10729, 695, 'Estação 19 S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/376166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10730, 695, 'Estação 19 S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/385804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10731, 695, 'Estação 19 S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/376168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10732, 695, 'Estação 19 S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/385806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10733, 695, 'Estação 19 S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/385807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10734, 695, 'Estação 19 S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/385808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10735, 695, 'Estação 19 S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/420706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10736, 695, 'Estação 19 S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/420707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10737, 695, 'Estação 19 S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/420708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10738, 695, 'Estação 19 S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/420709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kBhkpvuX03OWuLe8AupIjP8N7uk.jpg'),
(10739, 696, 'Stranger Things S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10740, 696, 'Stranger Things S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10741, 696, 'Stranger Things S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10742, 696, 'Stranger Things S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10743, 696, 'Stranger Things S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10744, 696, 'Stranger Things S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10745, 696, 'Stranger Things S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182584.mp4', 'http://timg.bdta.pro/images/f379958d74633ecdcc11e6a39cab82dc.jpg'),
(10746, 696, 'Stranger Things S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182585.mp4', 'http://timg.bdta.pro/images/2fe3ea4c5b0d8e7abfaf0655d58f55a3.jpg'),
(10747, 697, 'Stranger Things S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10748, 697, 'Stranger Things S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10749, 697, 'Stranger Things S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10750, 697, 'Stranger Things S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10751, 697, 'Stranger Things S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10752, 697, 'Stranger Things S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10753, 697, 'Stranger Things S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10754, 697, 'Stranger Things S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10755, 697, 'Stranger Things S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/182594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10756, 698, 'Stranger Things S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10757, 698, 'Stranger Things S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10758, 698, 'Stranger Things S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10759, 698, 'Stranger Things S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10760, 698, 'Stranger Things S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10761, 698, 'Stranger Things S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10762, 698, 'Stranger Things S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10763, 698, 'Stranger Things S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10764, 699, 'Stranger Things S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182603.mp4', 'http://timg.bdta.pro/images/8fdfe81dc88df3bd73da1e4f59199ec0.jpg'),
(10765, 699, 'Stranger Things S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182604.mp4', 'http://timg.bdta.pro/images/8eb36971805549c619d264c393188eb8.jpg'),
(10766, 699, 'Stranger Things S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182605.mp4', 'http://timg.bdta.pro/images/3da419f2060c26e2834695a583aed058.jpg'),
(10767, 699, 'Stranger Things S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182606.mp4', 'http://timg.bdta.pro/images/2277a8912ae60b7dd7e0d11eba0f435f.jpg'),
(10768, 699, 'Stranger Things S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182607.mp4', 'http://timg.bdta.pro/images/0d655e9f72c1d32ad568ae6ef2fd0c33.jpg'),
(10769, 699, 'Stranger Things S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182608.mp4', 'http://timg.bdta.pro/images/8f146994225e69b16163702f766cdcb5.jpg'),
(10770, 699, 'Stranger Things S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182609.mp4', 'http://timg.bdta.pro/images/a2b97807578ab67b5c980ccf65f4a5e1.jpg'),
(10771, 699, 'Stranger Things S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182610.mp4', 'http://timg.bdta.pro/images/652536d0dd35a5fd98d937ff9e35027f.jpg'),
(10772, 699, 'Stranger Things S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/182611.mp4', 'http://timg.bdta.pro/images/622ec986942f64f5154659ed48cd8ea3.jpg'),
(10773, 700, 'Stranger Things S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/893449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10774, 700, 'Stranger Things S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/893450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10775, 700, 'Stranger Things S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/893451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10776, 700, 'Stranger Things S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/893452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10777, 700, 'Stranger Things S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/896922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10778, 700, 'Stranger Things S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/896923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10779, 700, 'Stranger Things S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/896924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oqkld2D0qcnSNRm15rYV2883JE3.jpg'),
(10780, 701, 'Suits S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106867.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10781, 701, 'Suits S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106868.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10782, 701, 'Suits S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106869.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10783, 701, 'Suits S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106870.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10784, 701, 'Suits S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106871.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10785, 701, 'Suits S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106872.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10786, 701, 'Suits S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106873.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10787, 701, 'Suits S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106874.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10788, 701, 'Suits S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106875.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10789, 701, 'Suits S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106876.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10790, 701, 'Suits S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106877.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10791, 701, 'Suits S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/106878.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10792, 702, 'Suits S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106879.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10793, 702, 'Suits S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106880.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10794, 702, 'Suits S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106881.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10795, 702, 'Suits S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106882.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10796, 702, 'Suits S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106883.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10797, 702, 'Suits S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106884.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10798, 702, 'Suits S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106885.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10799, 702, 'Suits S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106886.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10800, 702, 'Suits S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106887.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10801, 702, 'Suits S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106888.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10802, 702, 'Suits S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106889.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10803, 702, 'Suits S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/106890.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10804, 702, 'Suits S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/106891.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10805, 702, 'Suits S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/106892.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10806, 702, 'Suits S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/106893.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10807, 702, 'Suits S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/106894.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10808, 703, 'Suits S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106895.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10809, 703, 'Suits S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106896.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10810, 703, 'Suits S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106897.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10811, 703, 'Suits S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106898.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10812, 703, 'Suits S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106899.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10813, 703, 'Suits S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106900.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10814, 703, 'Suits S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106901.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10815, 703, 'Suits S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106902.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10816, 703, 'Suits S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106903.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10817, 703, 'Suits S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106904.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10818, 703, 'Suits S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106905.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10819, 703, 'Suits S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/106906.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10820, 703, 'Suits S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/106907.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10821, 703, 'Suits S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/106908.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10822, 703, 'Suits S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/106909.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10823, 703, 'Suits S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/106910.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10824, 704, 'Suits S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106911.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10825, 704, 'Suits S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106912.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10826, 704, 'Suits S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106913.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10827, 704, 'Suits S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106914.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10828, 704, 'Suits S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106915.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10829, 704, 'Suits S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106916.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10830, 704, 'Suits S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106917.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10831, 704, 'Suits S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106918.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10832, 704, 'Suits S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106919.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10833, 704, 'Suits S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106920.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10834, 704, 'Suits S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106921.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10835, 704, 'Suits S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/106922.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10836, 704, 'Suits S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/106923.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10837, 704, 'Suits S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/106924.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10838, 704, 'Suits S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/106925.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10839, 704, 'Suits S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/106926.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10840, 705, 'Suits S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106927.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10841, 705, 'Suits S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106928.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10842, 705, 'Suits S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106929.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10843, 705, 'Suits S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106930.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10844, 705, 'Suits S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106931.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10845, 705, 'Suits S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106932.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10846, 705, 'Suits S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106933.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10847, 705, 'Suits S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106934.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10848, 705, 'Suits S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106935.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10849, 705, 'Suits S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106936.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10850, 705, 'Suits S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106937.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10851, 705, 'Suits S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/106938.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10852, 705, 'Suits S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/106939.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10853, 705, 'Suits S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/106940.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10854, 705, 'Suits S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/106941.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10855, 705, 'Suits S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/106942.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10856, 706, 'Suits S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106943.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10857, 706, 'Suits S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106944.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10858, 706, 'Suits S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106945.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10859, 706, 'Suits S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106946.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10860, 706, 'Suits S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106947.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10861, 706, 'Suits S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106948.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10862, 706, 'Suits S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106949.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10863, 706, 'Suits S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106950.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10864, 706, 'Suits S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106951.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10865, 706, 'Suits S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106952.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10866, 706, 'Suits S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106953.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10867, 706, 'Suits S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/106954.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10868, 706, 'Suits S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/106955.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10869, 706, 'Suits S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/106956.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10870, 706, 'Suits S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/106957.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10871, 706, 'Suits S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/106958.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10872, 707, 'Suits S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106959.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10873, 707, 'Suits S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106960.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10874, 707, 'Suits S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106961.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10875, 707, 'Suits S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106962.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10876, 707, 'Suits S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106963.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10877, 707, 'Suits S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106964.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10878, 707, 'Suits S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106965.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10879, 707, 'Suits S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106966.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10880, 707, 'Suits S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106967.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10881, 707, 'Suits S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106968.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10882, 707, 'Suits S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106969.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10883, 707, 'Suits S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/106970.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10884, 707, 'Suits S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/106971.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10885, 707, 'Suits S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/106972.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10886, 707, 'Suits S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/106973.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10887, 707, 'Suits S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/106974.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10888, 708, 'Suits S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106975.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10889, 708, 'Suits S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106976.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10890, 708, 'Suits S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106977.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10891, 708, 'Suits S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106978.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10892, 708, 'Suits S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106979.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10893, 708, 'Suits S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106980.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10894, 708, 'Suits S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106981.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10895, 708, 'Suits S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106982.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10896, 708, 'Suits S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106983.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10897, 708, 'Suits S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106984.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10898, 708, 'Suits S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106985.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10899, 708, 'Suits S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/106986.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10900, 708, 'Suits S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/106987.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10901, 708, 'Suits S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/106988.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10902, 708, 'Suits S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/106989.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10903, 708, 'Suits S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/106990.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10904, 709, 'Suits S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106991.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10905, 709, 'Suits S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106992.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10906, 709, 'Suits S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106993.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10907, 709, 'Suits S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106994.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10908, 709, 'Suits S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106995.mp4', 'http://gstaticontent.com/images/ubEYUaE1EOBnSgb1OteAeGJP1E5_big.jpg'),
(10909, 709, 'Suits S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106996.mp4', 'http://timg.bdta.pro/images/b2d2f80b4e57c8f25e4d7a32929d2819.jpg'),
(10910, 709, 'Suits S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106997.mp4', 'http://timg.bdta.pro/images/0a0b30eede723fb7f209e920003a1a3b.jpg'),
(10911, 709, 'Suits S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106998.mp4', 'http://timg.bdta.pro/images/ec252e87311d56c9f85a95f6067a3400.jpg'),
(10912, 709, 'Suits S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106999.mp4', 'http://timg.bdta.pro/images/cb7c1ad5b2f33bc0b028eef94cda4a96.jpg'),
(10913, 709, 'Suits S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107000.mp4', 'http://timg.bdta.pro/images/41ab5eab4f799c2340cc2c0a9adec6ad.jpg'),
(10914, 710, 'Supergirl S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163811.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10915, 710, 'Supergirl S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163812.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10916, 710, 'Supergirl S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163813.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10917, 710, 'Supergirl S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163814.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10918, 710, 'Supergirl S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163815.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10919, 710, 'Supergirl S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163816.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10920, 710, 'Supergirl S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163817.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10921, 710, 'Supergirl S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163818.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10922, 710, 'Supergirl S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163819.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10923, 710, 'Supergirl S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163820.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10924, 710, 'Supergirl S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163821.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10925, 710, 'Supergirl S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163822.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10926, 710, 'Supergirl S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163823.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10927, 710, 'Supergirl S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163824.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10928, 710, 'Supergirl S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163825.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10929, 710, 'Supergirl S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163826.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10930, 710, 'Supergirl S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163827.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10931, 710, 'Supergirl S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163828.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10932, 710, 'Supergirl S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163829.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10933, 710, 'Supergirl S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163830.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10934, 711, 'Supergirl S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163831.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10935, 711, 'Supergirl S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163832.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10936, 711, 'Supergirl S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163833.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10937, 711, 'Supergirl S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163834.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10938, 711, 'Supergirl S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163835.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10939, 711, 'Supergirl S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163836.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10940, 711, 'Supergirl S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163837.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10941, 711, 'Supergirl S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163838.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10942, 711, 'Supergirl S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163839.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10943, 711, 'Supergirl S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163840.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10944, 711, 'Supergirl S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163841.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10945, 711, 'Supergirl S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163842.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10946, 711, 'Supergirl S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163843.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10947, 711, 'Supergirl S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163844.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10948, 711, 'Supergirl S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163845.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10949, 711, 'Supergirl S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163846.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10950, 711, 'Supergirl S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163847.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10951, 711, 'Supergirl S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163848.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10952, 711, 'Supergirl S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163849.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10953, 711, 'Supergirl S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163850.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10954, 711, 'Supergirl S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/163851.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10955, 711, 'Supergirl S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/163852.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10956, 712, 'Supergirl S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163853.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10957, 712, 'Supergirl S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163854.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10958, 712, 'Supergirl S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163855.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10959, 712, 'Supergirl S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163856.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10960, 712, 'Supergirl S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163857.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10961, 712, 'Supergirl S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163858.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10962, 712, 'Supergirl S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163859.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10963, 712, 'Supergirl S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163860.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(10964, 712, 'Supergirl S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163861.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10965, 712, 'Supergirl S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163862.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10966, 712, 'Supergirl S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163863.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10967, 712, 'Supergirl S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163864.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10968, 712, 'Supergirl S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163865.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10969, 712, 'Supergirl S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163866.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10970, 712, 'Supergirl S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163867.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10971, 712, 'Supergirl S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163868.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10972, 712, 'Supergirl S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163869.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10973, 712, 'Supergirl S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163870.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10974, 712, 'Supergirl S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163871.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10975, 712, 'Supergirl S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163872.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10976, 712, 'Supergirl S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/163873.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10977, 712, 'Supergirl S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/163874.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10978, 712, 'Supergirl S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/163875.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10979, 713, 'Supergirl S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163876.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10980, 713, 'Supergirl S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163877.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10981, 713, 'Supergirl S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163878.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10982, 713, 'Supergirl S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163879.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10983, 713, 'Supergirl S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163880.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10984, 713, 'Supergirl S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163881.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10985, 713, 'Supergirl S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163882.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10986, 713, 'Supergirl S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163883.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10987, 713, 'Supergirl S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163884.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10988, 713, 'Supergirl S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163885.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10989, 713, 'Supergirl S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163886.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10990, 713, 'Supergirl S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163887.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10991, 713, 'Supergirl S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163888.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10992, 713, 'Supergirl S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163889.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10993, 713, 'Supergirl S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163890.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10994, 713, 'Supergirl S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163891.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10995, 713, 'Supergirl S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163892.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10996, 713, 'Supergirl S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163893.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10997, 713, 'Supergirl S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163894.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10998, 713, 'Supergirl S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163895.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(10999, 713, 'Supergirl S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/163896.mp4', 'http://timg.bdta.pro/images/7RSRDhh7y1WjLel1ILqArqDg2SR_small.jpg'),
(11000, 713, 'Supergirl S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/163897.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(11001, 714, 'Supergirl S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163898.mp4', 'http://timg.bdta.pro/images/742ae8f4c737e72ba590e5860ee9ee1a.jpg'),
(11002, 714, 'Supergirl S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163899.mp4', 'http://timg.bdta.pro/images/3bea0cace3f76f60c6d49510728a002a.jpg'),
(11003, 714, 'Supergirl S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163900.mp4', 'http://timg.bdta.pro/images/9f08b99badb2148f0ef0e740c6acb65f.jpg'),
(11004, 714, 'Supergirl S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163901.mp4', 'http://timg.bdta.pro/images/8caa375ad7b7fdaa48b4c1329b3d73a9.jpg'),
(11005, 714, 'Supergirl S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163902.mp4', 'http://timg.bdta.pro/images/a16dc691b5bbb3720906aaa906d5b648.jpg'),
(11006, 714, 'Supergirl S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163903.mp4', 'http://timg.bdta.pro/images/094bfb256592646935ae4e9d5145c0fd.jpg'),
(11007, 714, 'Supergirl S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163904.mp4', 'http://timg.bdta.pro/images/20c863d58cedd9feb412dd2d988e04cc.jpg'),
(11008, 714, 'Supergirl S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163905.mp4', 'http://timg.bdta.pro/images/a7ff5372861f23b9fb67d9c930233a0a.jpg'),
(11009, 714, 'Supergirl S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163906.mp4', 'http://timg.bdta.pro/images/0e02f24bb0a1d57239eca049e9d91466.jpg'),
(11010, 714, 'Supergirl S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163907.mp4', 'http://timg.bdta.pro/images/d730fb63288c39982ee8bdfcb4626c12.jpg'),
(11011, 714, 'Supergirl S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163908.mp4', 'http://timg.bdta.pro/images/8ea9bdbcf6852e092086db919694069d.jpg'),
(11012, 714, 'Supergirl S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163909.mp4', 'http://timg.bdta.pro/images/bc38df6a8012cc4ef74a8b5a3c3b7417.jpg'),
(11013, 714, 'Supergirl S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163910.mp4', 'http://timg.bdta.pro/images/88a5d6be961b34ef8dd93c8c56ad39f2.jpg'),
(11014, 714, 'Supergirl S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163911.mp4', 'http://timg.bdta.pro/images/21105ab90cf38b36827ce762cc920a1f.jpg'),
(11015, 714, 'Supergirl S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163912.mp4', 'http://timg.bdta.pro/images/1d8c20522a4773c28d1a6315fe71afee.jpg'),
(11016, 714, 'Supergirl S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163913.mp4', 'http://timg.bdta.pro/images/846abb57dfc1e49b044d1a512b566636.jpg'),
(11017, 714, 'Supergirl S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163914.mp4', 'http://timg.bdta.pro/images/657000382d27f5fbc49a37a482e7e38a.jpg'),
(11018, 714, 'Supergirl S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163915.mp4', 'http://timg.bdta.pro/images/32a966724dabddbc55f7a3a44399059e.jpg'),
(11019, 714, 'Supergirl S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163916.mp4', 'http://timg.bdta.pro/images/4fa32ba70a83ce12d2be32e7add87978.jpg'),
(11020, 715, 'Supergirl S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163917.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(11021, 715, 'Supergirl S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163918.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(11022, 715, 'Supergirl S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163919.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(11023, 715, 'Supergirl S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163920.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(11024, 715, 'Supergirl S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163921.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(11025, 715, 'Supergirl S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163922.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(11026, 715, 'Supergirl S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163923.mp4', 'http://gstaticontent.com/images/vqBsgL9nd2v04ZvCqPzwtckDdFD_big.jpg'),
(11027, 715, 'Supergirl S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163924.mp4', 'http://timg.bdta.pro/images/35c3e342d7438610f720cda3f4e88a6d.jpg'),
(11028, 715, 'Supergirl S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163925.mp4', 'http://image.tmdb.org/t/p/w1280/vQSk2BkbLiziX0ihTSPUmtLniQS.jpg'),
(11029, 715, 'Supergirl S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163926.mp4', 'http://image.tmdb.org/t/p/w1280/b1LHzY0vKQHQD9hVrMu7sAFQ6et.jpg'),
(11030, 715, 'Supergirl S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163927.mp4', 'http://image.tmdb.org/t/p/w1280/li3XmQJ9Q8EMHdEBtUtmnyHkFK1.jpg'),
(11031, 715, 'Supergirl S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163928.mp4', 'http://image.tmdb.org/t/p/w1280/IxWYRPtgwNLMNQfdGDFBADt2F8.jpg'),
(11032, 715, 'Supergirl S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163929.mp4', 'http://image.tmdb.org/t/p/w1280/kJBhPzOhDrYBtZA4mSppEzu4AUl.jpg'),
(11033, 715, 'Supergirl S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wVStvzrS4NLAi4gXZ65gyIkOq2M.jpg'),
(11034, 715, 'Supergirl S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wxwX1gSpb9Zuh4S2ZOPvsD4lB3S.jpg'),
(11035, 715, 'Supergirl S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z2t1g07vTnLY5iXDcutx7GfnJ48.jpg'),
(11036, 715, 'Supergirl S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zMSmBbkf7OhrA9KY72VJ6llojW1.jpg'),
(11037, 715, 'Supergirl S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tGHYpK3He3ptcXAwspFZ2IsLnzZ.jpg'),
(11038, 715, 'Supergirl S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lHNQseJPoPTh6zBORJZKSc6CaCF.jpg'),
(11039, 715, 'Supergirl S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/101CXw85alYtGKtqSWEGgxorsuu.jpg'),
(11040, 716, 'Sobrenatural S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212341.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11041, 716, 'Sobrenatural S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212342.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11042, 716, 'Sobrenatural S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212343.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11043, 716, 'Sobrenatural S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212344.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11044, 716, 'Sobrenatural S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212345.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11045, 716, 'Sobrenatural S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212346.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11046, 716, 'Sobrenatural S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212347.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11047, 716, 'Sobrenatural S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212348.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11048, 716, 'Sobrenatural S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212349.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11049, 716, 'Sobrenatural S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212350.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11050, 716, 'Sobrenatural S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212351.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11051, 716, 'Sobrenatural S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212352.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11052, 716, 'Sobrenatural S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212353.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11053, 716, 'Sobrenatural S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212354.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11054, 716, 'Sobrenatural S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212355.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11055, 716, 'Sobrenatural S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212356.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11056, 716, 'Sobrenatural S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212357.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11057, 716, 'Sobrenatural S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212358.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11058, 716, 'Sobrenatural S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212359.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11059, 716, 'Sobrenatural S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212360.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11060, 716, 'Sobrenatural S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212361.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11061, 716, 'Sobrenatural S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212362.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11062, 717, 'Sobrenatural S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212363.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11063, 717, 'Sobrenatural S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212364.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11064, 717, 'Sobrenatural S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212365.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11065, 717, 'Sobrenatural S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212366.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11066, 717, 'Sobrenatural S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212367.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11067, 717, 'Sobrenatural S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212368.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11068, 717, 'Sobrenatural S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212369.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11069, 717, 'Sobrenatural S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212370.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11070, 717, 'Sobrenatural S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212371.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11071, 717, 'Sobrenatural S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212372.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11072, 717, 'Sobrenatural S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212373.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11073, 717, 'Sobrenatural S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212374.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11074, 717, 'Sobrenatural S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212375.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11075, 717, 'Sobrenatural S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212376.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11076, 717, 'Sobrenatural S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212377.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11077, 717, 'Sobrenatural S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212378.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11078, 717, 'Sobrenatural S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212379.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11079, 717, 'Sobrenatural S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212380.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11080, 717, 'Sobrenatural S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212381.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11081, 717, 'Sobrenatural S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212382.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11082, 717, 'Sobrenatural S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212383.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11083, 717, 'Sobrenatural S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212384.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11084, 718, 'Sobrenatural S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212385.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11085, 718, 'Sobrenatural S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212386.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11086, 718, 'Sobrenatural S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212387.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11087, 718, 'Sobrenatural S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212388.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11088, 718, 'Sobrenatural S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212389.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11089, 718, 'Sobrenatural S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212390.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11090, 718, 'Sobrenatural S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212391.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11091, 718, 'Sobrenatural S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212392.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11092, 718, 'Sobrenatural S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212393.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11093, 718, 'Sobrenatural S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212394.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11094, 718, 'Sobrenatural S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212395.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11095, 718, 'Sobrenatural S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212396.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11096, 718, 'Sobrenatural S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212397.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11097, 718, 'Sobrenatural S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212398.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11098, 718, 'Sobrenatural S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212399.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11099, 718, 'Sobrenatural S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212400.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11100, 719, 'Sobrenatural S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212401.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11101, 719, 'Sobrenatural S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212402.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11102, 719, 'Sobrenatural S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212403.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11103, 719, 'Sobrenatural S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212404.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11104, 719, 'Sobrenatural S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212405.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11105, 719, 'Sobrenatural S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212406.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11106, 719, 'Sobrenatural S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212407.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11107, 719, 'Sobrenatural S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212408.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11108, 719, 'Sobrenatural S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212409.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11109, 719, 'Sobrenatural S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212410.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11110, 719, 'Sobrenatural S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212411.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11111, 719, 'Sobrenatural S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212412.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11112, 719, 'Sobrenatural S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212413.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11113, 719, 'Sobrenatural S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212414.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11114, 719, 'Sobrenatural S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212415.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11115, 719, 'Sobrenatural S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212416.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11116, 719, 'Sobrenatural S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212417.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11117, 719, 'Sobrenatural S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212418.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11118, 719, 'Sobrenatural S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212419.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11119, 719, 'Sobrenatural S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212420.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11120, 719, 'Sobrenatural S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212421.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11121, 719, 'Sobrenatural S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212422.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11122, 720, 'Sobrenatural S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212423.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11123, 720, 'Sobrenatural S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212424.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11124, 720, 'Sobrenatural S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212425.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11125, 720, 'Sobrenatural S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212426.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11126, 720, 'Sobrenatural S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212427.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11127, 720, 'Sobrenatural S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212428.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11128, 720, 'Sobrenatural S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212429.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11129, 720, 'Sobrenatural S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212430.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11130, 720, 'Sobrenatural S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212431.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11131, 720, 'Sobrenatural S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212432.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11132, 720, 'Sobrenatural S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212433.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11133, 720, 'Sobrenatural S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212434.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11134, 720, 'Sobrenatural S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212435.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11135, 720, 'Sobrenatural S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212436.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11136, 720, 'Sobrenatural S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212437.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11137, 720, 'Sobrenatural S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212438.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11138, 720, 'Sobrenatural S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212439.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11139, 720, 'Sobrenatural S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212440.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11140, 720, 'Sobrenatural S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212441.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11141, 720, 'Sobrenatural S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212442.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11142, 720, 'Sobrenatural S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212443.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11143, 720, 'Sobrenatural S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212444.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11144, 721, 'Sobrenatural S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212445.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11145, 721, 'Sobrenatural S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212446.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11146, 721, 'Sobrenatural S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212447.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11147, 721, 'Sobrenatural S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212448.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11148, 721, 'Sobrenatural S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212449.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11149, 721, 'Sobrenatural S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212450.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11150, 721, 'Sobrenatural S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212451.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11151, 721, 'Sobrenatural S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212452.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11152, 721, 'Sobrenatural S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212453.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11153, 721, 'Sobrenatural S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212454.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11154, 721, 'Sobrenatural S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212455.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11155, 721, 'Sobrenatural S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212456.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11156, 721, 'Sobrenatural S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212457.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11157, 721, 'Sobrenatural S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212458.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11158, 721, 'Sobrenatural S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212459.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11159, 721, 'Sobrenatural S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212460.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11160, 721, 'Sobrenatural S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212461.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11161, 721, 'Sobrenatural S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212462.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11162, 721, 'Sobrenatural S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212463.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11163, 721, 'Sobrenatural S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212464.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11164, 721, 'Sobrenatural S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212465.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11165, 721, 'Sobrenatural S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212466.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11166, 722, 'Sobrenatural S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212467.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11167, 722, 'Sobrenatural S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212468.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11168, 722, 'Sobrenatural S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212469.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11169, 722, 'Sobrenatural S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212470.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11170, 722, 'Sobrenatural S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212471.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11171, 722, 'Sobrenatural S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212472.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11172, 722, 'Sobrenatural S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212473.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11173, 722, 'Sobrenatural S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212474.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11174, 722, 'Sobrenatural S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212475.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11175, 722, 'Sobrenatural S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212476.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11176, 722, 'Sobrenatural S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212477.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11177, 722, 'Sobrenatural S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212478.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11178, 722, 'Sobrenatural S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212479.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11179, 722, 'Sobrenatural S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212480.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11180, 722, 'Sobrenatural S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212481.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11181, 722, 'Sobrenatural S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212482.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11182, 722, 'Sobrenatural S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212483.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11183, 722, 'Sobrenatural S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212484.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11184, 722, 'Sobrenatural S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212485.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11185, 722, 'Sobrenatural S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212486.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11186, 722, 'Sobrenatural S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212487.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11187, 722, 'Sobrenatural S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212488.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11188, 722, 'Sobrenatural S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/212489.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11189, 723, 'Sobrenatural S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212490.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11190, 723, 'Sobrenatural S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212491.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11191, 723, 'Sobrenatural S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212492.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11192, 723, 'Sobrenatural S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212493.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11193, 723, 'Sobrenatural S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212494.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11194, 723, 'Sobrenatural S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212495.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11195, 723, 'Sobrenatural S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212496.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11196, 723, 'Sobrenatural S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212497.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11197, 723, 'Sobrenatural S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212498.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11198, 723, 'Sobrenatural S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212499.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11199, 723, 'Sobrenatural S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212500.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11200, 723, 'Sobrenatural S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212501.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11201, 723, 'Sobrenatural S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212502.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11202, 723, 'Sobrenatural S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212503.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11203, 723, 'Sobrenatural S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212504.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11204, 723, 'Sobrenatural S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212505.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11205, 723, 'Sobrenatural S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212506.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11206, 723, 'Sobrenatural S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212507.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11207, 723, 'Sobrenatural S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212508.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11208, 723, 'Sobrenatural S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212509.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11209, 723, 'Sobrenatural S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212510.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11210, 723, 'Sobrenatural S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212511.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11211, 723, 'Sobrenatural S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/212512.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11212, 724, 'Sobrenatural S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212513.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11213, 724, 'Sobrenatural S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212514.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11214, 724, 'Sobrenatural S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212515.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11215, 724, 'Sobrenatural S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212516.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11216, 724, 'Sobrenatural S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212517.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11217, 724, 'Sobrenatural S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212518.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11218, 724, 'Sobrenatural S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212519.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11219, 724, 'Sobrenatural S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212520.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11220, 724, 'Sobrenatural S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212521.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11221, 724, 'Sobrenatural S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212522.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11222, 724, 'Sobrenatural S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212523.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11223, 724, 'Sobrenatural S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212524.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11224, 724, 'Sobrenatural S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212525.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11225, 724, 'Sobrenatural S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212526.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11226, 724, 'Sobrenatural S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212527.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11227, 724, 'Sobrenatural S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212528.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11228, 724, 'Sobrenatural S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212529.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11229, 724, 'Sobrenatural S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212530.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11230, 724, 'Sobrenatural S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212531.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11231, 724, 'Sobrenatural S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212532.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11232, 724, 'Sobrenatural S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212533.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11233, 724, 'Sobrenatural S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212534.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11234, 724, 'Sobrenatural S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/212535.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11235, 725, 'Sobrenatural S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212536.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11236, 725, 'Sobrenatural S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212537.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11237, 725, 'Sobrenatural S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212538.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11238, 725, 'Sobrenatural S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212539.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11239, 725, 'Sobrenatural S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212540.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11240, 725, 'Sobrenatural S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212541.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(11241, 725, 'Sobrenatural S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212542.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11242, 725, 'Sobrenatural S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212543.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11243, 725, 'Sobrenatural S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212544.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11244, 725, 'Sobrenatural S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212545.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11245, 725, 'Sobrenatural S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212546.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11246, 725, 'Sobrenatural S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212547.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11247, 725, 'Sobrenatural S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212548.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11248, 725, 'Sobrenatural S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212549.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11249, 725, 'Sobrenatural S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212550.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11250, 725, 'Sobrenatural S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212551.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11251, 725, 'Sobrenatural S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212552.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11252, 725, 'Sobrenatural S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212553.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11253, 725, 'Sobrenatural S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212554.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11254, 725, 'Sobrenatural S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212555.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11255, 725, 'Sobrenatural S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212556.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11256, 725, 'Sobrenatural S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212557.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11257, 725, 'Sobrenatural S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/212558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1rNqxT80PTUDa024jsZS00jITey.jpg'),
(11258, 726, 'Sobrenatural S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/et4wg0U4ZcXdCTVTJH1KLinjOzN.jpg'),
(11259, 726, 'Sobrenatural S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5E2iqdvFEmQSWggXym0rj4bs9M.jpg'),
(11260, 726, 'Sobrenatural S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6tjGWIxQDLmTj99asNWkApCz65g.jpg'),
(11261, 726, 'Sobrenatural S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yfScje9w75eG2sxuMOMOhYyMw0I.jpg'),
(11262, 726, 'Sobrenatural S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mwkHyNrfZzEixxdhvuACkUspcws.jpg'),
(11263, 726, 'Sobrenatural S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZPedFKFg29AK2VLIzDw1z68zXb.jpg'),
(11264, 726, 'Sobrenatural S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n9rzWIWj8vn0dQL0nQK7niEIu6v.jpg'),
(11265, 726, 'Sobrenatural S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dBvmYEJ1qbWLjyPEBmhrN0xu1bN.jpg'),
(11266, 726, 'Sobrenatural S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtpfPDXAnWh4pnUQAMsp14MtSMX.jpg'),
(11267, 726, 'Sobrenatural S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyp4eygcDNzzVILu0kJxYM3ylT.jpg'),
(11268, 726, 'Sobrenatural S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v6IjY4UObxlQ4QdaxAqgdGhJTyE.jpg'),
(11269, 726, 'Sobrenatural S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sLkl16kyH6G8TJzZdGdR1VCQpse.jpg'),
(11270, 726, 'Sobrenatural S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bNozQn6R651dOQiELYz1ew3TPgN.jpg'),
(11271, 726, 'Sobrenatural S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h2W5doNhVev2bsioRR63YegGpc3.jpg'),
(11272, 726, 'Sobrenatural S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dtGY55mqofeLWOULzOI06UCjeDQ.jpg'),
(11273, 726, 'Sobrenatural S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVZDBsDYWuXy9yQlUwOeZk6kOPP.jpg'),
(11274, 726, 'Sobrenatural S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cn10gcZW0PRnkgx7HkEYlRr6Js1.jpg'),
(11275, 726, 'Sobrenatural S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iazKVzJUbnRLbubB7LdZN9G1MQZ.jpg'),
(11276, 726, 'Sobrenatural S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zFOEfOJ7E9J99kX8XC6doXtBVRr.jpg'),
(11277, 726, 'Sobrenatural S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7y7YnAQoE2COuYPCwKAbclhA6cO.jpg'),
(11278, 726, 'Sobrenatural S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3zzzre0zHqcsSogECSJEUbVUJ4.jpg'),
(11279, 726, 'Sobrenatural S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g12CYzsU4YTgpfONU7NnVd6jLvO.jpg'),
(11280, 726, 'Sobrenatural S11 E23', 'http://sinalprivado.info:80/series/1533784/1533784/212581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z56RwqT5AUS6nfqNVlrhffRl5wa.jpg'),
(11281, 727, 'Sobrenatural S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kkC090DloV9Gt1UL5e9VAoT20hG.jpg'),
(11282, 727, 'Sobrenatural S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSjm8KvK3UUU33hqKU8570AvaOW.jpg'),
(11283, 727, 'Sobrenatural S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVBD4ptxZjnS0d4g4JO3NVMZarL.jpg'),
(11284, 727, 'Sobrenatural S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b3yzp8TKrSWnZv4IWmJTXQXFFpY.jpg'),
(11285, 727, 'Sobrenatural S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4n1aCD9MeOl6mxp24glAFhubMDt.jpg'),
(11286, 727, 'Sobrenatural S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8LhfYudv1zgr04ziFz3rX3PM8W.jpg'),
(11287, 727, 'Sobrenatural S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/20VAXuvcwKMgRxhNYohAHpupyXf.jpg'),
(11288, 727, 'Sobrenatural S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nMaVXiiGoNOgjIGfKrkzoKfIiXZ.jpg'),
(11289, 727, 'Sobrenatural S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Qc4xpudV5Q9c976GfFYXknKBD0.jpg'),
(11290, 727, 'Sobrenatural S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FX6ejptbTyxGpfK1GWI1vhj2WS.jpg'),
(11291, 727, 'Sobrenatural S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mb9y3B7rNs9BJZ6sE4NcG2XO8Gn.jpg'),
(11292, 727, 'Sobrenatural S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gnrPC2RNDvopoOwQClkwA8KvTtm.jpg'),
(11293, 727, 'Sobrenatural S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iad32u3l7D3OLXUg5XzwVJpUL9s.jpg'),
(11294, 727, 'Sobrenatural S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ympOe0aTXssXY1CxZHveEF1f7SK.jpg'),
(11295, 727, 'Sobrenatural S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8hyHbg3PAtuzkv5DpO6EMoQlnV0.jpg'),
(11296, 727, 'Sobrenatural S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u9oGI4uldjvJVtnPhqu0Kt2FNJu.jpg'),
(11297, 727, 'Sobrenatural S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/adf1CAcUnvo2gikRtswORgivIQh.jpg'),
(11298, 727, 'Sobrenatural S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dP7g38SwQRKqHATLmXIYH0RVue.jpg'),
(11299, 727, 'Sobrenatural S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hzPCbrmtklGRbVIBn584cCJlZuy.jpg'),
(11300, 727, 'Sobrenatural S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/28MfSp7aJs1PsesJKY7u3Yz9qY6.jpg'),
(11301, 727, 'Sobrenatural S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cSRKU8VGm5qXw5cUHHmSt7y1f5u.jpg'),
(11302, 727, 'Sobrenatural S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/10KczbZQDLVcYBulIKHKIuZHsw8.jpg'),
(11303, 727, 'Sobrenatural S12 E23', 'http://sinalprivado.info:80/series/1533784/1533784/212604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uxmhXLFOo1LfSo9UIk0tmp7dPlw.jpg'),
(11304, 728, 'Sobrenatural S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tg6KW03bMd4pbG2xKtDXoig6eoe.jpg'),
(11305, 728, 'Sobrenatural S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rXYi5BuU8CeYcN3cABJupUnFI8h.jpg'),
(11306, 728, 'Sobrenatural S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2dtmuhfPKL0Most3hDKPNYTOTx.jpg'),
(11307, 728, 'Sobrenatural S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l4Cbi7sQNzA9uWyTVpY1gPJxESt.jpg'),
(11308, 728, 'Sobrenatural S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iA4IsmX6sThD82893as6bDnlHZA.jpg'),
(11309, 728, 'Sobrenatural S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/atYbcuhfAv9sYpsFXJXlkb2u3Wz.jpg'),
(11310, 728, 'Sobrenatural S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/NG2i00MWSlri2d2ZMSze6rV4Ec.jpg'),
(11311, 728, 'Sobrenatural S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7T2uQmUMnKCZ3BTcehRNr6JlWah.jpg'),
(11312, 728, 'Sobrenatural S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yxQ2wZrzkiqdaHvNMHwItrrvVdo.jpg'),
(11313, 728, 'Sobrenatural S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uvwsgMxFdeP9KTOnhMMujf9daK3.jpg'),
(11314, 728, 'Sobrenatural S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a48yKCJXcqECP1JermfFMZTwnH7.jpg'),
(11315, 728, 'Sobrenatural S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cvKnyPE0nOdvmsfoocmijknvaRV.jpg'),
(11316, 728, 'Sobrenatural S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oTlyAcBl3TLgXdwbSbElcPIlTdm.jpg'),
(11317, 728, 'Sobrenatural S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kCnrpmpB7oVNEquGmkkksLxuvT7.jpg'),
(11318, 728, 'Sobrenatural S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e7Rf351ZWiRqcBjAe47txA6jkLM.jpg'),
(11319, 728, 'Sobrenatural S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tw9NRq3ZB0lLhCgo5DvInTb7UWK.jpg'),
(11320, 728, 'Sobrenatural S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3AKhafdiKPZCg7QvlaVjMT0KpvU.jpg'),
(11321, 728, 'Sobrenatural S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iWrHjid38fV1ebrXdQK8j4L2xOY.jpg'),
(11322, 728, 'Sobrenatural S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13eoBfvtTpu2a0mvkhMxdXaBMzD.jpg'),
(11323, 728, 'Sobrenatural S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AfkiTPNFYZgsnENUpRIIvFLmuPS.jpg'),
(11324, 728, 'Sobrenatural S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ASsAXVIFtFJ9Rjk03kuViVkI7N.jpg'),
(11325, 728, 'Sobrenatural S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dm4L93LmaZn544sFRP0bv5KTmdX.jpg'),
(11326, 728, 'Sobrenatural S13 E23', 'http://sinalprivado.info:80/series/1533784/1533784/212627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBQaHEIXeGqJB7STG1arnrhRoFx.jpg'),
(11327, 729, 'Sobrenatural S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvaNg9xftwoSeIbYgLCHpS5zMkO.jpg'),
(11328, 729, 'Sobrenatural S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/luJZctaTqSmcFAO4rn44X5cGkmL.jpg'),
(11329, 729, 'Sobrenatural S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6c9xhU2rrUcpq1UAzPghSt5BU7E.jpg'),
(11330, 729, 'Sobrenatural S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/21KM2qFdjK3f06TKhbtZHZdwCnV.jpg'),
(11331, 729, 'Sobrenatural S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v2k2tG7UxfC6YVJchnV1yzDwiUa.jpg'),
(11332, 729, 'Sobrenatural S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8UmHVrMYMECcR3KkxfjyvGoFnr7.jpg'),
(11333, 729, 'Sobrenatural S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8uqoHeWFl2tLGg7xTsyPvD1BUnQ.jpg'),
(11334, 729, 'Sobrenatural S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kqFjHrEMk9bd0EUM18WhMDxCyCY.jpg'),
(11335, 729, 'Sobrenatural S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTN6TgJRprjzkF1z9eoDmpPqAZd.jpg'),
(11336, 729, 'Sobrenatural S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eyiuWNSpHFhk5f3sq4Lb9Kalzvm.jpg'),
(11337, 729, 'Sobrenatural S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0rKwKuz0boMVjRkQPmtT4fgYah.jpg'),
(11338, 729, 'Sobrenatural S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9jEB0ZLDpQAi8CxSm227WR6Vgyh.jpg'),
(11339, 729, 'Sobrenatural S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bFEYwpF3ErAYu3fbol9b1Oekawm.jpg'),
(11340, 729, 'Sobrenatural S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fP3fai8vEfCnHtyZqDuFutGRrhf.jpg'),
(11341, 729, 'Sobrenatural S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24HLpGuTzZ0QMFMWf3XpM7G6HA9.jpg'),
(11342, 729, 'Sobrenatural S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2b2ZykCAvOuI5fshy1XUR4pCca8.jpg'),
(11343, 729, 'Sobrenatural S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7cosSom3XC8jYPKV1x4RUthLmQ.jpg'),
(11344, 729, 'Sobrenatural S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/90GLDB79EifULn0WhGQk2JK25nS.jpg'),
(11345, 729, 'Sobrenatural S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ma6XhWpDHDmD41LeU7eo5pQnf8r.jpg'),
(11346, 729, 'Sobrenatural S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aWZZHwuaRRD6DFyeIYvKZPC5V5.jpg'),
(11347, 730, 'Sobrenatural S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gOdsgcvRqK11e0c9eL3ILEke1pn.jpg'),
(11348, 730, 'Sobrenatural S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eJS5KPXfa0vuaSLXNV9wnQxQMQJ.jpg'),
(11349, 730, 'Sobrenatural S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9OOdt8aGA2G5UNJWc2j5HhzqjMo.jpg'),
(11350, 730, 'Sobrenatural S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zukePbvG2FUgnPEvTGcIVM4FKWc.jpg'),
(11351, 730, 'Sobrenatural S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vDocJPyJIfIhJzGCgXlkhQCZGur.jpg'),
(11352, 730, 'Sobrenatural S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1Um35J4ml4L1KLCsOnOYOSttQe.jpg'),
(11353, 730, 'Sobrenatural S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3A47t2hckQe0RB4PnKVHLRBYOaN.jpg'),
(11354, 730, 'Sobrenatural S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kClbqTOPyNQer5FIblkPoHcI5aJ.jpg'),
(11355, 730, 'Sobrenatural S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cfCv6navhRZQBQPuEY83DRQJfo8.jpg'),
(11356, 730, 'Sobrenatural S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kAxxgHbnfAavbZaJIkB6Rb4tDu3.jpg'),
(11357, 730, 'Sobrenatural S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4BN8JV7kn6b7GD2OqI2LIOzgGEV.jpg'),
(11358, 730, 'Sobrenatural S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AtZkIR0Azy6klwJleZ7ugX7xDTG.jpg'),
(11359, 730, 'Sobrenatural S15 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2WQwdohqH9h6Qr94XMfo5HhT5QQ.jpg'),
(11360, 730, 'Sobrenatural S15 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7PaAID5SU5mBuNnMg88m845YXdp.jpg'),
(11361, 730, 'Sobrenatural S15 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFkF4KkPsgUb72NcuV7eSZgGmRM.jpg'),
(11362, 730, 'Sobrenatural S15 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2rZMzoDJlbnGRhw1WMVQUgvoYF.jpg'),
(11363, 730, 'Sobrenatural S15 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFynBN8uxKfYKW2aoRqVhPNEp5p.jpg'),
(11364, 730, 'Sobrenatural S15 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sdBnjJxoitWamhnrjstuXx0R3Mb.jpg'),
(11365, 730, 'Sobrenatural S15 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wUuwkiLKd2peA1YLfKMW4EifCTd.jpg'),
(11366, 730, 'Sobrenatural S15 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/frpiXDldkh3P2VtNPxetsRawbpm.jpg'),
(11367, 730, 'Sobrenatural S15 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212668.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(11368, 731, 'S.W.A.T.: Força de Intervenção S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241273.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11369, 731, 'S.W.A.T.: Força de Intervenção S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241274.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11370, 731, 'S.W.A.T.: Força de Intervenção S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241275.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11371, 731, 'S.W.A.T.: Força de Intervenção S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241276.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11372, 731, 'S.W.A.T.: Força de Intervenção S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241277.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11373, 731, 'S.W.A.T.: Força de Intervenção S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241278.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11374, 731, 'S.W.A.T.: Força de Intervenção S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241279.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11375, 731, 'S.W.A.T.: Força de Intervenção S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241280.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11376, 731, 'S.W.A.T.: Força de Intervenção S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241281.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11377, 731, 'S.W.A.T.: Força de Intervenção S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241282.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11378, 731, 'S.W.A.T.: Força de Intervenção S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241283.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11379, 731, 'S.W.A.T.: Força de Intervenção S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241284.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11380, 731, 'S.W.A.T.: Força de Intervenção S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241285.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11381, 731, 'S.W.A.T.: Força de Intervenção S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241286.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11382, 731, 'S.W.A.T.: Força de Intervenção S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241287.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11383, 731, 'S.W.A.T.: Força de Intervenção S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/241288.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11384, 731, 'S.W.A.T.: Força de Intervenção S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/241289.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11385, 731, 'S.W.A.T.: Força de Intervenção S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/241290.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11386, 731, 'S.W.A.T.: Força de Intervenção S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/241291.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11387, 731, 'S.W.A.T.: Força de Intervenção S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/241292.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11388, 731, 'S.W.A.T.: Força de Intervenção S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/241293.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11389, 731, 'S.W.A.T.: Força de Intervenção S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/241294.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11390, 732, 'S.W.A.T.: Força de Intervenção S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241295.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11391, 732, 'S.W.A.T.: Força de Intervenção S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241296.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11392, 732, 'S.W.A.T.: Força de Intervenção S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241297.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11393, 732, 'S.W.A.T.: Força de Intervenção S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241298.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11394, 732, 'S.W.A.T.: Força de Intervenção S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241299.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11395, 732, 'S.W.A.T.: Força de Intervenção S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241300.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11396, 732, 'S.W.A.T.: Força de Intervenção S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241301.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11397, 732, 'S.W.A.T.: Força de Intervenção S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241302.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11398, 732, 'S.W.A.T.: Força de Intervenção S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241303.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11399, 732, 'S.W.A.T.: Força de Intervenção S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241304.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11400, 732, 'S.W.A.T.: Força de Intervenção S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241305.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11401, 732, 'S.W.A.T.: Força de Intervenção S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241306.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11402, 732, 'S.W.A.T.: Força de Intervenção S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241307.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11403, 732, 'S.W.A.T.: Força de Intervenção S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241308.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11404, 732, 'S.W.A.T.: Força de Intervenção S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241309.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11405, 732, 'S.W.A.T.: Força de Intervenção S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/241310.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11406, 732, 'S.W.A.T.: Força de Intervenção S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/241311.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11407, 732, 'S.W.A.T.: Força de Intervenção S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/241312.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11408, 732, 'S.W.A.T.: Força de Intervenção S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/241313.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11409, 732, 'S.W.A.T.: Força de Intervenção S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/241314.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11410, 732, 'S.W.A.T.: Força de Intervenção S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/241315.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11411, 732, 'S.W.A.T.: Força de Intervenção S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/241316.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11412, 732, 'S.W.A.T.: Força de Intervenção S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/241317.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11413, 733, 'S.W.A.T.: Força de Intervenção S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241318.mp4', 'http://timg.bdta.pro/images/a66e787103caea3c8149568fdf36053d.jpg'),
(11414, 733, 'S.W.A.T.: Força de Intervenção S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241319.mp4', 'http://timg.bdta.pro/images/fe386a21cff984cff9563b70af7968cf.jpg'),
(11415, 733, 'S.W.A.T.: Força de Intervenção S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241320.mp4', 'http://timg.bdta.pro/images/691afc03832e5c018445ac95a0d414a0.jpg'),
(11416, 733, 'S.W.A.T.: Força de Intervenção S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241321.mp4', 'http://timg.bdta.pro/images/d8c6891909ee63fc945bb2ccb8cd8abe.jpg'),
(11417, 733, 'S.W.A.T.: Força de Intervenção S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241322.mp4', 'http://timg.bdta.pro/images/1c469f58a57cc6fae5745c31d8b40ce4.jpg'),
(11418, 733, 'S.W.A.T.: Força de Intervenção S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241323.mp4', 'http://timg.bdta.pro/images/6d0d19d84fc6275562fa6c7e6732bc3a.jpg'),
(11419, 733, 'S.W.A.T.: Força de Intervenção S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241324.mp4', 'http://timg.bdta.pro/images/f9809e49a0ee63beeb0b9710e1c44269.jpg'),
(11420, 733, 'S.W.A.T.: Força de Intervenção S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241325.mp4', 'http://timg.bdta.pro/images/f085eb1ce70a2716c878cfd5fe5fa5e5.jpg'),
(11421, 733, 'S.W.A.T.: Força de Intervenção S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241326.mp4', 'http://timg.bdta.pro/images/a2de5f019429e26c5b3e38b5b394d557.jpg'),
(11422, 733, 'S.W.A.T.: Força de Intervenção S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241327.mp4', 'http://timg.bdta.pro/images/2b53ac22481df22b9d6d9ef36c1d903e.jpg'),
(11423, 733, 'S.W.A.T.: Força de Intervenção S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241328.mp4', 'http://timg.bdta.pro/images/5a30a210e44a770d1d4871c15262e677.jpg'),
(11424, 733, 'S.W.A.T.: Força de Intervenção S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241329.mp4', 'http://timg.bdta.pro/images/c23185269e92afc85eac2d040e5dce5a.jpg'),
(11425, 733, 'S.W.A.T.: Força de Intervenção S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241330.mp4', 'http://timg.bdta.pro/images/69e1f4c4af53cb48555795a70c5ba060.jpg'),
(11426, 733, 'S.W.A.T.: Força de Intervenção S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241331.mp4', 'http://timg.bdta.pro/images/b983d904f2d203bb0567b072b8868afb.jpg'),
(11427, 733, 'S.W.A.T.: Força de Intervenção S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241332.mp4', 'http://timg.bdta.pro/images/b25e1c318bac531d40df0359b4272d20.jpg'),
(11428, 733, 'S.W.A.T.: Força de Intervenção S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/241333.mp4', 'http://timg.bdta.pro/images/68131d76ce60bcf664b21fabef9355cb.jpg'),
(11429, 733, 'S.W.A.T.: Força de Intervenção S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/241334.mp4', 'http://timg.bdta.pro/images/b4903f1134ccaaaa16ba90c6e9567e8c.jpg'),
(11430, 733, 'S.W.A.T.: Força de Intervenção S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/241335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aOcoUfEdXMpRZ3I651zbotxAyX5.jpg'),
(11431, 733, 'S.W.A.T.: Força de Intervenção S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/241336.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11432, 733, 'S.W.A.T.: Força de Intervenção S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/241337.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11433, 733, 'S.W.A.T.: Força de Intervenção S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/241338.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11434, 734, 'S.W.A.T.: Força de Intervenção S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241339.mp4', 'http://timg.bdta.pro/images/861f583fa7de236ba168cc1feee4da35.jpg'),
(11435, 734, 'S.W.A.T.: Força de Intervenção S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241340.mp4', 'http://timg.bdta.pro/images/7c48c5914d6ec7dbc5b6c58a6e89de7b.jpg'),
(11436, 734, 'S.W.A.T.: Força de Intervenção S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241341.mp4', 'http://timg.bdta.pro/images/fb3ff5926e4963bf937f12c8e5dfa48e.jpg'),
(11437, 734, 'S.W.A.T.: Força de Intervenção S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241342.mp4', 'http://timg.bdta.pro/images/5389b66ff4f3b909aed746d1801a28b6.jpg'),
(11438, 734, 'S.W.A.T.: Força de Intervenção S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241343.mp4', 'http://timg.bdta.pro/images/02b26e48831c273045d3693c8babcce0.jpg'),
(11439, 734, 'S.W.A.T.: Força de Intervenção S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241344.mp4', 'http://timg.bdta.pro/images/0d2dfbaacca6908cdfba20929747dc1a.jpg'),
(11440, 734, 'S.W.A.T.: Força de Intervenção S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241345.mp4', 'http://timg.bdta.pro/images/b5d6ad875447f7b949b6653d4c5e1371.jpg'),
(11441, 734, 'S.W.A.T.: Força de Intervenção S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241346.mp4', 'http://timg.bdta.pro/images/c8ca4a4535d98eaef0dd3aad8797a107.jpg'),
(11442, 734, 'S.W.A.T.: Força de Intervenção S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241347.mp4', 'http://timg.bdta.pro/images/3d33f32524e83f8f96224d295fd1dfbc.jpg'),
(11443, 734, 'S.W.A.T.: Força de Intervenção S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241348.mp4', 'http://timg.bdta.pro/images/1d8959cf8f3cd0fde1e70e038671faf8.jpg'),
(11444, 734, 'S.W.A.T.: Força de Intervenção S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241349.mp4', 'http://timg.bdta.pro/images/d70437b6ca2f4e64250b46bcde1948f4.jpg'),
(11445, 734, 'S.W.A.T.: Força de Intervenção S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241350.mp4', 'http://timg.bdta.pro/images/e7f4574f113851f0716acdca446641b9.jpg'),
(11446, 734, 'S.W.A.T.: Força de Intervenção S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241351.mp4', 'http://timg.bdta.pro/images/b76a7acb5594497009eb522a79f7dadb.jpg'),
(11447, 734, 'S.W.A.T.: Força de Intervenção S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241352.mp4', 'http://timg.bdta.pro/images/8f72705f20a25dc0b55ea364bb2801db.jpg'),
(11448, 734, 'S.W.A.T.: Força de Intervenção S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241353.mp4', 'http://timg.bdta.pro/images/fcf6405b9e4fcb4fb080e292489685a7.jpg'),
(11449, 734, 'S.W.A.T.: Força de Intervenção S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/241354.mp4', 'http://timg.bdta.pro/images/3225ef435e234228516b1f9e2bcb4c5f.jpg'),
(11450, 734, 'S.W.A.T.: Força de Intervenção S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/241355.mp4', 'http://timg.bdta.pro/images/ce570bc67341de94917788f0615c3fb3.jpg'),
(11451, 734, 'S.W.A.T.: Força de Intervenção S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/241356.mp4', 'http://timg.bdta.pro/images/3b6e28f6e67b766979b36b1edb57b178.jpg'),
(11452, 735, 'S.W.A.T.: Força de Intervenção S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241357.mp4', 'http://timg.bdta.pro/images/f5abc28648d4822f06e87911cb9c950a.jpg'),
(11453, 735, 'S.W.A.T.: Força de Intervenção S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241358.mp4', 'http://timg.bdta.pro/images/2cda1216b440ddb60335292ffd824de5.jpg'),
(11454, 735, 'S.W.A.T.: Força de Intervenção S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241359.mp4', 'http://timg.bdta.pro/images/5958b1e376298373c8722cb4312d9ae4.jpg'),
(11455, 735, 'S.W.A.T.: Força de Intervenção S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241360.mp4', 'http://timg.bdta.pro/images/7361aa44e8e6ae044acd30f1a18a56fe.jpg'),
(11456, 735, 'S.W.A.T.: Força de Intervenção S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241361.mp4', 'http://timg.bdta.pro/images/64d0d60abb5ed1595f8cfd24a6922bb6.jpg'),
(11457, 735, 'S.W.A.T.: Força de Intervenção S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241362.mp4', 'http://timg.bdta.pro/images/d85400ca2ea3d0d3c4e1b7b80e6f40e1.jpg'),
(11458, 735, 'S.W.A.T.: Força de Intervenção S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241363.mp4', 'http://timg.bdta.pro/images/a96861c513f9eba2c0ab8e60ec9a6e10.jpg'),
(11459, 735, 'S.W.A.T.: Força de Intervenção S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241364.mp4', 'http://timg.bdta.pro/images/1a74f67060cf9dee9d7ec91150d51010.jpg'),
(11460, 735, 'S.W.A.T.: Força de Intervenção S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241365.mp4', 'http://timg.bdta.pro/images/55ef9dc04191716f370765e3d84748f6.jpg'),
(11461, 735, 'S.W.A.T.: Força de Intervenção S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241366.mp4', 'http://timg.bdta.pro/images/19a2292dc15dd82fcbb7601d32ebab63.jpg'),
(11462, 735, 'S.W.A.T.: Força de Intervenção S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241367.mp4', 'http://timg.bdta.pro/images/d7fb2d3b1757ec3a7e4803d056f46cd0.jpg'),
(11463, 735, 'S.W.A.T.: Força de Intervenção S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241368.mp4', 'http://timg.bdta.pro/images/b75a01ee63eb96a71773e0820e9f2117.jpg'),
(11464, 735, 'S.W.A.T.: Força de Intervenção S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241369.mp4', 'http://timg.bdta.pro/images/49495092e236d8a40fae9a4ababbff41.jpg'),
(11465, 735, 'S.W.A.T.: Força de Intervenção S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241370.mp4', 'http://timg.bdta.pro/images/0fd425e55b750fc7562f1323be56555e.jpg'),
(11466, 735, 'S.W.A.T.: Força de Intervenção S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241371.mp4', 'http://timg.bdta.pro/images/6d35bff87ec4710a0442432e74a72a42.jpg'),
(11467, 735, 'S.W.A.T.: Força de Intervenção S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/241372.mp4', 'http://timg.bdta.pro/images/1481fd581f6b89bda02468383e3dcb41.jpg'),
(11468, 735, 'S.W.A.T.: Força de Intervenção S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/241373.mp4', 'http://timg.bdta.pro/images/6f33ba2a07de6e41ec333387d2e678d7.jpg'),
(11469, 735, 'S.W.A.T.: Força de Intervenção S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/241374.mp4', 'http://timg.bdta.pro/images/0079cad532058b53d447ec6b3c0b3dcb.jpg'),
(11470, 735, 'S.W.A.T.: Força de Intervenção S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/241375.mp4', 'http://timg.bdta.pro/images/d177e4cdd13df143baf55558f4add434.jpg'),
(11471, 735, 'S.W.A.T.: Força de Intervenção S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/241376.mp4', 'http://timg.bdta.pro/images/c775775a9c82e65bb51f60ce475d9ff8.jpg'),
(11472, 735, 'S.W.A.T.: Força de Intervenção S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/241377.mp4', 'http://timg.bdta.pro/images/7800d385d6aa3b259f80d685ebf5f62a.jpg'),
(11473, 735, 'S.W.A.T.: Força de Intervenção S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/241378.mp4', 'http://timg.bdta.pro/images/79b315f08b13d43ad29d6f6429eae239.jpg'),
(11474, 736, 'S.W.A.T.: Força de Intervenção S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/VVkAUAEAnfFrDVOhCiABYAEo77.jpg'),
(11475, 736, 'S.W.A.T.: Força de Intervenção S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11vGfMXwxyJnt2VeR2zJnGYskhv.jpg'),
(11476, 736, 'S.W.A.T.: Força de Intervenção S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yjKoJwmUiTwnnrPE11N8IBEy6bh.jpg'),
(11477, 736, 'S.W.A.T.: Força de Intervenção S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s7SZAskcLMNwGhia1cVfFifq63e.jpg'),
(11478, 736, 'S.W.A.T.: Força de Intervenção S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1DO8lwRCZrK2rjXkeQUF26ojYQl.jpg'),
(11479, 736, 'S.W.A.T.: Força de Intervenção S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7BP0gQxGwBbInhME8SwkiUo2aZs.jpg'),
(11480, 736, 'S.W.A.T.: Força de Intervenção S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gYqDh4aqXpcrWBrw6tei54z4Ubn.jpg'),
(11481, 736, 'S.W.A.T.: Força de Intervenção S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m9LOC4I66XaJ4UC4PgEEbX90fyk.jpg'),
(11482, 736, 'S.W.A.T.: Força de Intervenção S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iRf1TX2oBuuBoDLn5uPQbS1zfDF.jpg'),
(11483, 736, 'S.W.A.T.: Força de Intervenção S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gBtq4IpeTnKZxDHZmbcjVgrQrb2.jpg'),
(11484, 736, 'S.W.A.T.: Força de Intervenção S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241389.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11485, 736, 'S.W.A.T.: Força de Intervenção S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241390.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11486, 736, 'S.W.A.T.: Força de Intervenção S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241391.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11487, 736, 'S.W.A.T.: Força de Intervenção S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241392.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11488, 736, 'S.W.A.T.: Força de Intervenção S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241393.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11489, 736, 'S.W.A.T.: Força de Intervenção S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/241394.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11490, 736, 'S.W.A.T.: Força de Intervenção S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/241395.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11491, 736, 'S.W.A.T.: Força de Intervenção S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/241396.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11492, 736, 'S.W.A.T.: Força de Intervenção S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/241397.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11493, 736, 'S.W.A.T.: Força de Intervenção S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/241398.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11494, 736, 'S.W.A.T.: Força de Intervenção S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/241399.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11495, 736, 'S.W.A.T.: Força de Intervenção S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/241400.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11496, 737, 'S.W.A.T.: Força de Intervenção S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/450463.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11497, 737, 'S.W.A.T.: Força de Intervenção S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/450464.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11498, 737, 'S.W.A.T.: Força de Intervenção S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/450465.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11499, 737, 'S.W.A.T.: Força de Intervenção S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/450466.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11500, 737, 'S.W.A.T.: Força de Intervenção S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/450467.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11501, 737, 'S.W.A.T.: Força de Intervenção S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/450468.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11502, 737, 'S.W.A.T.: Força de Intervenção S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/450469.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11503, 737, 'S.W.A.T.: Força de Intervenção S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/450470.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11504, 737, 'S.W.A.T.: Força de Intervenção S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/450471.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11505, 737, 'S.W.A.T.: Força de Intervenção S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/450472.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11506, 737, 'S.W.A.T.: Força de Intervenção S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/450473.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11507, 737, 'S.W.A.T.: Força de Intervenção S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/450474.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(11508, 737, 'S.W.A.T.: Força de Intervenção S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/450475.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11509, 738, 'S.W.A.T.: Força de Intervenção S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/883970.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11510, 738, 'S.W.A.T.: Força de Intervenção S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/883971.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11511, 738, 'S.W.A.T.: Força de Intervenção S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/883972.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11512, 738, 'S.W.A.T.: Força de Intervenção S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/883973.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11513, 738, 'S.W.A.T.: Força de Intervenção S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/883974.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11514, 738, 'S.W.A.T.: Força de Intervenção S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/883975.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11515, 738, 'S.W.A.T.: Força de Intervenção S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/883976.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11516, 738, 'S.W.A.T.: Força de Intervenção S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/883977.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11517, 738, 'S.W.A.T.: Força de Intervenção S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/883978.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11518, 738, 'S.W.A.T.: Força de Intervenção S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/883979.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11519, 738, 'S.W.A.T.: Força de Intervenção S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/883980.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11520, 738, 'S.W.A.T.: Força de Intervenção S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/883981.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11521, 738, 'S.W.A.T.: Força de Intervenção S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/883982.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11522, 738, 'S.W.A.T.: Força de Intervenção S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/883983.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11523, 738, 'S.W.A.T.: Força de Intervenção S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/883984.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11524, 738, 'S.W.A.T.: Força de Intervenção S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/883985.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11525, 738, 'S.W.A.T.: Força de Intervenção S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/883986.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11526, 738, 'S.W.A.T.: Força de Intervenção S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/883987.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11527, 738, 'S.W.A.T.: Força de Intervenção S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/883988.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11528, 738, 'S.W.A.T.: Força de Intervenção S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/883989.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11529, 738, 'S.W.A.T.: Força de Intervenção S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/883990.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11530, 738, 'S.W.A.T.: Força de Intervenção S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/883991.mp4', 'http://gstaticontent.com/images/06d1ceea7d4f6d226f557590023aecd2.jpg'),
(11531, 739, 'Teen Wolf S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102921.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11532, 739, 'Teen Wolf S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102922.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11533, 739, 'Teen Wolf S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102923.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11534, 739, 'Teen Wolf S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102924.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11535, 739, 'Teen Wolf S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102925.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11536, 739, 'Teen Wolf S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102926.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11537, 739, 'Teen Wolf S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102927.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11538, 739, 'Teen Wolf S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102928.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11539, 739, 'Teen Wolf S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102929.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11540, 739, 'Teen Wolf S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102930.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11541, 739, 'Teen Wolf S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102931.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11542, 739, 'Teen Wolf S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102932.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11543, 740, 'Teen Wolf S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102933.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11544, 740, 'Teen Wolf S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102934.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11545, 740, 'Teen Wolf S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102935.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11546, 740, 'Teen Wolf S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102936.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11547, 740, 'Teen Wolf S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102937.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11548, 740, 'Teen Wolf S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102938.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11549, 740, 'Teen Wolf S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102939.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11550, 740, 'Teen Wolf S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102940.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11551, 740, 'Teen Wolf S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102941.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11552, 740, 'Teen Wolf S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102942.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11553, 740, 'Teen Wolf S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102943.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11554, 740, 'Teen Wolf S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102944.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11555, 741, 'Teen Wolf S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102945.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11556, 741, 'Teen Wolf S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102946.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11557, 741, 'Teen Wolf S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102947.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11558, 741, 'Teen Wolf S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102948.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11559, 741, 'Teen Wolf S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102949.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11560, 741, 'Teen Wolf S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102950.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11561, 741, 'Teen Wolf S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102951.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11562, 741, 'Teen Wolf S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102952.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11563, 741, 'Teen Wolf S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102953.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11564, 741, 'Teen Wolf S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102954.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11565, 741, 'Teen Wolf S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102955.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11566, 741, 'Teen Wolf S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102956.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11567, 741, 'Teen Wolf S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102957.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11568, 741, 'Teen Wolf S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/102958.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11569, 741, 'Teen Wolf S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/102959.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11570, 741, 'Teen Wolf S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/102960.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11571, 741, 'Teen Wolf S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/102961.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11572, 741, 'Teen Wolf S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/102962.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11573, 741, 'Teen Wolf S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/102963.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11574, 741, 'Teen Wolf S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/102964.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11575, 741, 'Teen Wolf S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/102965.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11576, 741, 'Teen Wolf S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/102966.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11577, 741, 'Teen Wolf S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/102967.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11578, 741, 'Teen Wolf S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/102968.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11579, 742, 'Teen Wolf S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102969.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11580, 742, 'Teen Wolf S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102970.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11581, 742, 'Teen Wolf S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102971.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11582, 742, 'Teen Wolf S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102972.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11583, 742, 'Teen Wolf S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102973.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11584, 742, 'Teen Wolf S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102974.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11585, 742, 'Teen Wolf S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102975.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11586, 742, 'Teen Wolf S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102976.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11587, 742, 'Teen Wolf S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102977.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11588, 742, 'Teen Wolf S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102978.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11589, 742, 'Teen Wolf S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102979.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11590, 742, 'Teen Wolf S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102980.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11591, 743, 'Teen Wolf S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102981.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11592, 743, 'Teen Wolf S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102982.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11593, 743, 'Teen Wolf S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102983.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11594, 743, 'Teen Wolf S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102984.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11595, 743, 'Teen Wolf S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102985.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11596, 743, 'Teen Wolf S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102986.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11597, 743, 'Teen Wolf S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102987.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11598, 743, 'Teen Wolf S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102988.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11599, 743, 'Teen Wolf S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102989.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11600, 743, 'Teen Wolf S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102990.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11601, 743, 'Teen Wolf S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102991.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11602, 743, 'Teen Wolf S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102992.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11603, 743, 'Teen Wolf S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102993.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11604, 743, 'Teen Wolf S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/102994.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11605, 743, 'Teen Wolf S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/102995.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11606, 743, 'Teen Wolf S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/102996.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11607, 743, 'Teen Wolf S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/102997.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11608, 743, 'Teen Wolf S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/102998.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11609, 743, 'Teen Wolf S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/102999.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11610, 743, 'Teen Wolf S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/103000.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11611, 744, 'Teen Wolf S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103001.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11612, 744, 'Teen Wolf S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103002.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11613, 744, 'Teen Wolf S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103003.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11614, 744, 'Teen Wolf S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103004.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11615, 744, 'Teen Wolf S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103005.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11616, 744, 'Teen Wolf S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103006.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11617, 744, 'Teen Wolf S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103007.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11618, 744, 'Teen Wolf S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103008.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11619, 744, 'Teen Wolf S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103009.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11620, 744, 'Teen Wolf S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103010.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11621, 744, 'Teen Wolf S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103011.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11622, 744, 'Teen Wolf S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103012.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11623, 744, 'Teen Wolf S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/103013.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11624, 744, 'Teen Wolf S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/103014.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11625, 744, 'Teen Wolf S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/103015.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11626, 744, 'Teen Wolf S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/103016.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11627, 744, 'Teen Wolf S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/103017.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11628, 744, 'Teen Wolf S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/103018.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11629, 744, 'Teen Wolf S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/103019.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11630, 744, 'Teen Wolf S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/103020.mp4', 'http://gstaticontent.com/images/jL1yfqC52aSnyq41hvwfZATrYhK_big.jpg'),
(11631, 745, 'Terra Nova S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107907.mp4', 'http://timg.bdta.pro/images/889b0c5075b914923d0e7dbc126b37a4.jpg'),
(11632, 745, 'Terra Nova S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107908.mp4', 'http://timg.bdta.pro/images/3a6b4b1f2b3591925128459a3ad8b38f.jpg'),
(11633, 745, 'Terra Nova S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107909.mp4', 'http://timg.bdta.pro/images/03a6c5d35d55840303b0d94df407c72b.jpg'),
(11634, 745, 'Terra Nova S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107910.mp4', 'http://timg.bdta.pro/images/ac1c7b5009b1e6066bd35d250655dd1e.jpg'),
(11635, 745, 'Terra Nova S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107911.mp4', 'http://timg.bdta.pro/images/47a2221a5c057ed454896433e8f456f7.jpg'),
(11636, 745, 'Terra Nova S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107912.mp4', 'http://timg.bdta.pro/images/316a9df0bc41d585305de084bef74bc2.jpg'),
(11637, 745, 'Terra Nova S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107913.mp4', 'http://timg.bdta.pro/images/854b34eef835278d81ebca91a62e7c00.jpg'),
(11638, 745, 'Terra Nova S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107914.mp4', 'http://timg.bdta.pro/images/aa685b882bbb5c0680e9a3c6334648b7.jpg'),
(11639, 745, 'Terra Nova S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107915.mp4', 'http://timg.bdta.pro/images/e35a1dd89f4c56752eeb7421209bf729.jpg'),
(11640, 745, 'Terra Nova S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107916.mp4', 'http://timg.bdta.pro/images/ff6e4df96b13c09863f53eb8ae6d31f4.jpg'),
(11641, 745, 'Terra Nova S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107917.mp4', 'http://gstaticontent.com/images/y8dFONeUSXhMHiFecqFoaGI7S6y_big.jpg'),
(11642, 746, 'The Americans S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102480.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11643, 746, 'The Americans S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102481.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11644, 746, 'The Americans S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102482.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11645, 746, 'The Americans S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102483.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11646, 746, 'The Americans S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102484.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11647, 746, 'The Americans S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102485.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11648, 746, 'The Americans S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102486.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11649, 746, 'The Americans S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102487.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11650, 746, 'The Americans S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102488.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11651, 746, 'The Americans S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102489.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11652, 746, 'The Americans S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102490.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11653, 746, 'The Americans S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102491.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11654, 746, 'The Americans S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102492.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11655, 747, 'The Americans S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102493.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11656, 747, 'The Americans S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102494.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11657, 747, 'The Americans S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102495.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11658, 747, 'The Americans S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102496.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11659, 747, 'The Americans S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102497.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11660, 747, 'The Americans S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102498.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11661, 747, 'The Americans S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102499.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11662, 747, 'The Americans S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102500.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11663, 747, 'The Americans S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102501.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11664, 747, 'The Americans S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102502.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11665, 747, 'The Americans S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102503.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11666, 747, 'The Americans S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102504.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11667, 747, 'The Americans S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102505.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11668, 748, 'The Americans S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102506.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11669, 748, 'The Americans S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102507.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11670, 748, 'The Americans S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102508.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11671, 748, 'The Americans S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102509.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11672, 748, 'The Americans S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102510.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11673, 748, 'The Americans S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102511.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11674, 748, 'The Americans S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102512.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11675, 748, 'The Americans S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102513.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11676, 748, 'The Americans S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102514.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11677, 749, 'The Americans S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102515.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11678, 749, 'The Americans S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102516.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11679, 749, 'The Americans S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102517.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11680, 749, 'The Americans S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102518.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11681, 749, 'The Americans S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102519.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11682, 749, 'The Americans S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102520.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11683, 749, 'The Americans S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102521.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11684, 749, 'The Americans S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102522.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11685, 749, 'The Americans S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102523.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11686, 749, 'The Americans S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102524.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11687, 749, 'The Americans S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102525.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11688, 749, 'The Americans S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102526.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11689, 749, 'The Americans S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102527.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11690, 750, 'The Americans S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102528.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11691, 750, 'The Americans S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102529.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11692, 750, 'The Americans S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102530.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11693, 750, 'The Americans S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102531.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11694, 750, 'The Americans S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102532.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11695, 750, 'The Americans S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102533.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11696, 750, 'The Americans S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102534.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11697, 750, 'The Americans S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102535.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11698, 750, 'The Americans S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102536.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11699, 750, 'The Americans S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102537.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11700, 750, 'The Americans S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102538.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11701, 750, 'The Americans S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102539.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11702, 750, 'The Americans S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102540.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11703, 751, 'The Americans S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102541.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11704, 751, 'The Americans S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102542.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11705, 751, 'The Americans S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102543.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11706, 751, 'The Americans S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102544.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11707, 751, 'The Americans S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102545.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11708, 751, 'The Americans S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102546.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11709, 751, 'The Americans S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102547.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11710, 751, 'The Americans S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102548.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11711, 751, 'The Americans S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102549.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11712, 751, 'The Americans S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102550.mp4', 'http://gstaticontent.com/images/qB7WPVQnmODg2mZ1xUmPOrCa0wL_big.jpg'),
(11713, 752, 'The Blacklist S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226364.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11714, 752, 'The Blacklist S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226365.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11715, 752, 'The Blacklist S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226366.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11716, 752, 'The Blacklist S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226367.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11717, 752, 'The Blacklist S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226368.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11718, 752, 'The Blacklist S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226369.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11719, 752, 'The Blacklist S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226370.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11720, 752, 'The Blacklist S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226371.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11721, 752, 'The Blacklist S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226372.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11722, 752, 'The Blacklist S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226373.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11723, 752, 'The Blacklist S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226374.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11724, 752, 'The Blacklist S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226375.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11725, 752, 'The Blacklist S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226376.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11726, 752, 'The Blacklist S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226377.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11727, 752, 'The Blacklist S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226378.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11728, 752, 'The Blacklist S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/226379.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11729, 752, 'The Blacklist S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/226380.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11730, 752, 'The Blacklist S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/226381.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11731, 752, 'The Blacklist S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/226382.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11732, 752, 'The Blacklist S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/226383.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11733, 752, 'The Blacklist S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/226384.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11734, 752, 'The Blacklist S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/226385.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11735, 753, 'The Blacklist S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226386.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11736, 753, 'The Blacklist S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226387.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11737, 753, 'The Blacklist S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226388.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11738, 753, 'The Blacklist S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226389.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11739, 753, 'The Blacklist S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226390.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11740, 753, 'The Blacklist S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226391.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11741, 753, 'The Blacklist S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226392.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11742, 753, 'The Blacklist S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226393.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11743, 753, 'The Blacklist S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226394.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11744, 753, 'The Blacklist S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226395.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11745, 753, 'The Blacklist S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226396.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11746, 753, 'The Blacklist S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226397.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11747, 753, 'The Blacklist S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226398.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11748, 753, 'The Blacklist S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226399.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11749, 753, 'The Blacklist S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226400.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11750, 753, 'The Blacklist S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/226401.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11751, 753, 'The Blacklist S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/226402.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11752, 753, 'The Blacklist S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/226403.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11753, 753, 'The Blacklist S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/226404.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11754, 753, 'The Blacklist S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/226405.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11755, 753, 'The Blacklist S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/226406.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11756, 753, 'The Blacklist S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/226407.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11757, 754, 'The Blacklist S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226408.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11758, 754, 'The Blacklist S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226409.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11759, 754, 'The Blacklist S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226410.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11760, 754, 'The Blacklist S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226411.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11761, 754, 'The Blacklist S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226412.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11762, 754, 'The Blacklist S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226413.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11763, 754, 'The Blacklist S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226414.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11764, 754, 'The Blacklist S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226415.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11765, 754, 'The Blacklist S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226416.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11766, 754, 'The Blacklist S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226417.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11767, 754, 'The Blacklist S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226418.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11768, 754, 'The Blacklist S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226419.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11769, 754, 'The Blacklist S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226420.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11770, 754, 'The Blacklist S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226421.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11771, 754, 'The Blacklist S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226422.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11772, 754, 'The Blacklist S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/226423.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11773, 754, 'The Blacklist S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/226424.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11774, 754, 'The Blacklist S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/226425.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11775, 754, 'The Blacklist S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/226426.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11776, 754, 'The Blacklist S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/226427.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11777, 754, 'The Blacklist S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/226428.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11778, 754, 'The Blacklist S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/226429.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11779, 754, 'The Blacklist S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/226430.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11780, 755, 'The Blacklist S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226431.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11781, 755, 'The Blacklist S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226432.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11782, 755, 'The Blacklist S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226433.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11783, 755, 'The Blacklist S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226434.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11784, 755, 'The Blacklist S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226435.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11785, 755, 'The Blacklist S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226436.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11786, 755, 'The Blacklist S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226437.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11787, 755, 'The Blacklist S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226438.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11788, 755, 'The Blacklist S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226439.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11789, 755, 'The Blacklist S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226440.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11790, 755, 'The Blacklist S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226441.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11791, 755, 'The Blacklist S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226442.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11792, 755, 'The Blacklist S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226443.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11793, 755, 'The Blacklist S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226444.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11794, 755, 'The Blacklist S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226445.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11795, 755, 'The Blacklist S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/226446.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(11796, 755, 'The Blacklist S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/226447.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11797, 755, 'The Blacklist S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/226448.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11798, 755, 'The Blacklist S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/226449.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11799, 755, 'The Blacklist S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/226450.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11800, 755, 'The Blacklist S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/226451.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11801, 755, 'The Blacklist S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/226452.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11802, 756, 'The Blacklist S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226453.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11803, 756, 'The Blacklist S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226454.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11804, 756, 'The Blacklist S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226455.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11805, 756, 'The Blacklist S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226456.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11806, 756, 'The Blacklist S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226457.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11807, 756, 'The Blacklist S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226458.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11808, 756, 'The Blacklist S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226459.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11809, 756, 'The Blacklist S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226460.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11810, 756, 'The Blacklist S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226461.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11811, 756, 'The Blacklist S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226462.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11812, 756, 'The Blacklist S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226463.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11813, 756, 'The Blacklist S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226464.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11814, 756, 'The Blacklist S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226465.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11815, 756, 'The Blacklist S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226466.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11816, 756, 'The Blacklist S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226467.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11817, 756, 'The Blacklist S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/226468.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11818, 756, 'The Blacklist S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/226469.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11819, 756, 'The Blacklist S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/226470.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11820, 756, 'The Blacklist S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/226471.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11821, 756, 'The Blacklist S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/226472.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11822, 756, 'The Blacklist S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/226473.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11823, 756, 'The Blacklist S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/226474.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11824, 757, 'The Blacklist S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226475.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11825, 757, 'The Blacklist S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226476.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11826, 757, 'The Blacklist S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226477.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11827, 757, 'The Blacklist S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226478.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11828, 757, 'The Blacklist S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226479.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11829, 757, 'The Blacklist S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226480.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11830, 757, 'The Blacklist S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226481.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11831, 757, 'The Blacklist S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226482.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11832, 757, 'The Blacklist S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226483.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11833, 757, 'The Blacklist S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226484.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11834, 757, 'The Blacklist S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226485.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11835, 757, 'The Blacklist S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226486.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11836, 757, 'The Blacklist S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226487.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11837, 757, 'The Blacklist S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226488.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11838, 757, 'The Blacklist S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226489.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11839, 757, 'The Blacklist S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/226490.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11840, 757, 'The Blacklist S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/226491.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11841, 757, 'The Blacklist S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/226492.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11842, 757, 'The Blacklist S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/226493.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11843, 757, 'The Blacklist S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/226494.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11844, 757, 'The Blacklist S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/226495.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11845, 757, 'The Blacklist S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/226496.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11846, 758, 'The Blacklist S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226497.mp4', 'http://timg.bdta.pro/images/2cdd1128909004d4d8541f4f9196af6d.jpg'),
(11847, 758, 'The Blacklist S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226498.mp4', 'http://timg.bdta.pro/images/5b9eac92552412468c48d5cf23b1d123.jpg'),
(11848, 758, 'The Blacklist S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226499.mp4', 'http://timg.bdta.pro/images/db737b60bbb72a277b22e25199366428.jpg'),
(11849, 758, 'The Blacklist S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226500.mp4', 'http://timg.bdta.pro/images/e3cad1b6a3836b94786523d9fb747298.jpg'),
(11850, 758, 'The Blacklist S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226501.mp4', 'http://timg.bdta.pro/images/cd551ad472be77528d1e4d8d7ce1c441.jpg'),
(11851, 758, 'The Blacklist S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226502.mp4', 'http://timg.bdta.pro/images/cc503c25b14c48c9f9b32fad813dfe00.jpg'),
(11852, 758, 'The Blacklist S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226503.mp4', 'http://timg.bdta.pro/images/e36816b02acc1bbee5e74b4c1436d32a.jpg'),
(11853, 758, 'The Blacklist S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226504.mp4', 'http://timg.bdta.pro/images/154074404af8e11c8a20249c1663046a.jpg'),
(11854, 758, 'The Blacklist S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226505.mp4', 'http://timg.bdta.pro/images/4bd25e468499c906d316429be3e6eeee.jpg'),
(11855, 758, 'The Blacklist S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226506.mp4', 'http://timg.bdta.pro/images/b26c1469ca78090eb86fc5d01c4df439.jpg'),
(11856, 758, 'The Blacklist S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226507.mp4', 'http://timg.bdta.pro/images/ecc65350fb72b9d93ff53e82d28b7401.jpg'),
(11857, 758, 'The Blacklist S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226508.mp4', 'http://timg.bdta.pro/images/c9a11b3a4ec27e05f90ab1cdd6b945bd.jpg'),
(11858, 758, 'The Blacklist S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226509.mp4', 'http://timg.bdta.pro/images/ce26fee897e6fb03eab0215dba5319c1.jpg'),
(11859, 758, 'The Blacklist S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226510.mp4', 'http://timg.bdta.pro/images/8020bdf39327e90db64e3ba6c8bda524.jpg'),
(11860, 758, 'The Blacklist S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226511.mp4', 'http://timg.bdta.pro/images/907a6ad71333946da38c8d8abce9f439.jpg'),
(11861, 758, 'The Blacklist S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/226512.mp4', 'http://timg.bdta.pro/images/566c18738fb76aecdbcaa836e885cb65.jpg'),
(11862, 758, 'The Blacklist S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/226513.mp4', 'http://timg.bdta.pro/images/8c13eac027f58b9dabab8dee19153756.jpg'),
(11863, 758, 'The Blacklist S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/226514.mp4', 'http://timg.bdta.pro/images/4b88d2555908386f7badde913f15f642.jpg'),
(11864, 758, 'The Blacklist S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/226515.mp4', 'http://timg.bdta.pro/images/70afda70ff053ef9fe57b76bcd2ce8df.jpg'),
(11865, 759, 'The Blacklist S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226516.mp4', 'http://timg.bdta.pro/images/206086c6ae25ad4e7734d558c9c1f8b1.jpg'),
(11866, 759, 'The Blacklist S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226517.mp4', 'http://timg.bdta.pro/images/9ed7ea1a7b6f1a0835a454c596076afc.jpg'),
(11867, 759, 'The Blacklist S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226518.mp4', 'http://timg.bdta.pro/images/47c7a6e51e2f0ba25883a10dcceccdd7.jpg'),
(11868, 759, 'The Blacklist S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226519.mp4', 'http://timg.bdta.pro/images/e8a4a2c024bef5c2cf5174348cb841b0.jpg'),
(11869, 759, 'The Blacklist S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226520.mp4', 'http://timg.bdta.pro/images/5bc3bfa5deeeac7d2d09f40975e220aa.jpg'),
(11870, 759, 'The Blacklist S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226521.mp4', 'http://timg.bdta.pro/images/eb33961080837abad0ddc293716e34c3.jpg'),
(11871, 759, 'The Blacklist S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226522.mp4', 'http://timg.bdta.pro/images/9febd171f30a162c741f508013a2a21d.jpg'),
(11872, 759, 'The Blacklist S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226523.mp4', 'http://timg.bdta.pro/images/9637904c58fe9f5ebd5ef4f41aa38ce0.jpg'),
(11873, 759, 'The Blacklist S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226524.mp4', 'http://timg.bdta.pro/images/82906ba2a165fa4ee244303724cc6c2e.jpg'),
(11874, 759, 'The Blacklist S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226525.mp4', 'http://timg.bdta.pro/images/fa5162625e82a73467ca9c9f06a1daac.jpg'),
(11875, 759, 'The Blacklist S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226526.mp4', 'http://timg.bdta.pro/images/b363ad303e0d23e694c31d0b56990228.jpg'),
(11876, 759, 'The Blacklist S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226527.mp4', 'http://timg.bdta.pro/images/3d94d617c481da07997bd24a14e3f674.jpg'),
(11877, 759, 'The Blacklist S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226528.mp4', 'http://timg.bdta.pro/images/187d7e92423943c8c5b3ae6a54b47aae.jpg'),
(11878, 759, 'The Blacklist S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226529.mp4', 'http://timg.bdta.pro/images/185735b068d0a9a0d7193b05ca0849c6.jpg'),
(11879, 759, 'The Blacklist S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226530.mp4', 'http://timg.bdta.pro/images/9966125749a4874aa9e64d1aaac0fde8.jpg'),
(11880, 759, 'The Blacklist S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/226531.mp4', 'http://timg.bdta.pro/images/3676efa1294c114f01c3134f1adcd525.jpg'),
(11881, 759, 'The Blacklist S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/226532.mp4', 'http://timg.bdta.pro/images/03543f7001d082695c285a55354aad8b.jpg'),
(11882, 759, 'The Blacklist S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/226533.mp4', 'http://timg.bdta.pro/images/8bae1ccbf7c011de0c0db9cba49ca9ad.jpg'),
(11883, 759, 'The Blacklist S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/226534.mp4', 'http://timg.bdta.pro/images/b33935d5808e79c23925190215634d9f.jpg'),
(11884, 759, 'The Blacklist S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/226535.mp4', 'http://timg.bdta.pro/images/62605a6560fa653794071c52652c5652.jpg'),
(11885, 759, 'The Blacklist S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/226536.mp4', 'http://timg.bdta.pro/images/4232c1147c15d250074e1ab84182bb58.jpg'),
(11886, 759, 'The Blacklist S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/226537.mp4', 'http://timg.bdta.pro/images/74c306ba27905a7e5fc9c47d880fb6f1.jpg'),
(11887, 760, 'The Blacklist S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226538.mp4', 'http://timg.bdta.pro/images/238cfdae76d29ab81787b7dff3fe2dc4.jpg'),
(11888, 760, 'The Blacklist S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226539.mp4', 'http://timg.bdta.pro/images/96a5913662bf6d829a81b4d39bd4f2e6.jpg'),
(11889, 760, 'The Blacklist S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226540.mp4', 'http://timg.bdta.pro/images/755a52ada7b56107ea0fa805db67a871.jpg'),
(11890, 760, 'The Blacklist S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226541.mp4', 'http://timg.bdta.pro/images/b206bbb9deaea21b0462fd71e3477f57.jpg'),
(11891, 760, 'The Blacklist S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226542.mp4', 'http://timg.bdta.pro/images/230ae79f73b1f057c43931ad4a50f6ae.jpg'),
(11892, 760, 'The Blacklist S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226543.mp4', 'http://timg.bdta.pro/images/40d7cc2420e2bc8fb7631ba997193b76.jpg'),
(11893, 760, 'The Blacklist S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226544.mp4', 'http://timg.bdta.pro/images/897aed7bd7c0d6ddd9c4940c5c6a06a7.jpg'),
(11894, 760, 'The Blacklist S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226545.mp4', 'http://timg.bdta.pro/images/641b4dc860604e0b381d2ddde1a084a8.jpg'),
(11895, 760, 'The Blacklist S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226546.mp4', 'http://timg.bdta.pro/images/443ac48d250eecc12287fc6716cd5143.jpg'),
(11896, 760, 'The Blacklist S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226547.mp4', 'http://timg.bdta.pro/images/51a592a63bc7c2df16fa075d7d3e1dc5.jpg'),
(11897, 760, 'The Blacklist S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226548.mp4', 'http://timg.bdta.pro/images/77575295174b6cc90ab9505cd1f1a2ea.jpg'),
(11898, 760, 'The Blacklist S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226549.mp4', 'http://timg.bdta.pro/images/f6fbf44bd048abaefcb47996974b8461.jpg'),
(11899, 760, 'The Blacklist S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226550.mp4', 'http://timg.bdta.pro/images/6c4ae40e7924ebdb8b329128fc9023c1.jpg'),
(11900, 760, 'The Blacklist S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226551.mp4', 'http://timg.bdta.pro/images/22d83e6bfca23d2694dd0ca18322a7c0.jpg'),
(11901, 760, 'The Blacklist S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226552.mp4', 'http://timg.bdta.pro/images/95fe327b43bd5f403fc71ceddf629413.jpg'),
(11902, 760, 'The Blacklist S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/226553.mp4', 'http://timg.bdta.pro/images/ad3c39e5cd56830729069eef42fd59da.jpg'),
(11903, 760, 'The Blacklist S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/226554.mp4', 'http://timg.bdta.pro/images/c51eb050555ea14ba5470993b709a8ef.jpg'),
(11904, 760, 'The Blacklist S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/226555.mp4', 'http://timg.bdta.pro/images/1b7eea4d1304cc2429b9f34cfb08184f.jpg'),
(11905, 760, 'The Blacklist S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/226556.mp4', 'http://timg.bdta.pro/images/d2ab74118b8589ddf531774f493577a2.jpg'),
(11906, 760, 'The Blacklist S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/226557.mp4', 'http://timg.bdta.pro/images/72b52c6701ce6b001799cd8154d2350d.jpg'),
(11907, 760, 'The Blacklist S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/226558.mp4', 'http://timg.bdta.pro/images/8546d3e1e3a8e909dc58cb12e07967b3.jpg'),
(11908, 760, 'The Blacklist S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/226559.mp4', 'http://timg.bdta.pro/images/bb3a2c015b26493892aaa2f3983e769a.jpg'),
(11909, 761, 'The Blacklist S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226560.mp4', 'http://image.tmdb.org/t/p/w1280/v4SBnUl6HJJnebTgcjbKwyxd63F.jpg'),
(11910, 761, 'The Blacklist S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226561.mp4', 'http://image.tmdb.org/t/p/w1280/3jzAAk8Ue3NNctyR00WaaRkEpX6.jpg'),
(11911, 761, 'The Blacklist S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226562.mp4', 'http://image.tmdb.org/t/p/w1280/bJh8ux65bAwLt2ednGAomnfydRu.jpg'),
(11912, 761, 'The Blacklist S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226563.mp4', 'http://image.tmdb.org/t/p/w1280/jjZm7p9lAIVLcANsGYaVGblLaFP.jpg'),
(11913, 761, 'The Blacklist S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226564.mp4', 'http://image.tmdb.org/t/p/w1280/zFqg0VpDYphLEafujvPc8Di3upq.jpg'),
(11914, 761, 'The Blacklist S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226565.mp4', 'http://image.tmdb.org/t/p/w1280/oaEBlt28kFDuOPNoHR2Bo1gizqL.jpg'),
(11915, 761, 'The Blacklist S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226566.mp4', 'http://image.tmdb.org/t/p/w1280/cCuJpgY7EOO3qVdPatvZTvlALI8.jpg'),
(11916, 761, 'The Blacklist S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226567.mp4', 'http://image.tmdb.org/t/p/w1280/vFBJrYh7Apfk0GX9jzWdWhcI5AP.jpg'),
(11917, 761, 'The Blacklist S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226568.mp4', 'http://image.tmdb.org/t/p/w1280/aWTFRbx98UAFMYm0FKsi0eCE7fZ.jpg'),
(11918, 761, 'The Blacklist S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226569.mp4', 'http://image.tmdb.org/t/p/w1280/jFSkJQYR2VXkDFMPFHHFaKcryMB.jpg'),
(11919, 761, 'The Blacklist S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226570.mp4', 'http://image.tmdb.org/t/p/w1280/BgT47p3PDYYQ3fcf9srQQNaCEh.jpg'),
(11920, 761, 'The Blacklist S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226571.mp4', 'http://image.tmdb.org/t/p/w1280/4cTmKbFjpJ4wJgWhS9cUzFY3Jr6.jpg'),
(11921, 761, 'The Blacklist S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226572.mp4', 'http://image.tmdb.org/t/p/w1280/j0XQ72eCExcOBsMAcdiV06gzdSM.jpg'),
(11922, 761, 'The Blacklist S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/573730.mp4', 'http://image.tmdb.org//t/p/w1280/am9mvcOumG6ZPIv9NdHigtuHhBL.jpg'),
(11923, 761, 'The Blacklist S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226575.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11924, 761, 'The Blacklist S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/226576.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11925, 761, 'The Blacklist S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/226577.mp4', 'http://gstaticontent.com/images/ziy2LUOZOA3Ob5hGZAvKXCmvwe9_big.jpg'),
(11926, 761, 'The Blacklist S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/226578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qv91CMbbWjjx672FHNmipvol9oq.jpg'),
(11927, 761, 'The Blacklist S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/226579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3KGU8zu89Tb4pbwJvA7fmZYxxZP.jpg'),
(11928, 761, 'The Blacklist S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/226580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/64ozLMOwOlQ2AUCLCfNkAVQUNay.jpg'),
(11929, 761, 'The Blacklist S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/226581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m9BppEGYACgm4B1uUwjT89tmzhr.jpg'),
(11930, 761, 'The Blacklist S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/226582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oYrNXZUDn7x5xgew2eIO7zElVhD.jpg'),
(11931, 762, 'Entre Dois Mundos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105876.mp4', 'http://timg.bdta.pro/images/709da8dcfe926e2bcbebdefd7b0a8a3c.jpg'),
(11932, 762, 'Entre Dois Mundos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105877.mp4', 'http://timg.bdta.pro/images/bcce74ae63e97a301127005c4ba5ea64.jpg'),
(11933, 762, 'Entre Dois Mundos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105878.mp4', 'http://timg.bdta.pro/images/3ddb7c0818afd2a091ebf6c09ae3fa4b.jpg'),
(11934, 762, 'Entre Dois Mundos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105879.mp4', 'http://timg.bdta.pro/images/60a324363e70d8c98bba628755331cc0.jpg'),
(11935, 762, 'Entre Dois Mundos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105880.mp4', 'http://timg.bdta.pro/images/494e475b2b9c447bf52d59bf27850619.jpg'),
(11936, 762, 'Entre Dois Mundos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105881.mp4', 'http://timg.bdta.pro/images/82aad288d405c87b5d83f1f29193f193.jpg'),
(11937, 762, 'Entre Dois Mundos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105882.mp4', 'http://timg.bdta.pro/images/46f9579b5eb5b223954cd2621a7a86da.jpg'),
(11938, 762, 'Entre Dois Mundos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105883.mp4', 'http://timg.bdta.pro/images/660cfe9895e4f421f33effcf5f242200.jpg'),
(11939, 762, 'Entre Dois Mundos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105884.mp4', 'http://timg.bdta.pro/images/50588f67bd04f936bf918d95a0b837b2.jpg'),
(11940, 762, 'Entre Dois Mundos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105885.mp4', 'http://timg.bdta.pro/images/9583abd085f1a9b7d52c4d2e90255efa.jpg'),
(11941, 762, 'Entre Dois Mundos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105886.mp4', 'http://timg.bdta.pro/images/31e12aa77322c3f7fcbfbaeb3c10fab2.jpg'),
(11942, 763, 'The End of the F***ing World S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zQ5fG5NAQ5K8cMm58bxQNwUEbMj.jpg'),
(11943, 763, 'The End of the F***ing World S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zQ5fG5NAQ5K8cMm58bxQNwUEbMj.jpg'),
(11944, 763, 'The End of the F***ing World S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zQ5fG5NAQ5K8cMm58bxQNwUEbMj.jpg'),
(11945, 763, 'The End of the F***ing World S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zQ5fG5NAQ5K8cMm58bxQNwUEbMj.jpg'),
(11946, 763, 'The End of the F***ing World S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zQ5fG5NAQ5K8cMm58bxQNwUEbMj.jpg'),
(11947, 763, 'The End of the F***ing World S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zQ5fG5NAQ5K8cMm58bxQNwUEbMj.jpg'),
(11948, 763, 'The End of the F***ing World S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zQ5fG5NAQ5K8cMm58bxQNwUEbMj.jpg'),
(11949, 763, 'The End of the F***ing World S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zQ5fG5NAQ5K8cMm58bxQNwUEbMj.jpg'),
(11950, 764, 'The End of the F***ing World S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106851.mp4', 'http://timg.bdta.pro/images/120ca9693c5a92f81495fa40065a960f.jpg'),
(11951, 764, 'The End of the F***ing World S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106852.mp4', 'http://timg.bdta.pro/images/9f7c43b9967d79dc7fb3cb9377818dd3.jpg'),
(11952, 764, 'The End of the F***ing World S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106853.mp4', 'http://timg.bdta.pro/images/dec28416dbb45da5b92ed975a8db0e35.jpg'),
(11953, 764, 'The End of the F***ing World S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106854.mp4', 'http://timg.bdta.pro/images/ee4bc5af2b53ed1c0652a0dce151b67d.jpg'),
(11954, 764, 'The End of the F***ing World S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106855.mp4', 'http://timg.bdta.pro/images/cdedf96e6e95ba702d78ad2c9af3202f.jpg'),
(11955, 764, 'The End of the F***ing World S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106856.mp4', 'http://timg.bdta.pro/images/570504fe483f76ec8ca274a2c9de1202.jpg'),
(11956, 764, 'The End of the F***ing World S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106857.mp4', 'http://timg.bdta.pro/images/600894e1fe3c992cc86288d4e85c75f3.jpg'),
(11957, 764, 'The End of the F***ing World S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106858.mp4', 'http://timg.bdta.pro/images/8f8bea19af0f7280bd9ad18d71fd341f.jpg'),
(11958, 765, 'Flash S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11959, 765, 'Flash S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11960, 765, 'Flash S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11961, 765, 'Flash S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11962, 765, 'Flash S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11963, 765, 'Flash S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11964, 765, 'Flash S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11965, 765, 'Flash S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11966, 765, 'Flash S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11967, 765, 'Flash S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11968, 765, 'Flash S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11969, 765, 'Flash S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11970, 765, 'Flash S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11971, 765, 'Flash S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11972, 765, 'Flash S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11973, 765, 'Flash S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11974, 765, 'Flash S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/215204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11975, 765, 'Flash S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/215205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11976, 765, 'Flash S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/215206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11977, 765, 'Flash S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/215207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11978, 765, 'Flash S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/215208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11979, 765, 'Flash S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/215209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11980, 765, 'Flash S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/215210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11981, 766, 'Flash S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11982, 766, 'Flash S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11983, 766, 'Flash S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11984, 766, 'Flash S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11985, 766, 'Flash S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11986, 766, 'Flash S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11987, 766, 'Flash S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11988, 766, 'Flash S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11989, 766, 'Flash S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11990, 766, 'Flash S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11991, 766, 'Flash S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11992, 766, 'Flash S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11993, 766, 'Flash S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11994, 766, 'Flash S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11995, 766, 'Flash S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11996, 766, 'Flash S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11997, 766, 'Flash S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/215227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11998, 766, 'Flash S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/215228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(11999, 766, 'Flash S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/215229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12000, 766, 'Flash S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/215230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12001, 766, 'Flash S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/215231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12002, 766, 'Flash S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/215232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12003, 766, 'Flash S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/215233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12004, 767, 'Flash S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12005, 767, 'Flash S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12006, 767, 'Flash S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12007, 767, 'Flash S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12008, 767, 'Flash S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12009, 767, 'Flash S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12010, 767, 'Flash S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12011, 767, 'Flash S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12012, 767, 'Flash S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12013, 767, 'Flash S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12014, 767, 'Flash S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12015, 767, 'Flash S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12016, 767, 'Flash S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12017, 767, 'Flash S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12018, 767, 'Flash S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12019, 767, 'Flash S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12020, 767, 'Flash S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/215250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12021, 767, 'Flash S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/215251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12022, 767, 'Flash S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/215252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12023, 767, 'Flash S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/215253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12024, 767, 'Flash S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/215254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12025, 767, 'Flash S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/215255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12026, 767, 'Flash S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/215256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12027, 768, 'Flash S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12028, 768, 'Flash S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12029, 768, 'Flash S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12030, 768, 'Flash S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12031, 768, 'Flash S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12032, 768, 'Flash S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12033, 768, 'Flash S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12034, 768, 'Flash S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12035, 768, 'Flash S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12036, 768, 'Flash S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12037, 768, 'Flash S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12038, 768, 'Flash S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12039, 768, 'Flash S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12040, 768, 'Flash S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12041, 768, 'Flash S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12042, 768, 'Flash S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12043, 768, 'Flash S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/215273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12044, 768, 'Flash S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/215274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12045, 768, 'Flash S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/215275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12046, 768, 'Flash S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/215276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12047, 768, 'Flash S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/215277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12048, 768, 'Flash S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/215278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12049, 768, 'Flash S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/215279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12050, 769, 'Flash S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12051, 769, 'Flash S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12052, 769, 'Flash S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12053, 769, 'Flash S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12054, 769, 'Flash S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12055, 769, 'Flash S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215285.mkv', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12056, 769, 'Flash S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215286.mp4', 'http://timg.bdta.pro/images/uc7JijVE88SwXiuhNi5KcaskhZZ_small.jpg'),
(12057, 769, 'Flash S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215287.mkv', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12058, 769, 'Flash S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12059, 769, 'Flash S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12060, 769, 'Flash S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12061, 769, 'Flash S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12062, 769, 'Flash S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12063, 769, 'Flash S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12064, 769, 'Flash S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12065, 769, 'Flash S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12066, 769, 'Flash S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/215296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12067, 769, 'Flash S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/215297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12068, 769, 'Flash S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/215298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12069, 769, 'Flash S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/215299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12070, 769, 'Flash S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/215300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12071, 769, 'Flash S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/215301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFxIoMKqkgTuxpghTPHBjoVstMV.jpg'),
(12072, 770, 'Flash S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215302.mp4', 'http://timg.bdta.pro/images/8c2d9211042120fd73e82ad2b8e9e09f.jpg'),
(12073, 770, 'Flash S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215303.mp4', 'http://timg.bdta.pro/images/49d7ededf281848c907c0f6d11b3b3d2.jpg'),
(12074, 770, 'Flash S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215304.mp4', 'http://timg.bdta.pro/images/b1b0a65f8b760548765630d67ea2d85c.jpg'),
(12075, 770, 'Flash S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215305.mp4', 'http://timg.bdta.pro/images/3c444af311b47ee466531dc6a60d3f29.jpg'),
(12076, 770, 'Flash S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215306.mp4', 'http://timg.bdta.pro/images/fcbb5f5c0ab465fa4567692515227369.jpg'),
(12077, 770, 'Flash S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215307.mp4', 'http://timg.bdta.pro/images/05b0bf814c887f2eee27ac2abaaddb78.jpg'),
(12078, 770, 'Flash S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215308.mp4', 'http://timg.bdta.pro/images/d3010742313f25c09cb3f8dacc39798f.jpg'),
(12079, 770, 'Flash S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215309.mp4', 'http://timg.bdta.pro/images/139105d32f51d5715ca60dcf8696c01c.jpg'),
(12080, 770, 'Flash S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215310.mp4', 'http://timg.bdta.pro/images/a6534b8dea1795edf486a84328c53984.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(12081, 770, 'Flash S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215311.mp4', 'http://timg.bdta.pro/images/f1dc04b3c2836e8c114b4a2fb909221d.jpg'),
(12082, 770, 'Flash S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215312.mp4', 'http://timg.bdta.pro/images/edb6f1d3dafb4f346327655da9d7f79c.jpg'),
(12083, 770, 'Flash S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215313.mp4', 'http://timg.bdta.pro/images/4f4b22407ffd28b8007b1df6301aaf0e.jpg'),
(12084, 770, 'Flash S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215314.mp4', 'http://timg.bdta.pro/images/4875576f09eec1778cf5e1605573f83a.jpg'),
(12085, 770, 'Flash S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215315.mp4', 'http://timg.bdta.pro/images/1f5f17d0f74bff24d7d624eb93796cb2.jpg'),
(12086, 770, 'Flash S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215316.mp4', 'http://timg.bdta.pro/images/b33b1901ae5c09f1eaab1905c23ee9b6.jpg'),
(12087, 770, 'Flash S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215317.mp4', 'http://timg.bdta.pro/images/e93df21b25cad0c05b1265b6ad4f98c7.jpg'),
(12088, 770, 'Flash S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/215318.mp4', 'http://timg.bdta.pro/images/409cd111eaf6648634ee0ffca7f55752.jpg'),
(12089, 770, 'Flash S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/215319.mp4', 'http://timg.bdta.pro/images/429a41bbbdfbbdfd73d35ddb5385b8b4.jpg'),
(12090, 770, 'Flash S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/215320.mp4', 'http://timg.bdta.pro/images/221b24c846ca27173405c3f104f80b83.jpg'),
(12091, 771, 'Flash S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215321.mp4', 'http://timg.bdta.pro/images/342a04a5f70b710188d6c79662bef6bd.jpg'),
(12092, 771, 'Flash S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215322.mp4', 'http://timg.bdta.pro/images/b58261297ffeec5787a1977032cb65a6.jpg'),
(12093, 771, 'Flash S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215323.mp4', 'http://timg.bdta.pro/images/e4bef60cb56baab74e6e5d3318c8371b.jpg'),
(12094, 771, 'Flash S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215324.mp4', 'http://timg.bdta.pro/images/9331ba509f1477875ef637a2b8804cdb.jpg'),
(12095, 771, 'Flash S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215325.mp4', 'http://timg.bdta.pro/images/2a7d275736f783559f7a6862e5a7a050.jpg'),
(12096, 771, 'Flash S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215326.mp4', 'http://timg.bdta.pro/images/d4021831e2270151c00d8d26a98208d8.jpg'),
(12097, 771, 'Flash S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215327.mp4', 'http://timg.bdta.pro/images/cbd4a634f1b922b3da42d1ccfc9d4a3b.jpg'),
(12098, 771, 'Flash S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215328.mp4', 'http://timg.bdta.pro/images/f5023f788ad8f25f6e565ffabebcc443.jpg'),
(12099, 771, 'Flash S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215329.mp4', 'http://timg.bdta.pro/images/5e07ba3cc9f0a8b10abdcfdfc646d3d8.jpg'),
(12100, 771, 'Flash S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215330.mp4', 'http://timg.bdta.pro/images/ff4af6b170632ae17105aac5e0790c29.jpg'),
(12101, 771, 'Flash S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215331.mp4', 'http://timg.bdta.pro/images/503f9dedab92524fca93e94163c59c4c.jpg'),
(12102, 771, 'Flash S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215332.mp4', 'http://timg.bdta.pro/images/8c1036c4ce014a8de13fcb3b924f3c30.jpg'),
(12103, 771, 'Flash S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215333.mp4', 'http://timg.bdta.pro/images/2a8c3980e68af7023e044cd097f9edb5.jpg'),
(12104, 771, 'Flash S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215334.mp4', 'http://timg.bdta.pro/images/7d52b7969619352be0d8f0776fd2151d.jpg'),
(12105, 771, 'Flash S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215335.mp4', 'http://timg.bdta.pro/images/a8e17fe3647fa90a7b66b2b01b38eda6.jpg'),
(12106, 771, 'Flash S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215336.mp4', 'http://timg.bdta.pro/images/db3cc68089fe559556b4228421a93093.jpg'),
(12107, 771, 'Flash S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/215337.mp4', 'http://timg.bdta.pro/images/9e32111460ed005a7833c6923b6d364a.jpg'),
(12108, 771, 'Flash S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/215338.mp4', 'http://timg.bdta.pro/images/9cfeb3aa2ba7380f149fa3db88e958ee.jpg'),
(12109, 772, 'Flash S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215339.mp4', 'http://image.tmdb.org/t/p/w1280/btxoq1RGpcnEBmqAra5yFU63VCS.jpg'),
(12110, 772, 'Flash S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215340.mp4', 'http://image.tmdb.org/t/p/w1280/gBpdIhf92UffxDIGEEkHhstQugQ.jpg'),
(12111, 772, 'Flash S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xrgK4eftY5k2k3whdWkUYh9Fg5s.jpg'),
(12112, 772, 'Flash S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rPQtmrYMAT3bSp9RO2CnkMbFEIu.jpg'),
(12113, 772, 'Flash S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215343.mp4', 'http://image.tmdb.org/t/p/w1280/a60PsRobF9Upa7sM5RV2iUys54j.jpg'),
(12114, 772, 'Flash S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215344.mp4', 'http://timg.bdta.pro/images/6b5d79da0fddac3d23ea82c4a1f73111.jpg'),
(12115, 772, 'Flash S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215345.mp4', 'http://timg.bdta.pro/images/787673408b1a2d3001fa1d48f754ee1f.jpg'),
(12116, 772, 'Flash S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215346.mp4', 'http://timg.bdta.pro/images/3e05ab787f32793166e1c6729f64c3b0.jpg'),
(12117, 772, 'Flash S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215347.mp4', 'http://timg.bdta.pro/images/2ca0299ec4d53418dea8f48b83c6bce9.jpg'),
(12118, 772, 'Flash S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215348.mp4', 'http://timg.bdta.pro/images/fa85ab5ee94f3be99e3d549ba015a9b6.jpg'),
(12119, 772, 'Flash S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215349.mp4', 'http://timg.bdta.pro/images/a223e5a687a20499a7d7077b4a04fe08.jpg'),
(12120, 772, 'Flash S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215350.mp4', 'http://timg.bdta.pro/images/4b38ce10063b20dd97245c525db308a8.jpg'),
(12121, 772, 'Flash S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215351.mp4', 'http://timg.bdta.pro/images/0f6199235e0be535562c697bae43f78b.jpg'),
(12122, 772, 'Flash S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215352.mp4', 'http://timg.bdta.pro/images/4ee2b37ece5d73a20ebc613f23c6096a.jpg'),
(12123, 772, 'Flash S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215353.mp4', 'http://timg.bdta.pro/images/c583eb7ab40959fe090e8df36d207e1f.jpg'),
(12124, 772, 'Flash S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215354.mp4', 'http://timg.bdta.pro/images/6fe7ad566c6e0a0be371dea3fe9298ab.jpg'),
(12125, 772, 'Flash S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/215355.mp4', 'http://timg.bdta.pro/images/837a809638bf83810bad7efd7c615477.jpg'),
(12126, 772, 'Flash S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/215356.mp4', 'http://timg.bdta.pro/images/5db7a8368ede6298605c72e3d42b3a3e.jpg'),
(12127, 772, 'Flash S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/215357.mp4', 'http://timg.bdta.pro/images/4b43a2f3adf53965aa6a52d619f31b81.jpg'),
(12128, 772, 'Flash S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/215358.mp4', 'http://timg.bdta.pro/images/3aef69a31c340f876c6570a8df8b4862.jpg'),
(12129, 773, 'Flash S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215359.mp4', 'http://image.tmdb.org/t/p/w1280/4S4XAyU71fOqHnL97cB4KueHutf.jpg'),
(12130, 773, 'Flash S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215360.mp4', 'http://image.tmdb.org/t/p/w1280/kZV0EQL8pmLQqa3Cm8lWo1r10J9.jpg'),
(12131, 773, 'Flash S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215361.mp4', 'http://image.tmdb.org/t/p/w1280/lBUAtHlKIAKNQG0KAf5WH9DaikF.jpg'),
(12132, 773, 'Flash S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215362.mp4', 'http://image.tmdb.org/t/p/w1280/lnPULvDX1dfGfC23fDdJj8zQGMR.jpg'),
(12133, 773, 'Flash S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215363.mp4', 'http://image.tmdb.org/t/p/w1280/qeUVFYGswpWUqnluvQmCVVwSTOm.jpg'),
(12134, 773, 'Flash S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215364.mp4', 'http://image.tmdb.org/t/p/w1280/g0xY1gF9fQtquuRGQeiBlGAIVaI.jpg'),
(12135, 773, 'Flash S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215365.mp4', 'http://image.tmdb.org/t/p/w1280/7rsAFeWUft4q3eq9gqXaZYzbeVs.jpg'),
(12136, 773, 'Flash S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215366.mp4', 'http://image.tmdb.org/t/p/w1280/tCJutF1brVERN77ORR3VQNsev0h.jpg'),
(12137, 773, 'Flash S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215367.mp4', 'http://image.tmdb.org/t/p/w1280/sRcyVNPd43rxTRSdnAEbizbeXMZ.jpg'),
(12138, 773, 'Flash S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215368.mp4', 'http://image.tmdb.org/t/p/w1280/mEuzzEYCWjnaocPuvJGbmAV8lL1.jpg'),
(12139, 773, 'Flash S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215369.mp4', 'http://image.tmdb.org/t/p/w1280/4XwTComc7dHQ5RFveWlMuPRFGz0.jpg'),
(12140, 773, 'Flash S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215370.mp4', 'http://image.tmdb.org/t/p/w1280/jEqKyagrsoPhjhzze7ckBbwTBAV.jpg'),
(12141, 773, 'Flash S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215371.mp4', 'http://image.tmdb.org/t/p/w1280/mTl6JlhrGjqexyphqCFGCTzrJE8.jpg'),
(12142, 774, 'The Good Doctor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236111.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12143, 774, 'The Good Doctor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236112.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12144, 774, 'The Good Doctor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236113.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12145, 774, 'The Good Doctor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236114.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12146, 774, 'The Good Doctor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236115.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12147, 774, 'The Good Doctor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236116.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12148, 774, 'The Good Doctor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236117.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12149, 774, 'The Good Doctor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236118.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12150, 774, 'The Good Doctor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236119.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12151, 774, 'The Good Doctor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236120.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12152, 774, 'The Good Doctor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236121.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12153, 774, 'The Good Doctor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236122.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12154, 774, 'The Good Doctor S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236123.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12155, 774, 'The Good Doctor S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236124.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12156, 774, 'The Good Doctor S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236125.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12157, 774, 'The Good Doctor S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236126.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12158, 774, 'The Good Doctor S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236127.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12159, 774, 'The Good Doctor S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236128.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12160, 775, 'The Good Doctor S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236129.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12161, 775, 'The Good Doctor S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236130.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12162, 775, 'The Good Doctor S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236131.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12163, 775, 'The Good Doctor S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236132.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12164, 775, 'The Good Doctor S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236133.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12165, 775, 'The Good Doctor S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236134.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12166, 775, 'The Good Doctor S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236135.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12167, 775, 'The Good Doctor S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236136.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12168, 775, 'The Good Doctor S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236137.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12169, 775, 'The Good Doctor S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236138.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12170, 775, 'The Good Doctor S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236139.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12171, 775, 'The Good Doctor S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236140.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12172, 775, 'The Good Doctor S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236141.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12173, 775, 'The Good Doctor S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236142.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12174, 775, 'The Good Doctor S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236143.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12175, 775, 'The Good Doctor S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236144.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12176, 775, 'The Good Doctor S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236145.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12177, 775, 'The Good Doctor S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236146.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12178, 776, 'The Good Doctor S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236147.mp4', 'http://timg.bdta.pro/images/3dcb71f51728faf2e8b8635548bfbb90.jpg'),
(12179, 776, 'The Good Doctor S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236148.mp4', 'http://timg.bdta.pro/images/e60aae230559df7766b5453443eea5a8.jpg'),
(12180, 776, 'The Good Doctor S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236149.mp4', 'http://timg.bdta.pro/images/b381848802910328dc418381c094d565.jpg'),
(12181, 776, 'The Good Doctor S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236150.mp4', 'http://timg.bdta.pro/images/d22be35d525e898d442314a965064a17.jpg'),
(12182, 776, 'The Good Doctor S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236151.mp4', 'http://timg.bdta.pro/images/1470132479c6d9f1461e72376fcfadce.jpg'),
(12183, 776, 'The Good Doctor S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236152.mp4', 'http://timg.bdta.pro/images/30c6b02e6593eae7560151d6016324aa.jpg'),
(12184, 776, 'The Good Doctor S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236153.mp4', 'http://timg.bdta.pro/images/37184f2c412c0dc41647117c4c1c57c5.jpg'),
(12185, 776, 'The Good Doctor S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236154.mp4', 'http://timg.bdta.pro/images/bfa2f3ca78d3b1c76d6d0bdbc44db276.jpg'),
(12186, 776, 'The Good Doctor S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236155.mp4', 'http://timg.bdta.pro/images/75505e800e5dba18db57a7dc72f4eb69.jpg'),
(12187, 776, 'The Good Doctor S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236156.mp4', 'http://timg.bdta.pro/images/03c7c6beabbd5f3b9f28e18ba4649075.jpg'),
(12188, 776, 'The Good Doctor S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236157.mp4', 'http://timg.bdta.pro/images/96e1c2d71e34d4e7f818ceb5b7f043a4.jpg'),
(12189, 776, 'The Good Doctor S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236158.mp4', 'http://timg.bdta.pro/images/d774f1c5da67bd75a755105b5f10c2e2.jpg'),
(12190, 776, 'The Good Doctor S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236159.mp4', 'http://timg.bdta.pro/images/36aa04509dab41ad524911abbaea8b41.jpg'),
(12191, 776, 'The Good Doctor S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236160.mp4', 'http://timg.bdta.pro/images/063c56f3dd8423221a926b1a1c67814f.jpg'),
(12192, 776, 'The Good Doctor S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236161.mp4', 'http://timg.bdta.pro/images/f2e5181cbb69481c751c89c1de499d46.jpg'),
(12193, 776, 'The Good Doctor S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236162.mp4', 'http://timg.bdta.pro/images/fd76da48ef6160a54eaf32d8cba26691.jpg'),
(12194, 776, 'The Good Doctor S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236163.mp4', 'http://timg.bdta.pro/images/33a4f39fcbec4bac65b0391810017151.jpg'),
(12195, 776, 'The Good Doctor S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236164.mp4', 'http://timg.bdta.pro/images/4210ee15d7f06ab71af8066410f3d18b.jpg'),
(12196, 776, 'The Good Doctor S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/236165.mp4', 'http://timg.bdta.pro/images/56f98c7f9489c14f3966e410ec26334a.jpg'),
(12197, 776, 'The Good Doctor S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/236166.mp4', 'http://timg.bdta.pro/images/8984853e973f8771091a4aec5b3c0fa6.jpg'),
(12198, 777, 'The Good Doctor S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236167.mp4', 'http://timg.bdta.pro/images/5c562cbe6e795b955e0c917e549080e8.jpg'),
(12199, 777, 'The Good Doctor S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236168.mp4', 'http://timg.bdta.pro/images/7d7865f2d79151eb82b91be5c23622ae.jpg'),
(12200, 777, 'The Good Doctor S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236169.mp4', 'http://timg.bdta.pro/images/5b7e60c9b9975e67b4396f0d4cf5106c.jpg'),
(12201, 777, 'The Good Doctor S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236170.mp4', 'http://timg.bdta.pro/images/8ae3a22d26724f60fd3dba033df64325.jpg'),
(12202, 777, 'The Good Doctor S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236171.mp4', 'http://timg.bdta.pro/images/831e7f1c114233a3d38e4bc384aa2690.jpg'),
(12203, 777, 'The Good Doctor S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236172.mp4', 'http://timg.bdta.pro/images/f758904117698e09713a58d63b28ae06.jpg'),
(12204, 777, 'The Good Doctor S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236173.mp4', 'http://timg.bdta.pro/images/84045d8cbe3238e37cba4bcedc6b9228.jpg'),
(12205, 777, 'The Good Doctor S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236174.mp4', 'http://timg.bdta.pro/images/989fa7b4772504174370838329ff2a5c.jpg'),
(12206, 777, 'The Good Doctor S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236175.mp4', 'http://timg.bdta.pro/images/3f76b7dbc17871cf72f1d0cd008eca0e.jpg'),
(12207, 777, 'The Good Doctor S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236176.mp4', 'http://timg.bdta.pro/images/8773af5948761e8577ed542e1f57d012.jpg'),
(12208, 777, 'The Good Doctor S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236177.mp4', 'http://timg.bdta.pro/images/c48716afb38fc07ac3cd68080808ffcf.jpg'),
(12209, 777, 'The Good Doctor S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236178.mp4', 'http://timg.bdta.pro/images/e32fe5c866ec5fc569636663e80d3249.jpg'),
(12210, 777, 'The Good Doctor S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236179.mp4', 'http://timg.bdta.pro/images/f80a04886450b413cb0323d256538792.jpg'),
(12211, 777, 'The Good Doctor S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236180.mp4', 'http://timg.bdta.pro/images/249e20b08cb16228cf66684a1b617d55.jpg'),
(12212, 777, 'The Good Doctor S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236181.mp4', 'http://timg.bdta.pro/images/4f263d3ef098f39a1078278b221d87f4.jpg'),
(12213, 777, 'The Good Doctor S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236182.mp4', 'http://timg.bdta.pro/images/a26ad88596089a655557c83f81128ecd.jpg'),
(12214, 777, 'The Good Doctor S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236183.mp4', 'http://timg.bdta.pro/images/3cd13b242751271bd7234be3af94d1f5.jpg'),
(12215, 777, 'The Good Doctor S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236184.mp4', 'http://timg.bdta.pro/images/deeb2ab5c8230beb9df409393399be22.jpg'),
(12216, 777, 'The Good Doctor S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/236185.mp4', 'http://timg.bdta.pro/images/8e61bd0aa981356e973e0140ca561f0d.jpg'),
(12217, 777, 'The Good Doctor S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/236186.mp4', 'http://timg.bdta.pro/images/90c75778f30e1cb826e8edbbadf9aff5.jpg'),
(12218, 778, 'The Good Doctor S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236187.mp4', 'http://timg.bdta.pro/images/14562bb329281d7b9c9e239e988e1811.jpg'),
(12219, 778, 'The Good Doctor S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236188.mp4', 'http://timg.bdta.pro/images/06d86c01ec0bb835da47951ae11365ac.jpg'),
(12220, 778, 'The Good Doctor S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236189.mp4', 'http://timg.bdta.pro/images/94c832fc47c1fb69154adcfd04447a2d.jpg'),
(12221, 778, 'The Good Doctor S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236190.mp4', 'http://timg.bdta.pro/images/6e2c1b02b5f91652b988bafb9a6387c9.jpg'),
(12222, 778, 'The Good Doctor S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236191.mp4', 'http://timg.bdta.pro/images/846374c9dfc3fca05159f025b37a56b7.jpg'),
(12223, 778, 'The Good Doctor S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236192.mp4', 'http://timg.bdta.pro/images/2af7dc368ab9a79523f2ac20c2e58d54.jpg'),
(12224, 778, 'The Good Doctor S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236193.mp4', 'http://timg.bdta.pro/images/ea43fb77f33950865657ae5e39382015.jpg'),
(12225, 778, 'The Good Doctor S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236194.mp4', 'http://timg.bdta.pro/images/966718c9515a4cf7bb64197e137c762a.jpg'),
(12226, 778, 'The Good Doctor S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236195.mp4', 'http://timg.bdta.pro/images/d0aee0e747f1412e3d516a8973261875.jpg'),
(12227, 778, 'The Good Doctor S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236196.mp4', 'http://timg.bdta.pro/images/fada14d3b5562b0e35c294d4f2ca7368.jpg'),
(12228, 778, 'The Good Doctor S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236197.mp4', 'http://timg.bdta.pro/images/8930504f459676791c29df4aaa6d9b31.jpg'),
(12229, 778, 'The Good Doctor S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236198.mp4', 'http://timg.bdta.pro/images/dc155495a7975a8ee7aa215d1f836950.jpg'),
(12230, 778, 'The Good Doctor S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236199.mp4', 'http://timg.bdta.pro/images/6f34966ed725649b649f4869086964c5.jpg'),
(12231, 778, 'The Good Doctor S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236200.mp4', 'http://timg.bdta.pro/images/cd6177292224b177cf6ec78aab349c19.jpg'),
(12232, 778, 'The Good Doctor S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236201.mp4', 'http://timg.bdta.pro/images/735d011fd852b4ae6958a3c138c04773.jpg'),
(12233, 778, 'The Good Doctor S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236202.mp4', 'http://timg.bdta.pro/images/0309e8e2508175813f597334bb4089e0.jpg'),
(12234, 778, 'The Good Doctor S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236203.mp4', 'http://timg.bdta.pro/images/b93ee49ecfec660cefac95a55ae37365.jpg'),
(12235, 778, 'The Good Doctor S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236204.mp4', 'http://timg.bdta.pro/images/11fb88831046828d3c7a4cafb1e6d0d0.jpg'),
(12236, 779, 'The Good Doctor S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jiwfFwM6DyEGMsq86n6WotqEML3.jpg'),
(12237, 779, 'The Good Doctor S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tVtGgTvlpk0uOBFU3zpSdtFjn6Q.jpg'),
(12238, 779, 'The Good Doctor S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/roCnOVshIkgrOdpJpk7FX2wPyDa.jpg'),
(12239, 779, 'The Good Doctor S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8AIjk2dNEOOOfpRxvVsC8smg0Ev.jpg'),
(12240, 779, 'The Good Doctor S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xAdcwwUGBMLSDK7AmNYbCq7vDQR.jpg'),
(12241, 779, 'The Good Doctor S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pEBWrz8eMp0SZeO96z1hl7WVkyP.jpg'),
(12242, 779, 'The Good Doctor S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x8oyBQ0Sfbo7jeaQQDYGqtjApOJ.jpg'),
(12243, 779, 'The Good Doctor S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bnDUPqjGoyzFoJZyGfX95TcdDWp.jpg'),
(12244, 779, 'The Good Doctor S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/92Aw0sMgAj5XZX4vk31DoZDncog.jpg'),
(12245, 779, 'The Good Doctor S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236214.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12246, 779, 'The Good Doctor S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236215.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12247, 779, 'The Good Doctor S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236216.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12248, 779, 'The Good Doctor S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236217.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12249, 779, 'The Good Doctor S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236218.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12250, 779, 'The Good Doctor S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236219.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12251, 779, 'The Good Doctor S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236220.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12252, 779, 'The Good Doctor S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236221.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12253, 779, 'The Good Doctor S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236222.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12254, 779, 'The Good Doctor S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/236223.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12255, 779, 'The Good Doctor S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/236224.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12256, 779, 'The Good Doctor S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/236225.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12257, 779, 'The Good Doctor S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/236226.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12258, 780, 'The Good Doctor S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/400182.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12259, 780, 'The Good Doctor S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/400183.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12260, 780, 'The Good Doctor S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/400184.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12261, 780, 'The Good Doctor S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/400185.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12262, 780, 'The Good Doctor S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/400186.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12263, 780, 'The Good Doctor S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/400187.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12264, 780, 'The Good Doctor S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/400188.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12265, 780, 'The Good Doctor S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/400189.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12266, 780, 'The Good Doctor S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/400190.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12267, 780, 'The Good Doctor S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/400191.mp4', 'http://gstaticontent.com/images/jtLB7xJKcbekmOYkb5NZditBsgk_big.jpg'),
(12268, 781, 'O Último Navio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12269, 781, 'O Último Navio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12270, 781, 'O Último Navio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12271, 781, 'O Último Navio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12272, 781, 'O Último Navio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12273, 781, 'O Último Navio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12274, 781, 'O Último Navio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12275, 781, 'O Último Navio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12276, 781, 'O Último Navio S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12277, 781, 'O Último Navio S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12278, 782, 'O Último Navio S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12279, 782, 'O Último Navio S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12280, 782, 'O Último Navio S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12281, 782, 'O Último Navio S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12282, 782, 'O Último Navio S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12283, 782, 'O Último Navio S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12284, 782, 'O Último Navio S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12285, 782, 'O Último Navio S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12286, 782, 'O Último Navio S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12287, 782, 'O Último Navio S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12288, 782, 'O Último Navio S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/210053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12289, 782, 'O Último Navio S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/210054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12290, 782, 'O Último Navio S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/210055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12291, 783, 'O Último Navio S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12292, 783, 'O Último Navio S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12293, 783, 'O Último Navio S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12294, 783, 'O Último Navio S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12295, 783, 'O Último Navio S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12296, 783, 'O Último Navio S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12297, 783, 'O Último Navio S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12298, 783, 'O Último Navio S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12299, 783, 'O Último Navio S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12300, 783, 'O Último Navio S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12301, 783, 'O Último Navio S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/210066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12302, 783, 'O Último Navio S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/210067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12303, 783, 'O Último Navio S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/210068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12304, 784, 'O Último Navio S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12305, 784, 'O Último Navio S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12306, 784, 'O Último Navio S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12307, 784, 'O Último Navio S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12308, 784, 'O Último Navio S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12309, 784, 'O Último Navio S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12310, 784, 'O Último Navio S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12311, 784, 'O Último Navio S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12312, 784, 'O Último Navio S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12313, 784, 'O Último Navio S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12314, 785, 'O Último Navio S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12315, 785, 'O Último Navio S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12316, 785, 'O Último Navio S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12317, 785, 'O Último Navio S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12318, 785, 'O Último Navio S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12319, 785, 'O Último Navio S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12320, 785, 'O Último Navio S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12321, 785, 'O Último Navio S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12322, 785, 'O Último Navio S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12323, 785, 'O Último Navio S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cG0knRS3OZIhxsQDkYZPYJHhfCP.jpg'),
(12324, 786, 'The O C - Um Estranho No Paraiso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140263.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12325, 786, 'The O C - Um Estranho No Paraiso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140264.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12326, 786, 'The O C - Um Estranho No Paraiso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140265.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12327, 786, 'The O C - Um Estranho No Paraiso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140266.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12328, 786, 'The O C - Um Estranho No Paraiso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140267.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12329, 786, 'The O C - Um Estranho No Paraiso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140268.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12330, 786, 'The O C - Um Estranho No Paraiso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140269.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12331, 786, 'The O C - Um Estranho No Paraiso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140270.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12332, 786, 'The O C - Um Estranho No Paraiso S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140271.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12333, 786, 'The O C - Um Estranho No Paraiso S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140272.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12334, 786, 'The O C - Um Estranho No Paraiso S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140273.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12335, 786, 'The O C - Um Estranho No Paraiso S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140274.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12336, 786, 'The O C - Um Estranho No Paraiso S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140275.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12337, 786, 'The O C - Um Estranho No Paraiso S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/140276.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12338, 786, 'The O C - Um Estranho No Paraiso S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/140277.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12339, 786, 'The O C - Um Estranho No Paraiso S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/140278.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12340, 786, 'The O C - Um Estranho No Paraiso S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/140279.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12341, 786, 'The O C - Um Estranho No Paraiso S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/140280.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12342, 786, 'The O C - Um Estranho No Paraiso S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/140281.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12343, 786, 'The O C - Um Estranho No Paraiso S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/140282.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12344, 786, 'The O C - Um Estranho No Paraiso S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/140283.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12345, 786, 'The O C - Um Estranho No Paraiso S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/140284.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12346, 786, 'The O C - Um Estranho No Paraiso S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/140285.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12347, 786, 'The O C - Um Estranho No Paraiso S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/140286.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12348, 786, 'The O C - Um Estranho No Paraiso S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/140287.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12349, 786, 'The O C - Um Estranho No Paraiso S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/140288.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12350, 786, 'The O C - Um Estranho No Paraiso S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/140289.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12351, 787, 'The O C - Um Estranho No Paraiso S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140290.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12352, 787, 'The O C - Um Estranho No Paraiso S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140291.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12353, 787, 'The O C - Um Estranho No Paraiso S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140292.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12354, 787, 'The O C - Um Estranho No Paraiso S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140293.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12355, 787, 'The O C - Um Estranho No Paraiso S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140294.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12356, 787, 'The O C - Um Estranho No Paraiso S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140295.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12357, 787, 'The O C - Um Estranho No Paraiso S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140296.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12358, 787, 'The O C - Um Estranho No Paraiso S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140297.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12359, 787, 'The O C - Um Estranho No Paraiso S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140298.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12360, 787, 'The O C - Um Estranho No Paraiso S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140299.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12361, 787, 'The O C - Um Estranho No Paraiso S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140300.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12362, 787, 'The O C - Um Estranho No Paraiso S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140301.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(12363, 787, 'The O C - Um Estranho No Paraiso S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140302.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12364, 787, 'The O C - Um Estranho No Paraiso S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/140303.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12365, 787, 'The O C - Um Estranho No Paraiso S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/140304.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12366, 787, 'The O C - Um Estranho No Paraiso S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/140305.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12367, 787, 'The O C - Um Estranho No Paraiso S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/140306.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12368, 787, 'The O C - Um Estranho No Paraiso S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/140307.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12369, 787, 'The O C - Um Estranho No Paraiso S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/140308.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12370, 787, 'The O C - Um Estranho No Paraiso S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/140309.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12371, 787, 'The O C - Um Estranho No Paraiso S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/140310.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12372, 787, 'The O C - Um Estranho No Paraiso S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/140311.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12373, 787, 'The O C - Um Estranho No Paraiso S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/140312.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12374, 787, 'The O C - Um Estranho No Paraiso S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/140313.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12375, 788, 'The O C - Um Estranho No Paraiso S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140314.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12376, 788, 'The O C - Um Estranho No Paraiso S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140315.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12377, 788, 'The O C - Um Estranho No Paraiso S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140316.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12378, 788, 'The O C - Um Estranho No Paraiso S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140317.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12379, 788, 'The O C - Um Estranho No Paraiso S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140318.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12380, 788, 'The O C - Um Estranho No Paraiso S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140319.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12381, 788, 'The O C - Um Estranho No Paraiso S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140320.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12382, 788, 'The O C - Um Estranho No Paraiso S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140321.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12383, 788, 'The O C - Um Estranho No Paraiso S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140322.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12384, 788, 'The O C - Um Estranho No Paraiso S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140323.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12385, 788, 'The O C - Um Estranho No Paraiso S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140324.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12386, 788, 'The O C - Um Estranho No Paraiso S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140325.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12387, 788, 'The O C - Um Estranho No Paraiso S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140326.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12388, 788, 'The O C - Um Estranho No Paraiso S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/140327.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12389, 788, 'The O C - Um Estranho No Paraiso S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/140328.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12390, 788, 'The O C - Um Estranho No Paraiso S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/140329.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12391, 788, 'The O C - Um Estranho No Paraiso S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/140330.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12392, 788, 'The O C - Um Estranho No Paraiso S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/140331.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12393, 788, 'The O C - Um Estranho No Paraiso S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/140332.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12394, 788, 'The O C - Um Estranho No Paraiso S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/140333.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12395, 788, 'The O C - Um Estranho No Paraiso S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/140334.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12396, 788, 'The O C - Um Estranho No Paraiso S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/140335.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12397, 788, 'The O C - Um Estranho No Paraiso S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/140336.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12398, 788, 'The O C - Um Estranho No Paraiso S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/140337.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12399, 788, 'The O C - Um Estranho No Paraiso S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/140338.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12400, 789, 'The O C - Um Estranho No Paraiso S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140339.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12401, 789, 'The O C - Um Estranho No Paraiso S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140340.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12402, 789, 'The O C - Um Estranho No Paraiso S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140341.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12403, 789, 'The O C - Um Estranho No Paraiso S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140342.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12404, 789, 'The O C - Um Estranho No Paraiso S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140343.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12405, 789, 'The O C - Um Estranho No Paraiso S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140344.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12406, 789, 'The O C - Um Estranho No Paraiso S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140345.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12407, 789, 'The O C - Um Estranho No Paraiso S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140346.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12408, 789, 'The O C - Um Estranho No Paraiso S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140347.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12409, 789, 'The O C - Um Estranho No Paraiso S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140348.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12410, 789, 'The O C - Um Estranho No Paraiso S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140349.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12411, 789, 'The O C - Um Estranho No Paraiso S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140350.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12412, 789, 'The O C - Um Estranho No Paraiso S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140351.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12413, 789, 'The O C - Um Estranho No Paraiso S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/140352.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12414, 789, 'The O C - Um Estranho No Paraiso S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/140353.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12415, 789, 'The O C - Um Estranho No Paraiso S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/140354.mp4', 'http://gstaticontent.com/images/6WbpU2WTW13wbLEoSoQFNLukM09_big.jpg'),
(12416, 790, 'Os Originais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12417, 790, 'Os Originais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12418, 790, 'Os Originais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12419, 790, 'Os Originais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12420, 790, 'Os Originais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12421, 790, 'Os Originais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12422, 790, 'Os Originais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12423, 790, 'Os Originais S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12424, 790, 'Os Originais S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12425, 790, 'Os Originais S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12426, 790, 'Os Originais S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12427, 790, 'Os Originais S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12428, 790, 'Os Originais S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12429, 790, 'Os Originais S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/136277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12430, 790, 'Os Originais S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/136278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12431, 790, 'Os Originais S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/136279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12432, 790, 'Os Originais S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/136280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12433, 790, 'Os Originais S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/136281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12434, 790, 'Os Originais S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/136282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12435, 790, 'Os Originais S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/136283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12436, 790, 'Os Originais S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/136284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12437, 790, 'Os Originais S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/136285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12438, 791, 'Os Originais S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12439, 791, 'Os Originais S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12440, 791, 'Os Originais S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12441, 791, 'Os Originais S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12442, 791, 'Os Originais S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12443, 791, 'Os Originais S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12444, 791, 'Os Originais S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12445, 791, 'Os Originais S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12446, 791, 'Os Originais S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12447, 791, 'Os Originais S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12448, 791, 'Os Originais S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12449, 791, 'Os Originais S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12450, 791, 'Os Originais S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12451, 791, 'Os Originais S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/136299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12452, 791, 'Os Originais S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/136300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12453, 791, 'Os Originais S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/136301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12454, 791, 'Os Originais S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/136302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12455, 791, 'Os Originais S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/136303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12456, 791, 'Os Originais S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/136304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12457, 791, 'Os Originais S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/136305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12458, 791, 'Os Originais S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/136306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12459, 791, 'Os Originais S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/136307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12460, 792, 'Os Originais S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12461, 792, 'Os Originais S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12462, 792, 'Os Originais S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12463, 792, 'Os Originais S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12464, 792, 'Os Originais S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12465, 792, 'Os Originais S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12466, 792, 'Os Originais S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12467, 792, 'Os Originais S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12468, 792, 'Os Originais S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12469, 792, 'Os Originais S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12470, 792, 'Os Originais S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12471, 792, 'Os Originais S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12472, 792, 'Os Originais S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12473, 792, 'Os Originais S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/136321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12474, 792, 'Os Originais S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/136322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12475, 792, 'Os Originais S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/136323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12476, 792, 'Os Originais S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/136324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12477, 792, 'Os Originais S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/136325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12478, 792, 'Os Originais S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/136326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12479, 792, 'Os Originais S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/136327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12480, 792, 'Os Originais S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/136328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12481, 792, 'Os Originais S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/136329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12482, 793, 'Os Originais S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12483, 793, 'Os Originais S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12484, 793, 'Os Originais S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12485, 793, 'Os Originais S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12486, 793, 'Os Originais S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12487, 793, 'Os Originais S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12488, 793, 'Os Originais S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12489, 793, 'Os Originais S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12490, 793, 'Os Originais S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12491, 793, 'Os Originais S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12492, 793, 'Os Originais S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12493, 793, 'Os Originais S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12494, 793, 'Os Originais S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12495, 794, 'Os Originais S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12496, 794, 'Os Originais S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12497, 794, 'Os Originais S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12498, 794, 'Os Originais S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12499, 794, 'Os Originais S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12500, 794, 'Os Originais S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12501, 794, 'Os Originais S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12502, 794, 'Os Originais S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12503, 794, 'Os Originais S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12504, 794, 'Os Originais S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12505, 794, 'Os Originais S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12506, 794, 'Os Originais S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12507, 794, 'Os Originais S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YEHjh1t9mHpdDwbqLCc04xBMY.jpg'),
(12508, 795, 'The Outpost [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159875.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12509, 795, 'The Outpost [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159876.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12510, 795, 'The Outpost [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159877.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12511, 795, 'The Outpost [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159878.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12512, 795, 'The Outpost [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159879.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12513, 795, 'The Outpost [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159880.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12514, 795, 'The Outpost [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159881.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12515, 795, 'The Outpost [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159882.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12516, 795, 'The Outpost [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159883.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12517, 795, 'The Outpost [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159884.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12518, 796, 'The Outpost [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159885.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12519, 796, 'The Outpost [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159886.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12520, 796, 'The Outpost [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159887.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12521, 796, 'The Outpost [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159888.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12522, 796, 'The Outpost [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159889.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12523, 796, 'The Outpost [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159890.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12524, 796, 'The Outpost [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159891.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12525, 796, 'The Outpost [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159892.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12526, 796, 'The Outpost [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159893.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12527, 796, 'The Outpost [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159894.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12528, 796, 'The Outpost [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159895.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12529, 796, 'The Outpost [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159896.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12530, 796, 'The Outpost [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159897.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12531, 797, 'The Outpost [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159898.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12532, 797, 'The Outpost [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159899.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12533, 797, 'The Outpost [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159900.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12534, 797, 'The Outpost [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159901.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12535, 797, 'The Outpost [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159902.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12536, 797, 'The Outpost [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159903.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12537, 797, 'The Outpost [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159904.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12538, 797, 'The Outpost [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159905.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12539, 797, 'The Outpost [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159906.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12540, 797, 'The Outpost [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159907.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12541, 797, 'The Outpost [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159908.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12542, 797, 'The Outpost [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159909.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12543, 797, 'The Outpost [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159910.mp4', 'http://gstaticontent.com/images/081a38d00b35843aa58e638537d3bc36.jpg'),
(12544, 798, 'The Outpost [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159911.mp4', 'http://timg.bdta.pro/images/dfade96b78e7e3150a70724de71f9611.jpg'),
(12545, 798, 'The Outpost [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159912.mp4', 'http://timg.bdta.pro/images/393787cde05ca3561b68e842e11f4cfe.jpg'),
(12546, 798, 'The Outpost [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159913.mp4', 'http://timg.bdta.pro/images/78c59f6f97c6d165e5d9f4a89e210393.jpg'),
(12547, 798, 'The Outpost [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159914.mp4', 'http://timg.bdta.pro/images/b07e448cdb0adf25b23abb94d0c1f4ba.jpg'),
(12548, 798, 'The Outpost [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159915.mp4', 'http://timg.bdta.pro/images/1d6beac49972450106898fcb83f6218a.jpg'),
(12549, 798, 'The Outpost [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159916.mp4', 'http://timg.bdta.pro/images/f171705b44dc8f4d9747ae7a2e00326a.jpg'),
(12550, 798, 'The Outpost [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159917.mp4', 'http://timg.bdta.pro/images/9f2b71f0d00b866f4b17abef3e2711f2.jpg'),
(12551, 798, 'The Outpost [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159918.mp4', 'http://timg.bdta.pro/images/fdfc338afeac22b42b12e52665127b1b.jpg'),
(12552, 798, 'The Outpost [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159919.mp4', 'http://timg.bdta.pro/images/a40c6029b0dd3d04bf38dc25bb39e36f.jpg'),
(12553, 798, 'The Outpost [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159920.mp4', 'http://image.tmdb.org/t/p/w1280/5k0Y3t7uaMGzHZSc4UGMl1MqA3q.jpg'),
(12554, 798, 'The Outpost [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159921.mp4', 'http://image.tmdb.org/t/p/w1280/qqZC2ROPwAODu9jl2s1b7uFWwXx.jpg'),
(12555, 798, 'The Outpost [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159922.mp4', 'http://image.tmdb.org/t/p/w1280/eQnda9ANrlwDxmHSgDpB5y3WLPG.jpg'),
(12556, 798, 'The Outpost [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159923.mp4', 'http://image.tmdb.org/t/p/w1280/iThGkIwZIYvzrQdJp7T380SDKbh.jpg'),
(12557, 799, 'O Pacífico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7bsZXJ90sesqdL4qDzkMvUSMWln.jpg'),
(12558, 799, 'O Pacífico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7bsZXJ90sesqdL4qDzkMvUSMWln.jpg'),
(12559, 799, 'O Pacífico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7bsZXJ90sesqdL4qDzkMvUSMWln.jpg'),
(12560, 799, 'O Pacífico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7bsZXJ90sesqdL4qDzkMvUSMWln.jpg'),
(12561, 799, 'O Pacífico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7bsZXJ90sesqdL4qDzkMvUSMWln.jpg'),
(12562, 799, 'O Pacífico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7bsZXJ90sesqdL4qDzkMvUSMWln.jpg'),
(12563, 799, 'O Pacífico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7bsZXJ90sesqdL4qDzkMvUSMWln.jpg'),
(12564, 799, 'O Pacífico S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7bsZXJ90sesqdL4qDzkMvUSMWln.jpg'),
(12565, 799, 'O Pacífico S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7bsZXJ90sesqdL4qDzkMvUSMWln.jpg'),
(12566, 799, 'O Pacífico S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7bsZXJ90sesqdL4qDzkMvUSMWln.jpg'),
(12567, 800, 'The Rain S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128221.mp4', 'http://timg.bdta.pro/images/61fba1756c670cc12df289b8ec071f3e.jpg'),
(12568, 800, 'The Rain S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128222.mp4', 'http://timg.bdta.pro/images/27f5f634cf7e21fc2272ae0e591ddcc5.jpg'),
(12569, 800, 'The Rain S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128223.mp4', 'http://timg.bdta.pro/images/f51923b6483372cc27999cb2c59f0719.jpg'),
(12570, 800, 'The Rain S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128224.mp4', 'http://timg.bdta.pro/images/7430501a617dde450c44b1dc5626781d.jpg'),
(12571, 800, 'The Rain S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128225.mp4', 'http://timg.bdta.pro/images/ca5ec604b5cfcfab4d1986a35028eb6e.jpg'),
(12572, 800, 'The Rain S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128226.mp4', 'http://timg.bdta.pro/images/304560c9dbae1168d230dcd62c12d6d2.jpg'),
(12573, 800, 'The Rain S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128227.mp4', 'http://timg.bdta.pro/images/366b949159a0ce57eb4b6cf9c9170784.jpg'),
(12574, 800, 'The Rain S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128228.mp4', 'http://timg.bdta.pro/images/db01603257d7c6015761796da0c967f7.jpg'),
(12575, 801, 'The Rain S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128229.mp4', 'http://timg.bdta.pro/images/2c741dfdfe760ff1347b44f8ee7dc0b8.jpg'),
(12576, 801, 'The Rain S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128230.mp4', 'http://timg.bdta.pro/images/6605cd0ed1f948bde39eb1a1cd2473a6.jpg'),
(12577, 801, 'The Rain S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128231.mp4', 'http://timg.bdta.pro/images/68fb5a9b2cb189f9107671152ee1caac.jpg'),
(12578, 801, 'The Rain S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128232.mp4', 'http://timg.bdta.pro/images/ffbe7a2de40c2ac27f6066d0cc069b1a.jpg'),
(12579, 801, 'The Rain S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128233.mp4', 'http://timg.bdta.pro/images/4e10200cdd354c489efb6e91b3d03754.jpg'),
(12580, 801, 'The Rain S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128234.mp4', 'http://timg.bdta.pro/images/a0237f998d65817c243f4398db3ca628.jpg'),
(12581, 802, 'The Rain S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128235.mp4', 'http://timg.bdta.pro/images/8654637f81254ddefc28c9618236d963.jpg'),
(12582, 802, 'The Rain S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128236.mp4', 'http://timg.bdta.pro/images/faad58b27a8253d39929eb4f7785f4bf.jpg'),
(12583, 802, 'The Rain S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128237.mp4', 'http://timg.bdta.pro/images/0e0e53b1eb0b755b6e287ed27c847571.jpg'),
(12584, 802, 'The Rain S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128238.mp4', 'http://timg.bdta.pro/images/301eedb48441ce5db1eea4f6b6cb4f69.jpg'),
(12585, 802, 'The Rain S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128239.mp4', 'http://timg.bdta.pro/images/91337bfbea9bc996f7af0f61fe29973f.jpg'),
(12586, 802, 'The Rain S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128240.mp4', 'http://timg.bdta.pro/images/03a1eed58c75d6c96049fb91c5b771eb.jpg'),
(12587, 803, 'O Rancho S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141641.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12588, 803, 'O Rancho S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141642.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12589, 803, 'O Rancho S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141643.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12590, 803, 'O Rancho S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141644.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12591, 803, 'O Rancho S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141645.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12592, 803, 'O Rancho S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141646.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12593, 803, 'O Rancho S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141647.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12594, 803, 'O Rancho S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141648.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12595, 803, 'O Rancho S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141649.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12596, 803, 'O Rancho S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141650.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12597, 803, 'O Rancho S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/889526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lxTJr2HZGTLGetiYaszophIRe2I.jpg'),
(12598, 803, 'O Rancho S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/889527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uB97jlfS9nIwqlzAd6z9w4wS8NZ.jpg'),
(12599, 803, 'O Rancho S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/889528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jHsprJbhvulGTZHzJ1klPsiTpUy.jpg'),
(12600, 803, 'O Rancho S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/889529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yVGwAIh2fnNBiSzBKYWp1pVNhpD.jpg'),
(12601, 803, 'O Rancho S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/889530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eio7EFsS7oV5fW00QJWkwFfBRFo.jpg'),
(12602, 803, 'O Rancho S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/889531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8cf0bhhKU3hohg0jwKbObuBz0DH.jpg'),
(12603, 803, 'O Rancho S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/889532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nACTWRth9dr9oAKqxjqGVbSX89k.jpg'),
(12604, 803, 'O Rancho S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/889533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uH34nb52pPJbySP9pC3NIGneAO1.jpg'),
(12605, 803, 'O Rancho S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/889534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C8OViho9qUyAOYvm9mCiqY6y9B.jpg'),
(12606, 803, 'O Rancho S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/889535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vbPwbfXBW4Bv5xju3hSMnMyGjUt.jpg'),
(12607, 804, 'O Rancho S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141651.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12608, 804, 'O Rancho S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141652.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12609, 804, 'O Rancho S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141653.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12610, 804, 'O Rancho S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141654.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12611, 804, 'O Rancho S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141655.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12612, 804, 'O Rancho S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141656.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12613, 804, 'O Rancho S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141657.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12614, 804, 'O Rancho S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141658.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12615, 804, 'O Rancho S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141659.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12616, 804, 'O Rancho S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141660.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12617, 804, 'O Rancho S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/889536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wXbwWq0gU8ZpHzVhkS3Qz2pES3u.jpg'),
(12618, 804, 'O Rancho S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/889537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bdlQOdlzcW1P70rOa2nBDXqmrRS.jpg'),
(12619, 804, 'O Rancho S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/889538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4S2IbJGa1pY7CxFXILDv2pZx9o7.jpg'),
(12620, 804, 'O Rancho S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/889539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hqK4EYdkWTtHTl0xEbbHJp2LAta.jpg'),
(12621, 804, 'O Rancho S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/889540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pvVKEVuVPwd6659VUB8SfbxAE9j.jpg'),
(12622, 804, 'O Rancho S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/889541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/anpkpoaBGgv8n2urjjYiKGReemc.jpg'),
(12623, 804, 'O Rancho S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/889542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u85RBkKlmYsZOEdKUDr4KZkamDt.jpg'),
(12624, 804, 'O Rancho S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/889543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yT3nsrx4ki2HKXHRcB8OoovEI5z.jpg'),
(12625, 804, 'O Rancho S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/889544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yYGiIvioE2jKqkPvfwA106Kv7IF.jpg'),
(12626, 804, 'O Rancho S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/889545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6vDwR3TvzejdQTnrqXdEvVGZCj.jpg'),
(12627, 805, 'O Rancho S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141661.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12628, 805, 'O Rancho S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141662.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12629, 805, 'O Rancho S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141663.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12630, 805, 'O Rancho S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141664.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12631, 805, 'O Rancho S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141665.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12632, 805, 'O Rancho S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141666.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12633, 805, 'O Rancho S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141667.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12634, 805, 'O Rancho S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141668.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12635, 805, 'O Rancho S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141669.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12636, 805, 'O Rancho S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141670.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12637, 805, 'O Rancho S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/889546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pPPawUfpG55jGBOO4PH5l144IZs.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(12638, 805, 'O Rancho S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/889547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xXGnA1wR9DX5SjxKa2OtvvdzI8Z.jpg'),
(12639, 805, 'O Rancho S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/889548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yq9XgXSiIO5jKmatFWD3lPF01Lu.jpg'),
(12640, 805, 'O Rancho S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/889549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4AnVr2oASo6tNtJdHF7x78vri6e.jpg'),
(12641, 805, 'O Rancho S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/889550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gRQlYvB28uQcOfVN42iOFHTCh5A.jpg'),
(12642, 805, 'O Rancho S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/889551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uN7wqhCgDrWa51L6PFVmRwIxbkn.jpg'),
(12643, 805, 'O Rancho S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/889552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fyRKFEetAMFKV0tTmO1hBDUWqN.jpg'),
(12644, 805, 'O Rancho S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/889553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMQ9sIh4FA4YcZrsjlDZFfphE7V.jpg'),
(12645, 805, 'O Rancho S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/889554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/15JqWBkfhDTNrk0z5gRuxOxizuw.jpg'),
(12646, 805, 'O Rancho S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/889555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jrEShrdSDQ97IEl7bIlCBVMfD8.jpg'),
(12647, 806, 'O Rancho S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141671.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12648, 806, 'O Rancho S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141672.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12649, 806, 'O Rancho S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141673.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12650, 806, 'O Rancho S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141674.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12651, 806, 'O Rancho S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141675.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12652, 806, 'O Rancho S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141676.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12653, 806, 'O Rancho S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141677.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12654, 806, 'O Rancho S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141678.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12655, 806, 'O Rancho S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141679.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12656, 806, 'O Rancho S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141680.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12657, 806, 'O Rancho S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/889556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Amn2OFPRbgam0X6Toijxs6MdlCw.jpg'),
(12658, 806, 'O Rancho S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/889557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gaPC5o0Y4acjIKarusEAkNRYee4.jpg'),
(12659, 806, 'O Rancho S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/889558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wmhtkVSYqcRUdOwQWLb75zOM2VV.jpg'),
(12660, 806, 'O Rancho S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/889559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sns0j5mlQ8grTsnZ6EKXDFSKwtf.jpg'),
(12661, 806, 'O Rancho S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/889560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1H64wtZQi1ZXk7HU8MBzUM1rlGP.jpg'),
(12662, 806, 'O Rancho S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/889561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4C5wSDNPhpaNW1ZGMIGTle6EKD8.jpg'),
(12663, 806, 'O Rancho S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/889562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/HPvdCJouNfZ7KU2zGUxgsaO80o.jpg'),
(12664, 806, 'O Rancho S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/889563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dNsaE04uzpPUpVwX9AyfnLMuMYi.jpg'),
(12665, 806, 'O Rancho S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/889564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w4GRyPg5qDESWdyZxq9Iuv1u9jo.jpg'),
(12666, 806, 'O Rancho S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/889565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kkhZPP0AM4foxeSRRpuRIOtEoHp.jpg'),
(12667, 807, 'O Rancho S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141681.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12668, 807, 'O Rancho S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141682.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12669, 807, 'O Rancho S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141683.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12670, 807, 'O Rancho S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141684.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12671, 807, 'O Rancho S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141685.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12672, 807, 'O Rancho S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141686.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12673, 807, 'O Rancho S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141687.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12674, 807, 'O Rancho S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141688.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12675, 807, 'O Rancho S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141689.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12676, 807, 'O Rancho S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141690.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12677, 808, 'O Rancho S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141691.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12678, 808, 'O Rancho S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141692.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12679, 808, 'O Rancho S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141693.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12680, 808, 'O Rancho S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141694.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12681, 808, 'O Rancho S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141695.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12682, 808, 'O Rancho S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141696.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12683, 808, 'O Rancho S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141697.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12684, 808, 'O Rancho S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141698.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12685, 808, 'O Rancho S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141699.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12686, 808, 'O Rancho S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141700.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12687, 809, 'O Rancho S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141701.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12688, 809, 'O Rancho S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141702.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12689, 809, 'O Rancho S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141703.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12690, 809, 'O Rancho S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141704.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12691, 809, 'O Rancho S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141705.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12692, 809, 'O Rancho S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141706.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12693, 809, 'O Rancho S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141707.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12694, 809, 'O Rancho S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141708.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12695, 809, 'O Rancho S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141709.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12696, 809, 'O Rancho S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141710.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12697, 810, 'O Rancho S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141711.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12698, 810, 'O Rancho S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141712.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12699, 810, 'O Rancho S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141713.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12700, 810, 'O Rancho S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141714.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12701, 810, 'O Rancho S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141715.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12702, 810, 'O Rancho S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141716.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12703, 810, 'O Rancho S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141717.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12704, 810, 'O Rancho S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141718.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12705, 810, 'O Rancho S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141719.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12706, 810, 'O Rancho S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141720.mp4', 'http://gstaticontent.com/images/lCQou4m9D5NnALrled5qNzrG0AT_big.jpg'),
(12707, 811, 'O Residente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12708, 811, 'O Residente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12709, 811, 'O Residente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12710, 811, 'O Residente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12711, 811, 'O Residente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12712, 811, 'O Residente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12713, 811, 'O Residente S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12714, 811, 'O Residente S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12715, 811, 'O Residente S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12716, 811, 'O Residente S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12717, 811, 'O Residente S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12718, 811, 'O Residente S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12719, 811, 'O Residente S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12720, 811, 'O Residente S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12721, 812, 'O Residente S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206227.mp4', 'http://timg.bdta.pro/images/55ed70b975defae6101bed8c48ea4cfb.jpg'),
(12722, 812, 'O Residente S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206228.mp4', 'http://timg.bdta.pro/images/199e5d770068f4d4ee9eb9d052b58fb5.jpg'),
(12723, 812, 'O Residente S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206229.mp4', 'http://timg.bdta.pro/images/edf199026fb9b100db7f46cc85cc229c.jpg'),
(12724, 812, 'O Residente S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206230.mp4', 'http://timg.bdta.pro/images/ecc37554bd8bb687a325c4e8f6799ca4.jpg'),
(12725, 812, 'O Residente S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206231.mp4', 'http://timg.bdta.pro/images/e3db30bc56f6fd85350474b89c61b9b2.jpg'),
(12726, 812, 'O Residente S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206232.mp4', 'http://timg.bdta.pro/images/dfcee6ad25a15a99706070a3281080e5.jpg'),
(12727, 812, 'O Residente S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206233.mp4', 'http://timg.bdta.pro/images/f676fd9fed0c49774bf8c42f3f3d2e14.jpg'),
(12728, 812, 'O Residente S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206234.mp4', 'http://timg.bdta.pro/images/3abe052a97040e647c56cff021ed9024.jpg'),
(12729, 812, 'O Residente S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206235.mp4', 'http://timg.bdta.pro/images/e5ab8f65c327a8259e126565aa333aff.jpg'),
(12730, 812, 'O Residente S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206236.mp4', 'http://timg.bdta.pro/images/f569f28636cd3016dc336aa19350fa7b.jpg'),
(12731, 812, 'O Residente S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206237.mp4', 'http://timg.bdta.pro/images/515f577fd60e543b4c7d65e71b6101e8.jpg'),
(12732, 812, 'O Residente S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206238.mp4', 'http://timg.bdta.pro/images/57307ddbea26b0d8f4ab9f3da392223c.jpg'),
(12733, 812, 'O Residente S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206239.mp4', 'http://timg.bdta.pro/images/b2337433f103344dbe1fe8ed2d514329.jpg'),
(12734, 812, 'O Residente S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206240.mp4', 'http://timg.bdta.pro/images/c0532c892eb56a30da14e2d9b84378db.jpg'),
(12735, 812, 'O Residente S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206241.mp4', 'http://timg.bdta.pro/images/7246fb25e1af03b6f1da7425aa44cea1.jpg'),
(12736, 812, 'O Residente S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206242.mp4', 'http://timg.bdta.pro/images/bddcbcc5a8952af97d0bb84b6f74651b.jpg'),
(12737, 812, 'O Residente S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/206243.mp4', 'http://timg.bdta.pro/images/59b546a5c74c641889cfd7ca923ec014.jpg'),
(12738, 812, 'O Residente S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/206244.mp4', 'http://timg.bdta.pro/images/d46c3aa2404b3d59c819f00401a8d625.jpg'),
(12739, 812, 'O Residente S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/206245.mp4', 'http://timg.bdta.pro/images/d656c7d3e6dee9403b02c1303fcb086b.jpg'),
(12740, 812, 'O Residente S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/206246.mp4', 'http://timg.bdta.pro/images/1d9c5658e87d5e0e61d998d3c53f9f44.jpg'),
(12741, 812, 'O Residente S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/206247.mp4', 'http://timg.bdta.pro/images/ead2ab60d59b59cc6800da4b7efc89fd.jpg'),
(12742, 812, 'O Residente S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/206248.mp4', 'http://timg.bdta.pro/images/ca63f8ceb588de8bfc56dc3f54293b22.jpg'),
(12743, 812, 'O Residente S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/206249.mp4', 'http://timg.bdta.pro/images/3cd73b4bb66fa614d685e9a015844e8c.jpg'),
(12744, 813, 'O Residente S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12745, 813, 'O Residente S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12746, 813, 'O Residente S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12747, 813, 'O Residente S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12748, 813, 'O Residente S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12749, 813, 'O Residente S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12750, 813, 'O Residente S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12751, 813, 'O Residente S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12752, 813, 'O Residente S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12753, 813, 'O Residente S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12754, 813, 'O Residente S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12755, 813, 'O Residente S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12756, 813, 'O Residente S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12757, 813, 'O Residente S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12758, 813, 'O Residente S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12759, 813, 'O Residente S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12760, 813, 'O Residente S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/206266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12761, 813, 'O Residente S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/206267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12762, 813, 'O Residente S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/206268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12763, 813, 'O Residente S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/206269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hzirecGzlfxcLyrxPi1W6L5TtQ.jpg'),
(12764, 814, 'O Residente S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206270.mp4', 'http://timg.bdta.pro/images/a73bbfcbbced4da620dac0185b43ddf2.jpg'),
(12765, 814, 'O Residente S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206271.mp4', 'http://timg.bdta.pro/images/27bee1007dab31a34b36bc7ff812bfce.jpg'),
(12766, 814, 'O Residente S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206272.mp4', 'http://timg.bdta.pro/images/e5becd36370a0f4284f149f88acc9d25.jpg'),
(12767, 814, 'O Residente S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206273.mp4', 'http://timg.bdta.pro/images/24c58e6996693640e3a7427540d4d97e.jpg'),
(12768, 814, 'O Residente S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206274.mp4', 'http://timg.bdta.pro/images/f8bebb9c071eb745c1424f4dfb7b9af7.jpg'),
(12769, 814, 'O Residente S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206275.mp4', 'http://timg.bdta.pro/images/800b8a153d646054061c1cee78c853eb.jpg'),
(12770, 814, 'O Residente S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206276.mp4', 'http://timg.bdta.pro/images/aaad6c64770b478344fddccd711e2169.jpg'),
(12771, 814, 'O Residente S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206277.mp4', 'http://timg.bdta.pro/images/ebcda53e7084e34578a6eba8d1b15a6c.jpg'),
(12772, 814, 'O Residente S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206278.mp4', 'http://timg.bdta.pro/images/d44dfcaebec353aecf40af4917ff2950.jpg'),
(12773, 814, 'O Residente S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206279.mp4', 'http://timg.bdta.pro/images/4e516ba59588724b815d2a54922e520a.jpg'),
(12774, 814, 'O Residente S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206280.mp4', 'http://timg.bdta.pro/images/5f77dfd6401c281ecbe8879810f516bc.jpg'),
(12775, 814, 'O Residente S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206281.mp4', 'http://timg.bdta.pro/images/3368827d4f10748b87302465a537e7c6.jpg'),
(12776, 814, 'O Residente S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206282.mp4', 'http://timg.bdta.pro/images/223009ab268a6219f46ed4047e4aa7c9.jpg'),
(12777, 814, 'O Residente S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206283.mp4', 'http://timg.bdta.pro/images/243ab5993ac7a06fce2638df46fdd3de.jpg'),
(12778, 815, 'O Residente S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206284.mp4', 'http://timg.bdta.pro/images/3406145ec147b570891593b2a8fb4f83.jpg'),
(12779, 815, 'O Residente S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206285.mp4', 'http://timg.bdta.pro/images/bc70a51f5669ed9a05f348f34889bdae.jpg'),
(12780, 815, 'O Residente S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206286.mp4', 'http://timg.bdta.pro/images/d381a97ff6f7f2bc67ace5a13110b7a5.jpg'),
(12781, 815, 'O Residente S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206287.mp4', 'http://timg.bdta.pro/images/e01505c4289940dcf7365e0eaa984e4a.jpg'),
(12782, 815, 'O Residente S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206288.mp4', 'http://timg.bdta.pro/images/8046a7cc037d4fe96a84776be87262e5.jpg'),
(12783, 815, 'O Residente S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206289.mp4', 'http://timg.bdta.pro/images/387a6204105171f44cab70bd0fcbc04d.jpg'),
(12784, 815, 'O Residente S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206290.mp4', 'http://timg.bdta.pro/images/172e0abe7be9da41ada1345bf525e347.jpg'),
(12785, 815, 'O Residente S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206291.mp4', 'http://timg.bdta.pro/images/cf65ecdda03775974e7550905b4e802d.jpg'),
(12786, 815, 'O Residente S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206292.mp4', 'http://timg.bdta.pro/images/abf8d96f3ebef2cca93e7309cf492260.jpg'),
(12787, 815, 'O Residente S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206293.mp4', 'http://timg.bdta.pro/images/82ba0e13adf93d5805f5e39a89cb167b.jpg'),
(12788, 815, 'O Residente S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206294.mp4', 'http://timg.bdta.pro/images/1763fb07db952e41bb9224386256100a.jpg'),
(12789, 815, 'O Residente S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206295.mp4', 'http://timg.bdta.pro/images/4bd4378d01cc6f18a1c744f4c6ae351a.jpg'),
(12790, 815, 'O Residente S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206296.mp4', 'http://timg.bdta.pro/images/7049ca1cd3f64669674fbbcb797b2fdb.jpg'),
(12791, 815, 'O Residente S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206297.mp4', 'http://timg.bdta.pro/images/140f3c196ea40b43b2b03f4547eaca69.jpg'),
(12792, 815, 'O Residente S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206298.mp4', 'http://timg.bdta.pro/images/a37376983ab1471fb1ab444fdf27a7f6.jpg'),
(12793, 815, 'O Residente S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206299.mp4', 'http://timg.bdta.pro/images/24b5a264524c55b2c99d1a537b1eef98.jpg'),
(12794, 815, 'O Residente S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/206300.mp4', 'http://timg.bdta.pro/images/497c91e2deb5184185a5ff118472d89c.jpg'),
(12795, 815, 'O Residente S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/206301.mp4', 'http://timg.bdta.pro/images/35299ad66ba10aa0694e4dae07aceebd.jpg'),
(12796, 815, 'O Residente S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/206302.mp4', 'http://timg.bdta.pro/images/bd42a316ce6b235a3b5cfee50b62f2b7.jpg'),
(12797, 815, 'O Residente S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/206303.mp4', 'http://timg.bdta.pro/images/ff541846a8dddb2ba9ceb0c5ed1dc1d3.jpg'),
(12798, 815, 'O Residente S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/206304.mp4', 'http://timg.bdta.pro/images/f81234832f7c3991a115aff26505208b.jpg'),
(12799, 815, 'O Residente S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/206305.mp4', 'http://timg.bdta.pro/images/7e639490b43b4803c01a26917b2e1197.jpg'),
(12800, 815, 'O Residente S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/206306.mp4', 'http://timg.bdta.pro/images/83f5ad84fc81eb74e3e92b1a79f6a670.jpg'),
(12801, 816, 'O Residente S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gVj5rCRCGOSfO0he3WjTPxMJrTC.jpg'),
(12802, 816, 'O Residente S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9gLCTK7W6jclC2CnUmALmfrMH6m.jpg'),
(12803, 816, 'O Residente S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206309.mp4', 'http://image.tmdb.org/t/p/w1280/41PBBkqCdW7Bo73hQmz39kdAtuy.jpg'),
(12804, 816, 'O Residente S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cukybUbuTT1FrCHG0DKchuk1Ljo.jpg'),
(12805, 816, 'O Residente S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jLy33dzAe8aQiKIJLTR70xOCG1H.jpg'),
(12806, 816, 'O Residente S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206312.mp4', 'http://image.tmdb.org/t/p/w1280/8fIMVvqpifdlGAr30CuJUjKPjrl.jpg'),
(12807, 816, 'O Residente S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206313.mp4', 'http://image.tmdb.org/t/p/w1280/jBWETr1brg5BuRUhTmc3NC5FxtY.jpg'),
(12808, 816, 'O Residente S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206314.mp4', 'http://image.tmdb.org/t/p/w1280/n1Vxqc7njrZAKMaJaPtYUqj9VcK.jpg'),
(12809, 816, 'O Residente S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206315.mp4', 'http://image.tmdb.org/t/p/w1280/enUEFoOsJo7g3mj2NKlHYW8ThPD.jpg'),
(12810, 816, 'O Residente S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206316.mp4', 'http://image.tmdb.org/t/p/w1280/xHH3gE5RnG8Rl9x6SDpofrol0wo.jpg'),
(12811, 816, 'O Residente S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206317.mp4', 'http://image.tmdb.org/t/p/w1280/npYvGU8s3twbXvJ1ysGtaACexNn.jpg'),
(12812, 816, 'O Residente S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206318.mp4', 'http://image.tmdb.org/t/p/w1280/8iY5AnR12huXZQh5iEw4zoUqUi1.jpg'),
(12813, 816, 'O Residente S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206319.mp4', 'http://image.tmdb.org/t/p/w1280/qGJ00bJVNGlhLRuA95KWrfWG2zv.jpg'),
(12814, 817, 'The Sinner S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177364.mp4', 'http://gstaticontent.com/images/jFcxMLCAA7XHYeGOLaouyqChRhY_big.jpg'),
(12815, 817, 'The Sinner S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177365.mp4', 'http://gstaticontent.com/images/jFcxMLCAA7XHYeGOLaouyqChRhY_big.jpg'),
(12816, 817, 'The Sinner S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177366.mp4', 'http://gstaticontent.com/images/jFcxMLCAA7XHYeGOLaouyqChRhY_big.jpg'),
(12817, 817, 'The Sinner S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177367.mp4', 'http://gstaticontent.com/images/jFcxMLCAA7XHYeGOLaouyqChRhY_big.jpg'),
(12818, 817, 'The Sinner S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177368.mp4', 'http://gstaticontent.com/images/jFcxMLCAA7XHYeGOLaouyqChRhY_big.jpg'),
(12819, 817, 'The Sinner S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177369.mp4', 'http://gstaticontent.com/images/jFcxMLCAA7XHYeGOLaouyqChRhY_big.jpg'),
(12820, 817, 'The Sinner S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177370.mp4', 'http://gstaticontent.com/images/jFcxMLCAA7XHYeGOLaouyqChRhY_big.jpg'),
(12821, 817, 'The Sinner S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177371.mp4', 'http://gstaticontent.com/images/jFcxMLCAA7XHYeGOLaouyqChRhY_big.jpg'),
(12822, 818, 'The Sinner S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177372.mp4', 'http://gstaticontent.com/images/jFcxMLCAA7XHYeGOLaouyqChRhY_big.jpg'),
(12823, 818, 'The Sinner S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177373.mp4', 'http://gstaticontent.com/images/jFcxMLCAA7XHYeGOLaouyqChRhY_big.jpg'),
(12824, 818, 'The Sinner S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177374.mp4', 'http://gstaticontent.com/images/jFcxMLCAA7XHYeGOLaouyqChRhY_big.jpg'),
(12825, 818, 'The Sinner S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177375.mp4', 'http://gstaticontent.com/images/jFcxMLCAA7XHYeGOLaouyqChRhY_big.jpg'),
(12826, 818, 'The Sinner S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177376.mp4', 'http://gstaticontent.com/images/jFcxMLCAA7XHYeGOLaouyqChRhY_big.jpg'),
(12827, 818, 'The Sinner S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177377.mp4', 'http://gstaticontent.com/images/jFcxMLCAA7XHYeGOLaouyqChRhY_big.jpg'),
(12828, 818, 'The Sinner S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177378.mp4', 'http://gstaticontent.com/images/jFcxMLCAA7XHYeGOLaouyqChRhY_big.jpg'),
(12829, 818, 'The Sinner S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177379.mp4', 'http://gstaticontent.com/images/jFcxMLCAA7XHYeGOLaouyqChRhY_big.jpg'),
(12830, 819, 'The Sinner S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177380.mp4', 'http://timg.bdta.pro/images/e5b58634600b2977d5f0dd4dc03db2b3.jpg'),
(12831, 819, 'The Sinner S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177381.mp4', 'http://timg.bdta.pro/images/0279f80574b698c63446b35d8e12e71d.jpg'),
(12832, 819, 'The Sinner S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177382.mp4', 'http://timg.bdta.pro/images/794b496f19e1cec9e3d68a00b85f64b8.jpg'),
(12833, 819, 'The Sinner S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177383.mp4', 'http://timg.bdta.pro/images/43f57f7bfbdc9965df2f1c816f27b6cd.jpg'),
(12834, 819, 'The Sinner S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177384.mp4', 'http://timg.bdta.pro/images/5eda28a19a799f7613d84c75cf3b3764.jpg'),
(12835, 819, 'The Sinner S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177385.mp4', 'http://timg.bdta.pro/images/3ab89c1a4693497171cde89b3b87e255.jpg'),
(12836, 819, 'The Sinner S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177386.mp4', 'http://timg.bdta.pro/images/8367db8f364ab8eedd6b90754ac9bdf7.jpg'),
(12837, 819, 'The Sinner S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177387.mp4', 'http://timg.bdta.pro/images/792438a8dba75e40ef36945817e9de28.jpg'),
(12838, 820, 'The Sinner S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177388.mp4', 'http://timg.bdta.pro/images/bdb9db5fd4cff1f86e568057b51006f7.jpg'),
(12839, 820, 'The Sinner S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177389.mp4', 'http://timg.bdta.pro/images/8f97a22cc50d3147dcd9af29fd4f837d.jpg'),
(12840, 820, 'The Sinner S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177390.mp4', 'http://timg.bdta.pro/images/35111a17a7ec0339f5da4e2bc1edf1b8.jpg'),
(12841, 820, 'The Sinner S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177391.mp4', 'http://timg.bdta.pro/images/eb5e8ec25374b864f4f01ab2d8158233.jpg'),
(12842, 820, 'The Sinner S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177392.mp4', 'http://timg.bdta.pro/images/8f64a8fe7d14d003645ce9bfb7a31f96.jpg'),
(12843, 820, 'The Sinner S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177393.mp4', 'http://timg.bdta.pro/images/5744c3f2019fe52482776825f52a6af9.jpg'),
(12844, 820, 'The Sinner S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177394.mp4', 'http://timg.bdta.pro/images/d801ad35f4dbdd4bb1c8bddd0736a058.jpg'),
(12845, 820, 'The Sinner S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177395.mp4', 'http://timg.bdta.pro/images/1aa0371072499893c2796307f8fcb015.jpg'),
(12846, 821, 'The Strain S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194010.mp4', 'http://gstaticontent.com/images/2BWErT9QcADpf2G4BZ769eSnFTP_big.jpg'),
(12847, 821, 'The Strain S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194011.mp4', 'http://gstaticontent.com/images/2BWErT9QcADpf2G4BZ769eSnFTP_big.jpg'),
(12848, 821, 'The Strain S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194012.mp4', 'http://gstaticontent.com/images/2BWErT9QcADpf2G4BZ769eSnFTP_big.jpg'),
(12849, 821, 'The Strain S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194013.mp4', 'http://gstaticontent.com/images/2BWErT9QcADpf2G4BZ769eSnFTP_big.jpg'),
(12850, 821, 'The Strain S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194014.mp4', 'http://gstaticontent.com/images/2BWErT9QcADpf2G4BZ769eSnFTP_big.jpg'),
(12851, 821, 'The Strain S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194015.mp4', 'http://gstaticontent.com/images/2BWErT9QcADpf2G4BZ769eSnFTP_big.jpg'),
(12852, 821, 'The Strain S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194016.mp4', 'http://gstaticontent.com/images/2BWErT9QcADpf2G4BZ769eSnFTP_big.jpg'),
(12853, 821, 'The Strain S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194017.mp4', 'http://gstaticontent.com/images/2BWErT9QcADpf2G4BZ769eSnFTP_big.jpg'),
(12854, 821, 'The Strain S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194018.mp4', 'http://gstaticontent.com/images/2BWErT9QcADpf2G4BZ769eSnFTP_big.jpg'),
(12855, 821, 'The Strain S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194019.mp4', 'http://gstaticontent.com/images/2BWErT9QcADpf2G4BZ769eSnFTP_big.jpg'),
(12856, 821, 'The Strain S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194020.mp4', 'http://gstaticontent.com/images/2BWErT9QcADpf2G4BZ769eSnFTP_big.jpg'),
(12857, 821, 'The Strain S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194021.mp4', 'http://gstaticontent.com/images/2BWErT9QcADpf2G4BZ769eSnFTP_big.jpg'),
(12858, 821, 'The Strain S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/194022.mp4', 'http://gstaticontent.com/images/2BWErT9QcADpf2G4BZ769eSnFTP_big.jpg'),
(12859, 822, 'The Strain S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194023.mp4', 'http://gstaticontent.com/images/2BWErT9QcADpf2G4BZ769eSnFTP_big.jpg'),
(12860, 822, 'The Strain S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194024.mp4', 'http://gstaticontent.com/images/2BWErT9QcADpf2G4BZ769eSnFTP_big.jpg'),
(12861, 822, 'The Strain S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194025.mp4', 'http://gstaticontent.com/images/2BWErT9QcADpf2G4BZ769eSnFTP_big.jpg'),
(12862, 822, 'The Strain S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194026.mp4', 'http://gstaticontent.com/images/2BWErT9QcADpf2G4BZ769eSnFTP_big.jpg'),
(12863, 822, 'The Strain S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194027.mp4', 'http://gstaticontent.com/images/2BWErT9QcADpf2G4BZ769eSnFTP_big.jpg'),
(12864, 822, 'The Strain S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194028.mp4', 'http://gstaticontent.com/images/2BWErT9QcADpf2G4BZ769eSnFTP_big.jpg'),
(12865, 822, 'The Strain S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194029.mp4', 'http://gstaticontent.com/images/2BWErT9QcADpf2G4BZ769eSnFTP_big.jpg'),
(12866, 822, 'The Strain S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194030.mp4', 'http://timg.bdta.pro/images/27f227188aa9cbed65a7e7215a28dac2.jpg'),
(12867, 822, 'The Strain S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194031.mp4', 'http://timg.bdta.pro/images/2f693cb97a4fb17c1a0382d151a7b795.jpg'),
(12868, 822, 'The Strain S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194032.mp4', 'http://timg.bdta.pro/images/1ff69983945bec1cec1edd4e82f4fa8f.jpg'),
(12869, 822, 'The Strain S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194033.mp4', 'http://timg.bdta.pro/images/af27c1ac1208175bafd595d0a061b621.jpg'),
(12870, 822, 'The Strain S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194034.mp4', 'http://timg.bdta.pro/images/cc76f6f630c6c399080040114a280feb.jpg'),
(12871, 822, 'The Strain S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/194035.mp4', 'http://timg.bdta.pro/images/f57ea68f9c00bc11f9688eea0b405622.jpg'),
(12872, 823, 'The Strain S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194036.mp4', 'http://timg.bdta.pro/images/e280e05ba02598b7f6c2e1bde6d343ff.jpg'),
(12873, 823, 'The Strain S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194037.mp4', 'http://timg.bdta.pro/images/9e5732d76a46fdcdd1cb87dad5aade34.jpg'),
(12874, 823, 'The Strain S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194038.mp4', 'http://timg.bdta.pro/images/08f43e4edc9b9859cf909f6f3f42063c.jpg'),
(12875, 823, 'The Strain S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194039.mp4', 'http://timg.bdta.pro/images/0f3f9b25fc966f981c4b83efe2b92b2e.jpg'),
(12876, 823, 'The Strain S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194040.mp4', 'http://timg.bdta.pro/images/05287206caa77a0b343134b133e3c3cd.jpg'),
(12877, 823, 'The Strain S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194041.mp4', 'http://timg.bdta.pro/images/ce8aa1c9d69fb441264721372ae659de.jpg'),
(12878, 823, 'The Strain S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194042.mp4', 'http://timg.bdta.pro/images/1588cb5f60f1f72250e854d35cad1990.jpg'),
(12879, 823, 'The Strain S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194043.mp4', 'http://timg.bdta.pro/images/ad3bac983e8697b4988ba77232ad6fe7.jpg'),
(12880, 823, 'The Strain S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194044.mp4', 'http://timg.bdta.pro/images/3b1b766eb9fbc7d6cd247ac8e838336e.jpg'),
(12881, 823, 'The Strain S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194045.mp4', 'http://timg.bdta.pro/images/45d8d8da7962808a54fde0a9ad3d6366.jpg'),
(12882, 824, 'The Strain S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194046.mp4', 'http://timg.bdta.pro/images/ce24bafb754f567a2b1128b22c1657a7.jpg'),
(12883, 824, 'The Strain S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194047.mp4', 'http://timg.bdta.pro/images/0a32792dfb8b616dd96a7ab29f184680.jpg'),
(12884, 824, 'The Strain S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194048.mp4', 'http://timg.bdta.pro/images/f3f4474bfd7df3f4b21d593d1d420d43.jpg'),
(12885, 824, 'The Strain S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194049.mp4', 'http://timg.bdta.pro/images/e84b8ad7d29c478ed53b16011f4428d6.jpg'),
(12886, 824, 'The Strain S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194050.mp4', 'http://timg.bdta.pro/images/651508ac983b23a3acb553fe143a97d1.jpg'),
(12887, 824, 'The Strain S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194051.mp4', 'http://timg.bdta.pro/images/e1f751092cb5cef3505e508a907e4ec0.jpg'),
(12888, 824, 'The Strain S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ufGuEUFC8v64sf7g2XhmTL0vRU.jpg'),
(12889, 824, 'The Strain S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194053.mp4', 'http://timg.bdta.pro/images/0ec3647a45116aaa0f50d7c5a5d7699c.jpg'),
(12890, 824, 'The Strain S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194054.mp4', 'http://timg.bdta.pro/images/0532f3a6c01d4971019e0f6dbc197e02.jpg'),
(12891, 824, 'The Strain S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194055.mp4', 'http://timg.bdta.pro/images/fd2a75f7205193ed08204bdf99406996.jpg'),
(12892, 825, 'The Terror S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217496.mp4', 'http://gstaticontent.com/images/eoxvAUG5hbqon869PXuFhvR1LOu_big.jpg'),
(12893, 825, 'The Terror S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217497.mp4', 'http://gstaticontent.com/images/eoxvAUG5hbqon869PXuFhvR1LOu_big.jpg'),
(12894, 825, 'The Terror S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217498.mp4', 'http://gstaticontent.com/images/eoxvAUG5hbqon869PXuFhvR1LOu_big.jpg'),
(12895, 825, 'The Terror S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217499.mp4', 'http://gstaticontent.com/images/eoxvAUG5hbqon869PXuFhvR1LOu_big.jpg'),
(12896, 825, 'The Terror S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217500.mp4', 'http://gstaticontent.com/images/eoxvAUG5hbqon869PXuFhvR1LOu_big.jpg'),
(12897, 825, 'The Terror S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217501.mp4', 'http://gstaticontent.com/images/eoxvAUG5hbqon869PXuFhvR1LOu_big.jpg'),
(12898, 825, 'The Terror S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217502.mp4', 'http://gstaticontent.com/images/eoxvAUG5hbqon869PXuFhvR1LOu_big.jpg'),
(12899, 825, 'The Terror S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217503.mp4', 'http://gstaticontent.com/images/eoxvAUG5hbqon869PXuFhvR1LOu_big.jpg'),
(12900, 825, 'The Terror S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217504.mp4', 'http://gstaticontent.com/images/eoxvAUG5hbqon869PXuFhvR1LOu_big.jpg'),
(12901, 825, 'The Terror S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217505.mp4', 'http://gstaticontent.com/images/eoxvAUG5hbqon869PXuFhvR1LOu_big.jpg'),
(12902, 826, 'The Terror S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q21tU1PObxx7GLCfSsqPJHgdkg6.jpg'),
(12903, 826, 'The Terror S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jq65nAKans69zTfg6RaX1WrYjBS.jpg'),
(12904, 826, 'The Terror S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y0oTbBvzbMewUog4vaG0KuDRXeN.jpg'),
(12905, 826, 'The Terror S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sQpnWJzRmyY39OSEv7AuqNYHgBp.jpg'),
(12906, 826, 'The Terror S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hHtpLdlAGCvFn6j6N5aad6KD8xg.jpg'),
(12907, 826, 'The Terror S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uYHfYMCjoBg0e67j8CLqz8NjRvW.jpg'),
(12908, 826, 'The Terror S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aWBbHH8PxqheatoCAYtjyvSzIBV.jpg'),
(12909, 826, 'The Terror S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AozDGmldFdBm5VcMyrZteYjV0mJ.jpg'),
(12910, 826, 'The Terror S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ceHkp9BniayycZi1utE4nRokn0T.jpg'),
(12911, 826, 'The Terror S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hiSof699vGX4VWxTJz0DwEhC3sV.jpg'),
(12912, 827, 'Diarios de um Vampiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132970.mp4', 'http://timg.bdta.pro/images/a6e9c2997ec262577b989c04f15cf00f.jpg'),
(12913, 827, 'Diarios de um Vampiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132971.mp4', 'http://timg.bdta.pro/images/dcf4e71b9a542274c69ba870e2b517bb.jpg'),
(12914, 827, 'Diarios de um Vampiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132972.mp4', 'http://timg.bdta.pro/images/a040f4f38631d15b5159a02b91b04237.jpg'),
(12915, 827, 'Diarios de um Vampiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132973.mp4', 'http://timg.bdta.pro/images/f1c5cc0e58b256c78a7529f5b270d99e.jpg'),
(12916, 827, 'Diarios de um Vampiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132974.mp4', 'http://timg.bdta.pro/images/ceb5a63487130fd958594f4036f60e3a.jpg'),
(12917, 827, 'Diarios de um Vampiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132975.mp4', 'http://timg.bdta.pro/images/644194264feb2cef64d54a015300c3f0.jpg'),
(12918, 827, 'Diarios de um Vampiro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132976.mp4', 'http://timg.bdta.pro/images/09bcf3ad26b150a34959b4fa04c6e458.jpg'),
(12919, 827, 'Diarios de um Vampiro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132977.mp4', 'http://timg.bdta.pro/images/88dfe931441d29bd7411cff4c9810469.jpg'),
(12920, 827, 'Diarios de um Vampiro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132978.mp4', 'http://timg.bdta.pro/images/fd78e86d756459548f1e80e0f60a4536.jpg'),
(12921, 827, 'Diarios de um Vampiro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132979.mp4', 'http://timg.bdta.pro/images/b335b8bf6c94335e7dce04dff3b53e26.jpg'),
(12922, 827, 'Diarios de um Vampiro S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132980.mp4', 'http://timg.bdta.pro/images/c9da899ec3e885f388e54ce80fa7f9da.jpg'),
(12923, 827, 'Diarios de um Vampiro S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132981.mp4', 'http://timg.bdta.pro/images/d276a089d079bf8f2d41199940824d4b.jpg'),
(12924, 827, 'Diarios de um Vampiro S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132982.mp4', 'http://timg.bdta.pro/images/93e24b3c63af25e2e29796fa23848e65.jpg'),
(12925, 827, 'Diarios de um Vampiro S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132983.mp4', 'http://timg.bdta.pro/images/6ac370ed69a526c7149ef7d7540a59ac.jpg'),
(12926, 827, 'Diarios de um Vampiro S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132984.mp4', 'http://timg.bdta.pro/images/1b42dff49b7195138c47859c3948bb4a.jpg'),
(12927, 827, 'Diarios de um Vampiro S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132985.mp4', 'http://timg.bdta.pro/images/d23a5b3ef950c03eba946353d1eedae4.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(12928, 827, 'Diarios de um Vampiro S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132986.mp4', 'http://timg.bdta.pro/images/1b54ec2aa47588a05417549faffb4522.jpg'),
(12929, 827, 'Diarios de um Vampiro S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132987.mp4', 'http://timg.bdta.pro/images/b7b24dfd17d1ea30b8609c524c6ab76f.jpg'),
(12930, 827, 'Diarios de um Vampiro S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132988.mp4', 'http://timg.bdta.pro/images/920741fcb54f4220bd2776890b46bab9.jpg'),
(12931, 827, 'Diarios de um Vampiro S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132989.mp4', 'http://timg.bdta.pro/images/79db440cac397e3a0d035579602a723b.jpg'),
(12932, 827, 'Diarios de um Vampiro S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132990.mp4', 'http://timg.bdta.pro/images/3a5f3b53958d46b4eb153b9ec8d2be0e.jpg'),
(12933, 827, 'Diarios de um Vampiro S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132991.mp4', 'http://timg.bdta.pro/images/431e4f08e024c01e4fd319d14a4ea1b6.jpg'),
(12934, 828, 'Diarios de um Vampiro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132992.mp4', 'http://timg.bdta.pro/images/29399e6d72276114db41a03667d349fc.jpg'),
(12935, 828, 'Diarios de um Vampiro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132993.mp4', 'http://timg.bdta.pro/images/003e3dd7b18cdae27bdc3d95a3803e04.jpg'),
(12936, 828, 'Diarios de um Vampiro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132994.mp4', 'http://timg.bdta.pro/images/7bd85767ab0a7f653647e1a1ad978003.jpg'),
(12937, 828, 'Diarios de um Vampiro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132995.mp4', 'http://timg.bdta.pro/images/85773c751daaf3dbb8c68899d0938e2b.jpg'),
(12938, 828, 'Diarios de um Vampiro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132996.mp4', 'http://timg.bdta.pro/images/d41c378156075199ba1c4e7414de1217.jpg'),
(12939, 828, 'Diarios de um Vampiro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132997.mp4', 'http://timg.bdta.pro/images/546425c282f48118ba9e5cdf54d91b2e.jpg'),
(12940, 828, 'Diarios de um Vampiro S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132998.mp4', 'http://timg.bdta.pro/images/b2c5340322d70e835a78304957370213.jpg'),
(12941, 828, 'Diarios de um Vampiro S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132999.mp4', 'http://timg.bdta.pro/images/20f3b9ec400db71bd9210ba504bfb614.jpg'),
(12942, 828, 'Diarios de um Vampiro S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/133000.mp4', 'http://timg.bdta.pro/images/991946795d3405ddecdedc38074fd160.jpg'),
(12943, 828, 'Diarios de um Vampiro S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/133001.mp4', 'http://timg.bdta.pro/images/3a24485e28ef8091fa7649c16cffd8e5.jpg'),
(12944, 828, 'Diarios de um Vampiro S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/133002.mp4', 'http://timg.bdta.pro/images/b2aaf4451212195b40682bc47b9d0d3a.jpg'),
(12945, 828, 'Diarios de um Vampiro S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/133003.mp4', 'http://timg.bdta.pro/images/4f9f3b91f17d7ca42aa58ea7a1c12f92.jpg'),
(12946, 828, 'Diarios de um Vampiro S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/133004.mp4', 'http://timg.bdta.pro/images/265e952f5586db9b31ed95324d79be71.jpg'),
(12947, 828, 'Diarios de um Vampiro S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/133005.mp4', 'http://timg.bdta.pro/images/57b76fb61eb691117ca80e89c3f886da.jpg'),
(12948, 828, 'Diarios de um Vampiro S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/133006.mp4', 'http://timg.bdta.pro/images/a125448cbae758e79e00b84fd4ac82cf.jpg'),
(12949, 828, 'Diarios de um Vampiro S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/133007.mp4', 'http://timg.bdta.pro/images/60b0b0390cc0b441f491d5f62cc2a540.jpg'),
(12950, 828, 'Diarios de um Vampiro S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/133008.mp4', 'http://timg.bdta.pro/images/0f80217e3b79e270372a03ade79b16ec.jpg'),
(12951, 828, 'Diarios de um Vampiro S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/133009.mp4', 'http://timg.bdta.pro/images/9c071bf338bd07627165d1af7f2b911f.jpg'),
(12952, 828, 'Diarios de um Vampiro S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/133010.mp4', 'http://timg.bdta.pro/images/43753739cf9746acb2a8c7c40da02954.jpg'),
(12953, 828, 'Diarios de um Vampiro S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/133011.mp4', 'http://timg.bdta.pro/images/494b20c41dd9931a3fe50c890dc3b1e2.jpg'),
(12954, 828, 'Diarios de um Vampiro S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/133012.mp4', 'http://timg.bdta.pro/images/ec545de9e4f3887a269beffc3531ca03.jpg'),
(12955, 828, 'Diarios de um Vampiro S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/133013.mp4', 'http://timg.bdta.pro/images/4cc0a74068e883e412ba29bad8b9e7af.jpg'),
(12956, 829, 'Diarios de um Vampiro S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/133014.mp4', 'http://timg.bdta.pro/images/3d02b2d00df6d2782e791d619ba74190.jpg'),
(12957, 829, 'Diarios de um Vampiro S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/133015.mp4', 'http://timg.bdta.pro/images/b1fdc6400d948ba05d6c013526476cc2.jpg'),
(12958, 829, 'Diarios de um Vampiro S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/133016.mp4', 'http://timg.bdta.pro/images/7dd586e95b6606cec9c033d14895326d.jpg'),
(12959, 829, 'Diarios de um Vampiro S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/133017.mp4', 'http://timg.bdta.pro/images/21563c95072950f354de9f5dc6bc05fd.jpg'),
(12960, 829, 'Diarios de um Vampiro S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/133018.mp4', 'http://timg.bdta.pro/images/ee502789af8c60684ff1a0bbb695ed6d.jpg'),
(12961, 829, 'Diarios de um Vampiro S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/133019.mp4', 'http://timg.bdta.pro/images/75e2e51d1963708361f5b43960b7517a.jpg'),
(12962, 829, 'Diarios de um Vampiro S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/133020.mp4', 'http://timg.bdta.pro/images/38eb20c6b621ca23822e94be98e45205.jpg'),
(12963, 829, 'Diarios de um Vampiro S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/133021.mp4', 'http://timg.bdta.pro/images/cb87fbc814330aeb1d8f00269c0b7fef.jpg'),
(12964, 829, 'Diarios de um Vampiro S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/133022.mp4', 'http://timg.bdta.pro/images/45399e475936e1d1e8be284de7089f5f.jpg'),
(12965, 829, 'Diarios de um Vampiro S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/133023.mp4', 'http://timg.bdta.pro/images/044e84d905753f274ffedf28a5bb8909.jpg'),
(12966, 829, 'Diarios de um Vampiro S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/133024.mp4', 'http://timg.bdta.pro/images/eadd5a47c151de41301eb489b84ed65c.jpg'),
(12967, 829, 'Diarios de um Vampiro S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/133025.mp4', 'http://timg.bdta.pro/images/8653c62c69b7313d572bd02b724affeb.jpg'),
(12968, 829, 'Diarios de um Vampiro S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/133026.mp4', 'http://timg.bdta.pro/images/2cc2af0ff6d10756bd80c26a7dc4c5f8.jpg'),
(12969, 829, 'Diarios de um Vampiro S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/133027.mp4', 'http://timg.bdta.pro/images/c63516a06502f625e01d6a2dd9195106.jpg'),
(12970, 829, 'Diarios de um Vampiro S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/133028.mp4', 'http://timg.bdta.pro/images/717fd72357183090962d64f54beb2baa.jpg'),
(12971, 829, 'Diarios de um Vampiro S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/133029.mp4', 'http://timg.bdta.pro/images/71a052fbbb98f15db49f2baf5f219125.jpg'),
(12972, 829, 'Diarios de um Vampiro S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/133030.mp4', 'http://timg.bdta.pro/images/f1a4991bfacb3f36bfcd6512aed38a5d.jpg'),
(12973, 829, 'Diarios de um Vampiro S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/133031.mp4', 'http://timg.bdta.pro/images/04978745dd0d32e12befb3a24fd5c799.jpg'),
(12974, 829, 'Diarios de um Vampiro S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/133032.mp4', 'http://timg.bdta.pro/images/b44b4d750974a83791d636a81a38c4f1.jpg'),
(12975, 829, 'Diarios de um Vampiro S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/133033.mp4', 'http://timg.bdta.pro/images/4171cc7f489c66abe02196c5ca8e416f.jpg'),
(12976, 829, 'Diarios de um Vampiro S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/133034.mp4', 'http://timg.bdta.pro/images/7ed697456600e5cf88ba9d5c80724626.jpg'),
(12977, 829, 'Diarios de um Vampiro S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/133035.mp4', 'http://timg.bdta.pro/images/1393d6e526a70ca2bb3d608594f32508.jpg'),
(12978, 830, 'Diarios de um Vampiro S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/133036.mp4', 'http://timg.bdta.pro/images/0ab42d0997d03dfd77c7d8695dcf9e26.jpg'),
(12979, 830, 'Diarios de um Vampiro S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/133037.mp4', 'http://timg.bdta.pro/images/7e8ba872261057f656358ccdd0a195f0.jpg'),
(12980, 830, 'Diarios de um Vampiro S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/133038.mp4', 'http://timg.bdta.pro/images/9bb03f0461c36bce978027f6fd484add.jpg'),
(12981, 830, 'Diarios de um Vampiro S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/133039.mp4', 'http://timg.bdta.pro/images/785b1740e1db2dbaf81cfdb6e4957b65.jpg'),
(12982, 830, 'Diarios de um Vampiro S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/133040.mp4', 'http://timg.bdta.pro/images/759c27ec3c0377906c919c830fce9ad4.jpg'),
(12983, 830, 'Diarios de um Vampiro S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/133041.mp4', 'http://timg.bdta.pro/images/46003a3c82d6e33e8445c4cc5d838f22.jpg'),
(12984, 830, 'Diarios de um Vampiro S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/133042.mp4', 'http://timg.bdta.pro/images/49c4a79bd155ebe7855005168501ecd7.jpg'),
(12985, 830, 'Diarios de um Vampiro S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/133043.mp4', 'http://timg.bdta.pro/images/23446ef93a02b62b4f8da16b00b38e99.jpg'),
(12986, 830, 'Diarios de um Vampiro S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/133044.mp4', 'http://timg.bdta.pro/images/404a9de2f2b9cb3ba83673314a4b547a.jpg'),
(12987, 830, 'Diarios de um Vampiro S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/133045.mp4', 'http://timg.bdta.pro/images/d66809ed80d3b9fb5566fc35f339548b.jpg'),
(12988, 830, 'Diarios de um Vampiro S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/133046.mp4', 'http://timg.bdta.pro/images/ef44fb68d28abbbdd84c2e8b76aae9e8.jpg'),
(12989, 830, 'Diarios de um Vampiro S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/133047.mp4', 'http://timg.bdta.pro/images/302aedb6ca70863751d909e01a9a9c8c.jpg'),
(12990, 830, 'Diarios de um Vampiro S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/133048.mp4', 'http://timg.bdta.pro/images/58c4bb4a7f94721b39a06fed61349d42.jpg'),
(12991, 830, 'Diarios de um Vampiro S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/133049.mp4', 'http://timg.bdta.pro/images/ebb772b677fb64c88a75e69974279745.jpg'),
(12992, 830, 'Diarios de um Vampiro S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/133050.mp4', 'http://timg.bdta.pro/images/b14f48b44844e6ca0879c7f07d4e7497.jpg'),
(12993, 830, 'Diarios de um Vampiro S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/133051.mp4', 'http://timg.bdta.pro/images/996a0b735b431220f0beac3c2250c0df.jpg'),
(12994, 830, 'Diarios de um Vampiro S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/133052.mp4', 'http://timg.bdta.pro/images/4a613680093f29414873c4a37ae448e2.jpg'),
(12995, 830, 'Diarios de um Vampiro S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/133053.mp4', 'http://timg.bdta.pro/images/074d8b37038058fc96711624f364d66c.jpg'),
(12996, 830, 'Diarios de um Vampiro S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/133054.mp4', 'http://timg.bdta.pro/images/71eb87ce3f95e041b07a3ba258e2ca2e.jpg'),
(12997, 830, 'Diarios de um Vampiro S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/133055.mp4', 'http://timg.bdta.pro/images/bb9470a1eb3da953ce93fe1fdac911c6.jpg'),
(12998, 830, 'Diarios de um Vampiro S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/133056.mp4', 'http://timg.bdta.pro/images/aa21f9cffde20c816e8700c8c63f7efb.jpg'),
(12999, 830, 'Diarios de um Vampiro S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/133057.mp4', 'http://timg.bdta.pro/images/c43b1b52a40187deb0551aa9521f0aa6.jpg'),
(13000, 830, 'Diarios de um Vampiro S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/133058.mp4', 'http://timg.bdta.pro/images/26eaf3faedeeb3cdeeb12e348a724806.jpg'),
(13001, 831, 'Diarios de um Vampiro S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/133059.mp4', 'http://timg.bdta.pro/images/d555c98d7a9e12be9cc2450d9c9c0894.jpg'),
(13002, 831, 'Diarios de um Vampiro S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/133060.mp4', 'http://timg.bdta.pro/images/6620ad2c643a8ebfe466d5b8d60b48f4.jpg'),
(13003, 831, 'Diarios de um Vampiro S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/133061.mp4', 'http://timg.bdta.pro/images/07399f298de36c65705552251fa084e0.jpg'),
(13004, 831, 'Diarios de um Vampiro S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/133062.mp4', 'http://timg.bdta.pro/images/9866d2e8a89ffa061fe637cf61a436f6.jpg'),
(13005, 831, 'Diarios de um Vampiro S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/133063.mp4', 'http://timg.bdta.pro/images/92c261d388b1883f42b58258f443d7db.jpg'),
(13006, 831, 'Diarios de um Vampiro S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/133064.mp4', 'http://timg.bdta.pro/images/da1ab7c8b949c800af35910faca21fa3.jpg'),
(13007, 831, 'Diarios de um Vampiro S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/133065.mp4', 'http://timg.bdta.pro/images/4abeeabf6c5e31f52a66a5d479421c3c.jpg'),
(13008, 831, 'Diarios de um Vampiro S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/133066.mp4', 'http://timg.bdta.pro/images/944dfa36a788c17bf91aa439edb46467.jpg'),
(13009, 831, 'Diarios de um Vampiro S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/133067.mp4', 'http://timg.bdta.pro/images/b848b94baf312807e45492c9efdfcc37.jpg'),
(13010, 831, 'Diarios de um Vampiro S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/133068.mp4', 'http://timg.bdta.pro/images/89bf3ceaa138c97346149ce78dc8e903.jpg'),
(13011, 831, 'Diarios de um Vampiro S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/133069.mp4', 'http://timg.bdta.pro/images/4dcda4764a688017475baf6d77f85743.jpg'),
(13012, 831, 'Diarios de um Vampiro S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/133070.mp4', 'http://timg.bdta.pro/images/5704d291ff61496d9d8fb304107ca80e.jpg'),
(13013, 831, 'Diarios de um Vampiro S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/133071.mp4', 'http://timg.bdta.pro/images/c2187721a13ab7011b599e25b73281fb.jpg'),
(13014, 831, 'Diarios de um Vampiro S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/133072.mp4', 'http://timg.bdta.pro/images/e386d4ae1018faa6e863db85f2154ba2.jpg'),
(13015, 831, 'Diarios de um Vampiro S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/133073.mp4', 'http://timg.bdta.pro/images/d90b0d913b4d31e8a7fe66e7e2374849.jpg'),
(13016, 831, 'Diarios de um Vampiro S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/133074.mp4', 'http://timg.bdta.pro/images/97d29895a5cddb76b138eba0228fae20.jpg'),
(13017, 831, 'Diarios de um Vampiro S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/133075.mp4', 'http://timg.bdta.pro/images/5d2a56b5e9c6fc8a4cfe066214fed08e.jpg'),
(13018, 831, 'Diarios de um Vampiro S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/133076.mp4', 'http://timg.bdta.pro/images/3a6bfd4f98a0d897a725cb015980ac89.jpg'),
(13019, 831, 'Diarios de um Vampiro S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/133077.mp4', 'http://timg.bdta.pro/images/1803b233be982bfe9b4e9b165f49fc80.jpg'),
(13020, 831, 'Diarios de um Vampiro S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/133078.mp4', 'http://timg.bdta.pro/images/e987a26a0f73b77b82103595bb01bc2b.jpg'),
(13021, 831, 'Diarios de um Vampiro S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/133079.mp4', 'http://timg.bdta.pro/images/72a70f09aa0272706950e94660e69eb3.jpg'),
(13022, 831, 'Diarios de um Vampiro S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/133080.mp4', 'http://timg.bdta.pro/images/8e85922684042b8532319cd43e0369c7.jpg'),
(13023, 832, 'Diarios de um Vampiro S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/133081.mp4', 'http://timg.bdta.pro/images/cff55cfca896ba351635ac97647d08e1.jpg'),
(13024, 832, 'Diarios de um Vampiro S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/133082.mp4', 'http://timg.bdta.pro/images/26767b1a65e42a1ceae82ecb7773d9d0.jpg'),
(13025, 832, 'Diarios de um Vampiro S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/133083.mp4', 'http://timg.bdta.pro/images/4ed7826c5f571de3fd46ef8d33e3cffc.jpg'),
(13026, 832, 'Diarios de um Vampiro S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/133084.mp4', 'http://timg.bdta.pro/images/24f25cec13c03f5e97ae85589906f5a9.jpg'),
(13027, 832, 'Diarios de um Vampiro S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/133085.mp4', 'http://timg.bdta.pro/images/a539ffebcf19f8dcc1baaa67152b8092.jpg'),
(13028, 832, 'Diarios de um Vampiro S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/133086.mp4', 'http://timg.bdta.pro/images/828442cc08cbadde287b7034373e9737.jpg'),
(13029, 832, 'Diarios de um Vampiro S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/133087.mp4', 'http://timg.bdta.pro/images/b94cd55442eeafccd6a4a058369cfbd2.jpg'),
(13030, 832, 'Diarios de um Vampiro S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/133088.mp4', 'http://timg.bdta.pro/images/eee0cbc0f796d12965cad826357da62f.jpg'),
(13031, 832, 'Diarios de um Vampiro S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/133089.mp4', 'http://timg.bdta.pro/images/2ab7c912be11c50bf190fadc6f94e496.jpg'),
(13032, 832, 'Diarios de um Vampiro S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/133090.mp4', 'http://timg.bdta.pro/images/6d38a57446d497285a61505340b7e83c.jpg'),
(13033, 832, 'Diarios de um Vampiro S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/133091.mp4', 'http://timg.bdta.pro/images/f9a4d2c1b3476609ef2225888f1421c1.jpg'),
(13034, 832, 'Diarios de um Vampiro S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/133092.mp4', 'http://timg.bdta.pro/images/3d93fc49f4abf6814fda9374cbee4d15.jpg'),
(13035, 832, 'Diarios de um Vampiro S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/133093.mp4', 'http://timg.bdta.pro/images/0caf60d5a61fe9dd2cea2f797e104faa.jpg'),
(13036, 832, 'Diarios de um Vampiro S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/133094.mp4', 'http://timg.bdta.pro/images/6f6eeab72bddd418af8ca0c63aafdda8.jpg'),
(13037, 832, 'Diarios de um Vampiro S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/133095.mp4', 'http://timg.bdta.pro/images/8b6688a50f306408a1ccd697f0655468.jpg'),
(13038, 832, 'Diarios de um Vampiro S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/133096.mp4', 'http://timg.bdta.pro/images/661ac8208a26af1fc48f8781af6c4c11.jpg'),
(13039, 832, 'Diarios de um Vampiro S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/133097.mp4', 'http://timg.bdta.pro/images/19499325ff44609667146d0235e77070.jpg'),
(13040, 832, 'Diarios de um Vampiro S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/133098.mp4', 'http://timg.bdta.pro/images/2996e853b35ab57a93389de574acde25.jpg'),
(13041, 832, 'Diarios de um Vampiro S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/133099.mp4', 'http://timg.bdta.pro/images/c7fa50c75aa42ab2c1d4f6a538ec4922.jpg'),
(13042, 832, 'Diarios de um Vampiro S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/133100.mp4', 'http://timg.bdta.pro/images/669912bb6f370acb5b56ce7d6041f2af.jpg'),
(13043, 832, 'Diarios de um Vampiro S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/133101.mp4', 'http://timg.bdta.pro/images/0b6e96da62b3a77104213f4d25f1e608.jpg'),
(13044, 832, 'Diarios de um Vampiro S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/133102.mp4', 'http://timg.bdta.pro/images/3536793e0fed3d5caca1e1bd8228ac3c.jpg'),
(13045, 833, 'Diarios de um Vampiro S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/133103.mp4', 'http://timg.bdta.pro/images/cd2210718a2f4c7878c6b119ee040560.jpg'),
(13046, 833, 'Diarios de um Vampiro S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/133104.mp4', 'http://timg.bdta.pro/images/b4bc751bb7d6f2aa7b1574399cb7a811.jpg'),
(13047, 833, 'Diarios de um Vampiro S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/133105.mp4', 'http://timg.bdta.pro/images/03721d5f6d7236908397da65f9cd0b94.jpg'),
(13048, 833, 'Diarios de um Vampiro S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/133106.mp4', 'http://timg.bdta.pro/images/c5676e696412c855f1b4887e6cc5f20d.jpg'),
(13049, 833, 'Diarios de um Vampiro S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/133107.mp4', 'http://timg.bdta.pro/images/fbecf1063cf9e381d7508e28c8f0fc4b.jpg'),
(13050, 833, 'Diarios de um Vampiro S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/133108.mp4', 'http://timg.bdta.pro/images/16f5dcf34227cec3221ed1376adbf30a.jpg'),
(13051, 833, 'Diarios de um Vampiro S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/133109.mp4', 'http://timg.bdta.pro/images/b1b034107962680c36edf3874e9c51e2.jpg'),
(13052, 833, 'Diarios de um Vampiro S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/133110.mp4', 'http://timg.bdta.pro/images/df765448c365f51c90eb08765c1b5182.jpg'),
(13053, 833, 'Diarios de um Vampiro S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/133111.mp4', 'http://timg.bdta.pro/images/a343170550a059a0f6c0726044f0c65d.jpg'),
(13054, 833, 'Diarios de um Vampiro S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/133112.mp4', 'http://timg.bdta.pro/images/b6dda75b169fac6e598841107f674f3a.jpg'),
(13055, 833, 'Diarios de um Vampiro S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/133113.mp4', 'http://timg.bdta.pro/images/684fdafeda7bd5371418cc6515b98efa.jpg'),
(13056, 833, 'Diarios de um Vampiro S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/133114.mp4', 'http://timg.bdta.pro/images/5ec77f5fd1c0e3b9c1c690e79df09960.jpg'),
(13057, 833, 'Diarios de um Vampiro S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/133115.mp4', 'http://timg.bdta.pro/images/e6677a5a9379bec545e09f28b5d2a114.jpg'),
(13058, 833, 'Diarios de um Vampiro S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/133116.mp4', 'http://timg.bdta.pro/images/74c251a92eab2b51e3f4588adb2e1513.jpg'),
(13059, 833, 'Diarios de um Vampiro S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/133117.mp4', 'http://timg.bdta.pro/images/8756c153e8507e9a2004057f7fd649ad.jpg'),
(13060, 833, 'Diarios de um Vampiro S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/133118.mp4', 'http://timg.bdta.pro/images/ebb8cf465ee6722626ab8d29a2a32424.jpg'),
(13061, 833, 'Diarios de um Vampiro S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/133119.mp4', 'http://timg.bdta.pro/images/d0f9647b25080424f61929acfd015d45.jpg'),
(13062, 833, 'Diarios de um Vampiro S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/133120.mp4', 'http://timg.bdta.pro/images/3c3c4395d434fb7cafd2d807e91fdd73.jpg'),
(13063, 833, 'Diarios de um Vampiro S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/133121.mp4', 'http://timg.bdta.pro/images/ddd9364d6d4d508114a01275f69f8d39.jpg'),
(13064, 833, 'Diarios de um Vampiro S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/133122.mp4', 'http://timg.bdta.pro/images/03db60f357fe5ad7aa2d8b9186c77dea.jpg'),
(13065, 833, 'Diarios de um Vampiro S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/133123.mp4', 'http://timg.bdta.pro/images/3baf1a55ce603b5a61d8f7bee66260e6.jpg'),
(13066, 833, 'Diarios de um Vampiro S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/133124.mp4', 'http://timg.bdta.pro/images/0c8aa89acb3241a29c3f3e96183c2041.jpg'),
(13067, 834, 'Diarios de um Vampiro S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/133125.mp4', 'http://timg.bdta.pro/images/3848410c33e7294589900e46cf2affad.jpg'),
(13068, 834, 'Diarios de um Vampiro S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/133126.mp4', 'http://timg.bdta.pro/images/a996106169e89b0209a19498b36d8136.jpg'),
(13069, 834, 'Diarios de um Vampiro S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/133127.mp4', 'http://timg.bdta.pro/images/2017601998b65a1baa912a5b1f466a07.jpg'),
(13070, 834, 'Diarios de um Vampiro S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/133128.mp4', 'http://timg.bdta.pro/images/a17d42945fae39bf69e73408f6eda383.jpg'),
(13071, 834, 'Diarios de um Vampiro S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/133129.mp4', 'http://timg.bdta.pro/images/801f8ab5111f38a7b1c3061980865728.jpg'),
(13072, 834, 'Diarios de um Vampiro S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/133130.mp4', 'http://timg.bdta.pro/images/b83e1e150decf075459df2a9c6825ecf.jpg'),
(13073, 834, 'Diarios de um Vampiro S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/133131.mp4', 'http://timg.bdta.pro/images/a00b01c796315ad98f8636ae604c17c9.jpg'),
(13074, 834, 'Diarios de um Vampiro S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/133132.mp4', 'http://timg.bdta.pro/images/c82749653845089862c99f7d9fe2dcd2.jpg'),
(13075, 834, 'Diarios de um Vampiro S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/133133.mp4', 'http://timg.bdta.pro/images/7f5fb1fdd1ebca1f2ae4a36fb4e19f34.jpg'),
(13076, 834, 'Diarios de um Vampiro S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/133134.mp4', 'http://timg.bdta.pro/images/8b6e42568837b7512d3c430e61cf350a.jpg'),
(13077, 834, 'Diarios de um Vampiro S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/133135.mp4', 'http://timg.bdta.pro/images/e403809148a29013aa8aa565f2b69a0a.jpg'),
(13078, 834, 'Diarios de um Vampiro S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/133136.mp4', 'http://timg.bdta.pro/images/34b2004299c188787c1337b5f98a5215.jpg'),
(13079, 834, 'Diarios de um Vampiro S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/133137.mp4', 'http://timg.bdta.pro/images/db063a55dc89ff7ba18a0db7b557900a.jpg'),
(13080, 834, 'Diarios de um Vampiro S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/133138.mp4', 'http://timg.bdta.pro/images/6ed15b500186322bc6297e17dc012df3.jpg'),
(13081, 834, 'Diarios de um Vampiro S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/133139.mp4', 'http://timg.bdta.pro/images/2d8afe0ec28a80cb5337885a58bff581.jpg'),
(13082, 834, 'Diarios de um Vampiro S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/133140.mp4', 'http://timg.bdta.pro/images/44fe5be0f375876f09146549c385de40.jpg'),
(13083, 835, 'The Walking Dead S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201271.mp4', 'http://timg.bdta.pro/images/0a0697555c84cd30ba3234b74aba52ae.jpg'),
(13084, 835, 'The Walking Dead S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201272.mp4', 'http://timg.bdta.pro/images/c0d65ca7f83f033ca2bbfd70946ed272.jpg'),
(13085, 835, 'The Walking Dead S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201273.mp4', 'http://timg.bdta.pro/images/aef42570aa443aeabd8dc3bc75b8e448.jpg'),
(13086, 835, 'The Walking Dead S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201274.mp4', 'http://timg.bdta.pro/images/13a7c7a789c0edebf03f13b6b1143175.jpg'),
(13087, 835, 'The Walking Dead S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201275.mp4', 'http://timg.bdta.pro/images/6632b9958f9f5d278072dfb8012faa31.jpg'),
(13088, 835, 'The Walking Dead S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201276.mp4', 'http://timg.bdta.pro/images/8074818af3a16b95b213566478e816eb.jpg'),
(13089, 836, 'The Walking Dead S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201277.mp4', 'http://timg.bdta.pro/images/efda5b13481a54cb96a1477d13ae1761.jpg'),
(13090, 836, 'The Walking Dead S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201278.mp4', 'http://timg.bdta.pro/images/87ff95db76b72a773613f3432b0a6b0f.jpg'),
(13091, 836, 'The Walking Dead S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201279.mp4', 'http://timg.bdta.pro/images/9f3c7fda3ab9c24cf103b5649f3c92ab.jpg'),
(13092, 836, 'The Walking Dead S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201280.mp4', 'http://timg.bdta.pro/images/25b4b33d7b5ffb7fc570eb69dc7a92ca.jpg'),
(13093, 836, 'The Walking Dead S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201281.mp4', 'http://timg.bdta.pro/images/7d12ede66894c9f7a8a44dd9c7cb7de0.jpg'),
(13094, 836, 'The Walking Dead S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201282.mp4', 'http://timg.bdta.pro/images/ca722afcf8c220a793d3f6eb7a3195c0.jpg'),
(13095, 836, 'The Walking Dead S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201283.mp4', 'http://timg.bdta.pro/images/51c057715b734697f07d6d4ac10c6118.jpg'),
(13096, 836, 'The Walking Dead S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201284.mp4', 'http://timg.bdta.pro/images/f48454020ccc895b75e298b9efd5803e.jpg'),
(13097, 836, 'The Walking Dead S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201285.mp4', 'http://timg.bdta.pro/images/3aa4f45711792f9fcbc3505a3d647731.jpg'),
(13098, 836, 'The Walking Dead S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201286.mp4', 'http://timg.bdta.pro/images/1926571c1f06acee1492f9d7661a24f6.jpg'),
(13099, 836, 'The Walking Dead S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201287.mp4', 'http://timg.bdta.pro/images/8583e8e23f683b09f28b1a09a38046de.jpg'),
(13100, 836, 'The Walking Dead S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201288.mp4', 'http://timg.bdta.pro/images/15551c8bfab7f55d9e42a81d7beacfcf.jpg'),
(13101, 836, 'The Walking Dead S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201289.mp4', 'http://timg.bdta.pro/images/887de6c0539789517c146633929cfd19.jpg'),
(13102, 837, 'The Walking Dead S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201290.mp4', 'http://timg.bdta.pro/images/f3376bd9b231f24695e2d684bb9e4fa5.jpg'),
(13103, 837, 'The Walking Dead S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201291.mp4', 'http://timg.bdta.pro/images/3ae77a9fc392b567a3c8efa56719c342.jpg'),
(13104, 837, 'The Walking Dead S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201292.mp4', 'http://timg.bdta.pro/images/e618bab3c4a534e6cbf2753990b76ff5.jpg'),
(13105, 837, 'The Walking Dead S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201293.mp4', 'http://timg.bdta.pro/images/f6a9e6d2a86b93d5d07a7761da101f37.jpg'),
(13106, 837, 'The Walking Dead S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201294.mp4', 'http://timg.bdta.pro/images/3672ca90e4a37b1119a4813558dc3895.jpg'),
(13107, 837, 'The Walking Dead S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201295.mp4', 'http://timg.bdta.pro/images/08f89acc179c46f310bb0112b35a72c7.jpg'),
(13108, 837, 'The Walking Dead S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201296.mp4', 'http://timg.bdta.pro/images/cab872c8ad8b42f3fabc2866d9630d71.jpg'),
(13109, 837, 'The Walking Dead S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201297.mp4', 'http://timg.bdta.pro/images/4de2512c738e2b8943334a0dee3790b7.jpg'),
(13110, 837, 'The Walking Dead S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201298.mp4', 'http://timg.bdta.pro/images/870d65f35dd5ddbe8c933b4459f6860c.jpg'),
(13111, 837, 'The Walking Dead S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201299.mp4', 'http://timg.bdta.pro/images/44da0aece4ef04215f912c3109d5cc01.jpg'),
(13112, 837, 'The Walking Dead S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201300.mp4', 'http://timg.bdta.pro/images/dbf117052133d0998455c061d8ebb26f.jpg'),
(13113, 837, 'The Walking Dead S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201301.mp4', 'http://timg.bdta.pro/images/79f8ea44629790012c1413b067c43775.jpg'),
(13114, 837, 'The Walking Dead S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201302.mp4', 'http://timg.bdta.pro/images/efc2c2f60c962450db330ba2b58b715a.jpg'),
(13115, 837, 'The Walking Dead S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/201303.mp4', 'http://timg.bdta.pro/images/a9debd7f9360013f5ba65d58eff5ecad.jpg'),
(13116, 837, 'The Walking Dead S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/201304.mp4', 'http://timg.bdta.pro/images/d99616efa0e45ee94883ffd2e650d969.jpg'),
(13117, 837, 'The Walking Dead S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/201305.mp4', 'http://timg.bdta.pro/images/cc09bda6ab1d50b498f8987ab954392a.jpg'),
(13118, 838, 'The Walking Dead S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201306.mp4', 'http://timg.bdta.pro/images/f7ad0ebbb0c9eec9cee0c1b2a0d74ee4.jpg'),
(13119, 838, 'The Walking Dead S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201307.mp4', 'http://timg.bdta.pro/images/3cda1cce98e12e9628b7ae91f03c95da.jpg'),
(13120, 838, 'The Walking Dead S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201308.mp4', 'http://timg.bdta.pro/images/bdf7ed475c651e071f00a7a69ac600e8.jpg'),
(13121, 838, 'The Walking Dead S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201309.mp4', 'http://timg.bdta.pro/images/6a09afec09a1bbea625bc48871e18cff.jpg'),
(13122, 838, 'The Walking Dead S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201310.mp4', 'http://timg.bdta.pro/images/fe32320372339e6b65db11bcbc69ab94.jpg'),
(13123, 838, 'The Walking Dead S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201311.mp4', 'http://timg.bdta.pro/images/9b01c0ef6e5d427381eb531fde35efd7.jpg'),
(13124, 838, 'The Walking Dead S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201312.mp4', 'http://timg.bdta.pro/images/ea2fad439eee35659fd635986a9332d5.jpg'),
(13125, 838, 'The Walking Dead S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201313.mp4', 'http://timg.bdta.pro/images/de2559006713be194028c0d70e01768a.jpg'),
(13126, 838, 'The Walking Dead S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201314.mp4', 'http://timg.bdta.pro/images/b3d0f153b13478416a9cafd640f4be96.jpg'),
(13127, 838, 'The Walking Dead S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201315.mp4', 'http://timg.bdta.pro/images/18c55a20b93429bd1ca1860e88dc1bb1.jpg'),
(13128, 838, 'The Walking Dead S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201316.mp4', 'http://timg.bdta.pro/images/977cfc12d75198c48143bd3293fbf7d8.jpg'),
(13129, 838, 'The Walking Dead S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201317.mp4', 'http://timg.bdta.pro/images/27e71779714964ca49024943082e787b.jpg'),
(13130, 838, 'The Walking Dead S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201318.mp4', 'http://timg.bdta.pro/images/2ccfe8101e42df79d72f81d73168570a.jpg'),
(13131, 838, 'The Walking Dead S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/201319.mp4', 'http://timg.bdta.pro/images/a1d30bf2932e09811d393013f2b4455d.jpg'),
(13132, 838, 'The Walking Dead S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/201320.mp4', 'http://timg.bdta.pro/images/9b5156193bf964abca805a15b7ed9478.jpg'),
(13133, 838, 'The Walking Dead S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/201321.mp4', 'http://timg.bdta.pro/images/6bc656fd88d0b2a157987d563a55f23a.jpg'),
(13134, 839, 'The Walking Dead S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201322.mp4', 'http://timg.bdta.pro/images/1a8c1e47b9cc87809d5fcd3be2e3225b.jpg'),
(13135, 839, 'The Walking Dead S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201323.mp4', 'http://timg.bdta.pro/images/c2f0c13b209c8e81b401ea3949c97992.jpg'),
(13136, 839, 'The Walking Dead S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201324.mp4', 'http://timg.bdta.pro/images/40ae6a39b6eacb327b18f0c6389c164e.jpg'),
(13137, 839, 'The Walking Dead S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201325.mp4', 'http://timg.bdta.pro/images/c05d60adeb7df404cef54beafa47bd69.jpg'),
(13138, 839, 'The Walking Dead S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201326.mp4', 'http://timg.bdta.pro/images/2cea7475e9d5cb828900a40fc7b4bbe6.jpg'),
(13139, 839, 'The Walking Dead S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201327.mp4', 'http://timg.bdta.pro/images/d5c9fb0b9c5b389743c83ec7fcfd471a.jpg'),
(13140, 839, 'The Walking Dead S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201328.mp4', 'http://timg.bdta.pro/images/ec844780353b1d83d3ae534352de1061.jpg'),
(13141, 839, 'The Walking Dead S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201329.mp4', 'http://timg.bdta.pro/images/8fc1d21ef7c710a575c84b1b4a62dcc8.jpg'),
(13142, 839, 'The Walking Dead S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201330.mp4', 'http://timg.bdta.pro/images/90f7fc1a654fa7d36421f992087a67e7.jpg'),
(13143, 839, 'The Walking Dead S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201331.mp4', 'http://timg.bdta.pro/images/8f55d844c97af91c50f3d3ad7cea9431.jpg'),
(13144, 839, 'The Walking Dead S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201332.mp4', 'http://timg.bdta.pro/images/587ff933b5bdbd92d89aa665579dffdb.jpg'),
(13145, 839, 'The Walking Dead S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201333.mp4', 'http://timg.bdta.pro/images/335e4ecc743a5207afe21b4ed251f634.jpg'),
(13146, 839, 'The Walking Dead S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201334.mp4', 'http://timg.bdta.pro/images/e78d8e1197bbeb5d229d5f66435c4687.jpg'),
(13147, 839, 'The Walking Dead S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/201335.mp4', 'http://timg.bdta.pro/images/5fecbd3d9e2f4978f57aa6850eb9bde4.jpg'),
(13148, 839, 'The Walking Dead S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/201336.mp4', 'http://timg.bdta.pro/images/5f5f8f65602a215f919efd6dad9b730e.jpg'),
(13149, 839, 'The Walking Dead S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/201337.mp4', 'http://timg.bdta.pro/images/f1a3e7cf3af736f1e031d14440882824.jpg'),
(13150, 840, 'The Walking Dead S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201338.mp4', 'http://timg.bdta.pro/images/fb49bd3e5bf52768f36f47ad0dca4fc7.jpg'),
(13151, 840, 'The Walking Dead S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201339.mp4', 'http://timg.bdta.pro/images/c87dbca8af5b5b7637ce2a7213e7554c.jpg'),
(13152, 840, 'The Walking Dead S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201340.mp4', 'http://timg.bdta.pro/images/3dbd3c7b156ade97e75d1f4d38a48c0c.jpg'),
(13153, 840, 'The Walking Dead S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201341.mp4', 'http://timg.bdta.pro/images/8e32fade9c7646b4a36af11c5d0fa55e.jpg'),
(13154, 840, 'The Walking Dead S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201342.mp4', 'http://timg.bdta.pro/images/7d9b6e541791b665129427af92da7751.jpg'),
(13155, 840, 'The Walking Dead S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201343.mp4', 'http://timg.bdta.pro/images/7be10f745053a2ad5f4c855d7c108274.jpg'),
(13156, 840, 'The Walking Dead S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201344.mp4', 'http://timg.bdta.pro/images/176a02711c2b0b9d7dc9adc7e9def762.jpg'),
(13157, 840, 'The Walking Dead S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201345.mp4', 'http://timg.bdta.pro/images/d4ed8f3a7187c52b0f0e62ae4b047fb7.jpg'),
(13158, 840, 'The Walking Dead S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201346.mp4', 'http://timg.bdta.pro/images/952ddd5390baa83a5d65cb6cb0fc6ba1.jpg'),
(13159, 840, 'The Walking Dead S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201347.mp4', 'http://timg.bdta.pro/images/012bece81bf0dd4cf98bf8858ce34c8a.jpg'),
(13160, 840, 'The Walking Dead S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201348.mp4', 'http://timg.bdta.pro/images/e65e0adbb410bb478e3709111fee14ce.jpg'),
(13161, 840, 'The Walking Dead S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201349.mp4', 'http://timg.bdta.pro/images/73480b01551f18a166e075d306afef39.jpg'),
(13162, 840, 'The Walking Dead S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201350.mp4', 'http://timg.bdta.pro/images/8834a6aca1ab26d981a508ee15a806a1.jpg'),
(13163, 840, 'The Walking Dead S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/201351.mp4', 'http://timg.bdta.pro/images/c6a93f2aff00d44a1daac054960bec54.jpg'),
(13164, 840, 'The Walking Dead S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/201352.mp4', 'http://timg.bdta.pro/images/6190dcd7ec84d75aa96c922f9e4ad009.jpg'),
(13165, 840, 'The Walking Dead S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/201353.mp4', 'http://timg.bdta.pro/images/770263a6e81399f70cb772b427cfcd3f.jpg'),
(13166, 841, 'The Walking Dead S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201354.mp4', 'http://timg.bdta.pro/images/6815e044ecae041c17c9f781d504ab71.jpg'),
(13167, 841, 'The Walking Dead S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201355.mp4', 'http://timg.bdta.pro/images/cbdc8a9d15b33eb55165f0101e8c0caf.jpg'),
(13168, 841, 'The Walking Dead S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201356.mp4', 'http://timg.bdta.pro/images/ea8015a26591727b401677a9bb32b246.jpg'),
(13169, 841, 'The Walking Dead S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201357.mp4', 'http://timg.bdta.pro/images/d7468726674fe96b20ddf3bf0eb8f853.jpg'),
(13170, 841, 'The Walking Dead S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201358.mp4', 'http://timg.bdta.pro/images/c63dd3ca252dc694f7c23230b3b700d0.jpg'),
(13171, 841, 'The Walking Dead S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201359.mp4', 'http://timg.bdta.pro/images/74e0aab994230b1109c0952d810eee27.jpg'),
(13172, 841, 'The Walking Dead S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201360.mp4', 'http://timg.bdta.pro/images/ca284214d70764aeb8df2fd765c43927.jpg'),
(13173, 841, 'The Walking Dead S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201361.mp4', 'http://timg.bdta.pro/images/307d7a49e5ac02f04b75be40c976d241.jpg'),
(13174, 841, 'The Walking Dead S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201362.mp4', 'http://timg.bdta.pro/images/29e414be6354520795f2f3e2fd899bc5.jpg'),
(13175, 841, 'The Walking Dead S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201363.mp4', 'http://timg.bdta.pro/images/b83f7bbbca8e53be09dc216bd99aa61e.jpg'),
(13176, 841, 'The Walking Dead S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201364.mp4', 'http://timg.bdta.pro/images/f1b80ef800e059c90c75c76d32e74373.jpg'),
(13177, 841, 'The Walking Dead S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201365.mp4', 'http://timg.bdta.pro/images/5c0582e73a8530159eb3a262b58463fc.jpg'),
(13178, 841, 'The Walking Dead S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201366.mp4', 'http://timg.bdta.pro/images/e09dabcff5a8ef11f962716ff1b439df.jpg'),
(13179, 841, 'The Walking Dead S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/201367.mp4', 'http://timg.bdta.pro/images/30b5af66517d7a3be78d42b104b6858e.jpg'),
(13180, 841, 'The Walking Dead S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/201368.mp4', 'http://timg.bdta.pro/images/5810ba3ffce6ef4c4e397ff2a3b65ecd.jpg'),
(13181, 841, 'The Walking Dead S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/201369.mp4', 'http://timg.bdta.pro/images/296794fc6c39fdb862815fef1a2fb3fd.jpg'),
(13182, 842, 'The Walking Dead S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201370.mp4', 'http://timg.bdta.pro/images/9c91d0fd5ff0800553863f15ce04cace.jpg'),
(13183, 842, 'The Walking Dead S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201371.mp4', 'http://timg.bdta.pro/images/78f87040819218ba17371ec637ed8d10.jpg'),
(13184, 842, 'The Walking Dead S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201372.mp4', 'http://timg.bdta.pro/images/ae08b3dfb8d340279a41769580895327.jpg'),
(13185, 842, 'The Walking Dead S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201373.mp4', 'http://timg.bdta.pro/images/6525aaf3874b459248045db13415c25e.jpg'),
(13186, 842, 'The Walking Dead S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201374.mp4', 'http://timg.bdta.pro/images/0bbbe439475675c40e3eae6cd40309b5.jpg'),
(13187, 842, 'The Walking Dead S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201375.mp4', 'http://timg.bdta.pro/images/c30531b544b47cb755887e64e030e80b.jpg'),
(13188, 842, 'The Walking Dead S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201376.mp4', 'http://timg.bdta.pro/images/7999fe223911d481c10b676a6c223746.jpg'),
(13189, 842, 'The Walking Dead S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201377.mp4', 'http://timg.bdta.pro/images/fd1cfbf686b2ce79bb3dd6b0d1774deb.jpg'),
(13190, 842, 'The Walking Dead S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201378.mp4', 'http://timg.bdta.pro/images/bb18170954794f41ef49d6ee32252088.jpg'),
(13191, 842, 'The Walking Dead S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201379.mp4', 'http://timg.bdta.pro/images/e871e45ca2165a9d6d38deacf138b84d.jpg'),
(13192, 842, 'The Walking Dead S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201380.mp4', 'http://timg.bdta.pro/images/3519e032cf6cb301c7d67d39cdd9d313.jpg'),
(13193, 842, 'The Walking Dead S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201381.mp4', 'http://timg.bdta.pro/images/aa5b1c03b32b6ab026f6ffafe5f363a3.jpg'),
(13194, 842, 'The Walking Dead S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201382.mp4', 'http://timg.bdta.pro/images/bf281c7c3b7498b03a2ec9a227c6b35e.jpg'),
(13195, 842, 'The Walking Dead S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/201383.mp4', 'http://timg.bdta.pro/images/6f53afdb5d22b18eb3b555a0269b74f7.jpg'),
(13196, 842, 'The Walking Dead S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/201384.mp4', 'http://timg.bdta.pro/images/7c7236a7931c051bde2f7be1763dd903.jpg'),
(13197, 842, 'The Walking Dead S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/201385.mp4', 'http://timg.bdta.pro/images/53fcc813b04ad5f32daf8976b28a9a81.jpg'),
(13198, 843, 'The Walking Dead S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201386.mp4', 'http://timg.bdta.pro/images/095a3ee81dc865105b12ec2148155d74.jpg'),
(13199, 843, 'The Walking Dead S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201387.mp4', 'http://timg.bdta.pro/images/85b736b3008e28d6103623049392833b.jpg'),
(13200, 843, 'The Walking Dead S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201388.mp4', 'http://timg.bdta.pro/images/b5dd4b47a8a9cd85d657be4f468930a4.jpg'),
(13201, 843, 'The Walking Dead S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201389.mp4', 'http://timg.bdta.pro/images/7150b9ba8bcfb6e170cc0879bf92b397.jpg'),
(13202, 843, 'The Walking Dead S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201390.mp4', 'http://timg.bdta.pro/images/ceefad2591ee64b4c8f4c27449e296b1.jpg'),
(13203, 843, 'The Walking Dead S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201391.mp4', 'http://timg.bdta.pro/images/58b3b95a62e124b4a667b128e94576db.jpg'),
(13204, 843, 'The Walking Dead S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201392.mp4', 'http://timg.bdta.pro/images/28c3825a895f8e3b2c8a76e252248c2e.jpg'),
(13205, 843, 'The Walking Dead S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201393.mp4', 'http://timg.bdta.pro/images/3ef54b31226d3bceb62f2260dbc019c4.jpg'),
(13206, 843, 'The Walking Dead S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201394.mp4', 'http://timg.bdta.pro/images/13bee6aeb49d29873074a46692298eb1.jpg'),
(13207, 843, 'The Walking Dead S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201395.mp4', 'http://timg.bdta.pro/images/6a00e3743dd78952586dbe61bee492f7.jpg'),
(13208, 843, 'The Walking Dead S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201396.mp4', 'http://timg.bdta.pro/images/61ca74137eaa417436658970dd7ad553.jpg'),
(13209, 843, 'The Walking Dead S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201397.mp4', 'http://timg.bdta.pro/images/5a0a2991644a0010b7fb8df2f8c21867.jpg'),
(13210, 843, 'The Walking Dead S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201398.mp4', 'http://timg.bdta.pro/images/91bdb1f360eca75879c94221c5480f29.jpg'),
(13211, 843, 'The Walking Dead S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/201399.mp4', 'http://timg.bdta.pro/images/a9aa4f5deab12348974d0a4ee47b9490.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(13212, 843, 'The Walking Dead S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/201400.mp4', 'http://timg.bdta.pro/images/7bdbf5eab34c619a4d0bf26c15931d7d.jpg'),
(13213, 843, 'The Walking Dead S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/201401.mp4', 'http://timg.bdta.pro/images/7f770041572ef5d74bb51cfb044b16d6.jpg'),
(13214, 844, 'The Walking Dead S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201402.mp4', 'http://image.tmdb.org/t/p/w300/j55MwsdBFbkVnXBe4auVWqawRy7.jpg'),
(13215, 844, 'The Walking Dead S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201403.mp4', 'http://image.tmdb.org/t/p/w300/y6gXWKMIfcNBd3HKMNNSagmD8B.jpg'),
(13216, 844, 'The Walking Dead S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201404.mp4', 'http://image.tmdb.org/t/p/w300/nOkcmuzFpatH6kBoy6yffq28Sm7.jpg'),
(13217, 844, 'The Walking Dead S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201405.mp4', 'http://image.tmdb.org/t/p/w300/xtA5BvN6LoB8Yb71tjp9T0Kgad.jpg'),
(13218, 844, 'The Walking Dead S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201406.mp4', 'http://image.tmdb.org/t/p/w300/aqVRzGML87bdlZQXnfnfKmF5LRA.jpg'),
(13219, 844, 'The Walking Dead S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201407.mp4', 'http://image.tmdb.org/t/p/w300/ueJUQ2y2ReiuPDQqvluG9J1M3Et.jpg'),
(13220, 844, 'The Walking Dead S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201408.mp4', 'http://image.tmdb.org/t/p/w300/iauRDeUVh6Bjx1CCBasdQzToUXb.jpg'),
(13221, 844, 'The Walking Dead S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201409.mp4', 'http://timg.bdta.pro/images/196cbf0a986dd4c47b57115d35cb812e.jpg'),
(13222, 844, 'The Walking Dead S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201410.mp4', 'http://timg.bdta.pro/images/8e96df70574c37034b1f9af77282fc12.jpg'),
(13223, 844, 'The Walking Dead S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201411.mp4', 'http://image.tmdb.org/t/p/w300/vLEq2WudpyWyDoYgYSKqiUfSV26.jpg'),
(13224, 844, 'The Walking Dead S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201412.mp4', 'http://image.tmdb.org/t/p/w300/mGFHGgljPH6OPeNugRySAQ1pD9S.jpg'),
(13225, 844, 'The Walking Dead S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201413.mp4', 'http://timg.bdta.pro/images/d966890e70ce3943a4dd7f8b9ce3e414.jpg'),
(13226, 844, 'The Walking Dead S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201414.mp4', 'http://image.tmdb.org/t/p/w300/nbJ0Rfv3i2TBuOrJtcmtzVxCgvQ.jpg'),
(13227, 844, 'The Walking Dead S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/201415.mp4', 'http://image.tmdb.org/t/p/w300/ysyqoqkN7aMVitSJVZ1NflRfoYa.jpg'),
(13228, 844, 'The Walking Dead S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/201416.mp4', 'http://image.tmdb.org/t/p/w300/bcxUD6pCTvAByIH1YxwuXIb72rk.jpg'),
(13229, 844, 'The Walking Dead S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/201417.mp4', 'http://image.tmdb.org/t/p/w300/slxrzIPXGs1cmgJRcVT1GUUGESz.jpg'),
(13230, 844, 'The Walking Dead S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/201418.mp4', 'http://gstaticontent.com/images/reKs8y4mPwPkZG99ZpbKRhBPKsX_big.jpg'),
(13231, 844, 'The Walking Dead S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/201419.mp4', 'http://gstaticontent.com/images/reKs8y4mPwPkZG99ZpbKRhBPKsX_big.jpg'),
(13232, 844, 'The Walking Dead S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/201420.mp4', 'http://gstaticontent.com/images/reKs8y4mPwPkZG99ZpbKRhBPKsX_big.jpg'),
(13233, 844, 'The Walking Dead S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/201421.mp4', 'http://gstaticontent.com/images/reKs8y4mPwPkZG99ZpbKRhBPKsX_big.jpg'),
(13234, 844, 'The Walking Dead S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/201422.mp4', 'http://gstaticontent.com/images/reKs8y4mPwPkZG99ZpbKRhBPKsX_big.jpg'),
(13235, 844, 'The Walking Dead S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/201423.mp4', 'http://gstaticontent.com/images/reKs8y4mPwPkZG99ZpbKRhBPKsX_big.jpg'),
(13236, 845, 'The Walking Dead S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201424.mp4', 'http://timg.bdta.pro/images/d83371f8464504f737f091035e570fd2.jpg'),
(13237, 845, 'The Walking Dead S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201425.mp4', 'http://timg.bdta.pro/images/df536188153ff33916e3d10a6fa5c628.jpg'),
(13238, 845, 'The Walking Dead S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201426.mp4', 'http://timg.bdta.pro/images/2599d6cc1266148bff97795cd5fdd3b1.jpg'),
(13239, 845, 'The Walking Dead S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201427.mp4', 'http://timg.bdta.pro/images/e500c4405622049df9e401304c33e780.jpg'),
(13240, 845, 'The Walking Dead S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201428.mp4', 'http://timg.bdta.pro/images/c681e688f2effc4c346057d8fca7531d.jpg'),
(13241, 845, 'The Walking Dead S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201429.mp4', 'http://image.tmdb.org/t/p/w1280/qxCFJGyhiuWRiT9uDC3tbJEAh0.jpg'),
(13242, 845, 'The Walking Dead S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201430.mp4', 'http://image.tmdb.org/t/p/w1280/nBBWiVkRfGlLE1MBinkvorKwDj5.jpg'),
(13243, 845, 'The Walking Dead S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201431.mp4', 'http://image.tmdb.org/t/p/w1280/xWTsERiIUjl0TPTcXxgnsCKdw4O.jpg'),
(13244, 845, 'The Walking Dead S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201432.mp4', 'http://timg.bdta.pro/images/280bfa67fafd1e8ee25a19ae69589398.jpg'),
(13245, 845, 'The Walking Dead S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201433.mp4', 'http://timg.bdta.pro/images/816beea23d39a80971a1873e32b494c0.jpg'),
(13246, 845, 'The Walking Dead S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201434.mp4', 'http://timg.bdta.pro/images/9fa80ba28386336445ab9d55123dc30d.jpg'),
(13247, 845, 'The Walking Dead S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201435.mp4', 'http://timg.bdta.pro/images/aff5970f326a7f1a3c158b1a5d6a8895.jpg'),
(13248, 845, 'The Walking Dead S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201436.mp4', 'http://timg.bdta.pro/images/23adeeed4ab7aabe7ee58629b02c2811.jpg'),
(13249, 845, 'The Walking Dead S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/201437.mp4', 'http://timg.bdta.pro/images/b9f3919167cb15db33a28cf2eba97d69.jpg'),
(13250, 845, 'The Walking Dead S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/201438.mp4', 'http://timg.bdta.pro/images/e45d914c97c09504ec70398506d55930.jpg'),
(13251, 845, 'The Walking Dead S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/201439.mp4', 'http://timg.bdta.pro/images/18f81c086fc60f55c98cd6f157a4f724.jpg'),
(13252, 845, 'The Walking Dead S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/201440.mp4', 'http://timg.bdta.pro/images/d5ce5be766b2c4929ae5c093ff4142ec.jpg'),
(13253, 845, 'The Walking Dead S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/201441.mp4', 'http://timg.bdta.pro/images/04a00d1a9e317eec3912b095c9c1ca7e.jpg'),
(13254, 845, 'The Walking Dead S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/201442.mp4', 'http://timg.bdta.pro/images/6b7731345f0d547a49a5b6cfa8adff19.jpg'),
(13255, 845, 'The Walking Dead S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/201443.mp4', 'http://timg.bdta.pro/images/2b186524ee27d455e98649d2fcc8bc2d.jpg'),
(13256, 845, 'The Walking Dead S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/201444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ei1hF5nGXAvW4LiMarRIOibfE52.jpg'),
(13257, 845, 'The Walking Dead S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/201445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aU9BqBuqKiO0rT9FlWJ9uaGZwko.jpg'),
(13258, 845, 'The Walking Dead S11 E23', 'http://sinalprivado.info:80/series/1533784/1533784/201446.mp4', 'http://image.tmdb.org/t/p/w1280/xD0sBthEdZJSI9PzTKDhrxx3nmP.jpg'),
(13259, 845, 'The Walking Dead S11 E24', 'http://sinalprivado.info:80/series/1533784/1533784/201447.mp4', 'http://image.tmdb.org/t/p/w1280/7TTGntkqcOse4kDekAd5RCGKGrR.jpg'),
(13260, 846, 'This Is US S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189988.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13261, 846, 'This Is US S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189989.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13262, 846, 'This Is US S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189990.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13263, 846, 'This Is US S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189991.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13264, 846, 'This Is US S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189992.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13265, 846, 'This Is US S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189993.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13266, 846, 'This Is US S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189994.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13267, 846, 'This Is US S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189995.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13268, 846, 'This Is US S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/189996.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13269, 846, 'This Is US S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/189997.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13270, 846, 'This Is US S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/189998.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13271, 846, 'This Is US S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/189999.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13272, 846, 'This Is US S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190000.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13273, 846, 'This Is US S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190001.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13274, 846, 'This Is US S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190002.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13275, 846, 'This Is US S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190003.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13276, 846, 'This Is US S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190004.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13277, 846, 'This Is US S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190005.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13278, 847, 'This Is US S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190006.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13279, 847, 'This Is US S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190007.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13280, 847, 'This Is US S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190008.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13281, 847, 'This Is US S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190009.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13282, 847, 'This Is US S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190010.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13283, 847, 'This Is US S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190011.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13284, 847, 'This Is US S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190012.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13285, 847, 'This Is US S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190013.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13286, 847, 'This Is US S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190014.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13287, 847, 'This Is US S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190015.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13288, 847, 'This Is US S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190016.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13289, 847, 'This Is US S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190017.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13290, 847, 'This Is US S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190018.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13291, 847, 'This Is US S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190019.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13292, 847, 'This Is US S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190020.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13293, 847, 'This Is US S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190021.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13294, 847, 'This Is US S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190022.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13295, 847, 'This Is US S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190023.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13296, 848, 'This Is US S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190024.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13297, 848, 'This Is US S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190025.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13298, 848, 'This Is US S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190026.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13299, 848, 'This Is US S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190027.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13300, 848, 'This Is US S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190028.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13301, 848, 'This Is US S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190029.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13302, 848, 'This Is US S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190030.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13303, 848, 'This Is US S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190031.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13304, 848, 'This Is US S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190032.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13305, 848, 'This Is US S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190033.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13306, 848, 'This Is US S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190034.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13307, 848, 'This Is US S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190035.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13308, 848, 'This Is US S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190036.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13309, 848, 'This Is US S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190037.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13310, 848, 'This Is US S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190038.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13311, 848, 'This Is US S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190039.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13312, 848, 'This Is US S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190040.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13313, 848, 'This Is US S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190041.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13314, 849, 'This Is US S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190042.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13315, 849, 'This Is US S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190043.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13316, 849, 'This Is US S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190044.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13317, 849, 'This Is US S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190045.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13318, 849, 'This Is US S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190046.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13319, 849, 'This Is US S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190047.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13320, 849, 'This Is US S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190048.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13321, 849, 'This Is US S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190049.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13322, 849, 'This Is US S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190050.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13323, 849, 'This Is US S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190051.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13324, 849, 'This Is US S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190052.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13325, 849, 'This Is US S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190053.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13326, 849, 'This Is US S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190054.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13327, 849, 'This Is US S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190055.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13328, 849, 'This Is US S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190056.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13329, 849, 'This Is US S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190057.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13330, 849, 'This Is US S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190058.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13331, 849, 'This Is US S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190059.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13332, 850, 'This Is US S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190060.mp4', 'http://timg.bdta.pro/images/0085b16bd06dfb16263194a9f734714e.jpg'),
(13333, 850, 'This Is US S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190061.mp4', 'http://gstaticontent.com/images/9oYpkVSbjX8TXifdAW0a5ek8XsW_big.jpg'),
(13334, 850, 'This Is US S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190062.mp4', 'http://timg.bdta.pro/images/1deb790eaafe157f4e230886d273d828.jpg'),
(13335, 850, 'This Is US S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190063.mp4', 'http://timg.bdta.pro/images/ece561480036f532f80e472a81d80d40.jpg'),
(13336, 850, 'This Is US S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190064.mp4', 'http://timg.bdta.pro/images/4bba4a40aaa89f0fd64758f9285aa65f.jpg'),
(13337, 850, 'This Is US S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190065.mp4', 'http://timg.bdta.pro/images/acd0ae175fa20db3d0bcdc76c51ec256.jpg'),
(13338, 850, 'This Is US S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190066.mp4', 'http://timg.bdta.pro/images/c7dfa1befb10fd228be19bf365a5752e.jpg'),
(13339, 850, 'This Is US S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190067.mp4', 'http://timg.bdta.pro/images/cf51cb11382595075fdc40ae60a4ab45.jpg'),
(13340, 850, 'This Is US S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190068.mp4', 'http://timg.bdta.pro/images/1c43a21f18f22e54026f38d66c30dbeb.jpg'),
(13341, 850, 'This Is US S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190069.mp4', 'http://timg.bdta.pro/images/a13256bfce1eb16388dd93d788f51b06.jpg'),
(13342, 850, 'This Is US S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190070.mp4', 'http://timg.bdta.pro/images/c4de45d655ee6123a3e4d5c9e3f607da.jpg'),
(13343, 850, 'This Is US S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190071.mp4', 'http://timg.bdta.pro/images/b39febaf151d2def627170d63b8c87df.jpg'),
(13344, 850, 'This Is US S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190072.mp4', 'http://timg.bdta.pro/images/2d30ee426f52d04109e71d52ecace37b.jpg'),
(13345, 850, 'This Is US S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190073.mp4', 'http://timg.bdta.pro/images/c68dbfeee7a1afb6a16dea0850cf2c2c.jpg'),
(13346, 850, 'This Is US S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190074.mp4', 'http://timg.bdta.pro/images/ca1e0121e356c2905d0d7302e2835644.jpg'),
(13347, 850, 'This Is US S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190075.mp4', 'http://timg.bdta.pro/images/458abe0906f671dbb93ba78fc06a23f8.jpg'),
(13348, 851, 'This Is US S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190076.mp4', 'http://timg.bdta.pro/images/04793988df796001153f91f0362745b9.jpg'),
(13349, 851, 'This Is US S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190077.mp4', 'http://timg.bdta.pro/images/fdb291f731da4737e2c98b5776b9b97b.jpg'),
(13350, 851, 'This Is US S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190078.mp4', 'http://timg.bdta.pro/images/750340df7aeaf28fe9a06731636de8b1.jpg'),
(13351, 851, 'This Is US S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190079.mp4', 'http://timg.bdta.pro/images/cb5abc5fa25afeec9ef5f193695f91c6.jpg'),
(13352, 851, 'This Is US S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190080.mp4', 'http://timg.bdta.pro/images/0c3a5da323a4a78ecf2a1ebb2f15e867.jpg'),
(13353, 851, 'This Is US S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190081.mp4', 'http://timg.bdta.pro/images/9de9a75dfbf9a6515e94a5c6d39986ae.jpg'),
(13354, 851, 'This Is US S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190082.mp4', 'http://timg.bdta.pro/images/340e9db30c89021880b0d6ea502531a4.jpg'),
(13355, 851, 'This Is US S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190083.mp4', 'http://timg.bdta.pro/images/42a1aaab15f9f832516ff8b78feb8a84.jpg'),
(13356, 851, 'This Is US S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190084.mp4', 'http://timg.bdta.pro/images/340f8f4315d66b2ec4a273cee3383518.jpg'),
(13357, 851, 'This Is US S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190085.mp4', 'http://timg.bdta.pro/images/e79073d8f576353481ccf1fdb6e8764a.jpg'),
(13358, 851, 'This Is US S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190086.mp4', 'http://timg.bdta.pro/images/904ab9a8961bb4ed01f988004e1cde1a.jpg'),
(13359, 851, 'This Is US S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190087.mp4', 'http://timg.bdta.pro/images/ff30ab1ee4c898aa470083548d003d42.jpg'),
(13360, 851, 'This Is US S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190088.mp4', 'http://timg.bdta.pro/images/10896531deaf26c7cab7b62532a0ca92.jpg'),
(13361, 851, 'This Is US S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190089.mp4', 'http://timg.bdta.pro/images/ccda6720f13c6515c7dd354b87cbb5a0.jpg'),
(13362, 851, 'This Is US S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190090.mp4', 'http://timg.bdta.pro/images/ee8a4a78a1865f394b853fe697adeebc.jpg'),
(13363, 851, 'This Is US S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190091.mp4', 'http://timg.bdta.pro/images/2dbf61cc91eb3dd353826fe940444eb2.jpg'),
(13364, 851, 'This Is US S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190092.mp4', 'http://timg.bdta.pro/images/31b40a36afd947b1f73afb2dcf28d743.jpg'),
(13365, 851, 'This Is US S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190093.mp4', 'http://timg.bdta.pro/images/a999a0360a86cc69782bee834a098e71.jpg'),
(13366, 852, 'Tidelands S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102617.mp4', 'http://gstaticontent.com/images/tGVQa6Fym1wGkoM5o6LYFTlk6jx_big.jpg'),
(13367, 852, 'Tidelands S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102618.mp4', 'http://gstaticontent.com/images/tGVQa6Fym1wGkoM5o6LYFTlk6jx_big.jpg'),
(13368, 852, 'Tidelands S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102619.mp4', 'http://gstaticontent.com/images/tGVQa6Fym1wGkoM5o6LYFTlk6jx_big.jpg'),
(13369, 852, 'Tidelands S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102620.mp4', 'http://gstaticontent.com/images/tGVQa6Fym1wGkoM5o6LYFTlk6jx_big.jpg'),
(13370, 852, 'Tidelands S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102621.mp4', 'http://gstaticontent.com/images/tGVQa6Fym1wGkoM5o6LYFTlk6jx_big.jpg'),
(13371, 852, 'Tidelands S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102622.mp4', 'http://gstaticontent.com/images/tGVQa6Fym1wGkoM5o6LYFTlk6jx_big.jpg'),
(13372, 852, 'Tidelands S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102623.mp4', 'http://gstaticontent.com/images/tGVQa6Fym1wGkoM5o6LYFTlk6jx_big.jpg'),
(13373, 852, 'Tidelands S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102624.mp4', 'http://gstaticontent.com/images/tGVQa6Fym1wGkoM5o6LYFTlk6jx_big.jpg'),
(13374, 853, 'Timão e Pumba S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SeT1SqFWPquGd36rF29TqF6lAG.jpg'),
(13375, 853, 'Timão e Pumba S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SeT1SqFWPquGd36rF29TqF6lAG.jpg'),
(13376, 853, 'Timão e Pumba S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SeT1SqFWPquGd36rF29TqF6lAG.jpg'),
(13377, 853, 'Timão e Pumba S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SeT1SqFWPquGd36rF29TqF6lAG.jpg'),
(13378, 853, 'Timão e Pumba S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SeT1SqFWPquGd36rF29TqF6lAG.jpg'),
(13379, 853, 'Timão e Pumba S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SeT1SqFWPquGd36rF29TqF6lAG.jpg'),
(13380, 853, 'Timão e Pumba S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SeT1SqFWPquGd36rF29TqF6lAG.jpg'),
(13381, 853, 'Timão e Pumba S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SeT1SqFWPquGd36rF29TqF6lAG.jpg'),
(13382, 853, 'Timão e Pumba S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SeT1SqFWPquGd36rF29TqF6lAG.jpg'),
(13383, 853, 'Timão e Pumba S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SeT1SqFWPquGd36rF29TqF6lAG.jpg'),
(13384, 853, 'Timão e Pumba S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SeT1SqFWPquGd36rF29TqF6lAG.jpg'),
(13385, 853, 'Timão e Pumba S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SeT1SqFWPquGd36rF29TqF6lAG.jpg'),
(13386, 853, 'Timão e Pumba S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SeT1SqFWPquGd36rF29TqF6lAG.jpg'),
(13387, 853, 'Timão e Pumba S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/102638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SeT1SqFWPquGd36rF29TqF6lAG.jpg'),
(13388, 853, 'Timão e Pumba S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/102639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SeT1SqFWPquGd36rF29TqF6lAG.jpg'),
(13389, 853, 'Timão e Pumba S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/102640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SeT1SqFWPquGd36rF29TqF6lAG.jpg'),
(13390, 853, 'Timão e Pumba S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/102641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SeT1SqFWPquGd36rF29TqF6lAG.jpg'),
(13391, 853, 'Timão e Pumba S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/102642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SeT1SqFWPquGd36rF29TqF6lAG.jpg'),
(13392, 853, 'Timão e Pumba S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/102643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SeT1SqFWPquGd36rF29TqF6lAG.jpg'),
(13393, 854, 'Titãs S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g6RUjZRd9PnmXQljLjsLLfuT6bP.jpg'),
(13394, 854, 'Titãs S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g6RUjZRd9PnmXQljLjsLLfuT6bP.jpg'),
(13395, 854, 'Titãs S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g6RUjZRd9PnmXQljLjsLLfuT6bP.jpg'),
(13396, 854, 'Titãs S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g6RUjZRd9PnmXQljLjsLLfuT6bP.jpg'),
(13397, 854, 'Titãs S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g6RUjZRd9PnmXQljLjsLLfuT6bP.jpg'),
(13398, 854, 'Titãs S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g6RUjZRd9PnmXQljLjsLLfuT6bP.jpg'),
(13399, 854, 'Titãs S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g6RUjZRd9PnmXQljLjsLLfuT6bP.jpg'),
(13400, 854, 'Titãs S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g6RUjZRd9PnmXQljLjsLLfuT6bP.jpg'),
(13401, 854, 'Titãs S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g6RUjZRd9PnmXQljLjsLLfuT6bP.jpg'),
(13402, 854, 'Titãs S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g6RUjZRd9PnmXQljLjsLLfuT6bP.jpg'),
(13403, 854, 'Titãs S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g6RUjZRd9PnmXQljLjsLLfuT6bP.jpg'),
(13404, 855, 'Titãs S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219994.mp4', 'http://timg.bdta.pro/images/b332089ee48b436f45b6d0edc1944451.jpg'),
(13405, 855, 'Titãs S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219995.mp4', 'http://timg.bdta.pro/images/c91facac20add1981170d8a0b34e0da8.jpg'),
(13406, 855, 'Titãs S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219996.mp4', 'http://timg.bdta.pro/images/0aa816e1d34fac86ed8e8242895349b3.jpg'),
(13407, 855, 'Titãs S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219997.mp4', 'http://timg.bdta.pro/images/13641fe41d4a4f1c8f42332f9a7e87af.jpg'),
(13408, 855, 'Titãs S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219998.mp4', 'http://timg.bdta.pro/images/0970939e59396a8de701bb3d771dcf84.jpg'),
(13409, 855, 'Titãs S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219999.mp4', 'http://timg.bdta.pro/images/a84ecc1f548be54bc708d7d5c2055e1d.jpg'),
(13410, 855, 'Titãs S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220000.mp4', 'http://timg.bdta.pro/images/1401367700a5c3925eed6ae99f9cb0da.jpg'),
(13411, 855, 'Titãs S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220001.mp4', 'http://timg.bdta.pro/images/92a214c1c0cc8226aae21561c3dc76d2.jpg'),
(13412, 855, 'Titãs S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220002.mp4', 'http://timg.bdta.pro/images/2108256c2bf9943191dd7cacd090ffce.jpg'),
(13413, 855, 'Titãs S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220003.mp4', 'http://timg.bdta.pro/images/96885baf28ddc111adf3f72ea32a2bac.jpg'),
(13414, 855, 'Titãs S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220004.mp4', 'http://timg.bdta.pro/images/144da83fa572b664ee22940c47618f54.jpg'),
(13415, 855, 'Titãs S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220005.mp4', 'http://timg.bdta.pro/images/0f7819659b5fec99d9dc6d3a3507c3a4.jpg'),
(13416, 855, 'Titãs S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220006.mp4', 'http://timg.bdta.pro/images/ad30247692176fc10013b218213e0df7.jpg'),
(13417, 856, 'Titãs S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3PtYggHFgNNnFZhTG0Pq9YlFfA5.jpg'),
(13418, 856, 'Titãs S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/woNeSXWXjje8WtI1jQ2pcwCYEXB.jpg'),
(13419, 856, 'Titãs S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gNVfwsSvnlx7UloUxkQc8sbTEE4.jpg'),
(13420, 856, 'Titãs S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3zH31AMTg026NEpSxp24mOM3WVN.jpg'),
(13421, 856, 'Titãs S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3cqvKlwN5KrBsmb5ScZYsrSUScL.jpg'),
(13422, 856, 'Titãs S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6mi4lwYuKWBmy3Ie0Xp5YOd2dv8.jpg'),
(13423, 856, 'Titãs S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ksSC8WDP5XdPCSlk6DhOKCq51bG.jpg'),
(13424, 856, 'Titãs S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y4eDX7DplCdizsZabQPScY5l99l.jpg'),
(13425, 856, 'Titãs S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/przAvtalNUXfSt93ga81ESPziEO.jpg'),
(13426, 856, 'Titãs S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oZ1ydFV1bFgWYIlLLLh0mqhPwN3.jpg'),
(13427, 856, 'Titãs S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhCJYLLgJC3QBzdJvt2ZXYhouIL.jpg'),
(13428, 856, 'Titãs S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yldz6JaZ9r2ihpVrXBzOJ2XohqP.jpg'),
(13429, 856, 'Titãs S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/avsljnvFXBEGRXvSAmq3m10tNWF.jpg'),
(13430, 857, 'Titãs S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1HuE6I5pBpwsPf4Nyw4wWvcTSh7.jpg'),
(13431, 857, 'Titãs S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqwWoG5vgwfAUrTkYaryr3HU5qk.jpg'),
(13432, 857, 'Titãs S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZ14GzeVXxcO0YOL2sgGfUHNfR6.jpg'),
(13433, 857, 'Titãs S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgddaq7KFmvwtjS0ruDlYjAmFTA.jpg'),
(13434, 857, 'Titãs S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5uyxgFwuC7LsKB9rlXjBWFYDBFT.jpg'),
(13435, 857, 'Titãs S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eXQe3C8bFomg7TAi2gUX3q6HGlU.jpg'),
(13436, 857, 'Titãs S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/upj00haJnfvCKg9ULeYuYITk5kb.jpg'),
(13437, 857, 'Titãs S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/psPWJiMkXqw99QpZZEpYlgIkK6.jpg'),
(13438, 857, 'Titãs S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2pgKxoRWhAsKmygSMM5rOe96gqW.jpg'),
(13439, 857, 'Titãs S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ujZbnR4idWpp1vQb3gN8QDEMcYr.jpg'),
(13440, 857, 'Titãs S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sQs8UeWOE0APYLJZHX1rYIO6Eb9.jpg'),
(13441, 857, 'Titãs S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gemmjF3GYI8c66bSGjI6zSCFSiX.jpg'),
(13442, 858, 'Todo Mundo Odeia o Chris S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13443, 858, 'Todo Mundo Odeia o Chris S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13444, 858, 'Todo Mundo Odeia o Chris S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13445, 858, 'Todo Mundo Odeia o Chris S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13446, 858, 'Todo Mundo Odeia o Chris S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13447, 858, 'Todo Mundo Odeia o Chris S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13448, 858, 'Todo Mundo Odeia o Chris S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13449, 858, 'Todo Mundo Odeia o Chris S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13450, 858, 'Todo Mundo Odeia o Chris S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13451, 858, 'Todo Mundo Odeia o Chris S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13452, 858, 'Todo Mundo Odeia o Chris S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13453, 858, 'Todo Mundo Odeia o Chris S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13454, 858, 'Todo Mundo Odeia o Chris S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13455, 858, 'Todo Mundo Odeia o Chris S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/102657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13456, 858, 'Todo Mundo Odeia o Chris S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/102658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13457, 858, 'Todo Mundo Odeia o Chris S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/102659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13458, 858, 'Todo Mundo Odeia o Chris S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/102660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13459, 858, 'Todo Mundo Odeia o Chris S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/102661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13460, 858, 'Todo Mundo Odeia o Chris S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/102662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13461, 858, 'Todo Mundo Odeia o Chris S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/102663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13462, 858, 'Todo Mundo Odeia o Chris S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/102664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13463, 858, 'Todo Mundo Odeia o Chris S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/102665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13464, 859, 'Todo Mundo Odeia o Chris S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13465, 859, 'Todo Mundo Odeia o Chris S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13466, 859, 'Todo Mundo Odeia o Chris S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13467, 859, 'Todo Mundo Odeia o Chris S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13468, 859, 'Todo Mundo Odeia o Chris S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13469, 859, 'Todo Mundo Odeia o Chris S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13470, 859, 'Todo Mundo Odeia o Chris S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13471, 859, 'Todo Mundo Odeia o Chris S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13472, 859, 'Todo Mundo Odeia o Chris S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13473, 859, 'Todo Mundo Odeia o Chris S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13474, 859, 'Todo Mundo Odeia o Chris S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13475, 859, 'Todo Mundo Odeia o Chris S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13476, 859, 'Todo Mundo Odeia o Chris S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13477, 859, 'Todo Mundo Odeia o Chris S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/102679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13478, 859, 'Todo Mundo Odeia o Chris S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/102680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13479, 859, 'Todo Mundo Odeia o Chris S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/102681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13480, 859, 'Todo Mundo Odeia o Chris S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/102682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13481, 859, 'Todo Mundo Odeia o Chris S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/102683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13482, 859, 'Todo Mundo Odeia o Chris S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/102684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13483, 859, 'Todo Mundo Odeia o Chris S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/102685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13484, 859, 'Todo Mundo Odeia o Chris S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/102686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13485, 859, 'Todo Mundo Odeia o Chris S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/102687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13486, 860, 'Todo Mundo Odeia o Chris S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13487, 860, 'Todo Mundo Odeia o Chris S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13488, 860, 'Todo Mundo Odeia o Chris S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13489, 860, 'Todo Mundo Odeia o Chris S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13490, 860, 'Todo Mundo Odeia o Chris S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13491, 860, 'Todo Mundo Odeia o Chris S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13492, 860, 'Todo Mundo Odeia o Chris S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13493, 860, 'Todo Mundo Odeia o Chris S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(13494, 860, 'Todo Mundo Odeia o Chris S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13495, 860, 'Todo Mundo Odeia o Chris S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13496, 860, 'Todo Mundo Odeia o Chris S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13497, 860, 'Todo Mundo Odeia o Chris S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13498, 860, 'Todo Mundo Odeia o Chris S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13499, 860, 'Todo Mundo Odeia o Chris S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/102701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13500, 860, 'Todo Mundo Odeia o Chris S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/102702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13501, 860, 'Todo Mundo Odeia o Chris S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/102703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13502, 860, 'Todo Mundo Odeia o Chris S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/102704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13503, 860, 'Todo Mundo Odeia o Chris S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/102705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13504, 860, 'Todo Mundo Odeia o Chris S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/102706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13505, 860, 'Todo Mundo Odeia o Chris S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/102707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13506, 860, 'Todo Mundo Odeia o Chris S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/102708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13507, 860, 'Todo Mundo Odeia o Chris S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/102709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13508, 861, 'Todo Mundo Odeia o Chris S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13509, 861, 'Todo Mundo Odeia o Chris S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13510, 861, 'Todo Mundo Odeia o Chris S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13511, 861, 'Todo Mundo Odeia o Chris S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13512, 861, 'Todo Mundo Odeia o Chris S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13513, 861, 'Todo Mundo Odeia o Chris S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13514, 861, 'Todo Mundo Odeia o Chris S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13515, 861, 'Todo Mundo Odeia o Chris S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13516, 861, 'Todo Mundo Odeia o Chris S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13517, 861, 'Todo Mundo Odeia o Chris S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13518, 861, 'Todo Mundo Odeia o Chris S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13519, 861, 'Todo Mundo Odeia o Chris S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13520, 861, 'Todo Mundo Odeia o Chris S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13521, 861, 'Todo Mundo Odeia o Chris S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/102723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13522, 861, 'Todo Mundo Odeia o Chris S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/102724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13523, 861, 'Todo Mundo Odeia o Chris S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/102725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13524, 861, 'Todo Mundo Odeia o Chris S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/102726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13525, 861, 'Todo Mundo Odeia o Chris S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/102727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13526, 861, 'Todo Mundo Odeia o Chris S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/102728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13527, 861, 'Todo Mundo Odeia o Chris S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/102729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13528, 861, 'Todo Mundo Odeia o Chris S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/102730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13529, 861, 'Todo Mundo Odeia o Chris S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/102731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nYfvhUtbqMGtd5iV9sj2fdEFN5p.jpg'),
(13530, 862, 'Troia: A Queda de Uma Cidade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7RPWQw4YfKQHFwnJXi7ZdfoE5vZ.jpg'),
(13531, 862, 'Troia: A Queda de Uma Cidade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7RPWQw4YfKQHFwnJXi7ZdfoE5vZ.jpg'),
(13532, 862, 'Troia: A Queda de Uma Cidade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7RPWQw4YfKQHFwnJXi7ZdfoE5vZ.jpg'),
(13533, 862, 'Troia: A Queda de Uma Cidade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7RPWQw4YfKQHFwnJXi7ZdfoE5vZ.jpg'),
(13534, 862, 'Troia: A Queda de Uma Cidade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7RPWQw4YfKQHFwnJXi7ZdfoE5vZ.jpg'),
(13535, 862, 'Troia: A Queda de Uma Cidade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7RPWQw4YfKQHFwnJXi7ZdfoE5vZ.jpg'),
(13536, 862, 'Troia: A Queda de Uma Cidade S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7RPWQw4YfKQHFwnJXi7ZdfoE5vZ.jpg'),
(13537, 862, 'Troia: A Queda de Uma Cidade S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7RPWQw4YfKQHFwnJXi7ZdfoE5vZ.jpg'),
(13538, 863, 'True Blood S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13539, 863, 'True Blood S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13540, 863, 'True Blood S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13541, 863, 'True Blood S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13542, 863, 'True Blood S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13543, 863, 'True Blood S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13544, 863, 'True Blood S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13545, 863, 'True Blood S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13546, 863, 'True Blood S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13547, 863, 'True Blood S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13548, 863, 'True Blood S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13549, 863, 'True Blood S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13550, 864, 'True Blood S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13551, 864, 'True Blood S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13552, 864, 'True Blood S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13553, 864, 'True Blood S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13554, 864, 'True Blood S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13555, 864, 'True Blood S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13556, 864, 'True Blood S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13557, 864, 'True Blood S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13558, 864, 'True Blood S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13559, 864, 'True Blood S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13560, 864, 'True Blood S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13561, 864, 'True Blood S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13562, 865, 'True Blood S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13563, 865, 'True Blood S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13564, 865, 'True Blood S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13565, 865, 'True Blood S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13566, 865, 'True Blood S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13567, 865, 'True Blood S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13568, 865, 'True Blood S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13569, 865, 'True Blood S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13570, 865, 'True Blood S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13571, 865, 'True Blood S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13572, 865, 'True Blood S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13573, 865, 'True Blood S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13574, 866, 'True Blood S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13575, 866, 'True Blood S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13576, 866, 'True Blood S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13577, 866, 'True Blood S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13578, 866, 'True Blood S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13579, 866, 'True Blood S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13580, 866, 'True Blood S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13581, 866, 'True Blood S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13582, 866, 'True Blood S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13583, 866, 'True Blood S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13584, 866, 'True Blood S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13585, 866, 'True Blood S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13586, 867, 'True Blood S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13587, 867, 'True Blood S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13588, 867, 'True Blood S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13589, 867, 'True Blood S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13590, 867, 'True Blood S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13591, 867, 'True Blood S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13592, 867, 'True Blood S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13593, 867, 'True Blood S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13594, 867, 'True Blood S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13595, 867, 'True Blood S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13596, 867, 'True Blood S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13597, 867, 'True Blood S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13598, 868, 'True Blood S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13599, 868, 'True Blood S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13600, 868, 'True Blood S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13601, 868, 'True Blood S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13602, 868, 'True Blood S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13603, 868, 'True Blood S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13604, 868, 'True Blood S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13605, 868, 'True Blood S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13606, 868, 'True Blood S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13607, 868, 'True Blood S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13608, 869, 'True Blood S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13609, 869, 'True Blood S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13610, 869, 'True Blood S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13611, 869, 'True Blood S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13612, 869, 'True Blood S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13613, 869, 'True Blood S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13614, 869, 'True Blood S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13615, 869, 'True Blood S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13616, 869, 'True Blood S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13617, 869, 'True Blood S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37KATZAbNWAZ34yQHWxuoX8rjII.jpg'),
(13618, 870, 'Tyrant S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140231.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13619, 870, 'Tyrant S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140232.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13620, 870, 'Tyrant S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140233.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13621, 870, 'Tyrant S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140234.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13622, 870, 'Tyrant S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140235.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13623, 870, 'Tyrant S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140236.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13624, 870, 'Tyrant S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140237.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13625, 870, 'Tyrant S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140238.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13626, 870, 'Tyrant S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140239.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13627, 870, 'Tyrant S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140240.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13628, 871, 'Tyrant S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140241.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13629, 871, 'Tyrant S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140242.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13630, 871, 'Tyrant S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140243.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13631, 871, 'Tyrant S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140244.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13632, 871, 'Tyrant S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140245.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13633, 871, 'Tyrant S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140246.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13634, 871, 'Tyrant S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140247.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13635, 871, 'Tyrant S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140248.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13636, 871, 'Tyrant S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140249.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13637, 871, 'Tyrant S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140250.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13638, 871, 'Tyrant S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140251.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13639, 871, 'Tyrant S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140252.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13640, 872, 'Tyrant S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140253.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13641, 872, 'Tyrant S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140254.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13642, 872, 'Tyrant S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140255.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13643, 872, 'Tyrant S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140256.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13644, 872, 'Tyrant S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140257.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13645, 872, 'Tyrant S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140258.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13646, 872, 'Tyrant S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140259.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13647, 872, 'Tyrant S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140260.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13648, 872, 'Tyrant S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140261.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13649, 872, 'Tyrant S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140262.mp4', 'http://gstaticontent.com/images/1kBp9QhaFHfgK3URibIqI7a3QU2_big.jpg'),
(13650, 873, 'Uma Noite De Crime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176043.mp4', 'http://gstaticontent.com/images/6cvhDZ5kk2fjDApl9aNaf0AiZlV_big.jpg'),
(13651, 873, 'Uma Noite De Crime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176044.mp4', 'http://gstaticontent.com/images/6cvhDZ5kk2fjDApl9aNaf0AiZlV_big.jpg'),
(13652, 873, 'Uma Noite De Crime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176045.mp4', 'http://gstaticontent.com/images/6cvhDZ5kk2fjDApl9aNaf0AiZlV_big.jpg'),
(13653, 873, 'Uma Noite De Crime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176046.mp4', 'http://gstaticontent.com/images/6cvhDZ5kk2fjDApl9aNaf0AiZlV_big.jpg'),
(13654, 873, 'Uma Noite De Crime S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176047.mp4', 'http://gstaticontent.com/images/6cvhDZ5kk2fjDApl9aNaf0AiZlV_big.jpg'),
(13655, 873, 'Uma Noite De Crime S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176048.mp4', 'http://gstaticontent.com/images/6cvhDZ5kk2fjDApl9aNaf0AiZlV_big.jpg'),
(13656, 873, 'Uma Noite De Crime S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176049.mp4', 'http://gstaticontent.com/images/6cvhDZ5kk2fjDApl9aNaf0AiZlV_big.jpg'),
(13657, 873, 'Uma Noite De Crime S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176050.mp4', 'http://gstaticontent.com/images/6cvhDZ5kk2fjDApl9aNaf0AiZlV_big.jpg'),
(13658, 873, 'Uma Noite De Crime S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176051.mp4', 'http://gstaticontent.com/images/6cvhDZ5kk2fjDApl9aNaf0AiZlV_big.jpg'),
(13659, 873, 'Uma Noite De Crime S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176052.mp4', 'http://gstaticontent.com/images/6cvhDZ5kk2fjDApl9aNaf0AiZlV_big.jpg'),
(13660, 874, 'Uma Noite De Crime S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176053.mp4', 'http://timg.bdta.pro/images/81d2773390c60c4d4706e914d5b6b0dc.jpg'),
(13661, 874, 'Uma Noite De Crime S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176054.mp4', 'http://timg.bdta.pro/images/0e244a4ed5a343a026d2f26c5052b4d5.jpg'),
(13662, 874, 'Uma Noite De Crime S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176055.mp4', 'http://timg.bdta.pro/images/a605e191bf3068095640d68a1d442f18.jpg'),
(13663, 874, 'Uma Noite De Crime S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176056.mp4', 'http://timg.bdta.pro/images/af5767baa80da03bf3a205c39ddae819.jpg'),
(13664, 874, 'Uma Noite De Crime S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176057.mp4', 'http://timg.bdta.pro/images/a7420ae5b40dcce7c3a51835e49845a5.jpg'),
(13665, 874, 'Uma Noite De Crime S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176058.mp4', 'http://timg.bdta.pro/images/9156e95a45cb40f9447db5b626683fcd.jpg'),
(13666, 874, 'Uma Noite De Crime S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176059.mp4', 'http://timg.bdta.pro/images/ecb3d584e0518ac4e601be198127b51f.jpg'),
(13667, 874, 'Uma Noite De Crime S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176060.mp4', 'http://timg.bdta.pro/images/7d2271a4ee631e4c079f50712db2de68.jpg'),
(13668, 874, 'Uma Noite De Crime S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176061.mp4', 'http://timg.bdta.pro/images/33c988b4fc3887e665c3a04117b2130c.jpg'),
(13669, 874, 'Uma Noite De Crime S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176062.mp4', 'http://timg.bdta.pro/images/97e1951cfc023a9ec287c07c59fc2cb4.jpg'),
(13670, 875, 'Unsolved S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWV5jwbQcPsQpLJnzB71gVIp9na.jpg'),
(13671, 875, 'Unsolved S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWV5jwbQcPsQpLJnzB71gVIp9na.jpg'),
(13672, 875, 'Unsolved S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWV5jwbQcPsQpLJnzB71gVIp9na.jpg'),
(13673, 875, 'Unsolved S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWV5jwbQcPsQpLJnzB71gVIp9na.jpg'),
(13674, 875, 'Unsolved S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWV5jwbQcPsQpLJnzB71gVIp9na.jpg'),
(13675, 875, 'Unsolved S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWV5jwbQcPsQpLJnzB71gVIp9na.jpg'),
(13676, 875, 'Unsolved S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWV5jwbQcPsQpLJnzB71gVIp9na.jpg'),
(13677, 875, 'Unsolved S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWV5jwbQcPsQpLJnzB71gVIp9na.jpg'),
(13678, 875, 'Unsolved S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWV5jwbQcPsQpLJnzB71gVIp9na.jpg'),
(13679, 875, 'Unsolved S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWV5jwbQcPsQpLJnzB71gVIp9na.jpg'),
(13680, 876, 'Van Helsing S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151663.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13681, 876, 'Van Helsing S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151664.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13682, 876, 'Van Helsing S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151665.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13683, 876, 'Van Helsing S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151666.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13684, 876, 'Van Helsing S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151667.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13685, 876, 'Van Helsing S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151668.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13686, 876, 'Van Helsing S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151669.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13687, 876, 'Van Helsing S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151670.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13688, 876, 'Van Helsing S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151671.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13689, 876, 'Van Helsing S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151672.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13690, 876, 'Van Helsing S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151673.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13691, 876, 'Van Helsing S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151674.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13692, 876, 'Van Helsing S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151675.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13693, 877, 'Van Helsing S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151676.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13694, 877, 'Van Helsing S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151677.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13695, 877, 'Van Helsing S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151678.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13696, 877, 'Van Helsing S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151679.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13697, 877, 'Van Helsing S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151680.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13698, 877, 'Van Helsing S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151681.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13699, 877, 'Van Helsing S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151682.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13700, 877, 'Van Helsing S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151683.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13701, 877, 'Van Helsing S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151684.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13702, 877, 'Van Helsing S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151685.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13703, 877, 'Van Helsing S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151686.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13704, 877, 'Van Helsing S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151687.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13705, 877, 'Van Helsing S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151688.mp4', 'http://gstaticontent.com/images/roBjNoeYeR0ngop7pwQYNUVcsav_big.jpg'),
(13706, 878, 'Van Helsing S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151689.mp4', 'http://timg.bdta.pro/images/da084a31a31b853e037f6e2eef5093ed.jpg'),
(13707, 878, 'Van Helsing S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151690.mp4', 'http://timg.bdta.pro/images/79559a9685f7b3a0df2face8d5debf93.jpg'),
(13708, 878, 'Van Helsing S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151691.mp4', 'http://timg.bdta.pro/images/64826ed24cdae2ce275752cdab206b2a.jpg'),
(13709, 878, 'Van Helsing S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151692.mp4', 'http://timg.bdta.pro/images/61427230e59244d5f40050b16a2e7091.jpg'),
(13710, 878, 'Van Helsing S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151693.mp4', 'http://timg.bdta.pro/images/7508edaa72c5ebde1a328a69889f3717.jpg'),
(13711, 878, 'Van Helsing S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151694.mp4', 'http://timg.bdta.pro/images/e7ef94399bbbd1c12053be84df3b9561.jpg'),
(13712, 878, 'Van Helsing S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151695.mp4', 'http://timg.bdta.pro/images/8aae524c4f9c9ac678157b84e92e9dfb.jpg'),
(13713, 878, 'Van Helsing S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151696.mp4', 'http://timg.bdta.pro/images/7daf24e3659e895874217698b4b8c133.jpg'),
(13714, 878, 'Van Helsing S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151697.mp4', 'http://timg.bdta.pro/images/96efe255c3119b2c22ebfc3fe1bc2e98.jpg'),
(13715, 878, 'Van Helsing S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151698.mp4', 'http://timg.bdta.pro/images/9a6d8d0fd0a71aacc6f33f04cc9f4008.jpg'),
(13716, 878, 'Van Helsing S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151699.mp4', 'http://timg.bdta.pro/images/21358c4c096f5f53e04b177ba4503d9d.jpg'),
(13717, 878, 'Van Helsing S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151700.mp4', 'http://timg.bdta.pro/images/93ae6c94f5d0ae834e07e5d1c98406e7.jpg'),
(13718, 878, 'Van Helsing S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151701.mp4', 'http://timg.bdta.pro/images/8cf698d698dc1ccdb220c27d68446000.jpg'),
(13719, 879, 'Van Helsing S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151702.mp4', 'http://timg.bdta.pro/images/fd336a637db285581317efaca857b5f3.jpg'),
(13720, 879, 'Van Helsing S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151703.mp4', 'http://timg.bdta.pro/images/2132f6b22930902a26005ae3f93d68f3.jpg'),
(13721, 879, 'Van Helsing S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151704.mp4', 'http://timg.bdta.pro/images/f82a42e3438e3d30c51f55bd380a9207.jpg'),
(13722, 879, 'Van Helsing S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151705.mp4', 'http://timg.bdta.pro/images/cf9c3a2077c5e76a428950408a9b09fa.jpg'),
(13723, 879, 'Van Helsing S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151706.mp4', 'http://timg.bdta.pro/images/78d5cc3008c9b2a515a0816fb7e71161.jpg'),
(13724, 879, 'Van Helsing S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151707.mp4', 'http://timg.bdta.pro/images/697c4bef0343537c64ea5e51656596e4.jpg'),
(13725, 879, 'Van Helsing S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151708.mp4', 'http://timg.bdta.pro/images/b4b9ae010dfa98e497f5bff44e0d8ffd.jpg'),
(13726, 879, 'Van Helsing S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151709.mp4', 'http://timg.bdta.pro/images/5e7e48dba671663560f7bb9a5f466d6e.jpg'),
(13727, 879, 'Van Helsing S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151710.mp4', 'http://timg.bdta.pro/images/38907b19eeb61cb0498b383c6cd09c69.jpg'),
(13728, 879, 'Van Helsing S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151711.mp4', 'http://timg.bdta.pro/images/b7dcf4cbe893e0f74eb6b36e5d3e23f1.jpg'),
(13729, 879, 'Van Helsing S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151712.mp4', 'http://timg.bdta.pro/images/af6625d73e18a1fbccb57d3922a01196.jpg'),
(13730, 879, 'Van Helsing S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151713.mp4', 'http://timg.bdta.pro/images/4a386b28684814b1715fae80f2973f6d.jpg'),
(13731, 879, 'Van Helsing S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151714.mp4', 'http://timg.bdta.pro/images/7611b0f691e62d5bd1bfd42f76944885.jpg'),
(13732, 880, 'Van Helsing S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151715.mp4', 'http://timg.bdta.pro/images/3c99e260be8cffe36b7fb165b5f46ebe.jpg'),
(13733, 880, 'Van Helsing S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151716.mp4', 'http://timg.bdta.pro/images/f40467de52537f78ceb29aa0bf36c1f6.jpg'),
(13734, 880, 'Van Helsing S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151717.mp4', 'http://timg.bdta.pro/images/56008a7e452c7c03f29ee9d22576976b.jpg'),
(13735, 880, 'Van Helsing S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151718.mp4', 'http://timg.bdta.pro/images/22ea1951a7b53265f02b230045fb0f25.jpg'),
(13736, 880, 'Van Helsing S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151719.mp4', 'http://timg.bdta.pro/images/3bb19df763ea510625bafa33fe20ebff.jpg'),
(13737, 880, 'Van Helsing S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151720.mp4', 'http://timg.bdta.pro/images/f92efdf039ab3c83aa7936ac2b7495d1.jpg'),
(13738, 880, 'Van Helsing S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151721.mp4', 'http://timg.bdta.pro/images/b554602e9a91f473e5fa6554091afa4b.jpg'),
(13739, 880, 'Van Helsing S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151722.mp4', 'http://timg.bdta.pro/images/a1701ad0a44df29c67afb380e7e84230.jpg'),
(13740, 880, 'Van Helsing S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151723.mp4', 'http://timg.bdta.pro/images/324be6fd968385c712c4e9d9a60a4b20.jpg'),
(13741, 880, 'Van Helsing S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151724.mp4', 'http://timg.bdta.pro/images/95b48c23749a2404e0322e3b9bc36ffd.jpg'),
(13742, 880, 'Van Helsing S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151725.mp4', 'http://timg.bdta.pro/images/a3ed1be84dc0735f04f7ffdce1c028a1.jpg'),
(13743, 880, 'Van Helsing S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151726.mp4', 'http://timg.bdta.pro/images/aca2a7df8a65437a00afbd8f3307fadd.jpg'),
(13744, 880, 'Van Helsing S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151727.mp4', 'http://timg.bdta.pro/images/a0e7a7fa25d9b9b0322adb3d64e01e8d.jpg'),
(13745, 881, 'Vikings S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147435.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13746, 881, 'Vikings S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147436.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13747, 881, 'Vikings S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147437.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13748, 881, 'Vikings S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147438.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13749, 881, 'Vikings S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147439.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13750, 881, 'Vikings S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147440.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13751, 881, 'Vikings S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147441.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13752, 881, 'Vikings S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147442.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13753, 881, 'Vikings S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147443.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13754, 882, 'Vikings S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147444.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13755, 882, 'Vikings S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147445.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13756, 882, 'Vikings S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147446.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13757, 882, 'Vikings S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147447.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13758, 882, 'Vikings S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147448.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13759, 882, 'Vikings S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147449.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13760, 882, 'Vikings S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147450.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13761, 882, 'Vikings S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147451.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13762, 882, 'Vikings S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147452.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13763, 882, 'Vikings S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147453.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13764, 883, 'Vikings S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147454.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13765, 883, 'Vikings S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147455.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13766, 883, 'Vikings S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147456.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13767, 883, 'Vikings S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147457.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13768, 883, 'Vikings S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147458.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13769, 883, 'Vikings S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147459.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13770, 883, 'Vikings S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147460.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13771, 883, 'Vikings S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147461.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13772, 883, 'Vikings S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147462.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13773, 883, 'Vikings S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147463.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(13774, 884, 'Vikings S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147464.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13775, 884, 'Vikings S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147465.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13776, 884, 'Vikings S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147466.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13777, 884, 'Vikings S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147467.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13778, 884, 'Vikings S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147468.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13779, 884, 'Vikings S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147469.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13780, 884, 'Vikings S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147470.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13781, 884, 'Vikings S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147471.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13782, 884, 'Vikings S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147472.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13783, 884, 'Vikings S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147473.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13784, 884, 'Vikings S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147474.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13785, 884, 'Vikings S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147475.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13786, 884, 'Vikings S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147476.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13787, 884, 'Vikings S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147477.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13788, 884, 'Vikings S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147478.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13789, 884, 'Vikings S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147479.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13790, 884, 'Vikings S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/147480.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13791, 884, 'Vikings S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/147481.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13792, 884, 'Vikings S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/147482.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13793, 884, 'Vikings S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/147483.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13794, 885, 'Vikings S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147484.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13795, 885, 'Vikings S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147485.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13796, 885, 'Vikings S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147486.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13797, 885, 'Vikings S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147487.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13798, 885, 'Vikings S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147488.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13799, 885, 'Vikings S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147489.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13800, 885, 'Vikings S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147490.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13801, 885, 'Vikings S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147491.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13802, 885, 'Vikings S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147492.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13803, 885, 'Vikings S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147493.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13804, 885, 'Vikings S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147494.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13805, 885, 'Vikings S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147495.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13806, 885, 'Vikings S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147496.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13807, 885, 'Vikings S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147497.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13808, 885, 'Vikings S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147498.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13809, 885, 'Vikings S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147499.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13810, 885, 'Vikings S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/147500.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13811, 885, 'Vikings S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/147501.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13812, 885, 'Vikings S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/147502.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13813, 885, 'Vikings S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/147503.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13814, 886, 'Vikings S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147504.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13815, 886, 'Vikings S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147505.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13816, 886, 'Vikings S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147506.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13817, 886, 'Vikings S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147507.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13818, 886, 'Vikings S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147508.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13819, 886, 'Vikings S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147509.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13820, 886, 'Vikings S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147510.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13821, 886, 'Vikings S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147511.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13822, 886, 'Vikings S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147512.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13823, 886, 'Vikings S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147513.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13824, 886, 'Vikings S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147514.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13825, 886, 'Vikings S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147515.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13826, 886, 'Vikings S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147516.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13827, 886, 'Vikings S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147517.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13828, 886, 'Vikings S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147518.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13829, 886, 'Vikings S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147519.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13830, 886, 'Vikings S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/147520.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13831, 886, 'Vikings S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/147521.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13832, 886, 'Vikings S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/147522.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13833, 886, 'Vikings S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/147523.mp4', 'http://gstaticontent.com/images/oktTNFM8PzdseiK1X0E0XhB6LvP_big.jpg'),
(13834, 887, 'Westworld S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199403.mp4', 'http://gstaticontent.com/images/qzri6QJvL7lG5Rir98cXwkjWK1y_big.jpg'),
(13835, 887, 'Westworld S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199404.mp4', 'http://gstaticontent.com/images/qzri6QJvL7lG5Rir98cXwkjWK1y_big.jpg'),
(13836, 887, 'Westworld S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199405.mp4', 'http://gstaticontent.com/images/qzri6QJvL7lG5Rir98cXwkjWK1y_big.jpg'),
(13837, 887, 'Westworld S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199406.mp4', 'http://gstaticontent.com/images/qzri6QJvL7lG5Rir98cXwkjWK1y_big.jpg'),
(13838, 887, 'Westworld S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199407.mp4', 'http://gstaticontent.com/images/qzri6QJvL7lG5Rir98cXwkjWK1y_big.jpg'),
(13839, 887, 'Westworld S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199408.mp4', 'http://gstaticontent.com/images/qzri6QJvL7lG5Rir98cXwkjWK1y_big.jpg'),
(13840, 887, 'Westworld S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199409.mp4', 'http://gstaticontent.com/images/qzri6QJvL7lG5Rir98cXwkjWK1y_big.jpg'),
(13841, 887, 'Westworld S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199410.mp4', 'http://gstaticontent.com/images/qzri6QJvL7lG5Rir98cXwkjWK1y_big.jpg'),
(13842, 887, 'Westworld S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199411.mp4', 'http://gstaticontent.com/images/qzri6QJvL7lG5Rir98cXwkjWK1y_big.jpg'),
(13843, 887, 'Westworld S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199412.mp4', 'http://gstaticontent.com/images/qzri6QJvL7lG5Rir98cXwkjWK1y_big.jpg'),
(13844, 888, 'Westworld S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199413.mp4', 'http://timg.bdta.pro/images/834c9b032c66681c07c169814f857032.jpg'),
(13845, 888, 'Westworld S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199414.mp4', 'http://timg.bdta.pro/images/08a559e7e2fdf5814e9191ca891e94a0.jpg'),
(13846, 888, 'Westworld S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199415.mp4', 'http://timg.bdta.pro/images/bf3215cceb74a004d31aab256f944151.jpg'),
(13847, 888, 'Westworld S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199416.mp4', 'http://timg.bdta.pro/images/9659e954c43b1ecb350f4c6b07c15cf6.jpg'),
(13848, 888, 'Westworld S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199417.mp4', 'http://timg.bdta.pro/images/fe6165867abfd7318722606f34757eff.jpg'),
(13849, 888, 'Westworld S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199418.mp4', 'http://timg.bdta.pro/images/cdfb2a5b395af2e145341517bda074eb.jpg'),
(13850, 888, 'Westworld S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199419.mp4', 'http://timg.bdta.pro/images/35014083293c243f8cde54dde8ab73cc.jpg'),
(13851, 888, 'Westworld S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199420.mp4', 'http://timg.bdta.pro/images/767c8a8658eb694eb68e48499009f0d5.jpg'),
(13852, 888, 'Westworld S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199421.mp4', 'http://timg.bdta.pro/images/cb124d5a648ea919eba9bdd63b2eb658.jpg'),
(13853, 888, 'Westworld S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199422.mp4', 'http://timg.bdta.pro/images/a7609e24ffd8c204546f14cfd73f2439.jpg'),
(13854, 889, 'Westworld S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199423.mp4', 'http://timg.bdta.pro/images/f32efd2451ef8209f4ee4183d50ec128.jpg'),
(13855, 889, 'Westworld S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199424.mp4', 'http://timg.bdta.pro/images/b6b005c7aa85974a30cf8d19ba717215.jpg'),
(13856, 889, 'Westworld S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199425.mp4', 'http://timg.bdta.pro/images/4b07d4a29352b518d73c2488f4ef1ac9.jpg'),
(13857, 889, 'Westworld S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199426.mp4', 'http://timg.bdta.pro/images/00dd38b0c8dc17bdcd4a90d17d660151.jpg'),
(13858, 889, 'Westworld S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199427.mp4', 'http://timg.bdta.pro/images/5526d4af0694214018c828eaab1a3703.jpg'),
(13859, 889, 'Westworld S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199428.mp4', 'http://timg.bdta.pro/images/2a191a12bd87ceba06696d8411cd5a23.jpg'),
(13860, 889, 'Westworld S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199429.mp4', 'http://timg.bdta.pro/images/916462422b518f3c52dd213302c31c8c.jpg'),
(13861, 889, 'Westworld S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199430.mp4', 'http://timg.bdta.pro/images/7cf351e6870c00544a4637b80638d9af.jpg'),
(13862, 890, 'Westworld S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199431.mp4', 'http://timg.bdta.pro/images/537f62272ed4e2ccf03fff394fa7949b.jpg'),
(13863, 890, 'Westworld S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199432.mp4', 'http://timg.bdta.pro/images/ac9893f14ec5c2569efde0851875a24f.jpg'),
(13864, 890, 'Westworld S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199433.mp4', 'http://timg.bdta.pro/images/b648d8993e4d8273c51815d3e5dd8fe3.jpg'),
(13865, 890, 'Westworld S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199434.mp4', 'http://timg.bdta.pro/images/5eb6057bb355add741b54b5d06e85754.jpg'),
(13866, 890, 'Westworld S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199435.mp4', 'http://timg.bdta.pro/images/095a1aa786255344a7e975f72cdd8500.jpg'),
(13867, 890, 'Westworld S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199436.mp4', 'http://timg.bdta.pro/images/82d9f379c0f4db7b99f230bd5a4daa25.jpg'),
(13868, 890, 'Westworld S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199437.mp4', 'http://timg.bdta.pro/images/86738158ff8d4e63fec9352b5e385fa4.jpg'),
(13869, 890, 'Westworld S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199438.mp4', 'http://timg.bdta.pro/images/48a80e832d2c932d53bd2d605cebb78e.jpg'),
(13870, 891, 'Você S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivqi64qY0S3ZAimvjlqXLEH7D6W.jpg'),
(13871, 891, 'Você S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivqi64qY0S3ZAimvjlqXLEH7D6W.jpg'),
(13872, 891, 'Você S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivqi64qY0S3ZAimvjlqXLEH7D6W.jpg'),
(13873, 891, 'Você S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivqi64qY0S3ZAimvjlqXLEH7D6W.jpg'),
(13874, 891, 'Você S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivqi64qY0S3ZAimvjlqXLEH7D6W.jpg'),
(13875, 891, 'Você S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivqi64qY0S3ZAimvjlqXLEH7D6W.jpg'),
(13876, 891, 'Você S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivqi64qY0S3ZAimvjlqXLEH7D6W.jpg'),
(13877, 891, 'Você S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivqi64qY0S3ZAimvjlqXLEH7D6W.jpg'),
(13878, 891, 'Você S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivqi64qY0S3ZAimvjlqXLEH7D6W.jpg'),
(13879, 891, 'Você S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivqi64qY0S3ZAimvjlqXLEH7D6W.jpg'),
(13880, 892, 'Você S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212697.mp4', 'http://timg.bdta.pro/images/e67dc4b715a7efa82adf9d956deb885d.jpg'),
(13881, 892, 'Você S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212698.mp4', 'http://timg.bdta.pro/images/75acb1bb17580b8b8b2b8bed1ef3eadd.jpg'),
(13882, 892, 'Você S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212699.mp4', 'http://timg.bdta.pro/images/0cb84987102fedf157a0b7c4de51fe60.jpg'),
(13883, 892, 'Você S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212700.mp4', 'http://timg.bdta.pro/images/b2858d9a927f05a0ba5eb3dbc647955d.jpg'),
(13884, 892, 'Você S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212701.mp4', 'http://timg.bdta.pro/images/dbf0cf498dd072f60c032b2d82b56997.jpg'),
(13885, 892, 'Você S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212702.mp4', 'http://timg.bdta.pro/images/6638f375bc4e3b6772599efcd3c50744.jpg'),
(13886, 892, 'Você S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212703.mp4', 'http://timg.bdta.pro/images/fcc2aaa936ecc4479951cc41563c5144.jpg'),
(13887, 892, 'Você S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212704.mp4', 'http://timg.bdta.pro/images/e27a808403e3ab05daa8c5a5279124ce.jpg'),
(13888, 892, 'Você S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212705.mp4', 'http://timg.bdta.pro/images/0d57863ad5f379ae62cee05d8de91839.jpg'),
(13889, 892, 'Você S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212706.mp4', 'http://timg.bdta.pro/images/940c50bed4b2330e7cb96c6d83451a59.jpg'),
(13890, 893, 'Você S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4jQrDHArxHo2Kmh55gWlzhm7mpK.jpg'),
(13891, 893, 'Você S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Co5v4HX2tFcvwXMJWJqGM19A7t.jpg'),
(13892, 893, 'Você S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c0zS6SuX9Yv1bOeAqOca1ceHuNr.jpg'),
(13893, 893, 'Você S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5BJ4wNRyQjWYrCjr92kAOhSPFxP.jpg'),
(13894, 893, 'Você S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/19LZNO4kw69O9i6a4gkt9UNl6of.jpg'),
(13895, 893, 'Você S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pqdU1sx5yFwHvUllRYAOQLr4Pdn.jpg'),
(13896, 893, 'Você S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hh5MR4FFNhI8QOm5exubYhNaO2v.jpg'),
(13897, 893, 'Você S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7AVod6ByyfcYZDHbDDlg6X33L4e.jpg'),
(13898, 893, 'Você S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aoTrlzBar5dn9TuLyBcX9FCNyXJ.jpg'),
(13899, 893, 'Você S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6vW2jWed5jzz2GhU1lu8JCKJoJf.jpg'),
(13900, 894, 'Você S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63e82tgnU7MhusDbja3sRqy5n8L.jpg'),
(13901, 894, 'Você S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y3JuEX08Fv38RyuSzDEBxchR5bL.jpg'),
(13902, 894, 'Você S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Qxo7hyaMo5doi3UcIZdX8KUZPF.jpg'),
(13903, 894, 'Você S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qe5Gu0z6pgR4Ax8Nk2Z6rERlQXu.jpg'),
(13904, 894, 'Você S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eZlPx1W9m66XGB7X9pUkfdksqA.jpg'),
(13905, 894, 'Você S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/78jEWlKtBaxu1u7rFJ2Fn8fWBEZ.jpg'),
(13906, 894, 'Você S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o3YYbR4l2bFlYtyWmw5nJZ5dxC3.jpg'),
(13907, 894, 'Você S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4q5jf1XKwzx0YEK7kvnYZQGjnYo.jpg'),
(13908, 894, 'Você S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gfRoSP7zs3SNmnf5XWoNEMga5l6.jpg'),
(13909, 894, 'Você S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8L7ofyA6ae9hTmVNes3udRYwEFO.jpg'),
(13910, 895, 'Você S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/788228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivqi64qY0S3ZAimvjlqXLEH7D6W.jpg'),
(13911, 895, 'Você S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/788229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivqi64qY0S3ZAimvjlqXLEH7D6W.jpg'),
(13912, 895, 'Você S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/788230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivqi64qY0S3ZAimvjlqXLEH7D6W.jpg'),
(13913, 895, 'Você S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/788231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivqi64qY0S3ZAimvjlqXLEH7D6W.jpg'),
(13914, 895, 'Você S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/788232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivqi64qY0S3ZAimvjlqXLEH7D6W.jpg'),
(13915, 895, 'Você S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/788233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivqi64qY0S3ZAimvjlqXLEH7D6W.jpg'),
(13916, 895, 'Você S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/788234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivqi64qY0S3ZAimvjlqXLEH7D6W.jpg'),
(13917, 895, 'Você S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/788235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivqi64qY0S3ZAimvjlqXLEH7D6W.jpg'),
(13918, 895, 'Você S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/788236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivqi64qY0S3ZAimvjlqXLEH7D6W.jpg'),
(13919, 895, 'Você S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/788237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivqi64qY0S3ZAimvjlqXLEH7D6W.jpg'),
(13920, 896, 'Zoo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102750.mp4', 'http://timg.bdta.pro/images/y7DV6v8YcshWXcAdvItx6Sa5GTD_small.jpg'),
(13921, 896, 'Zoo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102751.mp4', 'http://timg.bdta.pro/images/eyC8e7M1XO2G3ZGL7XybJ13vcBp_small.jpg'),
(13922, 896, 'Zoo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102752.mp4', 'http://timg.bdta.pro/images/1bWks1An9XZrtLcEKxWm2oVxYfN_small.jpg'),
(13923, 896, 'Zoo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102753.mp4', 'http://timg.bdta.pro/images/l3FfbwpdAnbluSvXynKjwxxgLvn_small.jpg'),
(13924, 896, 'Zoo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102754.mp4', 'http://timg.bdta.pro/images/zSxuj2bNQMCLBYwLrGBIrcy2r7k_small.jpg'),
(13925, 896, 'Zoo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102755.mp4', 'http://timg.bdta.pro/images/gMl2108Yyc0f2Psz2H877KsuYo4_small.jpg'),
(13926, 896, 'Zoo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102756.mp4', 'http://timg.bdta.pro/images/dnIah2q8qj2UKhedtnNDn3Xo7QD_small.jpg'),
(13927, 896, 'Zoo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102757.mp4', 'http://timg.bdta.pro/images/b5sWVCBTB7zZa0VNglH2Gz2W4Ge_small.jpg'),
(13928, 896, 'Zoo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102758.mp4', 'http://timg.bdta.pro/images/fmqaglY4o9VO65LHurUrCVvTC81_small.jpg'),
(13929, 896, 'Zoo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102759.mp4', 'http://timg.bdta.pro/images/etWd9qEkJcg49lCUGMI9KWN1AW5_small.jpg'),
(13930, 896, 'Zoo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102760.mp4', 'http://timg.bdta.pro/images/iGakwTtrOu3LMTVJJGgxsWZl7Dv_small.jpg'),
(13931, 896, 'Zoo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102761.mp4', 'http://timg.bdta.pro/images/pZIUXuwlBfiAczxWssxZm83rbeu_small.jpg'),
(13932, 896, 'Zoo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102762.mp4', 'http://timg.bdta.pro/images/1gwtaH10ZPBWaRqSeVaC7C7sEJE_small.jpg'),
(13933, 897, 'Zoo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102763.mp4', 'http://timg.bdta.pro/images/rnDWWe8S15JnCs0HL294wTtPRLu_small.jpg'),
(13934, 897, 'Zoo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102764.mp4', 'http://timg.bdta.pro/images/pqJ9sPP3ja6QdMmMs9HlanXa2fe_small.jpg'),
(13935, 897, 'Zoo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102765.mp4', 'http://timg.bdta.pro/images/byNwSbdFlKTK76Kdw3EUDHoi1KH_small.jpg'),
(13936, 897, 'Zoo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102766.mp4', 'http://timg.bdta.pro/images/4ej4xf8n0r4PcAVw0sZpjhUX8I6_small.jpg'),
(13937, 897, 'Zoo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102767.mp4', 'http://timg.bdta.pro/images/dkWKggyjxGe2GJNLYaldOzT5X90_small.jpg'),
(13938, 897, 'Zoo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102768.mp4', 'http://timg.bdta.pro/images/hieXCptRsHUfy5RFpzktQNDrUzl_small.jpg'),
(13939, 897, 'Zoo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102769.mp4', 'http://timg.bdta.pro/images/7JQ9EvCY8JnFO8C6pDtmYWHqItp_small.jpg'),
(13940, 897, 'Zoo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102770.mp4', 'http://timg.bdta.pro/images/u6Tmx2ZUNYbGKhYuVT6imKKEHyn_small.jpg'),
(13941, 897, 'Zoo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102771.mp4', 'http://timg.bdta.pro/images/ztTl25mC1IgSAbtYwRN0chfkbqq_small.jpg'),
(13942, 897, 'Zoo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102772.mp4', 'http://timg.bdta.pro/images/zrAgO23phCMMEaIRRYNwURIcTC3_small.jpg'),
(13943, 897, 'Zoo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102773.mp4', 'http://timg.bdta.pro/images/z1VuRBEqiJuPJEikLdRtTII2rgf_small.jpg'),
(13944, 897, 'Zoo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102774.mp4', 'http://timg.bdta.pro/images/EzoIH29cN01c9jfEg1dbT0H7zq_small.jpg'),
(13945, 898, 'Zoo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102775.mp4', 'http://gstaticontent.com/images/6Fp49zU7FjsJ4xvvZjCZBiBq9KQ_big.jpg'),
(13946, 898, 'Zoo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102776.mp4', 'http://gstaticontent.com/images/6Fp49zU7FjsJ4xvvZjCZBiBq9KQ_big.jpg'),
(13947, 898, 'Zoo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102777.mp4', 'http://gstaticontent.com/images/6Fp49zU7FjsJ4xvvZjCZBiBq9KQ_big.jpg'),
(13948, 898, 'Zoo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102778.mp4', 'http://gstaticontent.com/images/6Fp49zU7FjsJ4xvvZjCZBiBq9KQ_big.jpg'),
(13949, 898, 'Zoo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102779.mp4', 'http://gstaticontent.com/images/6Fp49zU7FjsJ4xvvZjCZBiBq9KQ_big.jpg'),
(13950, 898, 'Zoo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102780.mp4', 'http://gstaticontent.com/images/6Fp49zU7FjsJ4xvvZjCZBiBq9KQ_big.jpg'),
(13951, 898, 'Zoo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102781.mp4', 'http://gstaticontent.com/images/6Fp49zU7FjsJ4xvvZjCZBiBq9KQ_big.jpg'),
(13952, 898, 'Zoo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102782.mp4', 'http://gstaticontent.com/images/6Fp49zU7FjsJ4xvvZjCZBiBq9KQ_big.jpg'),
(13953, 898, 'Zoo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102783.mp4', 'http://gstaticontent.com/images/6Fp49zU7FjsJ4xvvZjCZBiBq9KQ_big.jpg'),
(13954, 898, 'Zoo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102784.mp4', 'http://gstaticontent.com/images/6Fp49zU7FjsJ4xvvZjCZBiBq9KQ_big.jpg'),
(13955, 899, '13 Reasons Why S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113280.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13956, 899, '13 Reasons Why S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113281.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13957, 899, '13 Reasons Why S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113282.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13958, 899, '13 Reasons Why S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113283.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13959, 899, '13 Reasons Why S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113284.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13960, 899, '13 Reasons Why S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113285.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13961, 899, '13 Reasons Why S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113286.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13962, 899, '13 Reasons Why S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113287.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13963, 899, '13 Reasons Why S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113288.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13964, 899, '13 Reasons Why S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113289.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13965, 899, '13 Reasons Why S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113290.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13966, 899, '13 Reasons Why S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113291.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13967, 899, '13 Reasons Why S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113292.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13968, 900, '13 Reasons Why S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113293.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13969, 900, '13 Reasons Why S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113294.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13970, 900, '13 Reasons Why S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113295.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13971, 900, '13 Reasons Why S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113296.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13972, 900, '13 Reasons Why S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113297.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13973, 900, '13 Reasons Why S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113298.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13974, 900, '13 Reasons Why S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113299.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13975, 900, '13 Reasons Why S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113300.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13976, 900, '13 Reasons Why S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113301.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13977, 900, '13 Reasons Why S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113302.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13978, 900, '13 Reasons Why S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113303.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13979, 900, '13 Reasons Why S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113304.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13980, 900, '13 Reasons Why S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113305.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13981, 901, '13 Reasons Why S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113306.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13982, 901, '13 Reasons Why S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113307.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13983, 901, '13 Reasons Why S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113308.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13984, 901, '13 Reasons Why S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113309.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13985, 901, '13 Reasons Why S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113310.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13986, 901, '13 Reasons Why S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113311.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13987, 901, '13 Reasons Why S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113312.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13988, 901, '13 Reasons Why S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113313.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13989, 901, '13 Reasons Why S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113314.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13990, 901, '13 Reasons Why S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113315.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13991, 901, '13 Reasons Why S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113316.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13992, 901, '13 Reasons Why S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113317.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13993, 901, '13 Reasons Why S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113318.mp4', 'http://gstaticontent.com/images/8eUJQK8wRiBvGqiqMKEcYmAnESQ_big.jpg'),
(13994, 902, '13 Reasons Why S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113319.mp4', 'http://timg.bdta.pro/images/7c159e44226aefef2e7763870b924292.jpg'),
(13995, 902, '13 Reasons Why S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113320.mp4', 'http://timg.bdta.pro/images/88b2472aef49c02e065cb1cad0094885.jpg'),
(13996, 902, '13 Reasons Why S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113321.mp4', 'http://timg.bdta.pro/images/bd9d9f127a9b0c68fe05f0a8d1b5938d.jpg'),
(13997, 902, '13 Reasons Why S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113322.mp4', 'http://timg.bdta.pro/images/0c8441437031c5e529c767555a2d1136.jpg'),
(13998, 902, '13 Reasons Why S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113323.mp4', 'http://timg.bdta.pro/images/b554517496b7c70ba683b89e9c8c9909.jpg'),
(13999, 902, '13 Reasons Why S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113324.mp4', 'http://timg.bdta.pro/images/16904f71d60ebebb0f9ed3e95b05d818.jpg'),
(14000, 902, '13 Reasons Why S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113325.mp4', 'http://timg.bdta.pro/images/784bd25adce173f442d40ac0950cfad5.jpg'),
(14001, 902, '13 Reasons Why S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113326.mp4', 'http://timg.bdta.pro/images/a0e572bfe6d4790d7fd58a6b835a1c7e.jpg'),
(14002, 902, '13 Reasons Why S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113327.mp4', 'http://timg.bdta.pro/images/e1f1fe17e32ea28e221aed3468f5a108.jpg'),
(14003, 902, '13 Reasons Why S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113328.mp4', 'http://timg.bdta.pro/images/bb1c917347c0fa3876128581d46e431f.jpg'),
(14004, 903, '1 Contra Todos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/idXR0Gk8bH8gUnsZZI3TMkaw4ea.jpg'),
(14005, 903, '1 Contra Todos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3WuQMlDpkpYhDtO0lkVTeJ5DrRC.jpg'),
(14006, 903, '1 Contra Todos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eXXXws9c0rsqugdjNpY2kOrpIHr.jpg'),
(14007, 903, '1 Contra Todos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ymS6J5ElifSJU28LqoVqtWfX7.jpg'),
(14008, 903, '1 Contra Todos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfcZFcB0KQtNdtF84j4F7S4iZ9M.jpg'),
(14009, 903, '1 Contra Todos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kuO6B9PZbwZ9Jlztcsspv7ZZsw7.jpg'),
(14010, 903, '1 Contra Todos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3UkoJyc229MQUnqJzPS22oQAwgV.jpg'),
(14011, 903, '1 Contra Todos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zk5PhT5AyOEcTGmmz50I7AS0Njx.jpg'),
(14012, 904, '1 Contra Todos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gmF57xiA0lCAAVmWJ3n8cWGhzgA.jpg'),
(14013, 904, '1 Contra Todos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dmQ0jm7jRH56Erikr5g8SD677Gb.jpg'),
(14014, 904, '1 Contra Todos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dGTglGR6mtYgI65Ombp4eNx2MPZ.jpg'),
(14015, 904, '1 Contra Todos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5cKFbJqiZTfv5CK22F1Wj1ElWYP.jpg'),
(14016, 904, '1 Contra Todos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i6l251vALjv5X1J847sK5JKLXWk.jpg'),
(14017, 904, '1 Contra Todos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bb8ElJxr3UujduxpQkeGthgR7vm.jpg'),
(14018, 904, '1 Contra Todos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bm5rOPgzYxDh3Ip4Ct1yKyNO9op.jpg'),
(14019, 904, '1 Contra Todos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tIDXj3kC03npk11RokZ1gKdQ5Xa.jpg'),
(14020, 905, '1 Contra Todos S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iVY1jx7diIWYnWWz2I8B3NFpIGb.jpg'),
(14021, 905, '1 Contra Todos S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ep8nV9vDrfiYubcoESAaxM9orWe.jpg'),
(14022, 905, '1 Contra Todos S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tvLNbhqnkx0WR8Gxlfwum7vFSWv.jpg'),
(14023, 905, '1 Contra Todos S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bJrVAkQO74mRE5XVcYMVA3aqsh9.jpg'),
(14024, 905, '1 Contra Todos S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hgJ2SdKsiQ4O2wKY9z3idtAQKif.jpg'),
(14025, 905, '1 Contra Todos S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p0Q3BYTIDOlJf1ScRYXoSn6dd2M.jpg'),
(14026, 905, '1 Contra Todos S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUJ0fxD9UjNMb6Rz9kOwn4Ut26b.jpg'),
(14027, 905, '1 Contra Todos S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2kBtbpoziXPq8Sgbrdg3tyODDri.jpg'),
(14028, 906, '1 Contra Todos S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3o7f2Xjwl5hcoiioR9eGdD9ezHt.jpg'),
(14029, 906, '1 Contra Todos S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3o7f2Xjwl5hcoiioR9eGdD9ezHt.jpg'),
(14030, 906, '1 Contra Todos S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3o7f2Xjwl5hcoiioR9eGdD9ezHt.jpg'),
(14031, 906, '1 Contra Todos S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3o7f2Xjwl5hcoiioR9eGdD9ezHt.jpg'),
(14032, 906, '1 Contra Todos S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3o7f2Xjwl5hcoiioR9eGdD9ezHt.jpg'),
(14033, 906, '1 Contra Todos S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3o7f2Xjwl5hcoiioR9eGdD9ezHt.jpg'),
(14034, 906, '1 Contra Todos S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3o7f2Xjwl5hcoiioR9eGdD9ezHt.jpg'),
(14035, 906, '1 Contra Todos S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3o7f2Xjwl5hcoiioR9eGdD9ezHt.jpg'),
(14036, 907, '24 Horas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129232.mp4', 'http://timg.bdta.pro/images/03efd9e15b1d61f44efdc48ec882e2f9.jpg'),
(14037, 907, '24 Horas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129233.mp4', 'http://timg.bdta.pro/images/d9e17009ab2e203f9da80158f8a43875.jpg'),
(14038, 907, '24 Horas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129234.mp4', 'http://timg.bdta.pro/images/14530fea6243b23c49f82627fd0a1cbe.jpg'),
(14039, 907, '24 Horas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129235.mp4', 'http://timg.bdta.pro/images/3ba5197d3caa5b8de896e724088fb169.jpg'),
(14040, 907, '24 Horas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129236.mp4', 'http://timg.bdta.pro/images/bc5f3f929cd7dc608904002e5b6999c1.jpg'),
(14041, 907, '24 Horas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129237.mp4', 'http://timg.bdta.pro/images/69f3aa67dfbc94cabf7e1dfffb040448.jpg'),
(14042, 907, '24 Horas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129238.mp4', 'http://timg.bdta.pro/images/2e21abbc3ce8bf0b0692a54065866c39.jpg'),
(14043, 907, '24 Horas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129239.mp4', 'http://timg.bdta.pro/images/f426c05e335572ab98964797bceed32f.jpg'),
(14044, 907, '24 Horas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129240.mp4', 'http://timg.bdta.pro/images/df0212d9fa105efbdf098f7610bcf8f4.jpg'),
(14045, 907, '24 Horas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129241.mp4', 'http://timg.bdta.pro/images/4e89a86bc96cf11aca8600628379fe47.jpg'),
(14046, 907, '24 Horas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129242.mp4', 'http://timg.bdta.pro/images/9d92b7239ade07abfc92b8fd8721aa8b.jpg'),
(14047, 907, '24 Horas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129243.mp4', 'http://timg.bdta.pro/images/3dde24860a6e1b6e76291289e6ade6b6.jpg'),
(14048, 907, '24 Horas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129244.mp4', 'http://timg.bdta.pro/images/2ab5e530f75b9e0e7dba20e47e5013e4.jpg'),
(14049, 907, '24 Horas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129245.mp4', 'http://timg.bdta.pro/images/208407b457049aab6a494c3e49ec6ada.jpg'),
(14050, 907, '24 Horas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129246.mp4', 'http://timg.bdta.pro/images/4b2869e0a4fb778591dc5e97b375aa45.jpg'),
(14051, 907, '24 Horas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129247.mp4', 'http://timg.bdta.pro/images/ea2ee44de3a0f1e521368929db8ae456.jpg'),
(14052, 907, '24 Horas S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129248.mp4', 'http://timg.bdta.pro/images/9d99c0e0ab53b0f43e0c6ec9d9bcc292.jpg'),
(14053, 907, '24 Horas S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129249.mp4', 'http://timg.bdta.pro/images/8b58283116bbbdf706fd0cb999cdac1e.jpg'),
(14054, 907, '24 Horas S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129250.mp4', 'http://timg.bdta.pro/images/1e157beccffe35aec0ce3560575a8531.jpg'),
(14055, 907, '24 Horas S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129251.mp4', 'http://timg.bdta.pro/images/1121d23d29b63deb11e4217151998a69.jpg'),
(14056, 907, '24 Horas S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129252.mp4', 'http://timg.bdta.pro/images/f708c6413c206875bfdada929a9174ed.jpg'),
(14057, 907, '24 Horas S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129253.mp4', 'http://timg.bdta.pro/images/84f7cfb16f9521f15ee205a638793331.jpg'),
(14058, 907, '24 Horas S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/129254.mp4', 'http://timg.bdta.pro/images/506d9da835cca60e50a4c36d2568fdf6.jpg'),
(14059, 907, '24 Horas S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/129255.mp4', 'http://timg.bdta.pro/images/42a5f343c633e9ebb117e1043aa903e0.jpg'),
(14060, 908, '24 Horas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129256.mp4', 'http://timg.bdta.pro/images/ec4fb6ed7a792a32f9a4a4465556400b.jpg'),
(14061, 908, '24 Horas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129257.mp4', 'http://timg.bdta.pro/images/6444cd2e1b1a3d76c2395bccab5c2837.jpg'),
(14062, 908, '24 Horas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129258.mp4', 'http://timg.bdta.pro/images/95569ace37e6cd561d690e48acf22397.jpg'),
(14063, 908, '24 Horas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129259.mp4', 'http://timg.bdta.pro/images/bea238d38570181754167f49e25474f3.jpg'),
(14064, 908, '24 Horas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129260.mp4', 'http://timg.bdta.pro/images/649b8a1ab0adfa5d33f3506c1624cf33.jpg'),
(14065, 908, '24 Horas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129261.mp4', 'http://timg.bdta.pro/images/d0de03bd03521b3011f183ef4de45c09.jpg'),
(14066, 908, '24 Horas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129262.mp4', 'http://timg.bdta.pro/images/1b419970b81dcf9e101255009be9d349.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(14067, 908, '24 Horas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129263.mp4', 'http://timg.bdta.pro/images/93e10e177ffc8b134ccfb75ae224920e.jpg'),
(14068, 908, '24 Horas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129264.mp4', 'http://timg.bdta.pro/images/9fce0a4b9cf1891539552c129a7646a8.jpg'),
(14069, 908, '24 Horas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129265.mp4', 'http://timg.bdta.pro/images/dc26d11bee9faaf85231ad4d44b2711a.jpg'),
(14070, 908, '24 Horas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129266.mp4', 'http://timg.bdta.pro/images/e60f3d30a6c3cc04301dad1815857c4d.jpg'),
(14071, 908, '24 Horas S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129267.mp4', 'http://timg.bdta.pro/images/c2e1bbcf8a9e7c5d674c131a1b3432be.jpg'),
(14072, 908, '24 Horas S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129268.mp4', 'http://timg.bdta.pro/images/03338978b405d416d02580703f5d021f.jpg'),
(14073, 908, '24 Horas S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129269.mp4', 'http://timg.bdta.pro/images/2b7fedc6d6c596329f3f707d3491816f.jpg'),
(14074, 908, '24 Horas S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129270.mp4', 'http://timg.bdta.pro/images/2d7016ba92ace77649922e15da450738.jpg'),
(14075, 908, '24 Horas S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129271.mp4', 'http://timg.bdta.pro/images/0469d434bbffde18f3580593a1d6a71c.jpg'),
(14076, 908, '24 Horas S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129272.mp4', 'http://timg.bdta.pro/images/b458ff416b467b9d4f231574c5ac68fc.jpg'),
(14077, 908, '24 Horas S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129273.mp4', 'http://timg.bdta.pro/images/aba0c772810c5245206c19469279b8b2.jpg'),
(14078, 908, '24 Horas S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129274.mp4', 'http://timg.bdta.pro/images/ed6d36095353e476db01975916985c93.jpg'),
(14079, 908, '24 Horas S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129275.mp4', 'http://timg.bdta.pro/images/2a89387bb49243134bae42dec760b5cc.jpg'),
(14080, 908, '24 Horas S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129276.mp4', 'http://timg.bdta.pro/images/7b8ccf04cf39195d1aaf09361f274fcc.jpg'),
(14081, 908, '24 Horas S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129277.mp4', 'http://timg.bdta.pro/images/1bfd6e73587656796c15218b7b45dafb.jpg'),
(14082, 908, '24 Horas S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/129278.mp4', 'http://timg.bdta.pro/images/67eda7ef749987e78cabc8a854a5fbdc.jpg'),
(14083, 908, '24 Horas S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/129279.mp4', 'http://timg.bdta.pro/images/bcdcc97dd8edafd8a2aba776b97efc87.jpg'),
(14084, 909, '24 Horas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129280.mp4', 'http://timg.bdta.pro/images/03554be40b0125910d296b8e6abf8951.jpg'),
(14085, 909, '24 Horas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129281.mp4', 'http://timg.bdta.pro/images/12bb36e89774b6c50e7a01d6415fd894.jpg'),
(14086, 909, '24 Horas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129282.mp4', 'http://timg.bdta.pro/images/535628ce8876ca921588591b337de1ee.jpg'),
(14087, 909, '24 Horas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129283.mp4', 'http://timg.bdta.pro/images/2ad372ab21d803592726275f91a74d6e.jpg'),
(14088, 909, '24 Horas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129284.mp4', 'http://timg.bdta.pro/images/c4c8b6ddfa08d3199ab1a1326b483704.jpg'),
(14089, 909, '24 Horas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129285.mp4', 'http://timg.bdta.pro/images/ac58c24c312647d9aa69f521d459714e.jpg'),
(14090, 909, '24 Horas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129286.mp4', 'http://timg.bdta.pro/images/c08e60a2c7c7fac819061fba5aafb062.jpg'),
(14091, 909, '24 Horas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129287.mp4', 'http://timg.bdta.pro/images/2e46045ec74755c77949b27548f305a4.jpg'),
(14092, 909, '24 Horas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129288.mp4', 'http://timg.bdta.pro/images/ef4499a25afc6d49db9e953df86ad3c8.jpg'),
(14093, 909, '24 Horas S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129289.mp4', 'http://timg.bdta.pro/images/5c29e59de8f5679cea9478818c7070a6.jpg'),
(14094, 909, '24 Horas S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129290.mp4', 'http://timg.bdta.pro/images/f2bee80d6236fb6e82726f578095456a.jpg'),
(14095, 909, '24 Horas S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129291.mp4', 'http://timg.bdta.pro/images/c099985f31bdab6cc8567e017bd79547.jpg'),
(14096, 909, '24 Horas S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129292.mp4', 'http://timg.bdta.pro/images/76ef054d9db55658067c0a237c98d42f.jpg'),
(14097, 909, '24 Horas S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129293.mp4', 'http://timg.bdta.pro/images/cc9c73985a89324a7b1451e73d14efea.jpg'),
(14098, 909, '24 Horas S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129294.mp4', 'http://timg.bdta.pro/images/572a18b3c2670d6d31ca5de8fdde902e.jpg'),
(14099, 909, '24 Horas S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129295.mp4', 'http://timg.bdta.pro/images/34a651b2db8f7c45f5ea188fe3c9d034.jpg'),
(14100, 909, '24 Horas S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129296.mp4', 'http://timg.bdta.pro/images/85b9f18f13c1da4707422f1d97cab09d.jpg'),
(14101, 909, '24 Horas S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129297.mp4', 'http://timg.bdta.pro/images/3f1db778568f2ecba65a13f3299580f8.jpg'),
(14102, 909, '24 Horas S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129298.mp4', 'http://timg.bdta.pro/images/d6e3c744115db709b3c3e73468a60a90.jpg'),
(14103, 909, '24 Horas S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129299.mp4', 'http://timg.bdta.pro/images/6a96283eed7eaaf9a4b99fac6a9a65f6.jpg'),
(14104, 909, '24 Horas S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129300.mp4', 'http://timg.bdta.pro/images/232f64ff5fa9cd606d5b765cd9a8a946.jpg'),
(14105, 909, '24 Horas S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129301.mp4', 'http://timg.bdta.pro/images/39edf057965856c66af76b4c9e26d5f5.jpg'),
(14106, 909, '24 Horas S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/129302.mp4', 'http://timg.bdta.pro/images/f0c73b455c3f6434b4ef59fc3146e2d1.jpg'),
(14107, 909, '24 Horas S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/129303.mp4', 'http://timg.bdta.pro/images/b570b38fafae346053444b8c42427a0b.jpg'),
(14108, 910, '24 Horas S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129304.mp4', 'http://timg.bdta.pro/images/b8335214f1c5b3017d16692e2b8b7a0e.jpg'),
(14109, 910, '24 Horas S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129305.mp4', 'http://timg.bdta.pro/images/00b4fd900f55f6b34ffa8f007249b683.jpg'),
(14110, 910, '24 Horas S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129306.mp4', 'http://timg.bdta.pro/images/ac094386767c0cfa2a69337b36d7a582.jpg'),
(14111, 910, '24 Horas S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129307.mp4', 'http://timg.bdta.pro/images/cebe8a5718675a2fdcf184d69419fdc2.jpg'),
(14112, 910, '24 Horas S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129308.mp4', 'http://timg.bdta.pro/images/e8640845f1b1080eb8b13a7f7574e44d.jpg'),
(14113, 910, '24 Horas S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129309.mp4', 'http://timg.bdta.pro/images/ec14d9e87687de32c0280842b966c974.jpg'),
(14114, 910, '24 Horas S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129310.mp4', 'http://timg.bdta.pro/images/92011f6768f6dbe15c2b5ac896501b0f.jpg'),
(14115, 910, '24 Horas S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129311.mp4', 'http://timg.bdta.pro/images/7a238756829973947c949cba8e68b856.jpg'),
(14116, 910, '24 Horas S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129312.mp4', 'http://timg.bdta.pro/images/edd3aa30996d10a4afdcc46180f098d3.jpg'),
(14117, 910, '24 Horas S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129313.mp4', 'http://timg.bdta.pro/images/bd9dfc469a5515ab20842c92c7fb92c4.jpg'),
(14118, 910, '24 Horas S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129314.mp4', 'http://timg.bdta.pro/images/39aa4abcdc857597f45c6bc0341c4a7e.jpg'),
(14119, 910, '24 Horas S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129315.mp4', 'http://timg.bdta.pro/images/63f898bfb6b192bc9fc7e3f99c5dd9fc.jpg'),
(14120, 910, '24 Horas S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129316.mp4', 'http://timg.bdta.pro/images/86fe8c66e373da22a74f4ce606273e08.jpg'),
(14121, 910, '24 Horas S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129317.mp4', 'http://timg.bdta.pro/images/eb6824ffe943909a5240465a5f01e67b.jpg'),
(14122, 910, '24 Horas S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129318.mp4', 'http://timg.bdta.pro/images/5c925e8bbff650437120355190945677.jpg'),
(14123, 910, '24 Horas S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129319.mp4', 'http://timg.bdta.pro/images/195bf6a3db03a4db2008a6105f0d27c8.jpg'),
(14124, 910, '24 Horas S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129320.mp4', 'http://timg.bdta.pro/images/5e18902077711d100ae2c4dee212f276.jpg'),
(14125, 910, '24 Horas S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129321.mp4', 'http://timg.bdta.pro/images/157cb67f822e3507c4730319b5128d9a.jpg'),
(14126, 910, '24 Horas S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129322.mp4', 'http://timg.bdta.pro/images/2baa19b3af94d4d3a7605489dd60bab2.jpg'),
(14127, 910, '24 Horas S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129323.mp4', 'http://timg.bdta.pro/images/dc0b869d240b4d64ae34d9103f1dbeb7.jpg'),
(14128, 910, '24 Horas S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129324.mp4', 'http://timg.bdta.pro/images/7082c234c9e5b3517c0a4e9c478669bf.jpg'),
(14129, 910, '24 Horas S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129325.mp4', 'http://timg.bdta.pro/images/e3893c4f62e67dc105fd74929d689744.jpg'),
(14130, 910, '24 Horas S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/129326.mp4', 'http://timg.bdta.pro/images/f2b15c211f4bf76b2c31d045360e1e17.jpg'),
(14131, 910, '24 Horas S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/129327.mp4', 'http://timg.bdta.pro/images/015d0fd5ac2df817ef85711bd6ecf04d.jpg'),
(14132, 911, '24 Horas S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129328.mp4', 'http://timg.bdta.pro/images/08a0e549b33dc558a34393513a013ceb.jpg'),
(14133, 911, '24 Horas S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129329.mp4', 'http://timg.bdta.pro/images/a7c141b17d7b0fcee1991367da75a473.jpg'),
(14134, 911, '24 Horas S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129330.mp4', 'http://timg.bdta.pro/images/03863c0964f8fadc58f3848abf026c75.jpg'),
(14135, 911, '24 Horas S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129331.mp4', 'http://timg.bdta.pro/images/855894ab2affe5de3fe6eb575c8329c0.jpg'),
(14136, 911, '24 Horas S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129332.mp4', 'http://timg.bdta.pro/images/d5f07056c29546f22941275bb47ce8ff.jpg'),
(14137, 911, '24 Horas S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129333.mp4', 'http://timg.bdta.pro/images/696e152c44649ed1453c26a73896aaf7.jpg'),
(14138, 911, '24 Horas S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129334.mp4', 'http://timg.bdta.pro/images/5f1a500f4d73794499848dce66d41391.jpg'),
(14139, 911, '24 Horas S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129335.mp4', 'http://timg.bdta.pro/images/934604ce9156d1755db5e8168ae454ec.jpg'),
(14140, 911, '24 Horas S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129336.mp4', 'http://timg.bdta.pro/images/c56a158aa69b5b0c212567f87d4244bf.jpg'),
(14141, 911, '24 Horas S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129337.mp4', 'http://timg.bdta.pro/images/47c433b8e161005c201f9a38ec97ded6.jpg'),
(14142, 911, '24 Horas S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129338.mp4', 'http://timg.bdta.pro/images/56bc28821877b2c74288ec5c1ea5c6ba.jpg'),
(14143, 911, '24 Horas S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129339.mp4', 'http://timg.bdta.pro/images/f7e2ad06adaff4a4a707f36ba6ce2304.jpg'),
(14144, 911, '24 Horas S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129340.mp4', 'http://timg.bdta.pro/images/5761c2e64bb4a953dbecc26d472ead17.jpg'),
(14145, 911, '24 Horas S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129341.mp4', 'http://timg.bdta.pro/images/90bae5c66ce257e7f914646a21334010.jpg'),
(14146, 911, '24 Horas S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129342.mp4', 'http://timg.bdta.pro/images/eeaed6ec566a51ac2de7e75db4e15116.jpg'),
(14147, 911, '24 Horas S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129343.mp4', 'http://timg.bdta.pro/images/a4e74ece32abdfd77a012937999edf76.jpg'),
(14148, 911, '24 Horas S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129344.mp4', 'http://timg.bdta.pro/images/158dec1c265c2b8900f1ed05df1a2931.jpg'),
(14149, 911, '24 Horas S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129345.mp4', 'http://timg.bdta.pro/images/72c65d90370bdfa70410f9ca3e65ccab.jpg'),
(14150, 911, '24 Horas S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129346.mp4', 'http://timg.bdta.pro/images/da07fbf2614673e6e5512705c2804772.jpg'),
(14151, 911, '24 Horas S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129347.mp4', 'http://timg.bdta.pro/images/1efcd27462a2b8e475ceaa1943751731.jpg'),
(14152, 911, '24 Horas S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129348.mp4', 'http://timg.bdta.pro/images/4095f828f636308d642b7efb637e496a.jpg'),
(14153, 911, '24 Horas S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129349.mp4', 'http://timg.bdta.pro/images/abf0d326f3b036d4bea8d4d2a23f8da7.jpg'),
(14154, 911, '24 Horas S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/129350.mp4', 'http://timg.bdta.pro/images/8a99372a60fdc9e460c754027d94ed04.jpg'),
(14155, 911, '24 Horas S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/129351.mp4', 'http://timg.bdta.pro/images/98ec7bdb5e0394b4d1d40424d7aebff3.jpg'),
(14156, 912, '24 Horas S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129352.mp4', 'http://timg.bdta.pro/images/3bddd28e15915e089d5af94deb8939b3.jpg'),
(14157, 912, '24 Horas S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129353.mp4', 'http://timg.bdta.pro/images/f3c6581ac2fa167a1fc2ac0b1b7ba269.jpg'),
(14158, 912, '24 Horas S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129354.mp4', 'http://timg.bdta.pro/images/2e5c5af45860074e5dc6f4d0699205db.jpg'),
(14159, 912, '24 Horas S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129355.mp4', 'http://timg.bdta.pro/images/a3cf9c8383713908d388da2d02bd8a67.jpg'),
(14160, 912, '24 Horas S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129356.mp4', 'http://timg.bdta.pro/images/bd37f4524537b73ab0dde01b7e1305c0.jpg'),
(14161, 912, '24 Horas S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129357.mp4', 'http://timg.bdta.pro/images/ee955faf72f112ad1103d7256f0be1e4.jpg'),
(14162, 912, '24 Horas S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129358.mp4', 'http://timg.bdta.pro/images/52c183a41800c1d29a82fce06efb1c28.jpg'),
(14163, 912, '24 Horas S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129359.mp4', 'http://timg.bdta.pro/images/c079891e2fe714711f6cadd9967a37be.jpg'),
(14164, 912, '24 Horas S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129360.mp4', 'http://timg.bdta.pro/images/1fd2fb9f0c8c65c64d63583579280b44.jpg'),
(14165, 912, '24 Horas S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129361.mp4', 'http://timg.bdta.pro/images/c691580e8963c19f7299a44275a2eb81.jpg'),
(14166, 912, '24 Horas S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129362.mp4', 'http://timg.bdta.pro/images/fdf869dfd46e42ade787aa2bbb8fa6a2.jpg'),
(14167, 912, '24 Horas S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129363.mp4', 'http://timg.bdta.pro/images/d97f9516aaca8362d2bbc5c7145033e0.jpg'),
(14168, 912, '24 Horas S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129364.mp4', 'http://timg.bdta.pro/images/2baaac8fe5da0774cae8ea263df60c57.jpg'),
(14169, 912, '24 Horas S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129365.mp4', 'http://timg.bdta.pro/images/45b59ec47f5eaebbf292645b1b3fa0d2.jpg'),
(14170, 912, '24 Horas S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129366.mp4', 'http://timg.bdta.pro/images/11e2a8b1cc66ce4b64348e6d22d8d131.jpg'),
(14171, 912, '24 Horas S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129367.mp4', 'http://timg.bdta.pro/images/81c32941444f30232818d8a6c144c56f.jpg'),
(14172, 912, '24 Horas S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129368.mp4', 'http://timg.bdta.pro/images/8d6aef9651f987f5e32eaa4432f66887.jpg'),
(14173, 912, '24 Horas S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129369.mp4', 'http://timg.bdta.pro/images/83f4c2a3537a7ca0f41785cbc2f34d76.jpg'),
(14174, 912, '24 Horas S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129370.mp4', 'http://timg.bdta.pro/images/86dd15043fc13971e724624f40af57da.jpg'),
(14175, 912, '24 Horas S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129371.mp4', 'http://timg.bdta.pro/images/0cd324383f8b47afeee9a33706714df3.jpg'),
(14176, 912, '24 Horas S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129372.mp4', 'http://timg.bdta.pro/images/a98022ed4ba162db13fea3242d59cfb2.jpg'),
(14177, 912, '24 Horas S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129373.mp4', 'http://timg.bdta.pro/images/61b38e64e3061acef6f5b9b5e09833c3.jpg'),
(14178, 912, '24 Horas S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/129374.mp4', 'http://timg.bdta.pro/images/22041c71d3110d9a5a8f2af645f6c813.jpg'),
(14179, 912, '24 Horas S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/129375.mp4', 'http://timg.bdta.pro/images/abbcc5002fe7734aa2762c205188c95d.jpg'),
(14180, 913, '24 Horas S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129376.mp4', 'http://timg.bdta.pro/images/36c8046ef6e95564ac175a9269d6e8df.jpg'),
(14181, 913, '24 Horas S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129377.mp4', 'http://timg.bdta.pro/images/60f3b7b00e9081abc17b15ee5a375dde.jpg'),
(14182, 913, '24 Horas S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129378.mp4', 'http://timg.bdta.pro/images/233bdfea5132d8ce6a25e150ca9b3751.jpg'),
(14183, 913, '24 Horas S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129379.mp4', 'http://timg.bdta.pro/images/de155c6417913efff921556d4c5da709.jpg'),
(14184, 913, '24 Horas S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129380.mp4', 'http://timg.bdta.pro/images/821a9b7a9a46f242bd12e3346a394878.jpg'),
(14185, 913, '24 Horas S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129381.mp4', 'http://timg.bdta.pro/images/02ba4f3c7683b1b92e796204eb989264.jpg'),
(14186, 913, '24 Horas S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129382.mp4', 'http://timg.bdta.pro/images/b6483ac84a1ae7ade1fdf652f378c662.jpg'),
(14187, 913, '24 Horas S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129383.mp4', 'http://timg.bdta.pro/images/87abe060a6d973e5a925d5459372432b.jpg'),
(14188, 913, '24 Horas S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129384.mp4', 'http://timg.bdta.pro/images/8bf8219ed67d7612619b3e0f3084fea1.jpg'),
(14189, 913, '24 Horas S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129385.mp4', 'http://timg.bdta.pro/images/f159575c0b2de198c45c4b63f3e0a5a7.jpg'),
(14190, 913, '24 Horas S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129386.mp4', 'http://timg.bdta.pro/images/d6d46f4f1e634b6fa9a26823206f371d.jpg'),
(14191, 913, '24 Horas S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129387.mp4', 'http://timg.bdta.pro/images/fa920d9fe085e6f2e767809a70824bc1.jpg'),
(14192, 913, '24 Horas S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129388.mp4', 'http://timg.bdta.pro/images/07112f417e829102dc6db1ea4c4a0e08.jpg'),
(14193, 913, '24 Horas S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129389.mp4', 'http://timg.bdta.pro/images/037767488184e478b654bbd9c4642d63.jpg'),
(14194, 913, '24 Horas S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129390.mp4', 'http://timg.bdta.pro/images/0dcfb5f4e6d3e7f2a212aaa7919cbc9f.jpg'),
(14195, 913, '24 Horas S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129391.mp4', 'http://timg.bdta.pro/images/add653eaeb30a2bfccdbc0c8c63b6702.jpg'),
(14196, 913, '24 Horas S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129392.mp4', 'http://timg.bdta.pro/images/d533cbc3c513d8e526893115c64df5a0.jpg'),
(14197, 913, '24 Horas S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129393.mp4', 'http://timg.bdta.pro/images/9384b7ccebd9d450f378d5a6f9248db8.jpg'),
(14198, 913, '24 Horas S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129394.mp4', 'http://timg.bdta.pro/images/cb4acfb5eb9dff217b18f0329b02e1a0.jpg'),
(14199, 913, '24 Horas S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129395.mp4', 'http://timg.bdta.pro/images/544fecae64f1618b72f41cfbc51e3f25.jpg'),
(14200, 913, '24 Horas S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129396.mp4', 'http://timg.bdta.pro/images/3b3100fc6752bd6cfd1700246cd9a8ce.jpg'),
(14201, 913, '24 Horas S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129397.mp4', 'http://timg.bdta.pro/images/6ac08a5c922ced39bc5df363e70f5446.jpg'),
(14202, 913, '24 Horas S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/129398.mp4', 'http://timg.bdta.pro/images/c3116ea8deade6d3076a03c1b7415267.jpg'),
(14203, 913, '24 Horas S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/129399.mp4', 'http://timg.bdta.pro/images/0bed6de0814dd6cb240363f787dc3d44.jpg'),
(14204, 914, '24 Horas S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129400.mp4', 'http://timg.bdta.pro/images/38cbaaad23264985bfa36e10b289c711.jpg'),
(14205, 914, '24 Horas S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129401.mp4', 'http://timg.bdta.pro/images/3383d09aa6a28a50abef1bca154c8c01.jpg'),
(14206, 914, '24 Horas S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129402.mp4', 'http://timg.bdta.pro/images/32f168fecef4d760fcefb2e7140ab73b.jpg'),
(14207, 914, '24 Horas S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129403.mp4', 'http://timg.bdta.pro/images/3238fd3bf8f63d497c8ba6d029e3418d.jpg'),
(14208, 914, '24 Horas S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129404.mp4', 'http://timg.bdta.pro/images/da73c26a3b1158738be2691970a866c0.jpg'),
(14209, 914, '24 Horas S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129405.mp4', 'http://timg.bdta.pro/images/f4225ae507f5c219c55d3b5908c2f2e7.jpg'),
(14210, 914, '24 Horas S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129406.mp4', 'http://timg.bdta.pro/images/11b99f09bd54bd750a17df0795c39e67.jpg'),
(14211, 914, '24 Horas S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129407.mp4', 'http://timg.bdta.pro/images/6f33b8b421ada550c97409ad386506cc.jpg'),
(14212, 914, '24 Horas S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129408.mp4', 'http://timg.bdta.pro/images/cf531ef19cf2e5865c0232decd01cd91.jpg'),
(14213, 914, '24 Horas S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129409.mp4', 'http://timg.bdta.pro/images/20eec62fe9f465112f8951d6e778b7d0.jpg'),
(14214, 914, '24 Horas S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129410.mp4', 'http://timg.bdta.pro/images/b22a818e1514d609e44f539b2bb9e0de.jpg'),
(14215, 914, '24 Horas S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129411.mp4', 'http://timg.bdta.pro/images/f3e94af6a9c0c6c426a0490e4914571a.jpg'),
(14216, 914, '24 Horas S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129412.mp4', 'http://timg.bdta.pro/images/2909e4d76eae55ad83d05b3724a95732.jpg'),
(14217, 914, '24 Horas S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129413.mp4', 'http://timg.bdta.pro/images/90c50cb37acb1b76e23fff55cfa5b73a.jpg'),
(14218, 914, '24 Horas S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129414.mp4', 'http://timg.bdta.pro/images/0a753b8d8007df9787ad742857c4faba.jpg'),
(14219, 914, '24 Horas S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129415.mp4', 'http://timg.bdta.pro/images/b894bac7b9cc783ed1a3d86baa873c4f.jpg'),
(14220, 914, '24 Horas S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129416.mp4', 'http://timg.bdta.pro/images/d46a63fd43254701ed818ae9408ea1db.jpg'),
(14221, 914, '24 Horas S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129417.mp4', 'http://timg.bdta.pro/images/161b38608df15739ca3ec15534578ed5.jpg'),
(14222, 914, '24 Horas S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129418.mp4', 'http://timg.bdta.pro/images/e01bd8da423ac32cf4571fc41e8ac1c7.jpg'),
(14223, 914, '24 Horas S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129419.mp4', 'http://timg.bdta.pro/images/c71a552e49ff3620010c64366bb8333b.jpg'),
(14224, 914, '24 Horas S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129420.mp4', 'http://timg.bdta.pro/images/041b1e58a0d67120e0a298b58fc38678.jpg'),
(14225, 914, '24 Horas S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129421.mp4', 'http://timg.bdta.pro/images/348bc1dc87119600241413d4140199ed.jpg'),
(14226, 914, '24 Horas S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/129422.mp4', 'http://timg.bdta.pro/images/3e9c085bb60f51005c6d5bdca82449d7.jpg'),
(14227, 914, '24 Horas S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/129423.mp4', 'http://timg.bdta.pro/images/d8a99068a7288ee8f19281e8d3ca0c59.jpg'),
(14228, 915, '24 Horas S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129424.mp4', 'http://timg.bdta.pro/images/aba92e192656266b3baa843b98035144.jpg'),
(14229, 915, '24 Horas S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129425.mp4', 'http://timg.bdta.pro/images/d76f3b66c67f86844d09fa78b2ca13e9.jpg'),
(14230, 915, '24 Horas S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129426.mp4', 'http://timg.bdta.pro/images/a4d0f4a5694c13023eead1197a0fe8b8.jpg'),
(14231, 915, '24 Horas S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129427.mp4', 'http://timg.bdta.pro/images/e736d9c6a9ac3fb4e7437b8d3c4329bf.jpg'),
(14232, 915, '24 Horas S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129428.mp4', 'http://timg.bdta.pro/images/df0a21a3a028cf714807b5538f4f55b2.jpg'),
(14233, 915, '24 Horas S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129429.mp4', 'http://timg.bdta.pro/images/55fc049e3f7ed26d10b35b90f9020cca.jpg'),
(14234, 915, '24 Horas S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129430.mp4', 'http://timg.bdta.pro/images/1549c98a04336b6736876a324065b419.jpg'),
(14235, 915, '24 Horas S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129431.mp4', 'http://timg.bdta.pro/images/e1bb423437ea8ec8327204d78f518378.jpg'),
(14236, 915, '24 Horas S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129432.mp4', 'http://timg.bdta.pro/images/ec306b411b64b32654f1fa386c6af4e8.jpg'),
(14237, 915, '24 Horas S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129433.mp4', 'http://timg.bdta.pro/images/478b9d54e2a267778763fcb5afca5c32.jpg'),
(14238, 915, '24 Horas S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129434.mp4', 'http://timg.bdta.pro/images/7e1c512720063b334d998954b1a5df13.jpg'),
(14239, 915, '24 Horas S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129435.mp4', 'http://timg.bdta.pro/images/462a930e654259fd285c34b2f5900640.jpg'),
(14240, 916, '2 Garotas em Apuros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175712.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14241, 916, '2 Garotas em Apuros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175713.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14242, 916, '2 Garotas em Apuros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175714.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14243, 916, '2 Garotas em Apuros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175715.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14244, 916, '2 Garotas em Apuros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175716.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14245, 916, '2 Garotas em Apuros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175717.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14246, 916, '2 Garotas em Apuros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175718.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14247, 916, '2 Garotas em Apuros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175719.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14248, 916, '2 Garotas em Apuros S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/175720.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14249, 916, '2 Garotas em Apuros S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/175721.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14250, 916, '2 Garotas em Apuros S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/175722.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14251, 916, '2 Garotas em Apuros S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/175723.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14252, 916, '2 Garotas em Apuros S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/175724.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14253, 916, '2 Garotas em Apuros S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/175725.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14254, 916, '2 Garotas em Apuros S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/175726.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14255, 916, '2 Garotas em Apuros S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/175727.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14256, 916, '2 Garotas em Apuros S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/175728.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14257, 916, '2 Garotas em Apuros S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/175729.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14258, 916, '2 Garotas em Apuros S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/175730.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14259, 916, '2 Garotas em Apuros S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/175731.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14260, 916, '2 Garotas em Apuros S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/175732.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14261, 916, '2 Garotas em Apuros S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/175733.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14262, 916, '2 Garotas em Apuros S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/175734.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14263, 916, '2 Garotas em Apuros S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/175735.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14264, 917, '2 Garotas em Apuros S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175736.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14265, 917, '2 Garotas em Apuros S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175737.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14266, 917, '2 Garotas em Apuros S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175738.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14267, 917, '2 Garotas em Apuros S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175739.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14268, 917, '2 Garotas em Apuros S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175740.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14269, 917, '2 Garotas em Apuros S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175741.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14270, 917, '2 Garotas em Apuros S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175742.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14271, 917, '2 Garotas em Apuros S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175743.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14272, 917, '2 Garotas em Apuros S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/175744.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14273, 917, '2 Garotas em Apuros S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/175745.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14274, 917, '2 Garotas em Apuros S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/175746.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14275, 917, '2 Garotas em Apuros S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/175747.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14276, 917, '2 Garotas em Apuros S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/175748.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14277, 917, '2 Garotas em Apuros S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/175749.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14278, 917, '2 Garotas em Apuros S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/175750.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14279, 917, '2 Garotas em Apuros S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/175751.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14280, 917, '2 Garotas em Apuros S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/175752.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14281, 917, '2 Garotas em Apuros S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/175753.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14282, 917, '2 Garotas em Apuros S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/175754.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14283, 917, '2 Garotas em Apuros S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/175755.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14284, 917, '2 Garotas em Apuros S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/175756.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14285, 917, '2 Garotas em Apuros S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/175757.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14286, 917, '2 Garotas em Apuros S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/175758.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14287, 917, '2 Garotas em Apuros S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/175759.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14288, 918, '2 Garotas em Apuros S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175760.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14289, 918, '2 Garotas em Apuros S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175761.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14290, 918, '2 Garotas em Apuros S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175762.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14291, 918, '2 Garotas em Apuros S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175763.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14292, 918, '2 Garotas em Apuros S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175764.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14293, 918, '2 Garotas em Apuros S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175765.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14294, 918, '2 Garotas em Apuros S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175766.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14295, 918, '2 Garotas em Apuros S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175767.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14296, 918, '2 Garotas em Apuros S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/175768.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14297, 918, '2 Garotas em Apuros S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/175769.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14298, 918, '2 Garotas em Apuros S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/175770.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14299, 918, '2 Garotas em Apuros S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/175771.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14300, 918, '2 Garotas em Apuros S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/175772.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14301, 918, '2 Garotas em Apuros S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/175773.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14302, 918, '2 Garotas em Apuros S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/175774.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14303, 918, '2 Garotas em Apuros S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/175775.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14304, 918, '2 Garotas em Apuros S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/175776.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14305, 918, '2 Garotas em Apuros S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/175777.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14306, 918, '2 Garotas em Apuros S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/175778.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14307, 918, '2 Garotas em Apuros S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/175779.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14308, 918, '2 Garotas em Apuros S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/175780.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14309, 918, '2 Garotas em Apuros S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/175781.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14310, 918, '2 Garotas em Apuros S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/175782.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14311, 918, '2 Garotas em Apuros S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/175783.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14312, 919, '2 Garotas em Apuros S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175784.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14313, 919, '2 Garotas em Apuros S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175785.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14314, 919, '2 Garotas em Apuros S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175786.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14315, 919, '2 Garotas em Apuros S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175787.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14316, 919, '2 Garotas em Apuros S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175788.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14317, 919, '2 Garotas em Apuros S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175789.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14318, 919, '2 Garotas em Apuros S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175790.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14319, 919, '2 Garotas em Apuros S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175791.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14320, 919, '2 Garotas em Apuros S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/175792.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14321, 919, '2 Garotas em Apuros S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/175793.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14322, 919, '2 Garotas em Apuros S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/175794.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14323, 919, '2 Garotas em Apuros S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/175795.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14324, 919, '2 Garotas em Apuros S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/175796.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14325, 919, '2 Garotas em Apuros S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/175797.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14326, 919, '2 Garotas em Apuros S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/175798.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14327, 919, '2 Garotas em Apuros S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/175799.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14328, 919, '2 Garotas em Apuros S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/175800.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14329, 919, '2 Garotas em Apuros S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/175801.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14330, 919, '2 Garotas em Apuros S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/175802.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14331, 919, '2 Garotas em Apuros S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/175803.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14332, 919, '2 Garotas em Apuros S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/175804.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14333, 919, '2 Garotas em Apuros S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/175805.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14334, 920, '2 Garotas em Apuros S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175806.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14335, 920, '2 Garotas em Apuros S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175807.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14336, 920, '2 Garotas em Apuros S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175808.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14337, 920, '2 Garotas em Apuros S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175809.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14338, 920, '2 Garotas em Apuros S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175810.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14339, 920, '2 Garotas em Apuros S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175811.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14340, 920, '2 Garotas em Apuros S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175812.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14341, 920, '2 Garotas em Apuros S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175813.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14342, 920, '2 Garotas em Apuros S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/175814.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14343, 920, '2 Garotas em Apuros S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/175815.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14344, 920, '2 Garotas em Apuros S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/175816.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14345, 920, '2 Garotas em Apuros S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/175817.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14346, 920, '2 Garotas em Apuros S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/175818.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14347, 920, '2 Garotas em Apuros S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/175819.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14348, 920, '2 Garotas em Apuros S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/175820.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14349, 920, '2 Garotas em Apuros S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/175821.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14350, 920, '2 Garotas em Apuros S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/175822.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14351, 920, '2 Garotas em Apuros S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/175823.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14352, 920, '2 Garotas em Apuros S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/175824.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14353, 920, '2 Garotas em Apuros S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/175825.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14354, 920, '2 Garotas em Apuros S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/175826.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14355, 920, '2 Garotas em Apuros S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/175827.mp4', 'http://gstaticontent.com/images/35eeda0c4d4bb9e9ce1bffde0dbf8567.jpg'),
(14356, 921, '2 Garotas em Apuros S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175828.mp4', 'http://timg.bdta.pro/images/0491c147a0390110936cf2627095060d.jpg'),
(14357, 921, '2 Garotas em Apuros S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175829.mp4', 'http://timg.bdta.pro/images/a804e35f7586147f23290c333cd37466.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(14358, 921, '2 Garotas em Apuros S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175830.mp4', 'http://timg.bdta.pro/images/f501c105e36458cb5e7d2ed17f40322f.jpg'),
(14359, 921, '2 Garotas em Apuros S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175831.mp4', 'http://timg.bdta.pro/images/831a2001a0f0558bef063d010ce2cf65.jpg'),
(14360, 921, '2 Garotas em Apuros S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175832.mp4', 'http://timg.bdta.pro/images/b881fef59d1dae2918dd0f47a2db3ab0.jpg'),
(14361, 921, '2 Garotas em Apuros S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175833.mp4', 'http://timg.bdta.pro/images/7e8bf78b66162f53a819c506668c9bdb.jpg'),
(14362, 921, '2 Garotas em Apuros S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175834.mp4', 'http://timg.bdta.pro/images/ffa2d368e1a78a4efbadd5b7dcb62879.jpg'),
(14363, 921, '2 Garotas em Apuros S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175835.mp4', 'http://timg.bdta.pro/images/e324f75b16a17e8d5ec1bff0aeeb4ca2.jpg'),
(14364, 921, '2 Garotas em Apuros S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/175836.mp4', 'http://timg.bdta.pro/images/d21c5bb4645645e6d4d47c83ff76b3b1.jpg'),
(14365, 921, '2 Garotas em Apuros S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/175837.mp4', 'http://timg.bdta.pro/images/c198600c1726481d5b87f383a1066133.jpg'),
(14366, 921, '2 Garotas em Apuros S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/175838.mp4', 'http://timg.bdta.pro/images/d81eb48b3193340400bced6a520c0690.jpg'),
(14367, 921, '2 Garotas em Apuros S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/175839.mp4', 'http://timg.bdta.pro/images/e99c17d74356c356e62a473d1fec9142.jpg'),
(14368, 921, '2 Garotas em Apuros S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/175840.mp4', 'http://timg.bdta.pro/images/cb2deb6cfbd7afc0ae66dd13a0942d4d.jpg'),
(14369, 921, '2 Garotas em Apuros S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/175841.mp4', 'http://timg.bdta.pro/images/21f1830053dec875c0f6683dfffeb025.jpg'),
(14370, 921, '2 Garotas em Apuros S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/175842.mp4', 'http://timg.bdta.pro/images/e1484c05cef32cfdd9918d6b2bbd7f74.jpg'),
(14371, 921, '2 Garotas em Apuros S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/175843.mp4', 'http://timg.bdta.pro/images/ca6b7e7f874dd268828b5b87b53b71b0.jpg'),
(14372, 921, '2 Garotas em Apuros S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/175844.mp4', 'http://timg.bdta.pro/images/c0b1bfc13de4f4a65b3c0e2c7fd827b2.jpg'),
(14373, 921, '2 Garotas em Apuros S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/175845.mp4', 'http://timg.bdta.pro/images/9eec8f0008ea269cf03aa5d40fde87b1.jpg'),
(14374, 921, '2 Garotas em Apuros S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/175846.mp4', 'http://timg.bdta.pro/images/d965fa67e5e2c279b5a97f250357c3a0.jpg'),
(14375, 921, '2 Garotas em Apuros S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/175847.mp4', 'http://timg.bdta.pro/images/0139ec2002708a9cb567f92a7c7a0dcb.jpg'),
(14376, 921, '2 Garotas em Apuros S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/175848.mp4', 'http://timg.bdta.pro/images/9025fb7ea536065f8498e8553da312b7.jpg'),
(14377, 921, '2 Garotas em Apuros S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/175849.mp4', 'http://timg.bdta.pro/images/f9bd6bada589f1d9edc07e5dcb3f9851.jpg'),
(14378, 922, '12 Monkeys S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195960.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14379, 922, '12 Monkeys S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195961.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14380, 922, '12 Monkeys S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195962.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14381, 922, '12 Monkeys S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195963.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14382, 922, '12 Monkeys S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195964.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14383, 922, '12 Monkeys S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195965.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14384, 922, '12 Monkeys S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195966.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14385, 922, '12 Monkeys S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195967.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14386, 922, '12 Monkeys S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195968.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14387, 922, '12 Monkeys S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195969.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14388, 922, '12 Monkeys S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/195970.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14389, 922, '12 Monkeys S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/195971.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14390, 922, '12 Monkeys S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/195972.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14391, 923, '12 Monkeys S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195973.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14392, 923, '12 Monkeys S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195974.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14393, 923, '12 Monkeys S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195975.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14394, 923, '12 Monkeys S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195976.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14395, 923, '12 Monkeys S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195977.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14396, 923, '12 Monkeys S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195978.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14397, 923, '12 Monkeys S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195979.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14398, 923, '12 Monkeys S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195980.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14399, 923, '12 Monkeys S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195981.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14400, 923, '12 Monkeys S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195982.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14401, 923, '12 Monkeys S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/195983.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14402, 923, '12 Monkeys S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/195984.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14403, 923, '12 Monkeys S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/195985.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14404, 924, '12 Monkeys S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195986.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14405, 924, '12 Monkeys S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195987.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14406, 924, '12 Monkeys S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195988.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14407, 924, '12 Monkeys S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195989.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14408, 924, '12 Monkeys S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195990.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14409, 924, '12 Monkeys S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195991.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14410, 924, '12 Monkeys S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195992.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14411, 924, '12 Monkeys S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195993.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14412, 924, '12 Monkeys S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195994.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14413, 924, '12 Monkeys S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195995.mp4', 'http://gstaticontent.com/images/lnLlxi9GcPNyLcmvt6uVipI73m5_big.jpg'),
(14414, 925, '12 Monkeys S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195996.mp4', 'http://timg.bdta.pro/images/4931b8e9766f4cdc30fdc350041c2f32.jpg'),
(14415, 925, '12 Monkeys S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195997.mp4', 'http://timg.bdta.pro/images/ec209229faa5c75fa08b788661bfc43f.jpg'),
(14416, 925, '12 Monkeys S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195998.mp4', 'http://timg.bdta.pro/images/366aefc17f3a23941fedffb1afd9607e.jpg'),
(14417, 925, '12 Monkeys S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195999.mp4', 'http://timg.bdta.pro/images/6f9883184a82e4a10920360694d4fe89.jpg'),
(14418, 925, '12 Monkeys S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196000.mp4', 'http://timg.bdta.pro/images/1359b5078f23232784e50c88a9d182af.jpg'),
(14419, 925, '12 Monkeys S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196001.mp4', 'http://timg.bdta.pro/images/e60146fbaadd275a8b11e2ea37c1baff.jpg'),
(14420, 925, '12 Monkeys S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196002.mp4', 'http://timg.bdta.pro/images/04fada401fd3ae6a28144284ccfc5c93.jpg'),
(14421, 925, '12 Monkeys S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196003.mp4', 'http://timg.bdta.pro/images/468b16b26c32efcb59b1a8bc6f5a2a21.jpg'),
(14422, 925, '12 Monkeys S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196004.mp4', 'http://timg.bdta.pro/images/13664db2bc3297127bffd6fc1fe22d77.jpg'),
(14423, 925, '12 Monkeys S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196005.mp4', 'http://timg.bdta.pro/images/10c944965a7a7d7b444efb6246db2fe0.jpg'),
(14424, 925, '12 Monkeys S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196006.mp4', 'http://timg.bdta.pro/images/1ebd765e17d4bd6e9cf90fe501b8138e.jpg'),
(14425, 926, 'O Alienista S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zGaTmdahgU1nsvKNmYGilyoOrFT.jpg'),
(14426, 926, 'O Alienista S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zGaTmdahgU1nsvKNmYGilyoOrFT.jpg'),
(14427, 926, 'O Alienista S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zGaTmdahgU1nsvKNmYGilyoOrFT.jpg'),
(14428, 926, 'O Alienista S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zGaTmdahgU1nsvKNmYGilyoOrFT.jpg'),
(14429, 926, 'O Alienista S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zGaTmdahgU1nsvKNmYGilyoOrFT.jpg'),
(14430, 926, 'O Alienista S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zGaTmdahgU1nsvKNmYGilyoOrFT.jpg'),
(14431, 926, 'O Alienista S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zGaTmdahgU1nsvKNmYGilyoOrFT.jpg'),
(14432, 926, 'O Alienista S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zGaTmdahgU1nsvKNmYGilyoOrFT.jpg'),
(14433, 926, 'O Alienista S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zGaTmdahgU1nsvKNmYGilyoOrFT.jpg'),
(14434, 926, 'O Alienista S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zGaTmdahgU1nsvKNmYGilyoOrFT.jpg'),
(14435, 927, 'O Alienista S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128879.mp4', 'http://timg.bdta.pro/images/5639c0c3998e595af77c2e4aca9a1c04.jpg'),
(14436, 927, 'O Alienista S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128880.mp4', 'http://timg.bdta.pro/images/5cdc1facaaf695a4451c57d1a5ab04d9.jpg'),
(14437, 927, 'O Alienista S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128881.mp4', 'http://timg.bdta.pro/images/c9b3d33885f265c35f10bb1e77acaeb3.jpg'),
(14438, 927, 'O Alienista S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128882.mp4', 'http://timg.bdta.pro/images/243a4d5d619cdbc5daff64344e19ee28.jpg'),
(14439, 927, 'O Alienista S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128883.mp4', 'http://timg.bdta.pro/images/75e5b7608a58dea2105c1a1f7d59c5a2.jpg'),
(14440, 927, 'O Alienista S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128884.mp4', 'http://timg.bdta.pro/images/e6764af605b6e4cd075c6f6607145e18.jpg'),
(14441, 927, 'O Alienista S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128885.mp4', 'http://timg.bdta.pro/images/9540c42ca3330b95678deab4cc634381.jpg'),
(14442, 927, 'O Alienista S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128886.mp4', 'http://timg.bdta.pro/images/bb9847e52e61a798f4915df034072450.jpg'),
(14443, 928, 'Game of Thrones S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14444, 928, 'Game of Thrones S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14445, 928, 'Game of Thrones S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14446, 928, 'Game of Thrones S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14447, 928, 'Game of Thrones S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14448, 928, 'Game of Thrones S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14449, 928, 'Game of Thrones S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14450, 928, 'Game of Thrones S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14451, 928, 'Game of Thrones S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14452, 928, 'Game of Thrones S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14453, 929, 'Game of Thrones S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14454, 929, 'Game of Thrones S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14455, 929, 'Game of Thrones S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14456, 929, 'Game of Thrones S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14457, 929, 'Game of Thrones S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14458, 929, 'Game of Thrones S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14459, 929, 'Game of Thrones S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14460, 929, 'Game of Thrones S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14461, 929, 'Game of Thrones S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14462, 929, 'Game of Thrones S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14463, 930, 'Game of Thrones S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14464, 930, 'Game of Thrones S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14465, 930, 'Game of Thrones S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14466, 930, 'Game of Thrones S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14467, 930, 'Game of Thrones S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14468, 930, 'Game of Thrones S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14469, 930, 'Game of Thrones S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14470, 930, 'Game of Thrones S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14471, 930, 'Game of Thrones S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14472, 930, 'Game of Thrones S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14473, 931, 'Game of Thrones S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14474, 931, 'Game of Thrones S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14475, 931, 'Game of Thrones S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14476, 931, 'Game of Thrones S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14477, 931, 'Game of Thrones S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14478, 931, 'Game of Thrones S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14479, 931, 'Game of Thrones S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14480, 931, 'Game of Thrones S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14481, 931, 'Game of Thrones S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14482, 931, 'Game of Thrones S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14483, 932, 'Game of Thrones S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14484, 932, 'Game of Thrones S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14485, 932, 'Game of Thrones S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14486, 932, 'Game of Thrones S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14487, 932, 'Game of Thrones S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14488, 932, 'Game of Thrones S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14489, 932, 'Game of Thrones S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14490, 932, 'Game of Thrones S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14491, 932, 'Game of Thrones S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14492, 932, 'Game of Thrones S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14493, 933, 'Game of Thrones S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14494, 933, 'Game of Thrones S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14495, 933, 'Game of Thrones S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14496, 933, 'Game of Thrones S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14497, 933, 'Game of Thrones S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14498, 933, 'Game of Thrones S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14499, 933, 'Game of Thrones S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14500, 933, 'Game of Thrones S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14501, 933, 'Game of Thrones S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14502, 933, 'Game of Thrones S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14503, 934, 'Game of Thrones S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14504, 934, 'Game of Thrones S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14505, 934, 'Game of Thrones S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14506, 934, 'Game of Thrones S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14507, 934, 'Game of Thrones S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14508, 934, 'Game of Thrones S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14509, 934, 'Game of Thrones S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14510, 935, 'Game of Thrones S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14511, 935, 'Game of Thrones S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14512, 935, 'Game of Thrones S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14513, 935, 'Game of Thrones S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14514, 935, 'Game of Thrones S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14515, 935, 'Game of Thrones S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l2ezB41chGDjXcKo24lseuXYtKP.jpg'),
(14516, 936, 'Arquivo X S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127889.mp4', 'http://timg.bdta.pro/images/82a209d92db2645b8f259a9e4241d8c5.jpg'),
(14517, 936, 'Arquivo X S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127890.mp4', 'http://timg.bdta.pro/images/a3c6df7907dd53067e2f71747cd65d6f.jpg'),
(14518, 936, 'Arquivo X S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127891.mp4', 'http://timg.bdta.pro/images/9773414ca3a7f4e8a8214ec56f53fac9.jpg'),
(14519, 936, 'Arquivo X S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127892.mp4', 'http://timg.bdta.pro/images/ba2e9fe04d9554c52d0ad7604d2007f0.jpg'),
(14520, 936, 'Arquivo X S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127893.mp4', 'http://timg.bdta.pro/images/0305f16b82a5baf801b3b712c6cdf7bd.jpg'),
(14521, 936, 'Arquivo X S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127894.mp4', 'http://timg.bdta.pro/images/d148b4f0a96a0b9d700d6d39cb5a0508.jpg'),
(14522, 936, 'Arquivo X S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127895.mp4', 'http://timg.bdta.pro/images/c71005ba363138168c7b7d46c8e345c6.jpg'),
(14523, 936, 'Arquivo X S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127896.mp4', 'http://timg.bdta.pro/images/b80421bf0379ea89b0dfeec063e80065.jpg'),
(14524, 936, 'Arquivo X S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127897.mp4', 'http://timg.bdta.pro/images/6651cdce2a3cde64edb3d14770345fa6.jpg'),
(14525, 936, 'Arquivo X S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127898.mp4', 'http://timg.bdta.pro/images/696803f07804f58d2d63877a48e48caa.jpg'),
(14526, 936, 'Arquivo X S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127899.mp4', 'http://timg.bdta.pro/images/36cbb2ce36d609e1c6f83be2b977e998.jpg'),
(14527, 936, 'Arquivo X S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127900.mp4', 'http://timg.bdta.pro/images/ffd033fbf84a802c5f273c5fd13a6c94.jpg'),
(14528, 936, 'Arquivo X S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127901.mp4', 'http://timg.bdta.pro/images/10278dcc585cfd3f4df33d3f925690fc.jpg'),
(14529, 936, 'Arquivo X S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127902.mp4', 'http://timg.bdta.pro/images/ac50e607d091e2b046f86c791a058c5d.jpg'),
(14530, 936, 'Arquivo X S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127903.mp4', 'http://timg.bdta.pro/images/4e414444fd95d832336b27a2f7bfd738.jpg'),
(14531, 936, 'Arquivo X S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127904.mp4', 'http://timg.bdta.pro/images/e3e4482a054b2aa601850be0a692edaa.jpg'),
(14532, 936, 'Arquivo X S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127905.mp4', 'http://timg.bdta.pro/images/77245f3d127d9d267420a8a3a11d3d54.jpg'),
(14533, 936, 'Arquivo X S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127906.mp4', 'http://timg.bdta.pro/images/e4c27cb1487030ce7708ece2f9598f1d.jpg'),
(14534, 936, 'Arquivo X S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127907.mp4', 'http://timg.bdta.pro/images/a46f33b25b38780efc800788b88addb7.jpg'),
(14535, 936, 'Arquivo X S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127908.mp4', 'http://timg.bdta.pro/images/cd666719e76b44e9fa39300555e2b2c8.jpg'),
(14536, 936, 'Arquivo X S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127909.mp4', 'http://timg.bdta.pro/images/094bf55e038ea26916639d5ba4e020f5.jpg'),
(14537, 936, 'Arquivo X S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/127910.mp4', 'http://timg.bdta.pro/images/7b4d7f543ad6cc2634b6d91a420858be.jpg'),
(14538, 936, 'Arquivo X S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/127911.mp4', 'http://timg.bdta.pro/images/ec00e57d6553d0cd5b475dba18a4a109.jpg'),
(14539, 936, 'Arquivo X S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/127912.mp4', 'http://timg.bdta.pro/images/053108cfa3d1f769c8ce002768047798.jpg'),
(14540, 937, 'Arquivo X S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127913.mp4', 'http://timg.bdta.pro/images/f1babdc8122e1d9645fccc2c537dec29.jpg'),
(14541, 937, 'Arquivo X S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127914.mp4', 'http://timg.bdta.pro/images/526749fe985669600b82ec8f3a23718e.jpg'),
(14542, 937, 'Arquivo X S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127915.mp4', 'http://timg.bdta.pro/images/5f987c8d271d88f85d539fbd0bac5078.jpg'),
(14543, 937, 'Arquivo X S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127916.mp4', 'http://timg.bdta.pro/images/6d2d09d189a41a112fa9bfeb1763a93b.jpg'),
(14544, 937, 'Arquivo X S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127917.mp4', 'http://timg.bdta.pro/images/ad60ffe2df85195e4ea910b27b830ec2.jpg'),
(14545, 937, 'Arquivo X S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127918.mp4', 'http://timg.bdta.pro/images/ea17d6b517856e23e2db61a1a1d163fe.jpg'),
(14546, 937, 'Arquivo X S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127919.mp4', 'http://timg.bdta.pro/images/e5eaa114de1ff995cd65b9763318d4a5.jpg'),
(14547, 937, 'Arquivo X S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127920.mp4', 'http://timg.bdta.pro/images/ab6046ea3e0acc3defa0535ce24b7d3a.jpg'),
(14548, 937, 'Arquivo X S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127921.mp4', 'http://timg.bdta.pro/images/3779827aaddc01af3facd9be16d25815.jpg'),
(14549, 937, 'Arquivo X S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127922.mp4', 'http://timg.bdta.pro/images/a74c9b643e533647d364fd9aede423a7.jpg'),
(14550, 937, 'Arquivo X S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127923.mp4', 'http://timg.bdta.pro/images/040a5367ba3b936953a5e833ca804fb4.jpg'),
(14551, 937, 'Arquivo X S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127924.mp4', 'http://timg.bdta.pro/images/efa7ac699043b1a8e3507163cccdfa3f.jpg'),
(14552, 937, 'Arquivo X S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127925.mp4', 'http://timg.bdta.pro/images/ba626c742597f49cdb46eaa0af4b9c88.jpg'),
(14553, 937, 'Arquivo X S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127926.mp4', 'http://timg.bdta.pro/images/3e678dce8bf152ecb4cb0011c61f889c.jpg'),
(14554, 937, 'Arquivo X S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127927.mp4', 'http://timg.bdta.pro/images/09747506fb0703b1bf7761f496f8923f.jpg'),
(14555, 937, 'Arquivo X S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127928.mp4', 'http://timg.bdta.pro/images/ea1950f9c1c5288b3fdfbde5bfc593a5.jpg'),
(14556, 937, 'Arquivo X S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127929.mp4', 'http://timg.bdta.pro/images/b5724e3c39370190e2c894582e84e528.jpg'),
(14557, 937, 'Arquivo X S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127930.mp4', 'http://timg.bdta.pro/images/839e20918bdc68fb76697fc078c75053.jpg'),
(14558, 937, 'Arquivo X S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127931.mp4', 'http://timg.bdta.pro/images/711523b2653779c5607a82ae676dc9a5.jpg'),
(14559, 937, 'Arquivo X S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127932.mp4', 'http://timg.bdta.pro/images/6fcdcfbd75de4419ff847db0a136ba4c.jpg'),
(14560, 937, 'Arquivo X S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127933.mp4', 'http://timg.bdta.pro/images/7999b7f7e3135905be0015cc2605a85a.jpg'),
(14561, 937, 'Arquivo X S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/127934.mp4', 'http://timg.bdta.pro/images/9330c367ea692619427d1868ca525678.jpg'),
(14562, 937, 'Arquivo X S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/127935.mp4', 'http://timg.bdta.pro/images/ea34ca9ebe084ee0924e308125c4b1bb.jpg'),
(14563, 937, 'Arquivo X S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/127936.mp4', 'http://timg.bdta.pro/images/a8a53ff18c3ba63082818ab7795ade3f.jpg'),
(14564, 937, 'Arquivo X S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/127937.mp4', 'http://timg.bdta.pro/images/ba22c104b4f08f8bc64d0284d7c5a966.jpg'),
(14565, 938, 'Arquivo X S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127938.mp4', 'http://timg.bdta.pro/images/c3fdeb86b1afc3f1ff37b6933ac70041.jpg'),
(14566, 938, 'Arquivo X S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127939.mp4', 'http://timg.bdta.pro/images/85c023f1e74773b00d0cafe87961fe3d.jpg'),
(14567, 938, 'Arquivo X S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127940.mp4', 'http://timg.bdta.pro/images/b509493c6e52cc83e13ec858b44dfaef.jpg'),
(14568, 938, 'Arquivo X S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127941.mp4', 'http://timg.bdta.pro/images/9a321a26f4ba21e0291bc9c267a26a1c.jpg'),
(14569, 938, 'Arquivo X S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127942.mp4', 'http://timg.bdta.pro/images/b1e46e69c83302d381a1cb425b6701a6.jpg'),
(14570, 938, 'Arquivo X S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127943.mp4', 'http://timg.bdta.pro/images/86b1401d687ba7ecd5b91847d979b640.jpg'),
(14571, 938, 'Arquivo X S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127944.mp4', 'http://timg.bdta.pro/images/9f0d3667fa10fdbf169771de6ff8cf6d.jpg'),
(14572, 938, 'Arquivo X S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127945.mp4', 'http://timg.bdta.pro/images/a9aa5638c369e3b81cd7242312b2c868.jpg'),
(14573, 938, 'Arquivo X S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127946.mp4', 'http://timg.bdta.pro/images/503f2c759f8e92382340217b1f55dd55.jpg'),
(14574, 938, 'Arquivo X S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127947.mp4', 'http://timg.bdta.pro/images/e94e318b0078494c26bf9d9ba97a0a3f.jpg'),
(14575, 938, 'Arquivo X S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127948.mp4', 'http://timg.bdta.pro/images/0bfc2e4fdd39096e1e997e2a9d6bdd2c.jpg'),
(14576, 938, 'Arquivo X S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127949.mp4', 'http://timg.bdta.pro/images/73f75f21afaddda6e9b5e6eeaf1b43f7.jpg'),
(14577, 938, 'Arquivo X S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127950.mp4', 'http://timg.bdta.pro/images/bb4ba1c6dd98f8a07142a972a5b462a0.jpg'),
(14578, 938, 'Arquivo X S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127951.mp4', 'http://timg.bdta.pro/images/9e1ea96e08ee7d445f16c55348baa6a1.jpg'),
(14579, 938, 'Arquivo X S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127952.mp4', 'http://timg.bdta.pro/images/74adc212947d989dd2abe555eaba90df.jpg'),
(14580, 938, 'Arquivo X S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127953.mp4', 'http://timg.bdta.pro/images/6e1dcfcd7cdbd765ff69cc85b893d51f.jpg'),
(14581, 938, 'Arquivo X S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127954.mp4', 'http://timg.bdta.pro/images/fd9a71eae2a2179b8259a495ddc401fe.jpg'),
(14582, 938, 'Arquivo X S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127955.mp4', 'http://timg.bdta.pro/images/ef508c3b484798a72c15a44a42c5c399.jpg'),
(14583, 938, 'Arquivo X S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127956.mp4', 'http://timg.bdta.pro/images/7a71ebaf57ad54d0d12ebf333fabd14e.jpg'),
(14584, 938, 'Arquivo X S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127957.mp4', 'http://timg.bdta.pro/images/c1f03e18d56ed71b5fe4cce45c1e7e5a.jpg'),
(14585, 938, 'Arquivo X S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127958.mp4', 'http://timg.bdta.pro/images/687d9f218af0c148cc6d670c017f146b.jpg'),
(14586, 938, 'Arquivo X S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/127959.mp4', 'http://timg.bdta.pro/images/a366cd64dbb450328dd9d28c735724f5.jpg'),
(14587, 938, 'Arquivo X S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/127960.mp4', 'http://timg.bdta.pro/images/ae42f30af1964ab9c9e3dae9d998eab3.jpg'),
(14588, 938, 'Arquivo X S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/127961.mp4', 'http://timg.bdta.pro/images/14b22ae8192d490f7c069fbecd128b70.jpg'),
(14589, 939, 'Arquivo X S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127962.mp4', 'http://timg.bdta.pro/images/bffaa39510ef47b91b70049456ba0bc5.jpg'),
(14590, 939, 'Arquivo X S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127963.mp4', 'http://timg.bdta.pro/images/2996f9f7d37e0ec60f826f09f5eb5d98.jpg'),
(14591, 939, 'Arquivo X S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127964.mp4', 'http://timg.bdta.pro/images/dd3bb220f54a3a1aa7fc5d2679d442c9.jpg'),
(14592, 939, 'Arquivo X S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127965.mp4', 'http://timg.bdta.pro/images/975fe9a536ea294394e758dc0c3eb9e4.jpg'),
(14593, 939, 'Arquivo X S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127966.mp4', 'http://timg.bdta.pro/images/bf3c2848a233e5880d6d309b94a233e4.jpg'),
(14594, 939, 'Arquivo X S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127967.mp4', 'http://timg.bdta.pro/images/b6ba7f011bff36c551bf6d84dfae6c3d.jpg'),
(14595, 939, 'Arquivo X S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127968.mp4', 'http://timg.bdta.pro/images/88749871d171d689c6603ffcb6a7ebfd.jpg'),
(14596, 939, 'Arquivo X S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127969.mp4', 'http://timg.bdta.pro/images/be465bf62574f6a6b6a24a1abf61e9ba.jpg'),
(14597, 939, 'Arquivo X S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127970.mp4', 'http://timg.bdta.pro/images/4ef0615aa7cd9c914d8cc056d8f78a89.jpg'),
(14598, 939, 'Arquivo X S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127971.mp4', 'http://timg.bdta.pro/images/e2de04b0199fe1247f3cb213d4d6451a.jpg'),
(14599, 939, 'Arquivo X S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127972.mp4', 'http://timg.bdta.pro/images/6e0f88cfa8f85ffc71b515ecfc10029c.jpg'),
(14600, 939, 'Arquivo X S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127973.mp4', 'http://timg.bdta.pro/images/f52422c1d7766e2007abc52fd0b1c200.jpg'),
(14601, 939, 'Arquivo X S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127974.mp4', 'http://timg.bdta.pro/images/b9252de99dd356f2205805352ab37c0f.jpg'),
(14602, 939, 'Arquivo X S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127975.mp4', 'http://timg.bdta.pro/images/659694e52b34527362c3b884e791d343.jpg'),
(14603, 939, 'Arquivo X S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127976.mp4', 'http://timg.bdta.pro/images/be9e0d57d9e7ae0706aeecc9d8cff5b6.jpg'),
(14604, 939, 'Arquivo X S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127977.mp4', 'http://timg.bdta.pro/images/b9b53b931c9ab49f4e0ec0420e942006.jpg'),
(14605, 939, 'Arquivo X S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127978.mp4', 'http://timg.bdta.pro/images/050e820e5b2ca6db0c4ea721d9724ac2.jpg'),
(14606, 939, 'Arquivo X S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127979.mp4', 'http://timg.bdta.pro/images/eea02d8c87524639893d300dbcce5775.jpg'),
(14607, 939, 'Arquivo X S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127980.mp4', 'http://timg.bdta.pro/images/204d54e9db2555ac536ce0742c2ac38d.jpg'),
(14608, 939, 'Arquivo X S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127981.mp4', 'http://timg.bdta.pro/images/bfcbe8b3c12cc05e4e92bbc0db34b0e9.jpg'),
(14609, 939, 'Arquivo X S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127982.mp4', 'http://timg.bdta.pro/images/854cbda68fd51a54a53afa1b483b1c1c.jpg'),
(14610, 939, 'Arquivo X S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/127983.mp4', 'http://timg.bdta.pro/images/fd10139ea7336276eb43a2791a61df10.jpg'),
(14611, 939, 'Arquivo X S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/127984.mp4', 'http://timg.bdta.pro/images/a75e14482cb3411a6324ae7120cd2e5d.jpg'),
(14612, 939, 'Arquivo X S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/127985.mp4', 'http://timg.bdta.pro/images/dccaffa33ab7ac437bf6ea6707885576.jpg'),
(14613, 940, 'Arquivo X S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127986.mp4', 'http://timg.bdta.pro/images/ea88917807fc209e72cfbc9f6eaed480.jpg'),
(14614, 940, 'Arquivo X S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127987.mp4', 'http://timg.bdta.pro/images/e0b7f02d75aca7c71e3048e33e5976a9.jpg'),
(14615, 940, 'Arquivo X S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127988.mp4', 'http://timg.bdta.pro/images/3728d087dd3685c2678ba2cc09092cb8.jpg'),
(14616, 940, 'Arquivo X S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127989.mp4', 'http://timg.bdta.pro/images/7dcd552bb377365896df7215c7042d58.jpg'),
(14617, 940, 'Arquivo X S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127990.mp4', 'http://timg.bdta.pro/images/1019adfa6fcae765b6de7ffea82e2e11.jpg'),
(14618, 940, 'Arquivo X S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127991.mp4', 'http://timg.bdta.pro/images/51c2490160af7a086a2d27491e6a699f.jpg'),
(14619, 940, 'Arquivo X S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127992.mp4', 'http://timg.bdta.pro/images/a1b44b4faa9605b546b24e175cefe844.jpg'),
(14620, 940, 'Arquivo X S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127993.mp4', 'http://timg.bdta.pro/images/733d23f3d476cfcde231dfe45d28b920.jpg'),
(14621, 940, 'Arquivo X S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127994.mp4', 'http://timg.bdta.pro/images/574b95d9a522be5c7f7c619ba80b8858.jpg'),
(14622, 940, 'Arquivo X S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127995.mp4', 'http://timg.bdta.pro/images/2dc88ff36c8ec15c190dd13eb7a46c14.jpg'),
(14623, 940, 'Arquivo X S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127996.mp4', 'http://timg.bdta.pro/images/4002a473860d1650836f4049b7ac5151.jpg'),
(14624, 940, 'Arquivo X S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127997.mp4', 'http://timg.bdta.pro/images/894dba809c403bcda2423d3d09a0ac6b.jpg'),
(14625, 940, 'Arquivo X S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127998.mp4', 'http://timg.bdta.pro/images/19d15fc0a155d4fd833b474208226e2f.jpg'),
(14626, 940, 'Arquivo X S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127999.mp4', 'http://timg.bdta.pro/images/7c3cb7bf07059aa94e6f4857bf4d0278.jpg'),
(14627, 940, 'Arquivo X S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/128000.mp4', 'http://timg.bdta.pro/images/8961b158639a68e4043371130beba204.jpg'),
(14628, 940, 'Arquivo X S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/128001.mp4', 'http://timg.bdta.pro/images/b1c7340d10c11b93c15b132343e76496.jpg'),
(14629, 940, 'Arquivo X S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/128002.mp4', 'http://timg.bdta.pro/images/3431da83f9f092b591e1008d1c2063b8.jpg'),
(14630, 940, 'Arquivo X S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/128003.mp4', 'http://timg.bdta.pro/images/4c78a4fce4d0310b62d4d6708f554a42.jpg'),
(14631, 940, 'Arquivo X S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/128004.mp4', 'http://timg.bdta.pro/images/7006b5541dd90babea96a7bfc8fe4cc3.jpg'),
(14632, 940, 'Arquivo X S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/128005.mp4', 'http://timg.bdta.pro/images/c63d39815c2090bf4bdea527c56756a8.jpg'),
(14633, 941, 'Arquivo X S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128006.mp4', 'http://timg.bdta.pro/images/77d3dc5167375d9aad32195e32ade26d.jpg'),
(14634, 941, 'Arquivo X S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128007.mp4', 'http://timg.bdta.pro/images/830e122bdb0688f122465908ce47d6d1.jpg'),
(14635, 941, 'Arquivo X S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128008.mp4', 'http://timg.bdta.pro/images/11bcbe3f51aa615758734f6518f1fdb5.jpg'),
(14636, 941, 'Arquivo X S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128009.mp4', 'http://timg.bdta.pro/images/f6ee7b8163f7df884e357d38ff100d26.jpg'),
(14637, 941, 'Arquivo X S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128010.mp4', 'http://timg.bdta.pro/images/ba8b244ff272134cb17d021b35eda1cc.jpg'),
(14638, 941, 'Arquivo X S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128011.mp4', 'http://timg.bdta.pro/images/7e7ac7d9ecf4f15d0e37a5fdd06a19af.jpg'),
(14639, 941, 'Arquivo X S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128012.mp4', 'http://timg.bdta.pro/images/73f2fb62be65ed04a31cda556b504589.jpg'),
(14640, 941, 'Arquivo X S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128013.mp4', 'http://timg.bdta.pro/images/7c5ba7d5fc4d2034229cd3086b810110.jpg'),
(14641, 941, 'Arquivo X S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128014.mp4', 'http://timg.bdta.pro/images/a0eba76a5d15b0a6a589fe722cb2c5f4.jpg'),
(14642, 941, 'Arquivo X S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128015.mp4', 'http://timg.bdta.pro/images/e14f432ca96be9c192eeadb54dd02a5e.jpg'),
(14643, 941, 'Arquivo X S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/128016.mp4', 'http://timg.bdta.pro/images/e10f69855fab6e88f8ce68b288d80f8b.jpg'),
(14644, 941, 'Arquivo X S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/128017.mp4', 'http://timg.bdta.pro/images/1abe2bae716942e68bd3ea51a4ca6afa.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(14645, 941, 'Arquivo X S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/128018.mp4', 'http://timg.bdta.pro/images/92d3ed1ca2a3634243344ce4a7e5a86a.jpg'),
(14646, 941, 'Arquivo X S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/128019.mp4', 'http://timg.bdta.pro/images/34ccd33333e6c6ba92a52316aac53f0a.jpg'),
(14647, 941, 'Arquivo X S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/128020.mp4', 'http://timg.bdta.pro/images/149226b5b27f986f944a111a1a85b6b5.jpg'),
(14648, 941, 'Arquivo X S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/128021.mp4', 'http://timg.bdta.pro/images/e1d4bdf5199372bcb2c8679cbd306f3b.jpg'),
(14649, 941, 'Arquivo X S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/128022.mp4', 'http://timg.bdta.pro/images/d0556078017c6fcc1b6418f89beba44d.jpg'),
(14650, 941, 'Arquivo X S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/128023.mp4', 'http://timg.bdta.pro/images/a94a7a9d6fa7032f4bc2648ec10bd2ef.jpg'),
(14651, 941, 'Arquivo X S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/128024.mp4', 'http://timg.bdta.pro/images/656597631bce2f15f97fdbe3be3d1af2.jpg'),
(14652, 941, 'Arquivo X S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/128025.mp4', 'http://timg.bdta.pro/images/30f48a5518d4bf4bf8b3a4233630c26d.jpg'),
(14653, 941, 'Arquivo X S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/128026.mp4', 'http://timg.bdta.pro/images/47dfba3d8840261cc46ca459ec241976.jpg'),
(14654, 941, 'Arquivo X S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/128027.mp4', 'http://timg.bdta.pro/images/931843023bb9d582a044c9b8443582d4.jpg'),
(14655, 942, 'Arquivo X S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128028.mp4', 'http://timg.bdta.pro/images/c4c6f4ec34734ffa43af2551568d5c18.jpg'),
(14656, 942, 'Arquivo X S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128029.mp4', 'http://timg.bdta.pro/images/82c2c830f5820bb9a36166232f3c0ac2.jpg'),
(14657, 942, 'Arquivo X S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128030.mp4', 'http://timg.bdta.pro/images/3082019ea6e1b554e9afa8d3fe5dd204.jpg'),
(14658, 942, 'Arquivo X S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128031.mp4', 'http://timg.bdta.pro/images/63de1466eeb6a50e6d29f20dbaf77d74.jpg'),
(14659, 942, 'Arquivo X S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128032.mp4', 'http://timg.bdta.pro/images/719807b092457a67afed8850bb742bc7.jpg'),
(14660, 942, 'Arquivo X S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128033.mp4', 'http://timg.bdta.pro/images/350149bec6b2cfadd4fcc6a30ae710ac.jpg'),
(14661, 942, 'Arquivo X S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128034.mp4', 'http://timg.bdta.pro/images/8f47f6503789b028285da34736086e90.jpg'),
(14662, 942, 'Arquivo X S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128035.mp4', 'http://timg.bdta.pro/images/2d6502f3e882cc773f4bf7b60f3038ea.jpg'),
(14663, 942, 'Arquivo X S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128036.mp4', 'http://timg.bdta.pro/images/35ed1b8518b78bae8114e18f47fffd24.jpg'),
(14664, 942, 'Arquivo X S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128037.mp4', 'http://timg.bdta.pro/images/5fcaa14f085f4ba21bfd9d54ac307abd.jpg'),
(14665, 942, 'Arquivo X S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/128038.mp4', 'http://timg.bdta.pro/images/138b1ac95e6e812338a26d16414d9733.jpg'),
(14666, 942, 'Arquivo X S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/128039.mp4', 'http://timg.bdta.pro/images/9b0f670b044aee9eab6518fad3494a00.jpg'),
(14667, 942, 'Arquivo X S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/128040.mp4', 'http://timg.bdta.pro/images/406d69d39091bf1241ce1e4168788ab4.jpg'),
(14668, 942, 'Arquivo X S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/128041.mp4', 'http://timg.bdta.pro/images/a1f3d7a5b0cb8a1e2c934c570e04bdc1.jpg'),
(14669, 942, 'Arquivo X S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/128042.mp4', 'http://timg.bdta.pro/images/2712faae3b6b472db1889768d40f4fa8.jpg'),
(14670, 942, 'Arquivo X S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/128043.mp4', 'http://timg.bdta.pro/images/83b9309b89883296f1772e0df0edd088.jpg'),
(14671, 942, 'Arquivo X S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/128044.mp4', 'http://timg.bdta.pro/images/36ce498d91ffd08ca265f1c3100b15c4.jpg'),
(14672, 942, 'Arquivo X S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/128045.mp4', 'http://timg.bdta.pro/images/ee0a2e6dda48cd66fe3f88f9fd5aeaf7.jpg'),
(14673, 942, 'Arquivo X S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/128046.mp4', 'http://timg.bdta.pro/images/78f5c5e8de99d9bac3d65d71b4584878.jpg'),
(14674, 942, 'Arquivo X S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/128047.mp4', 'http://timg.bdta.pro/images/7e870a298db6e814a44024fe5a98c082.jpg'),
(14675, 942, 'Arquivo X S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/128048.mp4', 'http://timg.bdta.pro/images/098963c9eb175ac10cef3dec96d4d2a4.jpg'),
(14676, 942, 'Arquivo X S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/128049.mp4', 'http://timg.bdta.pro/images/f7d6c1137393f6f690c476acd3544dff.jpg'),
(14677, 943, 'Arquivo X S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128050.mp4', 'http://timg.bdta.pro/images/e77a383afd7627418e86cb31a7960c2f.jpg'),
(14678, 943, 'Arquivo X S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128051.mp4', 'http://timg.bdta.pro/images/c2270cf211500fac523b7fe8c0b9a46b.jpg'),
(14679, 943, 'Arquivo X S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128052.mp4', 'http://timg.bdta.pro/images/cb3fe03592f37627a0e6159e44cbf762.jpg'),
(14680, 943, 'Arquivo X S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128053.mp4', 'http://timg.bdta.pro/images/69eb93035a40eefa4b5701b8307af530.jpg'),
(14681, 943, 'Arquivo X S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128054.mp4', 'http://timg.bdta.pro/images/d5add74f34faecda4c9f3aca9357b6ad.jpg'),
(14682, 943, 'Arquivo X S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128055.mp4', 'http://timg.bdta.pro/images/8faa73004e9082f56fd7bc818a3c3cf4.jpg'),
(14683, 943, 'Arquivo X S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128056.mp4', 'http://timg.bdta.pro/images/bbba8bbe40da99f9a77a40a1a638eaf7.jpg'),
(14684, 943, 'Arquivo X S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128057.mp4', 'http://timg.bdta.pro/images/686589e379a9ce66a8c7c8b0ec195d8a.jpg'),
(14685, 943, 'Arquivo X S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128058.mp4', 'http://timg.bdta.pro/images/d1a214001fcee901ca052e36b7fd0ead.jpg'),
(14686, 943, 'Arquivo X S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128059.mp4', 'http://timg.bdta.pro/images/668cc10a35de3f2e755738b793044b1c.jpg'),
(14687, 943, 'Arquivo X S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/128060.mp4', 'http://timg.bdta.pro/images/919b293013efccb748fcb0717a892435.jpg'),
(14688, 943, 'Arquivo X S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/128061.mp4', 'http://timg.bdta.pro/images/f81176bb1d0a31b22697fc658ae7fceb.jpg'),
(14689, 943, 'Arquivo X S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/128062.mp4', 'http://timg.bdta.pro/images/7b911beab170d77e34edf3876e452a9d.jpg'),
(14690, 943, 'Arquivo X S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/128063.mp4', 'http://timg.bdta.pro/images/a89b30725126c2a691f294ceada8ff47.jpg'),
(14691, 943, 'Arquivo X S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/128064.mp4', 'http://timg.bdta.pro/images/ba532bd02e6372c0b0cbf9023feabb0b.jpg'),
(14692, 943, 'Arquivo X S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/128065.mp4', 'http://timg.bdta.pro/images/1f3191435b5f3f43258458c5198edb17.jpg'),
(14693, 943, 'Arquivo X S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/128066.mp4', 'http://timg.bdta.pro/images/cb1db4d45b5fe084faa14110fbdb703d.jpg'),
(14694, 943, 'Arquivo X S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/128067.mp4', 'http://timg.bdta.pro/images/868597586c1b67100706dbf26795298a.jpg'),
(14695, 943, 'Arquivo X S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/128068.mp4', 'http://timg.bdta.pro/images/6716fccc2c8d120f491aa76d0609aebd.jpg'),
(14696, 943, 'Arquivo X S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/128069.mp4', 'http://timg.bdta.pro/images/6ed893cb1354b62e7513eb7d0a8aec8d.jpg'),
(14697, 943, 'Arquivo X S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/128070.mp4', 'http://timg.bdta.pro/images/6daaf7eed2141325ee3384b50857f2d0.jpg'),
(14698, 944, 'Arquivo X S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128071.mp4', 'http://timg.bdta.pro/images/2c12d7eb965db438ab52dd666f62412f.jpg'),
(14699, 944, 'Arquivo X S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128072.mp4', 'http://timg.bdta.pro/images/d81c76e5d8e4e62e69fea809e6d069f6.jpg'),
(14700, 944, 'Arquivo X S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128073.mp4', 'http://timg.bdta.pro/images/98da84c8bf004717963b82c7a9516ed4.jpg'),
(14701, 944, 'Arquivo X S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128074.mp4', 'http://timg.bdta.pro/images/f532e101cbab339f9268695a2e2fb1f2.jpg'),
(14702, 944, 'Arquivo X S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128075.mp4', 'http://timg.bdta.pro/images/fb22a5fcd88d5d302683b1b168a1d77f.jpg'),
(14703, 944, 'Arquivo X S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128076.mp4', 'http://timg.bdta.pro/images/ec033e17b74bcc5fb579f1e88bb93745.jpg'),
(14704, 944, 'Arquivo X S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128077.mp4', 'http://timg.bdta.pro/images/1383039954ceb7214a60b07dcfeb8acc.jpg'),
(14705, 944, 'Arquivo X S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128078.mp4', 'http://timg.bdta.pro/images/c7401a2d604a99ffe70221035f07cec4.jpg'),
(14706, 944, 'Arquivo X S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128079.mp4', 'http://timg.bdta.pro/images/a72e06e5932f45b1a2661bf1616b01e0.jpg'),
(14707, 944, 'Arquivo X S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128080.mp4', 'http://timg.bdta.pro/images/42533fed76664df0d6ce2c342bdc1ecc.jpg'),
(14708, 944, 'Arquivo X S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/128081.mp4', 'http://timg.bdta.pro/images/72e10b2aaad6e9dd47c64beb62f3c6df.jpg'),
(14709, 944, 'Arquivo X S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/128082.mp4', 'http://timg.bdta.pro/images/04a0982822f0396e6b945a0bb00badee.jpg'),
(14710, 944, 'Arquivo X S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/128083.mp4', 'http://timg.bdta.pro/images/9094d632b3bf0698f65f307c92048693.jpg'),
(14711, 944, 'Arquivo X S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/128084.mp4', 'http://timg.bdta.pro/images/3afe9fd3f7ee97258e15247989f8462b.jpg'),
(14712, 944, 'Arquivo X S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/128085.mp4', 'http://timg.bdta.pro/images/08f09981a1167647dc3ce4013af73e0b.jpg'),
(14713, 944, 'Arquivo X S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/128086.mp4', 'http://timg.bdta.pro/images/001ac6bff4e7aa2261b3bad1767ffa28.jpg'),
(14714, 944, 'Arquivo X S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/128087.mp4', 'http://timg.bdta.pro/images/2eb7e5ffec2724509eeb0693d7454c23.jpg'),
(14715, 944, 'Arquivo X S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/128088.mp4', 'http://timg.bdta.pro/images/dbde20444f0f58f57206c465daae454b.jpg'),
(14716, 944, 'Arquivo X S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/128089.mp4', 'http://timg.bdta.pro/images/c112068e02ecaef9c5753d7ecded5600.jpg'),
(14717, 945, 'Arquivo X S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128090.mp4', 'http://timg.bdta.pro/images/17850d835d2efc370ec09549ac551cd7.jpg'),
(14718, 945, 'Arquivo X S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128091.mp4', 'http://timg.bdta.pro/images/4f407a252d862c4c8e78123c7859acb5.jpg'),
(14719, 945, 'Arquivo X S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128092.mp4', 'http://timg.bdta.pro/images/23ea65bf9bab9370993cb860e97ebb92.jpg'),
(14720, 945, 'Arquivo X S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128093.mp4', 'http://timg.bdta.pro/images/d2f39d59109b2a7a5899e0170b5da667.jpg'),
(14721, 945, 'Arquivo X S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128094.mp4', 'http://timg.bdta.pro/images/f6ce2cbd91d3e6fb18f82abb58d804c7.jpg'),
(14722, 945, 'Arquivo X S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128095.mp4', 'http://timg.bdta.pro/images/40a18e67fea7981778b238ddb59a40d0.jpg'),
(14723, 946, 'Arquivo X S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128096.mp4', 'http://timg.bdta.pro/images/2b7c8a60f7c604866ac6e20f6f00bebb.jpg'),
(14724, 946, 'Arquivo X S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128097.mp4', 'http://timg.bdta.pro/images/81c3f4eea24f4145b264013d1be7cd64.jpg'),
(14725, 946, 'Arquivo X S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128098.mp4', 'http://timg.bdta.pro/images/d107a6e796fb0f658ad334fdf67a5ba7.jpg'),
(14726, 946, 'Arquivo X S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128099.mp4', 'http://timg.bdta.pro/images/7c28ad43bb7c92e48125e879cc3f0045.jpg'),
(14727, 946, 'Arquivo X S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128100.mp4', 'http://timg.bdta.pro/images/bef0cdf790fd0dfd34bddcc911a3938e.jpg'),
(14728, 946, 'Arquivo X S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128101.mp4', 'http://timg.bdta.pro/images/10b7bdd6106539d4fe9ea9dadae854a8.jpg'),
(14729, 946, 'Arquivo X S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128102.mp4', 'http://timg.bdta.pro/images/a092a31b2c74b86eae178679f3f4aea8.jpg'),
(14730, 946, 'Arquivo X S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128103.mp4', 'http://timg.bdta.pro/images/2885c72741586a6c3b95fd0c0c8cde0a.jpg'),
(14731, 946, 'Arquivo X S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128104.mp4', 'http://timg.bdta.pro/images/f4baaf135360af23b7e7636aa9b1eabe.jpg'),
(14732, 946, 'Arquivo X S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128105.mp4', 'http://timg.bdta.pro/images/0e9d74293bc1668f3b97a644ba561600.jpg'),
(14733, 947, 'American Crime Story S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100017.mp4', 'http://gstaticontent.com/images/9px1qxEcSs3pgf9Pu48vD5VpoEH_big.jpg'),
(14734, 947, 'American Crime Story S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100018.mp4', 'http://gstaticontent.com/images/9px1qxEcSs3pgf9Pu48vD5VpoEH_big.jpg'),
(14735, 947, 'American Crime Story S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100019.mp4', 'http://gstaticontent.com/images/9px1qxEcSs3pgf9Pu48vD5VpoEH_big.jpg'),
(14736, 947, 'American Crime Story S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100020.mp4', 'http://gstaticontent.com/images/9px1qxEcSs3pgf9Pu48vD5VpoEH_big.jpg'),
(14737, 947, 'American Crime Story S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100021.mp4', 'http://gstaticontent.com/images/9px1qxEcSs3pgf9Pu48vD5VpoEH_big.jpg'),
(14738, 947, 'American Crime Story S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100022.mp4', 'http://gstaticontent.com/images/9px1qxEcSs3pgf9Pu48vD5VpoEH_big.jpg'),
(14739, 947, 'American Crime Story S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100023.mp4', 'http://gstaticontent.com/images/9px1qxEcSs3pgf9Pu48vD5VpoEH_big.jpg'),
(14740, 947, 'American Crime Story S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100024.mp4', 'http://gstaticontent.com/images/9px1qxEcSs3pgf9Pu48vD5VpoEH_big.jpg'),
(14741, 947, 'American Crime Story S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100025.mp4', 'http://gstaticontent.com/images/9px1qxEcSs3pgf9Pu48vD5VpoEH_big.jpg'),
(14742, 947, 'American Crime Story S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/100026.mp4', 'http://gstaticontent.com/images/9px1qxEcSs3pgf9Pu48vD5VpoEH_big.jpg'),
(14743, 948, 'American Crime Story S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/100027.mp4', 'http://gstaticontent.com/images/9px1qxEcSs3pgf9Pu48vD5VpoEH_big.jpg'),
(14744, 948, 'American Crime Story S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/100028.mp4', 'http://gstaticontent.com/images/9px1qxEcSs3pgf9Pu48vD5VpoEH_big.jpg'),
(14745, 948, 'American Crime Story S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/100029.mp4', 'http://gstaticontent.com/images/9px1qxEcSs3pgf9Pu48vD5VpoEH_big.jpg'),
(14746, 948, 'American Crime Story S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/100030.mp4', 'http://gstaticontent.com/images/9px1qxEcSs3pgf9Pu48vD5VpoEH_big.jpg'),
(14747, 948, 'American Crime Story S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/100031.mp4', 'http://gstaticontent.com/images/9px1qxEcSs3pgf9Pu48vD5VpoEH_big.jpg'),
(14748, 948, 'American Crime Story S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/100032.mp4', 'http://gstaticontent.com/images/9px1qxEcSs3pgf9Pu48vD5VpoEH_big.jpg'),
(14749, 948, 'American Crime Story S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/100033.mp4', 'http://gstaticontent.com/images/9px1qxEcSs3pgf9Pu48vD5VpoEH_big.jpg'),
(14750, 948, 'American Crime Story S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/100034.mp4', 'http://gstaticontent.com/images/9px1qxEcSs3pgf9Pu48vD5VpoEH_big.jpg'),
(14751, 948, 'American Crime Story S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/100035.mp4', 'http://gstaticontent.com/images/9px1qxEcSs3pgf9Pu48vD5VpoEH_big.jpg'),
(14752, 949, 'American Crime Story S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/379149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2eIipbVbmJRPDqUiI7jehkz9fs5.jpg'),
(14753, 949, 'American Crime Story S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/379150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lO0IEvzRJFKlJBMtsi0ERPgqKaf.jpg'),
(14754, 949, 'American Crime Story S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/379151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ike1mOqmmL9GUX6pZz97qqePYkF.jpg'),
(14755, 949, 'American Crime Story S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/379152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLLs9L4JWAnWf0x6ZnV9cgqDHFT.jpg'),
(14756, 949, 'American Crime Story S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/379153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v4GkX2i3e2q166LGnqIPQgeIR1Y.jpg'),
(14757, 949, 'American Crime Story S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/379154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lQMMVTu9DGURFZo7c1AhpdRUYOB.jpg'),
(14758, 949, 'American Crime Story S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/379155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xm4I8twUzlZMrjx8GpTEMTyBlJo.jpg'),
(14759, 949, 'American Crime Story S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/379156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x874nyZLiTZaXF39iO8EGGmxuLX.jpg'),
(14760, 949, 'American Crime Story S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/379157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xSEzAOjAtmeUXFdQKAZ0d9Bcfr8.jpg'),
(14761, 949, 'American Crime Story S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/379158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xmbpt97PQo4CyEJfzEZYz6kJSm4.jpg'),
(14762, 950, 'Deuses Americanos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14763, 950, 'Deuses Americanos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14764, 950, 'Deuses Americanos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14765, 950, 'Deuses Americanos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14766, 950, 'Deuses Americanos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14767, 950, 'Deuses Americanos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14768, 950, 'Deuses Americanos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14769, 950, 'Deuses Americanos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14770, 951, 'Deuses Americanos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14771, 951, 'Deuses Americanos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14772, 951, 'Deuses Americanos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14773, 951, 'Deuses Americanos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14774, 951, 'Deuses Americanos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14775, 951, 'Deuses Americanos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14776, 951, 'Deuses Americanos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14777, 951, 'Deuses Americanos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14778, 952, 'Deuses Americanos S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14779, 952, 'Deuses Americanos S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14780, 952, 'Deuses Americanos S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14781, 952, 'Deuses Americanos S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14782, 952, 'Deuses Americanos S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14783, 952, 'Deuses Americanos S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14784, 952, 'Deuses Americanos S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14785, 952, 'Deuses Americanos S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14786, 952, 'Deuses Americanos S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14787, 952, 'Deuses Americanos S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPylofcSv0xhhXIPIlcciFfUOLT.jpg'),
(14788, 953, 'Vai Que Cola S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14789, 953, 'Vai Que Cola S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14790, 953, 'Vai Que Cola S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14791, 953, 'Vai Que Cola S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14792, 953, 'Vai Que Cola S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14793, 953, 'Vai Que Cola S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14794, 953, 'Vai Que Cola S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14795, 953, 'Vai Que Cola S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14796, 953, 'Vai Que Cola S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14797, 953, 'Vai Que Cola S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14798, 953, 'Vai Que Cola S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14799, 953, 'Vai Que Cola S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14800, 953, 'Vai Que Cola S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14801, 953, 'Vai Que Cola S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/247342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14802, 953, 'Vai Que Cola S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/247343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14803, 953, 'Vai Que Cola S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/247344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14804, 953, 'Vai Que Cola S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/247345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14805, 953, 'Vai Que Cola S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/247346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14806, 953, 'Vai Que Cola S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/247347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14807, 953, 'Vai Que Cola S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/247348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14808, 953, 'Vai Que Cola S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/247349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14809, 953, 'Vai Que Cola S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/247350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14810, 953, 'Vai Que Cola S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/247351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14811, 953, 'Vai Que Cola S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/247352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14812, 953, 'Vai Que Cola S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/247353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14813, 953, 'Vai Que Cola S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/247354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14814, 953, 'Vai Que Cola S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/247355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14815, 953, 'Vai Que Cola S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/247356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14816, 953, 'Vai Que Cola S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/247357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14817, 953, 'Vai Que Cola S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/247358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14818, 953, 'Vai Que Cola S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/247359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14819, 953, 'Vai Que Cola S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/247360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14820, 953, 'Vai Que Cola S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/247361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14821, 953, 'Vai Que Cola S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/247362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14822, 953, 'Vai Que Cola S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/247363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14823, 953, 'Vai Que Cola S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/247364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14824, 953, 'Vai Que Cola S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/247365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14825, 953, 'Vai Que Cola S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/247366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14826, 953, 'Vai Que Cola S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/247367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14827, 953, 'Vai Que Cola S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/247368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14828, 954, 'Vai Que Cola S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14829, 954, 'Vai Que Cola S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14830, 954, 'Vai Que Cola S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14831, 954, 'Vai Que Cola S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14832, 954, 'Vai Que Cola S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14833, 954, 'Vai Que Cola S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14834, 954, 'Vai Que Cola S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14835, 954, 'Vai Que Cola S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14836, 954, 'Vai Que Cola S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14837, 954, 'Vai Que Cola S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14838, 954, 'Vai Que Cola S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14839, 954, 'Vai Que Cola S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14840, 954, 'Vai Que Cola S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14841, 954, 'Vai Que Cola S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/247382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14842, 954, 'Vai Que Cola S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/247383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14843, 954, 'Vai Que Cola S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/247384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14844, 954, 'Vai Que Cola S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/247385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14845, 954, 'Vai Que Cola S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/247386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14846, 954, 'Vai Que Cola S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/247387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14847, 954, 'Vai Que Cola S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/247388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14848, 954, 'Vai Que Cola S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/247389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14849, 954, 'Vai Que Cola S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/247390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14850, 954, 'Vai Que Cola S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/247391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14851, 954, 'Vai Que Cola S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/247392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14852, 954, 'Vai Que Cola S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/247393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14853, 954, 'Vai Que Cola S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/247394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14854, 954, 'Vai Que Cola S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/247395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14855, 954, 'Vai Que Cola S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/247396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14856, 954, 'Vai Que Cola S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/247397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14857, 954, 'Vai Que Cola S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/247398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14858, 954, 'Vai Que Cola S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/247399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14859, 954, 'Vai Que Cola S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/247400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14860, 954, 'Vai Que Cola S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/247401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14861, 954, 'Vai Que Cola S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/247402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14862, 954, 'Vai Que Cola S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/247403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14863, 954, 'Vai Que Cola S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/247404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14864, 954, 'Vai Que Cola S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/247405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14865, 954, 'Vai Que Cola S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/247406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14866, 954, 'Vai Que Cola S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/247407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14867, 954, 'Vai Que Cola S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/247408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14868, 955, 'Vai Que Cola S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14869, 955, 'Vai Que Cola S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14870, 955, 'Vai Que Cola S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14871, 955, 'Vai Que Cola S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14872, 955, 'Vai Que Cola S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14873, 955, 'Vai Que Cola S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14874, 955, 'Vai Que Cola S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14875, 955, 'Vai Que Cola S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14876, 955, 'Vai Que Cola S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14877, 955, 'Vai Que Cola S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14878, 955, 'Vai Que Cola S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14879, 955, 'Vai Que Cola S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14880, 955, 'Vai Que Cola S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14881, 955, 'Vai Que Cola S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/247422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14882, 955, 'Vai Que Cola S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/247423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14883, 955, 'Vai Que Cola S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/247424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14884, 955, 'Vai Que Cola S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/247425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14885, 955, 'Vai Que Cola S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/247426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14886, 955, 'Vai Que Cola S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/247427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14887, 955, 'Vai Que Cola S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/247428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14888, 955, 'Vai Que Cola S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/247429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14889, 955, 'Vai Que Cola S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/247430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14890, 955, 'Vai Que Cola S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/247431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14891, 955, 'Vai Que Cola S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/247432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14892, 955, 'Vai Que Cola S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/247433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14893, 955, 'Vai Que Cola S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/247434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14894, 955, 'Vai Que Cola S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/247435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14895, 955, 'Vai Que Cola S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/247436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14896, 955, 'Vai Que Cola S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/247437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14897, 955, 'Vai Que Cola S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/247438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14898, 955, 'Vai Que Cola S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/247439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14899, 955, 'Vai Que Cola S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/247440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14900, 955, 'Vai Que Cola S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/247441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14901, 955, 'Vai Que Cola S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/247442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14902, 955, 'Vai Que Cola S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/247443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14903, 955, 'Vai Que Cola S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/247444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14904, 955, 'Vai Que Cola S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/247445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14905, 955, 'Vai Que Cola S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/247446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14906, 955, 'Vai Que Cola S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/247447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14907, 955, 'Vai Que Cola S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/247448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14908, 956, 'Vai Que Cola S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14909, 956, 'Vai Que Cola S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14910, 956, 'Vai Que Cola S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14911, 956, 'Vai Que Cola S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14912, 956, 'Vai Que Cola S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14913, 956, 'Vai Que Cola S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14914, 956, 'Vai Que Cola S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14915, 956, 'Vai Que Cola S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14916, 956, 'Vai Que Cola S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14917, 956, 'Vai Que Cola S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14918, 956, 'Vai Que Cola S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14919, 956, 'Vai Que Cola S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14920, 956, 'Vai Que Cola S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14921, 956, 'Vai Que Cola S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/247462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14922, 956, 'Vai Que Cola S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/247463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(14923, 956, 'Vai Que Cola S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/247464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14924, 956, 'Vai Que Cola S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/247465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14925, 956, 'Vai Que Cola S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/247466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14926, 956, 'Vai Que Cola S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/247467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14927, 956, 'Vai Que Cola S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/247468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14928, 956, 'Vai Que Cola S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/247469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14929, 956, 'Vai Que Cola S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/247470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14930, 956, 'Vai Que Cola S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/247471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14931, 956, 'Vai Que Cola S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/247472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14932, 956, 'Vai Que Cola S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/247473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14933, 956, 'Vai Que Cola S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/247474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14934, 956, 'Vai Que Cola S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/247475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14935, 956, 'Vai Que Cola S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/247476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14936, 956, 'Vai Que Cola S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/247477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14937, 956, 'Vai Que Cola S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/247478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14938, 956, 'Vai Que Cola S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/247479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14939, 956, 'Vai Que Cola S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/247480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14940, 956, 'Vai Que Cola S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/247481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14941, 956, 'Vai Que Cola S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/247482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14942, 956, 'Vai Que Cola S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/247483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14943, 956, 'Vai Que Cola S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/247484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14944, 956, 'Vai Que Cola S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/247485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14945, 956, 'Vai Que Cola S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/247486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14946, 956, 'Vai Que Cola S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/247487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14947, 956, 'Vai Que Cola S04 E40', 'http://sinalprivado.info:80/series/1533784/1533784/247488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14948, 957, 'Vai Que Cola S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14949, 957, 'Vai Que Cola S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14950, 957, 'Vai Que Cola S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14951, 957, 'Vai Que Cola S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14952, 957, 'Vai Que Cola S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14953, 957, 'Vai Que Cola S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14954, 957, 'Vai Que Cola S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14955, 957, 'Vai Que Cola S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14956, 957, 'Vai Que Cola S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14957, 957, 'Vai Que Cola S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14958, 957, 'Vai Que Cola S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14959, 957, 'Vai Que Cola S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14960, 957, 'Vai Que Cola S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14961, 957, 'Vai Que Cola S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/247502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14962, 957, 'Vai Que Cola S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/247503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14963, 957, 'Vai Que Cola S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/247504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14964, 957, 'Vai Que Cola S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/247505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14965, 957, 'Vai Que Cola S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/247506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14966, 957, 'Vai Que Cola S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/247507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14967, 957, 'Vai Que Cola S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/247508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14968, 957, 'Vai Que Cola S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/247509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14969, 957, 'Vai Que Cola S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/247510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14970, 957, 'Vai Que Cola S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/247511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14971, 957, 'Vai Que Cola S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/247512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14972, 957, 'Vai Que Cola S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/247513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14973, 957, 'Vai Que Cola S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/247514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14974, 957, 'Vai Que Cola S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/247515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14975, 957, 'Vai Que Cola S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/247516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14976, 957, 'Vai Que Cola S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/247517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14977, 957, 'Vai Que Cola S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/247518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14978, 957, 'Vai Que Cola S05 E31', 'http://sinalprivado.info:80/series/1533784/1533784/247519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14979, 957, 'Vai Que Cola S05 E32', 'http://sinalprivado.info:80/series/1533784/1533784/247520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14980, 957, 'Vai Que Cola S05 E33', 'http://sinalprivado.info:80/series/1533784/1533784/247521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14981, 957, 'Vai Que Cola S05 E34', 'http://sinalprivado.info:80/series/1533784/1533784/247522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14982, 957, 'Vai Que Cola S05 E35', 'http://sinalprivado.info:80/series/1533784/1533784/247523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14983, 957, 'Vai Que Cola S05 E36', 'http://sinalprivado.info:80/series/1533784/1533784/247524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14984, 957, 'Vai Que Cola S05 E37', 'http://sinalprivado.info:80/series/1533784/1533784/247525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14985, 957, 'Vai Que Cola S05 E38', 'http://sinalprivado.info:80/series/1533784/1533784/247526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14986, 957, 'Vai Que Cola S05 E39', 'http://sinalprivado.info:80/series/1533784/1533784/247527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14987, 957, 'Vai Que Cola S05 E40', 'http://sinalprivado.info:80/series/1533784/1533784/247528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14988, 958, 'Vai Que Cola S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14989, 958, 'Vai Que Cola S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14990, 958, 'Vai Que Cola S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14991, 958, 'Vai Que Cola S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14992, 958, 'Vai Que Cola S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14993, 958, 'Vai Que Cola S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14994, 958, 'Vai Que Cola S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14995, 958, 'Vai Que Cola S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14996, 958, 'Vai Que Cola S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14997, 958, 'Vai Que Cola S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14998, 958, 'Vai Que Cola S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(14999, 958, 'Vai Que Cola S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15000, 958, 'Vai Que Cola S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15001, 958, 'Vai Que Cola S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/247542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15002, 958, 'Vai Que Cola S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/247543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15003, 958, 'Vai Que Cola S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/247544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15004, 958, 'Vai Que Cola S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/247545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15005, 958, 'Vai Que Cola S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/247546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15006, 958, 'Vai Que Cola S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/247547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15007, 958, 'Vai Que Cola S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/247548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15008, 958, 'Vai Que Cola S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/247549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15009, 958, 'Vai Que Cola S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/247550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15010, 958, 'Vai Que Cola S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/247551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15011, 958, 'Vai Que Cola S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/247552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15012, 958, 'Vai Que Cola S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/247553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15013, 958, 'Vai Que Cola S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/247554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15014, 958, 'Vai Que Cola S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/247555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15015, 958, 'Vai Que Cola S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/247556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15016, 958, 'Vai Que Cola S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/247557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15017, 958, 'Vai Que Cola S06 E30', 'http://sinalprivado.info:80/series/1533784/1533784/247558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15018, 958, 'Vai Que Cola S06 E31', 'http://sinalprivado.info:80/series/1533784/1533784/247559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15019, 958, 'Vai Que Cola S06 E32', 'http://sinalprivado.info:80/series/1533784/1533784/247560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15020, 958, 'Vai Que Cola S06 E33', 'http://sinalprivado.info:80/series/1533784/1533784/247561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15021, 958, 'Vai Que Cola S06 E34', 'http://sinalprivado.info:80/series/1533784/1533784/247562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15022, 958, 'Vai Que Cola S06 E35', 'http://sinalprivado.info:80/series/1533784/1533784/247563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15023, 958, 'Vai Que Cola S06 E36', 'http://sinalprivado.info:80/series/1533784/1533784/247564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15024, 958, 'Vai Que Cola S06 E37', 'http://sinalprivado.info:80/series/1533784/1533784/247565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15025, 958, 'Vai Que Cola S06 E38', 'http://sinalprivado.info:80/series/1533784/1533784/247566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15026, 958, 'Vai Que Cola S06 E39', 'http://sinalprivado.info:80/series/1533784/1533784/247567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15027, 958, 'Vai Que Cola S06 E40', 'http://sinalprivado.info:80/series/1533784/1533784/247568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15028, 959, 'Vai Que Cola S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15029, 959, 'Vai Que Cola S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15030, 959, 'Vai Que Cola S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15031, 959, 'Vai Que Cola S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15032, 959, 'Vai Que Cola S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15033, 959, 'Vai Que Cola S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15034, 959, 'Vai Que Cola S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15035, 959, 'Vai Que Cola S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15036, 959, 'Vai Que Cola S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15037, 959, 'Vai Que Cola S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15038, 959, 'Vai Que Cola S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15039, 959, 'Vai Que Cola S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15040, 959, 'Vai Que Cola S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15041, 959, 'Vai Que Cola S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/247582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15042, 959, 'Vai Que Cola S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/247583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15043, 959, 'Vai Que Cola S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/247584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15044, 959, 'Vai Que Cola S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/247585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15045, 959, 'Vai Que Cola S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/247586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15046, 959, 'Vai Que Cola S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/247587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15047, 959, 'Vai Que Cola S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/247588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15048, 959, 'Vai Que Cola S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/247589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15049, 959, 'Vai Que Cola S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/247590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15050, 959, 'Vai Que Cola S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/247591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15051, 959, 'Vai Que Cola S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/247592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15052, 959, 'Vai Que Cola S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/247593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15053, 959, 'Vai Que Cola S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/247594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15054, 959, 'Vai Que Cola S07 E27', 'http://sinalprivado.info:80/series/1533784/1533784/247595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15055, 959, 'Vai Que Cola S07 E28', 'http://sinalprivado.info:80/series/1533784/1533784/247596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15056, 959, 'Vai Que Cola S07 E29', 'http://sinalprivado.info:80/series/1533784/1533784/247597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15057, 959, 'Vai Que Cola S07 E30', 'http://sinalprivado.info:80/series/1533784/1533784/247598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15058, 959, 'Vai Que Cola S07 E31', 'http://sinalprivado.info:80/series/1533784/1533784/247599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15059, 959, 'Vai Que Cola S07 E32', 'http://sinalprivado.info:80/series/1533784/1533784/247600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15060, 959, 'Vai Que Cola S07 E33', 'http://sinalprivado.info:80/series/1533784/1533784/247601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15061, 959, 'Vai Que Cola S07 E34', 'http://sinalprivado.info:80/series/1533784/1533784/247602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15062, 959, 'Vai Que Cola S07 E35', 'http://sinalprivado.info:80/series/1533784/1533784/247603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15063, 959, 'Vai Que Cola S07 E36', 'http://sinalprivado.info:80/series/1533784/1533784/247604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15064, 959, 'Vai Que Cola S07 E37', 'http://sinalprivado.info:80/series/1533784/1533784/247605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15065, 959, 'Vai Que Cola S07 E38', 'http://sinalprivado.info:80/series/1533784/1533784/247606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15066, 959, 'Vai Que Cola S07 E39', 'http://sinalprivado.info:80/series/1533784/1533784/247607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15067, 959, 'Vai Que Cola S07 E40', 'http://sinalprivado.info:80/series/1533784/1533784/247608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15068, 960, 'Vai Que Cola S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15069, 960, 'Vai Que Cola S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15070, 960, 'Vai Que Cola S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15071, 960, 'Vai Que Cola S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15072, 960, 'Vai Que Cola S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15073, 960, 'Vai Que Cola S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15074, 960, 'Vai Que Cola S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15075, 960, 'Vai Que Cola S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15076, 960, 'Vai Que Cola S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15077, 960, 'Vai Que Cola S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15078, 960, 'Vai Que Cola S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15079, 960, 'Vai Que Cola S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15080, 960, 'Vai Que Cola S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15081, 960, 'Vai Que Cola S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/247622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15082, 960, 'Vai Que Cola S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/247623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15083, 960, 'Vai Que Cola S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/247624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15084, 960, 'Vai Que Cola S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/247625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15085, 960, 'Vai Que Cola S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/247626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15086, 960, 'Vai Que Cola S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/247627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15087, 960, 'Vai Que Cola S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/247628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15088, 960, 'Vai Que Cola S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/247629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15089, 960, 'Vai Que Cola S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/247630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15090, 960, 'Vai Que Cola S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/247631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15091, 960, 'Vai Que Cola S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/247632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15092, 960, 'Vai Que Cola S08 E25', 'http://sinalprivado.info:80/series/1533784/1533784/247633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15093, 960, 'Vai Que Cola S08 E26', 'http://sinalprivado.info:80/series/1533784/1533784/247634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15094, 960, 'Vai Que Cola S08 E27', 'http://sinalprivado.info:80/series/1533784/1533784/247635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15095, 960, 'Vai Que Cola S08 E28', 'http://sinalprivado.info:80/series/1533784/1533784/247636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15096, 960, 'Vai Que Cola S08 E29', 'http://sinalprivado.info:80/series/1533784/1533784/247637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15097, 960, 'Vai Que Cola S08 E30', 'http://sinalprivado.info:80/series/1533784/1533784/247638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15098, 960, 'Vai Que Cola S08 E31', 'http://sinalprivado.info:80/series/1533784/1533784/247639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15099, 960, 'Vai Que Cola S08 E32', 'http://sinalprivado.info:80/series/1533784/1533784/247640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15100, 960, 'Vai Que Cola S08 E33', 'http://sinalprivado.info:80/series/1533784/1533784/247641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15101, 960, 'Vai Que Cola S08 E34', 'http://sinalprivado.info:80/series/1533784/1533784/247642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15102, 960, 'Vai Que Cola S08 E35', 'http://sinalprivado.info:80/series/1533784/1533784/247643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15103, 960, 'Vai Que Cola S08 E36', 'http://sinalprivado.info:80/series/1533784/1533784/247644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15104, 960, 'Vai Que Cola S08 E37', 'http://sinalprivado.info:80/series/1533784/1533784/247645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15105, 960, 'Vai Que Cola S08 E38', 'http://sinalprivado.info:80/series/1533784/1533784/247646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15106, 960, 'Vai Que Cola S08 E39', 'http://sinalprivado.info:80/series/1533784/1533784/247647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15107, 960, 'Vai Que Cola S08 E40', 'http://sinalprivado.info:80/series/1533784/1533784/247648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15108, 961, 'Vai Que Cola S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15109, 961, 'Vai Que Cola S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15110, 961, 'Vai Que Cola S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15111, 961, 'Vai Que Cola S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15112, 961, 'Vai Que Cola S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15113, 961, 'Vai Que Cola S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/629722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15114, 961, 'Vai Que Cola S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15115, 961, 'Vai Que Cola S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15116, 961, 'Vai Que Cola S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15117, 961, 'Vai Que Cola S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15118, 961, 'Vai Que Cola S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15119, 961, 'Vai Que Cola S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15120, 961, 'Vai Que Cola S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15121, 961, 'Vai Que Cola S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/247663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15122, 961, 'Vai Que Cola S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/247664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15123, 961, 'Vai Que Cola S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/247665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15124, 961, 'Vai Que Cola S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/247666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15125, 961, 'Vai Que Cola S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/247667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15126, 961, 'Vai Que Cola S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/247668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15127, 961, 'Vai Que Cola S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/247669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15128, 961, 'Vai Que Cola S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/247670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15129, 961, 'Vai Que Cola S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/247671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15130, 961, 'Vai Que Cola S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/247672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15131, 961, 'Vai Que Cola S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/247673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15132, 961, 'Vai Que Cola S09 E25', 'http://sinalprivado.info:80/series/1533784/1533784/247674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15133, 961, 'Vai Que Cola S09 E26', 'http://sinalprivado.info:80/series/1533784/1533784/247675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15134, 961, 'Vai Que Cola S09 E27', 'http://sinalprivado.info:80/series/1533784/1533784/247676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15135, 961, 'Vai Que Cola S09 E28', 'http://sinalprivado.info:80/series/1533784/1533784/247677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15136, 961, 'Vai Que Cola S09 E29', 'http://sinalprivado.info:80/series/1533784/1533784/247678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15137, 961, 'Vai Que Cola S09 E30', 'http://sinalprivado.info:80/series/1533784/1533784/247679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15138, 961, 'Vai Que Cola S09 E31', 'http://sinalprivado.info:80/series/1533784/1533784/247680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15139, 961, 'Vai Que Cola S09 E32', 'http://sinalprivado.info:80/series/1533784/1533784/247681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15140, 961, 'Vai Que Cola S09 E33', 'http://sinalprivado.info:80/series/1533784/1533784/247682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15141, 961, 'Vai Que Cola S09 E34', 'http://sinalprivado.info:80/series/1533784/1533784/247683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15142, 961, 'Vai Que Cola S09 E35', 'http://sinalprivado.info:80/series/1533784/1533784/247684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15143, 961, 'Vai Que Cola S09 E36', 'http://sinalprivado.info:80/series/1533784/1533784/247685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15144, 961, 'Vai Que Cola S09 E37', 'http://sinalprivado.info:80/series/1533784/1533784/247686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15145, 961, 'Vai Que Cola S09 E38', 'http://sinalprivado.info:80/series/1533784/1533784/247687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15146, 961, 'Vai Que Cola S09 E39', 'http://sinalprivado.info:80/series/1533784/1533784/247688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15147, 961, 'Vai Que Cola S09 E40', 'http://sinalprivado.info:80/series/1533784/1533784/247689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15148, 962, 'Vai Que Cola S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15149, 962, 'Vai Que Cola S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15150, 962, 'Vai Que Cola S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15151, 962, 'Vai Que Cola S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15152, 962, 'Vai Que Cola S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15153, 962, 'Vai Que Cola S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15154, 962, 'Vai Que Cola S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15155, 962, 'Vai Que Cola S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15156, 962, 'Vai Que Cola S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15157, 962, 'Vai Que Cola S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15158, 962, 'Vai Que Cola S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15159, 962, 'Vai Que Cola S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15160, 962, 'Vai Que Cola S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15161, 962, 'Vai Que Cola S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/247703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15162, 962, 'Vai Que Cola S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/247704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15163, 962, 'Vai Que Cola S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/247705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15164, 962, 'Vai Que Cola S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/247706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15165, 962, 'Vai Que Cola S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/247707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15166, 962, 'Vai Que Cola S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/247708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15167, 962, 'Vai Que Cola S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/247709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15168, 962, 'Vai Que Cola S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/247710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15169, 962, 'Vai Que Cola S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/247711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15170, 962, 'Vai Que Cola S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/247712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15171, 962, 'Vai Que Cola S10 E24', 'http://sinalprivado.info:80/series/1533784/1533784/247713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15172, 962, 'Vai Que Cola S10 E25', 'http://sinalprivado.info:80/series/1533784/1533784/247714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15173, 962, 'Vai Que Cola S10 E26', 'http://sinalprivado.info:80/series/1533784/1533784/247715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15174, 962, 'Vai Que Cola S10 E27', 'http://sinalprivado.info:80/series/1533784/1533784/247716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15175, 962, 'Vai Que Cola S10 E28', 'http://sinalprivado.info:80/series/1533784/1533784/247717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15176, 962, 'Vai Que Cola S10 E29', 'http://sinalprivado.info:80/series/1533784/1533784/247718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15177, 962, 'Vai Que Cola S10 E30', 'http://sinalprivado.info:80/series/1533784/1533784/247719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15178, 962, 'Vai Que Cola S10 E31', 'http://sinalprivado.info:80/series/1533784/1533784/247720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15179, 962, 'Vai Que Cola S10 E32', 'http://sinalprivado.info:80/series/1533784/1533784/247721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15180, 962, 'Vai Que Cola S10 E33', 'http://sinalprivado.info:80/series/1533784/1533784/247722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15181, 962, 'Vai Que Cola S10 E34', 'http://sinalprivado.info:80/series/1533784/1533784/247723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15182, 962, 'Vai Que Cola S10 E35', 'http://sinalprivado.info:80/series/1533784/1533784/247724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15183, 962, 'Vai Que Cola S10 E36', 'http://sinalprivado.info:80/series/1533784/1533784/247725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15184, 962, 'Vai Que Cola S10 E37', 'http://sinalprivado.info:80/series/1533784/1533784/247726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15185, 962, 'Vai Que Cola S10 E38', 'http://sinalprivado.info:80/series/1533784/1533784/247727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15186, 962, 'Vai Que Cola S10 E39', 'http://sinalprivado.info:80/series/1533784/1533784/247728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15187, 962, 'Vai Que Cola S10 E40', 'http://sinalprivado.info:80/series/1533784/1533784/247729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15188, 963, 'Vai Que Cola S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15189, 963, 'Vai Que Cola S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/629799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15190, 963, 'Vai Que Cola S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15191, 963, 'Vai Que Cola S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(15192, 963, 'Vai Que Cola S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15193, 963, 'Vai Que Cola S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15194, 963, 'Vai Que Cola S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15195, 963, 'Vai Que Cola S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15196, 963, 'Vai Que Cola S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15197, 963, 'Vai Que Cola S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15198, 963, 'Vai Que Cola S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15199, 963, 'Vai Que Cola S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15200, 963, 'Vai Que Cola S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15201, 963, 'Vai Que Cola S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/247744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15202, 963, 'Vai Que Cola S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/247745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15203, 963, 'Vai Que Cola S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/247746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15204, 963, 'Vai Que Cola S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/247747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15205, 963, 'Vai Que Cola S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/247748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15206, 963, 'Vai Que Cola S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/247749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15207, 963, 'Vai Que Cola S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/247750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15208, 963, 'Vai Que Cola S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/247751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15209, 963, 'Vai Que Cola S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/247752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15210, 963, 'Vai Que Cola S11 E23', 'http://sinalprivado.info:80/series/1533784/1533784/247753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15211, 963, 'Vai Que Cola S11 E24', 'http://sinalprivado.info:80/series/1533784/1533784/247754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15212, 963, 'Vai Que Cola S11 E25', 'http://sinalprivado.info:80/series/1533784/1533784/247755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15213, 963, 'Vai Que Cola S11 E26', 'http://sinalprivado.info:80/series/1533784/1533784/247756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15214, 963, 'Vai Que Cola S11 E27', 'http://sinalprivado.info:80/series/1533784/1533784/247757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15215, 963, 'Vai Que Cola S11 E28', 'http://sinalprivado.info:80/series/1533784/1533784/247758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15216, 963, 'Vai Que Cola S11 E29', 'http://sinalprivado.info:80/series/1533784/1533784/247759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15217, 963, 'Vai Que Cola S11 E30', 'http://sinalprivado.info:80/series/1533784/1533784/247760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15218, 963, 'Vai Que Cola S11 E31', 'http://sinalprivado.info:80/series/1533784/1533784/247761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15219, 963, 'Vai Que Cola S11 E32', 'http://sinalprivado.info:80/series/1533784/1533784/247762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15220, 963, 'Vai Que Cola S11 E33', 'http://sinalprivado.info:80/series/1533784/1533784/247763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15221, 963, 'Vai Que Cola S11 E34', 'http://sinalprivado.info:80/series/1533784/1533784/247764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15222, 963, 'Vai Que Cola S11 E35', 'http://sinalprivado.info:80/series/1533784/1533784/247765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15223, 963, 'Vai Que Cola S11 E36', 'http://sinalprivado.info:80/series/1533784/1533784/247766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15224, 963, 'Vai Que Cola S11 E37', 'http://sinalprivado.info:80/series/1533784/1533784/247767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15225, 963, 'Vai Que Cola S11 E38', 'http://sinalprivado.info:80/series/1533784/1533784/247768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15226, 963, 'Vai Que Cola S11 E39', 'http://sinalprivado.info:80/series/1533784/1533784/247769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15227, 963, 'Vai Que Cola S11 E40', 'http://sinalprivado.info:80/series/1533784/1533784/247770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15228, 964, 'Vai Que Cola S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/466176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15229, 964, 'Vai Que Cola S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/466177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15230, 964, 'Vai Que Cola S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/466178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15231, 964, 'Vai Que Cola S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/466179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15232, 964, 'Vai Que Cola S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/466180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15233, 964, 'Vai Que Cola S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/469024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15234, 964, 'Vai Que Cola S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/469025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15235, 964, 'Vai Que Cola S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/469026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15236, 964, 'Vai Que Cola S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/471678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15237, 964, 'Vai Que Cola S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/471679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15238, 964, 'Vai Que Cola S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/480347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15239, 964, 'Vai Que Cola S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/480348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15240, 964, 'Vai Que Cola S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/480349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15241, 964, 'Vai Que Cola S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/480350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15242, 964, 'Vai Que Cola S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/480351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15243, 964, 'Vai Que Cola S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/480352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15244, 964, 'Vai Que Cola S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/480353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15245, 964, 'Vai Que Cola S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/480354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15246, 964, 'Vai Que Cola S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/487960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15247, 964, 'Vai Que Cola S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/487961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15248, 964, 'Vai Que Cola S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/489911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15249, 964, 'Vai Que Cola S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/489912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15250, 964, 'Vai Que Cola S12 E23', 'http://sinalprivado.info:80/series/1533784/1533784/489913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15251, 964, 'Vai Que Cola S12 E24', 'http://sinalprivado.info:80/series/1533784/1533784/489914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15252, 964, 'Vai Que Cola S12 E25', 'http://sinalprivado.info:80/series/1533784/1533784/489915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15253, 964, 'Vai Que Cola S12 E26', 'http://sinalprivado.info:80/series/1533784/1533784/629864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15254, 964, 'Vai Que Cola S12 E27', 'http://sinalprivado.info:80/series/1533784/1533784/494862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15255, 964, 'Vai Que Cola S12 E28', 'http://sinalprivado.info:80/series/1533784/1533784/494863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15256, 964, 'Vai Que Cola S12 E29', 'http://sinalprivado.info:80/series/1533784/1533784/494864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15257, 964, 'Vai Que Cola S12 E30', 'http://sinalprivado.info:80/series/1533784/1533784/494865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15258, 964, 'Vai Que Cola S12 E31', 'http://sinalprivado.info:80/series/1533784/1533784/629869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15259, 964, 'Vai Que Cola S12 E32', 'http://sinalprivado.info:80/series/1533784/1533784/498765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15260, 964, 'Vai Que Cola S12 E33', 'http://sinalprivado.info:80/series/1533784/1533784/498766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15261, 964, 'Vai Que Cola S12 E34', 'http://sinalprivado.info:80/series/1533784/1533784/498767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15262, 964, 'Vai Que Cola S12 E35', 'http://sinalprivado.info:80/series/1533784/1533784/504494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15263, 964, 'Vai Que Cola S12 E36', 'http://sinalprivado.info:80/series/1533784/1533784/504495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15264, 964, 'Vai Que Cola S12 E37', 'http://sinalprivado.info:80/series/1533784/1533784/504496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15265, 964, 'Vai Que Cola S12 E38', 'http://sinalprivado.info:80/series/1533784/1533784/504497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15266, 964, 'Vai Que Cola S12 E39', 'http://sinalprivado.info:80/series/1533784/1533784/504498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15267, 964, 'Vai Que Cola S12 E40', 'http://sinalprivado.info:80/series/1533784/1533784/507490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15268, 965, 'Vai Que Cola S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/890634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15269, 965, 'Vai Que Cola S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/890635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15270, 965, 'Vai Que Cola S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/890993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15271, 965, 'Vai Que Cola S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/891812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15272, 965, 'Vai Que Cola S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/891813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15273, 965, 'Vai Que Cola S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/891814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15274, 965, 'Vai Que Cola S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/891815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15275, 965, 'Vai Que Cola S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/891988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15276, 965, 'Vai Que Cola S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/892186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15277, 965, 'Vai Que Cola S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/892405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15278, 965, 'Vai Que Cola S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/892406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15279, 965, 'Vai Que Cola S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/892407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15280, 965, 'Vai Que Cola S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/892408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15281, 965, 'Vai Que Cola S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/892599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15282, 965, 'Vai Que Cola S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/893046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15283, 965, 'Vai Que Cola S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/893047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15284, 965, 'Vai Que Cola S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/893048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15285, 965, 'Vai Que Cola S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/893331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15286, 965, 'Vai Que Cola S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/893332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15287, 965, 'Vai Que Cola S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/893438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zkzMxY964DsFMmS42pL1j4h4KyP.jpg'),
(15288, 966, 'Fear the Walking Dead S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250664.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15289, 966, 'Fear the Walking Dead S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250665.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15290, 966, 'Fear the Walking Dead S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250666.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15291, 966, 'Fear the Walking Dead S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250667.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15292, 966, 'Fear the Walking Dead S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250668.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15293, 966, 'Fear the Walking Dead S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250669.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15294, 967, 'Fear the Walking Dead S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250670.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15295, 967, 'Fear the Walking Dead S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250671.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15296, 967, 'Fear the Walking Dead S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250672.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15297, 967, 'Fear the Walking Dead S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250673.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15298, 967, 'Fear the Walking Dead S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250674.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15299, 967, 'Fear the Walking Dead S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250675.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15300, 967, 'Fear the Walking Dead S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250676.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15301, 967, 'Fear the Walking Dead S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250677.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15302, 967, 'Fear the Walking Dead S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250678.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15303, 967, 'Fear the Walking Dead S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250679.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15304, 967, 'Fear the Walking Dead S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250680.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15305, 967, 'Fear the Walking Dead S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250681.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15306, 967, 'Fear the Walking Dead S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250682.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15307, 967, 'Fear the Walking Dead S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250683.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15308, 967, 'Fear the Walking Dead S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250684.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15309, 968, 'Fear the Walking Dead S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250685.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15310, 968, 'Fear the Walking Dead S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250686.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15311, 968, 'Fear the Walking Dead S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250687.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15312, 968, 'Fear the Walking Dead S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250688.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15313, 968, 'Fear the Walking Dead S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250689.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15314, 968, 'Fear the Walking Dead S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250690.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15315, 968, 'Fear the Walking Dead S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250691.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15316, 968, 'Fear the Walking Dead S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250692.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15317, 968, 'Fear the Walking Dead S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250693.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15318, 968, 'Fear the Walking Dead S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250694.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15319, 968, 'Fear the Walking Dead S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250695.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15320, 968, 'Fear the Walking Dead S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250696.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15321, 968, 'Fear the Walking Dead S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250697.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15322, 968, 'Fear the Walking Dead S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250698.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15323, 968, 'Fear the Walking Dead S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250699.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15324, 968, 'Fear the Walking Dead S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250700.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15325, 969, 'Fear the Walking Dead S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250701.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15326, 969, 'Fear the Walking Dead S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250702.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15327, 969, 'Fear the Walking Dead S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250703.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15328, 969, 'Fear the Walking Dead S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250704.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15329, 969, 'Fear the Walking Dead S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250705.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15330, 969, 'Fear the Walking Dead S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250706.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15331, 969, 'Fear the Walking Dead S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250707.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15332, 969, 'Fear the Walking Dead S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250708.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15333, 969, 'Fear the Walking Dead S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250709.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15334, 969, 'Fear the Walking Dead S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250710.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15335, 969, 'Fear the Walking Dead S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250711.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15336, 969, 'Fear the Walking Dead S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250712.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15337, 969, 'Fear the Walking Dead S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250713.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15338, 969, 'Fear the Walking Dead S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250714.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15339, 969, 'Fear the Walking Dead S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250715.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15340, 969, 'Fear the Walking Dead S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250716.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15341, 970, 'Fear the Walking Dead S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250717.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15342, 970, 'Fear the Walking Dead S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250718.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15343, 970, 'Fear the Walking Dead S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250719.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15344, 970, 'Fear the Walking Dead S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250720.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15345, 970, 'Fear the Walking Dead S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250721.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15346, 970, 'Fear the Walking Dead S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250722.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15347, 970, 'Fear the Walking Dead S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250723.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15348, 970, 'Fear the Walking Dead S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250724.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15349, 970, 'Fear the Walking Dead S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250725.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15350, 970, 'Fear the Walking Dead S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250726.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15351, 970, 'Fear the Walking Dead S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250727.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15352, 970, 'Fear the Walking Dead S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250728.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15353, 970, 'Fear the Walking Dead S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250729.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15354, 970, 'Fear the Walking Dead S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250730.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15355, 970, 'Fear the Walking Dead S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250731.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15356, 970, 'Fear the Walking Dead S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250732.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15357, 971, 'Fear the Walking Dead S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250733.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15358, 971, 'Fear the Walking Dead S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250734.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15359, 971, 'Fear the Walking Dead S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250735.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15360, 971, 'Fear the Walking Dead S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250736.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15361, 971, 'Fear the Walking Dead S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250737.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15362, 971, 'Fear the Walking Dead S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250738.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15363, 971, 'Fear the Walking Dead S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250739.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15364, 971, 'Fear the Walking Dead S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250740.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15365, 971, 'Fear the Walking Dead S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250741.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15366, 971, 'Fear the Walking Dead S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250742.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15367, 971, 'Fear the Walking Dead S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250743.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15368, 971, 'Fear the Walking Dead S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250744.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15369, 971, 'Fear the Walking Dead S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250745.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15370, 971, 'Fear the Walking Dead S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250746.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15371, 971, 'Fear the Walking Dead S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250747.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15372, 971, 'Fear the Walking Dead S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250748.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15373, 972, 'Fear the Walking Dead S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9h7xP5eMAsSC9gwfeyy7KqBnk5H.jpg'),
(15374, 972, 'Fear the Walking Dead S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8innKhmvNGRIxkJ3u0XzLH7LbU7.jpg'),
(15375, 972, 'Fear the Walking Dead S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250751.mp4', 'http://image.tmdb.org/t/p/w1280/koxhjsltlLvrR1LY8aa58IzTcNO.jpg'),
(15376, 972, 'Fear the Walking Dead S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250752.mp4', 'http://image.tmdb.org/t/p/w1280/7Itwrz3Z501xQfXgkQVnO03DxYh.jpg'),
(15377, 972, 'Fear the Walking Dead S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZzOB6xDmkgwF4v7QtZaokXna8k.jpg'),
(15378, 972, 'Fear the Walking Dead S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4GIeh5hNtwfzpPUNmJL7vLjvSNN.jpg'),
(15379, 972, 'Fear the Walking Dead S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBfTXRfC8nwTx4jcTE6eOBHKCYc.jpg'),
(15380, 972, 'Fear the Walking Dead S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bu0l6eL2LP4uW5AdcwHaKH7kDoB.jpg'),
(15381, 972, 'Fear the Walking Dead S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250757.mp4', 'http://timg.bdta.pro/images/8aafe3a9d72ccff1f5d154a99c4f8f94.jpg'),
(15382, 972, 'Fear the Walking Dead S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250758.mp4', 'http://timg.bdta.pro/images/9cb0efec47e841817103c2d68137c2f1.jpg'),
(15383, 972, 'Fear the Walking Dead S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250759.mp4', 'http://timg.bdta.pro/images/001bc34cafb2f43f02d2f262ea35c51e.jpg'),
(15384, 972, 'Fear the Walking Dead S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250760.mp4', 'http://timg.bdta.pro/images/c36e75e5a216d748f3b305418db040b7.jpg'),
(15385, 972, 'Fear the Walking Dead S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250761.mp4', 'http://timg.bdta.pro/images/3111ac522f87b05856fd238e35685d81.jpg'),
(15386, 972, 'Fear the Walking Dead S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250762.mp4', 'http://timg.bdta.pro/images/74882ed8f4b375f7352621f972b73a04.jpg'),
(15387, 972, 'Fear the Walking Dead S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250763.mp4', 'http://timg.bdta.pro/images/a3af97ae658189c9bdbb3911e3a30484.jpg'),
(15388, 972, 'Fear the Walking Dead S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250764.mp4', 'http://timg.bdta.pro/images/cd65410fc4ce04f864f689912f9ca8f6.jpg'),
(15389, 973, 'Fear the Walking Dead S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250765.mp4', 'http://image.tmdb.org/t/p/w1280/uWYkksUdKJo3FybEKg2V9DWmOVO.jpg'),
(15390, 973, 'Fear the Walking Dead S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250766.mp4', 'http://image.tmdb.org/t/p/w1280/6AZnIGEny6czF47owayTuOgrLMy.jpg'),
(15391, 973, 'Fear the Walking Dead S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250767.mp4', 'http://image.tmdb.org/t/p/w1280/sNszAEdYUKP1EoPxppurGm2MqgZ.jpg'),
(15392, 973, 'Fear the Walking Dead S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250768.mp4', 'http://image.tmdb.org/t/p/w1280/zfgubuNO1QovsKN9aXMmH2AIxgG.jpg'),
(15393, 973, 'Fear the Walking Dead S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250769.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15394, 973, 'Fear the Walking Dead S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250770.mp4', 'http://image.tmdb.org/t/p/w1280/s2y5CVJBAWTLUzPnJUqrPxWFkDB.jpg'),
(15395, 973, 'Fear the Walking Dead S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250771.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15396, 973, 'Fear the Walking Dead S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250772.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15397, 973, 'Fear the Walking Dead S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250773.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15398, 973, 'Fear the Walking Dead S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250774.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15399, 973, 'Fear the Walking Dead S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250775.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15400, 973, 'Fear the Walking Dead S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250776.mp4', 'http://gstaticontent.com/images/tbgPaIEZa9BuKKESdyapOn0CZh6_big.jpg'),
(15401, 974, 'Dragon Ball Super S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15402, 974, 'Dragon Ball Super S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15403, 974, 'Dragon Ball Super S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15404, 974, 'Dragon Ball Super S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15405, 974, 'Dragon Ball Super S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15406, 974, 'Dragon Ball Super S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15407, 974, 'Dragon Ball Super S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15408, 974, 'Dragon Ball Super S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15409, 974, 'Dragon Ball Super S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15410, 974, 'Dragon Ball Super S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15411, 974, 'Dragon Ball Super S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15412, 974, 'Dragon Ball Super S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15413, 974, 'Dragon Ball Super S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/105269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15414, 974, 'Dragon Ball Super S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/105270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15415, 974, 'Dragon Ball Super S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/105271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15416, 974, 'Dragon Ball Super S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/105272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15417, 974, 'Dragon Ball Super S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/105273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15418, 974, 'Dragon Ball Super S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/105274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15419, 974, 'Dragon Ball Super S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/105275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15420, 974, 'Dragon Ball Super S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/105276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15421, 974, 'Dragon Ball Super S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/105277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15422, 974, 'Dragon Ball Super S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/105278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15423, 974, 'Dragon Ball Super S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/105279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15424, 974, 'Dragon Ball Super S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/105280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15425, 974, 'Dragon Ball Super S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/105281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15426, 974, 'Dragon Ball Super S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/105282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15427, 974, 'Dragon Ball Super S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/105283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15428, 974, 'Dragon Ball Super S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/105284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15429, 974, 'Dragon Ball Super S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/105285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15430, 974, 'Dragon Ball Super S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/105286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15431, 974, 'Dragon Ball Super S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/105287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15432, 974, 'Dragon Ball Super S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/105288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15433, 974, 'Dragon Ball Super S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/105289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15434, 974, 'Dragon Ball Super S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/105290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15435, 974, 'Dragon Ball Super S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/105291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15436, 974, 'Dragon Ball Super S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/105292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15437, 974, 'Dragon Ball Super S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/105293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15438, 974, 'Dragon Ball Super S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/105294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15439, 974, 'Dragon Ball Super S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/105295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15440, 974, 'Dragon Ball Super S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/105296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15441, 974, 'Dragon Ball Super S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/105297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15442, 974, 'Dragon Ball Super S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/105298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15443, 974, 'Dragon Ball Super S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/105299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15444, 974, 'Dragon Ball Super S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/105300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15445, 974, 'Dragon Ball Super S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/105301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15446, 974, 'Dragon Ball Super S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/105302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15447, 974, 'Dragon Ball Super S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/105303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15448, 974, 'Dragon Ball Super S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/105304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15449, 974, 'Dragon Ball Super S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/105305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15450, 974, 'Dragon Ball Super S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/105306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15451, 974, 'Dragon Ball Super S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/105307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15452, 974, 'Dragon Ball Super S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/105308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15453, 974, 'Dragon Ball Super S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/105309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15454, 974, 'Dragon Ball Super S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/105310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15455, 974, 'Dragon Ball Super S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/105311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15456, 974, 'Dragon Ball Super S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/105312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15457, 974, 'Dragon Ball Super S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/105313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15458, 974, 'Dragon Ball Super S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/105314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15459, 974, 'Dragon Ball Super S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/105315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15460, 974, 'Dragon Ball Super S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/105316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15461, 974, 'Dragon Ball Super S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/105317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(15462, 974, 'Dragon Ball Super S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/105318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15463, 974, 'Dragon Ball Super S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/105319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15464, 974, 'Dragon Ball Super S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/105320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15465, 974, 'Dragon Ball Super S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/105321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15466, 974, 'Dragon Ball Super S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/105322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15467, 974, 'Dragon Ball Super S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/105323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15468, 974, 'Dragon Ball Super S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/105324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15469, 974, 'Dragon Ball Super S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/105325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15470, 974, 'Dragon Ball Super S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/105326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15471, 974, 'Dragon Ball Super S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/105327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15472, 974, 'Dragon Ball Super S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/105328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15473, 974, 'Dragon Ball Super S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/105329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15474, 974, 'Dragon Ball Super S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/105330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15475, 974, 'Dragon Ball Super S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/105331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15476, 974, 'Dragon Ball Super S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/105332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15477, 974, 'Dragon Ball Super S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/105333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15478, 974, 'Dragon Ball Super S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/105334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15479, 974, 'Dragon Ball Super S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/105335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15480, 974, 'Dragon Ball Super S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/105336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15481, 974, 'Dragon Ball Super S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/105337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15482, 974, 'Dragon Ball Super S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/105338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15483, 974, 'Dragon Ball Super S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/105339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15484, 974, 'Dragon Ball Super S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/105340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15485, 974, 'Dragon Ball Super S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/105341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15486, 974, 'Dragon Ball Super S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/105342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15487, 974, 'Dragon Ball Super S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/105343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15488, 974, 'Dragon Ball Super S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/105344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15489, 974, 'Dragon Ball Super S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/105345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15490, 974, 'Dragon Ball Super S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/105346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15491, 974, 'Dragon Ball Super S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/105347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15492, 974, 'Dragon Ball Super S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/105348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15493, 974, 'Dragon Ball Super S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/105349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15494, 974, 'Dragon Ball Super S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/105350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15495, 974, 'Dragon Ball Super S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/105351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15496, 974, 'Dragon Ball Super S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/105352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15497, 974, 'Dragon Ball Super S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/105353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15498, 974, 'Dragon Ball Super S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/105354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15499, 974, 'Dragon Ball Super S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/105355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15500, 974, 'Dragon Ball Super S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/105356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15501, 974, 'Dragon Ball Super S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/105357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15502, 974, 'Dragon Ball Super S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/105358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15503, 974, 'Dragon Ball Super S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/105359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15504, 974, 'Dragon Ball Super S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/105360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15505, 974, 'Dragon Ball Super S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/105361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15506, 974, 'Dragon Ball Super S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/105362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15507, 974, 'Dragon Ball Super S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/105363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15508, 974, 'Dragon Ball Super S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/105364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15509, 974, 'Dragon Ball Super S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/105365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15510, 974, 'Dragon Ball Super S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/105366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15511, 974, 'Dragon Ball Super S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/105367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15512, 974, 'Dragon Ball Super S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/105368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15513, 974, 'Dragon Ball Super S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/105369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15514, 974, 'Dragon Ball Super S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/105370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15515, 974, 'Dragon Ball Super S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/105371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15516, 974, 'Dragon Ball Super S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/105372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15517, 974, 'Dragon Ball Super S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/105373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15518, 974, 'Dragon Ball Super S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/105374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15519, 974, 'Dragon Ball Super S01 E119', 'http://sinalprivado.info:80/series/1533784/1533784/105375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15520, 974, 'Dragon Ball Super S01 E120', 'http://sinalprivado.info:80/series/1533784/1533784/105376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15521, 974, 'Dragon Ball Super S01 E121', 'http://sinalprivado.info:80/series/1533784/1533784/105377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15522, 974, 'Dragon Ball Super S01 E122', 'http://sinalprivado.info:80/series/1533784/1533784/105378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15523, 974, 'Dragon Ball Super S01 E123', 'http://sinalprivado.info:80/series/1533784/1533784/105379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15524, 974, 'Dragon Ball Super S01 E124', 'http://sinalprivado.info:80/series/1533784/1533784/105380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15525, 974, 'Dragon Ball Super S01 E125', 'http://sinalprivado.info:80/series/1533784/1533784/105381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15526, 974, 'Dragon Ball Super S01 E126', 'http://sinalprivado.info:80/series/1533784/1533784/105382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15527, 974, 'Dragon Ball Super S01 E127', 'http://sinalprivado.info:80/series/1533784/1533784/105383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15528, 974, 'Dragon Ball Super S01 E128', 'http://sinalprivado.info:80/series/1533784/1533784/105384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15529, 974, 'Dragon Ball Super S01 E129', 'http://sinalprivado.info:80/series/1533784/1533784/105385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15530, 974, 'Dragon Ball Super S01 E130', 'http://sinalprivado.info:80/series/1533784/1533784/105386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15531, 974, 'Dragon Ball Super S01 E131', 'http://sinalprivado.info:80/series/1533784/1533784/105387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZH4rdTKEB1xWMt61oXL6SLXzZ.jpg'),
(15532, 975, 'Chernobyl S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlLXt2tOPT6RRnjiUmoxyG1LTFi.jpg'),
(15533, 975, 'Chernobyl S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlLXt2tOPT6RRnjiUmoxyG1LTFi.jpg'),
(15534, 975, 'Chernobyl S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlLXt2tOPT6RRnjiUmoxyG1LTFi.jpg'),
(15535, 975, 'Chernobyl S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlLXt2tOPT6RRnjiUmoxyG1LTFi.jpg'),
(15536, 975, 'Chernobyl S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlLXt2tOPT6RRnjiUmoxyG1LTFi.jpg'),
(15537, 976, 'Börü S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105251.mp4', 'http://gstaticontent.com/images/6xBjeBSzvhQhb97ln9PeodXxf6h_big.jpg'),
(15538, 976, 'Börü S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105252.mp4', 'http://gstaticontent.com/images/6xBjeBSzvhQhb97ln9PeodXxf6h_big.jpg'),
(15539, 976, 'Börü S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105253.mp4', 'http://gstaticontent.com/images/6xBjeBSzvhQhb97ln9PeodXxf6h_big.jpg'),
(15540, 976, 'Börü S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105254.mp4', 'http://gstaticontent.com/images/6xBjeBSzvhQhb97ln9PeodXxf6h_big.jpg'),
(15541, 976, 'Börü S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105255.mp4', 'http://gstaticontent.com/images/6xBjeBSzvhQhb97ln9PeodXxf6h_big.jpg'),
(15542, 976, 'Börü S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105256.mp4', 'http://gstaticontent.com/images/6xBjeBSzvhQhb97ln9PeodXxf6h_big.jpg'),
(15543, 977, 'Rick e Morty S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15544, 977, 'Rick e Morty S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15545, 977, 'Rick e Morty S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15546, 977, 'Rick e Morty S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15547, 977, 'Rick e Morty S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15548, 977, 'Rick e Morty S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15549, 977, 'Rick e Morty S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15550, 977, 'Rick e Morty S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15551, 977, 'Rick e Morty S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15552, 977, 'Rick e Morty S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15553, 977, 'Rick e Morty S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15554, 978, 'Rick e Morty S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15555, 978, 'Rick e Morty S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15556, 978, 'Rick e Morty S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15557, 978, 'Rick e Morty S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15558, 978, 'Rick e Morty S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15559, 978, 'Rick e Morty S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15560, 978, 'Rick e Morty S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15561, 978, 'Rick e Morty S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15562, 978, 'Rick e Morty S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15563, 978, 'Rick e Morty S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15564, 979, 'Rick e Morty S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15565, 979, 'Rick e Morty S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15566, 979, 'Rick e Morty S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15567, 979, 'Rick e Morty S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15568, 979, 'Rick e Morty S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15569, 979, 'Rick e Morty S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15570, 979, 'Rick e Morty S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15571, 979, 'Rick e Morty S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15572, 979, 'Rick e Morty S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15573, 979, 'Rick e Morty S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15574, 980, 'Rick e Morty S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253599.mp4', 'http://timg.bdta.pro/images/3d530e306b8c06be40b9a9cce9f21057.jpg'),
(15575, 980, 'Rick e Morty S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253600.mp4', 'http://timg.bdta.pro/images/a8254d9804172fba5a417942f375e027.jpg'),
(15576, 980, 'Rick e Morty S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253601.mp4', 'http://timg.bdta.pro/images/ba93c5f6a334a3c33ae650c4dc892096.jpg'),
(15577, 980, 'Rick e Morty S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253602.mp4', 'http://timg.bdta.pro/images/b09db0c692d2a48eefb4056b61def39c.jpg'),
(15578, 980, 'Rick e Morty S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253603.mp4', 'http://timg.bdta.pro/images/36d5d6432ef939fff293f22771008972.jpg'),
(15579, 980, 'Rick e Morty S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253604.mp4', 'http://timg.bdta.pro/images/59e3c9b7300bea284a0a55a8bdb4cac3.jpg'),
(15580, 980, 'Rick e Morty S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253605.mp4', 'http://timg.bdta.pro/images/7f7b0865257bc7cf9bb280b96c143c8a.jpg'),
(15581, 980, 'Rick e Morty S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253606.mp4', 'http://timg.bdta.pro/images/a07c2a79009038734c625c2848bdded9.jpg'),
(15582, 980, 'Rick e Morty S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253607.mp4', 'http://timg.bdta.pro/images/ac808cbf0d073e0a59a93f8b976be052.jpg'),
(15583, 980, 'Rick e Morty S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253608.mp4', 'http://timg.bdta.pro/images/fcd641c56165df08cada02224cd709fc.jpg'),
(15584, 981, 'Rick e Morty S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253609.mp4', 'http://timg.bdta.pro/images/a5ee0cf5ed86edd93bb7e88f3911b85a.jpg'),
(15585, 981, 'Rick e Morty S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253610.mp4', 'http://timg.bdta.pro/images/28d7c8a9ae12be201c81f99124bc7902.jpg'),
(15586, 981, 'Rick e Morty S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253611.mp4', 'http://timg.bdta.pro/images/792b549c84ecef86d18fd8f5aa82afcb.jpg'),
(15587, 981, 'Rick e Morty S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253612.mp4', 'http://timg.bdta.pro/images/44e727c06ca777fac12017c630c1f4ee.jpg'),
(15588, 981, 'Rick e Morty S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253613.mp4', 'http://timg.bdta.pro/images/3c24edb78bfcd7a56a61c8d75b11297c.jpg'),
(15589, 981, 'Rick e Morty S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253614.mp4', 'http://timg.bdta.pro/images/ed9e356170c95359b25163cdb1de925c.jpg'),
(15590, 981, 'Rick e Morty S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253615.mp4', 'http://timg.bdta.pro/images/ecaef6a6581ad8303f95f8c27a377883.jpg'),
(15591, 981, 'Rick e Morty S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253616.mp4', 'http://timg.bdta.pro/images/944df439f288ea20545ea93741b074a0.jpg'),
(15592, 981, 'Rick e Morty S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253617.mp4', 'http://timg.bdta.pro/images/28390f3086dc26324a3f36df086effcc.jpg'),
(15593, 981, 'Rick e Morty S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253618.mp4', 'http://timg.bdta.pro/images/a4899810081524bec346f6a0fe274449.jpg'),
(15594, 982, 'Rick e Morty S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253619.mp4', 'http://timg.bdta.pro/images/376a2cad3fef691a301e76b2e3d7fbd9.jpg'),
(15595, 982, 'Rick e Morty S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253620.mp4', 'http://timg.bdta.pro/images/ebd01e7b1192e953b12ef796085051a8.jpg'),
(15596, 982, 'Rick e Morty S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253621.mp4', 'http://timg.bdta.pro/images/56ddf360f2f8677291d10e831d017b4a.jpg'),
(15597, 982, 'Rick e Morty S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253622.mp4', 'http://timg.bdta.pro/images/60977a041ebbc17ff16b3b27842a4e92.jpg'),
(15598, 982, 'Rick e Morty S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253623.mp4', 'http://timg.bdta.pro/images/cea530ac4727d88f1ed16fe59e490745.jpg'),
(15599, 982, 'Rick e Morty S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253624.mp4', 'http://timg.bdta.pro/images/c691167d28df2595eef9721548aba150.jpg'),
(15600, 982, 'Rick e Morty S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m867icwqTcOVKMySh0ip96zWbeA.jpg'),
(15601, 982, 'Rick e Morty S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEz4PBtbs2TU0r4fq3gkZ01Mxl2.jpg'),
(15602, 982, 'Rick e Morty S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253627.mp4', 'http://image.tmdb.org/t/p/w1280/xiPSthi7ZF5xosfEqvAp6bl0sFu.jpg'),
(15603, 982, 'Rick e Morty S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253628.mp4', 'http://image.tmdb.org/t/p/w1280/i9DrzFapnE2LTBOlR0xD4pejHm3.jpg'),
(15604, 983, 'Rick e Morty S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15605, 983, 'Rick e Morty S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15606, 983, 'Rick e Morty S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15607, 983, 'Rick e Morty S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15608, 983, 'Rick e Morty S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15609, 983, 'Rick e Morty S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15610, 983, 'Rick e Morty S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15611, 983, 'Rick e Morty S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15612, 983, 'Rick e Morty S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15613, 983, 'Rick e Morty S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15614, 984, 'Rick e Morty S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/816835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15615, 984, 'Rick e Morty S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/820435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15616, 984, 'Rick e Morty S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/832910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15617, 984, 'Rick e Morty S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/841342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15618, 984, 'Rick e Morty S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/848512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15619, 984, 'Rick e Morty S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/859284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15620, 984, 'Rick e Morty S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/861889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15621, 984, 'Rick e Morty S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/868044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15622, 984, 'Rick e Morty S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/872303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15623, 984, 'Rick e Morty S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/877053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9OAC2sOt38Ni5NNu9tVXLcrAUyh.jpg'),
(15624, 985, 'Dilema S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z6c9jVlj6LKypp6KJn2TRA8Onyt.jpg'),
(15625, 985, 'Dilema S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z6c9jVlj6LKypp6KJn2TRA8Onyt.jpg'),
(15626, 985, 'Dilema S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z6c9jVlj6LKypp6KJn2TRA8Onyt.jpg'),
(15627, 985, 'Dilema S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z6c9jVlj6LKypp6KJn2TRA8Onyt.jpg'),
(15628, 985, 'Dilema S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z6c9jVlj6LKypp6KJn2TRA8Onyt.jpg'),
(15629, 985, 'Dilema S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z6c9jVlj6LKypp6KJn2TRA8Onyt.jpg'),
(15630, 985, 'Dilema S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z6c9jVlj6LKypp6KJn2TRA8Onyt.jpg'),
(15631, 985, 'Dilema S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z6c9jVlj6LKypp6KJn2TRA8Onyt.jpg'),
(15632, 985, 'Dilema S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z6c9jVlj6LKypp6KJn2TRA8Onyt.jpg'),
(15633, 985, 'Dilema S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z6c9jVlj6LKypp6KJn2TRA8Onyt.jpg'),
(15634, 986, 'Alto Mar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8fKWzuR3o8NZQ3xuaGHI7QUKeho.jpg'),
(15635, 986, 'Alto Mar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8fKWzuR3o8NZQ3xuaGHI7QUKeho.jpg'),
(15636, 986, 'Alto Mar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8fKWzuR3o8NZQ3xuaGHI7QUKeho.jpg'),
(15637, 986, 'Alto Mar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8fKWzuR3o8NZQ3xuaGHI7QUKeho.jpg'),
(15638, 986, 'Alto Mar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8fKWzuR3o8NZQ3xuaGHI7QUKeho.jpg'),
(15639, 986, 'Alto Mar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8fKWzuR3o8NZQ3xuaGHI7QUKeho.jpg'),
(15640, 986, 'Alto Mar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8fKWzuR3o8NZQ3xuaGHI7QUKeho.jpg'),
(15641, 986, 'Alto Mar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8fKWzuR3o8NZQ3xuaGHI7QUKeho.jpg'),
(15642, 987, 'Alto Mar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107318.mp4', 'http://timg.bdta.pro/images/53fe7185e2cc5d9399d998fdfb2c3043.jpg'),
(15643, 987, 'Alto Mar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107319.mp4', 'http://timg.bdta.pro/images/9453afac89e12b4d2670d83cd6169a7f.jpg'),
(15644, 987, 'Alto Mar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107320.mp4', 'http://timg.bdta.pro/images/83e7a05a3cfbfd8478d01a36d47e8fd8.jpg'),
(15645, 987, 'Alto Mar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107321.mp4', 'http://timg.bdta.pro/images/b1b177aa35d1fb9b47da0f2ccb38207d.jpg'),
(15646, 987, 'Alto Mar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107322.mp4', 'http://timg.bdta.pro/images/78ecc55bca0df5179bf4a135ded48be5.jpg'),
(15647, 987, 'Alto Mar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107323.mp4', 'http://timg.bdta.pro/images/0aa5f71cb748319702ad958b0914f4dc.jpg'),
(15648, 987, 'Alto Mar S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107324.mp4', 'http://timg.bdta.pro/images/6fe786218ef513a0b1700e000f275c11.jpg'),
(15649, 987, 'Alto Mar S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107325.mp4', 'http://timg.bdta.pro/images/72451ec7aeb884040eb0da2bf80a200a.jpg'),
(15650, 988, 'It\'s Bruno! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105209.mp4', 'http://gstaticontent.com/images/5T7QerajngWRWlNUrDg9hiruf9w_big.jpg'),
(15651, 988, 'It\'s Bruno! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105210.mp4', 'http://gstaticontent.com/images/5T7QerajngWRWlNUrDg9hiruf9w_big.jpg'),
(15652, 988, 'It\'s Bruno! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105211.mp4', 'http://gstaticontent.com/images/5T7QerajngWRWlNUrDg9hiruf9w_big.jpg'),
(15653, 988, 'It\'s Bruno! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105212.mp4', 'http://gstaticontent.com/images/5T7QerajngWRWlNUrDg9hiruf9w_big.jpg'),
(15654, 988, 'It\'s Bruno! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105213.mp4', 'http://gstaticontent.com/images/5T7QerajngWRWlNUrDg9hiruf9w_big.jpg'),
(15655, 988, 'It\'s Bruno! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105214.mp4', 'http://gstaticontent.com/images/5T7QerajngWRWlNUrDg9hiruf9w_big.jpg'),
(15656, 988, 'It\'s Bruno! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105215.mp4', 'http://gstaticontent.com/images/5T7QerajngWRWlNUrDg9hiruf9w_big.jpg'),
(15657, 988, 'It\'s Bruno! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105216.mp4', 'http://gstaticontent.com/images/5T7QerajngWRWlNUrDg9hiruf9w_big.jpg'),
(15658, 989, 'The Passage S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105038.mp4', 'http://gstaticontent.com/images/aquYKS9cFzmULgV6mSnS2RPjxdp_big.jpg'),
(15659, 989, 'The Passage S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105039.mp4', 'http://gstaticontent.com/images/aquYKS9cFzmULgV6mSnS2RPjxdp_big.jpg'),
(15660, 989, 'The Passage S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105040.mp4', 'http://gstaticontent.com/images/aquYKS9cFzmULgV6mSnS2RPjxdp_big.jpg'),
(15661, 989, 'The Passage S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105041.mp4', 'http://gstaticontent.com/images/aquYKS9cFzmULgV6mSnS2RPjxdp_big.jpg'),
(15662, 989, 'The Passage S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105042.mp4', 'http://gstaticontent.com/images/aquYKS9cFzmULgV6mSnS2RPjxdp_big.jpg'),
(15663, 989, 'The Passage S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105043.mp4', 'http://gstaticontent.com/images/aquYKS9cFzmULgV6mSnS2RPjxdp_big.jpg'),
(15664, 989, 'The Passage S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105044.mp4', 'http://gstaticontent.com/images/aquYKS9cFzmULgV6mSnS2RPjxdp_big.jpg'),
(15665, 989, 'The Passage S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105045.mp4', 'http://gstaticontent.com/images/aquYKS9cFzmULgV6mSnS2RPjxdp_big.jpg'),
(15666, 989, 'The Passage S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105046.mp4', 'http://gstaticontent.com/images/aquYKS9cFzmULgV6mSnS2RPjxdp_big.jpg'),
(15667, 989, 'The Passage S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105047.mp4', 'http://gstaticontent.com/images/aquYKS9cFzmULgV6mSnS2RPjxdp_big.jpg'),
(15668, 990, 'Belas Maldições S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/thOMZPH5oBQ0bqknc9jGHw7Izbv.jpg'),
(15669, 990, 'Belas Maldições S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/thOMZPH5oBQ0bqknc9jGHw7Izbv.jpg'),
(15670, 990, 'Belas Maldições S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/thOMZPH5oBQ0bqknc9jGHw7Izbv.jpg'),
(15671, 990, 'Belas Maldições S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/thOMZPH5oBQ0bqknc9jGHw7Izbv.jpg'),
(15672, 990, 'Belas Maldições S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/thOMZPH5oBQ0bqknc9jGHw7Izbv.jpg'),
(15673, 990, 'Belas Maldições S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/thOMZPH5oBQ0bqknc9jGHw7Izbv.jpg'),
(15674, 991, 'Belas Maldições S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e4co8S5FzoNKVvvIZZRevdS5gWU.jpg'),
(15675, 991, 'Belas Maldições S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sIH60OisSu5IHeO6H89KJoloBKD.jpg'),
(15676, 991, 'Belas Maldições S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aje98UWC6CJWTJ9wuGjJj9Szhgd.jpg'),
(15677, 991, 'Belas Maldições S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wkLzmGsQLKXSmAepjMzlanaSRHp.jpg'),
(15678, 991, 'Belas Maldições S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qY4If1b9zxiAKOxcf6M0z6ZF6Y1.jpg'),
(15679, 991, 'Belas Maldições S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ncbzsXMLhSfx0YflISmKIbCzVp5.jpg'),
(15680, 992, 'FBI S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15681, 992, 'FBI S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15682, 992, 'FBI S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15683, 992, 'FBI S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15684, 992, 'FBI S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15685, 992, 'FBI S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15686, 992, 'FBI S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15687, 992, 'FBI S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15688, 992, 'FBI S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15689, 992, 'FBI S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15690, 992, 'FBI S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15691, 992, 'FBI S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15692, 992, 'FBI S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15693, 992, 'FBI S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15694, 992, 'FBI S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15695, 992, 'FBI S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15696, 992, 'FBI S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15697, 992, 'FBI S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15698, 992, 'FBI S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15699, 992, 'FBI S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15700, 992, 'FBI S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15701, 992, 'FBI S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15702, 993, 'FBI S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15703, 993, 'FBI S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15704, 993, 'FBI S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15705, 993, 'FBI S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15706, 993, 'FBI S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15707, 993, 'FBI S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15708, 993, 'FBI S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15709, 993, 'FBI S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15710, 993, 'FBI S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15711, 993, 'FBI S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15712, 993, 'FBI S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15713, 993, 'FBI S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15714, 993, 'FBI S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15715, 993, 'FBI S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15716, 993, 'FBI S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15717, 993, 'FBI S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15718, 993, 'FBI S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15719, 993, 'FBI S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15720, 993, 'FBI S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15721, 994, 'FBI S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15722, 994, 'FBI S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15723, 994, 'FBI S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15724, 994, 'FBI S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15725, 994, 'FBI S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15726, 994, 'FBI S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15727, 994, 'FBI S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15728, 994, 'FBI S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15729, 994, 'FBI S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15730, 994, 'FBI S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15731, 994, 'FBI S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15732, 994, 'FBI S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15733, 994, 'FBI S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15734, 995, 'FBI S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224242.mp4', 'http://image.tmdb.org/t/p/w1280/1GCOme9j3PXXnsKlrJTPOXkZBs2.jpg'),
(15735, 995, 'FBI S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224243.mp4', 'http://timg.bdta.pro/images/a91949f0ea361f4eb2b716381ac521c4.jpg'),
(15736, 995, 'FBI S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224244.mp4', 'http://timg.bdta.pro/images/46a4f4abc7acb0c0da0e4bbb1f0bb6d0.jpg'),
(15737, 995, 'FBI S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224245.mp4', 'http://timg.bdta.pro/images/9a12633db6db2eb7113cf50cd3ef2a3d.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(15738, 995, 'FBI S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224246.mp4', 'http://timg.bdta.pro/images/0a283674b53bd135ec5dbc0530d98bdc.jpg'),
(15739, 995, 'FBI S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224247.mp4', 'http://timg.bdta.pro/images/df1385524938e5dfd83b50037396d425.jpg'),
(15740, 995, 'FBI S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224248.mp4', 'http://timg.bdta.pro/images/1d52094cbd7ed653d5f40dc8c3e68798.jpg'),
(15741, 995, 'FBI S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224249.mp4', 'http://timg.bdta.pro/images/9a87392295cf59fbd550b974faef3e88.jpg'),
(15742, 995, 'FBI S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15743, 995, 'FBI S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224251.mp4', 'http://timg.bdta.pro/images/d7dff849982f44a6a7a65a64f8f2b3d3.jpg'),
(15744, 995, 'FBI S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224252.mp4', 'http://timg.bdta.pro/images/e35074a159e71f5aa91886d048a9bf77.jpg'),
(15745, 995, 'FBI S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224253.mp4', 'http://timg.bdta.pro/images/9fa9066ca02f806edbec62e227f3d15f.jpg'),
(15746, 995, 'FBI S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224254.mp4', 'http://timg.bdta.pro/images/ab41745e36410d5dfacfa3225368b4d5.jpg'),
(15747, 995, 'FBI S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224255.mp4', 'http://timg.bdta.pro/images/7b3f7e6be313f95dc3f6a6d6df9e6130.jpg'),
(15748, 995, 'FBI S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224256.mp4', 'http://timg.bdta.pro/images/943151b716d7b5a353e269fe22c3c7ee.jpg'),
(15749, 995, 'FBI S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224257.mp4', 'http://timg.bdta.pro/images/d8299e1acb1a5f948e37edcfa9036e7a.jpg'),
(15750, 995, 'FBI S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224258.mp4', 'http://timg.bdta.pro/images/d5499813b3e4cf093ef04002f15bdb98.jpg'),
(15751, 995, 'FBI S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224259.mp4', 'http://timg.bdta.pro/images/30365fd88656b7525b082d7e40111b54.jpg'),
(15752, 995, 'FBI S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224260.mp4', 'http://timg.bdta.pro/images/027edee9ef78795890534966c8971608.jpg'),
(15753, 995, 'FBI S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224261.mp4', 'http://timg.bdta.pro/images/0c69cbeaa9a3f89252b109f5fabd0915.jpg'),
(15754, 995, 'FBI S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224262.mp4', 'http://timg.bdta.pro/images/09df16bc2dd3f4bf353ca69d3fbab6c8.jpg'),
(15755, 996, 'FBI S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224263.mp4', 'http://image.tmdb.org/t/p/w1280/4knxgyJ882BbMgWFU9O3jequrCi.jpg'),
(15756, 996, 'FBI S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224264.mp4', 'http://image.tmdb.org/t/p/w1280/yvvSSCrQKczmQkfjov6S8R7VydM.jpg'),
(15757, 996, 'FBI S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224265.mp4', 'http://image.tmdb.org/t/p/w1280/qX1eYZFkofQlhY2tv2hsociR0L3.jpg'),
(15758, 996, 'FBI S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224266.mp4', 'http://image.tmdb.org/t/p/w1280/lYwHSP54xcqipoMqmq17Q3MRMJG.jpg'),
(15759, 996, 'FBI S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224267.mp4', 'http://image.tmdb.org/t/p/w1280/fzmnHkjqERJTN2PMew9PC2WYJPH.jpg'),
(15760, 996, 'FBI S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224268.mp4', 'http://image.tmdb.org/t/p/w1280/2AqGghJUOBw0YKKpk1mRkGEJU9w.jpg'),
(15761, 996, 'FBI S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224269.mp4', 'http://image.tmdb.org/t/p/w1280/vQYh6KEhWd8bDm2UXfcXkebMR1n.jpg'),
(15762, 996, 'FBI S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224270.mp4', 'http://image.tmdb.org/t/p/w1280/ydUn3EvfG7BHHNRxN5Q1nhNwxJT.jpg'),
(15763, 996, 'FBI S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224271.mp4', 'http://image.tmdb.org/t/p/w1280/aZhixAJ9EaTpGFM9OHt1hqRwtkh.jpg'),
(15764, 996, 'FBI S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224272.mp4', 'http://image.tmdb.org/t/p/w1280/7xanzxOyQCW8A1v8FNjYqkPKl4j.jpg'),
(15765, 996, 'FBI S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224273.mp4', 'http://image.tmdb.org/t/p/w1280/ggplXtiaCaG3YYLr7U2vVHipdf4.jpg'),
(15766, 996, 'FBI S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224274.mp4', 'http://image.tmdb.org/t/p/w1280/5Vl6HTmuE6dEw4QmN46Yex2OsC3.jpg'),
(15767, 996, 'FBI S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224275.mp4', 'http://image.tmdb.org/t/p/w1280/xSiAowldVUDPTB7hsKhIiUFgX7E.jpg'),
(15768, 996, 'FBI S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224276.mp4', 'http://image.tmdb.org/t/p/w1280/5lNfcK9bIJxBnYJN59M0fQwJ2vh.jpg'),
(15769, 996, 'FBI S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224277.mp4', 'http://image.tmdb.org/t/p/w1280/xUO3VmBPiD10bGYjLG3wZzeG1a0.jpg'),
(15770, 996, 'FBI S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224278.mp4', 'http://image.tmdb.org/t/p/w1280/mXYr5z5kBRT1hQeuWDG65CgM0KR.jpg'),
(15771, 996, 'FBI S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224279.mp4', 'http://image.tmdb.org/t/p/w1280/wuvniu34Nez4qh1GufD1d2gqYjd.jpg'),
(15772, 996, 'FBI S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224280.mp4', 'http://image.tmdb.org/t/p/w1280/arL7lM3tNMch9iM0PFO0aeqKHhz.jpg'),
(15773, 996, 'FBI S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224281.mp4', 'http://image.tmdb.org/t/p/w1280/76APcyhd5RudNrW7Vo9JzRdVSWX.jpg'),
(15774, 996, 'FBI S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224282.mp4', 'http://image.tmdb.org/t/p/w1280/4zgaqiMJaeeCUdSRP3UWgHJPr7d.jpg'),
(15775, 996, 'FBI S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224283.mp4', 'http://image.tmdb.org/t/p/w1280/lqembmcm9ko3EAhMvwEM3wWrC0Y.jpg'),
(15776, 996, 'FBI S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224284.mp4', 'http://image.tmdb.org/t/p/w1280/6zAuxGjjPy1rf8vRvoKFrh8TnHr.jpg'),
(15777, 996, 'FBI S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/224285.mp4', 'http://image.tmdb.org/t/p/w1280/teLAUtXiJdr0ceR9aHbq2SZZs7J.jpg'),
(15778, 997, 'FBI S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/338761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15779, 997, 'FBI S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/338762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15780, 997, 'FBI S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/345477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15781, 997, 'FBI S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/356529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15782, 997, 'FBI S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/356530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15783, 997, 'FBI S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/363422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15784, 997, 'FBI S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/368847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15785, 997, 'FBI S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/384171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15786, 997, 'FBI S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/384172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15787, 997, 'FBI S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/384173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15788, 997, 'FBI S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/396944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15789, 997, 'FBI S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/403354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15790, 997, 'FBI S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/409093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15791, 998, 'FBI S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/662840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15792, 998, 'FBI S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15793, 998, 'FBI S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/677659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15794, 998, 'FBI S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/679650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15795, 998, 'FBI S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/687508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15796, 998, 'FBI S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/696034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15797, 998, 'FBI S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/701841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15798, 998, 'FBI S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/714821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15799, 998, 'FBI S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/718373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15800, 998, 'FBI S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/724760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15801, 998, 'FBI S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/731386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15802, 998, 'FBI S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/742590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15803, 998, 'FBI S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/767287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15804, 998, 'FBI S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/767288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15805, 998, 'FBI S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/795060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15806, 998, 'FBI S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/796217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15807, 998, 'FBI S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/801326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15808, 998, 'FBI S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/810125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15809, 998, 'FBI S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/822529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15810, 998, 'FBI S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/838275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15811, 998, 'FBI S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/847583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15812, 998, 'FBI S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/855047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGLQRv3MLWGrHMhRGn1zsSa9n2i.jpg'),
(15813, 999, 'Monstro do Pântano [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWv8T2WlSrmssqQ4egi9oE4g237.jpg'),
(15814, 999, 'Monstro do Pântano [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWv8T2WlSrmssqQ4egi9oE4g237.jpg'),
(15815, 999, 'Monstro do Pântano [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWv8T2WlSrmssqQ4egi9oE4g237.jpg'),
(15816, 999, 'Monstro do Pântano [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWv8T2WlSrmssqQ4egi9oE4g237.jpg'),
(15817, 999, 'Monstro do Pântano [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWv8T2WlSrmssqQ4egi9oE4g237.jpg'),
(15818, 999, 'Monstro do Pântano [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWv8T2WlSrmssqQ4egi9oE4g237.jpg'),
(15819, 999, 'Monstro do Pântano [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWv8T2WlSrmssqQ4egi9oE4g237.jpg'),
(15820, 999, 'Monstro do Pântano [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWv8T2WlSrmssqQ4egi9oE4g237.jpg'),
(15821, 999, 'Monstro do Pântano [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWv8T2WlSrmssqQ4egi9oE4g237.jpg'),
(15822, 999, 'Monstro do Pântano [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWv8T2WlSrmssqQ4egi9oE4g237.jpg'),
(15823, 1000, 'Bad Blood S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105024.mp4', 'http://gstaticontent.com/images/ukrAdTtJHHEaDRUJmi4XYwBUpRu_big.jpg'),
(15824, 1000, 'Bad Blood S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105025.mp4', 'http://gstaticontent.com/images/ukrAdTtJHHEaDRUJmi4XYwBUpRu_big.jpg'),
(15825, 1000, 'Bad Blood S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105026.mp4', 'http://gstaticontent.com/images/ukrAdTtJHHEaDRUJmi4XYwBUpRu_big.jpg'),
(15826, 1000, 'Bad Blood S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105027.mp4', 'http://gstaticontent.com/images/ukrAdTtJHHEaDRUJmi4XYwBUpRu_big.jpg'),
(15827, 1000, 'Bad Blood S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105028.mp4', 'http://gstaticontent.com/images/ukrAdTtJHHEaDRUJmi4XYwBUpRu_big.jpg'),
(15828, 1000, 'Bad Blood S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105029.mp4', 'http://gstaticontent.com/images/ukrAdTtJHHEaDRUJmi4XYwBUpRu_big.jpg'),
(15829, 1001, 'Bad Blood S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105030.mp4', 'http://gstaticontent.com/images/ukrAdTtJHHEaDRUJmi4XYwBUpRu_big.jpg'),
(15830, 1001, 'Bad Blood S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105031.mp4', 'http://gstaticontent.com/images/ukrAdTtJHHEaDRUJmi4XYwBUpRu_big.jpg'),
(15831, 1001, 'Bad Blood S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105032.mp4', 'http://gstaticontent.com/images/ukrAdTtJHHEaDRUJmi4XYwBUpRu_big.jpg'),
(15832, 1001, 'Bad Blood S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105033.mp4', 'http://gstaticontent.com/images/ukrAdTtJHHEaDRUJmi4XYwBUpRu_big.jpg'),
(15833, 1001, 'Bad Blood S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105034.mp4', 'http://gstaticontent.com/images/ukrAdTtJHHEaDRUJmi4XYwBUpRu_big.jpg'),
(15834, 1001, 'Bad Blood S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105035.mp4', 'http://gstaticontent.com/images/ukrAdTtJHHEaDRUJmi4XYwBUpRu_big.jpg'),
(15835, 1001, 'Bad Blood S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105036.mp4', 'http://gstaticontent.com/images/ukrAdTtJHHEaDRUJmi4XYwBUpRu_big.jpg'),
(15836, 1001, 'Bad Blood S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105037.mp4', 'http://gstaticontent.com/images/ukrAdTtJHHEaDRUJmi4XYwBUpRu_big.jpg'),
(15837, 1002, 'Bandidos na TV S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105017.mp4', 'http://gstaticontent.com/images/b5cnl6p3xTpHlDWVXhi9isf4yMd_big.jpg'),
(15838, 1002, 'Bandidos na TV S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105018.mp4', 'http://gstaticontent.com/images/b5cnl6p3xTpHlDWVXhi9isf4yMd_big.jpg'),
(15839, 1002, 'Bandidos na TV S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105019.mp4', 'http://gstaticontent.com/images/b5cnl6p3xTpHlDWVXhi9isf4yMd_big.jpg'),
(15840, 1002, 'Bandidos na TV S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105020.mp4', 'http://gstaticontent.com/images/b5cnl6p3xTpHlDWVXhi9isf4yMd_big.jpg'),
(15841, 1002, 'Bandidos na TV S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105021.mp4', 'http://gstaticontent.com/images/b5cnl6p3xTpHlDWVXhi9isf4yMd_big.jpg'),
(15842, 1002, 'Bandidos na TV S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105022.mp4', 'http://gstaticontent.com/images/b5cnl6p3xTpHlDWVXhi9isf4yMd_big.jpg'),
(15843, 1002, 'Bandidos na TV S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105023.mp4', 'http://gstaticontent.com/images/b5cnl6p3xTpHlDWVXhi9isf4yMd_big.jpg'),
(15844, 1003, 'Olhos que Condenam S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105013.mp4', 'http://gstaticontent.com/images/nkJtmjDsRdIzRKNctsMX33W55uJ_big.jpg'),
(15845, 1003, 'Olhos que Condenam S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105014.mp4', 'http://gstaticontent.com/images/nkJtmjDsRdIzRKNctsMX33W55uJ_big.jpg'),
(15846, 1003, 'Olhos que Condenam S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105015.mp4', 'http://gstaticontent.com/images/nkJtmjDsRdIzRKNctsMX33W55uJ_big.jpg'),
(15847, 1003, 'Olhos que Condenam S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105016.mp4', 'http://gstaticontent.com/images/nkJtmjDsRdIzRKNctsMX33W55uJ_big.jpg'),
(15848, 1004, 'The Hot Zone S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174648.mp4', 'http://gstaticontent.com/images/73w8Q1aY0XkRJyyy43sZ02tTcra_big.jpg'),
(15849, 1004, 'The Hot Zone S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174649.mp4', 'http://gstaticontent.com/images/73w8Q1aY0XkRJyyy43sZ02tTcra_big.jpg'),
(15850, 1004, 'The Hot Zone S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174650.mp4', 'http://gstaticontent.com/images/73w8Q1aY0XkRJyyy43sZ02tTcra_big.jpg'),
(15851, 1004, 'The Hot Zone S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174651.mp4', 'http://gstaticontent.com/images/73w8Q1aY0XkRJyyy43sZ02tTcra_big.jpg'),
(15852, 1004, 'The Hot Zone S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174652.mp4', 'http://gstaticontent.com/images/73w8Q1aY0XkRJyyy43sZ02tTcra_big.jpg'),
(15853, 1004, 'The Hot Zone S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174653.mp4', 'http://gstaticontent.com/images/73w8Q1aY0XkRJyyy43sZ02tTcra_big.jpg'),
(15854, 1005, 'The Hot Zone S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174654.mp4', 'http://timg.bdta.pro/images/69fd2ddeae4551f7516756eaee66453a.jpg'),
(15855, 1005, 'The Hot Zone S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174655.mp4', 'http://timg.bdta.pro/images/ba008a7f638da6a409ea7a4dd140f9bb.jpg'),
(15856, 1005, 'The Hot Zone S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174656.mp4', 'http://timg.bdta.pro/images/0126de80666dad1a104673bee35bb91b.jpg'),
(15857, 1005, 'The Hot Zone S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174657.mp4', 'http://timg.bdta.pro/images/c3c36d7813627304091f3cfce4860c1f.jpg'),
(15858, 1005, 'The Hot Zone S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174658.mp4', 'http://timg.bdta.pro/images/a3f74362b09d549d638d7e5cd064cfac.jpg'),
(15859, 1005, 'The Hot Zone S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174659.mp4', 'http://timg.bdta.pro/images/7d952057c6b45f37c5ddd244c673b139.jpg'),
(15860, 1, '3% S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15861, 1, '3% S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15862, 1, '3% S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15863, 1, '3% S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15864, 1, '3% S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15865, 1, '3% S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15866, 1, '3% S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15867, 1, '3% S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15868, 2, '3% S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15869, 2, '3% S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15870, 2, '3% S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15871, 2, '3% S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15872, 2, '3% S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15873, 2, '3% S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15874, 2, '3% S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15875, 2, '3% S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15876, 2, '3% S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15877, 2, '3% S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15878, 3, '3% S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15879, 3, '3% S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15880, 3, '3% S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15881, 3, '3% S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15882, 3, '3% S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15883, 3, '3% S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15884, 3, '3% S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15885, 3, '3% S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCQP1El20FFncM0lIYcaW3Kq19o.jpg'),
(15886, 1006, '3% S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130498.mp4', 'http://timg.bdta.pro/images/a4a516295e9386dd01eca146270bca1b.jpg'),
(15887, 1006, '3% S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130499.mp4', 'http://timg.bdta.pro/images/08ee7eb1080ab869e0ab6b0e88a5f3bd.jpg'),
(15888, 1006, '3% S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130500.mp4', 'http://timg.bdta.pro/images/e2edc11f805802a2ac1d30c9dc166baa.jpg'),
(15889, 1006, '3% S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130501.mp4', 'http://timg.bdta.pro/images/b14ec507c9b6bc1435101236d595d0b9.jpg'),
(15890, 1006, '3% S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130502.mp4', 'http://timg.bdta.pro/images/456947bac3fe42763b3ce6e4b433e16a.jpg'),
(15891, 1006, '3% S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130503.mp4', 'http://timg.bdta.pro/images/a19fe75631a45dd9aa9ebefd5987e6c5.jpg'),
(15892, 1006, '3% S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130504.mp4', 'http://timg.bdta.pro/images/b567749081eb3858d2037f8ab6c0fb5f.jpg'),
(15893, 1007, 'The Son S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103958.mp4', 'http://gstaticontent.com/images/eTlc7oTjL8R5sbHxiRbSSjMQyo2_big.jpg'),
(15894, 1007, 'The Son S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103959.mp4', 'http://gstaticontent.com/images/eTlc7oTjL8R5sbHxiRbSSjMQyo2_big.jpg'),
(15895, 1007, 'The Son S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103960.mp4', 'http://gstaticontent.com/images/eTlc7oTjL8R5sbHxiRbSSjMQyo2_big.jpg'),
(15896, 1007, 'The Son S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103961.mp4', 'http://gstaticontent.com/images/eTlc7oTjL8R5sbHxiRbSSjMQyo2_big.jpg'),
(15897, 1007, 'The Son S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103962.mp4', 'http://gstaticontent.com/images/eTlc7oTjL8R5sbHxiRbSSjMQyo2_big.jpg'),
(15898, 1007, 'The Son S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103963.mp4', 'http://gstaticontent.com/images/eTlc7oTjL8R5sbHxiRbSSjMQyo2_big.jpg'),
(15899, 1007, 'The Son S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103964.mp4', 'http://gstaticontent.com/images/eTlc7oTjL8R5sbHxiRbSSjMQyo2_big.jpg'),
(15900, 1007, 'The Son S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103965.mp4', 'http://gstaticontent.com/images/eTlc7oTjL8R5sbHxiRbSSjMQyo2_big.jpg'),
(15901, 1007, 'The Son S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103966.mp4', 'http://gstaticontent.com/images/eTlc7oTjL8R5sbHxiRbSSjMQyo2_big.jpg'),
(15902, 1007, 'The Son S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103967.mp4', 'http://gstaticontent.com/images/eTlc7oTjL8R5sbHxiRbSSjMQyo2_big.jpg'),
(15903, 1008, 'The Son S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103968.mp4', 'http://gstaticontent.com/images/eTlc7oTjL8R5sbHxiRbSSjMQyo2_big.jpg'),
(15904, 1008, 'The Son S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103969.mp4', 'http://gstaticontent.com/images/eTlc7oTjL8R5sbHxiRbSSjMQyo2_big.jpg'),
(15905, 1008, 'The Son S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103970.mp4', 'http://gstaticontent.com/images/eTlc7oTjL8R5sbHxiRbSSjMQyo2_big.jpg'),
(15906, 1008, 'The Son S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103971.mp4', 'http://gstaticontent.com/images/eTlc7oTjL8R5sbHxiRbSSjMQyo2_big.jpg'),
(15907, 1008, 'The Son S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103972.mp4', 'http://gstaticontent.com/images/eTlc7oTjL8R5sbHxiRbSSjMQyo2_big.jpg'),
(15908, 1008, 'The Son S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103973.mp4', 'http://gstaticontent.com/images/eTlc7oTjL8R5sbHxiRbSSjMQyo2_big.jpg'),
(15909, 1008, 'The Son S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103974.mp4', 'http://gstaticontent.com/images/eTlc7oTjL8R5sbHxiRbSSjMQyo2_big.jpg'),
(15910, 1008, 'The Son S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103975.mp4', 'http://gstaticontent.com/images/eTlc7oTjL8R5sbHxiRbSSjMQyo2_big.jpg'),
(15911, 1008, 'The Son S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103976.mp4', 'http://gstaticontent.com/images/eTlc7oTjL8R5sbHxiRbSSjMQyo2_big.jpg'),
(15912, 1009, 'Lifeline S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hSOGzV7NBKxcg6WxmzKVZmCApvf.jpg'),
(15913, 1009, 'Lifeline S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hSOGzV7NBKxcg6WxmzKVZmCApvf.jpg'),
(15914, 1009, 'Lifeline S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hSOGzV7NBKxcg6WxmzKVZmCApvf.jpg'),
(15915, 1009, 'Lifeline S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hSOGzV7NBKxcg6WxmzKVZmCApvf.jpg'),
(15916, 1009, 'Lifeline S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hSOGzV7NBKxcg6WxmzKVZmCApvf.jpg'),
(15917, 1009, 'Lifeline S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hSOGzV7NBKxcg6WxmzKVZmCApvf.jpg'),
(15918, 1009, 'Lifeline S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hSOGzV7NBKxcg6WxmzKVZmCApvf.jpg'),
(15919, 1009, 'Lifeline S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hSOGzV7NBKxcg6WxmzKVZmCApvf.jpg'),
(15920, 1010, 'Shippados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wjAicavb1aHQf6ZGIHVGkR47RkQ.jpg'),
(15921, 1010, 'Shippados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wjAicavb1aHQf6ZGIHVGkR47RkQ.jpg'),
(15922, 1010, 'Shippados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wjAicavb1aHQf6ZGIHVGkR47RkQ.jpg'),
(15923, 1010, 'Shippados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wjAicavb1aHQf6ZGIHVGkR47RkQ.jpg'),
(15924, 1010, 'Shippados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wjAicavb1aHQf6ZGIHVGkR47RkQ.jpg'),
(15925, 1010, 'Shippados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wjAicavb1aHQf6ZGIHVGkR47RkQ.jpg'),
(15926, 1010, 'Shippados S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wjAicavb1aHQf6ZGIHVGkR47RkQ.jpg'),
(15927, 1010, 'Shippados S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wjAicavb1aHQf6ZGIHVGkR47RkQ.jpg'),
(15928, 1010, 'Shippados S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wjAicavb1aHQf6ZGIHVGkR47RkQ.jpg'),
(15929, 1010, 'Shippados S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wjAicavb1aHQf6ZGIHVGkR47RkQ.jpg'),
(15930, 1010, 'Shippados S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/104998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wjAicavb1aHQf6ZGIHVGkR47RkQ.jpg'),
(15931, 1010, 'Shippados S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/104999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wjAicavb1aHQf6ZGIHVGkR47RkQ.jpg'),
(15932, 1011, 'Killing Eve S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182479.mp4', 'http://gstaticontent.com/images/uyniy2OqqsmIVHswfZ9AIz06wYp_big.jpg'),
(15933, 1011, 'Killing Eve S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182480.mp4', 'http://gstaticontent.com/images/uyniy2OqqsmIVHswfZ9AIz06wYp_big.jpg'),
(15934, 1011, 'Killing Eve S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182481.mp4', 'http://gstaticontent.com/images/uyniy2OqqsmIVHswfZ9AIz06wYp_big.jpg'),
(15935, 1011, 'Killing Eve S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182482.mp4', 'http://gstaticontent.com/images/uyniy2OqqsmIVHswfZ9AIz06wYp_big.jpg'),
(15936, 1011, 'Killing Eve S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182483.mp4', 'http://gstaticontent.com/images/uyniy2OqqsmIVHswfZ9AIz06wYp_big.jpg'),
(15937, 1011, 'Killing Eve S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182484.mp4', 'http://gstaticontent.com/images/uyniy2OqqsmIVHswfZ9AIz06wYp_big.jpg'),
(15938, 1011, 'Killing Eve S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182485.mp4', 'http://gstaticontent.com/images/uyniy2OqqsmIVHswfZ9AIz06wYp_big.jpg'),
(15939, 1011, 'Killing Eve S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182486.mp4', 'http://gstaticontent.com/images/uyniy2OqqsmIVHswfZ9AIz06wYp_big.jpg'),
(15940, 1012, 'Killing Eve S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182487.mp4', 'http://gstaticontent.com/images/uyniy2OqqsmIVHswfZ9AIz06wYp_big.jpg'),
(15941, 1012, 'Killing Eve S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182488.mp4', 'http://gstaticontent.com/images/uyniy2OqqsmIVHswfZ9AIz06wYp_big.jpg'),
(15942, 1012, 'Killing Eve S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182489.mp4', 'http://gstaticontent.com/images/uyniy2OqqsmIVHswfZ9AIz06wYp_big.jpg'),
(15943, 1012, 'Killing Eve S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182490.mp4', 'http://gstaticontent.com/images/uyniy2OqqsmIVHswfZ9AIz06wYp_big.jpg'),
(15944, 1012, 'Killing Eve S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182491.mp4', 'http://gstaticontent.com/images/uyniy2OqqsmIVHswfZ9AIz06wYp_big.jpg'),
(15945, 1012, 'Killing Eve S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182492.mp4', 'http://gstaticontent.com/images/uyniy2OqqsmIVHswfZ9AIz06wYp_big.jpg'),
(15946, 1012, 'Killing Eve S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182493.mp4', 'http://gstaticontent.com/images/uyniy2OqqsmIVHswfZ9AIz06wYp_big.jpg'),
(15947, 1012, 'Killing Eve S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182494.mp4', 'http://gstaticontent.com/images/uyniy2OqqsmIVHswfZ9AIz06wYp_big.jpg'),
(15948, 1013, 'Killing Eve S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182495.mp4', 'http://timg.bdta.pro/images/9e52b76ead26afec2f85095533e6298d.jpg'),
(15949, 1013, 'Killing Eve S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182496.mp4', 'http://timg.bdta.pro/images/7ecfc0456269933148381c9d34664e32.jpg'),
(15950, 1013, 'Killing Eve S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182497.mp4', 'http://timg.bdta.pro/images/d7b43c6908f8fa31b8bebd7cbafb0f96.jpg'),
(15951, 1013, 'Killing Eve S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182498.mp4', 'http://timg.bdta.pro/images/0ab93af557ea93775f954a46765bf6db.jpg'),
(15952, 1013, 'Killing Eve S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182499.mp4', 'http://timg.bdta.pro/images/c822faffd2f1680dbd6ca9e913efa0ca.jpg'),
(15953, 1013, 'Killing Eve S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182500.mp4', 'http://timg.bdta.pro/images/a3c9764fd4dbff4c8d00c0877a719bef.jpg'),
(15954, 1013, 'Killing Eve S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182501.mp4', 'http://timg.bdta.pro/images/8a200c04300c53a9eb988bc7708d3ec5.jpg'),
(15955, 1013, 'Killing Eve S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182502.mp4', 'http://timg.bdta.pro/images/15de02147c154b0051b9dde4ea8fffeb.jpg'),
(15956, 1014, 'Killing Eve S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182503.mp4', 'http://timg.bdta.pro/images/54279dbddebaa8ee53c84822a97e5619.jpg'),
(15957, 1014, 'Killing Eve S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182504.mp4', 'http://timg.bdta.pro/images/a6aa716c3162c287e0a07f6ba11a80bb.jpg'),
(15958, 1014, 'Killing Eve S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182505.mp4', 'http://timg.bdta.pro/images/289dbfc5f6b663a38b9024dba742ac1a.jpg'),
(15959, 1014, 'Killing Eve S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182506.mp4', 'http://timg.bdta.pro/images/49072d0011b9e5ed95883afac346a04c.jpg'),
(15960, 1014, 'Killing Eve S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182507.mp4', 'http://timg.bdta.pro/images/5cbef7c784aca7dd9cf8b4e3b6175708.jpg'),
(15961, 1014, 'Killing Eve S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182508.mp4', 'http://timg.bdta.pro/images/f11a11e549763678cce4198a0cd2f1c8.jpg'),
(15962, 1014, 'Killing Eve S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182509.mp4', 'http://timg.bdta.pro/images/0e0741595b6d066b38efb7e3f4e86d37.jpg'),
(15963, 1014, 'Killing Eve S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182510.mp4', 'http://timg.bdta.pro/images/94573ff3332d0379ee2ff5b703fb85a2.jpg'),
(15964, 1015, 'Big Little Lies S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxGkno93ExrTMsJVllH6mzQ652z.jpg'),
(15965, 1015, 'Big Little Lies S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxGkno93ExrTMsJVllH6mzQ652z.jpg'),
(15966, 1015, 'Big Little Lies S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxGkno93ExrTMsJVllH6mzQ652z.jpg'),
(15967, 1015, 'Big Little Lies S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxGkno93ExrTMsJVllH6mzQ652z.jpg'),
(15968, 1015, 'Big Little Lies S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxGkno93ExrTMsJVllH6mzQ652z.jpg'),
(15969, 1015, 'Big Little Lies S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxGkno93ExrTMsJVllH6mzQ652z.jpg'),
(15970, 1015, 'Big Little Lies S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxGkno93ExrTMsJVllH6mzQ652z.jpg'),
(15971, 1016, 'Big Little Lies S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxGkno93ExrTMsJVllH6mzQ652z.jpg'),
(15972, 1016, 'Big Little Lies S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxGkno93ExrTMsJVllH6mzQ652z.jpg'),
(15973, 1016, 'Big Little Lies S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxGkno93ExrTMsJVllH6mzQ652z.jpg'),
(15974, 1016, 'Big Little Lies S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxGkno93ExrTMsJVllH6mzQ652z.jpg'),
(15975, 1016, 'Big Little Lies S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxGkno93ExrTMsJVllH6mzQ652z.jpg'),
(15976, 1016, 'Big Little Lies S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxGkno93ExrTMsJVllH6mzQ652z.jpg'),
(15977, 1016, 'Big Little Lies S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxGkno93ExrTMsJVllH6mzQ652z.jpg'),
(15978, 1017, 'O Jardim de Bronze S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tD5184GDaV2JvrIHm7Pgkdzfzj9.jpg'),
(15979, 1017, 'O Jardim de Bronze S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tD5184GDaV2JvrIHm7Pgkdzfzj9.jpg'),
(15980, 1017, 'O Jardim de Bronze S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tD5184GDaV2JvrIHm7Pgkdzfzj9.jpg'),
(15981, 1017, 'O Jardim de Bronze S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tD5184GDaV2JvrIHm7Pgkdzfzj9.jpg'),
(15982, 1017, 'O Jardim de Bronze S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tD5184GDaV2JvrIHm7Pgkdzfzj9.jpg'),
(15983, 1017, 'O Jardim de Bronze S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tD5184GDaV2JvrIHm7Pgkdzfzj9.jpg'),
(15984, 1017, 'O Jardim de Bronze S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tD5184GDaV2JvrIHm7Pgkdzfzj9.jpg'),
(15985, 1017, 'O Jardim de Bronze S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tD5184GDaV2JvrIHm7Pgkdzfzj9.jpg'),
(15986, 1018, 'O Jardim de Bronze S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tD5184GDaV2JvrIHm7Pgkdzfzj9.jpg'),
(15987, 1018, 'O Jardim de Bronze S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tD5184GDaV2JvrIHm7Pgkdzfzj9.jpg'),
(15988, 1018, 'O Jardim de Bronze S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tD5184GDaV2JvrIHm7Pgkdzfzj9.jpg'),
(15989, 1018, 'O Jardim de Bronze S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tD5184GDaV2JvrIHm7Pgkdzfzj9.jpg'),
(15990, 1018, 'O Jardim de Bronze S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tD5184GDaV2JvrIHm7Pgkdzfzj9.jpg'),
(15991, 1018, 'O Jardim de Bronze S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tD5184GDaV2JvrIHm7Pgkdzfzj9.jpg'),
(15992, 1018, 'O Jardim de Bronze S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tD5184GDaV2JvrIHm7Pgkdzfzj9.jpg'),
(15993, 1018, 'O Jardim de Bronze S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tD5184GDaV2JvrIHm7Pgkdzfzj9.jpg'),
(15994, 1019, 'O Jardim de Bronze S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tD5184GDaV2JvrIHm7Pgkdzfzj9.jpg'),
(15995, 1019, 'O Jardim de Bronze S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4V9qHQItbqT6eObe90ru570F5lZ.jpg'),
(15996, 1019, 'O Jardim de Bronze S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qnAaCg4Mt4wZ5mmvXO7q3OnzGyJ.jpg'),
(15997, 1019, 'O Jardim de Bronze S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2NNTZCWZnRtVc8Tgp52JdznnpyI.jpg'),
(15998, 1019, 'O Jardim de Bronze S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pQQTuhqCk5kqy20WpcrcQOQOhlW.jpg'),
(15999, 1019, 'O Jardim de Bronze S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rSnK1uQ2yKYPhLC6xxrEuxuKT3H.jpg'),
(16000, 1019, 'O Jardim de Bronze S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tD5184GDaV2JvrIHm7Pgkdzfzj9.jpg'),
(16001, 1019, 'O Jardim de Bronze S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tD5184GDaV2JvrIHm7Pgkdzfzj9.jpg'),
(16002, 1020, 'De Férias com o Ex Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16003, 1020, 'De Férias com o Ex Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16004, 1020, 'De Férias com o Ex Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16005, 1020, 'De Férias com o Ex Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16006, 1020, 'De Férias com o Ex Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16007, 1020, 'De Férias com o Ex Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16008, 1020, 'De Férias com o Ex Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16009, 1020, 'De Férias com o Ex Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16010, 1020, 'De Férias com o Ex Brasil S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16011, 1020, 'De Férias com o Ex Brasil S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16012, 1021, 'De Férias com o Ex Brasil S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16013, 1021, 'De Férias com o Ex Brasil S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16014, 1021, 'De Férias com o Ex Brasil S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16015, 1021, 'De Férias com o Ex Brasil S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16016, 1021, 'De Férias com o Ex Brasil S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16017, 1021, 'De Férias com o Ex Brasil S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16018, 1021, 'De Férias com o Ex Brasil S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16019, 1021, 'De Férias com o Ex Brasil S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16020, 1021, 'De Férias com o Ex Brasil S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(16021, 1021, 'De Férias com o Ex Brasil S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16022, 1022, 'De Férias com o Ex Brasil S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16023, 1022, 'De Férias com o Ex Brasil S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16024, 1022, 'De Férias com o Ex Brasil S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16025, 1022, 'De Férias com o Ex Brasil S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16026, 1022, 'De Férias com o Ex Brasil S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16027, 1022, 'De Férias com o Ex Brasil S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16028, 1022, 'De Férias com o Ex Brasil S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16029, 1022, 'De Férias com o Ex Brasil S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16030, 1022, 'De Férias com o Ex Brasil S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16031, 1022, 'De Férias com o Ex Brasil S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16032, 1022, 'De Férias com o Ex Brasil S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16033, 1022, 'De Férias com o Ex Brasil S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16034, 1023, 'De Férias com o Ex Brasil S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16035, 1023, 'De Férias com o Ex Brasil S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16036, 1023, 'De Férias com o Ex Brasil S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16037, 1023, 'De Férias com o Ex Brasil S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16038, 1023, 'De Férias com o Ex Brasil S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16039, 1023, 'De Férias com o Ex Brasil S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16040, 1023, 'De Férias com o Ex Brasil S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16041, 1023, 'De Férias com o Ex Brasil S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16042, 1023, 'De Férias com o Ex Brasil S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16043, 1023, 'De Férias com o Ex Brasil S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16044, 1023, 'De Férias com o Ex Brasil S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16045, 1023, 'De Férias com o Ex Brasil S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16046, 1024, 'De Férias com o Ex Brasil S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16047, 1024, 'De Férias com o Ex Brasil S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16048, 1024, 'De Férias com o Ex Brasil S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16049, 1024, 'De Férias com o Ex Brasil S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16050, 1024, 'De Férias com o Ex Brasil S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16051, 1024, 'De Férias com o Ex Brasil S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16052, 1024, 'De Férias com o Ex Brasil S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16053, 1024, 'De Férias com o Ex Brasil S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16054, 1024, 'De Férias com o Ex Brasil S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16055, 1024, 'De Férias com o Ex Brasil S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16056, 1024, 'De Férias com o Ex Brasil S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16057, 1024, 'De Férias com o Ex Brasil S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16058, 1025, 'De Férias com o Ex Brasil S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16059, 1025, 'De Férias com o Ex Brasil S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16060, 1025, 'De Férias com o Ex Brasil S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16061, 1025, 'De Férias com o Ex Brasil S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16062, 1025, 'De Férias com o Ex Brasil S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16063, 1025, 'De Férias com o Ex Brasil S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16064, 1025, 'De Férias com o Ex Brasil S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16065, 1025, 'De Férias com o Ex Brasil S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16066, 1025, 'De Férias com o Ex Brasil S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16067, 1025, 'De Férias com o Ex Brasil S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16068, 1025, 'De Férias com o Ex Brasil S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16069, 1025, 'De Férias com o Ex Brasil S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16070, 1026, 'De Férias com o Ex Brasil S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16071, 1026, 'De Férias com o Ex Brasil S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16072, 1026, 'De Férias com o Ex Brasil S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16073, 1026, 'De Férias com o Ex Brasil S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16074, 1026, 'De Férias com o Ex Brasil S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16075, 1026, 'De Férias com o Ex Brasil S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16076, 1026, 'De Férias com o Ex Brasil S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16077, 1026, 'De Férias com o Ex Brasil S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16078, 1026, 'De Férias com o Ex Brasil S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16079, 1026, 'De Férias com o Ex Brasil S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16080, 1026, 'De Férias com o Ex Brasil S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9aBYWnwd86ejV4ic36z188ZiGu4.jpg'),
(16081, 1027, 'Felizes para Sempre S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4ILKuQpGWbnHfauwdirCUtWYbaw.jpg'),
(16082, 1027, 'Felizes para Sempre S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4ILKuQpGWbnHfauwdirCUtWYbaw.jpg'),
(16083, 1027, 'Felizes para Sempre S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4ILKuQpGWbnHfauwdirCUtWYbaw.jpg'),
(16084, 1027, 'Felizes para Sempre S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4ILKuQpGWbnHfauwdirCUtWYbaw.jpg'),
(16085, 1027, 'Felizes para Sempre S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4ILKuQpGWbnHfauwdirCUtWYbaw.jpg'),
(16086, 1027, 'Felizes para Sempre S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4ILKuQpGWbnHfauwdirCUtWYbaw.jpg'),
(16087, 1027, 'Felizes para Sempre S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4ILKuQpGWbnHfauwdirCUtWYbaw.jpg'),
(16088, 1027, 'Felizes para Sempre S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4ILKuQpGWbnHfauwdirCUtWYbaw.jpg'),
(16089, 1027, 'Felizes para Sempre S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4ILKuQpGWbnHfauwdirCUtWYbaw.jpg'),
(16090, 1027, 'Felizes para Sempre S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4ILKuQpGWbnHfauwdirCUtWYbaw.jpg'),
(16091, 1028, 'The Titan Games S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cEs94sKekYmUjHKN2c9Untznq9J.jpg'),
(16092, 1028, 'The Titan Games S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cEs94sKekYmUjHKN2c9Untznq9J.jpg'),
(16093, 1028, 'The Titan Games S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cEs94sKekYmUjHKN2c9Untznq9J.jpg'),
(16094, 1028, 'The Titan Games S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cEs94sKekYmUjHKN2c9Untznq9J.jpg'),
(16095, 1028, 'The Titan Games S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cEs94sKekYmUjHKN2c9Untznq9J.jpg'),
(16096, 1028, 'The Titan Games S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cEs94sKekYmUjHKN2c9Untznq9J.jpg'),
(16097, 1028, 'The Titan Games S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cEs94sKekYmUjHKN2c9Untznq9J.jpg'),
(16098, 1028, 'The Titan Games S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cEs94sKekYmUjHKN2c9Untznq9J.jpg'),
(16099, 1028, 'The Titan Games S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cEs94sKekYmUjHKN2c9Untznq9J.jpg'),
(16100, 1029, 'The Titan Games S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131538.mp4', 'http://timg.bdta.pro/images/9e343af450bc5aece1d003c1174be1b8.jpg'),
(16101, 1029, 'The Titan Games S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131539.mp4', 'http://timg.bdta.pro/images/61f3deb2b65fae038d91205219158eb8.jpg'),
(16102, 1029, 'The Titan Games S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131540.mp4', 'http://timg.bdta.pro/images/69f56106e5c47e3738c34fe0267754b3.jpg'),
(16103, 1029, 'The Titan Games S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131541.mp4', 'http://timg.bdta.pro/images/c8a2750973fb064431ae2506a102f8e9.jpg'),
(16104, 1029, 'The Titan Games S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mUOOTCnQRj21TSwyoO7WYZm2TrX.jpg'),
(16105, 1029, 'The Titan Games S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kwt6Th04Y2KJXKpFuIoJ405ZnJR.jpg'),
(16106, 1030, 'Ultimate Beastmaster Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104949.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16107, 1030, 'Ultimate Beastmaster Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104950.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16108, 1030, 'Ultimate Beastmaster Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104951.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16109, 1030, 'Ultimate Beastmaster Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104952.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16110, 1030, 'Ultimate Beastmaster Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104953.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16111, 1030, 'Ultimate Beastmaster Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104954.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16112, 1030, 'Ultimate Beastmaster Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104955.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16113, 1030, 'Ultimate Beastmaster Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104956.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16114, 1030, 'Ultimate Beastmaster Brasil S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104957.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16115, 1030, 'Ultimate Beastmaster Brasil S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104958.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16116, 1031, 'Ultimate Beastmaster Brasil S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104959.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16117, 1031, 'Ultimate Beastmaster Brasil S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104960.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16118, 1031, 'Ultimate Beastmaster Brasil S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104961.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16119, 1031, 'Ultimate Beastmaster Brasil S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104962.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16120, 1031, 'Ultimate Beastmaster Brasil S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104963.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16121, 1031, 'Ultimate Beastmaster Brasil S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104964.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16122, 1031, 'Ultimate Beastmaster Brasil S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104965.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16123, 1031, 'Ultimate Beastmaster Brasil S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104966.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16124, 1031, 'Ultimate Beastmaster Brasil S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104967.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16125, 1031, 'Ultimate Beastmaster Brasil S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104968.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16126, 1032, 'Ultimate Beastmaster Brasil S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104969.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16127, 1032, 'Ultimate Beastmaster Brasil S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104970.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16128, 1032, 'Ultimate Beastmaster Brasil S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104971.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16129, 1032, 'Ultimate Beastmaster Brasil S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104972.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16130, 1032, 'Ultimate Beastmaster Brasil S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104973.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16131, 1032, 'Ultimate Beastmaster Brasil S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104974.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16132, 1032, 'Ultimate Beastmaster Brasil S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104975.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16133, 1032, 'Ultimate Beastmaster Brasil S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104976.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16134, 1032, 'Ultimate Beastmaster Brasil S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104977.mp4', 'http://gstaticontent.com/images/yYRkguaVv8Cw25AZwT7xpkMitpr_big.jpg'),
(16135, 1033, 'Ransom S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104865.mp4', 'http://gstaticontent.com/images/msn327MnlMG2iMess6CSTcn3HT2_big.jpg'),
(16136, 1033, 'Ransom S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104866.mp4', 'http://gstaticontent.com/images/msn327MnlMG2iMess6CSTcn3HT2_big.jpg'),
(16137, 1033, 'Ransom S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104867.mp4', 'http://gstaticontent.com/images/msn327MnlMG2iMess6CSTcn3HT2_big.jpg'),
(16138, 1033, 'Ransom S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104868.mp4', 'http://gstaticontent.com/images/msn327MnlMG2iMess6CSTcn3HT2_big.jpg'),
(16139, 1033, 'Ransom S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104869.mp4', 'http://gstaticontent.com/images/msn327MnlMG2iMess6CSTcn3HT2_big.jpg'),
(16140, 1033, 'Ransom S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104870.mp4', 'http://gstaticontent.com/images/msn327MnlMG2iMess6CSTcn3HT2_big.jpg'),
(16141, 1033, 'Ransom S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104871.mp4', 'http://gstaticontent.com/images/msn327MnlMG2iMess6CSTcn3HT2_big.jpg'),
(16142, 1033, 'Ransom S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104872.mp4', 'http://gstaticontent.com/images/msn327MnlMG2iMess6CSTcn3HT2_big.jpg'),
(16143, 1033, 'Ransom S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104873.mp4', 'http://gstaticontent.com/images/msn327MnlMG2iMess6CSTcn3HT2_big.jpg'),
(16144, 1033, 'Ransom S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104874.mp4', 'http://gstaticontent.com/images/msn327MnlMG2iMess6CSTcn3HT2_big.jpg'),
(16145, 1033, 'Ransom S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/104875.mp4', 'http://gstaticontent.com/images/msn327MnlMG2iMess6CSTcn3HT2_big.jpg'),
(16146, 1033, 'Ransom S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/104876.mp4', 'http://gstaticontent.com/images/msn327MnlMG2iMess6CSTcn3HT2_big.jpg'),
(16147, 1033, 'Ransom S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/104877.mp4', 'http://gstaticontent.com/images/msn327MnlMG2iMess6CSTcn3HT2_big.jpg'),
(16148, 1034, 'Ransom S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104878.mp4', 'http://gstaticontent.com/images/msn327MnlMG2iMess6CSTcn3HT2_big.jpg'),
(16149, 1034, 'Ransom S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104879.mp4', 'http://gstaticontent.com/images/msn327MnlMG2iMess6CSTcn3HT2_big.jpg'),
(16150, 1034, 'Ransom S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104880.mp4', 'http://gstaticontent.com/images/msn327MnlMG2iMess6CSTcn3HT2_big.jpg'),
(16151, 1034, 'Ransom S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104881.mp4', 'http://gstaticontent.com/images/msn327MnlMG2iMess6CSTcn3HT2_big.jpg'),
(16152, 1034, 'Ransom S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104882.mp4', 'http://gstaticontent.com/images/msn327MnlMG2iMess6CSTcn3HT2_big.jpg'),
(16153, 1034, 'Ransom S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104883.mp4', 'http://gstaticontent.com/images/msn327MnlMG2iMess6CSTcn3HT2_big.jpg'),
(16154, 1034, 'Ransom S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104884.mp4', 'http://gstaticontent.com/images/msn327MnlMG2iMess6CSTcn3HT2_big.jpg'),
(16155, 1035, 'Ransom S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/884315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s1iIl4hRvbHrLduJ0Mb6mG8KpKx.jpg'),
(16156, 1035, 'Ransom S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/884316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hnjqtNh6PK0CttHG3qIArGrD9Iu.jpg'),
(16157, 1035, 'Ransom S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/884317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rWsfP5lmcaGlyMoRE1Faze5RpGi.jpg'),
(16158, 1035, 'Ransom S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/884318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xP8n12ujfZr8NJ28pFyW3kHhzIg.jpg'),
(16159, 1035, 'Ransom S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/884319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPbdEfLt1OMTBbPFm3xqYNCmAeM.jpg'),
(16160, 1035, 'Ransom S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/884320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8A6IEdAcA5wKVQ0lO4cHCL9ZscL.jpg'),
(16161, 1035, 'Ransom S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/884321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/95DhF7xTKrQpSsoAm0ia4xYnSbF.jpg'),
(16162, 1035, 'Ransom S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/884322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zVZSCs3k2TCajLPKe8jI4JV0gBc.jpg'),
(16163, 1035, 'Ransom S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/884323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uk93ze0JyekwIWQahyjIJ5SbDWK.jpg'),
(16164, 1035, 'Ransom S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/884324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3RbPHlwuLr0Qt45PdQvCi0GBl4o.jpg'),
(16165, 1035, 'Ransom S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/884325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pbLJOsIge6MrOFJm7Qi7mUsjbrZ.jpg'),
(16166, 1035, 'Ransom S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/884326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wCZPOo3Mc8IQSt4SpBeWAStNlhb.jpg'),
(16167, 1035, 'Ransom S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/884327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5EGcQLh3riD1LwG1adHrDbg4z3e.jpg'),
(16168, 1036, 'Stan Against Evil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104803.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16169, 1036, 'Stan Against Evil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104804.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16170, 1036, 'Stan Against Evil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104805.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16171, 1036, 'Stan Against Evil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104806.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16172, 1036, 'Stan Against Evil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104807.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16173, 1036, 'Stan Against Evil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104808.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16174, 1036, 'Stan Against Evil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104809.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16175, 1036, 'Stan Against Evil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104810.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16176, 1037, 'Stan Against Evil S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104811.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16177, 1037, 'Stan Against Evil S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104812.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16178, 1037, 'Stan Against Evil S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104813.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16179, 1037, 'Stan Against Evil S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104814.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16180, 1037, 'Stan Against Evil S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104815.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16181, 1037, 'Stan Against Evil S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104816.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16182, 1037, 'Stan Against Evil S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104817.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16183, 1037, 'Stan Against Evil S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104818.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16184, 1038, 'Stan Against Evil S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104819.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16185, 1038, 'Stan Against Evil S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104820.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16186, 1038, 'Stan Against Evil S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104821.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16187, 1038, 'Stan Against Evil S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104822.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16188, 1038, 'Stan Against Evil S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104823.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16189, 1038, 'Stan Against Evil S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104824.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16190, 1038, 'Stan Against Evil S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104825.mp4', 'http://gstaticontent.com/images/iY6KP7buG2DhQQwGoKlqyxxRbk5_big.jpg'),
(16191, 1039, 'Street Food: Ásia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1lye2ah4QAiWNXRqF9RkUoWUfaV.jpg'),
(16192, 1039, 'Street Food: Ásia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1lye2ah4QAiWNXRqF9RkUoWUfaV.jpg'),
(16193, 1039, 'Street Food: Ásia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1lye2ah4QAiWNXRqF9RkUoWUfaV.jpg'),
(16194, 1039, 'Street Food: Ásia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1lye2ah4QAiWNXRqF9RkUoWUfaV.jpg'),
(16195, 1039, 'Street Food: Ásia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1lye2ah4QAiWNXRqF9RkUoWUfaV.jpg'),
(16196, 1039, 'Street Food: Ásia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1lye2ah4QAiWNXRqF9RkUoWUfaV.jpg'),
(16197, 1039, 'Street Food: Ásia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1lye2ah4QAiWNXRqF9RkUoWUfaV.jpg'),
(16198, 1039, 'Street Food: Ásia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1lye2ah4QAiWNXRqF9RkUoWUfaV.jpg'),
(16199, 1039, 'Street Food: Ásia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1lye2ah4QAiWNXRqF9RkUoWUfaV.jpg'),
(16200, 1040, 'Franquias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1lye2ah4QAiWNXRqF9RkUoWUfaV.jpg'),
(16201, 1040, 'Franquias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1lye2ah4QAiWNXRqF9RkUoWUfaV.jpg'),
(16202, 1040, 'Franquias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1lye2ah4QAiWNXRqF9RkUoWUfaV.jpg'),
(16203, 1040, 'Franquias S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1lye2ah4QAiWNXRqF9RkUoWUfaV.jpg'),
(16204, 1040, 'Franquias S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1lye2ah4QAiWNXRqF9RkUoWUfaV.jpg'),
(16205, 1040, 'Franquias S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1lye2ah4QAiWNXRqF9RkUoWUfaV.jpg'),
(16206, 1040, 'Franquias S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1lye2ah4QAiWNXRqF9RkUoWUfaV.jpg'),
(16207, 1041, 'Os Mistérios da Civilizacao Maia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104778.mp4', 'http://gstaticontent.com/images/sfQS9bI0GBzQ9z4DtDvWj1SktR0_big.jpg'),
(16208, 1041, 'Os Mistérios da Civilizacao Maia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104779.mp4', 'http://gstaticontent.com/images/sfQS9bI0GBzQ9z4DtDvWj1SktR0_big.jpg'),
(16209, 1041, 'Os Mistérios da Civilizacao Maia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104780.mp4', 'http://gstaticontent.com/images/sfQS9bI0GBzQ9z4DtDvWj1SktR0_big.jpg'),
(16210, 1041, 'Os Mistérios da Civilizacao Maia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104781.mp4', 'http://gstaticontent.com/images/sfQS9bI0GBzQ9z4DtDvWj1SktR0_big.jpg'),
(16211, 1042, 'NOS4A2 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127454.mp4', 'http://gstaticontent.com/images/gnosVTTRTCqooJuipwU6C0bgOGf_big.jpg'),
(16212, 1042, 'NOS4A2 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127455.mp4', 'http://gstaticontent.com/images/gnosVTTRTCqooJuipwU6C0bgOGf_big.jpg'),
(16213, 1042, 'NOS4A2 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127456.mp4', 'http://gstaticontent.com/images/gnosVTTRTCqooJuipwU6C0bgOGf_big.jpg'),
(16214, 1042, 'NOS4A2 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127457.mp4', 'http://gstaticontent.com/images/gnosVTTRTCqooJuipwU6C0bgOGf_big.jpg'),
(16215, 1042, 'NOS4A2 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127458.mp4', 'http://gstaticontent.com/images/gnosVTTRTCqooJuipwU6C0bgOGf_big.jpg'),
(16216, 1042, 'NOS4A2 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127459.mp4', 'http://gstaticontent.com/images/gnosVTTRTCqooJuipwU6C0bgOGf_big.jpg'),
(16217, 1042, 'NOS4A2 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127460.mp4', 'http://gstaticontent.com/images/gnosVTTRTCqooJuipwU6C0bgOGf_big.jpg'),
(16218, 1042, 'NOS4A2 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127461.mp4', 'http://gstaticontent.com/images/gnosVTTRTCqooJuipwU6C0bgOGf_big.jpg'),
(16219, 1042, 'NOS4A2 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127462.mp4', 'http://gstaticontent.com/images/gnosVTTRTCqooJuipwU6C0bgOGf_big.jpg'),
(16220, 1043, 'NOS4A2 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127463.mp4', 'http://timg.bdta.pro/images/d2b1d03b87b0ddb9b14fba1acdffcd21.jpg'),
(16221, 1043, 'NOS4A2 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127464.mp4', 'http://timg.bdta.pro/images/315e9cde490dc0e07747783fd7f95824.jpg'),
(16222, 1043, 'NOS4A2 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127465.mp4', 'http://timg.bdta.pro/images/d6a05f0b19cf702b4ebf68a99c4f9390.jpg'),
(16223, 1043, 'NOS4A2 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127466.mp4', 'http://timg.bdta.pro/images/cddc163d667ee72d5dd244fadd4320f4.jpg'),
(16224, 1043, 'NOS4A2 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127467.mp4', 'http://timg.bdta.pro/images/28f43c0de0daed97e32448263f69dd93.jpg'),
(16225, 1043, 'NOS4A2 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127468.mp4', 'http://timg.bdta.pro/images/a72f1baa131bbd299ad2a59664f75505.jpg'),
(16226, 1043, 'NOS4A2 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127469.mp4', 'http://timg.bdta.pro/images/384c5fac40ef407c0201b6ce121d127e.jpg'),
(16227, 1043, 'NOS4A2 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127470.mp4', 'http://timg.bdta.pro/images/e9ad5e4b8289bc9197122cb854403fb0.jpg'),
(16228, 1043, 'NOS4A2 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127471.mp4', 'http://timg.bdta.pro/images/217e6647fb807801c540a96b1daa7cf4.jpg'),
(16229, 1043, 'NOS4A2 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127472.mp4', 'http://timg.bdta.pro/images/cf2752e7dfe45e79e8d9a99032f428b5.jpg'),
(16230, 1044, 'Hackers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104782.mp4', 'http://gstaticontent.com/images/oYDfutdJDVQGCnYNdTB36CS0tPg_big.jpg'),
(16231, 1044, 'Hackers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104783.mp4', 'http://gstaticontent.com/images/oYDfutdJDVQGCnYNdTB36CS0tPg_big.jpg'),
(16232, 1044, 'Hackers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104784.mp4', 'http://gstaticontent.com/images/oYDfutdJDVQGCnYNdTB36CS0tPg_big.jpg'),
(16233, 1044, 'Hackers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104785.mp4', 'http://gstaticontent.com/images/oYDfutdJDVQGCnYNdTB36CS0tPg_big.jpg'),
(16234, 1044, 'Hackers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104786.mp4', 'http://gstaticontent.com/images/oYDfutdJDVQGCnYNdTB36CS0tPg_big.jpg'),
(16235, 1044, 'Hackers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104787.mp4', 'http://gstaticontent.com/images/oYDfutdJDVQGCnYNdTB36CS0tPg_big.jpg'),
(16236, 1044, 'Hackers S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104788.mp4', 'http://gstaticontent.com/images/oYDfutdJDVQGCnYNdTB36CS0tPg_big.jpg'),
(16237, 1044, 'Hackers S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104789.mp4', 'http://gstaticontent.com/images/oYDfutdJDVQGCnYNdTB36CS0tPg_big.jpg'),
(16238, 1044, 'Hackers S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104790.mp4', 'http://gstaticontent.com/images/oYDfutdJDVQGCnYNdTB36CS0tPg_big.jpg'),
(16239, 1044, 'Hackers S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104791.mp4', 'http://gstaticontent.com/images/oYDfutdJDVQGCnYNdTB36CS0tPg_big.jpg'),
(16240, 1045, 'Hackers S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104792.mp4', 'http://gstaticontent.com/images/oYDfutdJDVQGCnYNdTB36CS0tPg_big.jpg'),
(16241, 1045, 'Hackers S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104793.mp4', 'http://gstaticontent.com/images/oYDfutdJDVQGCnYNdTB36CS0tPg_big.jpg'),
(16242, 1045, 'Hackers S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104794.mp4', 'http://gstaticontent.com/images/oYDfutdJDVQGCnYNdTB36CS0tPg_big.jpg'),
(16243, 1045, 'Hackers S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104795.mp4', 'http://gstaticontent.com/images/oYDfutdJDVQGCnYNdTB36CS0tPg_big.jpg'),
(16244, 1045, 'Hackers S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104796.mp4', 'http://gstaticontent.com/images/oYDfutdJDVQGCnYNdTB36CS0tPg_big.jpg'),
(16245, 1045, 'Hackers S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104797.mp4', 'http://gstaticontent.com/images/oYDfutdJDVQGCnYNdTB36CS0tPg_big.jpg'),
(16246, 1045, 'Hackers S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104798.mp4', 'http://gstaticontent.com/images/oYDfutdJDVQGCnYNdTB36CS0tPg_big.jpg'),
(16247, 1045, 'Hackers S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104799.mp4', 'http://gstaticontent.com/images/oYDfutdJDVQGCnYNdTB36CS0tPg_big.jpg'),
(16248, 1045, 'Hackers S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104800.mp4', 'http://gstaticontent.com/images/oYDfutdJDVQGCnYNdTB36CS0tPg_big.jpg'),
(16249, 1045, 'Hackers S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104801.mp4', 'http://gstaticontent.com/images/oYDfutdJDVQGCnYNdTB36CS0tPg_big.jpg'),
(16250, 1045, 'Hackers S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/104802.mp4', 'http://gstaticontent.com/images/oYDfutdJDVQGCnYNdTB36CS0tPg_big.jpg'),
(16251, 1046, 'The Fix S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103233.mp4', 'http://gstaticontent.com/images/6NfIhX3XjH7IBvUnctnhxoWnwRF_big.jpg'),
(16252, 1046, 'The Fix S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103234.mp4', 'http://gstaticontent.com/images/6NfIhX3XjH7IBvUnctnhxoWnwRF_big.jpg'),
(16253, 1046, 'The Fix S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103235.mp4', 'http://gstaticontent.com/images/6NfIhX3XjH7IBvUnctnhxoWnwRF_big.jpg'),
(16254, 1046, 'The Fix S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103236.mp4', 'http://gstaticontent.com/images/6NfIhX3XjH7IBvUnctnhxoWnwRF_big.jpg'),
(16255, 1046, 'The Fix S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103237.mp4', 'http://gstaticontent.com/images/6NfIhX3XjH7IBvUnctnhxoWnwRF_big.jpg'),
(16256, 1046, 'The Fix S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103238.mp4', 'http://gstaticontent.com/images/6NfIhX3XjH7IBvUnctnhxoWnwRF_big.jpg'),
(16257, 1046, 'The Fix S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103239.mp4', 'http://gstaticontent.com/images/6NfIhX3XjH7IBvUnctnhxoWnwRF_big.jpg'),
(16258, 1046, 'The Fix S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103240.mp4', 'http://gstaticontent.com/images/6NfIhX3XjH7IBvUnctnhxoWnwRF_big.jpg'),
(16259, 1046, 'The Fix S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103241.mp4', 'http://gstaticontent.com/images/6NfIhX3XjH7IBvUnctnhxoWnwRF_big.jpg'),
(16260, 1046, 'The Fix S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103242.mp4', 'http://gstaticontent.com/images/6NfIhX3XjH7IBvUnctnhxoWnwRF_big.jpg'),
(16261, 1047, 'MasterChef Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236741.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16262, 1047, 'MasterChef Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236742.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16263, 1047, 'MasterChef Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236743.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16264, 1047, 'MasterChef Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236744.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16265, 1047, 'MasterChef Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236745.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16266, 1047, 'MasterChef Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236746.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16267, 1047, 'MasterChef Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236747.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16268, 1047, 'MasterChef Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236748.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16269, 1047, 'MasterChef Brasil S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236749.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16270, 1047, 'MasterChef Brasil S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236750.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16271, 1047, 'MasterChef Brasil S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236751.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16272, 1047, 'MasterChef Brasil S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236752.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16273, 1047, 'MasterChef Brasil S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236753.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16274, 1047, 'MasterChef Brasil S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236754.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16275, 1047, 'MasterChef Brasil S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236755.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16276, 1047, 'MasterChef Brasil S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236756.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16277, 1047, 'MasterChef Brasil S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236757.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16278, 1048, 'MasterChef Brasil S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236758.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16279, 1048, 'MasterChef Brasil S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236759.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16280, 1048, 'MasterChef Brasil S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236760.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16281, 1048, 'MasterChef Brasil S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236761.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16282, 1048, 'MasterChef Brasil S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236762.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16283, 1048, 'MasterChef Brasil S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236763.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16284, 1048, 'MasterChef Brasil S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236764.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16285, 1048, 'MasterChef Brasil S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236765.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16286, 1048, 'MasterChef Brasil S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236766.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16287, 1048, 'MasterChef Brasil S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236767.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16288, 1048, 'MasterChef Brasil S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236768.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16289, 1048, 'MasterChef Brasil S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236769.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16290, 1048, 'MasterChef Brasil S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236770.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16291, 1048, 'MasterChef Brasil S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236771.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16292, 1048, 'MasterChef Brasil S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236772.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16293, 1048, 'MasterChef Brasil S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236773.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(16294, 1048, 'MasterChef Brasil S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236774.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16295, 1048, 'MasterChef Brasil S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236775.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16296, 1049, 'MasterChef Brasil S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236776.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16297, 1049, 'MasterChef Brasil S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236777.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16298, 1049, 'MasterChef Brasil S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236778.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16299, 1049, 'MasterChef Brasil S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236779.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16300, 1049, 'MasterChef Brasil S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236780.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16301, 1049, 'MasterChef Brasil S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236781.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16302, 1049, 'MasterChef Brasil S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236782.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16303, 1049, 'MasterChef Brasil S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236783.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16304, 1049, 'MasterChef Brasil S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236784.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16305, 1049, 'MasterChef Brasil S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236785.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16306, 1049, 'MasterChef Brasil S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236786.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16307, 1049, 'MasterChef Brasil S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236787.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16308, 1049, 'MasterChef Brasil S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236788.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16309, 1049, 'MasterChef Brasil S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236789.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16310, 1049, 'MasterChef Brasil S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236790.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16311, 1049, 'MasterChef Brasil S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236791.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16312, 1049, 'MasterChef Brasil S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236792.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16313, 1049, 'MasterChef Brasil S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236793.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16314, 1049, 'MasterChef Brasil S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/236794.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16315, 1049, 'MasterChef Brasil S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/236795.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16316, 1049, 'MasterChef Brasil S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/236796.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16317, 1049, 'MasterChef Brasil S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/236797.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16318, 1049, 'MasterChef Brasil S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/236798.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16319, 1049, 'MasterChef Brasil S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/236799.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16320, 1049, 'MasterChef Brasil S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/236800.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16321, 1050, 'MasterChef Brasil S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236801.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16322, 1050, 'MasterChef Brasil S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236802.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16323, 1050, 'MasterChef Brasil S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236803.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16324, 1050, 'MasterChef Brasil S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236804.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16325, 1050, 'MasterChef Brasil S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236805.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16326, 1050, 'MasterChef Brasil S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236806.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16327, 1050, 'MasterChef Brasil S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236807.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16328, 1050, 'MasterChef Brasil S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236808.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16329, 1050, 'MasterChef Brasil S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236809.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16330, 1050, 'MasterChef Brasil S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236810.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16331, 1050, 'MasterChef Brasil S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236811.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16332, 1050, 'MasterChef Brasil S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236812.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16333, 1050, 'MasterChef Brasil S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236813.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16334, 1050, 'MasterChef Brasil S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236814.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16335, 1050, 'MasterChef Brasil S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236815.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16336, 1050, 'MasterChef Brasil S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236816.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16337, 1050, 'MasterChef Brasil S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236817.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16338, 1050, 'MasterChef Brasil S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236818.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16339, 1050, 'MasterChef Brasil S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/236819.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16340, 1050, 'MasterChef Brasil S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/236820.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16341, 1050, 'MasterChef Brasil S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/236821.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16342, 1050, 'MasterChef Brasil S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/236822.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16343, 1050, 'MasterChef Brasil S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/236823.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16344, 1050, 'MasterChef Brasil S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/236824.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16345, 1051, 'MasterChef Brasil S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236825.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16346, 1051, 'MasterChef Brasil S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236826.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16347, 1051, 'MasterChef Brasil S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236827.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16348, 1051, 'MasterChef Brasil S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236828.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16349, 1051, 'MasterChef Brasil S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236829.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16350, 1051, 'MasterChef Brasil S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236830.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16351, 1051, 'MasterChef Brasil S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236831.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16352, 1051, 'MasterChef Brasil S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236832.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16353, 1051, 'MasterChef Brasil S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236833.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16354, 1051, 'MasterChef Brasil S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236834.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16355, 1051, 'MasterChef Brasil S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236835.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16356, 1051, 'MasterChef Brasil S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236836.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16357, 1051, 'MasterChef Brasil S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236837.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16358, 1051, 'MasterChef Brasil S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236838.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16359, 1051, 'MasterChef Brasil S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236839.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16360, 1051, 'MasterChef Brasil S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236840.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16361, 1051, 'MasterChef Brasil S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236841.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16362, 1051, 'MasterChef Brasil S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236842.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16363, 1051, 'MasterChef Brasil S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/236843.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16364, 1051, 'MasterChef Brasil S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/236844.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16365, 1051, 'MasterChef Brasil S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/236845.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16366, 1051, 'MasterChef Brasil S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/236846.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16367, 1052, 'MasterChef Brasil S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236847.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16368, 1052, 'MasterChef Brasil S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236848.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16369, 1052, 'MasterChef Brasil S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236849.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16370, 1052, 'MasterChef Brasil S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236850.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16371, 1052, 'MasterChef Brasil S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236851.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16372, 1052, 'MasterChef Brasil S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236852.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16373, 1052, 'MasterChef Brasil S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236853.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16374, 1052, 'MasterChef Brasil S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236854.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16375, 1052, 'MasterChef Brasil S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236855.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16376, 1052, 'MasterChef Brasil S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236856.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16377, 1052, 'MasterChef Brasil S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236857.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16378, 1052, 'MasterChef Brasil S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236858.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16379, 1052, 'MasterChef Brasil S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236859.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16380, 1052, 'MasterChef Brasil S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236860.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16381, 1052, 'MasterChef Brasil S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236861.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16382, 1052, 'MasterChef Brasil S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236862.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16383, 1052, 'MasterChef Brasil S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236863.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16384, 1052, 'MasterChef Brasil S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236864.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16385, 1052, 'MasterChef Brasil S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/236865.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16386, 1052, 'MasterChef Brasil S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/236866.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16387, 1052, 'MasterChef Brasil S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/236867.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16388, 1052, 'MasterChef Brasil S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/236868.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16389, 1053, 'MasterChef Brasil S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236869.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16390, 1053, 'MasterChef Brasil S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236870.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16391, 1053, 'MasterChef Brasil S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236871.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16392, 1053, 'MasterChef Brasil S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236872.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16393, 1053, 'MasterChef Brasil S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236873.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16394, 1053, 'MasterChef Brasil S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236874.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16395, 1053, 'MasterChef Brasil S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236875.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16396, 1053, 'MasterChef Brasil S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236876.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16397, 1053, 'MasterChef Brasil S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236877.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16398, 1053, 'MasterChef Brasil S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236878.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16399, 1053, 'MasterChef Brasil S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236879.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16400, 1053, 'MasterChef Brasil S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236880.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16401, 1053, 'MasterChef Brasil S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236881.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16402, 1053, 'MasterChef Brasil S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236882.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16403, 1053, 'MasterChef Brasil S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236883.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16404, 1053, 'MasterChef Brasil S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236884.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16405, 1053, 'MasterChef Brasil S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236885.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16406, 1053, 'MasterChef Brasil S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236886.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16407, 1053, 'MasterChef Brasil S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/236887.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16408, 1053, 'MasterChef Brasil S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/236888.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16409, 1053, 'MasterChef Brasil S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/236889.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16410, 1053, 'MasterChef Brasil S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/236890.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16411, 1053, 'MasterChef Brasil S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/236891.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16412, 1053, 'MasterChef Brasil S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/236892.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16413, 1053, 'MasterChef Brasil S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/236893.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16414, 1054, 'MasterChef Brasil S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236894.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16415, 1054, 'MasterChef Brasil S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236895.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16416, 1054, 'MasterChef Brasil S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236896.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16417, 1054, 'MasterChef Brasil S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236897.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16418, 1054, 'MasterChef Brasil S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236898.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16419, 1054, 'MasterChef Brasil S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236899.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16420, 1054, 'MasterChef Brasil S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236900.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16421, 1054, 'MasterChef Brasil S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236901.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16422, 1054, 'MasterChef Brasil S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236902.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16423, 1054, 'MasterChef Brasil S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236903.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16424, 1054, 'MasterChef Brasil S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236904.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16425, 1054, 'MasterChef Brasil S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236905.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16426, 1054, 'MasterChef Brasil S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236906.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16427, 1054, 'MasterChef Brasil S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236907.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16428, 1054, 'MasterChef Brasil S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236908.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16429, 1054, 'MasterChef Brasil S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236909.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16430, 1054, 'MasterChef Brasil S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236910.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16431, 1054, 'MasterChef Brasil S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236911.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16432, 1054, 'MasterChef Brasil S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/236912.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16433, 1054, 'MasterChef Brasil S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/236913.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16434, 1054, 'MasterChef Brasil S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/236914.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16435, 1054, 'MasterChef Brasil S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/236915.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16436, 1054, 'MasterChef Brasil S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/236916.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16437, 1054, 'MasterChef Brasil S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/236917.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16438, 1054, 'MasterChef Brasil S08 E25', 'http://sinalprivado.info:80/series/1533784/1533784/236918.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16439, 1055, 'MasterChef Brasil S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236919.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16440, 1055, 'MasterChef Brasil S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236920.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16441, 1055, 'MasterChef Brasil S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236921.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16442, 1055, 'MasterChef Brasil S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236922.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16443, 1055, 'MasterChef Brasil S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236923.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16444, 1055, 'MasterChef Brasil S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236924.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16445, 1055, 'MasterChef Brasil S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236925.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16446, 1055, 'MasterChef Brasil S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236926.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16447, 1055, 'MasterChef Brasil S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236927.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16448, 1055, 'MasterChef Brasil S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236928.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16449, 1055, 'MasterChef Brasil S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236929.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16450, 1055, 'MasterChef Brasil S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236930.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16451, 1055, 'MasterChef Brasil S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236931.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16452, 1055, 'MasterChef Brasil S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236932.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16453, 1055, 'MasterChef Brasil S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236933.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16454, 1055, 'MasterChef Brasil S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236934.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16455, 1055, 'MasterChef Brasil S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236935.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16456, 1056, 'MasterChef Brasil S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236936.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16457, 1056, 'MasterChef Brasil S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236937.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16458, 1056, 'MasterChef Brasil S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236938.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16459, 1056, 'MasterChef Brasil S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236939.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16460, 1056, 'MasterChef Brasil S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236940.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16461, 1056, 'MasterChef Brasil S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236941.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16462, 1056, 'MasterChef Brasil S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236942.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16463, 1056, 'MasterChef Brasil S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236943.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16464, 1056, 'MasterChef Brasil S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236944.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16465, 1056, 'MasterChef Brasil S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236945.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16466, 1056, 'MasterChef Brasil S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236946.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16467, 1056, 'MasterChef Brasil S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236947.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16468, 1056, 'MasterChef Brasil S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236948.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16469, 1056, 'MasterChef Brasil S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236949.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16470, 1056, 'MasterChef Brasil S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236950.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16471, 1056, 'MasterChef Brasil S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236951.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16472, 1056, 'MasterChef Brasil S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236952.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16473, 1056, 'MasterChef Brasil S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236953.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16474, 1056, 'MasterChef Brasil S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/236954.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16475, 1056, 'MasterChef Brasil S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/236955.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16476, 1057, 'MasterChef Brasil S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/630390.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16477, 1057, 'MasterChef Brasil S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/392595.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16478, 1057, 'MasterChef Brasil S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/392596.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16479, 1057, 'MasterChef Brasil S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/392597.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16480, 1057, 'MasterChef Brasil S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/396658.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16481, 1057, 'MasterChef Brasil S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/401184.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16482, 1057, 'MasterChef Brasil S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/405091.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16483, 1057, 'MasterChef Brasil S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/412144.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16484, 1057, 'MasterChef Brasil S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/414921.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16485, 1057, 'MasterChef Brasil S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/421385.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16486, 1057, 'MasterChef Brasil S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/427331.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16487, 1057, 'MasterChef Brasil S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/429605.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16488, 1057, 'MasterChef Brasil S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/436332.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16489, 1057, 'MasterChef Brasil S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/442153.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16490, 1057, 'MasterChef Brasil S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/447600.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16491, 1057, 'MasterChef Brasil S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/452583.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16492, 1057, 'MasterChef Brasil S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/457838.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16493, 1057, 'MasterChef Brasil S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/464333.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16494, 1057, 'MasterChef Brasil S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/470248.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16495, 1057, 'MasterChef Brasil S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/477784.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16496, 1057, 'MasterChef Brasil S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/482940.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16497, 1057, 'MasterChef Brasil S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/491043.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16498, 1057, 'MasterChef Brasil S11 E23', 'http://sinalprivado.info:80/series/1533784/1533784/492514.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16499, 1057, 'MasterChef Brasil S11 E24', 'http://sinalprivado.info:80/series/1533784/1533784/500096.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16500, 1057, 'MasterChef Brasil S11 E25', 'http://sinalprivado.info:80/series/1533784/1533784/505821.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16501, 1058, 'MasterChef Brasil S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/816110.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16502, 1058, 'MasterChef Brasil S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/825482.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16503, 1058, 'MasterChef Brasil S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/836831.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16504, 1058, 'MasterChef Brasil S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/845615.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16505, 1058, 'MasterChef Brasil S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/850717.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16506, 1058, 'MasterChef Brasil S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/857488.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16507, 1058, 'MasterChef Brasil S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/864690.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16508, 1058, 'MasterChef Brasil S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/870596.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16509, 1058, 'MasterChef Brasil S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/874450.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16510, 1058, 'MasterChef Brasil S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/880397.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16511, 1058, 'MasterChef Brasil S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/880398.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16512, 1058, 'MasterChef Brasil S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/880399.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16513, 1058, 'MasterChef Brasil S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/881213.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16514, 1058, 'MasterChef Brasil S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/881324.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16515, 1058, 'MasterChef Brasil S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/882872.mp4', 'http://gstaticontent.com/images/84Ku5P8ISu3zQG0hC315WPjjsBx_big.jpg'),
(16516, 1059, 'Dragon Ball Classico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104609.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16517, 1059, 'Dragon Ball Classico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104610.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16518, 1059, 'Dragon Ball Classico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104611.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16519, 1059, 'Dragon Ball Classico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104612.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16520, 1059, 'Dragon Ball Classico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104613.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16521, 1059, 'Dragon Ball Classico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104614.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16522, 1059, 'Dragon Ball Classico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104615.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16523, 1059, 'Dragon Ball Classico S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104616.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16524, 1059, 'Dragon Ball Classico S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104617.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16525, 1059, 'Dragon Ball Classico S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104618.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16526, 1059, 'Dragon Ball Classico S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/104619.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16527, 1059, 'Dragon Ball Classico S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/104620.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16528, 1059, 'Dragon Ball Classico S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/104621.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16529, 1059, 'Dragon Ball Classico S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/104622.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16530, 1059, 'Dragon Ball Classico S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/104623.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16531, 1059, 'Dragon Ball Classico S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/104624.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16532, 1059, 'Dragon Ball Classico S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/104625.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16533, 1059, 'Dragon Ball Classico S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/104626.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16534, 1059, 'Dragon Ball Classico S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/104627.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16535, 1059, 'Dragon Ball Classico S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/104628.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16536, 1059, 'Dragon Ball Classico S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/104629.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16537, 1059, 'Dragon Ball Classico S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/104630.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16538, 1059, 'Dragon Ball Classico S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/104631.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16539, 1059, 'Dragon Ball Classico S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/104632.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16540, 1059, 'Dragon Ball Classico S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/104633.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16541, 1059, 'Dragon Ball Classico S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/104634.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16542, 1059, 'Dragon Ball Classico S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/104635.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16543, 1059, 'Dragon Ball Classico S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/104636.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16544, 1059, 'Dragon Ball Classico S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/104637.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16545, 1059, 'Dragon Ball Classico S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/104638.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16546, 1059, 'Dragon Ball Classico S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/104639.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16547, 1059, 'Dragon Ball Classico S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/104640.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16548, 1059, 'Dragon Ball Classico S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/104641.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16549, 1059, 'Dragon Ball Classico S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/104642.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16550, 1059, 'Dragon Ball Classico S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/104643.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16551, 1059, 'Dragon Ball Classico S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/104644.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16552, 1059, 'Dragon Ball Classico S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/104645.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16553, 1059, 'Dragon Ball Classico S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/104646.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16554, 1059, 'Dragon Ball Classico S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/104647.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16555, 1059, 'Dragon Ball Classico S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/104648.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16556, 1059, 'Dragon Ball Classico S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/104649.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16557, 1059, 'Dragon Ball Classico S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/104650.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16558, 1059, 'Dragon Ball Classico S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/104651.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16559, 1059, 'Dragon Ball Classico S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/104652.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16560, 1059, 'Dragon Ball Classico S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/104653.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16561, 1059, 'Dragon Ball Classico S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/104654.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16562, 1059, 'Dragon Ball Classico S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/104655.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16563, 1059, 'Dragon Ball Classico S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/104656.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16564, 1059, 'Dragon Ball Classico S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/104657.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16565, 1059, 'Dragon Ball Classico S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/104658.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16566, 1059, 'Dragon Ball Classico S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/104659.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16567, 1059, 'Dragon Ball Classico S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/104660.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16568, 1059, 'Dragon Ball Classico S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/104661.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16569, 1059, 'Dragon Ball Classico S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/104662.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16570, 1059, 'Dragon Ball Classico S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/104663.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16571, 1059, 'Dragon Ball Classico S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/104664.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16572, 1059, 'Dragon Ball Classico S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/104665.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(16573, 1059, 'Dragon Ball Classico S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/104666.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16574, 1059, 'Dragon Ball Classico S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/104667.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16575, 1059, 'Dragon Ball Classico S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/104668.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16576, 1059, 'Dragon Ball Classico S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/104669.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16577, 1059, 'Dragon Ball Classico S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/104670.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16578, 1059, 'Dragon Ball Classico S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/104671.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16579, 1059, 'Dragon Ball Classico S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/104672.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16580, 1059, 'Dragon Ball Classico S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/104673.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16581, 1059, 'Dragon Ball Classico S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/104674.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16582, 1059, 'Dragon Ball Classico S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/104675.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16583, 1059, 'Dragon Ball Classico S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/104676.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16584, 1059, 'Dragon Ball Classico S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/104677.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16585, 1059, 'Dragon Ball Classico S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/104678.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16586, 1059, 'Dragon Ball Classico S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/104679.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16587, 1059, 'Dragon Ball Classico S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/104680.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16588, 1059, 'Dragon Ball Classico S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/104681.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16589, 1059, 'Dragon Ball Classico S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/104682.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16590, 1059, 'Dragon Ball Classico S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/104683.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16591, 1059, 'Dragon Ball Classico S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/104684.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16592, 1059, 'Dragon Ball Classico S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/104685.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16593, 1059, 'Dragon Ball Classico S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/104686.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16594, 1059, 'Dragon Ball Classico S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/104687.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16595, 1059, 'Dragon Ball Classico S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/104688.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16596, 1059, 'Dragon Ball Classico S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/104689.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16597, 1059, 'Dragon Ball Classico S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/104690.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16598, 1059, 'Dragon Ball Classico S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/104691.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16599, 1059, 'Dragon Ball Classico S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/104692.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16600, 1059, 'Dragon Ball Classico S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/104693.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16601, 1059, 'Dragon Ball Classico S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/104694.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16602, 1059, 'Dragon Ball Classico S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/104695.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16603, 1059, 'Dragon Ball Classico S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/104696.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16604, 1059, 'Dragon Ball Classico S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/104697.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16605, 1059, 'Dragon Ball Classico S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/104698.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16606, 1059, 'Dragon Ball Classico S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/104699.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16607, 1059, 'Dragon Ball Classico S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/104700.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16608, 1059, 'Dragon Ball Classico S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/104701.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16609, 1059, 'Dragon Ball Classico S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/104702.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16610, 1059, 'Dragon Ball Classico S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/104703.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16611, 1059, 'Dragon Ball Classico S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/104704.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16612, 1059, 'Dragon Ball Classico S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/104705.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16613, 1059, 'Dragon Ball Classico S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/104706.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16614, 1059, 'Dragon Ball Classico S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/104707.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16615, 1059, 'Dragon Ball Classico S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/104708.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16616, 1059, 'Dragon Ball Classico S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/104709.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16617, 1059, 'Dragon Ball Classico S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/104710.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16618, 1059, 'Dragon Ball Classico S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/104711.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16619, 1059, 'Dragon Ball Classico S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/104712.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16620, 1059, 'Dragon Ball Classico S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/104713.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16621, 1059, 'Dragon Ball Classico S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/104714.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16622, 1059, 'Dragon Ball Classico S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/104715.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16623, 1059, 'Dragon Ball Classico S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/104716.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16624, 1059, 'Dragon Ball Classico S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/104717.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16625, 1059, 'Dragon Ball Classico S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/104718.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16626, 1059, 'Dragon Ball Classico S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/104719.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16627, 1059, 'Dragon Ball Classico S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/104720.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16628, 1059, 'Dragon Ball Classico S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/104721.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16629, 1059, 'Dragon Ball Classico S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/104722.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16630, 1059, 'Dragon Ball Classico S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/104723.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16631, 1059, 'Dragon Ball Classico S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/104724.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16632, 1059, 'Dragon Ball Classico S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/104725.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16633, 1059, 'Dragon Ball Classico S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/104726.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16634, 1059, 'Dragon Ball Classico S01 E119', 'http://sinalprivado.info:80/series/1533784/1533784/104727.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16635, 1059, 'Dragon Ball Classico S01 E120', 'http://sinalprivado.info:80/series/1533784/1533784/104728.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16636, 1059, 'Dragon Ball Classico S01 E121', 'http://sinalprivado.info:80/series/1533784/1533784/104729.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16637, 1059, 'Dragon Ball Classico S01 E122', 'http://sinalprivado.info:80/series/1533784/1533784/104730.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16638, 1059, 'Dragon Ball Classico S01 E123', 'http://sinalprivado.info:80/series/1533784/1533784/104731.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16639, 1059, 'Dragon Ball Classico S01 E124', 'http://sinalprivado.info:80/series/1533784/1533784/104732.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16640, 1059, 'Dragon Ball Classico S01 E125', 'http://sinalprivado.info:80/series/1533784/1533784/104733.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16641, 1059, 'Dragon Ball Classico S01 E126', 'http://sinalprivado.info:80/series/1533784/1533784/104734.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16642, 1059, 'Dragon Ball Classico S01 E127', 'http://sinalprivado.info:80/series/1533784/1533784/104735.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16643, 1059, 'Dragon Ball Classico S01 E128', 'http://sinalprivado.info:80/series/1533784/1533784/104736.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16644, 1059, 'Dragon Ball Classico S01 E129', 'http://sinalprivado.info:80/series/1533784/1533784/104737.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16645, 1059, 'Dragon Ball Classico S01 E130', 'http://sinalprivado.info:80/series/1533784/1533784/104738.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16646, 1059, 'Dragon Ball Classico S01 E131', 'http://sinalprivado.info:80/series/1533784/1533784/104739.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16647, 1059, 'Dragon Ball Classico S01 E132', 'http://sinalprivado.info:80/series/1533784/1533784/104740.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16648, 1059, 'Dragon Ball Classico S01 E133', 'http://sinalprivado.info:80/series/1533784/1533784/104741.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16649, 1059, 'Dragon Ball Classico S01 E134', 'http://sinalprivado.info:80/series/1533784/1533784/104742.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16650, 1059, 'Dragon Ball Classico S01 E135', 'http://sinalprivado.info:80/series/1533784/1533784/104743.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16651, 1059, 'Dragon Ball Classico S01 E136', 'http://sinalprivado.info:80/series/1533784/1533784/104744.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16652, 1059, 'Dragon Ball Classico S01 E137', 'http://sinalprivado.info:80/series/1533784/1533784/104745.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16653, 1059, 'Dragon Ball Classico S01 E138', 'http://sinalprivado.info:80/series/1533784/1533784/104746.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16654, 1059, 'Dragon Ball Classico S01 E139', 'http://sinalprivado.info:80/series/1533784/1533784/104747.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16655, 1059, 'Dragon Ball Classico S01 E140', 'http://sinalprivado.info:80/series/1533784/1533784/104748.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16656, 1059, 'Dragon Ball Classico S01 E141', 'http://sinalprivado.info:80/series/1533784/1533784/104749.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16657, 1059, 'Dragon Ball Classico S01 E142', 'http://sinalprivado.info:80/series/1533784/1533784/104750.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16658, 1059, 'Dragon Ball Classico S01 E143', 'http://sinalprivado.info:80/series/1533784/1533784/104751.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16659, 1059, 'Dragon Ball Classico S01 E144', 'http://sinalprivado.info:80/series/1533784/1533784/104752.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16660, 1059, 'Dragon Ball Classico S01 E145', 'http://sinalprivado.info:80/series/1533784/1533784/104753.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16661, 1059, 'Dragon Ball Classico S01 E146', 'http://sinalprivado.info:80/series/1533784/1533784/104754.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16662, 1059, 'Dragon Ball Classico S01 E147', 'http://sinalprivado.info:80/series/1533784/1533784/104755.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16663, 1059, 'Dragon Ball Classico S01 E148', 'http://sinalprivado.info:80/series/1533784/1533784/104756.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16664, 1059, 'Dragon Ball Classico S01 E149', 'http://sinalprivado.info:80/series/1533784/1533784/104757.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16665, 1059, 'Dragon Ball Classico S01 E150', 'http://sinalprivado.info:80/series/1533784/1533784/104758.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16666, 1059, 'Dragon Ball Classico S01 E151', 'http://sinalprivado.info:80/series/1533784/1533784/104759.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16667, 1059, 'Dragon Ball Classico S01 E152', 'http://sinalprivado.info:80/series/1533784/1533784/104760.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16668, 1059, 'Dragon Ball Classico S01 E153', 'http://sinalprivado.info:80/series/1533784/1533784/104761.mp4', 'http://gstaticontent.com/images/6sMyV1KRpvnOTsry7ZUT0k2tDmk_big.jpg'),
(16669, 1060, 'Mr. Iglesias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104599.mp4', 'http://gstaticontent.com/images/ruNVQ6S87T1JipVdvllcDQlgwb3_big.jpg'),
(16670, 1060, 'Mr. Iglesias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104600.mp4', 'http://gstaticontent.com/images/ruNVQ6S87T1JipVdvllcDQlgwb3_big.jpg'),
(16671, 1060, 'Mr. Iglesias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104601.mp4', 'http://gstaticontent.com/images/ruNVQ6S87T1JipVdvllcDQlgwb3_big.jpg'),
(16672, 1060, 'Mr. Iglesias S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104602.mp4', 'http://gstaticontent.com/images/ruNVQ6S87T1JipVdvllcDQlgwb3_big.jpg'),
(16673, 1060, 'Mr. Iglesias S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104603.mp4', 'http://gstaticontent.com/images/ruNVQ6S87T1JipVdvllcDQlgwb3_big.jpg'),
(16674, 1060, 'Mr. Iglesias S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104604.mp4', 'http://gstaticontent.com/images/ruNVQ6S87T1JipVdvllcDQlgwb3_big.jpg'),
(16675, 1060, 'Mr. Iglesias S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104605.mp4', 'http://gstaticontent.com/images/ruNVQ6S87T1JipVdvllcDQlgwb3_big.jpg'),
(16676, 1060, 'Mr. Iglesias S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104606.mp4', 'http://gstaticontent.com/images/ruNVQ6S87T1JipVdvllcDQlgwb3_big.jpg'),
(16677, 1060, 'Mr. Iglesias S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104607.mp4', 'http://gstaticontent.com/images/ruNVQ6S87T1JipVdvllcDQlgwb3_big.jpg'),
(16678, 1060, 'Mr. Iglesias S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104608.mp4', 'http://gstaticontent.com/images/ruNVQ6S87T1JipVdvllcDQlgwb3_big.jpg'),
(16679, 1061, 'Euphoria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174808.mp4', 'http://timg.bdta.pro/images/e30aa2f934f923bb46bfac3768d1f542.jpg'),
(16680, 1061, 'Euphoria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174809.mp4', 'http://timg.bdta.pro/images/32e7865c6b18ec70563185c79677a40e.jpg'),
(16681, 1061, 'Euphoria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174810.mp4', 'http://timg.bdta.pro/images/9fa36bc5ace1faac02a4ee0c9aed30f1.jpg'),
(16682, 1061, 'Euphoria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174811.mp4', 'http://timg.bdta.pro/images/91dc4dd81c46cfbf46d5d43b6625cad9.jpg'),
(16683, 1061, 'Euphoria S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174812.mp4', 'http://timg.bdta.pro/images/bcc561201395db265124696bc972d12d.jpg'),
(16684, 1061, 'Euphoria S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174813.mp4', 'http://timg.bdta.pro/images/8b893c3168d330912cdd7ae527283965.jpg'),
(16685, 1061, 'Euphoria S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174814.mp4', 'http://timg.bdta.pro/images/7893eb00125b13100b935ba98d6dc606.jpg'),
(16686, 1061, 'Euphoria S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174815.mp4', 'http://timg.bdta.pro/images/cc022b3c9aef7e0507cbb36052298241.jpg'),
(16687, 1061, 'Euphoria S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174816.mp4', 'http://gstaticontent.com/images/5mi3aRl16yKmfpQJMzvqN5TXkdA_big.jpg'),
(16688, 1061, 'Euphoria S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174817.mp4', 'http://gstaticontent.com/images/5mi3aRl16yKmfpQJMzvqN5TXkdA_big.jpg'),
(16689, 1062, 'Euphoria S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174818.mp4', 'http://image.tmdb.org/t/p/w1280/p3oOluSyg2WkUxgShqc0Ji68YiN.jpg'),
(16690, 1062, 'Euphoria S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174819.mp4', 'http://image.tmdb.org/t/p/w1280/rCYPediP7oA0ybibYCDeRmCBKJo.jpg'),
(16691, 1062, 'Euphoria S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174820.mp4', 'http://timg.bdta.pro/images/a83a83eecc240af49bd3882cb1b41399.jpg'),
(16692, 1062, 'Euphoria S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174821.mp4', 'http://timg.bdta.pro/images/8422ad1e5bf61845ed6570ff058582a3.jpg'),
(16693, 1062, 'Euphoria S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174822.mp4', 'http://timg.bdta.pro/images/20ed7485ebc41ac0a10ddf519d731407.jpg'),
(16694, 1062, 'Euphoria S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174823.mp4', 'http://timg.bdta.pro/images/ecdfd7a1e1c285fce6b6e40e55716d9b.jpg'),
(16695, 1062, 'Euphoria S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174824.mp4', 'http://timg.bdta.pro/images/27b365a6f07291c79613ad6e5335eb8c.jpg'),
(16696, 1062, 'Euphoria S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174825.mp4', 'http://timg.bdta.pro/images/8cfc06ac0a6a7c2a9d3e002e5a69d186.jpg'),
(16697, 1063, 'Single Parents S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104593.mp4', 'http://gstaticontent.com/images/6C4gUhBoIfN6ctohW8mkdL5mex8_big.jpg'),
(16698, 1063, 'Single Parents S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104594.mp4', 'http://gstaticontent.com/images/6C4gUhBoIfN6ctohW8mkdL5mex8_big.jpg'),
(16699, 1063, 'Single Parents S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104595.mp4', 'http://gstaticontent.com/images/6C4gUhBoIfN6ctohW8mkdL5mex8_big.jpg'),
(16700, 1063, 'Single Parents S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104596.mp4', 'http://gstaticontent.com/images/6C4gUhBoIfN6ctohW8mkdL5mex8_big.jpg'),
(16701, 1063, 'Single Parents S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104597.mp4', 'http://gstaticontent.com/images/6C4gUhBoIfN6ctohW8mkdL5mex8_big.jpg'),
(16702, 1063, 'Single Parents S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104598.mp4', 'http://gstaticontent.com/images/6C4gUhBoIfN6ctohW8mkdL5mex8_big.jpg'),
(16703, 1064, 'Too Old to Die Young S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104583.mp4', 'http://gstaticontent.com/images/6pvWn7uPMRAOZWjKh7EDBITqVo1_big.jpg'),
(16704, 1064, 'Too Old to Die Young S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104584.mp4', 'http://gstaticontent.com/images/6pvWn7uPMRAOZWjKh7EDBITqVo1_big.jpg'),
(16705, 1064, 'Too Old to Die Young S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104585.mp4', 'http://gstaticontent.com/images/6pvWn7uPMRAOZWjKh7EDBITqVo1_big.jpg'),
(16706, 1064, 'Too Old to Die Young S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104586.mp4', 'http://gstaticontent.com/images/6pvWn7uPMRAOZWjKh7EDBITqVo1_big.jpg'),
(16707, 1064, 'Too Old to Die Young S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104587.mp4', 'http://gstaticontent.com/images/6pvWn7uPMRAOZWjKh7EDBITqVo1_big.jpg'),
(16708, 1064, 'Too Old to Die Young S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104588.mp4', 'http://gstaticontent.com/images/6pvWn7uPMRAOZWjKh7EDBITqVo1_big.jpg'),
(16709, 1064, 'Too Old to Die Young S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104589.mp4', 'http://gstaticontent.com/images/6pvWn7uPMRAOZWjKh7EDBITqVo1_big.jpg'),
(16710, 1064, 'Too Old to Die Young S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104590.mp4', 'http://gstaticontent.com/images/6pvWn7uPMRAOZWjKh7EDBITqVo1_big.jpg'),
(16711, 1064, 'Too Old to Die Young S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104591.mp4', 'http://gstaticontent.com/images/6pvWn7uPMRAOZWjKh7EDBITqVo1_big.jpg'),
(16712, 1064, 'Too Old to Die Young S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104592.mp4', 'http://gstaticontent.com/images/6pvWn7uPMRAOZWjKh7EDBITqVo1_big.jpg'),
(16713, 1065, 'Vis A Vis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106787.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16714, 1065, 'Vis A Vis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106788.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16715, 1065, 'Vis A Vis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106789.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16716, 1065, 'Vis A Vis S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106790.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16717, 1065, 'Vis A Vis S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106791.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16718, 1065, 'Vis A Vis S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106792.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16719, 1065, 'Vis A Vis S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106793.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16720, 1065, 'Vis A Vis S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106794.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16721, 1065, 'Vis A Vis S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106795.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16722, 1065, 'Vis A Vis S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106796.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16723, 1065, 'Vis A Vis S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106797.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16724, 1066, 'Vis A Vis S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106798.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16725, 1066, 'Vis A Vis S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106799.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16726, 1066, 'Vis A Vis S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106800.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16727, 1066, 'Vis A Vis S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106801.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16728, 1066, 'Vis A Vis S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106802.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16729, 1066, 'Vis A Vis S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106803.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16730, 1066, 'Vis A Vis S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106804.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16731, 1066, 'Vis A Vis S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106805.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16732, 1066, 'Vis A Vis S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106806.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16733, 1066, 'Vis A Vis S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106807.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16734, 1066, 'Vis A Vis S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106808.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16735, 1066, 'Vis A Vis S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/106809.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16736, 1066, 'Vis A Vis S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/106810.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16737, 1067, 'Vis A Vis S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106811.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16738, 1067, 'Vis A Vis S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106812.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16739, 1067, 'Vis A Vis S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106813.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16740, 1067, 'Vis A Vis S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106814.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16741, 1067, 'Vis A Vis S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106815.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16742, 1067, 'Vis A Vis S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106816.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16743, 1067, 'Vis A Vis S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106817.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16744, 1067, 'Vis A Vis S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106818.mp4', 'http://gstaticontent.com/images/vIFsPAn5EFHZnimvekXhi4LJf1p_big.jpg'),
(16745, 1068, 'Vis A Vis S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106819.mp4', 'http://timg.bdta.pro/images/ccd8f13b37db51fe99325ef7e30a3004.jpg'),
(16746, 1068, 'Vis A Vis S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106820.mp4', 'http://timg.bdta.pro/images/9124c71090c1ec393d6a925494e14adb.jpg'),
(16747, 1068, 'Vis A Vis S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106821.mp4', 'http://timg.bdta.pro/images/eba1f60cf776b17c35967b833af9bf82.jpg'),
(16748, 1068, 'Vis A Vis S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106822.mp4', 'http://timg.bdta.pro/images/9aac5ca941752af3f3af7fa6354ced8a.jpg'),
(16749, 1068, 'Vis A Vis S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106823.mp4', 'http://timg.bdta.pro/images/d40968800aef72d44f37960f00516aa6.jpg'),
(16750, 1068, 'Vis A Vis S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106824.mp4', 'http://timg.bdta.pro/images/55e60068fc3d08651b9e6f2d35a36140.jpg'),
(16751, 1068, 'Vis A Vis S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106825.mp4', 'http://timg.bdta.pro/images/99c8f58eaaad0e2c1bc27c63fa7399eb.jpg'),
(16752, 1068, 'Vis A Vis S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106826.mp4', 'http://timg.bdta.pro/images/4af479d982d84d1f134b97f92af25740.jpg'),
(16753, 1069, 'True Detective S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104559.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16754, 1069, 'True Detective S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104560.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16755, 1069, 'True Detective S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104561.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16756, 1069, 'True Detective S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104562.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16757, 1069, 'True Detective S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104563.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16758, 1069, 'True Detective S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104564.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16759, 1069, 'True Detective S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104565.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16760, 1069, 'True Detective S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104566.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16761, 1070, 'True Detective S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104567.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16762, 1070, 'True Detective S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104568.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16763, 1070, 'True Detective S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104569.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16764, 1070, 'True Detective S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104570.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16765, 1070, 'True Detective S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104571.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16766, 1070, 'True Detective S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104572.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16767, 1070, 'True Detective S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104573.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16768, 1070, 'True Detective S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104574.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16769, 1071, 'True Detective S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104575.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16770, 1071, 'True Detective S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104576.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16771, 1071, 'True Detective S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104577.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16772, 1071, 'True Detective S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104578.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16773, 1071, 'True Detective S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104579.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16774, 1071, 'True Detective S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104580.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16775, 1071, 'True Detective S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104581.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16776, 1071, 'True Detective S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104582.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16777, 1072, 'True Detective S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/270557.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16778, 1072, 'True Detective S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/270558.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16779, 1072, 'True Detective S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/270559.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16780, 1072, 'True Detective S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/270560.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16781, 1072, 'True Detective S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/270722.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16782, 1072, 'True Detective S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274930.mp4', 'http://gstaticontent.com/images/aowr4xpLP5sRCL50TkuADomJ98T_big.jpg'),
(16783, 1073, 'As Maiores Maquinas Do Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104553.mp4', 'http://gstaticontent.com/images/ofBqhfdH3MGM0U4NRTAxuqsCGYa_big.jpg'),
(16784, 1073, 'As Maiores Maquinas Do Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104554.mp4', 'http://gstaticontent.com/images/ofBqhfdH3MGM0U4NRTAxuqsCGYa_big.jpg'),
(16785, 1073, 'As Maiores Maquinas Do Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104555.mp4', 'http://gstaticontent.com/images/ofBqhfdH3MGM0U4NRTAxuqsCGYa_big.jpg'),
(16786, 1073, 'As Maiores Maquinas Do Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104556.mp4', 'http://gstaticontent.com/images/ofBqhfdH3MGM0U4NRTAxuqsCGYa_big.jpg'),
(16787, 1073, 'As Maiores Maquinas Do Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104557.mp4', 'http://gstaticontent.com/images/ofBqhfdH3MGM0U4NRTAxuqsCGYa_big.jpg'),
(16788, 1073, 'As Maiores Maquinas Do Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104558.mp4', 'http://gstaticontent.com/images/ofBqhfdH3MGM0U4NRTAxuqsCGYa_big.jpg'),
(16789, 1074, 'Los Espookys S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104550.mp4', 'http://gstaticontent.com/images/ta0weEMHFnnLArj0RCicSZBQuRk_big.jpg'),
(16790, 1074, 'Los Espookys S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104551.mp4', 'http://gstaticontent.com/images/ta0weEMHFnnLArj0RCicSZBQuRk_big.jpg'),
(16791, 1074, 'Los Espookys S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104552.mp4', 'http://gstaticontent.com/images/ta0weEMHFnnLArj0RCicSZBQuRk_big.jpg'),
(16792, 1075, 'Valley of the Boom S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104544.mp4', 'http://gstaticontent.com/images/8SEBKi1AvwzBu2mmqLLX7GcYnCS_big.jpg'),
(16793, 1075, 'Valley of the Boom S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104545.mp4', 'http://gstaticontent.com/images/8SEBKi1AvwzBu2mmqLLX7GcYnCS_big.jpg'),
(16794, 1075, 'Valley of the Boom S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104546.mp4', 'http://gstaticontent.com/images/8SEBKi1AvwzBu2mmqLLX7GcYnCS_big.jpg'),
(16795, 1075, 'Valley of the Boom S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104547.mp4', 'http://gstaticontent.com/images/8SEBKi1AvwzBu2mmqLLX7GcYnCS_big.jpg'),
(16796, 1075, 'Valley of the Boom S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104548.mp4', 'http://gstaticontent.com/images/8SEBKi1AvwzBu2mmqLLX7GcYnCS_big.jpg'),
(16797, 1075, 'Valley of the Boom S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104549.mp4', 'http://gstaticontent.com/images/8SEBKi1AvwzBu2mmqLLX7GcYnCS_big.jpg'),
(16798, 1076, 'Provas Suspeitas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104540.mp4', 'http://gstaticontent.com/images/fqyDyPlvovDP0qxKs6l837V804p_big.jpg'),
(16799, 1076, 'Provas Suspeitas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104541.mp4', 'http://gstaticontent.com/images/fqyDyPlvovDP0qxKs6l837V804p_big.jpg'),
(16800, 1076, 'Provas Suspeitas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104542.mp4', 'http://gstaticontent.com/images/fqyDyPlvovDP0qxKs6l837V804p_big.jpg'),
(16801, 1076, 'Provas Suspeitas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104543.mp4', 'http://gstaticontent.com/images/fqyDyPlvovDP0qxKs6l837V804p_big.jpg'),
(16802, 1077, 'Aruanas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164026.mp4', 'http://gstaticontent.com/images/xeFwKEy9wIOGJLZ5s4vDpoPbDrZ_big.jpg'),
(16803, 1077, 'Aruanas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164027.mp4', 'http://gstaticontent.com/images/xeFwKEy9wIOGJLZ5s4vDpoPbDrZ_big.jpg'),
(16804, 1077, 'Aruanas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164028.mp4', 'http://gstaticontent.com/images/xeFwKEy9wIOGJLZ5s4vDpoPbDrZ_big.jpg'),
(16805, 1077, 'Aruanas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164029.mp4', 'http://gstaticontent.com/images/xeFwKEy9wIOGJLZ5s4vDpoPbDrZ_big.jpg'),
(16806, 1077, 'Aruanas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164030.mp4', 'http://gstaticontent.com/images/xeFwKEy9wIOGJLZ5s4vDpoPbDrZ_big.jpg'),
(16807, 1077, 'Aruanas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164031.mp4', 'http://gstaticontent.com/images/xeFwKEy9wIOGJLZ5s4vDpoPbDrZ_big.jpg'),
(16808, 1077, 'Aruanas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164032.mp4', 'http://gstaticontent.com/images/xeFwKEy9wIOGJLZ5s4vDpoPbDrZ_big.jpg'),
(16809, 1077, 'Aruanas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164033.mp4', 'http://gstaticontent.com/images/xeFwKEy9wIOGJLZ5s4vDpoPbDrZ_big.jpg'),
(16810, 1077, 'Aruanas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164034.mp4', 'http://gstaticontent.com/images/xeFwKEy9wIOGJLZ5s4vDpoPbDrZ_big.jpg'),
(16811, 1077, 'Aruanas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164035.mp4', 'http://gstaticontent.com/images/xeFwKEy9wIOGJLZ5s4vDpoPbDrZ_big.jpg'),
(16812, 1078, 'Aruanas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164036.mp4', 'http://gstaticontent.com/images/xeFwKEy9wIOGJLZ5s4vDpoPbDrZ_big.jpg'),
(16813, 1078, 'Aruanas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164037.mp4', 'http://gstaticontent.com/images/xeFwKEy9wIOGJLZ5s4vDpoPbDrZ_big.jpg'),
(16814, 1078, 'Aruanas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164038.mp4', 'http://gstaticontent.com/images/xeFwKEy9wIOGJLZ5s4vDpoPbDrZ_big.jpg'),
(16815, 1078, 'Aruanas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164039.mp4', 'http://gstaticontent.com/images/xeFwKEy9wIOGJLZ5s4vDpoPbDrZ_big.jpg'),
(16816, 1078, 'Aruanas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164040.mp4', 'http://gstaticontent.com/images/xeFwKEy9wIOGJLZ5s4vDpoPbDrZ_big.jpg'),
(16817, 1078, 'Aruanas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164041.mp4', 'http://gstaticontent.com/images/xeFwKEy9wIOGJLZ5s4vDpoPbDrZ_big.jpg'),
(16818, 1078, 'Aruanas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164042.mp4', 'http://gstaticontent.com/images/xeFwKEy9wIOGJLZ5s4vDpoPbDrZ_big.jpg'),
(16819, 1078, 'Aruanas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164043.mp4', 'http://gstaticontent.com/images/xeFwKEy9wIOGJLZ5s4vDpoPbDrZ_big.jpg'),
(16820, 1078, 'Aruanas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164044.mp4', 'http://gstaticontent.com/images/xeFwKEy9wIOGJLZ5s4vDpoPbDrZ_big.jpg'),
(16821, 1078, 'Aruanas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164045.mp4', 'http://gstaticontent.com/images/xeFwKEy9wIOGJLZ5s4vDpoPbDrZ_big.jpg'),
(16822, 1079, 'Girls Incarcerated S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104524.mp4', 'http://gstaticontent.com/images/tDDouGXzhuFHBbUrxY9toR0Ocbv_big.jpg'),
(16823, 1079, 'Girls Incarcerated S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104525.mp4', 'http://gstaticontent.com/images/tDDouGXzhuFHBbUrxY9toR0Ocbv_big.jpg'),
(16824, 1079, 'Girls Incarcerated S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104526.mp4', 'http://gstaticontent.com/images/tDDouGXzhuFHBbUrxY9toR0Ocbv_big.jpg'),
(16825, 1079, 'Girls Incarcerated S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104527.mp4', 'http://gstaticontent.com/images/tDDouGXzhuFHBbUrxY9toR0Ocbv_big.jpg'),
(16826, 1079, 'Girls Incarcerated S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104528.mp4', 'http://gstaticontent.com/images/tDDouGXzhuFHBbUrxY9toR0Ocbv_big.jpg'),
(16827, 1079, 'Girls Incarcerated S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104529.mp4', 'http://gstaticontent.com/images/tDDouGXzhuFHBbUrxY9toR0Ocbv_big.jpg'),
(16828, 1079, 'Girls Incarcerated S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104530.mp4', 'http://gstaticontent.com/images/tDDouGXzhuFHBbUrxY9toR0Ocbv_big.jpg'),
(16829, 1079, 'Girls Incarcerated S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104531.mp4', 'http://gstaticontent.com/images/tDDouGXzhuFHBbUrxY9toR0Ocbv_big.jpg'),
(16830, 1080, 'Girls Incarcerated S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104532.mp4', 'http://gstaticontent.com/images/tDDouGXzhuFHBbUrxY9toR0Ocbv_big.jpg'),
(16831, 1080, 'Girls Incarcerated S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104533.mp4', 'http://gstaticontent.com/images/tDDouGXzhuFHBbUrxY9toR0Ocbv_big.jpg'),
(16832, 1080, 'Girls Incarcerated S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104534.mp4', 'http://gstaticontent.com/images/tDDouGXzhuFHBbUrxY9toR0Ocbv_big.jpg'),
(16833, 1080, 'Girls Incarcerated S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104535.mp4', 'http://gstaticontent.com/images/tDDouGXzhuFHBbUrxY9toR0Ocbv_big.jpg'),
(16834, 1080, 'Girls Incarcerated S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104536.mp4', 'http://gstaticontent.com/images/tDDouGXzhuFHBbUrxY9toR0Ocbv_big.jpg'),
(16835, 1080, 'Girls Incarcerated S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104537.mp4', 'http://gstaticontent.com/images/tDDouGXzhuFHBbUrxY9toR0Ocbv_big.jpg'),
(16836, 1080, 'Girls Incarcerated S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104538.mp4', 'http://gstaticontent.com/images/tDDouGXzhuFHBbUrxY9toR0Ocbv_big.jpg'),
(16837, 1080, 'Girls Incarcerated S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104539.mp4', 'http://gstaticontent.com/images/tDDouGXzhuFHBbUrxY9toR0Ocbv_big.jpg'),
(16838, 1081, '7 Seeds S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108835.mp4', 'http://gstaticontent.com/images/v3es21M3q4yKBxNhSImReB7Wh8U_big.jpg'),
(16839, 1081, '7 Seeds S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108836.mp4', 'http://gstaticontent.com/images/v3es21M3q4yKBxNhSImReB7Wh8U_big.jpg'),
(16840, 1081, '7 Seeds S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108837.mp4', 'http://gstaticontent.com/images/v3es21M3q4yKBxNhSImReB7Wh8U_big.jpg'),
(16841, 1081, '7 Seeds S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108838.mp4', 'http://gstaticontent.com/images/v3es21M3q4yKBxNhSImReB7Wh8U_big.jpg'),
(16842, 1081, '7 Seeds S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108839.mp4', 'http://gstaticontent.com/images/v3es21M3q4yKBxNhSImReB7Wh8U_big.jpg'),
(16843, 1081, '7 Seeds S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108840.mp4', 'http://gstaticontent.com/images/v3es21M3q4yKBxNhSImReB7Wh8U_big.jpg'),
(16844, 1081, '7 Seeds S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108841.mp4', 'http://gstaticontent.com/images/v3es21M3q4yKBxNhSImReB7Wh8U_big.jpg'),
(16845, 1081, '7 Seeds S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108842.mp4', 'http://gstaticontent.com/images/v3es21M3q4yKBxNhSImReB7Wh8U_big.jpg'),
(16846, 1081, '7 Seeds S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108843.mp4', 'http://gstaticontent.com/images/v3es21M3q4yKBxNhSImReB7Wh8U_big.jpg'),
(16847, 1081, '7 Seeds S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108844.mp4', 'http://gstaticontent.com/images/v3es21M3q4yKBxNhSImReB7Wh8U_big.jpg'),
(16848, 1081, '7 Seeds S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108845.mp4', 'http://gstaticontent.com/images/v3es21M3q4yKBxNhSImReB7Wh8U_big.jpg'),
(16849, 1081, '7 Seeds S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108846.mp4', 'http://gstaticontent.com/images/v3es21M3q4yKBxNhSImReB7Wh8U_big.jpg'),
(16850, 1082, '7 Seeds S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108847.mp4', 'http://timg.bdta.pro/images/35ce3e8cc0bb866a90deb4db0dfe8be5.jpg'),
(16851, 1082, '7 Seeds S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108848.mp4', 'http://timg.bdta.pro/images/d4cfd96aeab3ecc6276fa92e42b27193.jpg'),
(16852, 1082, '7 Seeds S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108849.mp4', 'http://timg.bdta.pro/images/d7c223ce04401554f9e95cc6354cac0d.jpg'),
(16853, 1082, '7 Seeds S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108850.mp4', 'http://timg.bdta.pro/images/518a26cf948399b9efa3102cc4bc1964.jpg'),
(16854, 1082, '7 Seeds S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108851.mp4', 'http://timg.bdta.pro/images/6736da1b8e76279f1309ea7232f57100.jpg'),
(16855, 1082, '7 Seeds S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108852.mp4', 'http://timg.bdta.pro/images/c1f02fd582ca4adeb8745128e1a6c551.jpg'),
(16856, 1082, '7 Seeds S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108853.mp4', 'http://timg.bdta.pro/images/b212cbd7a42b714d719170cb937b1f87.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(16857, 1082, '7 Seeds S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108854.mp4', 'http://timg.bdta.pro/images/a312409a8a76958935bb3c09fa4f72db.jpg'),
(16858, 1082, '7 Seeds S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108855.mp4', 'http://timg.bdta.pro/images/a6d434393b76dc6e1dea13b51287eb11.jpg'),
(16859, 1082, '7 Seeds S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108856.mp4', 'http://timg.bdta.pro/images/0a7084cd53209c292269a8c7de381e74.jpg'),
(16860, 1082, '7 Seeds S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108857.mp4', 'http://timg.bdta.pro/images/92a586e5f2e9a57377389e0f394cd43a.jpg'),
(16861, 1082, '7 Seeds S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108858.mp4', 'http://timg.bdta.pro/images/f46ad2b8784a26d602c798bfbd66ed70.jpg'),
(16862, 1083, 'Guerras do Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104519.mp4', 'http://gstaticontent.com/images/eZXiyrbMtMywpXaWEFon9FRKwoj_big.jpg'),
(16863, 1083, 'Guerras do Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104520.mp4', 'http://gstaticontent.com/images/eZXiyrbMtMywpXaWEFon9FRKwoj_big.jpg'),
(16864, 1083, 'Guerras do Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104521.mp4', 'http://gstaticontent.com/images/eZXiyrbMtMywpXaWEFon9FRKwoj_big.jpg'),
(16865, 1083, 'Guerras do Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104522.mp4', 'http://gstaticontent.com/images/eZXiyrbMtMywpXaWEFon9FRKwoj_big.jpg'),
(16866, 1083, 'Guerras do Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104523.mp4', 'http://gstaticontent.com/images/eZXiyrbMtMywpXaWEFon9FRKwoj_big.jpg'),
(16867, 1084, 'O Escolhido S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166098.mp4', 'http://gstaticontent.com/images/kbAheGTyuU0vCWOjzeFkd24bPuJ_big.jpg'),
(16868, 1084, 'O Escolhido S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166099.mp4', 'http://gstaticontent.com/images/kbAheGTyuU0vCWOjzeFkd24bPuJ_big.jpg'),
(16869, 1084, 'O Escolhido S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166100.mp4', 'http://gstaticontent.com/images/kbAheGTyuU0vCWOjzeFkd24bPuJ_big.jpg'),
(16870, 1084, 'O Escolhido S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166101.mp4', 'http://gstaticontent.com/images/kbAheGTyuU0vCWOjzeFkd24bPuJ_big.jpg'),
(16871, 1084, 'O Escolhido S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166102.mp4', 'http://gstaticontent.com/images/kbAheGTyuU0vCWOjzeFkd24bPuJ_big.jpg'),
(16872, 1084, 'O Escolhido S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166103.mp4', 'http://gstaticontent.com/images/kbAheGTyuU0vCWOjzeFkd24bPuJ_big.jpg'),
(16873, 1085, 'O Escolhido S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nsOuZXk75atjNf5raqZs1aNMBoe.jpg'),
(16874, 1085, 'O Escolhido S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hex2XEia1uQ6ql0AKQ8qV57lT6i.jpg'),
(16875, 1085, 'O Escolhido S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166106.mp4', 'http://gstaticontent.com/images/kbAheGTyuU0vCWOjzeFkd24bPuJ_big.jpg'),
(16876, 1085, 'O Escolhido S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166107.mp4', 'http://gstaticontent.com/images/kbAheGTyuU0vCWOjzeFkd24bPuJ_big.jpg'),
(16877, 1085, 'O Escolhido S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166108.mp4', 'http://gstaticontent.com/images/kbAheGTyuU0vCWOjzeFkd24bPuJ_big.jpg'),
(16878, 1085, 'O Escolhido S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166109.mp4', 'http://gstaticontent.com/images/kbAheGTyuU0vCWOjzeFkd24bPuJ_big.jpg'),
(16879, 1086, 'Flagrantes de Familia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104513.mp4', 'http://gstaticontent.com/images/ty8FF3wcpQTRJVFV6xpCQ8zmPqI_big.jpg'),
(16880, 1086, 'Flagrantes de Familia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104514.mp4', 'http://gstaticontent.com/images/ty8FF3wcpQTRJVFV6xpCQ8zmPqI_big.jpg'),
(16881, 1086, 'Flagrantes de Familia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104515.mp4', 'http://gstaticontent.com/images/ty8FF3wcpQTRJVFV6xpCQ8zmPqI_big.jpg'),
(16882, 1086, 'Flagrantes de Familia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104516.mp4', 'http://gstaticontent.com/images/ty8FF3wcpQTRJVFV6xpCQ8zmPqI_big.jpg'),
(16883, 1086, 'Flagrantes de Familia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104517.mp4', 'http://gstaticontent.com/images/ty8FF3wcpQTRJVFV6xpCQ8zmPqI_big.jpg'),
(16884, 1086, 'Flagrantes de Familia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104518.mp4', 'http://gstaticontent.com/images/ty8FF3wcpQTRJVFV6xpCQ8zmPqI_big.jpg'),
(16885, 1087, 'Shark Tank Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253360.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16886, 1087, 'Shark Tank Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253361.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16887, 1087, 'Shark Tank Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253362.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16888, 1087, 'Shark Tank Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253363.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16889, 1087, 'Shark Tank Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253364.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16890, 1087, 'Shark Tank Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253365.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16891, 1087, 'Shark Tank Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253366.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16892, 1087, 'Shark Tank Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253367.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16893, 1087, 'Shark Tank Brasil S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253368.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16894, 1087, 'Shark Tank Brasil S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253369.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16895, 1087, 'Shark Tank Brasil S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253370.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16896, 1087, 'Shark Tank Brasil S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253371.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16897, 1087, 'Shark Tank Brasil S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/253372.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16898, 1087, 'Shark Tank Brasil S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/253373.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16899, 1087, 'Shark Tank Brasil S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/253374.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16900, 1087, 'Shark Tank Brasil S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/253375.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16901, 1088, 'Shark Tank Brasil S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253376.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16902, 1088, 'Shark Tank Brasil S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253377.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16903, 1088, 'Shark Tank Brasil S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253378.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16904, 1088, 'Shark Tank Brasil S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253379.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16905, 1088, 'Shark Tank Brasil S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253380.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16906, 1088, 'Shark Tank Brasil S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253381.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16907, 1088, 'Shark Tank Brasil S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253382.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16908, 1088, 'Shark Tank Brasil S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253383.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16909, 1088, 'Shark Tank Brasil S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253384.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16910, 1088, 'Shark Tank Brasil S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253385.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16911, 1088, 'Shark Tank Brasil S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253386.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16912, 1088, 'Shark Tank Brasil S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253387.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16913, 1088, 'Shark Tank Brasil S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/253388.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16914, 1089, 'Shark Tank Brasil S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253389.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16915, 1089, 'Shark Tank Brasil S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253390.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16916, 1089, 'Shark Tank Brasil S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253391.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16917, 1089, 'Shark Tank Brasil S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253392.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16918, 1089, 'Shark Tank Brasil S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253393.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16919, 1089, 'Shark Tank Brasil S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253394.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16920, 1089, 'Shark Tank Brasil S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253395.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16921, 1089, 'Shark Tank Brasil S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253396.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16922, 1089, 'Shark Tank Brasil S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253397.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16923, 1089, 'Shark Tank Brasil S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253398.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16924, 1089, 'Shark Tank Brasil S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253399.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16925, 1089, 'Shark Tank Brasil S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253400.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16926, 1089, 'Shark Tank Brasil S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/253401.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16927, 1089, 'Shark Tank Brasil S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/253402.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16928, 1089, 'Shark Tank Brasil S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/253403.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16929, 1089, 'Shark Tank Brasil S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/253404.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16930, 1090, 'Shark Tank Brasil S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253405.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16931, 1090, 'Shark Tank Brasil S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253406.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16932, 1090, 'Shark Tank Brasil S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253407.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16933, 1090, 'Shark Tank Brasil S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253408.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16934, 1090, 'Shark Tank Brasil S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253409.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16935, 1090, 'Shark Tank Brasil S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253410.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16936, 1090, 'Shark Tank Brasil S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253411.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16937, 1090, 'Shark Tank Brasil S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253412.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16938, 1090, 'Shark Tank Brasil S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253413.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16939, 1090, 'Shark Tank Brasil S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253414.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16940, 1090, 'Shark Tank Brasil S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253415.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16941, 1090, 'Shark Tank Brasil S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253416.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16942, 1090, 'Shark Tank Brasil S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/253417.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16943, 1090, 'Shark Tank Brasil S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/253418.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16944, 1090, 'Shark Tank Brasil S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/253419.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16945, 1090, 'Shark Tank Brasil S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/253420.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16946, 1091, 'Shark Tank Brasil S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253421.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16947, 1091, 'Shark Tank Brasil S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253422.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16948, 1091, 'Shark Tank Brasil S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253423.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16949, 1091, 'Shark Tank Brasil S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253424.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16950, 1091, 'Shark Tank Brasil S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253425.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16951, 1091, 'Shark Tank Brasil S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253426.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16952, 1091, 'Shark Tank Brasil S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253427.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16953, 1091, 'Shark Tank Brasil S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253428.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16954, 1091, 'Shark Tank Brasil S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253429.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16955, 1091, 'Shark Tank Brasil S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253430.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16956, 1091, 'Shark Tank Brasil S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253431.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16957, 1091, 'Shark Tank Brasil S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253432.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16958, 1092, 'Shark Tank Brasil S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253433.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16959, 1092, 'Shark Tank Brasil S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253434.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16960, 1092, 'Shark Tank Brasil S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253435.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16961, 1092, 'Shark Tank Brasil S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253436.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16962, 1092, 'Shark Tank Brasil S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253437.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16963, 1092, 'Shark Tank Brasil S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253438.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16964, 1092, 'Shark Tank Brasil S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253439.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16965, 1092, 'Shark Tank Brasil S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253440.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16966, 1092, 'Shark Tank Brasil S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253441.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16967, 1092, 'Shark Tank Brasil S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253442.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16968, 1092, 'Shark Tank Brasil S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253443.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16969, 1092, 'Shark Tank Brasil S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/636052.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16970, 1093, 'Shark Tank Brasil S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253445.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16971, 1093, 'Shark Tank Brasil S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253446.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16972, 1093, 'Shark Tank Brasil S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253447.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16973, 1093, 'Shark Tank Brasil S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253448.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16974, 1093, 'Shark Tank Brasil S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253449.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16975, 1093, 'Shark Tank Brasil S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253450.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16976, 1093, 'Shark Tank Brasil S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253451.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16977, 1093, 'Shark Tank Brasil S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253452.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16978, 1093, 'Shark Tank Brasil S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253453.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16979, 1093, 'Shark Tank Brasil S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253454.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16980, 1093, 'Shark Tank Brasil S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253455.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16981, 1093, 'Shark Tank Brasil S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253456.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16982, 1093, 'Shark Tank Brasil S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/253457.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16983, 1094, 'Shark Tank Brasil S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253458.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16984, 1094, 'Shark Tank Brasil S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253459.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16985, 1094, 'Shark Tank Brasil S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253460.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16986, 1094, 'Shark Tank Brasil S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253461.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16987, 1094, 'Shark Tank Brasil S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253462.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16988, 1094, 'Shark Tank Brasil S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253463.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16989, 1094, 'Shark Tank Brasil S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253464.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16990, 1094, 'Shark Tank Brasil S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253465.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16991, 1094, 'Shark Tank Brasil S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253466.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16992, 1094, 'Shark Tank Brasil S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253467.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16993, 1094, 'Shark Tank Brasil S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253468.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16994, 1095, 'Shark Tank Brasil S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/490183.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16995, 1095, 'Shark Tank Brasil S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/490184.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16996, 1095, 'Shark Tank Brasil S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/490185.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16997, 1095, 'Shark Tank Brasil S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/504870.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16998, 1095, 'Shark Tank Brasil S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/504871.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(16999, 1095, 'Shark Tank Brasil S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/504872.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(17000, 1095, 'Shark Tank Brasil S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/506870.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(17001, 1095, 'Shark Tank Brasil S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/515077.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(17002, 1095, 'Shark Tank Brasil S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/517135.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(17003, 1095, 'Shark Tank Brasil S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/636086.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(17004, 1095, 'Shark Tank Brasil S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/661437.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(17005, 1096, 'Shark Tank Brasil S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/889730.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(17006, 1096, 'Shark Tank Brasil S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/889731.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(17007, 1096, 'Shark Tank Brasil S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/891018.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(17008, 1096, 'Shark Tank Brasil S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/892419.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(17009, 1096, 'Shark Tank Brasil S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/893064.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(17010, 1096, 'Shark Tank Brasil S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/893065.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(17011, 1096, 'Shark Tank Brasil S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/894199.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(17012, 1096, 'Shark Tank Brasil S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/894200.mp4', 'http://gstaticontent.com/images/gXFCuBl0Mn1oGngxhnrOW4WUark_big.jpg'),
(17013, 1097, 'As Aventuras de Blinky Bill S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104461.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17014, 1097, 'As Aventuras de Blinky Bill S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104462.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17015, 1097, 'As Aventuras de Blinky Bill S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104463.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17016, 1097, 'As Aventuras de Blinky Bill S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104464.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17017, 1097, 'As Aventuras de Blinky Bill S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104465.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17018, 1097, 'As Aventuras de Blinky Bill S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104466.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17019, 1097, 'As Aventuras de Blinky Bill S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104467.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17020, 1097, 'As Aventuras de Blinky Bill S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104468.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17021, 1097, 'As Aventuras de Blinky Bill S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104469.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17022, 1097, 'As Aventuras de Blinky Bill S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104470.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17023, 1097, 'As Aventuras de Blinky Bill S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/104471.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17024, 1097, 'As Aventuras de Blinky Bill S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/104472.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17025, 1097, 'As Aventuras de Blinky Bill S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/104473.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17026, 1097, 'As Aventuras de Blinky Bill S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/104474.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17027, 1097, 'As Aventuras de Blinky Bill S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/104475.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17028, 1097, 'As Aventuras de Blinky Bill S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/104476.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17029, 1097, 'As Aventuras de Blinky Bill S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/104477.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17030, 1097, 'As Aventuras de Blinky Bill S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/104478.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17031, 1097, 'As Aventuras de Blinky Bill S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/104479.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17032, 1097, 'As Aventuras de Blinky Bill S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/104480.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17033, 1097, 'As Aventuras de Blinky Bill S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/104481.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17034, 1097, 'As Aventuras de Blinky Bill S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/104482.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17035, 1097, 'As Aventuras de Blinky Bill S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/104483.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17036, 1097, 'As Aventuras de Blinky Bill S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/104484.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17037, 1098, 'As Aventuras de Blinky Bill S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104485.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17038, 1098, 'As Aventuras de Blinky Bill S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104486.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17039, 1098, 'As Aventuras de Blinky Bill S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104487.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17040, 1098, 'As Aventuras de Blinky Bill S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104488.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17041, 1098, 'As Aventuras de Blinky Bill S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104489.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17042, 1098, 'As Aventuras de Blinky Bill S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104490.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17043, 1098, 'As Aventuras de Blinky Bill S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104491.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17044, 1098, 'As Aventuras de Blinky Bill S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104492.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17045, 1098, 'As Aventuras de Blinky Bill S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104493.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17046, 1098, 'As Aventuras de Blinky Bill S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104494.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17047, 1098, 'As Aventuras de Blinky Bill S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/104495.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17048, 1098, 'As Aventuras de Blinky Bill S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/104496.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17049, 1098, 'As Aventuras de Blinky Bill S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/104497.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17050, 1098, 'As Aventuras de Blinky Bill S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/104498.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17051, 1098, 'As Aventuras de Blinky Bill S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/104499.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17052, 1098, 'As Aventuras de Blinky Bill S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/104500.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17053, 1098, 'As Aventuras de Blinky Bill S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/104501.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17054, 1098, 'As Aventuras de Blinky Bill S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/104502.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17055, 1098, 'As Aventuras de Blinky Bill S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/104503.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17056, 1098, 'As Aventuras de Blinky Bill S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/104504.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17057, 1098, 'As Aventuras de Blinky Bill S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/104505.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17058, 1098, 'As Aventuras de Blinky Bill S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/104506.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17059, 1098, 'As Aventuras de Blinky Bill S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/104507.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17060, 1098, 'As Aventuras de Blinky Bill S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/104508.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17061, 1098, 'As Aventuras de Blinky Bill S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/104509.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17062, 1098, 'As Aventuras de Blinky Bill S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/104510.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17063, 1098, 'As Aventuras de Blinky Bill S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/104511.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17064, 1098, 'As Aventuras de Blinky Bill S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/104512.mp4', 'http://gstaticontent.com/images/kn77nwxJJG3NyLoovY2c0o1eKTv_big.jpg'),
(17065, 1099, 'Dragon Ball GT S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104397.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17066, 1099, 'Dragon Ball GT S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104398.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17067, 1099, 'Dragon Ball GT S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104399.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17068, 1099, 'Dragon Ball GT S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104400.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17069, 1099, 'Dragon Ball GT S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104401.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17070, 1099, 'Dragon Ball GT S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104402.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17071, 1099, 'Dragon Ball GT S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104403.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17072, 1099, 'Dragon Ball GT S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104404.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17073, 1099, 'Dragon Ball GT S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104405.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17074, 1099, 'Dragon Ball GT S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104406.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17075, 1099, 'Dragon Ball GT S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/104407.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17076, 1099, 'Dragon Ball GT S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/104408.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17077, 1099, 'Dragon Ball GT S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/104409.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17078, 1099, 'Dragon Ball GT S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/104410.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17079, 1099, 'Dragon Ball GT S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/104411.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17080, 1099, 'Dragon Ball GT S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/104412.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17081, 1099, 'Dragon Ball GT S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/104413.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17082, 1099, 'Dragon Ball GT S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/104414.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17083, 1099, 'Dragon Ball GT S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/104415.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17084, 1099, 'Dragon Ball GT S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/104416.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17085, 1099, 'Dragon Ball GT S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/104417.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17086, 1099, 'Dragon Ball GT S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/104418.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17087, 1099, 'Dragon Ball GT S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/104419.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17088, 1099, 'Dragon Ball GT S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/104420.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17089, 1099, 'Dragon Ball GT S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/104421.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17090, 1099, 'Dragon Ball GT S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/104422.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17091, 1099, 'Dragon Ball GT S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/104423.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17092, 1099, 'Dragon Ball GT S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/104424.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17093, 1099, 'Dragon Ball GT S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/104425.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17094, 1099, 'Dragon Ball GT S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/104426.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17095, 1099, 'Dragon Ball GT S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/104427.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17096, 1099, 'Dragon Ball GT S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/104428.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17097, 1099, 'Dragon Ball GT S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/104429.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17098, 1099, 'Dragon Ball GT S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/104430.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17099, 1099, 'Dragon Ball GT S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/104431.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17100, 1099, 'Dragon Ball GT S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/104432.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17101, 1099, 'Dragon Ball GT S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/104433.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17102, 1099, 'Dragon Ball GT S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/104434.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17103, 1099, 'Dragon Ball GT S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/104435.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17104, 1099, 'Dragon Ball GT S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/104436.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17105, 1099, 'Dragon Ball GT S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/104437.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17106, 1099, 'Dragon Ball GT S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/104438.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17107, 1099, 'Dragon Ball GT S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/104439.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17108, 1099, 'Dragon Ball GT S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/104440.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17109, 1099, 'Dragon Ball GT S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/104441.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17110, 1099, 'Dragon Ball GT S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/104442.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17111, 1099, 'Dragon Ball GT S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/104443.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17112, 1099, 'Dragon Ball GT S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/104444.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17113, 1099, 'Dragon Ball GT S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/104445.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17114, 1099, 'Dragon Ball GT S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/104446.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17115, 1099, 'Dragon Ball GT S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/104447.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17116, 1099, 'Dragon Ball GT S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/104448.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17117, 1099, 'Dragon Ball GT S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/104449.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17118, 1099, 'Dragon Ball GT S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/104450.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17119, 1099, 'Dragon Ball GT S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/104451.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17120, 1099, 'Dragon Ball GT S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/104452.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17121, 1099, 'Dragon Ball GT S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/104453.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17122, 1099, 'Dragon Ball GT S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/104454.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17123, 1099, 'Dragon Ball GT S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/104455.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17124, 1099, 'Dragon Ball GT S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/104456.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17125, 1099, 'Dragon Ball GT S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/104457.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17126, 1099, 'Dragon Ball GT S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/104458.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17127, 1099, 'Dragon Ball GT S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/104459.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17128, 1099, 'Dragon Ball GT S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/104460.mp4', 'http://gstaticontent.com/images/kmO4AHj1xx8wiaBMgwGjXhOQfNt_big.jpg'),
(17129, 1100, 'Dragon Ball Z S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104106.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17130, 1100, 'Dragon Ball Z S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104107.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17131, 1100, 'Dragon Ball Z S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104108.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17132, 1100, 'Dragon Ball Z S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104109.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17133, 1100, 'Dragon Ball Z S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104110.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17134, 1100, 'Dragon Ball Z S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104111.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17135, 1100, 'Dragon Ball Z S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104112.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(17136, 1100, 'Dragon Ball Z S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104113.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17137, 1100, 'Dragon Ball Z S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104114.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17138, 1100, 'Dragon Ball Z S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104115.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17139, 1100, 'Dragon Ball Z S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/104116.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17140, 1100, 'Dragon Ball Z S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/104117.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17141, 1100, 'Dragon Ball Z S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/104118.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17142, 1100, 'Dragon Ball Z S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/104119.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17143, 1100, 'Dragon Ball Z S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/104120.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17144, 1100, 'Dragon Ball Z S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/104121.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17145, 1100, 'Dragon Ball Z S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/104122.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17146, 1100, 'Dragon Ball Z S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/104123.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17147, 1100, 'Dragon Ball Z S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/104124.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17148, 1100, 'Dragon Ball Z S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/104125.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17149, 1100, 'Dragon Ball Z S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/104126.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17150, 1100, 'Dragon Ball Z S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/104127.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17151, 1100, 'Dragon Ball Z S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/104128.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17152, 1100, 'Dragon Ball Z S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/104129.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17153, 1100, 'Dragon Ball Z S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/104130.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17154, 1100, 'Dragon Ball Z S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/104131.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17155, 1100, 'Dragon Ball Z S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/104132.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17156, 1100, 'Dragon Ball Z S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/104133.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17157, 1100, 'Dragon Ball Z S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/104134.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17158, 1100, 'Dragon Ball Z S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/104135.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17159, 1100, 'Dragon Ball Z S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/104136.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17160, 1100, 'Dragon Ball Z S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/104137.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17161, 1100, 'Dragon Ball Z S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/104138.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17162, 1100, 'Dragon Ball Z S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/104139.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17163, 1100, 'Dragon Ball Z S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/104140.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17164, 1100, 'Dragon Ball Z S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/104141.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17165, 1100, 'Dragon Ball Z S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/104142.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17166, 1100, 'Dragon Ball Z S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/104143.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17167, 1100, 'Dragon Ball Z S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/104144.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17168, 1101, 'Dragon Ball Z S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104145.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17169, 1101, 'Dragon Ball Z S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104146.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17170, 1101, 'Dragon Ball Z S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104147.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17171, 1101, 'Dragon Ball Z S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104148.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17172, 1101, 'Dragon Ball Z S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104149.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17173, 1101, 'Dragon Ball Z S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104150.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17174, 1101, 'Dragon Ball Z S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104151.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17175, 1101, 'Dragon Ball Z S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104152.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17176, 1101, 'Dragon Ball Z S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104153.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17177, 1101, 'Dragon Ball Z S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104154.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17178, 1101, 'Dragon Ball Z S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/104155.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17179, 1101, 'Dragon Ball Z S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/104156.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17180, 1101, 'Dragon Ball Z S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/104157.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17181, 1101, 'Dragon Ball Z S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/104158.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17182, 1101, 'Dragon Ball Z S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/104159.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17183, 1101, 'Dragon Ball Z S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/104160.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17184, 1101, 'Dragon Ball Z S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/104161.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17185, 1101, 'Dragon Ball Z S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/104162.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17186, 1101, 'Dragon Ball Z S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/104163.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17187, 1101, 'Dragon Ball Z S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/104164.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17188, 1101, 'Dragon Ball Z S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/104165.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17189, 1101, 'Dragon Ball Z S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/104166.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17190, 1101, 'Dragon Ball Z S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/104167.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17191, 1101, 'Dragon Ball Z S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/104168.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17192, 1101, 'Dragon Ball Z S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/104169.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17193, 1101, 'Dragon Ball Z S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/104170.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17194, 1101, 'Dragon Ball Z S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/104171.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17195, 1101, 'Dragon Ball Z S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/104172.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17196, 1101, 'Dragon Ball Z S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/104173.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17197, 1101, 'Dragon Ball Z S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/104174.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17198, 1101, 'Dragon Ball Z S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/104175.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17199, 1101, 'Dragon Ball Z S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/104176.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17200, 1101, 'Dragon Ball Z S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/104177.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17201, 1101, 'Dragon Ball Z S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/104178.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17202, 1101, 'Dragon Ball Z S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/104179.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17203, 1102, 'Dragon Ball Z S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104180.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17204, 1102, 'Dragon Ball Z S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104181.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17205, 1102, 'Dragon Ball Z S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104182.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17206, 1102, 'Dragon Ball Z S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104183.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17207, 1102, 'Dragon Ball Z S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104184.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17208, 1102, 'Dragon Ball Z S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104185.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17209, 1102, 'Dragon Ball Z S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104186.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17210, 1102, 'Dragon Ball Z S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104187.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17211, 1102, 'Dragon Ball Z S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104188.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17212, 1102, 'Dragon Ball Z S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104189.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17213, 1102, 'Dragon Ball Z S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/104190.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17214, 1102, 'Dragon Ball Z S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/104191.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17215, 1102, 'Dragon Ball Z S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/104192.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17216, 1102, 'Dragon Ball Z S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/104193.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17217, 1102, 'Dragon Ball Z S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/104194.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17218, 1102, 'Dragon Ball Z S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/104195.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17219, 1102, 'Dragon Ball Z S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/104196.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17220, 1102, 'Dragon Ball Z S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/104197.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17221, 1102, 'Dragon Ball Z S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/104198.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17222, 1102, 'Dragon Ball Z S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/104199.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17223, 1102, 'Dragon Ball Z S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/104200.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17224, 1102, 'Dragon Ball Z S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/104201.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17225, 1102, 'Dragon Ball Z S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/104202.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17226, 1102, 'Dragon Ball Z S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/104203.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17227, 1102, 'Dragon Ball Z S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/104204.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17228, 1102, 'Dragon Ball Z S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/104205.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17229, 1102, 'Dragon Ball Z S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/104206.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17230, 1102, 'Dragon Ball Z S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/104207.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17231, 1102, 'Dragon Ball Z S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/104208.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17232, 1102, 'Dragon Ball Z S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/104209.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17233, 1102, 'Dragon Ball Z S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/104210.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17234, 1102, 'Dragon Ball Z S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/104211.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17235, 1102, 'Dragon Ball Z S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/104212.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17236, 1103, 'Dragon Ball Z S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104213.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17237, 1103, 'Dragon Ball Z S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104214.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17238, 1103, 'Dragon Ball Z S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104215.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17239, 1103, 'Dragon Ball Z S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104216.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17240, 1103, 'Dragon Ball Z S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104217.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17241, 1103, 'Dragon Ball Z S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104218.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17242, 1103, 'Dragon Ball Z S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104219.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17243, 1103, 'Dragon Ball Z S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104220.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17244, 1103, 'Dragon Ball Z S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104221.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17245, 1103, 'Dragon Ball Z S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104222.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17246, 1103, 'Dragon Ball Z S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/104223.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17247, 1103, 'Dragon Ball Z S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/104224.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17248, 1103, 'Dragon Ball Z S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/104225.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17249, 1103, 'Dragon Ball Z S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/104226.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17250, 1103, 'Dragon Ball Z S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/104227.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17251, 1103, 'Dragon Ball Z S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/104228.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17252, 1103, 'Dragon Ball Z S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/104229.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17253, 1103, 'Dragon Ball Z S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/104230.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17254, 1103, 'Dragon Ball Z S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/104231.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17255, 1103, 'Dragon Ball Z S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/104232.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17256, 1103, 'Dragon Ball Z S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/104233.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17257, 1103, 'Dragon Ball Z S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/104234.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17258, 1103, 'Dragon Ball Z S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/104235.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17259, 1103, 'Dragon Ball Z S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/104236.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17260, 1103, 'Dragon Ball Z S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/104237.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17261, 1103, 'Dragon Ball Z S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/104238.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17262, 1103, 'Dragon Ball Z S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/104239.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17263, 1103, 'Dragon Ball Z S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/104240.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17264, 1103, 'Dragon Ball Z S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/104241.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17265, 1103, 'Dragon Ball Z S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/104242.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17266, 1103, 'Dragon Ball Z S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/104243.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17267, 1103, 'Dragon Ball Z S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/104244.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17268, 1104, 'Dragon Ball Z S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104245.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17269, 1104, 'Dragon Ball Z S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104246.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17270, 1104, 'Dragon Ball Z S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104247.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17271, 1104, 'Dragon Ball Z S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104248.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17272, 1104, 'Dragon Ball Z S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104249.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17273, 1104, 'Dragon Ball Z S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104250.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17274, 1104, 'Dragon Ball Z S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104251.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17275, 1104, 'Dragon Ball Z S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104252.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17276, 1104, 'Dragon Ball Z S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104253.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17277, 1104, 'Dragon Ball Z S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104254.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17278, 1104, 'Dragon Ball Z S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/104255.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17279, 1104, 'Dragon Ball Z S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/104256.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17280, 1104, 'Dragon Ball Z S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/104257.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17281, 1104, 'Dragon Ball Z S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/104258.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17282, 1104, 'Dragon Ball Z S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/104259.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17283, 1104, 'Dragon Ball Z S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/104260.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17284, 1104, 'Dragon Ball Z S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/104261.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17285, 1104, 'Dragon Ball Z S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/104262.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17286, 1104, 'Dragon Ball Z S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/104263.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17287, 1104, 'Dragon Ball Z S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/104264.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17288, 1104, 'Dragon Ball Z S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/104265.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17289, 1104, 'Dragon Ball Z S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/104266.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17290, 1104, 'Dragon Ball Z S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/104267.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17291, 1104, 'Dragon Ball Z S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/104268.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17292, 1104, 'Dragon Ball Z S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/104269.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17293, 1104, 'Dragon Ball Z S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/104270.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17294, 1105, 'Dragon Ball Z S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104271.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17295, 1105, 'Dragon Ball Z S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104272.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17296, 1105, 'Dragon Ball Z S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104273.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17297, 1105, 'Dragon Ball Z S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104274.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17298, 1105, 'Dragon Ball Z S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104275.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17299, 1105, 'Dragon Ball Z S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104276.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17300, 1105, 'Dragon Ball Z S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104277.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17301, 1105, 'Dragon Ball Z S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104278.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17302, 1105, 'Dragon Ball Z S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104279.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17303, 1105, 'Dragon Ball Z S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104280.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17304, 1105, 'Dragon Ball Z S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/104281.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17305, 1105, 'Dragon Ball Z S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/104282.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17306, 1105, 'Dragon Ball Z S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/104283.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17307, 1105, 'Dragon Ball Z S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/104284.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17308, 1105, 'Dragon Ball Z S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/104285.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17309, 1105, 'Dragon Ball Z S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/104286.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17310, 1105, 'Dragon Ball Z S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/104287.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17311, 1105, 'Dragon Ball Z S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/104288.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17312, 1105, 'Dragon Ball Z S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/104289.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17313, 1105, 'Dragon Ball Z S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/104290.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17314, 1105, 'Dragon Ball Z S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/104291.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17315, 1105, 'Dragon Ball Z S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/104292.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17316, 1105, 'Dragon Ball Z S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/104293.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17317, 1105, 'Dragon Ball Z S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/104294.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17318, 1105, 'Dragon Ball Z S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/104295.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17319, 1105, 'Dragon Ball Z S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/104296.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17320, 1105, 'Dragon Ball Z S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/104297.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17321, 1105, 'Dragon Ball Z S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/104298.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17322, 1105, 'Dragon Ball Z S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/104299.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17323, 1106, 'Dragon Ball Z S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104300.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17324, 1106, 'Dragon Ball Z S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104301.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17325, 1106, 'Dragon Ball Z S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104302.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17326, 1106, 'Dragon Ball Z S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104303.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17327, 1106, 'Dragon Ball Z S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104304.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17328, 1106, 'Dragon Ball Z S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104305.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17329, 1106, 'Dragon Ball Z S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104306.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17330, 1106, 'Dragon Ball Z S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104307.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17331, 1106, 'Dragon Ball Z S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104308.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17332, 1106, 'Dragon Ball Z S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104309.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17333, 1106, 'Dragon Ball Z S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/104310.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17334, 1106, 'Dragon Ball Z S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/104311.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17335, 1106, 'Dragon Ball Z S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/104312.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17336, 1106, 'Dragon Ball Z S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/104313.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17337, 1106, 'Dragon Ball Z S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/104314.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17338, 1106, 'Dragon Ball Z S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/104315.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17339, 1106, 'Dragon Ball Z S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/104316.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17340, 1106, 'Dragon Ball Z S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/104317.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17341, 1106, 'Dragon Ball Z S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/104318.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17342, 1106, 'Dragon Ball Z S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/104319.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17343, 1106, 'Dragon Ball Z S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/104320.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17344, 1106, 'Dragon Ball Z S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/104321.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17345, 1106, 'Dragon Ball Z S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/104322.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17346, 1106, 'Dragon Ball Z S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/104323.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17347, 1106, 'Dragon Ball Z S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/104324.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17348, 1107, 'Dragon Ball Z S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104325.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17349, 1107, 'Dragon Ball Z S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104326.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17350, 1107, 'Dragon Ball Z S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104327.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17351, 1107, 'Dragon Ball Z S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104328.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17352, 1107, 'Dragon Ball Z S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104329.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17353, 1107, 'Dragon Ball Z S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104330.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17354, 1107, 'Dragon Ball Z S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104331.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17355, 1107, 'Dragon Ball Z S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104332.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17356, 1107, 'Dragon Ball Z S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104333.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17357, 1107, 'Dragon Ball Z S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104334.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17358, 1107, 'Dragon Ball Z S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/104335.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17359, 1107, 'Dragon Ball Z S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/104336.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17360, 1107, 'Dragon Ball Z S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/104337.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17361, 1107, 'Dragon Ball Z S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/104338.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17362, 1107, 'Dragon Ball Z S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/104339.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17363, 1107, 'Dragon Ball Z S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/104340.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17364, 1107, 'Dragon Ball Z S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/104341.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17365, 1107, 'Dragon Ball Z S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/104342.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17366, 1107, 'Dragon Ball Z S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/104343.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17367, 1107, 'Dragon Ball Z S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/104344.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17368, 1107, 'Dragon Ball Z S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/104345.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17369, 1107, 'Dragon Ball Z S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/104346.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17370, 1107, 'Dragon Ball Z S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/104347.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17371, 1107, 'Dragon Ball Z S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/104348.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17372, 1107, 'Dragon Ball Z S08 E25', 'http://sinalprivado.info:80/series/1533784/1533784/104349.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17373, 1107, 'Dragon Ball Z S08 E26', 'http://sinalprivado.info:80/series/1533784/1533784/104350.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17374, 1107, 'Dragon Ball Z S08 E27', 'http://sinalprivado.info:80/series/1533784/1533784/104351.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17375, 1107, 'Dragon Ball Z S08 E28', 'http://sinalprivado.info:80/series/1533784/1533784/104352.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17376, 1107, 'Dragon Ball Z S08 E29', 'http://sinalprivado.info:80/series/1533784/1533784/104353.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17377, 1107, 'Dragon Ball Z S08 E30', 'http://sinalprivado.info:80/series/1533784/1533784/104354.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17378, 1107, 'Dragon Ball Z S08 E31', 'http://sinalprivado.info:80/series/1533784/1533784/104355.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17379, 1107, 'Dragon Ball Z S08 E32', 'http://sinalprivado.info:80/series/1533784/1533784/104356.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17380, 1107, 'Dragon Ball Z S08 E33', 'http://sinalprivado.info:80/series/1533784/1533784/104357.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17381, 1107, 'Dragon Ball Z S08 E34', 'http://sinalprivado.info:80/series/1533784/1533784/104358.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17382, 1108, 'Dragon Ball Z S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104359.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17383, 1108, 'Dragon Ball Z S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104360.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17384, 1108, 'Dragon Ball Z S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104361.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17385, 1108, 'Dragon Ball Z S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104362.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17386, 1108, 'Dragon Ball Z S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104363.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17387, 1108, 'Dragon Ball Z S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104364.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17388, 1108, 'Dragon Ball Z S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104365.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17389, 1108, 'Dragon Ball Z S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104366.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17390, 1108, 'Dragon Ball Z S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104367.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17391, 1108, 'Dragon Ball Z S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104368.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17392, 1108, 'Dragon Ball Z S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/104369.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17393, 1108, 'Dragon Ball Z S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/104370.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17394, 1108, 'Dragon Ball Z S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/104371.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17395, 1108, 'Dragon Ball Z S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/104372.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17396, 1108, 'Dragon Ball Z S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/104373.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17397, 1108, 'Dragon Ball Z S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/104374.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17398, 1108, 'Dragon Ball Z S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/104375.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17399, 1108, 'Dragon Ball Z S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/104376.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17400, 1108, 'Dragon Ball Z S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/104377.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17401, 1108, 'Dragon Ball Z S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/104378.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17402, 1108, 'Dragon Ball Z S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/104379.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17403, 1108, 'Dragon Ball Z S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/104380.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17404, 1108, 'Dragon Ball Z S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/104381.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17405, 1108, 'Dragon Ball Z S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/104382.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17406, 1108, 'Dragon Ball Z S09 E25', 'http://sinalprivado.info:80/series/1533784/1533784/104383.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17407, 1108, 'Dragon Ball Z S09 E26', 'http://sinalprivado.info:80/series/1533784/1533784/104384.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17408, 1108, 'Dragon Ball Z S09 E27', 'http://sinalprivado.info:80/series/1533784/1533784/104385.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17409, 1108, 'Dragon Ball Z S09 E28', 'http://sinalprivado.info:80/series/1533784/1533784/104386.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17410, 1108, 'Dragon Ball Z S09 E29', 'http://sinalprivado.info:80/series/1533784/1533784/104387.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17411, 1108, 'Dragon Ball Z S09 E30', 'http://sinalprivado.info:80/series/1533784/1533784/104388.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17412, 1108, 'Dragon Ball Z S09 E31', 'http://sinalprivado.info:80/series/1533784/1533784/104389.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17413, 1108, 'Dragon Ball Z S09 E32', 'http://sinalprivado.info:80/series/1533784/1533784/104390.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17414, 1108, 'Dragon Ball Z S09 E33', 'http://sinalprivado.info:80/series/1533784/1533784/104391.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17415, 1108, 'Dragon Ball Z S09 E34', 'http://sinalprivado.info:80/series/1533784/1533784/104392.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17416, 1108, 'Dragon Ball Z S09 E35', 'http://sinalprivado.info:80/series/1533784/1533784/104393.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17417, 1108, 'Dragon Ball Z S09 E36', 'http://sinalprivado.info:80/series/1533784/1533784/104394.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17418, 1108, 'Dragon Ball Z S09 E37', 'http://sinalprivado.info:80/series/1533784/1533784/104395.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17419, 1108, 'Dragon Ball Z S09 E38', 'http://sinalprivado.info:80/series/1533784/1533784/104396.mp4', 'http://gstaticontent.com/images/eg2CakFFQh3dvujVj2qYCe7ybvK_big.jpg'),
(17420, 1109, 'Os Homens São de Marte... E é pra Lá que Eu Vou S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104093.mp4', 'http://gstaticontent.com/images/4ZVwv5c4FTcEyVbuVx80n9iJSvo_big.jpg'),
(17421, 1109, 'Os Homens São de Marte... E é pra Lá que Eu Vou S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104094.mp4', 'http://gstaticontent.com/images/4ZVwv5c4FTcEyVbuVx80n9iJSvo_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(17422, 1109, 'Os Homens São de Marte... E é pra Lá que Eu Vou S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104095.mp4', 'http://gstaticontent.com/images/4ZVwv5c4FTcEyVbuVx80n9iJSvo_big.jpg'),
(17423, 1109, 'Os Homens São de Marte... E é pra Lá que Eu Vou S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104096.mp4', 'http://gstaticontent.com/images/4ZVwv5c4FTcEyVbuVx80n9iJSvo_big.jpg'),
(17424, 1109, 'Os Homens São de Marte... E é pra Lá que Eu Vou S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104097.mp4', 'http://gstaticontent.com/images/4ZVwv5c4FTcEyVbuVx80n9iJSvo_big.jpg'),
(17425, 1109, 'Os Homens São de Marte... E é pra Lá que Eu Vou S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104098.mp4', 'http://gstaticontent.com/images/4ZVwv5c4FTcEyVbuVx80n9iJSvo_big.jpg'),
(17426, 1109, 'Os Homens São de Marte... E é pra Lá que Eu Vou S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104099.mp4', 'http://gstaticontent.com/images/4ZVwv5c4FTcEyVbuVx80n9iJSvo_big.jpg'),
(17427, 1109, 'Os Homens São de Marte... E é pra Lá que Eu Vou S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104100.mp4', 'http://gstaticontent.com/images/4ZVwv5c4FTcEyVbuVx80n9iJSvo_big.jpg'),
(17428, 1109, 'Os Homens São de Marte... E é pra Lá que Eu Vou S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104101.mp4', 'http://gstaticontent.com/images/4ZVwv5c4FTcEyVbuVx80n9iJSvo_big.jpg'),
(17429, 1109, 'Os Homens São de Marte... E é pra Lá que Eu Vou S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104102.mp4', 'http://gstaticontent.com/images/4ZVwv5c4FTcEyVbuVx80n9iJSvo_big.jpg'),
(17430, 1109, 'Os Homens São de Marte... E é pra Lá que Eu Vou S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/104103.mp4', 'http://gstaticontent.com/images/4ZVwv5c4FTcEyVbuVx80n9iJSvo_big.jpg'),
(17431, 1109, 'Os Homens São de Marte... E é pra Lá que Eu Vou S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/104104.mp4', 'http://gstaticontent.com/images/4ZVwv5c4FTcEyVbuVx80n9iJSvo_big.jpg'),
(17432, 1109, 'Os Homens São de Marte... E é pra Lá que Eu Vou S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/104105.mp4', 'http://gstaticontent.com/images/4ZVwv5c4FTcEyVbuVx80n9iJSvo_big.jpg'),
(17433, 1110, 'Pablo Escobar O Senhor do Trafico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103984.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17434, 1110, 'Pablo Escobar O Senhor do Trafico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103985.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17435, 1110, 'Pablo Escobar O Senhor do Trafico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103986.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17436, 1110, 'Pablo Escobar O Senhor do Trafico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103987.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17437, 1110, 'Pablo Escobar O Senhor do Trafico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103988.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17438, 1110, 'Pablo Escobar O Senhor do Trafico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103989.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17439, 1110, 'Pablo Escobar O Senhor do Trafico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103990.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17440, 1110, 'Pablo Escobar O Senhor do Trafico S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103991.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17441, 1110, 'Pablo Escobar O Senhor do Trafico S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103992.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17442, 1110, 'Pablo Escobar O Senhor do Trafico S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103993.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17443, 1110, 'Pablo Escobar O Senhor do Trafico S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103994.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17444, 1110, 'Pablo Escobar O Senhor do Trafico S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103995.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17445, 1110, 'Pablo Escobar O Senhor do Trafico S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/103996.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17446, 1110, 'Pablo Escobar O Senhor do Trafico S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/103997.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17447, 1110, 'Pablo Escobar O Senhor do Trafico S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/103998.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17448, 1110, 'Pablo Escobar O Senhor do Trafico S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/103999.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17449, 1110, 'Pablo Escobar O Senhor do Trafico S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/104000.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17450, 1110, 'Pablo Escobar O Senhor do Trafico S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/104001.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17451, 1110, 'Pablo Escobar O Senhor do Trafico S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/104002.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17452, 1110, 'Pablo Escobar O Senhor do Trafico S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/104003.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17453, 1110, 'Pablo Escobar O Senhor do Trafico S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/104004.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17454, 1110, 'Pablo Escobar O Senhor do Trafico S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/104005.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17455, 1110, 'Pablo Escobar O Senhor do Trafico S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/104006.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17456, 1110, 'Pablo Escobar O Senhor do Trafico S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/104007.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17457, 1110, 'Pablo Escobar O Senhor do Trafico S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/104008.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17458, 1110, 'Pablo Escobar O Senhor do Trafico S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/104009.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17459, 1110, 'Pablo Escobar O Senhor do Trafico S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/104010.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17460, 1110, 'Pablo Escobar O Senhor do Trafico S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/104011.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17461, 1110, 'Pablo Escobar O Senhor do Trafico S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/104012.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17462, 1110, 'Pablo Escobar O Senhor do Trafico S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/104013.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17463, 1110, 'Pablo Escobar O Senhor do Trafico S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/104014.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17464, 1110, 'Pablo Escobar O Senhor do Trafico S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/104015.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17465, 1110, 'Pablo Escobar O Senhor do Trafico S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/104016.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17466, 1110, 'Pablo Escobar O Senhor do Trafico S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/104017.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17467, 1110, 'Pablo Escobar O Senhor do Trafico S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/104018.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17468, 1110, 'Pablo Escobar O Senhor do Trafico S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/104019.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17469, 1110, 'Pablo Escobar O Senhor do Trafico S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/104020.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17470, 1110, 'Pablo Escobar O Senhor do Trafico S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/104021.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17471, 1110, 'Pablo Escobar O Senhor do Trafico S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/104022.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17472, 1110, 'Pablo Escobar O Senhor do Trafico S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/104023.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17473, 1110, 'Pablo Escobar O Senhor do Trafico S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/104024.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17474, 1110, 'Pablo Escobar O Senhor do Trafico S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/104025.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17475, 1110, 'Pablo Escobar O Senhor do Trafico S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/104026.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17476, 1110, 'Pablo Escobar O Senhor do Trafico S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/104027.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17477, 1110, 'Pablo Escobar O Senhor do Trafico S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/104028.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17478, 1110, 'Pablo Escobar O Senhor do Trafico S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/104029.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17479, 1110, 'Pablo Escobar O Senhor do Trafico S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/104030.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17480, 1110, 'Pablo Escobar O Senhor do Trafico S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/104031.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17481, 1110, 'Pablo Escobar O Senhor do Trafico S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/104032.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17482, 1110, 'Pablo Escobar O Senhor do Trafico S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/104033.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17483, 1110, 'Pablo Escobar O Senhor do Trafico S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/104034.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17484, 1110, 'Pablo Escobar O Senhor do Trafico S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/104035.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17485, 1110, 'Pablo Escobar O Senhor do Trafico S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/104036.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17486, 1110, 'Pablo Escobar O Senhor do Trafico S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/104037.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17487, 1110, 'Pablo Escobar O Senhor do Trafico S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/104038.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17488, 1110, 'Pablo Escobar O Senhor do Trafico S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/104039.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17489, 1110, 'Pablo Escobar O Senhor do Trafico S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/104040.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17490, 1110, 'Pablo Escobar O Senhor do Trafico S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/104041.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17491, 1110, 'Pablo Escobar O Senhor do Trafico S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/104042.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17492, 1110, 'Pablo Escobar O Senhor do Trafico S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/104043.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17493, 1110, 'Pablo Escobar O Senhor do Trafico S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/104044.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17494, 1110, 'Pablo Escobar O Senhor do Trafico S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/104045.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17495, 1110, 'Pablo Escobar O Senhor do Trafico S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/104046.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17496, 1110, 'Pablo Escobar O Senhor do Trafico S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/104047.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17497, 1110, 'Pablo Escobar O Senhor do Trafico S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/104048.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17498, 1110, 'Pablo Escobar O Senhor do Trafico S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/104049.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17499, 1110, 'Pablo Escobar O Senhor do Trafico S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/104050.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17500, 1110, 'Pablo Escobar O Senhor do Trafico S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/104051.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17501, 1110, 'Pablo Escobar O Senhor do Trafico S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/104052.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17502, 1110, 'Pablo Escobar O Senhor do Trafico S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/104053.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17503, 1110, 'Pablo Escobar O Senhor do Trafico S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/104054.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17504, 1110, 'Pablo Escobar O Senhor do Trafico S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/104055.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17505, 1110, 'Pablo Escobar O Senhor do Trafico S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/104056.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17506, 1110, 'Pablo Escobar O Senhor do Trafico S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/104057.mp4', 'http://gstaticontent.com/images/jZqm7HFuxfH9P0LFjQZ8nzrCUHP_big.jpg'),
(17507, 1111, 'Patrick Melrose S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104088.mp4', 'http://gstaticontent.com/images/t6ubZ1Bpu0elTzA8tT2mxkrfpxA_big.jpg'),
(17508, 1111, 'Patrick Melrose S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104089.mp4', 'http://gstaticontent.com/images/t6ubZ1Bpu0elTzA8tT2mxkrfpxA_big.jpg'),
(17509, 1111, 'Patrick Melrose S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104090.mp4', 'http://gstaticontent.com/images/t6ubZ1Bpu0elTzA8tT2mxkrfpxA_big.jpg'),
(17510, 1111, 'Patrick Melrose S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104091.mp4', 'http://gstaticontent.com/images/t6ubZ1Bpu0elTzA8tT2mxkrfpxA_big.jpg'),
(17511, 1111, 'Patrick Melrose S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104092.mp4', 'http://gstaticontent.com/images/t6ubZ1Bpu0elTzA8tT2mxkrfpxA_big.jpg'),
(17512, 1112, 'Patrulha Canina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246452.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17513, 1112, 'Patrulha Canina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246453.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17514, 1112, 'Patrulha Canina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246454.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17515, 1112, 'Patrulha Canina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246455.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17516, 1112, 'Patrulha Canina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246456.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17517, 1112, 'Patrulha Canina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246457.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17518, 1112, 'Patrulha Canina S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246458.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17519, 1112, 'Patrulha Canina S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246459.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17520, 1112, 'Patrulha Canina S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246460.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17521, 1112, 'Patrulha Canina S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246461.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17522, 1112, 'Patrulha Canina S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246462.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17523, 1112, 'Patrulha Canina S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246463.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17524, 1112, 'Patrulha Canina S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/246464.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17525, 1112, 'Patrulha Canina S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/246465.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17526, 1112, 'Patrulha Canina S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/246466.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17527, 1112, 'Patrulha Canina S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/246467.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17528, 1112, 'Patrulha Canina S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/246468.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17529, 1112, 'Patrulha Canina S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/246469.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17530, 1112, 'Patrulha Canina S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/246470.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17531, 1112, 'Patrulha Canina S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/246471.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17532, 1112, 'Patrulha Canina S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/246472.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17533, 1112, 'Patrulha Canina S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/246473.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17534, 1112, 'Patrulha Canina S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/246474.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17535, 1112, 'Patrulha Canina S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/246475.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17536, 1112, 'Patrulha Canina S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/246476.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17537, 1113, 'Patrulha Canina S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246477.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17538, 1113, 'Patrulha Canina S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246478.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17539, 1113, 'Patrulha Canina S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246479.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17540, 1113, 'Patrulha Canina S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246480.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17541, 1113, 'Patrulha Canina S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246481.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17542, 1113, 'Patrulha Canina S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246482.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17543, 1113, 'Patrulha Canina S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246483.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17544, 1113, 'Patrulha Canina S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246484.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17545, 1113, 'Patrulha Canina S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246485.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17546, 1113, 'Patrulha Canina S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246486.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17547, 1113, 'Patrulha Canina S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246487.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17548, 1113, 'Patrulha Canina S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246488.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17549, 1113, 'Patrulha Canina S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/246489.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17550, 1113, 'Patrulha Canina S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/246490.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17551, 1113, 'Patrulha Canina S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/246491.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17552, 1113, 'Patrulha Canina S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/246492.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17553, 1113, 'Patrulha Canina S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/246493.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17554, 1113, 'Patrulha Canina S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/246494.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17555, 1113, 'Patrulha Canina S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/246495.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17556, 1113, 'Patrulha Canina S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/246496.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17557, 1113, 'Patrulha Canina S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/246497.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17558, 1113, 'Patrulha Canina S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/246498.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17559, 1113, 'Patrulha Canina S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/246499.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17560, 1113, 'Patrulha Canina S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/246500.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17561, 1113, 'Patrulha Canina S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/246501.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17562, 1113, 'Patrulha Canina S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/246502.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17563, 1113, 'Patrulha Canina S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/246503.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17564, 1114, 'Patrulha Canina S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246504.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17565, 1114, 'Patrulha Canina S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246505.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17566, 1114, 'Patrulha Canina S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246506.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17567, 1114, 'Patrulha Canina S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246507.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17568, 1114, 'Patrulha Canina S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246508.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17569, 1114, 'Patrulha Canina S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246509.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17570, 1114, 'Patrulha Canina S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246510.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17571, 1114, 'Patrulha Canina S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246511.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17572, 1114, 'Patrulha Canina S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246512.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17573, 1114, 'Patrulha Canina S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246513.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17574, 1114, 'Patrulha Canina S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246514.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17575, 1114, 'Patrulha Canina S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246515.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17576, 1114, 'Patrulha Canina S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/246516.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17577, 1114, 'Patrulha Canina S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/246517.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17578, 1114, 'Patrulha Canina S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/246518.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17579, 1114, 'Patrulha Canina S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/246519.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17580, 1114, 'Patrulha Canina S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/246520.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17581, 1114, 'Patrulha Canina S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/246521.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17582, 1114, 'Patrulha Canina S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/246522.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17583, 1114, 'Patrulha Canina S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/246523.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17584, 1114, 'Patrulha Canina S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/246524.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17585, 1114, 'Patrulha Canina S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/246525.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17586, 1114, 'Patrulha Canina S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/246526.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17587, 1114, 'Patrulha Canina S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/246527.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17588, 1114, 'Patrulha Canina S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/246528.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17589, 1114, 'Patrulha Canina S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/246529.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17590, 1115, 'Patrulha Canina S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246530.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17591, 1115, 'Patrulha Canina S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246531.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17592, 1115, 'Patrulha Canina S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246532.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17593, 1115, 'Patrulha Canina S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246533.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17594, 1115, 'Patrulha Canina S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246534.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17595, 1115, 'Patrulha Canina S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246535.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17596, 1115, 'Patrulha Canina S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246536.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17597, 1115, 'Patrulha Canina S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246537.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17598, 1115, 'Patrulha Canina S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246538.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17599, 1115, 'Patrulha Canina S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246539.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17600, 1115, 'Patrulha Canina S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246540.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17601, 1115, 'Patrulha Canina S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246541.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17602, 1115, 'Patrulha Canina S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/246542.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17603, 1115, 'Patrulha Canina S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/246543.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17604, 1115, 'Patrulha Canina S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/246544.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17605, 1115, 'Patrulha Canina S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/246545.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17606, 1115, 'Patrulha Canina S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/246546.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17607, 1115, 'Patrulha Canina S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/246547.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17608, 1115, 'Patrulha Canina S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/246548.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17609, 1115, 'Patrulha Canina S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/246549.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17610, 1115, 'Patrulha Canina S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/246550.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17611, 1115, 'Patrulha Canina S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/246551.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17612, 1115, 'Patrulha Canina S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/246552.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17613, 1115, 'Patrulha Canina S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/246553.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17614, 1115, 'Patrulha Canina S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/246554.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17615, 1115, 'Patrulha Canina S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/246555.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17616, 1116, 'Patrulha Canina S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246556.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17617, 1116, 'Patrulha Canina S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246557.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17618, 1116, 'Patrulha Canina S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246558.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17619, 1116, 'Patrulha Canina S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246559.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17620, 1116, 'Patrulha Canina S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246560.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17621, 1116, 'Patrulha Canina S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246561.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17622, 1116, 'Patrulha Canina S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246562.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17623, 1116, 'Patrulha Canina S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246563.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17624, 1116, 'Patrulha Canina S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246564.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17625, 1116, 'Patrulha Canina S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246565.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17626, 1116, 'Patrulha Canina S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246566.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17627, 1116, 'Patrulha Canina S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246567.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17628, 1116, 'Patrulha Canina S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/246568.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17629, 1116, 'Patrulha Canina S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/246569.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17630, 1116, 'Patrulha Canina S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/246570.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17631, 1116, 'Patrulha Canina S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/246571.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17632, 1116, 'Patrulha Canina S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/246572.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17633, 1116, 'Patrulha Canina S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/246573.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17634, 1116, 'Patrulha Canina S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/246574.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17635, 1116, 'Patrulha Canina S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/246575.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17636, 1116, 'Patrulha Canina S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/246576.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17637, 1116, 'Patrulha Canina S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/246577.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17638, 1116, 'Patrulha Canina S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/246578.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17639, 1116, 'Patrulha Canina S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/246579.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17640, 1116, 'Patrulha Canina S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/246580.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17641, 1116, 'Patrulha Canina S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/246581.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17642, 1117, 'Patrulha Canina S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246582.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17643, 1117, 'Patrulha Canina S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246583.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17644, 1117, 'Patrulha Canina S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246584.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17645, 1117, 'Patrulha Canina S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246585.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17646, 1117, 'Patrulha Canina S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246586.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17647, 1117, 'Patrulha Canina S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246587.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17648, 1117, 'Patrulha Canina S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246588.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17649, 1117, 'Patrulha Canina S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246589.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17650, 1117, 'Patrulha Canina S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246590.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17651, 1117, 'Patrulha Canina S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246591.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17652, 1117, 'Patrulha Canina S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246592.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17653, 1117, 'Patrulha Canina S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246593.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17654, 1117, 'Patrulha Canina S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/246594.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17655, 1117, 'Patrulha Canina S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/246595.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17656, 1117, 'Patrulha Canina S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/246596.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17657, 1117, 'Patrulha Canina S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/246597.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17658, 1117, 'Patrulha Canina S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/246598.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17659, 1117, 'Patrulha Canina S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/246599.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17660, 1117, 'Patrulha Canina S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/246600.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17661, 1117, 'Patrulha Canina S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/246601.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17662, 1117, 'Patrulha Canina S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/246602.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17663, 1117, 'Patrulha Canina S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/246603.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17664, 1117, 'Patrulha Canina S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/246604.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17665, 1117, 'Patrulha Canina S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/246605.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17666, 1117, 'Patrulha Canina S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/246606.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17667, 1118, 'Patrulha Canina S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246607.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17668, 1118, 'Patrulha Canina S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246608.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17669, 1118, 'Patrulha Canina S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246609.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17670, 1118, 'Patrulha Canina S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246610.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17671, 1118, 'Patrulha Canina S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246611.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17672, 1118, 'Patrulha Canina S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246612.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17673, 1118, 'Patrulha Canina S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246613.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17674, 1118, 'Patrulha Canina S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246614.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17675, 1118, 'Patrulha Canina S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246615.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17676, 1118, 'Patrulha Canina S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246616.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17677, 1118, 'Patrulha Canina S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246617.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17678, 1118, 'Patrulha Canina S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246618.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17679, 1118, 'Patrulha Canina S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/246619.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17680, 1118, 'Patrulha Canina S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/246620.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17681, 1118, 'Patrulha Canina S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/246621.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17682, 1118, 'Patrulha Canina S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/246622.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17683, 1118, 'Patrulha Canina S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/246623.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17684, 1118, 'Patrulha Canina S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/246624.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17685, 1118, 'Patrulha Canina S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/246625.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17686, 1118, 'Patrulha Canina S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/246626.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17687, 1118, 'Patrulha Canina S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/246627.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17688, 1118, 'Patrulha Canina S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/246628.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17689, 1118, 'Patrulha Canina S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/246629.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17690, 1118, 'Patrulha Canina S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/246630.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17691, 1118, 'Patrulha Canina S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/246631.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17692, 1119, 'Patrulha Canina S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246632.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17693, 1119, 'Patrulha Canina S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246633.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17694, 1119, 'Patrulha Canina S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246634.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17695, 1119, 'Patrulha Canina S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246635.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(17696, 1119, 'Patrulha Canina S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246636.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17697, 1119, 'Patrulha Canina S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246637.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17698, 1119, 'Patrulha Canina S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246638.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17699, 1119, 'Patrulha Canina S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246639.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17700, 1119, 'Patrulha Canina S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246640.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17701, 1119, 'Patrulha Canina S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246641.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17702, 1119, 'Patrulha Canina S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246642.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17703, 1119, 'Patrulha Canina S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246643.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17704, 1119, 'Patrulha Canina S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/246644.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17705, 1119, 'Patrulha Canina S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/246645.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17706, 1119, 'Patrulha Canina S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/246646.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17707, 1119, 'Patrulha Canina S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/246647.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17708, 1119, 'Patrulha Canina S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/246648.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17709, 1119, 'Patrulha Canina S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/246649.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17710, 1119, 'Patrulha Canina S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/246650.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17711, 1119, 'Patrulha Canina S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/246651.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17712, 1119, 'Patrulha Canina S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/246652.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17713, 1119, 'Patrulha Canina S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/246653.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17714, 1119, 'Patrulha Canina S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/246654.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17715, 1119, 'Patrulha Canina S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/246655.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17716, 1119, 'Patrulha Canina S08 E25', 'http://sinalprivado.info:80/series/1533784/1533784/246656.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17717, 1120, 'Patrulha Canina S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246657.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17718, 1120, 'Patrulha Canina S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246658.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17719, 1120, 'Patrulha Canina S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246659.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17720, 1120, 'Patrulha Canina S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246660.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17721, 1120, 'Patrulha Canina S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246661.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17722, 1120, 'Patrulha Canina S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246662.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17723, 1120, 'Patrulha Canina S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246663.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17724, 1120, 'Patrulha Canina S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246664.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17725, 1120, 'Patrulha Canina S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246665.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17726, 1120, 'Patrulha Canina S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246666.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17727, 1120, 'Patrulha Canina S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246667.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17728, 1120, 'Patrulha Canina S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246668.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17729, 1120, 'Patrulha Canina S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/246669.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17730, 1120, 'Patrulha Canina S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/246670.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17731, 1120, 'Patrulha Canina S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/246671.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17732, 1120, 'Patrulha Canina S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/246672.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17733, 1120, 'Patrulha Canina S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/246673.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17734, 1120, 'Patrulha Canina S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/246674.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17735, 1120, 'Patrulha Canina S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/246675.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17736, 1120, 'Patrulha Canina S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/246676.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17737, 1120, 'Patrulha Canina S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/246677.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17738, 1120, 'Patrulha Canina S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/246678.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17739, 1120, 'Patrulha Canina S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/246679.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17740, 1120, 'Patrulha Canina S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/246680.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17741, 1120, 'Patrulha Canina S09 E25', 'http://sinalprivado.info:80/series/1533784/1533784/246681.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17742, 1120, 'Patrulha Canina S09 E26', 'http://sinalprivado.info:80/series/1533784/1533784/246682.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17743, 1121, 'Patrulha Canina S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/877285.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17744, 1121, 'Patrulha Canina S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/877286.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17745, 1121, 'Patrulha Canina S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/877287.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17746, 1121, 'Patrulha Canina S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/877288.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17747, 1121, 'Patrulha Canina S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/877289.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17748, 1121, 'Patrulha Canina S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/877290.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17749, 1121, 'Patrulha Canina S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/877291.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17750, 1121, 'Patrulha Canina S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/877292.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17751, 1121, 'Patrulha Canina S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/877293.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17752, 1121, 'Patrulha Canina S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/877294.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17753, 1121, 'Patrulha Canina S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/877295.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17754, 1121, 'Patrulha Canina S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/877296.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17755, 1121, 'Patrulha Canina S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/877297.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17756, 1121, 'Patrulha Canina S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/877298.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17757, 1121, 'Patrulha Canina S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/877299.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17758, 1121, 'Patrulha Canina S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/877300.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17759, 1121, 'Patrulha Canina S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/877301.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17760, 1121, 'Patrulha Canina S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/877302.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17761, 1121, 'Patrulha Canina S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/877303.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17762, 1121, 'Patrulha Canina S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/877304.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17763, 1121, 'Patrulha Canina S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/877305.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17764, 1121, 'Patrulha Canina S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/877306.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17765, 1121, 'Patrulha Canina S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/877307.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17766, 1121, 'Patrulha Canina S10 E24', 'http://sinalprivado.info:80/series/1533784/1533784/877308.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17767, 1121, 'Patrulha Canina S10 E25', 'http://sinalprivado.info:80/series/1533784/1533784/877309.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17768, 1121, 'Patrulha Canina S10 E26', 'http://sinalprivado.info:80/series/1533784/1533784/877310.mp4', 'http://gstaticontent.com/images/vN9BE385YKPgumoyrOd8Z8yh6Nn_big.jpg'),
(17769, 1122, 'Sneaky Pete S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104058.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17770, 1122, 'Sneaky Pete S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104059.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17771, 1122, 'Sneaky Pete S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104060.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17772, 1122, 'Sneaky Pete S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104061.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17773, 1122, 'Sneaky Pete S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104062.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17774, 1122, 'Sneaky Pete S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104063.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17775, 1122, 'Sneaky Pete S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104064.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17776, 1122, 'Sneaky Pete S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104065.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17777, 1122, 'Sneaky Pete S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104066.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17778, 1122, 'Sneaky Pete S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104067.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17779, 1123, 'Sneaky Pete S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104068.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17780, 1123, 'Sneaky Pete S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104069.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17781, 1123, 'Sneaky Pete S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104070.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17782, 1123, 'Sneaky Pete S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104071.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17783, 1123, 'Sneaky Pete S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104072.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17784, 1123, 'Sneaky Pete S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104073.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17785, 1123, 'Sneaky Pete S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104074.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17786, 1123, 'Sneaky Pete S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104075.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17787, 1123, 'Sneaky Pete S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104076.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17788, 1123, 'Sneaky Pete S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104077.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17789, 1124, 'Sneaky Pete S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/104078.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17790, 1124, 'Sneaky Pete S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/104079.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17791, 1124, 'Sneaky Pete S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/104080.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17792, 1124, 'Sneaky Pete S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/104081.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17793, 1124, 'Sneaky Pete S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/104082.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17794, 1124, 'Sneaky Pete S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/104083.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17795, 1124, 'Sneaky Pete S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/104084.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17796, 1124, 'Sneaky Pete S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/104085.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17797, 1124, 'Sneaky Pete S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/104086.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17798, 1124, 'Sneaky Pete S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/104087.mp4', 'http://gstaticontent.com/images/5dU7taWEgoH1RnmBqyUKmcD4ig4_big.jpg'),
(17799, 1125, 'The White Princess S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103977.mp4', 'http://gstaticontent.com/images/8urYFWrEd8ue94Fm4JpHccQg3M7_big.jpg'),
(17800, 1125, 'The White Princess S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103978.mp4', 'http://gstaticontent.com/images/8urYFWrEd8ue94Fm4JpHccQg3M7_big.jpg'),
(17801, 1125, 'The White Princess S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103979.mp4', 'http://gstaticontent.com/images/8urYFWrEd8ue94Fm4JpHccQg3M7_big.jpg'),
(17802, 1125, 'The White Princess S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103980.mp4', 'http://gstaticontent.com/images/8urYFWrEd8ue94Fm4JpHccQg3M7_big.jpg'),
(17803, 1125, 'The White Princess S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103981.mp4', 'http://gstaticontent.com/images/8urYFWrEd8ue94Fm4JpHccQg3M7_big.jpg'),
(17804, 1125, 'The White Princess S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103982.mp4', 'http://gstaticontent.com/images/8urYFWrEd8ue94Fm4JpHccQg3M7_big.jpg'),
(17805, 1125, 'The White Princess S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103983.mp4', 'http://gstaticontent.com/images/8urYFWrEd8ue94Fm4JpHccQg3M7_big.jpg'),
(17806, 1126, 'Pretty Little Liars The Perfectionists S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103948.mp4', 'http://gstaticontent.com/images/fc27a54e1f20da71f2a18a2b5146749a.jpg'),
(17807, 1126, 'Pretty Little Liars The Perfectionists S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103949.mp4', 'http://gstaticontent.com/images/fc27a54e1f20da71f2a18a2b5146749a.jpg'),
(17808, 1126, 'Pretty Little Liars The Perfectionists S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103950.mp4', 'http://gstaticontent.com/images/fc27a54e1f20da71f2a18a2b5146749a.jpg'),
(17809, 1126, 'Pretty Little Liars The Perfectionists S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103951.mp4', 'http://gstaticontent.com/images/fc27a54e1f20da71f2a18a2b5146749a.jpg'),
(17810, 1126, 'Pretty Little Liars The Perfectionists S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103952.mp4', 'http://gstaticontent.com/images/fc27a54e1f20da71f2a18a2b5146749a.jpg'),
(17811, 1126, 'Pretty Little Liars The Perfectionists S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103953.mp4', 'http://gstaticontent.com/images/fc27a54e1f20da71f2a18a2b5146749a.jpg'),
(17812, 1126, 'Pretty Little Liars The Perfectionists S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103954.mp4', 'http://gstaticontent.com/images/fc27a54e1f20da71f2a18a2b5146749a.jpg'),
(17813, 1126, 'Pretty Little Liars The Perfectionists S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103955.mp4', 'http://gstaticontent.com/images/fc27a54e1f20da71f2a18a2b5146749a.jpg'),
(17814, 1126, 'Pretty Little Liars The Perfectionists S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103956.mp4', 'http://gstaticontent.com/images/fc27a54e1f20da71f2a18a2b5146749a.jpg'),
(17815, 1126, 'Pretty Little Liars The Perfectionists S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103957.mp4', 'http://gstaticontent.com/images/fc27a54e1f20da71f2a18a2b5146749a.jpg'),
(17816, 1127, 'Terrores Urbanos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103943.mp4', 'http://gstaticontent.com/images/wNWfqkrD0dkSq8Lvk8Cw9pzc4JS_big.jpg'),
(17817, 1127, 'Terrores Urbanos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103944.mp4', 'http://gstaticontent.com/images/wNWfqkrD0dkSq8Lvk8Cw9pzc4JS_big.jpg'),
(17818, 1127, 'Terrores Urbanos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103945.mp4', 'http://gstaticontent.com/images/wNWfqkrD0dkSq8Lvk8Cw9pzc4JS_big.jpg'),
(17819, 1127, 'Terrores Urbanos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103946.mp4', 'http://gstaticontent.com/images/wNWfqkrD0dkSq8Lvk8Cw9pzc4JS_big.jpg'),
(17820, 1127, 'Terrores Urbanos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103947.mp4', 'http://gstaticontent.com/images/wNWfqkrD0dkSq8Lvk8Cw9pzc4JS_big.jpg'),
(17821, 1128, 'Instinto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103935.mp4', 'http://gstaticontent.com/images/a2dB5yR6CfMNsOoR18EULqdCIqQ_big.jpg'),
(17822, 1128, 'Instinto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103936.mp4', 'http://gstaticontent.com/images/a2dB5yR6CfMNsOoR18EULqdCIqQ_big.jpg'),
(17823, 1128, 'Instinto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103937.mp4', 'http://gstaticontent.com/images/a2dB5yR6CfMNsOoR18EULqdCIqQ_big.jpg'),
(17824, 1128, 'Instinto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103938.mp4', 'http://gstaticontent.com/images/a2dB5yR6CfMNsOoR18EULqdCIqQ_big.jpg'),
(17825, 1128, 'Instinto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103939.mp4', 'http://gstaticontent.com/images/a2dB5yR6CfMNsOoR18EULqdCIqQ_big.jpg'),
(17826, 1128, 'Instinto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103940.mp4', 'http://gstaticontent.com/images/a2dB5yR6CfMNsOoR18EULqdCIqQ_big.jpg'),
(17827, 1128, 'Instinto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103941.mp4', 'http://gstaticontent.com/images/a2dB5yR6CfMNsOoR18EULqdCIqQ_big.jpg'),
(17828, 1128, 'Instinto S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103942.mp4', 'http://gstaticontent.com/images/a2dB5yR6CfMNsOoR18EULqdCIqQ_big.jpg'),
(17829, 1129, 'Strike Back [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130579.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17830, 1129, 'Strike Back [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130580.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17831, 1129, 'Strike Back [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130581.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17832, 1129, 'Strike Back [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130582.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17833, 1129, 'Strike Back [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130583.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17834, 1129, 'Strike Back [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130584.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17835, 1130, 'Strike Back [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130585.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17836, 1130, 'Strike Back [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130586.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17837, 1130, 'Strike Back [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130587.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17838, 1130, 'Strike Back [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130588.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17839, 1130, 'Strike Back [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130589.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17840, 1130, 'Strike Back [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130590.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17841, 1130, 'Strike Back [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130591.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17842, 1130, 'Strike Back [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130592.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17843, 1130, 'Strike Back [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130593.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17844, 1130, 'Strike Back [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130594.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17845, 1131, 'Strike Back [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130595.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17846, 1131, 'Strike Back [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130596.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17847, 1131, 'Strike Back [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130597.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17848, 1131, 'Strike Back [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130598.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17849, 1131, 'Strike Back [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130599.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17850, 1131, 'Strike Back [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130600.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17851, 1131, 'Strike Back [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130601.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17852, 1131, 'Strike Back [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130602.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17853, 1131, 'Strike Back [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130603.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17854, 1132, 'Strike Back [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130604.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17855, 1132, 'Strike Back [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130605.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17856, 1132, 'Strike Back [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130606.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17857, 1132, 'Strike Back [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130607.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17858, 1132, 'Strike Back [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130608.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17859, 1132, 'Strike Back [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130609.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17860, 1132, 'Strike Back [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130610.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17861, 1132, 'Strike Back [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130611.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17862, 1132, 'Strike Back [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130612.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17863, 1132, 'Strike Back [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130613.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17864, 1133, 'Strike Back [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130614.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17865, 1133, 'Strike Back [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130615.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17866, 1133, 'Strike Back [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130616.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17867, 1133, 'Strike Back [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130617.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17868, 1133, 'Strike Back [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130618.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17869, 1133, 'Strike Back [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130619.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17870, 1133, 'Strike Back [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130620.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17871, 1133, 'Strike Back [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130621.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17872, 1133, 'Strike Back [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130622.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17873, 1133, 'Strike Back [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130623.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17874, 1134, 'Strike Back [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130624.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17875, 1134, 'Strike Back [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130625.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17876, 1134, 'Strike Back [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130626.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17877, 1134, 'Strike Back [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130627.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17878, 1134, 'Strike Back [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130628.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17879, 1134, 'Strike Back [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130629.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17880, 1134, 'Strike Back [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130630.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17881, 1134, 'Strike Back [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130631.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17882, 1134, 'Strike Back [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130632.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17883, 1134, 'Strike Back [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130633.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17884, 1135, 'Strike Back [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130634.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17885, 1135, 'Strike Back [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130635.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17886, 1135, 'Strike Back [L] S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130636.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17887, 1135, 'Strike Back [L] S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130637.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17888, 1135, 'Strike Back [L] S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130638.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17889, 1135, 'Strike Back [L] S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130639.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17890, 1135, 'Strike Back [L] S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130640.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17891, 1135, 'Strike Back [L] S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130641.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17892, 1135, 'Strike Back [L] S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130642.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17893, 1135, 'Strike Back [L] S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130643.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17894, 1136, 'Strike Back [L] S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130644.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17895, 1136, 'Strike Back [L] S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130645.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17896, 1136, 'Strike Back [L] S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130646.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17897, 1136, 'Strike Back [L] S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130647.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17898, 1136, 'Strike Back [L] S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130648.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17899, 1136, 'Strike Back [L] S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130649.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17900, 1136, 'Strike Back [L] S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130650.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17901, 1136, 'Strike Back [L] S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130651.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17902, 1136, 'Strike Back [L] S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130652.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17903, 1136, 'Strike Back [L] S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130653.mp4', 'http://gstaticontent.com/images/rFy3EOZrRymjkalih7W3v8kSVWr_big.jpg'),
(17904, 1137, 'Mya Go S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103883.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17905, 1137, 'Mya Go S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103884.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17906, 1137, 'Mya Go S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103885.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17907, 1137, 'Mya Go S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103886.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17908, 1137, 'Mya Go S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103887.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17909, 1137, 'Mya Go S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103888.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17910, 1137, 'Mya Go S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103889.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17911, 1137, 'Mya Go S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103890.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17912, 1137, 'Mya Go S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103891.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17913, 1137, 'Mya Go S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103892.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17914, 1137, 'Mya Go S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103893.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17915, 1137, 'Mya Go S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103894.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17916, 1137, 'Mya Go S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/103895.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17917, 1137, 'Mya Go S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/103896.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17918, 1137, 'Mya Go S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/103897.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17919, 1137, 'Mya Go S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/103898.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17920, 1137, 'Mya Go S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/103899.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17921, 1137, 'Mya Go S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/103900.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17922, 1137, 'Mya Go S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/103901.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17923, 1137, 'Mya Go S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/103902.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17924, 1137, 'Mya Go S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/103903.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17925, 1137, 'Mya Go S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/103904.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17926, 1137, 'Mya Go S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/103905.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17927, 1137, 'Mya Go S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/103906.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17928, 1137, 'Mya Go S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/103907.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17929, 1137, 'Mya Go S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/103908.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17930, 1137, 'Mya Go S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/103909.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17931, 1137, 'Mya Go S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/103910.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17932, 1137, 'Mya Go S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/103911.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17933, 1137, 'Mya Go S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/103912.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17934, 1137, 'Mya Go S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/103913.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17935, 1137, 'Mya Go S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/103914.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17936, 1137, 'Mya Go S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/103915.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17937, 1137, 'Mya Go S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/103916.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17938, 1137, 'Mya Go S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/103917.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17939, 1137, 'Mya Go S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/103918.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17940, 1137, 'Mya Go S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/103919.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17941, 1137, 'Mya Go S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/103920.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17942, 1137, 'Mya Go S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/103921.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17943, 1137, 'Mya Go S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/103922.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17944, 1137, 'Mya Go S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/103923.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17945, 1137, 'Mya Go S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/103924.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17946, 1137, 'Mya Go S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/103925.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17947, 1137, 'Mya Go S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/103926.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17948, 1137, 'Mya Go S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/103927.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17949, 1137, 'Mya Go S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/103928.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17950, 1137, 'Mya Go S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/103929.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17951, 1137, 'Mya Go S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/103930.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17952, 1137, 'Mya Go S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/103931.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17953, 1137, 'Mya Go S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/103932.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17954, 1137, 'Mya Go S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/103933.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17955, 1137, 'Mya Go S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/103934.mp4', 'http://gstaticontent.com/images/3oUyuWmhN9AQG3QZCjkip79PNl0_big.jpg'),
(17956, 1138, 'Strange Angel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103873.mp4', 'http://gstaticontent.com/images/61tpMZTpqzJ1T6nCqMyPvAQuGZM_big.jpg'),
(17957, 1138, 'Strange Angel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103874.mp4', 'http://gstaticontent.com/images/61tpMZTpqzJ1T6nCqMyPvAQuGZM_big.jpg'),
(17958, 1138, 'Strange Angel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103875.mp4', 'http://gstaticontent.com/images/61tpMZTpqzJ1T6nCqMyPvAQuGZM_big.jpg'),
(17959, 1138, 'Strange Angel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103876.mp4', 'http://gstaticontent.com/images/61tpMZTpqzJ1T6nCqMyPvAQuGZM_big.jpg'),
(17960, 1138, 'Strange Angel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103877.mp4', 'http://gstaticontent.com/images/61tpMZTpqzJ1T6nCqMyPvAQuGZM_big.jpg'),
(17961, 1138, 'Strange Angel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103878.mp4', 'http://gstaticontent.com/images/61tpMZTpqzJ1T6nCqMyPvAQuGZM_big.jpg'),
(17962, 1138, 'Strange Angel S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103879.mp4', 'http://gstaticontent.com/images/61tpMZTpqzJ1T6nCqMyPvAQuGZM_big.jpg'),
(17963, 1138, 'Strange Angel S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103880.mp4', 'http://gstaticontent.com/images/61tpMZTpqzJ1T6nCqMyPvAQuGZM_big.jpg'),
(17964, 1138, 'Strange Angel S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103881.mp4', 'http://gstaticontent.com/images/61tpMZTpqzJ1T6nCqMyPvAQuGZM_big.jpg'),
(17965, 1138, 'Strange Angel S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103882.mp4', 'http://gstaticontent.com/images/61tpMZTpqzJ1T6nCqMyPvAQuGZM_big.jpg'),
(17966, 1139, 'As Crônicas de Shannara S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103853.mp4', 'http://gstaticontent.com/images/mumIOwzoVjMr9aEANbpWyIlYDir_big.jpg'),
(17967, 1139, 'As Crônicas de Shannara S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103854.mp4', 'http://gstaticontent.com/images/mumIOwzoVjMr9aEANbpWyIlYDir_big.jpg'),
(17968, 1139, 'As Crônicas de Shannara S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103855.mp4', 'http://gstaticontent.com/images/mumIOwzoVjMr9aEANbpWyIlYDir_big.jpg'),
(17969, 1139, 'As Crônicas de Shannara S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103856.mp4', 'http://gstaticontent.com/images/mumIOwzoVjMr9aEANbpWyIlYDir_big.jpg'),
(17970, 1139, 'As Crônicas de Shannara S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103857.mp4', 'http://gstaticontent.com/images/mumIOwzoVjMr9aEANbpWyIlYDir_big.jpg'),
(17971, 1139, 'As Crônicas de Shannara S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103858.mp4', 'http://gstaticontent.com/images/mumIOwzoVjMr9aEANbpWyIlYDir_big.jpg'),
(17972, 1139, 'As Crônicas de Shannara S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103859.mp4', 'http://gstaticontent.com/images/mumIOwzoVjMr9aEANbpWyIlYDir_big.jpg'),
(17973, 1139, 'As Crônicas de Shannara S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103860.mp4', 'http://gstaticontent.com/images/mumIOwzoVjMr9aEANbpWyIlYDir_big.jpg'),
(17974, 1139, 'As Crônicas de Shannara S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103861.mp4', 'http://gstaticontent.com/images/mumIOwzoVjMr9aEANbpWyIlYDir_big.jpg'),
(17975, 1139, 'As Crônicas de Shannara S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103862.mp4', 'http://gstaticontent.com/images/mumIOwzoVjMr9aEANbpWyIlYDir_big.jpg'),
(17976, 1140, 'As Crônicas de Shannara S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103863.mp4', 'http://gstaticontent.com/images/mumIOwzoVjMr9aEANbpWyIlYDir_big.jpg'),
(17977, 1140, 'As Crônicas de Shannara S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103864.mp4', 'http://gstaticontent.com/images/mumIOwzoVjMr9aEANbpWyIlYDir_big.jpg'),
(17978, 1140, 'As Crônicas de Shannara S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103865.mp4', 'http://gstaticontent.com/images/mumIOwzoVjMr9aEANbpWyIlYDir_big.jpg'),
(17979, 1140, 'As Crônicas de Shannara S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103866.mp4', 'http://gstaticontent.com/images/mumIOwzoVjMr9aEANbpWyIlYDir_big.jpg'),
(17980, 1140, 'As Crônicas de Shannara S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103867.mp4', 'http://gstaticontent.com/images/mumIOwzoVjMr9aEANbpWyIlYDir_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(17981, 1140, 'As Crônicas de Shannara S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103868.mp4', 'http://gstaticontent.com/images/mumIOwzoVjMr9aEANbpWyIlYDir_big.jpg'),
(17982, 1140, 'As Crônicas de Shannara S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103869.mp4', 'http://gstaticontent.com/images/mumIOwzoVjMr9aEANbpWyIlYDir_big.jpg'),
(17983, 1140, 'As Crônicas de Shannara S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103870.mp4', 'http://gstaticontent.com/images/mumIOwzoVjMr9aEANbpWyIlYDir_big.jpg'),
(17984, 1140, 'As Crônicas de Shannara S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103871.mp4', 'http://gstaticontent.com/images/mumIOwzoVjMr9aEANbpWyIlYDir_big.jpg'),
(17985, 1140, 'As Crônicas de Shannara S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103872.mp4', 'http://gstaticontent.com/images/mumIOwzoVjMr9aEANbpWyIlYDir_big.jpg'),
(17986, 1141, 'Vidrados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103843.mp4', 'http://gstaticontent.com/images/9YmSm6x2aER6a7vfoOTDL9cKEuF_big.jpg'),
(17987, 1141, 'Vidrados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103844.mp4', 'http://gstaticontent.com/images/9YmSm6x2aER6a7vfoOTDL9cKEuF_big.jpg'),
(17988, 1141, 'Vidrados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103845.mp4', 'http://gstaticontent.com/images/9YmSm6x2aER6a7vfoOTDL9cKEuF_big.jpg'),
(17989, 1141, 'Vidrados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103846.mp4', 'http://gstaticontent.com/images/9YmSm6x2aER6a7vfoOTDL9cKEuF_big.jpg'),
(17990, 1141, 'Vidrados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103847.mp4', 'http://gstaticontent.com/images/9YmSm6x2aER6a7vfoOTDL9cKEuF_big.jpg'),
(17991, 1141, 'Vidrados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103848.mp4', 'http://gstaticontent.com/images/9YmSm6x2aER6a7vfoOTDL9cKEuF_big.jpg'),
(17992, 1141, 'Vidrados S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103849.mp4', 'http://gstaticontent.com/images/9YmSm6x2aER6a7vfoOTDL9cKEuF_big.jpg'),
(17993, 1141, 'Vidrados S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103850.mp4', 'http://gstaticontent.com/images/9YmSm6x2aER6a7vfoOTDL9cKEuF_big.jpg'),
(17994, 1141, 'Vidrados S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103851.mp4', 'http://gstaticontent.com/images/9YmSm6x2aER6a7vfoOTDL9cKEuF_big.jpg'),
(17995, 1141, 'Vidrados S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103852.mp4', 'http://gstaticontent.com/images/9YmSm6x2aER6a7vfoOTDL9cKEuF_big.jpg'),
(17996, 1142, 'Os Cavaleiros do Zodiaco Saint Seiya S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(17997, 1142, 'Os Cavaleiros do Zodiaco Saint Seiya S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(17998, 1142, 'Os Cavaleiros do Zodiaco Saint Seiya S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(17999, 1142, 'Os Cavaleiros do Zodiaco Saint Seiya S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(18000, 1142, 'Os Cavaleiros do Zodiaco Saint Seiya S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(18001, 1142, 'Os Cavaleiros do Zodiaco Saint Seiya S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(18002, 1143, 'Os Cavaleiros do Zodiaco Saint Seiya S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108518.mp4', 'http://timg.bdta.pro/images/184cd0f532b99cf3b8899c99bb2259c2.jpg'),
(18003, 1143, 'Os Cavaleiros do Zodiaco Saint Seiya S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108519.mp4', 'http://timg.bdta.pro/images/6026c821291df4fdc87ce3f1a2ed4709.jpg'),
(18004, 1143, 'Os Cavaleiros do Zodiaco Saint Seiya S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108520.mp4', 'http://timg.bdta.pro/images/82ac1303f6bd62305f3cb10c84e3d243.jpg'),
(18005, 1143, 'Os Cavaleiros do Zodiaco Saint Seiya S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108521.mp4', 'http://timg.bdta.pro/images/c63a0da8793ce35af35b49b9872df4cb.jpg'),
(18006, 1143, 'Os Cavaleiros do Zodiaco Saint Seiya S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108522.mp4', 'http://timg.bdta.pro/images/c78c42c8fff491eac6c31af65a93e6d3.jpg'),
(18007, 1143, 'Os Cavaleiros do Zodiaco Saint Seiya S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108523.mp4', 'http://timg.bdta.pro/images/04fa69e2ef99488451a51108e68a9438.jpg'),
(18008, 1143, 'Os Cavaleiros do Zodiaco Saint Seiya S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/323360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(18009, 1143, 'Os Cavaleiros do Zodiaco Saint Seiya S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/323361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(18010, 1143, 'Os Cavaleiros do Zodiaco Saint Seiya S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/323362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(18011, 1143, 'Os Cavaleiros do Zodiaco Saint Seiya S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/323363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(18012, 1143, 'Os Cavaleiros do Zodiaco Saint Seiya S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/323364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(18013, 1143, 'Os Cavaleiros do Zodiaco Saint Seiya S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/323365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(18014, 1144, 'Os Cavaleiros do Zodiaco Saint Seiya S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/323366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(18015, 1144, 'Os Cavaleiros do Zodiaco Saint Seiya S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/323367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(18016, 1144, 'Os Cavaleiros do Zodiaco Saint Seiya S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/323368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(18017, 1144, 'Os Cavaleiros do Zodiaco Saint Seiya S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/326780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(18018, 1144, 'Os Cavaleiros do Zodiaco Saint Seiya S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/329415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(18019, 1144, 'Os Cavaleiros do Zodiaco Saint Seiya S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/337294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(18020, 1144, 'Os Cavaleiros do Zodiaco Saint Seiya S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/343825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(18021, 1144, 'Os Cavaleiros do Zodiaco Saint Seiya S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/354984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(18022, 1144, 'Os Cavaleiros do Zodiaco Saint Seiya S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/354985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(18023, 1144, 'Os Cavaleiros do Zodiaco Saint Seiya S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/360535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(18024, 1144, 'Os Cavaleiros do Zodiaco Saint Seiya S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/373386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(18025, 1144, 'Os Cavaleiros do Zodiaco Saint Seiya S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/381909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j39p6zfHETY2O8nakbOHcwcMxay.jpg'),
(18026, 1145, 'Ouro e Sangue S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126682.mp4', 'http://gstaticontent.com/images/aJpsyLNDKuVxMKKoG1bQ8AA9781_big.jpg'),
(18027, 1145, 'Ouro e Sangue S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126683.mp4', 'http://gstaticontent.com/images/aJpsyLNDKuVxMKKoG1bQ8AA9781_big.jpg'),
(18028, 1145, 'Ouro e Sangue S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126684.mp4', 'http://gstaticontent.com/images/aJpsyLNDKuVxMKKoG1bQ8AA9781_big.jpg'),
(18029, 1145, 'Ouro e Sangue S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126685.mp4', 'http://gstaticontent.com/images/aJpsyLNDKuVxMKKoG1bQ8AA9781_big.jpg'),
(18030, 1145, 'Ouro e Sangue S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126686.mp4', 'http://gstaticontent.com/images/aJpsyLNDKuVxMKKoG1bQ8AA9781_big.jpg'),
(18031, 1145, 'Ouro e Sangue S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126687.mp4', 'http://gstaticontent.com/images/aJpsyLNDKuVxMKKoG1bQ8AA9781_big.jpg'),
(18032, 1145, 'Ouro e Sangue S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126688.mp4', 'http://gstaticontent.com/images/aJpsyLNDKuVxMKKoG1bQ8AA9781_big.jpg'),
(18033, 1145, 'Ouro e Sangue S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126689.mp4', 'http://gstaticontent.com/images/aJpsyLNDKuVxMKKoG1bQ8AA9781_big.jpg'),
(18034, 1146, 'Ouro e Sangue S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126690.mp4', 'http://timg.bdta.pro/images/d68c4916d3b862a07c9660a9ce3ff703.jpg'),
(18035, 1146, 'Ouro e Sangue S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126691.mp4', 'http://timg.bdta.pro/images/610ff161833a1293508f09ba777498ed.jpg'),
(18036, 1146, 'Ouro e Sangue S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126692.mp4', 'http://timg.bdta.pro/images/cb7dd9cef65876f408306154c2a83047.jpg'),
(18037, 1146, 'Ouro e Sangue S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126693.mp4', 'http://timg.bdta.pro/images/6e02cc97b72cfa882476a43a79eb3bf0.jpg'),
(18038, 1146, 'Ouro e Sangue S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126694.mp4', 'http://timg.bdta.pro/images/6e02cc97b72cfa882476a43a79eb3bf0.jpg'),
(18039, 1146, 'Ouro e Sangue S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126695.mp4', 'http://timg.bdta.pro/images/6e02cc97b72cfa882476a43a79eb3bf0.jpg'),
(18040, 1146, 'Ouro e Sangue S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126696.mp4', 'http://timg.bdta.pro/images/6e02cc97b72cfa882476a43a79eb3bf0.jpg'),
(18041, 1146, 'Ouro e Sangue S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126697.mp4', 'http://timg.bdta.pro/images/6e02cc97b72cfa882476a43a79eb3bf0.jpg'),
(18042, 1147, 'Ouro e Sangue S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126698.mp4', 'http://timg.bdta.pro/images/7cbb9372623a4d64829350a8e846df70.jpg'),
(18043, 1147, 'Ouro e Sangue S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126699.mp4', 'http://timg.bdta.pro/images/d71421cf3404e6ce7ec8f64babb8f4c8.jpg'),
(18044, 1147, 'Ouro e Sangue S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126700.mp4', 'http://timg.bdta.pro/images/88347588b1238b6670ae8f32f90736a2.jpg'),
(18045, 1147, 'Ouro e Sangue S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126701.mp4', 'http://timg.bdta.pro/images/3261425dccebb1f22b05301e84f1c690.jpg'),
(18046, 1147, 'Ouro e Sangue S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126702.mp4', 'http://timg.bdta.pro/images/fd8241d57f86b30d231d0c4d3a86c2be.jpg'),
(18047, 1147, 'Ouro e Sangue S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126703.mp4', 'http://timg.bdta.pro/images/82fb2df652e7333cd36864744315d899.jpg'),
(18048, 1147, 'Ouro e Sangue S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126704.mp4', 'http://timg.bdta.pro/images/56073f4ab316133f1b69505d21c0ccc8.jpg'),
(18049, 1147, 'Ouro e Sangue S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126705.mp4', 'http://timg.bdta.pro/images/dfb3cf4b5e07dc62ecb24d2d496c5e5e.jpg'),
(18050, 1148, 'A Divisão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243318.mp4', 'http://gstaticontent.com/images/zMD3mdhkBvxastdWzurZfgmgjaO_big.jpg'),
(18051, 1148, 'A Divisão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243319.mp4', 'http://gstaticontent.com/images/zMD3mdhkBvxastdWzurZfgmgjaO_big.jpg'),
(18052, 1148, 'A Divisão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243320.mp4', 'http://gstaticontent.com/images/zMD3mdhkBvxastdWzurZfgmgjaO_big.jpg'),
(18053, 1148, 'A Divisão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243321.mp4', 'http://gstaticontent.com/images/zMD3mdhkBvxastdWzurZfgmgjaO_big.jpg'),
(18054, 1148, 'A Divisão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243322.mp4', 'http://gstaticontent.com/images/zMD3mdhkBvxastdWzurZfgmgjaO_big.jpg'),
(18055, 1149, 'A Divisão S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243323.mp4', 'http://gstaticontent.com/images/zMD3mdhkBvxastdWzurZfgmgjaO_big.jpg'),
(18056, 1149, 'A Divisão S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243324.mp4', 'http://gstaticontent.com/images/zMD3mdhkBvxastdWzurZfgmgjaO_big.jpg'),
(18057, 1149, 'A Divisão S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243325.mp4', 'http://gstaticontent.com/images/zMD3mdhkBvxastdWzurZfgmgjaO_big.jpg'),
(18058, 1149, 'A Divisão S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243326.mp4', 'http://gstaticontent.com/images/zMD3mdhkBvxastdWzurZfgmgjaO_big.jpg'),
(18059, 1149, 'A Divisão S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243327.mp4', 'http://gstaticontent.com/images/zMD3mdhkBvxastdWzurZfgmgjaO_big.jpg'),
(18060, 1150, 'A Divisão S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243328.mp4', 'http://gstaticontent.com/images/zMD3mdhkBvxastdWzurZfgmgjaO_big.jpg'),
(18061, 1150, 'A Divisão S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243329.mp4', 'http://gstaticontent.com/images/zMD3mdhkBvxastdWzurZfgmgjaO_big.jpg'),
(18062, 1150, 'A Divisão S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243330.mp4', 'http://gstaticontent.com/images/zMD3mdhkBvxastdWzurZfgmgjaO_big.jpg'),
(18063, 1150, 'A Divisão S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243331.mp4', 'http://gstaticontent.com/images/zMD3mdhkBvxastdWzurZfgmgjaO_big.jpg'),
(18064, 1150, 'A Divisão S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243332.mp4', 'http://gstaticontent.com/images/zMD3mdhkBvxastdWzurZfgmgjaO_big.jpg'),
(18065, 1151, 'A Divisão S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/739459.mp4', 'http://gstaticontent.com/images/zMD3mdhkBvxastdWzurZfgmgjaO_big.jpg'),
(18066, 1151, 'A Divisão S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/739460.mp4', 'http://gstaticontent.com/images/zMD3mdhkBvxastdWzurZfgmgjaO_big.jpg'),
(18067, 1151, 'A Divisão S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/739461.mp4', 'http://gstaticontent.com/images/zMD3mdhkBvxastdWzurZfgmgjaO_big.jpg'),
(18068, 1151, 'A Divisão S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/739462.mp4', 'http://gstaticontent.com/images/zMD3mdhkBvxastdWzurZfgmgjaO_big.jpg'),
(18069, 1151, 'A Divisão S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/739463.mp4', 'http://gstaticontent.com/images/zMD3mdhkBvxastdWzurZfgmgjaO_big.jpg'),
(18070, 1152, 'Da Terra A Lua S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103831.mp4', 'http://gstaticontent.com/images/sSnYvoVT2PYWJbF0aWdUFvLqKhR_big.jpg'),
(18071, 1152, 'Da Terra A Lua S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103832.mp4', 'http://gstaticontent.com/images/sSnYvoVT2PYWJbF0aWdUFvLqKhR_big.jpg'),
(18072, 1152, 'Da Terra A Lua S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103833.mp4', 'http://gstaticontent.com/images/sSnYvoVT2PYWJbF0aWdUFvLqKhR_big.jpg'),
(18073, 1152, 'Da Terra A Lua S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103834.mp4', 'http://gstaticontent.com/images/sSnYvoVT2PYWJbF0aWdUFvLqKhR_big.jpg'),
(18074, 1152, 'Da Terra A Lua S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103835.mp4', 'http://gstaticontent.com/images/sSnYvoVT2PYWJbF0aWdUFvLqKhR_big.jpg'),
(18075, 1152, 'Da Terra A Lua S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103836.mp4', 'http://gstaticontent.com/images/sSnYvoVT2PYWJbF0aWdUFvLqKhR_big.jpg'),
(18076, 1152, 'Da Terra A Lua S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103837.mp4', 'http://gstaticontent.com/images/sSnYvoVT2PYWJbF0aWdUFvLqKhR_big.jpg'),
(18077, 1152, 'Da Terra A Lua S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103838.mp4', 'http://gstaticontent.com/images/sSnYvoVT2PYWJbF0aWdUFvLqKhR_big.jpg'),
(18078, 1152, 'Da Terra A Lua S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103839.mp4', 'http://gstaticontent.com/images/sSnYvoVT2PYWJbF0aWdUFvLqKhR_big.jpg'),
(18079, 1152, 'Da Terra A Lua S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103840.mp4', 'http://gstaticontent.com/images/sSnYvoVT2PYWJbF0aWdUFvLqKhR_big.jpg'),
(18080, 1152, 'Da Terra A Lua S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103841.mp4', 'http://gstaticontent.com/images/sSnYvoVT2PYWJbF0aWdUFvLqKhR_big.jpg'),
(18081, 1152, 'Da Terra A Lua S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103842.mp4', 'http://gstaticontent.com/images/sSnYvoVT2PYWJbF0aWdUFvLqKhR_big.jpg'),
(18082, 1153, 'Toque de Recolher S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103823.mp4', 'http://gstaticontent.com/images/vqYapg2WJw6dga93967lACbOS6Y_big.jpg'),
(18083, 1153, 'Toque de Recolher S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103824.mp4', 'http://gstaticontent.com/images/vqYapg2WJw6dga93967lACbOS6Y_big.jpg'),
(18084, 1153, 'Toque de Recolher S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103825.mp4', 'http://gstaticontent.com/images/vqYapg2WJw6dga93967lACbOS6Y_big.jpg'),
(18085, 1153, 'Toque de Recolher S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103826.mp4', 'http://gstaticontent.com/images/vqYapg2WJw6dga93967lACbOS6Y_big.jpg'),
(18086, 1153, 'Toque de Recolher S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103827.mp4', 'http://gstaticontent.com/images/vqYapg2WJw6dga93967lACbOS6Y_big.jpg'),
(18087, 1153, 'Toque de Recolher S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103828.mp4', 'http://gstaticontent.com/images/vqYapg2WJw6dga93967lACbOS6Y_big.jpg'),
(18088, 1153, 'Toque de Recolher S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103829.mp4', 'http://gstaticontent.com/images/vqYapg2WJw6dga93967lACbOS6Y_big.jpg'),
(18089, 1153, 'Toque de Recolher S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103830.mp4', 'http://gstaticontent.com/images/vqYapg2WJw6dga93967lACbOS6Y_big.jpg'),
(18090, 1154, 'You Me Her S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103784.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18091, 1154, 'You Me Her S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103785.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18092, 1154, 'You Me Her S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103786.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18093, 1154, 'You Me Her S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103787.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18094, 1154, 'You Me Her S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103788.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18095, 1154, 'You Me Her S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103789.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18096, 1154, 'You Me Her S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103790.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18097, 1154, 'You Me Her S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103791.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18098, 1154, 'You Me Her S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103792.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18099, 1154, 'You Me Her S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103793.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18100, 1155, 'You Me Her S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103794.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18101, 1155, 'You Me Her S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103795.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18102, 1155, 'You Me Her S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103796.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18103, 1155, 'You Me Her S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103797.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18104, 1155, 'You Me Her S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103798.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18105, 1155, 'You Me Her S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103799.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18106, 1155, 'You Me Her S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103800.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18107, 1155, 'You Me Her S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103801.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18108, 1155, 'You Me Her S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103802.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18109, 1155, 'You Me Her S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103803.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18110, 1156, 'You Me Her S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103804.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18111, 1156, 'You Me Her S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103805.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18112, 1156, 'You Me Her S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103806.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18113, 1156, 'You Me Her S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103807.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18114, 1156, 'You Me Her S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103808.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18115, 1156, 'You Me Her S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103809.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18116, 1156, 'You Me Her S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103810.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18117, 1156, 'You Me Her S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103811.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18118, 1156, 'You Me Her S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103812.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18119, 1157, 'You Me Her S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103813.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18120, 1157, 'You Me Her S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103814.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18121, 1157, 'You Me Her S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103815.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18122, 1157, 'You Me Her S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103816.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18123, 1157, 'You Me Her S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103817.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18124, 1157, 'You Me Her S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103818.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18125, 1157, 'You Me Her S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103819.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18126, 1157, 'You Me Her S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103820.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18127, 1157, 'You Me Her S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103821.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18128, 1157, 'You Me Her S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103822.mp4', 'http://gstaticontent.com/images/2kGB4jNvaCGq1Ia5ZKIrq5Voycf_big.jpg'),
(18129, 1158, 'Wild Wild Country S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103778.mp4', 'http://gstaticontent.com/images/kprB5Jj2LYQAYlqVQMEucT2vGt_big.jpg'),
(18130, 1158, 'Wild Wild Country S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103779.mp4', 'http://gstaticontent.com/images/kprB5Jj2LYQAYlqVQMEucT2vGt_big.jpg'),
(18131, 1158, 'Wild Wild Country S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103780.mp4', 'http://gstaticontent.com/images/kprB5Jj2LYQAYlqVQMEucT2vGt_big.jpg'),
(18132, 1158, 'Wild Wild Country S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103781.mp4', 'http://gstaticontent.com/images/kprB5Jj2LYQAYlqVQMEucT2vGt_big.jpg'),
(18133, 1158, 'Wild Wild Country S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103782.mp4', 'http://gstaticontent.com/images/kprB5Jj2LYQAYlqVQMEucT2vGt_big.jpg'),
(18134, 1158, 'Wild Wild Country S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103783.mp4', 'http://gstaticontent.com/images/kprB5Jj2LYQAYlqVQMEucT2vGt_big.jpg'),
(18135, 1159, 'Rotas do Odio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136797.mp4', 'http://gstaticontent.com/images/cRjGc1Am6dflcMGlxujUJsNWvsr_big.jpg'),
(18136, 1159, 'Rotas do Odio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136798.mp4', 'http://gstaticontent.com/images/cRjGc1Am6dflcMGlxujUJsNWvsr_big.jpg'),
(18137, 1159, 'Rotas do Odio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136799.mp4', 'http://gstaticontent.com/images/cRjGc1Am6dflcMGlxujUJsNWvsr_big.jpg'),
(18138, 1159, 'Rotas do Odio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136800.mp4', 'http://gstaticontent.com/images/cRjGc1Am6dflcMGlxujUJsNWvsr_big.jpg'),
(18139, 1159, 'Rotas do Odio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136801.mp4', 'http://gstaticontent.com/images/cRjGc1Am6dflcMGlxujUJsNWvsr_big.jpg'),
(18140, 1160, 'Rotas do Odio S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136802.mp4', 'http://gstaticontent.com/images/cRjGc1Am6dflcMGlxujUJsNWvsr_big.jpg'),
(18141, 1160, 'Rotas do Odio S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136803.mp4', 'http://gstaticontent.com/images/cRjGc1Am6dflcMGlxujUJsNWvsr_big.jpg'),
(18142, 1160, 'Rotas do Odio S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136804.mp4', 'http://gstaticontent.com/images/cRjGc1Am6dflcMGlxujUJsNWvsr_big.jpg'),
(18143, 1160, 'Rotas do Odio S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136805.mp4', 'http://gstaticontent.com/images/cRjGc1Am6dflcMGlxujUJsNWvsr_big.jpg'),
(18144, 1160, 'Rotas do Odio S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136806.mp4', 'http://gstaticontent.com/images/cRjGc1Am6dflcMGlxujUJsNWvsr_big.jpg'),
(18145, 1161, 'Rotas do Odio S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136807.mp4', 'http://gstaticontent.com/images/cRjGc1Am6dflcMGlxujUJsNWvsr_big.jpg'),
(18146, 1161, 'Rotas do Odio S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136808.mp4', 'http://gstaticontent.com/images/cRjGc1Am6dflcMGlxujUJsNWvsr_big.jpg'),
(18147, 1161, 'Rotas do Odio S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136809.mp4', 'http://gstaticontent.com/images/cRjGc1Am6dflcMGlxujUJsNWvsr_big.jpg'),
(18148, 1161, 'Rotas do Odio S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136810.mp4', 'http://gstaticontent.com/images/cRjGc1Am6dflcMGlxujUJsNWvsr_big.jpg'),
(18149, 1162, 'The Boys S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183110.mp4', 'http://gstaticontent.com/images/dzOxNbbz1liFzHU1IPvdgUR647b_big.jpg'),
(18150, 1162, 'The Boys S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183111.mp4', 'http://gstaticontent.com/images/dzOxNbbz1liFzHU1IPvdgUR647b_big.jpg'),
(18151, 1162, 'The Boys S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183112.mp4', 'http://gstaticontent.com/images/dzOxNbbz1liFzHU1IPvdgUR647b_big.jpg'),
(18152, 1162, 'The Boys S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183113.mp4', 'http://gstaticontent.com/images/dzOxNbbz1liFzHU1IPvdgUR647b_big.jpg'),
(18153, 1162, 'The Boys S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183114.mp4', 'http://gstaticontent.com/images/dzOxNbbz1liFzHU1IPvdgUR647b_big.jpg'),
(18154, 1162, 'The Boys S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183115.mp4', 'http://gstaticontent.com/images/dzOxNbbz1liFzHU1IPvdgUR647b_big.jpg'),
(18155, 1162, 'The Boys S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183116.mp4', 'http://gstaticontent.com/images/dzOxNbbz1liFzHU1IPvdgUR647b_big.jpg'),
(18156, 1162, 'The Boys S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183117.mp4', 'http://gstaticontent.com/images/dzOxNbbz1liFzHU1IPvdgUR647b_big.jpg'),
(18157, 1163, 'The Boys S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183118.mp4', 'http://timg.bdta.pro/images/332bb63a5ede0749257c2cb8d350843a.jpg'),
(18158, 1163, 'The Boys S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183119.mp4', 'http://timg.bdta.pro/images/d597b27295445c3873d20672c760d5b7.jpg'),
(18159, 1163, 'The Boys S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183120.mp4', 'http://timg.bdta.pro/images/66aa5fa1a17d2d8c0e4631dcfd44bcc0.jpg'),
(18160, 1163, 'The Boys S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183121.mp4', 'http://timg.bdta.pro/images/13cb76be54aafe54ab91601604c0df30.jpg'),
(18161, 1163, 'The Boys S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183122.mp4', 'http://timg.bdta.pro/images/5f236c5b9e8d86c54ce3a5f6537a451f.jpg'),
(18162, 1163, 'The Boys S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183123.mp4', 'http://timg.bdta.pro/images/8c9197af97b150d99c5bfa0ef1da8562.jpg'),
(18163, 1163, 'The Boys S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183124.mp4', 'http://timg.bdta.pro/images/6c029709d7157e0904e3415c362ae099.jpg'),
(18164, 1163, 'The Boys S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183125.mp4', 'http://timg.bdta.pro/images/97fbe9eb2ccb907b6dda8e92cc7e0328.jpg'),
(18165, 1164, 'The Boys S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183126.mp4', 'http://timg.bdta.pro/images/d2b2ed413c6523273d945f92ae886329.jpg'),
(18166, 1164, 'The Boys S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183127.mp4', 'http://timg.bdta.pro/images/fedb6a5a83035f726d0137fd58a459c1.jpg'),
(18167, 1164, 'The Boys S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183128.mp4', 'http://timg.bdta.pro/images/1f8498a1b2100580e8bb4f534e090588.jpg'),
(18168, 1164, 'The Boys S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183129.mp4', 'http://timg.bdta.pro/images/845774bd24e542297b01b232550e81cd.jpg'),
(18169, 1164, 'The Boys S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183130.mp4', 'http://timg.bdta.pro/images/aa3440fc6c50cc40a957b2857185fc7b.jpg'),
(18170, 1164, 'The Boys S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183131.mp4', 'http://timg.bdta.pro/images/f4299c168c89ce3029a082fb8af37ccf.jpg'),
(18171, 1164, 'The Boys S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183132.mp4', 'http://timg.bdta.pro/images/12cb004d4dcaf02625e1d229830924f6.jpg'),
(18172, 1164, 'The Boys S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183133.mp4', 'http://timg.bdta.pro/images/dfa5a584d1e8b7e5ae1b2d430d808205.jpg'),
(18173, 1165, 'The Boys S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/383943.mp4', 'http://gstaticontent.com/images/dzOxNbbz1liFzHU1IPvdgUR647b_big.jpg'),
(18174, 1165, 'The Boys S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/383944.mp4', 'http://gstaticontent.com/images/dzOxNbbz1liFzHU1IPvdgUR647b_big.jpg'),
(18175, 1165, 'The Boys S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/383945.mp4', 'http://gstaticontent.com/images/dzOxNbbz1liFzHU1IPvdgUR647b_big.jpg'),
(18176, 1165, 'The Boys S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/388458.mp4', 'http://gstaticontent.com/images/dzOxNbbz1liFzHU1IPvdgUR647b_big.jpg'),
(18177, 1165, 'The Boys S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/394076.mp4', 'http://gstaticontent.com/images/dzOxNbbz1liFzHU1IPvdgUR647b_big.jpg'),
(18178, 1165, 'The Boys S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/399581.mp4', 'http://gstaticontent.com/images/dzOxNbbz1liFzHU1IPvdgUR647b_big.jpg'),
(18179, 1165, 'The Boys S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/406180.mp4', 'http://gstaticontent.com/images/dzOxNbbz1liFzHU1IPvdgUR647b_big.jpg'),
(18180, 1165, 'The Boys S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/411271.mp4', 'http://gstaticontent.com/images/dzOxNbbz1liFzHU1IPvdgUR647b_big.jpg'),
(18181, 1166, 'Outra Vida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103663.mp4', 'http://gstaticontent.com/images/r4kUGt0H6A3IMbhvWfC1EA2HqR8_big.jpg'),
(18182, 1166, 'Outra Vida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103664.mp4', 'http://gstaticontent.com/images/r4kUGt0H6A3IMbhvWfC1EA2HqR8_big.jpg'),
(18183, 1166, 'Outra Vida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103665.mp4', 'http://gstaticontent.com/images/r4kUGt0H6A3IMbhvWfC1EA2HqR8_big.jpg'),
(18184, 1166, 'Outra Vida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103666.mp4', 'http://gstaticontent.com/images/r4kUGt0H6A3IMbhvWfC1EA2HqR8_big.jpg'),
(18185, 1166, 'Outra Vida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103667.mp4', 'http://gstaticontent.com/images/r4kUGt0H6A3IMbhvWfC1EA2HqR8_big.jpg'),
(18186, 1166, 'Outra Vida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103668.mp4', 'http://gstaticontent.com/images/r4kUGt0H6A3IMbhvWfC1EA2HqR8_big.jpg'),
(18187, 1166, 'Outra Vida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103669.mp4', 'http://gstaticontent.com/images/r4kUGt0H6A3IMbhvWfC1EA2HqR8_big.jpg'),
(18188, 1166, 'Outra Vida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103670.mp4', 'http://gstaticontent.com/images/r4kUGt0H6A3IMbhvWfC1EA2HqR8_big.jpg'),
(18189, 1166, 'Outra Vida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103671.mp4', 'http://gstaticontent.com/images/r4kUGt0H6A3IMbhvWfC1EA2HqR8_big.jpg'),
(18190, 1166, 'Outra Vida S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103672.mp4', 'http://gstaticontent.com/images/r4kUGt0H6A3IMbhvWfC1EA2HqR8_big.jpg'),
(18191, 1167, '8 Days S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103655.mp4', 'http://gstaticontent.com/images/bhkGEdIgot5RtJSNOEFjyYBzCOk_big.jpg'),
(18192, 1167, '8 Days S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103656.mp4', 'http://gstaticontent.com/images/bhkGEdIgot5RtJSNOEFjyYBzCOk_big.jpg'),
(18193, 1167, '8 Days S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103657.mp4', 'http://gstaticontent.com/images/bhkGEdIgot5RtJSNOEFjyYBzCOk_big.jpg'),
(18194, 1167, '8 Days S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103658.mp4', 'http://gstaticontent.com/images/bhkGEdIgot5RtJSNOEFjyYBzCOk_big.jpg'),
(18195, 1167, '8 Days S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103659.mp4', 'http://gstaticontent.com/images/bhkGEdIgot5RtJSNOEFjyYBzCOk_big.jpg'),
(18196, 1167, '8 Days S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103660.mp4', 'http://gstaticontent.com/images/bhkGEdIgot5RtJSNOEFjyYBzCOk_big.jpg'),
(18197, 1167, '8 Days S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103661.mp4', 'http://gstaticontent.com/images/bhkGEdIgot5RtJSNOEFjyYBzCOk_big.jpg'),
(18198, 1167, '8 Days S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103662.mp4', 'http://gstaticontent.com/images/bhkGEdIgot5RtJSNOEFjyYBzCOk_big.jpg'),
(18199, 1168, 'Contagem Regressiva (2018) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103649.mp4', 'http://gstaticontent.com/images/bX0VpCJqGKM8XPZaZPQYWaGHZDh_big.jpg'),
(18200, 1168, 'Contagem Regressiva (2018) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103650.mp4', 'http://gstaticontent.com/images/bX0VpCJqGKM8XPZaZPQYWaGHZDh_big.jpg'),
(18201, 1168, 'Contagem Regressiva (2018) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103651.mp4', 'http://gstaticontent.com/images/bX0VpCJqGKM8XPZaZPQYWaGHZDh_big.jpg'),
(18202, 1168, 'Contagem Regressiva (2018) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103652.mp4', 'http://gstaticontent.com/images/bX0VpCJqGKM8XPZaZPQYWaGHZDh_big.jpg'),
(18203, 1168, 'Contagem Regressiva (2018) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103653.mp4', 'http://gstaticontent.com/images/bX0VpCJqGKM8XPZaZPQYWaGHZDh_big.jpg'),
(18204, 1168, 'Contagem Regressiva (2018) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103654.mp4', 'http://gstaticontent.com/images/bX0VpCJqGKM8XPZaZPQYWaGHZDh_big.jpg'),
(18205, 1169, 'Serie Saude S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103640.mp4', 'http://gstaticontent.com/images/bX0VpCJqGKM8XPZaZPQYWaGHZDh_big.jpg'),
(18206, 1169, 'Serie Saude S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103641.mp4', 'http://gstaticontent.com/images/bX0VpCJqGKM8XPZaZPQYWaGHZDh_big.jpg'),
(18207, 1169, 'Serie Saude S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103642.mp4', 'http://gstaticontent.com/images/bX0VpCJqGKM8XPZaZPQYWaGHZDh_big.jpg'),
(18208, 1169, 'Serie Saude S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103643.mp4', 'http://gstaticontent.com/images/bX0VpCJqGKM8XPZaZPQYWaGHZDh_big.jpg'),
(18209, 1169, 'Serie Saude S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103644.mp4', 'http://gstaticontent.com/images/bX0VpCJqGKM8XPZaZPQYWaGHZDh_big.jpg'),
(18210, 1169, 'Serie Saude S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103645.mp4', 'http://gstaticontent.com/images/bX0VpCJqGKM8XPZaZPQYWaGHZDh_big.jpg'),
(18211, 1169, 'Serie Saude S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103646.mp4', 'http://gstaticontent.com/images/bX0VpCJqGKM8XPZaZPQYWaGHZDh_big.jpg'),
(18212, 1169, 'Serie Saude S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103647.mp4', 'http://gstaticontent.com/images/bX0VpCJqGKM8XPZaZPQYWaGHZDh_big.jpg'),
(18213, 1169, 'Serie Saude S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103648.mp4', 'http://gstaticontent.com/images/bX0VpCJqGKM8XPZaZPQYWaGHZDh_big.jpg'),
(18214, 1170, 'Sitiados Mexico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103632.mp4', 'http://gstaticontent.com/images/lApQI56NxQX7a3CaWJDso6W52UX_big.jpg'),
(18215, 1170, 'Sitiados Mexico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103633.mp4', 'http://gstaticontent.com/images/lApQI56NxQX7a3CaWJDso6W52UX_big.jpg'),
(18216, 1170, 'Sitiados Mexico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103634.mp4', 'http://gstaticontent.com/images/lApQI56NxQX7a3CaWJDso6W52UX_big.jpg'),
(18217, 1170, 'Sitiados Mexico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103635.mp4', 'http://gstaticontent.com/images/lApQI56NxQX7a3CaWJDso6W52UX_big.jpg'),
(18218, 1170, 'Sitiados Mexico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103636.mp4', 'http://gstaticontent.com/images/lApQI56NxQX7a3CaWJDso6W52UX_big.jpg'),
(18219, 1170, 'Sitiados Mexico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103637.mp4', 'http://gstaticontent.com/images/lApQI56NxQX7a3CaWJDso6W52UX_big.jpg'),
(18220, 1170, 'Sitiados Mexico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103638.mp4', 'http://gstaticontent.com/images/lApQI56NxQX7a3CaWJDso6W52UX_big.jpg'),
(18221, 1170, 'Sitiados Mexico S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103639.mp4', 'http://gstaticontent.com/images/lApQI56NxQX7a3CaWJDso6W52UX_big.jpg'),
(18222, 1171, 'A Descoberta das Bruxas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180264.mp4', 'http://gstaticontent.com/images/vCPIAUuxcPBgBBBdDz7rzfLelMD_big.jpg'),
(18223, 1171, 'A Descoberta das Bruxas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180265.mp4', 'http://gstaticontent.com/images/vCPIAUuxcPBgBBBdDz7rzfLelMD_big.jpg'),
(18224, 1171, 'A Descoberta das Bruxas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180266.mp4', 'http://gstaticontent.com/images/vCPIAUuxcPBgBBBdDz7rzfLelMD_big.jpg'),
(18225, 1171, 'A Descoberta das Bruxas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180267.mp4', 'http://gstaticontent.com/images/vCPIAUuxcPBgBBBdDz7rzfLelMD_big.jpg'),
(18226, 1171, 'A Descoberta das Bruxas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180268.mp4', 'http://gstaticontent.com/images/vCPIAUuxcPBgBBBdDz7rzfLelMD_big.jpg'),
(18227, 1171, 'A Descoberta das Bruxas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180269.mp4', 'http://gstaticontent.com/images/vCPIAUuxcPBgBBBdDz7rzfLelMD_big.jpg'),
(18228, 1171, 'A Descoberta das Bruxas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180270.mp4', 'http://gstaticontent.com/images/vCPIAUuxcPBgBBBdDz7rzfLelMD_big.jpg'),
(18229, 1171, 'A Descoberta das Bruxas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180271.mp4', 'http://gstaticontent.com/images/vCPIAUuxcPBgBBBdDz7rzfLelMD_big.jpg'),
(18230, 1172, 'A Descoberta das Bruxas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180272.mp4', 'http://gstaticontent.com/images/vCPIAUuxcPBgBBBdDz7rzfLelMD_big.jpg'),
(18231, 1172, 'A Descoberta das Bruxas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180273.mp4', 'http://gstaticontent.com/images/vCPIAUuxcPBgBBBdDz7rzfLelMD_big.jpg'),
(18232, 1172, 'A Descoberta das Bruxas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180274.mp4', 'http://gstaticontent.com/images/vCPIAUuxcPBgBBBdDz7rzfLelMD_big.jpg'),
(18233, 1172, 'A Descoberta das Bruxas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180275.mp4', 'http://gstaticontent.com/images/vCPIAUuxcPBgBBBdDz7rzfLelMD_big.jpg'),
(18234, 1172, 'A Descoberta das Bruxas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180276.mp4', 'http://gstaticontent.com/images/vCPIAUuxcPBgBBBdDz7rzfLelMD_big.jpg'),
(18235, 1172, 'A Descoberta das Bruxas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180277.mp4', 'http://gstaticontent.com/images/vCPIAUuxcPBgBBBdDz7rzfLelMD_big.jpg'),
(18236, 1172, 'A Descoberta das Bruxas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180278.mp4', 'http://gstaticontent.com/images/vCPIAUuxcPBgBBBdDz7rzfLelMD_big.jpg'),
(18237, 1172, 'A Descoberta das Bruxas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180279.mp4', 'http://gstaticontent.com/images/vCPIAUuxcPBgBBBdDz7rzfLelMD_big.jpg'),
(18238, 1172, 'A Descoberta das Bruxas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180280.mp4', 'http://gstaticontent.com/images/vCPIAUuxcPBgBBBdDz7rzfLelMD_big.jpg'),
(18239, 1172, 'A Descoberta das Bruxas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180281.mp4', 'http://gstaticontent.com/images/vCPIAUuxcPBgBBBdDz7rzfLelMD_big.jpg'),
(18240, 1173, 'A Descoberta das Bruxas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180282.mp4', 'http://timg.bdta.pro/images/d2bf9827258d3b2d6e498314d6ea9c30.jpg'),
(18241, 1173, 'A Descoberta das Bruxas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180283.mp4', 'http://timg.bdta.pro/images/bf50a9943537cfa73293b6aa1cd2c25c.jpg'),
(18242, 1173, 'A Descoberta das Bruxas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180284.mp4', 'http://timg.bdta.pro/images/7665a22aaff3d4acc0a1a1990c0760ae.jpg'),
(18243, 1173, 'A Descoberta das Bruxas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180285.mp4', 'http://timg.bdta.pro/images/c1edcb9585f6d90be3ccf67f4c1d1b57.jpg'),
(18244, 1173, 'A Descoberta das Bruxas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180286.mp4', 'http://timg.bdta.pro/images/c41b7dbbc599498fcc325fc895bdd522.jpg'),
(18245, 1173, 'A Descoberta das Bruxas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180287.mp4', 'http://timg.bdta.pro/images/2fb4900dd87c61b1dc873836f96934ee.jpg'),
(18246, 1173, 'A Descoberta das Bruxas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180288.mp4', 'http://timg.bdta.pro/images/4073332348a5f81abda34e5d8ed617d5.jpg'),
(18247, 1174, 'Divorce S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/115026.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18248, 1174, 'Divorce S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/115027.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18249, 1174, 'Divorce S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/115028.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18250, 1174, 'Divorce S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/115029.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18251, 1174, 'Divorce S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/115030.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18252, 1174, 'Divorce S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/115031.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18253, 1174, 'Divorce S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/115032.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18254, 1174, 'Divorce S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/115033.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18255, 1174, 'Divorce S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/115034.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18256, 1174, 'Divorce S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/115035.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18257, 1175, 'Divorce S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/115036.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18258, 1175, 'Divorce S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/115037.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18259, 1175, 'Divorce S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/115038.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18260, 1175, 'Divorce S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/115039.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18261, 1175, 'Divorce S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/115040.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18262, 1175, 'Divorce S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/115041.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(18263, 1175, 'Divorce S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/115042.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18264, 1175, 'Divorce S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/115043.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18265, 1176, 'Divorce S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/115044.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18266, 1176, 'Divorce S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/115045.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18267, 1176, 'Divorce S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/115046.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18268, 1176, 'Divorce S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/115047.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18269, 1176, 'Divorce S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/115048.mp4', 'http://gstaticontent.com/images/7mq174fSHoNPK3CI725564hRKR7_big.jpg'),
(18270, 1176, 'Divorce S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/115049.mp4', 'http://timg.bdta.pro/images/8a8597283babe34075869d79121f696b.jpg'),
(18271, 1177, 'I Am the Night S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103616.mp4', 'http://gstaticontent.com/images/sPRGQlCcyNIIoH1HSVEkhJKME75_big.jpg'),
(18272, 1177, 'I Am the Night S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103617.mp4', 'http://gstaticontent.com/images/sPRGQlCcyNIIoH1HSVEkhJKME75_big.jpg'),
(18273, 1177, 'I Am the Night S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103618.mp4', 'http://gstaticontent.com/images/sPRGQlCcyNIIoH1HSVEkhJKME75_big.jpg'),
(18274, 1177, 'I Am the Night S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103619.mp4', 'http://gstaticontent.com/images/sPRGQlCcyNIIoH1HSVEkhJKME75_big.jpg'),
(18275, 1177, 'I Am the Night S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103620.mp4', 'http://gstaticontent.com/images/sPRGQlCcyNIIoH1HSVEkhJKME75_big.jpg'),
(18276, 1177, 'I Am the Night S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103621.mp4', 'http://gstaticontent.com/images/sPRGQlCcyNIIoH1HSVEkhJKME75_big.jpg'),
(18277, 1178, 'Sex Education S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235536.mp4', 'http://gstaticontent.com/images/cK6JhcZFpwVW9tldz3llodY2TeY_big.jpg'),
(18278, 1178, 'Sex Education S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235537.mp4', 'http://gstaticontent.com/images/cK6JhcZFpwVW9tldz3llodY2TeY_big.jpg'),
(18279, 1178, 'Sex Education S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235538.mp4', 'http://gstaticontent.com/images/cK6JhcZFpwVW9tldz3llodY2TeY_big.jpg'),
(18280, 1178, 'Sex Education S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235539.mp4', 'http://gstaticontent.com/images/cK6JhcZFpwVW9tldz3llodY2TeY_big.jpg'),
(18281, 1178, 'Sex Education S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235540.mp4', 'http://gstaticontent.com/images/cK6JhcZFpwVW9tldz3llodY2TeY_big.jpg'),
(18282, 1178, 'Sex Education S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235541.mp4', 'http://gstaticontent.com/images/cK6JhcZFpwVW9tldz3llodY2TeY_big.jpg'),
(18283, 1178, 'Sex Education S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235542.mp4', 'http://gstaticontent.com/images/cK6JhcZFpwVW9tldz3llodY2TeY_big.jpg'),
(18284, 1178, 'Sex Education S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235543.mp4', 'http://gstaticontent.com/images/cK6JhcZFpwVW9tldz3llodY2TeY_big.jpg'),
(18285, 1179, 'Sex Education S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235544.mp4', 'http://timg.bdta.pro/images/c9aa03e702802a20ad29f0b599dae7a3.jpg'),
(18286, 1179, 'Sex Education S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235545.mp4', 'http://timg.bdta.pro/images/bb34a8beed39c3b577716930e9ccccc1.jpg'),
(18287, 1179, 'Sex Education S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235546.mp4', 'http://timg.bdta.pro/images/2fa5776b4d357588003baed09ae75de5.jpg'),
(18288, 1179, 'Sex Education S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235547.mp4', 'http://timg.bdta.pro/images/5dbe4d32e93149a058706144ce0bf4aa.jpg'),
(18289, 1179, 'Sex Education S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235548.mp4', 'http://timg.bdta.pro/images/9e43f29d123124b892c1964ce69e3643.jpg'),
(18290, 1179, 'Sex Education S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235549.mp4', 'http://timg.bdta.pro/images/143a2f2e6b74b20cb160c97f4c77849a.jpg'),
(18291, 1179, 'Sex Education S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235550.mp4', 'http://timg.bdta.pro/images/66998ce3b80244e7e1f095db2edaddf6.jpg'),
(18292, 1179, 'Sex Education S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235551.mp4', 'http://timg.bdta.pro/images/9d73dcc942dc56eddbe185839269e2ae.jpg'),
(18293, 1180, 'Sex Education S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235552.mp4', 'http://timg.bdta.pro/images/bb54f34c68d2c9438c7ec365a88687d9.jpg'),
(18294, 1180, 'Sex Education S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235553.mp4', 'http://timg.bdta.pro/images/7ca50b49078d587b546abf75efaaec64.jpg'),
(18295, 1180, 'Sex Education S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235554.mp4', 'http://timg.bdta.pro/images/606e19079e468863940c9465134ca9e1.jpg'),
(18296, 1180, 'Sex Education S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235555.mp4', 'http://timg.bdta.pro/images/57ef78d53ab9c30ce16a8ba7413b07cd.jpg'),
(18297, 1180, 'Sex Education S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235556.mp4', 'http://timg.bdta.pro/images/6bc3e0c3e61abcaaf58ba025f48be7cc.jpg'),
(18298, 1180, 'Sex Education S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235557.mp4', 'http://timg.bdta.pro/images/b42751551fb5fb172ab2d48487879ebb.jpg'),
(18299, 1180, 'Sex Education S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235558.mp4', 'http://timg.bdta.pro/images/d579bb1721709615212b3c57bc889724.jpg'),
(18300, 1180, 'Sex Education S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235559.mp4', 'http://timg.bdta.pro/images/8cca95cfc4216aebef7c9e1823bb00d9.jpg'),
(18301, 1181, 'Sex Education S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235560.mp4', 'http://gstaticontent.com/images/cK6JhcZFpwVW9tldz3llodY2TeY_big.jpg'),
(18302, 1181, 'Sex Education S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235561.mp4', 'http://gstaticontent.com/images/cK6JhcZFpwVW9tldz3llodY2TeY_big.jpg'),
(18303, 1181, 'Sex Education S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235562.mp4', 'http://gstaticontent.com/images/cK6JhcZFpwVW9tldz3llodY2TeY_big.jpg'),
(18304, 1181, 'Sex Education S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235563.mp4', 'http://gstaticontent.com/images/cK6JhcZFpwVW9tldz3llodY2TeY_big.jpg'),
(18305, 1181, 'Sex Education S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235564.mp4', 'http://gstaticontent.com/images/cK6JhcZFpwVW9tldz3llodY2TeY_big.jpg'),
(18306, 1181, 'Sex Education S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235565.mp4', 'http://gstaticontent.com/images/cK6JhcZFpwVW9tldz3llodY2TeY_big.jpg'),
(18307, 1181, 'Sex Education S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235566.mp4', 'http://gstaticontent.com/images/cK6JhcZFpwVW9tldz3llodY2TeY_big.jpg'),
(18308, 1181, 'Sex Education S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235567.mp4', 'http://gstaticontent.com/images/cK6JhcZFpwVW9tldz3llodY2TeY_big.jpg'),
(18309, 1182, 'Pico Da Neblina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234235.mp4', 'http://gstaticontent.com/images/3874QH77fQtGnffNPzWZjzoO7Z6_big.jpg'),
(18310, 1182, 'Pico Da Neblina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234236.mp4', 'http://gstaticontent.com/images/3874QH77fQtGnffNPzWZjzoO7Z6_big.jpg'),
(18311, 1182, 'Pico Da Neblina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234237.mp4', 'http://gstaticontent.com/images/3874QH77fQtGnffNPzWZjzoO7Z6_big.jpg'),
(18312, 1182, 'Pico Da Neblina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234238.mp4', 'http://gstaticontent.com/images/3874QH77fQtGnffNPzWZjzoO7Z6_big.jpg'),
(18313, 1182, 'Pico Da Neblina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234239.mp4', 'http://gstaticontent.com/images/3874QH77fQtGnffNPzWZjzoO7Z6_big.jpg'),
(18314, 1182, 'Pico Da Neblina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234240.mp4', 'http://gstaticontent.com/images/3874QH77fQtGnffNPzWZjzoO7Z6_big.jpg'),
(18315, 1182, 'Pico Da Neblina S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234241.mp4', 'http://gstaticontent.com/images/3874QH77fQtGnffNPzWZjzoO7Z6_big.jpg'),
(18316, 1182, 'Pico Da Neblina S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234242.mp4', 'http://gstaticontent.com/images/3874QH77fQtGnffNPzWZjzoO7Z6_big.jpg'),
(18317, 1182, 'Pico Da Neblina S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234243.mp4', 'http://gstaticontent.com/images/3874QH77fQtGnffNPzWZjzoO7Z6_big.jpg'),
(18318, 1182, 'Pico Da Neblina S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234244.mp4', 'http://gstaticontent.com/images/3874QH77fQtGnffNPzWZjzoO7Z6_big.jpg'),
(18319, 1183, 'Pico Da Neblina S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234245.mp4', 'http://timg.bdta.pro/images/bd13c2a5e87a1a629af325b76c8145cf.jpg'),
(18320, 1183, 'Pico Da Neblina S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234246.mp4', 'http://timg.bdta.pro/images/bf84abad6e2b12f0417eee06898a0faa.jpg'),
(18321, 1183, 'Pico Da Neblina S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234247.mp4', 'http://timg.bdta.pro/images/62b3c205ab3dbc634623bf9b89c3ca8e.jpg'),
(18322, 1183, 'Pico Da Neblina S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gG9LEG87oEOOcjMYkQziq466haE.jpg'),
(18323, 1183, 'Pico Da Neblina S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUSsx5Cga40xaq4gyAQGWZf9spE.jpg'),
(18324, 1183, 'Pico Da Neblina S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzvgLWspHRV2VmPLL7k6xqmyykM.jpg'),
(18325, 1183, 'Pico Da Neblina S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ZGVuv7FvhTKeHch5DlvPSyAJXy.jpg'),
(18326, 1183, 'Pico Da Neblina S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pLDgtmF6MZzVb68jsmTWXkXQaum.jpg'),
(18327, 1183, 'Pico Da Neblina S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p1EDXbF5FYLst5n0i9WuYvuBUiC.jpg'),
(18328, 1183, 'Pico Da Neblina S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3tB8zezVM1lZLebTFeZoIIVCSmz.jpg'),
(18329, 1184, 'Apollo Reconstruindo A Jornada Espacial S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103614.mp4', 'http://gstaticontent.com/images/xh6UPa6lVTmTA6d3mDyP4cw7qh_big.jpg'),
(18330, 1184, 'Apollo Reconstruindo A Jornada Espacial S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103615.mp4', 'http://gstaticontent.com/images/xh6UPa6lVTmTA6d3mDyP4cw7qh_big.jpg'),
(18331, 1185, 'Tempos de Crise S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103608.mp4', 'http://gstaticontent.com/images/8Njgd4vFSjJpKpT3sqNrY6NDspl_big.jpg'),
(18332, 1185, 'Tempos de Crise S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103609.mp4', 'http://gstaticontent.com/images/8Njgd4vFSjJpKpT3sqNrY6NDspl_big.jpg'),
(18333, 1185, 'Tempos de Crise S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103610.mp4', 'http://gstaticontent.com/images/8Njgd4vFSjJpKpT3sqNrY6NDspl_big.jpg'),
(18334, 1185, 'Tempos de Crise S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103611.mp4', 'http://gstaticontent.com/images/8Njgd4vFSjJpKpT3sqNrY6NDspl_big.jpg'),
(18335, 1185, 'Tempos de Crise S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103612.mp4', 'http://gstaticontent.com/images/8Njgd4vFSjJpKpT3sqNrY6NDspl_big.jpg'),
(18336, 1185, 'Tempos de Crise S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103613.mp4', 'http://gstaticontent.com/images/8Njgd4vFSjJpKpT3sqNrY6NDspl_big.jpg'),
(18337, 1186, 'This Is Football [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103602.mp4', 'http://gstaticontent.com/images/1ZMdAee5nXzUA7pyoYgJajG8Uus_big.jpg'),
(18338, 1186, 'This Is Football [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103603.mp4', 'http://gstaticontent.com/images/1ZMdAee5nXzUA7pyoYgJajG8Uus_big.jpg'),
(18339, 1186, 'This Is Football [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103604.mp4', 'http://gstaticontent.com/images/1ZMdAee5nXzUA7pyoYgJajG8Uus_big.jpg'),
(18340, 1186, 'This Is Football [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103605.mp4', 'http://gstaticontent.com/images/1ZMdAee5nXzUA7pyoYgJajG8Uus_big.jpg'),
(18341, 1186, 'This Is Football [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103606.mp4', 'http://gstaticontent.com/images/1ZMdAee5nXzUA7pyoYgJajG8Uus_big.jpg'),
(18342, 1186, 'This Is Football [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103607.mp4', 'http://gstaticontent.com/images/1ZMdAee5nXzUA7pyoYgJajG8Uus_big.jpg'),
(18343, 1187, 'iCarly S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140451.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18344, 1187, 'iCarly S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140452.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18345, 1187, 'iCarly S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140453.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18346, 1187, 'iCarly S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140454.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18347, 1187, 'iCarly S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140455.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18348, 1187, 'iCarly S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140456.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18349, 1187, 'iCarly S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140457.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18350, 1187, 'iCarly S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140458.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18351, 1187, 'iCarly S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140459.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18352, 1187, 'iCarly S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140460.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18353, 1187, 'iCarly S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140461.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18354, 1187, 'iCarly S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140462.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18355, 1187, 'iCarly S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140463.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18356, 1187, 'iCarly S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/140464.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18357, 1187, 'iCarly S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/140465.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18358, 1187, 'iCarly S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/140466.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18359, 1187, 'iCarly S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/140467.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18360, 1187, 'iCarly S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/140468.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18361, 1187, 'iCarly S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/140469.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18362, 1187, 'iCarly S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/140470.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18363, 1187, 'iCarly S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/140471.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18364, 1187, 'iCarly S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/140472.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18365, 1187, 'iCarly S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/140473.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18366, 1187, 'iCarly S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/140474.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18367, 1187, 'iCarly S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/140475.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18368, 1188, 'iCarly S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140476.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18369, 1188, 'iCarly S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140477.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18370, 1188, 'iCarly S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140478.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18371, 1188, 'iCarly S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140479.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18372, 1188, 'iCarly S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140480.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18373, 1188, 'iCarly S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140481.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18374, 1188, 'iCarly S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140482.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18375, 1188, 'iCarly S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140483.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18376, 1188, 'iCarly S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140484.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18377, 1188, 'iCarly S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140485.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18378, 1188, 'iCarly S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140486.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18379, 1188, 'iCarly S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140487.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18380, 1188, 'iCarly S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140488.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18381, 1188, 'iCarly S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/140489.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18382, 1188, 'iCarly S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/140490.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18383, 1188, 'iCarly S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/140491.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18384, 1188, 'iCarly S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/140492.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18385, 1188, 'iCarly S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/140493.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18386, 1188, 'iCarly S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/140494.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18387, 1188, 'iCarly S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/140495.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18388, 1188, 'iCarly S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/140496.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18389, 1189, 'iCarly S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140497.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18390, 1189, 'iCarly S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140498.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18391, 1189, 'iCarly S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140499.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18392, 1189, 'iCarly S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140500.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18393, 1189, 'iCarly S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140501.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18394, 1189, 'iCarly S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140502.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18395, 1189, 'iCarly S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140503.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18396, 1189, 'iCarly S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140504.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18397, 1189, 'iCarly S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140505.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18398, 1189, 'iCarly S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140506.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18399, 1189, 'iCarly S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140507.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18400, 1189, 'iCarly S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140508.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18401, 1189, 'iCarly S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140509.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18402, 1189, 'iCarly S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/140510.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18403, 1189, 'iCarly S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/140511.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18404, 1189, 'iCarly S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/140512.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18405, 1189, 'iCarly S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/140513.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18406, 1189, 'iCarly S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/140514.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18407, 1190, 'iCarly S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140515.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18408, 1190, 'iCarly S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140516.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18409, 1190, 'iCarly S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140517.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18410, 1190, 'iCarly S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140518.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18411, 1190, 'iCarly S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140519.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18412, 1190, 'iCarly S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140520.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18413, 1190, 'iCarly S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140521.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18414, 1190, 'iCarly S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140522.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18415, 1190, 'iCarly S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140523.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18416, 1190, 'iCarly S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140524.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18417, 1191, 'iCarly S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140525.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18418, 1191, 'iCarly S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140526.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18419, 1191, 'iCarly S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140527.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18420, 1191, 'iCarly S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140528.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18421, 1191, 'iCarly S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140529.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18422, 1191, 'iCarly S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140530.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18423, 1191, 'iCarly S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140531.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18424, 1191, 'iCarly S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140532.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18425, 1191, 'iCarly S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140533.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18426, 1191, 'iCarly S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140534.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18427, 1192, 'iCarly S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140535.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18428, 1192, 'iCarly S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140536.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18429, 1192, 'iCarly S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140537.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18430, 1192, 'iCarly S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140538.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18431, 1192, 'iCarly S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140539.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18432, 1192, 'iCarly S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140540.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18433, 1192, 'iCarly S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140541.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18434, 1192, 'iCarly S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140542.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18435, 1192, 'iCarly S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140543.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18436, 1192, 'iCarly S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140544.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18437, 1192, 'iCarly S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140545.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18438, 1192, 'iCarly S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140546.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18439, 1192, 'iCarly S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140547.mp4', 'http://gstaticontent.com/images/hLk6ey8dpcFIsxQwmTX5qMvRdxh_big.jpg'),
(18440, 1193, 'Ben 10 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226285.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18441, 1193, 'Ben 10 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226286.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18442, 1193, 'Ben 10 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226287.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18443, 1193, 'Ben 10 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226288.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18444, 1193, 'Ben 10 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226289.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18445, 1193, 'Ben 10 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226290.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18446, 1193, 'Ben 10 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226291.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18447, 1193, 'Ben 10 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226292.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18448, 1193, 'Ben 10 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226293.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18449, 1193, 'Ben 10 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226294.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18450, 1193, 'Ben 10 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226295.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18451, 1193, 'Ben 10 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226296.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18452, 1193, 'Ben 10 S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226297.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18453, 1194, 'Ben 10 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226298.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18454, 1194, 'Ben 10 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226299.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18455, 1194, 'Ben 10 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226300.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18456, 1194, 'Ben 10 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226301.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18457, 1194, 'Ben 10 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226302.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18458, 1194, 'Ben 10 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226303.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18459, 1194, 'Ben 10 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226304.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18460, 1194, 'Ben 10 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226305.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18461, 1194, 'Ben 10 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226306.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18462, 1194, 'Ben 10 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226307.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18463, 1194, 'Ben 10 S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226308.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18464, 1194, 'Ben 10 S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226309.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18465, 1194, 'Ben 10 S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226310.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18466, 1195, 'Ben 10 S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226311.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18467, 1195, 'Ben 10 S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226312.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18468, 1195, 'Ben 10 S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226313.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18469, 1195, 'Ben 10 S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226314.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18470, 1195, 'Ben 10 S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226315.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18471, 1195, 'Ben 10 S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226316.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18472, 1195, 'Ben 10 S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226317.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18473, 1195, 'Ben 10 S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226318.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18474, 1195, 'Ben 10 S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226319.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18475, 1195, 'Ben 10 S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226320.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18476, 1195, 'Ben 10 S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226321.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18477, 1195, 'Ben 10 S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226322.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18478, 1195, 'Ben 10 S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226323.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18479, 1196, 'Ben 10 S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226324.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18480, 1196, 'Ben 10 S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226325.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18481, 1196, 'Ben 10 S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226326.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18482, 1196, 'Ben 10 S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226327.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18483, 1196, 'Ben 10 S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226328.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18484, 1196, 'Ben 10 S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226329.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18485, 1196, 'Ben 10 S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226330.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18486, 1196, 'Ben 10 S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226331.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18487, 1196, 'Ben 10 S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226332.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18488, 1196, 'Ben 10 S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226333.mp4', 'http://gstaticontent.com/images/lU1ollblNqLSAof7fzvfiHSqb9C_big.jpg'),
(18489, 1196, 'Ben 10 S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uUjZ2imHeRzWcqVicjS8Sj6Ahwf.jpg'),
(18490, 1196, 'Ben 10 S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kGzCYFjYse8eXXQyvT3M6EtPBRg.jpg'),
(18491, 1196, 'Ben 10 S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x7OFNefxbVIskgcsuVC1tGZr7CR.jpg'),
(18492, 1197, 'Pesca Implacavel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103415.mp4', 'http://gstaticontent.com/images/f05CT7h9xoGTRC5ixFT3KmmB0Sp_big.jpg'),
(18493, 1197, 'Pesca Implacavel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103416.mp4', 'http://gstaticontent.com/images/f05CT7h9xoGTRC5ixFT3KmmB0Sp_big.jpg'),
(18494, 1197, 'Pesca Implacavel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103417.mp4', 'http://gstaticontent.com/images/f05CT7h9xoGTRC5ixFT3KmmB0Sp_big.jpg'),
(18495, 1197, 'Pesca Implacavel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103418.mp4', 'http://gstaticontent.com/images/f05CT7h9xoGTRC5ixFT3KmmB0Sp_big.jpg'),
(18496, 1197, 'Pesca Implacavel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103419.mp4', 'http://gstaticontent.com/images/f05CT7h9xoGTRC5ixFT3KmmB0Sp_big.jpg'),
(18497, 1197, 'Pesca Implacavel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103420.mp4', 'http://gstaticontent.com/images/f05CT7h9xoGTRC5ixFT3KmmB0Sp_big.jpg'),
(18498, 1197, 'Pesca Implacavel S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103421.mp4', 'http://gstaticontent.com/images/f05CT7h9xoGTRC5ixFT3KmmB0Sp_big.jpg'),
(18499, 1197, 'Pesca Implacavel S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103422.mp4', 'http://gstaticontent.com/images/f05CT7h9xoGTRC5ixFT3KmmB0Sp_big.jpg'),
(18500, 1198, 'Jose do Egito S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103347.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18501, 1198, 'Jose do Egito S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103348.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18502, 1198, 'Jose do Egito S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103349.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18503, 1198, 'Jose do Egito S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103350.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18504, 1198, 'Jose do Egito S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103351.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18505, 1198, 'Jose do Egito S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103352.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18506, 1198, 'Jose do Egito S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103353.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18507, 1198, 'Jose do Egito S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103354.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18508, 1198, 'Jose do Egito S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103355.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18509, 1198, 'Jose do Egito S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103356.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18510, 1198, 'Jose do Egito S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103357.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18511, 1198, 'Jose do Egito S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103358.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18512, 1198, 'Jose do Egito S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/103359.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18513, 1198, 'Jose do Egito S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/103360.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18514, 1198, 'Jose do Egito S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/103361.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18515, 1198, 'Jose do Egito S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/103362.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18516, 1198, 'Jose do Egito S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/103363.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18517, 1198, 'Jose do Egito S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/103364.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18518, 1198, 'Jose do Egito S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/103365.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18519, 1198, 'Jose do Egito S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/103366.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18520, 1198, 'Jose do Egito S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/103367.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18521, 1198, 'Jose do Egito S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/103368.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18522, 1198, 'Jose do Egito S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/103369.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18523, 1198, 'Jose do Egito S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/103370.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18524, 1198, 'Jose do Egito S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/103371.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18525, 1198, 'Jose do Egito S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/103372.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18526, 1198, 'Jose do Egito S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/103373.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18527, 1198, 'Jose do Egito S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/103374.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18528, 1198, 'Jose do Egito S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/103375.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18529, 1198, 'Jose do Egito S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/103376.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18530, 1198, 'Jose do Egito S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/103377.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18531, 1198, 'Jose do Egito S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/103378.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18532, 1198, 'Jose do Egito S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/103379.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18533, 1198, 'Jose do Egito S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/103380.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18534, 1198, 'Jose do Egito S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/103381.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18535, 1198, 'Jose do Egito S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/103382.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18536, 1198, 'Jose do Egito S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/103383.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18537, 1198, 'Jose do Egito S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/103384.mp4', 'http://gstaticontent.com/images/uFmIHBsj9YPIp0jhn0dc2g0KAqV_big.jpg'),
(18538, 1199, 'Wu Assassins S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103405.mp4', 'http://gstaticontent.com/images/nhWgmdLveoJNw1GZBkb62aIzyNr_big.jpg'),
(18539, 1199, 'Wu Assassins S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103406.mp4', 'http://gstaticontent.com/images/nhWgmdLveoJNw1GZBkb62aIzyNr_big.jpg'),
(18540, 1199, 'Wu Assassins S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103407.mp4', 'http://gstaticontent.com/images/nhWgmdLveoJNw1GZBkb62aIzyNr_big.jpg'),
(18541, 1199, 'Wu Assassins S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103408.mp4', 'http://gstaticontent.com/images/nhWgmdLveoJNw1GZBkb62aIzyNr_big.jpg'),
(18542, 1199, 'Wu Assassins S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103409.mp4', 'http://gstaticontent.com/images/nhWgmdLveoJNw1GZBkb62aIzyNr_big.jpg'),
(18543, 1199, 'Wu Assassins S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103410.mp4', 'http://gstaticontent.com/images/nhWgmdLveoJNw1GZBkb62aIzyNr_big.jpg'),
(18544, 1199, 'Wu Assassins S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103411.mp4', 'http://gstaticontent.com/images/nhWgmdLveoJNw1GZBkb62aIzyNr_big.jpg'),
(18545, 1199, 'Wu Assassins S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103412.mp4', 'http://gstaticontent.com/images/nhWgmdLveoJNw1GZBkb62aIzyNr_big.jpg'),
(18546, 1199, 'Wu Assassins S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103413.mp4', 'http://gstaticontent.com/images/nhWgmdLveoJNw1GZBkb62aIzyNr_big.jpg'),
(18547, 1199, 'Wu Assassins S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103414.mp4', 'http://gstaticontent.com/images/nhWgmdLveoJNw1GZBkb62aIzyNr_big.jpg'),
(18548, 1200, 'Cozinhando em 4:20 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103393.mp4', 'http://gstaticontent.com/images/cgIKvjs3oEh402wrwjjwUUZoawn_big.jpg'),
(18549, 1200, 'Cozinhando em 4:20 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103394.mp4', 'http://gstaticontent.com/images/cgIKvjs3oEh402wrwjjwUUZoawn_big.jpg'),
(18550, 1200, 'Cozinhando em 4:20 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103395.mp4', 'http://gstaticontent.com/images/cgIKvjs3oEh402wrwjjwUUZoawn_big.jpg'),
(18551, 1200, 'Cozinhando em 4:20 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103396.mp4', 'http://gstaticontent.com/images/cgIKvjs3oEh402wrwjjwUUZoawn_big.jpg'),
(18552, 1200, 'Cozinhando em 4:20 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103397.mp4', 'http://gstaticontent.com/images/cgIKvjs3oEh402wrwjjwUUZoawn_big.jpg'),
(18553, 1200, 'Cozinhando em 4:20 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103398.mp4', 'http://gstaticontent.com/images/cgIKvjs3oEh402wrwjjwUUZoawn_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(18554, 1200, 'Cozinhando em 4:20 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103399.mp4', 'http://gstaticontent.com/images/cgIKvjs3oEh402wrwjjwUUZoawn_big.jpg'),
(18555, 1200, 'Cozinhando em 4:20 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103400.mp4', 'http://gstaticontent.com/images/cgIKvjs3oEh402wrwjjwUUZoawn_big.jpg'),
(18556, 1200, 'Cozinhando em 4:20 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103401.mp4', 'http://gstaticontent.com/images/cgIKvjs3oEh402wrwjjwUUZoawn_big.jpg'),
(18557, 1200, 'Cozinhando em 4:20 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103402.mp4', 'http://gstaticontent.com/images/cgIKvjs3oEh402wrwjjwUUZoawn_big.jpg'),
(18558, 1200, 'Cozinhando em 4:20 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103403.mp4', 'http://gstaticontent.com/images/cgIKvjs3oEh402wrwjjwUUZoawn_big.jpg'),
(18559, 1200, 'Cozinhando em 4:20 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103404.mp4', 'http://gstaticontent.com/images/cgIKvjs3oEh402wrwjjwUUZoawn_big.jpg'),
(18560, 1201, 'O Diretor Nu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103385.mp4', 'http://gstaticontent.com/images/tTFixV61n0SErumUFHUZcwh1KK8_big.jpg'),
(18561, 1201, 'O Diretor Nu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103386.mp4', 'http://gstaticontent.com/images/tTFixV61n0SErumUFHUZcwh1KK8_big.jpg'),
(18562, 1201, 'O Diretor Nu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103387.mp4', 'http://gstaticontent.com/images/tTFixV61n0SErumUFHUZcwh1KK8_big.jpg'),
(18563, 1201, 'O Diretor Nu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103388.mp4', 'http://gstaticontent.com/images/tTFixV61n0SErumUFHUZcwh1KK8_big.jpg'),
(18564, 1201, 'O Diretor Nu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103389.mp4', 'http://gstaticontent.com/images/tTFixV61n0SErumUFHUZcwh1KK8_big.jpg'),
(18565, 1201, 'O Diretor Nu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103390.mp4', 'http://gstaticontent.com/images/tTFixV61n0SErumUFHUZcwh1KK8_big.jpg'),
(18566, 1201, 'O Diretor Nu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103391.mp4', 'http://gstaticontent.com/images/tTFixV61n0SErumUFHUZcwh1KK8_big.jpg'),
(18567, 1201, 'O Diretor Nu S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103392.mp4', 'http://gstaticontent.com/images/tTFixV61n0SErumUFHUZcwh1KK8_big.jpg'),
(18568, 1202, 'Dollar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103332.mp4', 'http://gstaticontent.com/images/d8nuQGs0RxoWUHYvQJl91xYm4Az_big.jpg'),
(18569, 1202, 'Dollar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103333.mp4', 'http://gstaticontent.com/images/d8nuQGs0RxoWUHYvQJl91xYm4Az_big.jpg'),
(18570, 1202, 'Dollar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103334.mp4', 'http://gstaticontent.com/images/d8nuQGs0RxoWUHYvQJl91xYm4Az_big.jpg'),
(18571, 1202, 'Dollar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103335.mp4', 'http://gstaticontent.com/images/d8nuQGs0RxoWUHYvQJl91xYm4Az_big.jpg'),
(18572, 1202, 'Dollar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103336.mp4', 'http://gstaticontent.com/images/d8nuQGs0RxoWUHYvQJl91xYm4Az_big.jpg'),
(18573, 1202, 'Dollar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103337.mp4', 'http://gstaticontent.com/images/d8nuQGs0RxoWUHYvQJl91xYm4Az_big.jpg'),
(18574, 1202, 'Dollar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103338.mp4', 'http://gstaticontent.com/images/d8nuQGs0RxoWUHYvQJl91xYm4Az_big.jpg'),
(18575, 1202, 'Dollar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103339.mp4', 'http://gstaticontent.com/images/d8nuQGs0RxoWUHYvQJl91xYm4Az_big.jpg'),
(18576, 1202, 'Dollar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103340.mp4', 'http://gstaticontent.com/images/d8nuQGs0RxoWUHYvQJl91xYm4Az_big.jpg'),
(18577, 1202, 'Dollar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103341.mp4', 'http://gstaticontent.com/images/d8nuQGs0RxoWUHYvQJl91xYm4Az_big.jpg'),
(18578, 1202, 'Dollar S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103342.mp4', 'http://gstaticontent.com/images/d8nuQGs0RxoWUHYvQJl91xYm4Az_big.jpg'),
(18579, 1202, 'Dollar S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103343.mp4', 'http://gstaticontent.com/images/d8nuQGs0RxoWUHYvQJl91xYm4Az_big.jpg'),
(18580, 1202, 'Dollar S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/103344.mp4', 'http://gstaticontent.com/images/d8nuQGs0RxoWUHYvQJl91xYm4Az_big.jpg'),
(18581, 1202, 'Dollar S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/103345.mp4', 'http://gstaticontent.com/images/d8nuQGs0RxoWUHYvQJl91xYm4Az_big.jpg'),
(18582, 1202, 'Dollar S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/103346.mp4', 'http://gstaticontent.com/images/d8nuQGs0RxoWUHYvQJl91xYm4Az_big.jpg'),
(18583, 1203, 'Sintonia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221460.mp4', 'http://gstaticontent.com/images/sTTxrKX9DzB5K6wdsfCs5bQ0r6r_big.jpg'),
(18584, 1203, 'Sintonia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221461.mp4', 'http://gstaticontent.com/images/sTTxrKX9DzB5K6wdsfCs5bQ0r6r_big.jpg'),
(18585, 1203, 'Sintonia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221462.mp4', 'http://gstaticontent.com/images/sTTxrKX9DzB5K6wdsfCs5bQ0r6r_big.jpg'),
(18586, 1203, 'Sintonia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221463.mp4', 'http://gstaticontent.com/images/sTTxrKX9DzB5K6wdsfCs5bQ0r6r_big.jpg'),
(18587, 1203, 'Sintonia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221464.mp4', 'http://gstaticontent.com/images/sTTxrKX9DzB5K6wdsfCs5bQ0r6r_big.jpg'),
(18588, 1203, 'Sintonia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221465.mp4', 'http://gstaticontent.com/images/sTTxrKX9DzB5K6wdsfCs5bQ0r6r_big.jpg'),
(18589, 1204, 'Sintonia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbIbw8iLqkXqIDUxMr9yEMK1aGt.jpg'),
(18590, 1204, 'Sintonia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4XUZBMnQYRoRKqnlIPMhAvVoSrX.jpg'),
(18591, 1204, 'Sintonia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j4KOBezK7PNs0RirNaICfeMxxFU.jpg'),
(18592, 1204, 'Sintonia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nwtp4rjCkGm6jkbfBVLRWouN6MU.jpg'),
(18593, 1204, 'Sintonia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2rdd3bmm2k7pTiDS1J2dtBF3CS.jpg'),
(18594, 1204, 'Sintonia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uovxIqm8XC4KKldCXJrt2PYT3kh.jpg'),
(18595, 1205, 'Sintonia S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221472.mp4', 'http://timg.bdta.pro/images/a703d544899c663a6627255d302a59ff.jpg'),
(18596, 1205, 'Sintonia S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221473.mp4', 'http://timg.bdta.pro/images/697270affc57d3ce655bfa2472970b2a.jpg'),
(18597, 1205, 'Sintonia S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221474.mp4', 'http://timg.bdta.pro/images/96c0233a0221797183aa6b6402e73c54.jpg'),
(18598, 1205, 'Sintonia S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221475.mp4', 'http://timg.bdta.pro/images/069338b0c72d117f3e364be999b3e046.jpg'),
(18599, 1205, 'Sintonia S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221476.mp4', 'http://timg.bdta.pro/images/cbe7d7b75a4a27b3f4497cd8fa08122e.jpg'),
(18600, 1205, 'Sintonia S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221477.mp4', 'http://timg.bdta.pro/images/e528e91fd9d22953ce10ec03d57b7185.jpg'),
(18601, 1206, 'Sintonia S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221478.mp4', 'http://gstaticontent.com/images/sTTxrKX9DzB5K6wdsfCs5bQ0r6r_big.jpg'),
(18602, 1206, 'Sintonia S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221479.mp4', 'http://gstaticontent.com/images/sTTxrKX9DzB5K6wdsfCs5bQ0r6r_big.jpg'),
(18603, 1206, 'Sintonia S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221480.mp4', 'http://gstaticontent.com/images/sTTxrKX9DzB5K6wdsfCs5bQ0r6r_big.jpg'),
(18604, 1206, 'Sintonia S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221481.mp4', 'http://gstaticontent.com/images/sTTxrKX9DzB5K6wdsfCs5bQ0r6r_big.jpg'),
(18605, 1206, 'Sintonia S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221482.mp4', 'http://gstaticontent.com/images/sTTxrKX9DzB5K6wdsfCs5bQ0r6r_big.jpg'),
(18606, 1206, 'Sintonia S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221483.mp4', 'http://gstaticontent.com/images/sTTxrKX9DzB5K6wdsfCs5bQ0r6r_big.jpg'),
(18607, 1206, 'Sintonia S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221484.mp4', 'http://gstaticontent.com/images/sTTxrKX9DzB5K6wdsfCs5bQ0r6r_big.jpg'),
(18608, 1206, 'Sintonia S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221485.mp4', 'http://gstaticontent.com/images/sTTxrKX9DzB5K6wdsfCs5bQ0r6r_big.jpg'),
(18609, 1207, 'Sintonia S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/684482.mp4', 'http://gstaticontent.com/images/sTTxrKX9DzB5K6wdsfCs5bQ0r6r_big.jpg'),
(18610, 1207, 'Sintonia S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/684483.mp4', 'http://gstaticontent.com/images/sTTxrKX9DzB5K6wdsfCs5bQ0r6r_big.jpg'),
(18611, 1207, 'Sintonia S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/684484.mp4', 'http://gstaticontent.com/images/sTTxrKX9DzB5K6wdsfCs5bQ0r6r_big.jpg'),
(18612, 1207, 'Sintonia S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/684485.mp4', 'http://gstaticontent.com/images/sTTxrKX9DzB5K6wdsfCs5bQ0r6r_big.jpg'),
(18613, 1207, 'Sintonia S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/684486.mp4', 'http://gstaticontent.com/images/sTTxrKX9DzB5K6wdsfCs5bQ0r6r_big.jpg'),
(18614, 1207, 'Sintonia S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/684487.mp4', 'http://gstaticontent.com/images/sTTxrKX9DzB5K6wdsfCs5bQ0r6r_big.jpg'),
(18615, 1208, 'Os 3 Lá Embaixo: Contos da Arcadia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103306.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18616, 1208, 'Os 3 Lá Embaixo: Contos da Arcadia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103307.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18617, 1208, 'Os 3 Lá Embaixo: Contos da Arcadia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103308.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18618, 1208, 'Os 3 Lá Embaixo: Contos da Arcadia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103309.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18619, 1208, 'Os 3 Lá Embaixo: Contos da Arcadia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103310.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18620, 1208, 'Os 3 Lá Embaixo: Contos da Arcadia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103311.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18621, 1208, 'Os 3 Lá Embaixo: Contos da Arcadia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103312.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18622, 1208, 'Os 3 Lá Embaixo: Contos da Arcadia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103313.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18623, 1208, 'Os 3 Lá Embaixo: Contos da Arcadia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103314.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18624, 1208, 'Os 3 Lá Embaixo: Contos da Arcadia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103315.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18625, 1208, 'Os 3 Lá Embaixo: Contos da Arcadia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103316.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18626, 1208, 'Os 3 Lá Embaixo: Contos da Arcadia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103317.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18627, 1208, 'Os 3 Lá Embaixo: Contos da Arcadia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/103318.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18628, 1209, 'Os 3 Lá Embaixo: Contos da Arcadia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103319.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18629, 1209, 'Os 3 Lá Embaixo: Contos da Arcadia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103320.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18630, 1209, 'Os 3 Lá Embaixo: Contos da Arcadia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103321.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18631, 1209, 'Os 3 Lá Embaixo: Contos da Arcadia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103322.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18632, 1209, 'Os 3 Lá Embaixo: Contos da Arcadia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103323.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18633, 1209, 'Os 3 Lá Embaixo: Contos da Arcadia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103324.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18634, 1209, 'Os 3 Lá Embaixo: Contos da Arcadia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103325.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18635, 1209, 'Os 3 Lá Embaixo: Contos da Arcadia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103326.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18636, 1209, 'Os 3 Lá Embaixo: Contos da Arcadia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103327.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18637, 1209, 'Os 3 Lá Embaixo: Contos da Arcadia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103328.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18638, 1209, 'Os 3 Lá Embaixo: Contos da Arcadia S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103329.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18639, 1209, 'Os 3 Lá Embaixo: Contos da Arcadia S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103330.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18640, 1209, 'Os 3 Lá Embaixo: Contos da Arcadia S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/103331.mp4', 'http://gstaticontent.com/images/6odQsKnU8d0TQfYxhLlpqRP6xyt_big.jpg'),
(18641, 1210, 'The InBESTigators S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105914.mp4', 'http://gstaticontent.com/images/7VdVta30X0cZZhEIFOsOWHn24TU_big.jpg'),
(18642, 1210, 'The InBESTigators S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105915.mp4', 'http://gstaticontent.com/images/7VdVta30X0cZZhEIFOsOWHn24TU_big.jpg'),
(18643, 1210, 'The InBESTigators S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105916.mp4', 'http://gstaticontent.com/images/7VdVta30X0cZZhEIFOsOWHn24TU_big.jpg'),
(18644, 1210, 'The InBESTigators S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105917.mp4', 'http://gstaticontent.com/images/7VdVta30X0cZZhEIFOsOWHn24TU_big.jpg'),
(18645, 1210, 'The InBESTigators S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105918.mp4', 'http://gstaticontent.com/images/7VdVta30X0cZZhEIFOsOWHn24TU_big.jpg'),
(18646, 1210, 'The InBESTigators S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105919.mp4', 'http://gstaticontent.com/images/7VdVta30X0cZZhEIFOsOWHn24TU_big.jpg'),
(18647, 1210, 'The InBESTigators S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105920.mp4', 'http://gstaticontent.com/images/7VdVta30X0cZZhEIFOsOWHn24TU_big.jpg'),
(18648, 1210, 'The InBESTigators S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105921.mp4', 'http://gstaticontent.com/images/7VdVta30X0cZZhEIFOsOWHn24TU_big.jpg'),
(18649, 1210, 'The InBESTigators S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105922.mp4', 'http://gstaticontent.com/images/7VdVta30X0cZZhEIFOsOWHn24TU_big.jpg'),
(18650, 1210, 'The InBESTigators S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105923.mp4', 'http://gstaticontent.com/images/7VdVta30X0cZZhEIFOsOWHn24TU_big.jpg'),
(18651, 1211, 'The InBESTigators S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105924.mp4', 'http://timg.bdta.pro/images/598d5214487c0100a12115e4c6788db5.jpg'),
(18652, 1211, 'The InBESTigators S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105925.mp4', 'http://timg.bdta.pro/images/a703bc5d23aa0d50c8b62777aebdb176.jpg'),
(18653, 1211, 'The InBESTigators S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105926.mp4', 'http://timg.bdta.pro/images/b9c55d1bab7a5b1dd76a1381c76a8cc3.jpg'),
(18654, 1211, 'The InBESTigators S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105927.mp4', 'http://timg.bdta.pro/images/daeb7290f3859521c435254d1686bf0c.jpg'),
(18655, 1211, 'The InBESTigators S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105928.mp4', 'http://timg.bdta.pro/images/bda2e5219094f57cc467efc70747e889.jpg'),
(18656, 1211, 'The InBESTigators S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105929.mp4', 'http://timg.bdta.pro/images/cc2943049eb5f9601aa436580ca52991.jpg'),
(18657, 1211, 'The InBESTigators S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105930.mp4', 'http://timg.bdta.pro/images/ec76888cfd5989a03fca42e7afea51ed.jpg'),
(18658, 1211, 'The InBESTigators S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105931.mp4', 'http://timg.bdta.pro/images/c46ac74c3ce74ec03309249d6f424ca1.jpg'),
(18659, 1211, 'The InBESTigators S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105932.mp4', 'http://timg.bdta.pro/images/47a0d087ffbb276d48422d80de76c07c.jpg'),
(18660, 1211, 'The InBESTigators S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105933.mp4', 'http://timg.bdta.pro/images/e26e68474063873288878317c0cd3014.jpg'),
(18661, 1212, 'The Family S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103301.mp4', 'http://gstaticontent.com/images/5uxUa1gF15oVTyVwaKPzIBWCamM_big.jpg'),
(18662, 1212, 'The Family S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103302.mp4', 'http://gstaticontent.com/images/5uxUa1gF15oVTyVwaKPzIBWCamM_big.jpg'),
(18663, 1212, 'The Family S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103303.mp4', 'http://gstaticontent.com/images/5uxUa1gF15oVTyVwaKPzIBWCamM_big.jpg'),
(18664, 1212, 'The Family S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103304.mp4', 'http://gstaticontent.com/images/5uxUa1gF15oVTyVwaKPzIBWCamM_big.jpg'),
(18665, 1212, 'The Family S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103305.mp4', 'http://gstaticontent.com/images/5uxUa1gF15oVTyVwaKPzIBWCamM_big.jpg'),
(18666, 1213, 'Pergunte Aos StoryBots S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103279.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18667, 1213, 'Pergunte Aos StoryBots S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103280.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18668, 1213, 'Pergunte Aos StoryBots S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103281.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18669, 1213, 'Pergunte Aos StoryBots S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103282.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18670, 1213, 'Pergunte Aos StoryBots S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103283.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18671, 1213, 'Pergunte Aos StoryBots S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103284.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18672, 1214, 'Pergunte Aos StoryBots S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103285.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18673, 1214, 'Pergunte Aos StoryBots S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103286.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18674, 1214, 'Pergunte Aos StoryBots S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103287.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18675, 1214, 'Pergunte Aos StoryBots S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103288.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18676, 1214, 'Pergunte Aos StoryBots S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103289.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18677, 1214, 'Pergunte Aos StoryBots S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103290.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18678, 1214, 'Pergunte Aos StoryBots S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103291.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18679, 1214, 'Pergunte Aos StoryBots S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103292.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18680, 1215, 'Pergunte Aos StoryBots S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103293.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18681, 1215, 'Pergunte Aos StoryBots S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103294.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18682, 1215, 'Pergunte Aos StoryBots S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103295.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18683, 1215, 'Pergunte Aos StoryBots S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103296.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18684, 1215, 'Pergunte Aos StoryBots S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103297.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18685, 1215, 'Pergunte Aos StoryBots S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103298.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18686, 1215, 'Pergunte Aos StoryBots S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103299.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18687, 1215, 'Pergunte Aos StoryBots S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103300.mp4', 'http://gstaticontent.com/images/1ogpRatqCWZ6cMBkUyIe4cL6WSm_big.jpg'),
(18688, 1216, 'Hospital New Amsterdam S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18689, 1216, 'Hospital New Amsterdam S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18690, 1216, 'Hospital New Amsterdam S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18691, 1216, 'Hospital New Amsterdam S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18692, 1216, 'Hospital New Amsterdam S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18693, 1216, 'Hospital New Amsterdam S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18694, 1216, 'Hospital New Amsterdam S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18695, 1216, 'Hospital New Amsterdam S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18696, 1216, 'Hospital New Amsterdam S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18697, 1216, 'Hospital New Amsterdam S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18698, 1216, 'Hospital New Amsterdam S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18699, 1216, 'Hospital New Amsterdam S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18700, 1216, 'Hospital New Amsterdam S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18701, 1216, 'Hospital New Amsterdam S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18702, 1216, 'Hospital New Amsterdam S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18703, 1216, 'Hospital New Amsterdam S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/241596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18704, 1216, 'Hospital New Amsterdam S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/241597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18705, 1216, 'Hospital New Amsterdam S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/241598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18706, 1216, 'Hospital New Amsterdam S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/241599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18707, 1216, 'Hospital New Amsterdam S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/241600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18708, 1216, 'Hospital New Amsterdam S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/241601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18709, 1216, 'Hospital New Amsterdam S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/241602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18710, 1217, 'Hospital New Amsterdam S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241603.mp4', 'http://timg.bdta.pro/images/d46b04128e42551e6da2bc3db28cac76.jpg'),
(18711, 1217, 'Hospital New Amsterdam S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241604.mp4', 'http://timg.bdta.pro/images/bda19db66b01f1fbc7b6ed85ae590e20.jpg'),
(18712, 1217, 'Hospital New Amsterdam S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241605.mp4', 'http://timg.bdta.pro/images/1b8a076a790aaaebc5a12546c901c1e4.jpg'),
(18713, 1217, 'Hospital New Amsterdam S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241606.mp4', 'http://timg.bdta.pro/images/a13bdb150437816337741ca919d6fb83.jpg'),
(18714, 1217, 'Hospital New Amsterdam S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241607.mp4', 'http://timg.bdta.pro/images/75e256f5e8d110c33c48176807656201.jpg'),
(18715, 1217, 'Hospital New Amsterdam S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241608.mp4', 'http://timg.bdta.pro/images/cd3977e30cf0ebe6d234484733052a3b.jpg'),
(18716, 1217, 'Hospital New Amsterdam S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241609.mp4', 'http://timg.bdta.pro/images/6e10b061826babfdff0b4f7907395a95.jpg'),
(18717, 1217, 'Hospital New Amsterdam S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241610.mp4', 'http://timg.bdta.pro/images/1ce04913b3603397e058c897e70fc585.jpg'),
(18718, 1217, 'Hospital New Amsterdam S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241611.mp4', 'http://timg.bdta.pro/images/2524c09977d3f2d8a780617676aba230.jpg'),
(18719, 1217, 'Hospital New Amsterdam S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241612.mp4', 'http://timg.bdta.pro/images/f926112a233559dc0e5317580d1e3c7b.jpg'),
(18720, 1217, 'Hospital New Amsterdam S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241613.mp4', 'http://timg.bdta.pro/images/8bacb1ba8d4d1c19b0b4b22a7d5f5b2b.jpg'),
(18721, 1217, 'Hospital New Amsterdam S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241614.mp4', 'http://timg.bdta.pro/images/e7020923650101642b7f03c673962ed7.jpg'),
(18722, 1217, 'Hospital New Amsterdam S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241615.mp4', 'http://timg.bdta.pro/images/bc7f207f21867b652bbfd7a55c2ca032.jpg'),
(18723, 1217, 'Hospital New Amsterdam S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241616.mp4', 'http://timg.bdta.pro/images/14c239c753ead1ad1fc6c6885b9021cc.jpg'),
(18724, 1217, 'Hospital New Amsterdam S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241617.mp4', 'http://timg.bdta.pro/images/2b07edc33ebda51eb948a3d6da9d8ab8.jpg'),
(18725, 1217, 'Hospital New Amsterdam S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/241618.mp4', 'http://timg.bdta.pro/images/ec733a75dc900cab42a7d37c738057e8.jpg'),
(18726, 1217, 'Hospital New Amsterdam S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/241619.mp4', 'http://timg.bdta.pro/images/b1951327e81a1517a8b5532689f2ae18.jpg'),
(18727, 1218, 'Hospital New Amsterdam S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d3Cx5EpFFWs9OS7UdR7HULlyJen.jpg'),
(18728, 1218, 'Hospital New Amsterdam S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/egfD8BdBAviSIYHisYp97pbQfTF.jpg'),
(18729, 1218, 'Hospital New Amsterdam S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v2scprwp4k0xtPKkcm4K60JSioZ.jpg'),
(18730, 1218, 'Hospital New Amsterdam S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vdUbNlnrgJtKJMsLXbDXyfEBvVc.jpg'),
(18731, 1218, 'Hospital New Amsterdam S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bvtwwC0L8PyHcYgs6pihhPEf2AY.jpg'),
(18732, 1218, 'Hospital New Amsterdam S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/er4Vz34iC1lDj9IrI00Q2GKHlJ7.jpg'),
(18733, 1218, 'Hospital New Amsterdam S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lrwSsw7fhuwWzhTnE9XaMuXdUsm.jpg'),
(18734, 1218, 'Hospital New Amsterdam S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pueiE0yX1wqVBdnAAg7WehUdFRr.jpg'),
(18735, 1218, 'Hospital New Amsterdam S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rw8et0dtMxpF4oiQJauE1xNjOtE.jpg'),
(18736, 1218, 'Hospital New Amsterdam S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gdlRQ2OXTp8YdlkGGf2jeO7TRVT.jpg'),
(18737, 1218, 'Hospital New Amsterdam S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBnTqNE5SwQDITWxoa8w0fCe36w.jpg'),
(18738, 1218, 'Hospital New Amsterdam S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ijolX19SREo0E8LS3Jy5qGriSnt.jpg'),
(18739, 1218, 'Hospital New Amsterdam S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/32VzP7s5ag5NDLvgHUxMhWdEV0j.jpg'),
(18740, 1218, 'Hospital New Amsterdam S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/20soyclFyK66bGHJKuc1RBw6Jmg.jpg'),
(18741, 1219, 'Hospital New Amsterdam S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dFDSFiuZySHNrVb2GplNwbKajMk.jpg'),
(18742, 1219, 'Hospital New Amsterdam S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pTebubVUylJtoNf5QA3waZwjAWb.jpg'),
(18743, 1219, 'Hospital New Amsterdam S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r4hJ4WrkdUA9n64PRWuAUUtZQCx.jpg'),
(18744, 1219, 'Hospital New Amsterdam S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wrBtaZSBTGEs1dYzM6PDc9Qm3PB.jpg'),
(18745, 1219, 'Hospital New Amsterdam S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n9X7yDAfNb36pFSWRtndw4u7iot.jpg'),
(18746, 1219, 'Hospital New Amsterdam S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wImvFAYZ5w3l7fgH41ljrkCvVoz.jpg'),
(18747, 1219, 'Hospital New Amsterdam S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3qatxMaEFeHeHr9g4LJ6TAM5pZ3.jpg'),
(18748, 1219, 'Hospital New Amsterdam S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fFREZTsanbqGablUoQwTLRSB7dz.jpg'),
(18749, 1219, 'Hospital New Amsterdam S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cRS4UHYGVZ9CwJg5G5niHnry2Nr.jpg'),
(18750, 1219, 'Hospital New Amsterdam S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v2e8xL0n8p8ucCpkZDAoapAN7Fl.jpg'),
(18751, 1219, 'Hospital New Amsterdam S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zZEkNGGIiJpu9RKu5pb71huvg0F.jpg'),
(18752, 1219, 'Hospital New Amsterdam S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jPt3zXR5oanCT7eQt29x56ouVE0.jpg'),
(18753, 1219, 'Hospital New Amsterdam S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3HTGD8ED4SruaR4rVTGcXNGfmzD.jpg'),
(18754, 1219, 'Hospital New Amsterdam S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xo9qQddNI9DrhF1jBMNEtZVJcsj.jpg'),
(18755, 1219, 'Hospital New Amsterdam S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/woev85opMBKFXxfOrXgVu5T8aS0.jpg'),
(18756, 1219, 'Hospital New Amsterdam S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/241649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ubXXDgiz9ZSsrLw7p9BW3Ggvxwi.jpg'),
(18757, 1219, 'Hospital New Amsterdam S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/241650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/moGwPNdVLP2cXtctYlHqF6tub8U.jpg'),
(18758, 1219, 'Hospital New Amsterdam S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/241651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zg0N7Wv15MDecfQGTqOUsX0bH3i.jpg'),
(18759, 1219, 'Hospital New Amsterdam S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/241652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QgAklFEzKdUrOtvtZpFC19bKUK.jpg'),
(18760, 1219, 'Hospital New Amsterdam S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/241653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7xV3pRrlm8Zzb0hjMyYeNVo1zW5.jpg'),
(18761, 1219, 'Hospital New Amsterdam S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/241654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kp13iNiMOiqcsJgV0v3cXvwn1ia.jpg'),
(18762, 1219, 'Hospital New Amsterdam S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/241655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/52kre9sojlvWyBQpW9yYAQsRa5C.jpg'),
(18763, 1220, 'Hospital New Amsterdam S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18764, 1220, 'Hospital New Amsterdam S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18765, 1220, 'Hospital New Amsterdam S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18766, 1220, 'Hospital New Amsterdam S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18767, 1220, 'Hospital New Amsterdam S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18768, 1220, 'Hospital New Amsterdam S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18769, 1220, 'Hospital New Amsterdam S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18770, 1220, 'Hospital New Amsterdam S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18771, 1220, 'Hospital New Amsterdam S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18772, 1220, 'Hospital New Amsterdam S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18773, 1220, 'Hospital New Amsterdam S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18774, 1220, 'Hospital New Amsterdam S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18775, 1220, 'Hospital New Amsterdam S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jeZ98Lh9kCQIDQSLoODljapaKUg.jpg'),
(18776, 1221, 'M - A Caca de um Assassino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103273.mp4', 'http://gstaticontent.com/images/pIhwIWsEwGZ574vrVKWQ7HYakZ4_big.jpg'),
(18777, 1221, 'M - A Caca de um Assassino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103274.mp4', 'http://gstaticontent.com/images/pIhwIWsEwGZ574vrVKWQ7HYakZ4_big.jpg'),
(18778, 1221, 'M - A Caca de um Assassino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103275.mp4', 'http://gstaticontent.com/images/pIhwIWsEwGZ574vrVKWQ7HYakZ4_big.jpg'),
(18779, 1221, 'M - A Caca de um Assassino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103276.mp4', 'http://gstaticontent.com/images/pIhwIWsEwGZ574vrVKWQ7HYakZ4_big.jpg'),
(18780, 1221, 'M - A Caca de um Assassino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103277.mp4', 'http://gstaticontent.com/images/pIhwIWsEwGZ574vrVKWQ7HYakZ4_big.jpg'),
(18781, 1221, 'M - A Caca de um Assassino S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103278.mp4', 'http://gstaticontent.com/images/pIhwIWsEwGZ574vrVKWQ7HYakZ4_big.jpg'),
(18782, 1222, 'GLOW S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103243.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18783, 1222, 'GLOW S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103244.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18784, 1222, 'GLOW S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103245.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18785, 1222, 'GLOW S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103246.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18786, 1222, 'GLOW S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103247.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18787, 1222, 'GLOW S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103248.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18788, 1222, 'GLOW S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103249.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18789, 1222, 'GLOW S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103250.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18790, 1222, 'GLOW S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103251.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18791, 1222, 'GLOW S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103252.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18792, 1223, 'GLOW S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103253.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18793, 1223, 'GLOW S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103254.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18794, 1223, 'GLOW S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103255.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18795, 1223, 'GLOW S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103256.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18796, 1223, 'GLOW S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103257.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18797, 1223, 'GLOW S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103258.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18798, 1223, 'GLOW S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103259.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18799, 1223, 'GLOW S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103260.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18800, 1223, 'GLOW S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103261.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18801, 1223, 'GLOW S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103262.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18802, 1224, 'GLOW S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103263.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18803, 1224, 'GLOW S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103264.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18804, 1224, 'GLOW S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103265.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18805, 1224, 'GLOW S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103266.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18806, 1224, 'GLOW S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103267.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18807, 1224, 'GLOW S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103268.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18808, 1224, 'GLOW S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103269.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18809, 1224, 'GLOW S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103270.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18810, 1224, 'GLOW S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103271.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18811, 1224, 'GLOW S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103272.mp4', 'http://gstaticontent.com/images/aqQlgRgUwVTfbdxe33vfDEMiCa2_big.jpg'),
(18812, 1225, 'Aquarius S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103207.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18813, 1225, 'Aquarius S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103208.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18814, 1225, 'Aquarius S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103209.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18815, 1225, 'Aquarius S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103210.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18816, 1225, 'Aquarius S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103211.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18817, 1225, 'Aquarius S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103212.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18818, 1225, 'Aquarius S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103213.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18819, 1225, 'Aquarius S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103214.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18820, 1225, 'Aquarius S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103215.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18821, 1225, 'Aquarius S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103216.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18822, 1225, 'Aquarius S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103217.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18823, 1225, 'Aquarius S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103218.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18824, 1225, 'Aquarius S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/103219.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18825, 1226, 'Aquarius S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103220.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18826, 1226, 'Aquarius S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103221.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18827, 1226, 'Aquarius S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103222.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18828, 1226, 'Aquarius S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103223.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(18829, 1226, 'Aquarius S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103224.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18830, 1226, 'Aquarius S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103225.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18831, 1226, 'Aquarius S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103226.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18832, 1226, 'Aquarius S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103227.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18833, 1226, 'Aquarius S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103228.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18834, 1226, 'Aquarius S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103229.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18835, 1226, 'Aquarius S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103230.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18836, 1226, 'Aquarius S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103231.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18837, 1226, 'Aquarius S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/103232.mp4', 'http://gstaticontent.com/images/dTihIjUI2ScBXVgcZiyTAq1PBBA_big.jpg'),
(18838, 1227, 'Pennyworth: A Origem do Mordomo do Batman [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107076.mp4', 'http://gstaticontent.com/images/94bf5080f1e702f470e32f5b90a1b58b.jpg'),
(18839, 1227, 'Pennyworth: A Origem do Mordomo do Batman [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107077.mp4', 'http://gstaticontent.com/images/94bf5080f1e702f470e32f5b90a1b58b.jpg'),
(18840, 1227, 'Pennyworth: A Origem do Mordomo do Batman [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107078.mp4', 'http://gstaticontent.com/images/94bf5080f1e702f470e32f5b90a1b58b.jpg'),
(18841, 1227, 'Pennyworth: A Origem do Mordomo do Batman [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107079.mp4', 'http://gstaticontent.com/images/94bf5080f1e702f470e32f5b90a1b58b.jpg'),
(18842, 1227, 'Pennyworth: A Origem do Mordomo do Batman [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107080.mp4', 'http://gstaticontent.com/images/94bf5080f1e702f470e32f5b90a1b58b.jpg'),
(18843, 1227, 'Pennyworth: A Origem do Mordomo do Batman [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107081.mp4', 'http://gstaticontent.com/images/94bf5080f1e702f470e32f5b90a1b58b.jpg'),
(18844, 1227, 'Pennyworth: A Origem do Mordomo do Batman [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107082.mp4', 'http://gstaticontent.com/images/94bf5080f1e702f470e32f5b90a1b58b.jpg'),
(18845, 1227, 'Pennyworth: A Origem do Mordomo do Batman [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107083.mp4', 'http://timg.bdta.pro/images/b6c1f85bbf52d08f24789c95319d2b3c.jpg'),
(18846, 1227, 'Pennyworth: A Origem do Mordomo do Batman [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107084.mp4', 'http://timg.bdta.pro/images/11671ef71a071362e59f40431fdd1996.jpg'),
(18847, 1227, 'Pennyworth: A Origem do Mordomo do Batman [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107085.mp4', 'http://timg.bdta.pro/images/098912bafb90c04b0845697c85b06997.jpg'),
(18848, 1228, 'Homens? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109258.mp4', 'http://gstaticontent.com/images/ujLRxAyB6PLPiwrbvjCULA6Qv5k_big.jpg'),
(18849, 1228, 'Homens? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109259.mp4', 'http://gstaticontent.com/images/ujLRxAyB6PLPiwrbvjCULA6Qv5k_big.jpg'),
(18850, 1228, 'Homens? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109260.mp4', 'http://gstaticontent.com/images/ujLRxAyB6PLPiwrbvjCULA6Qv5k_big.jpg'),
(18851, 1228, 'Homens? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109261.mp4', 'http://gstaticontent.com/images/ujLRxAyB6PLPiwrbvjCULA6Qv5k_big.jpg'),
(18852, 1228, 'Homens? S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109262.mp4', 'http://gstaticontent.com/images/ujLRxAyB6PLPiwrbvjCULA6Qv5k_big.jpg'),
(18853, 1228, 'Homens? S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109263.mp4', 'http://gstaticontent.com/images/ujLRxAyB6PLPiwrbvjCULA6Qv5k_big.jpg'),
(18854, 1228, 'Homens? S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109264.mp4', 'http://gstaticontent.com/images/ujLRxAyB6PLPiwrbvjCULA6Qv5k_big.jpg'),
(18855, 1228, 'Homens? S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109265.mp4', 'http://gstaticontent.com/images/ujLRxAyB6PLPiwrbvjCULA6Qv5k_big.jpg'),
(18856, 1229, 'Homens? S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109266.mp4', 'http://gstaticontent.com/images/ujLRxAyB6PLPiwrbvjCULA6Qv5k_big.jpg'),
(18857, 1229, 'Homens? S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109267.mp4', 'http://gstaticontent.com/images/ujLRxAyB6PLPiwrbvjCULA6Qv5k_big.jpg'),
(18858, 1229, 'Homens? S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109268.mp4', 'http://gstaticontent.com/images/ujLRxAyB6PLPiwrbvjCULA6Qv5k_big.jpg'),
(18859, 1229, 'Homens? S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109269.mp4', 'http://gstaticontent.com/images/ujLRxAyB6PLPiwrbvjCULA6Qv5k_big.jpg'),
(18860, 1229, 'Homens? S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109270.mp4', 'http://gstaticontent.com/images/ujLRxAyB6PLPiwrbvjCULA6Qv5k_big.jpg'),
(18861, 1229, 'Homens? S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109271.mp4', 'http://gstaticontent.com/images/ujLRxAyB6PLPiwrbvjCULA6Qv5k_big.jpg'),
(18862, 1229, 'Homens? S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109272.mp4', 'http://gstaticontent.com/images/ujLRxAyB6PLPiwrbvjCULA6Qv5k_big.jpg'),
(18863, 1229, 'Homens? S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109273.mp4', 'http://gstaticontent.com/images/ujLRxAyB6PLPiwrbvjCULA6Qv5k_big.jpg'),
(18864, 1230, 'Cannon Busters S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108667.mp4', 'http://gstaticontent.com/images/etU8k5nzNG0HfIIDGcM5TP4HAWS_big.jpg'),
(18865, 1230, 'Cannon Busters S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108668.mp4', 'http://gstaticontent.com/images/etU8k5nzNG0HfIIDGcM5TP4HAWS_big.jpg'),
(18866, 1230, 'Cannon Busters S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108669.mp4', 'http://gstaticontent.com/images/etU8k5nzNG0HfIIDGcM5TP4HAWS_big.jpg'),
(18867, 1230, 'Cannon Busters S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108670.mp4', 'http://gstaticontent.com/images/etU8k5nzNG0HfIIDGcM5TP4HAWS_big.jpg'),
(18868, 1230, 'Cannon Busters S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108671.mp4', 'http://gstaticontent.com/images/etU8k5nzNG0HfIIDGcM5TP4HAWS_big.jpg'),
(18869, 1230, 'Cannon Busters S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108672.mp4', 'http://gstaticontent.com/images/etU8k5nzNG0HfIIDGcM5TP4HAWS_big.jpg'),
(18870, 1230, 'Cannon Busters S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108673.mp4', 'http://gstaticontent.com/images/etU8k5nzNG0HfIIDGcM5TP4HAWS_big.jpg'),
(18871, 1230, 'Cannon Busters S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108674.mp4', 'http://gstaticontent.com/images/etU8k5nzNG0HfIIDGcM5TP4HAWS_big.jpg'),
(18872, 1230, 'Cannon Busters S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108675.mp4', 'http://gstaticontent.com/images/etU8k5nzNG0HfIIDGcM5TP4HAWS_big.jpg'),
(18873, 1230, 'Cannon Busters S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108676.mp4', 'http://gstaticontent.com/images/etU8k5nzNG0HfIIDGcM5TP4HAWS_big.jpg'),
(18874, 1230, 'Cannon Busters S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108677.mp4', 'http://timg.bdta.pro/images/8b6ddb0e2ebecf2d45cb3290397fe3c4.jpg'),
(18875, 1230, 'Cannon Busters S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108678.mp4', 'http://timg.bdta.pro/images/2fa0a0e3491bb87f9917c1ed812387d9.jpg'),
(18876, 1231, 'Tô de Graça S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190166.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18877, 1231, 'Tô de Graça S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190167.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18878, 1231, 'Tô de Graça S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190168.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18879, 1231, 'Tô de Graça S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190169.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18880, 1231, 'Tô de Graça S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190170.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18881, 1231, 'Tô de Graça S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190171.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18882, 1231, 'Tô de Graça S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190172.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18883, 1231, 'Tô de Graça S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190173.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18884, 1231, 'Tô de Graça S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190174.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18885, 1231, 'Tô de Graça S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190175.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18886, 1231, 'Tô de Graça S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190176.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18887, 1231, 'Tô de Graça S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190177.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18888, 1231, 'Tô de Graça S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190178.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18889, 1231, 'Tô de Graça S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190179.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18890, 1231, 'Tô de Graça S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190180.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18891, 1231, 'Tô de Graça S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190181.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18892, 1231, 'Tô de Graça S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190182.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18893, 1231, 'Tô de Graça S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190183.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18894, 1231, 'Tô de Graça S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/190184.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18895, 1231, 'Tô de Graça S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/190185.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18896, 1232, 'Tô de Graça S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190186.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18897, 1232, 'Tô de Graça S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190187.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18898, 1232, 'Tô de Graça S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190188.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18899, 1232, 'Tô de Graça S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190189.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18900, 1232, 'Tô de Graça S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190190.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18901, 1232, 'Tô de Graça S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190191.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18902, 1232, 'Tô de Graça S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190192.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18903, 1232, 'Tô de Graça S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190193.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18904, 1232, 'Tô de Graça S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190194.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18905, 1232, 'Tô de Graça S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190195.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18906, 1232, 'Tô de Graça S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190196.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18907, 1232, 'Tô de Graça S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190197.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18908, 1232, 'Tô de Graça S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190198.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18909, 1232, 'Tô de Graça S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190199.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18910, 1232, 'Tô de Graça S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190200.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18911, 1232, 'Tô de Graça S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190201.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18912, 1232, 'Tô de Graça S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190202.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18913, 1232, 'Tô de Graça S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190203.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18914, 1232, 'Tô de Graça S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/190204.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18915, 1232, 'Tô de Graça S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/190205.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18916, 1232, 'Tô de Graça S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/190206.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18917, 1232, 'Tô de Graça S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/190207.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18918, 1232, 'Tô de Graça S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/190208.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18919, 1232, 'Tô de Graça S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/190209.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18920, 1232, 'Tô de Graça S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/190210.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18921, 1232, 'Tô de Graça S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/190211.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18922, 1232, 'Tô de Graça S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/190212.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18923, 1232, 'Tô de Graça S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/190213.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18924, 1232, 'Tô de Graça S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/190214.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18925, 1232, 'Tô de Graça S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/190215.mp4', 'http://timg.bdta.pro/images/014f6606ff6a6b4685b78320b397e6e8.jpg'),
(18926, 1233, 'Tô de Graça S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190216.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18927, 1233, 'Tô de Graça S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190217.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18928, 1233, 'Tô de Graça S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190218.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18929, 1233, 'Tô de Graça S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190219.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18930, 1233, 'Tô de Graça S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190220.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18931, 1233, 'Tô de Graça S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190221.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18932, 1233, 'Tô de Graça S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190222.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18933, 1233, 'Tô de Graça S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190223.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18934, 1233, 'Tô de Graça S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190224.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18935, 1233, 'Tô de Graça S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190225.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18936, 1233, 'Tô de Graça S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190226.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18937, 1233, 'Tô de Graça S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190227.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18938, 1233, 'Tô de Graça S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190228.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18939, 1233, 'Tô de Graça S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190229.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18940, 1233, 'Tô de Graça S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190230.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18941, 1233, 'Tô de Graça S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190231.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18942, 1233, 'Tô de Graça S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190232.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18943, 1233, 'Tô de Graça S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190233.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18944, 1233, 'Tô de Graça S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/190234.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18945, 1233, 'Tô de Graça S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/190235.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18946, 1233, 'Tô de Graça S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/190236.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18947, 1233, 'Tô de Graça S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/190237.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18948, 1233, 'Tô de Graça S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/190238.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18949, 1233, 'Tô de Graça S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/190239.mp4', 'http://timg.bdta.pro/images/6804287978b591742a7c7cd8af5b5a55.jpg'),
(18950, 1233, 'Tô de Graça S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/190240.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18951, 1233, 'Tô de Graça S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/190241.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18952, 1233, 'Tô de Graça S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/190242.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18953, 1233, 'Tô de Graça S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/190243.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18954, 1233, 'Tô de Graça S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/190244.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18955, 1233, 'Tô de Graça S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/190245.mp4', 'http://timg.bdta.pro/images/14d7a48cd27148be26506288e3650065.jpg'),
(18956, 1234, 'Tô de Graça S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190246.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18957, 1234, 'Tô de Graça S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190247.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18958, 1234, 'Tô de Graça S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190248.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18959, 1234, 'Tô de Graça S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190249.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18960, 1234, 'Tô de Graça S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190250.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18961, 1234, 'Tô de Graça S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190251.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18962, 1234, 'Tô de Graça S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190252.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18963, 1234, 'Tô de Graça S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190253.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18964, 1234, 'Tô de Graça S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190254.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18965, 1234, 'Tô de Graça S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190255.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18966, 1234, 'Tô de Graça S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190256.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18967, 1234, 'Tô de Graça S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190257.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18968, 1234, 'Tô de Graça S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190258.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18969, 1234, 'Tô de Graça S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190259.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18970, 1234, 'Tô de Graça S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190260.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18971, 1234, 'Tô de Graça S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190261.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18972, 1234, 'Tô de Graça S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190262.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18973, 1234, 'Tô de Graça S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190263.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18974, 1234, 'Tô de Graça S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/190264.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18975, 1234, 'Tô de Graça S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/190265.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18976, 1234, 'Tô de Graça S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/190266.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18977, 1234, 'Tô de Graça S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/190267.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18978, 1234, 'Tô de Graça S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/190268.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18979, 1234, 'Tô de Graça S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/190269.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18980, 1234, 'Tô de Graça S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/190270.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18981, 1234, 'Tô de Graça S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/190271.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18982, 1234, 'Tô de Graça S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/190272.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18983, 1234, 'Tô de Graça S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/190273.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18984, 1234, 'Tô de Graça S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/190274.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18985, 1234, 'Tô de Graça S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/190275.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18986, 1235, 'Tô de Graça S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190276.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18987, 1235, 'Tô de Graça S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190277.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18988, 1235, 'Tô de Graça S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190278.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18989, 1235, 'Tô de Graça S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190279.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18990, 1235, 'Tô de Graça S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190280.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18991, 1235, 'Tô de Graça S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190281.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18992, 1235, 'Tô de Graça S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190282.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18993, 1235, 'Tô de Graça S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190283.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18994, 1235, 'Tô de Graça S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190284.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18995, 1235, 'Tô de Graça S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190285.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18996, 1235, 'Tô de Graça S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190286.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18997, 1235, 'Tô de Graça S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190287.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18998, 1235, 'Tô de Graça S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190288.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(18999, 1235, 'Tô de Graça S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190289.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19000, 1235, 'Tô de Graça S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190290.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19001, 1235, 'Tô de Graça S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190291.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19002, 1235, 'Tô de Graça S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190292.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19003, 1235, 'Tô de Graça S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190293.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19004, 1235, 'Tô de Graça S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/190294.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19005, 1235, 'Tô de Graça S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/190295.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19006, 1235, 'Tô de Graça S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/190296.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19007, 1235, 'Tô de Graça S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/190297.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19008, 1235, 'Tô de Graça S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/190298.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19009, 1235, 'Tô de Graça S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/190299.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19010, 1235, 'Tô de Graça S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/190300.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19011, 1236, 'Tô de Graça S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190301.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19012, 1236, 'Tô de Graça S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190302.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19013, 1236, 'Tô de Graça S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190303.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19014, 1236, 'Tô de Graça S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190304.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19015, 1236, 'Tô de Graça S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190305.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19016, 1236, 'Tô de Graça S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190306.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19017, 1236, 'Tô de Graça S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190307.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19018, 1236, 'Tô de Graça S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190308.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19019, 1236, 'Tô de Graça S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190309.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19020, 1236, 'Tô de Graça S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190310.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19021, 1236, 'Tô de Graça S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190311.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19022, 1236, 'Tô de Graça S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190312.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19023, 1236, 'Tô de Graça S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190313.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19024, 1236, 'Tô de Graça S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190314.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19025, 1236, 'Tô de Graça S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190315.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19026, 1236, 'Tô de Graça S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190316.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19027, 1236, 'Tô de Graça S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190317.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19028, 1236, 'Tô de Graça S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190318.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19029, 1236, 'Tô de Graça S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/190319.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19030, 1236, 'Tô de Graça S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/190320.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19031, 1236, 'Tô de Graça S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/190321.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19032, 1236, 'Tô de Graça S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/190322.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19033, 1236, 'Tô de Graça S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/190323.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19034, 1236, 'Tô de Graça S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/190324.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19035, 1236, 'Tô de Graça S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/190325.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19036, 1236, 'Tô de Graça S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/190326.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19037, 1236, 'Tô de Graça S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/190327.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19038, 1236, 'Tô de Graça S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/190328.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19039, 1236, 'Tô de Graça S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/190329.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19040, 1236, 'Tô de Graça S06 E30', 'http://sinalprivado.info:80/series/1533784/1533784/190330.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19041, 1237, 'Tô de Graça S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/789193.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19042, 1237, 'Tô de Graça S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/789194.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19043, 1237, 'Tô de Graça S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/789195.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19044, 1237, 'Tô de Graça S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/789196.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19045, 1237, 'Tô de Graça S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/789197.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19046, 1237, 'Tô de Graça S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/789198.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19047, 1237, 'Tô de Graça S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/789199.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19048, 1237, 'Tô de Graça S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/797354.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19049, 1237, 'Tô de Graça S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/797355.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19050, 1237, 'Tô de Graça S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/797356.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19051, 1237, 'Tô de Graça S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/801936.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19052, 1237, 'Tô de Graça S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/801937.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19053, 1237, 'Tô de Graça S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/801938.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19054, 1237, 'Tô de Graça S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/801939.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19055, 1237, 'Tô de Graça S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/801940.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19056, 1237, 'Tô de Graça S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/834985.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19057, 1237, 'Tô de Graça S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/834986.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19058, 1237, 'Tô de Graça S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/841246.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19059, 1237, 'Tô de Graça S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/841247.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19060, 1237, 'Tô de Graça S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/841248.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19061, 1237, 'Tô de Graça S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/842859.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19062, 1237, 'Tô de Graça S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/845072.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19063, 1237, 'Tô de Graça S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/846968.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19064, 1237, 'Tô de Graça S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/848435.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19065, 1237, 'Tô de Graça S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/848436.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19066, 1237, 'Tô de Graça S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/849900.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19067, 1237, 'Tô de Graça S07 E27', 'http://sinalprivado.info:80/series/1533784/1533784/849901.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19068, 1237, 'Tô de Graça S07 E28', 'http://sinalprivado.info:80/series/1533784/1533784/849902.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19069, 1237, 'Tô de Graça S07 E29', 'http://sinalprivado.info:80/series/1533784/1533784/853151.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19070, 1237, 'Tô de Graça S07 E30', 'http://sinalprivado.info:80/series/1533784/1533784/853152.mp4', 'http://gstaticontent.com/images/uIGmQgWGkkXkmylvdVQsdgb0Hnd_big.jpg'),
(19071, 1238, 'Jogos Sagrados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103191.mp4', 'http://gstaticontent.com/images/v68l72g8ycIt4t2sAfoUEoyvjJr_big.jpg'),
(19072, 1238, 'Jogos Sagrados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103192.mp4', 'http://gstaticontent.com/images/v68l72g8ycIt4t2sAfoUEoyvjJr_big.jpg'),
(19073, 1238, 'Jogos Sagrados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103193.mp4', 'http://gstaticontent.com/images/v68l72g8ycIt4t2sAfoUEoyvjJr_big.jpg'),
(19074, 1238, 'Jogos Sagrados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103194.mp4', 'http://gstaticontent.com/images/v68l72g8ycIt4t2sAfoUEoyvjJr_big.jpg'),
(19075, 1238, 'Jogos Sagrados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103195.mp4', 'http://gstaticontent.com/images/v68l72g8ycIt4t2sAfoUEoyvjJr_big.jpg'),
(19076, 1238, 'Jogos Sagrados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103196.mp4', 'http://gstaticontent.com/images/v68l72g8ycIt4t2sAfoUEoyvjJr_big.jpg'),
(19077, 1238, 'Jogos Sagrados S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103197.mp4', 'http://gstaticontent.com/images/v68l72g8ycIt4t2sAfoUEoyvjJr_big.jpg'),
(19078, 1238, 'Jogos Sagrados S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103198.mp4', 'http://gstaticontent.com/images/v68l72g8ycIt4t2sAfoUEoyvjJr_big.jpg'),
(19079, 1239, 'Jogos Sagrados S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103199.mp4', 'http://gstaticontent.com/images/v68l72g8ycIt4t2sAfoUEoyvjJr_big.jpg'),
(19080, 1239, 'Jogos Sagrados S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103200.mp4', 'http://gstaticontent.com/images/v68l72g8ycIt4t2sAfoUEoyvjJr_big.jpg'),
(19081, 1239, 'Jogos Sagrados S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103201.mp4', 'http://gstaticontent.com/images/v68l72g8ycIt4t2sAfoUEoyvjJr_big.jpg'),
(19082, 1239, 'Jogos Sagrados S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103202.mp4', 'http://gstaticontent.com/images/v68l72g8ycIt4t2sAfoUEoyvjJr_big.jpg'),
(19083, 1239, 'Jogos Sagrados S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103203.mp4', 'http://gstaticontent.com/images/v68l72g8ycIt4t2sAfoUEoyvjJr_big.jpg'),
(19084, 1239, 'Jogos Sagrados S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103204.mp4', 'http://gstaticontent.com/images/v68l72g8ycIt4t2sAfoUEoyvjJr_big.jpg'),
(19085, 1239, 'Jogos Sagrados S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103205.mp4', 'http://gstaticontent.com/images/v68l72g8ycIt4t2sAfoUEoyvjJr_big.jpg'),
(19086, 1239, 'Jogos Sagrados S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103206.mp4', 'http://gstaticontent.com/images/v68l72g8ycIt4t2sAfoUEoyvjJr_big.jpg'),
(19087, 1240, 'Mindhunter S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103172.mp4', 'http://gstaticontent.com/images/fbKE87mojpIETWepSbD5Qt741fp_big.jpg'),
(19088, 1240, 'Mindhunter S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103173.mp4', 'http://gstaticontent.com/images/fbKE87mojpIETWepSbD5Qt741fp_big.jpg'),
(19089, 1240, 'Mindhunter S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103174.mp4', 'http://gstaticontent.com/images/fbKE87mojpIETWepSbD5Qt741fp_big.jpg'),
(19090, 1240, 'Mindhunter S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103175.mp4', 'http://gstaticontent.com/images/fbKE87mojpIETWepSbD5Qt741fp_big.jpg'),
(19091, 1240, 'Mindhunter S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103176.mp4', 'http://gstaticontent.com/images/fbKE87mojpIETWepSbD5Qt741fp_big.jpg'),
(19092, 1240, 'Mindhunter S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103177.mp4', 'http://gstaticontent.com/images/fbKE87mojpIETWepSbD5Qt741fp_big.jpg'),
(19093, 1240, 'Mindhunter S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103178.mp4', 'http://gstaticontent.com/images/fbKE87mojpIETWepSbD5Qt741fp_big.jpg'),
(19094, 1240, 'Mindhunter S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103179.mp4', 'http://gstaticontent.com/images/fbKE87mojpIETWepSbD5Qt741fp_big.jpg'),
(19095, 1240, 'Mindhunter S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103180.mp4', 'http://gstaticontent.com/images/fbKE87mojpIETWepSbD5Qt741fp_big.jpg'),
(19096, 1240, 'Mindhunter S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103181.mp4', 'http://gstaticontent.com/images/fbKE87mojpIETWepSbD5Qt741fp_big.jpg'),
(19097, 1241, 'Mindhunter S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103182.mp4', 'http://gstaticontent.com/images/fbKE87mojpIETWepSbD5Qt741fp_big.jpg'),
(19098, 1241, 'Mindhunter S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103183.mp4', 'http://gstaticontent.com/images/fbKE87mojpIETWepSbD5Qt741fp_big.jpg'),
(19099, 1241, 'Mindhunter S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103184.mp4', 'http://gstaticontent.com/images/fbKE87mojpIETWepSbD5Qt741fp_big.jpg'),
(19100, 1241, 'Mindhunter S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103185.mp4', 'http://gstaticontent.com/images/fbKE87mojpIETWepSbD5Qt741fp_big.jpg'),
(19101, 1241, 'Mindhunter S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103186.mp4', 'http://gstaticontent.com/images/fbKE87mojpIETWepSbD5Qt741fp_big.jpg'),
(19102, 1241, 'Mindhunter S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103187.mp4', 'http://gstaticontent.com/images/fbKE87mojpIETWepSbD5Qt741fp_big.jpg'),
(19103, 1241, 'Mindhunter S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103188.mp4', 'http://gstaticontent.com/images/fbKE87mojpIETWepSbD5Qt741fp_big.jpg'),
(19104, 1241, 'Mindhunter S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103189.mp4', 'http://gstaticontent.com/images/fbKE87mojpIETWepSbD5Qt741fp_big.jpg'),
(19105, 1241, 'Mindhunter S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103190.mp4', 'http://gstaticontent.com/images/fbKE87mojpIETWepSbD5Qt741fp_big.jpg'),
(19106, 1242, 'The Act [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103164.mp4', 'http://gstaticontent.com/images/vb1sQLC2MqfCPOFqHd8SyVsyDVB_big.jpg'),
(19107, 1242, 'The Act [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103165.mp4', 'http://gstaticontent.com/images/vb1sQLC2MqfCPOFqHd8SyVsyDVB_big.jpg'),
(19108, 1242, 'The Act [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103166.mp4', 'http://gstaticontent.com/images/vb1sQLC2MqfCPOFqHd8SyVsyDVB_big.jpg'),
(19109, 1242, 'The Act [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103167.mp4', 'http://gstaticontent.com/images/vb1sQLC2MqfCPOFqHd8SyVsyDVB_big.jpg'),
(19110, 1242, 'The Act [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103168.mp4', 'http://gstaticontent.com/images/vb1sQLC2MqfCPOFqHd8SyVsyDVB_big.jpg'),
(19111, 1242, 'The Act [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103169.mp4', 'http://gstaticontent.com/images/vb1sQLC2MqfCPOFqHd8SyVsyDVB_big.jpg'),
(19112, 1242, 'The Act [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103170.mp4', 'http://gstaticontent.com/images/vb1sQLC2MqfCPOFqHd8SyVsyDVB_big.jpg'),
(19113, 1242, 'The Act [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103171.mp4', 'http://gstaticontent.com/images/vb1sQLC2MqfCPOFqHd8SyVsyDVB_big.jpg'),
(19114, 1243, 'A Garota do Blog S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103043.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19115, 1243, 'A Garota do Blog S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103044.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19116, 1243, 'A Garota do Blog S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103045.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19117, 1243, 'A Garota do Blog S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103046.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(19118, 1243, 'A Garota do Blog S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103047.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19119, 1243, 'A Garota do Blog S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103048.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19120, 1243, 'A Garota do Blog S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103049.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19121, 1243, 'A Garota do Blog S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103050.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19122, 1243, 'A Garota do Blog S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103051.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19123, 1243, 'A Garota do Blog S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103052.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19124, 1243, 'A Garota do Blog S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103053.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19125, 1243, 'A Garota do Blog S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103054.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19126, 1243, 'A Garota do Blog S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/103055.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19127, 1243, 'A Garota do Blog S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/103056.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19128, 1243, 'A Garota do Blog S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/103057.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19129, 1243, 'A Garota do Blog S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/103058.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19130, 1243, 'A Garota do Blog S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/103059.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19131, 1243, 'A Garota do Blog S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/103060.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19132, 1244, 'A Garota do Blog S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103061.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19133, 1244, 'A Garota do Blog S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103062.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19134, 1244, 'A Garota do Blog S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103063.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19135, 1244, 'A Garota do Blog S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103064.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19136, 1244, 'A Garota do Blog S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103065.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19137, 1244, 'A Garota do Blog S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103066.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19138, 1244, 'A Garota do Blog S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103067.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19139, 1244, 'A Garota do Blog S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103068.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19140, 1244, 'A Garota do Blog S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103069.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19141, 1244, 'A Garota do Blog S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103070.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19142, 1244, 'A Garota do Blog S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103071.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19143, 1244, 'A Garota do Blog S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103072.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19144, 1244, 'A Garota do Blog S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/103073.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19145, 1244, 'A Garota do Blog S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/103074.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19146, 1244, 'A Garota do Blog S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/103075.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19147, 1244, 'A Garota do Blog S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/103076.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19148, 1244, 'A Garota do Blog S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/103077.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19149, 1244, 'A Garota do Blog S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/103078.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19150, 1244, 'A Garota do Blog S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/103079.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19151, 1244, 'A Garota do Blog S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/103080.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19152, 1244, 'A Garota do Blog S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/103081.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19153, 1244, 'A Garota do Blog S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/103082.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19154, 1244, 'A Garota do Blog S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/103083.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19155, 1244, 'A Garota do Blog S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/103084.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19156, 1244, 'A Garota do Blog S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/103085.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19157, 1245, 'A Garota do Blog S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103086.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19158, 1245, 'A Garota do Blog S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103087.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19159, 1245, 'A Garota do Blog S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103088.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19160, 1245, 'A Garota do Blog S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103089.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19161, 1245, 'A Garota do Blog S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103090.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19162, 1245, 'A Garota do Blog S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103091.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19163, 1245, 'A Garota do Blog S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103092.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19164, 1245, 'A Garota do Blog S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103093.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19165, 1245, 'A Garota do Blog S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103094.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19166, 1245, 'A Garota do Blog S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103095.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19167, 1245, 'A Garota do Blog S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103096.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19168, 1245, 'A Garota do Blog S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103097.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19169, 1245, 'A Garota do Blog S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/103098.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19170, 1245, 'A Garota do Blog S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/103099.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19171, 1245, 'A Garota do Blog S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/103100.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19172, 1245, 'A Garota do Blog S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/103101.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19173, 1245, 'A Garota do Blog S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/103102.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19174, 1245, 'A Garota do Blog S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/103103.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19175, 1245, 'A Garota do Blog S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/103104.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19176, 1245, 'A Garota do Blog S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/103105.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19177, 1245, 'A Garota do Blog S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/103106.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19178, 1245, 'A Garota do Blog S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/103107.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19179, 1246, 'A Garota do Blog S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103108.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19180, 1246, 'A Garota do Blog S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103109.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19181, 1246, 'A Garota do Blog S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103110.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19182, 1246, 'A Garota do Blog S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103111.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19183, 1246, 'A Garota do Blog S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103112.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19184, 1246, 'A Garota do Blog S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103113.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19185, 1246, 'A Garota do Blog S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103114.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19186, 1246, 'A Garota do Blog S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103115.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19187, 1246, 'A Garota do Blog S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103116.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19188, 1246, 'A Garota do Blog S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103117.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19189, 1246, 'A Garota do Blog S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103118.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19190, 1246, 'A Garota do Blog S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103119.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19191, 1246, 'A Garota do Blog S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/103120.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19192, 1246, 'A Garota do Blog S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/103121.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19193, 1246, 'A Garota do Blog S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/103122.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19194, 1246, 'A Garota do Blog S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/103123.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19195, 1246, 'A Garota do Blog S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/103124.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19196, 1246, 'A Garota do Blog S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/103125.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19197, 1246, 'A Garota do Blog S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/103126.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19198, 1246, 'A Garota do Blog S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/103127.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19199, 1246, 'A Garota do Blog S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/103128.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19200, 1246, 'A Garota do Blog S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/103129.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19201, 1247, 'A Garota do Blog S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103130.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19202, 1247, 'A Garota do Blog S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103131.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19203, 1247, 'A Garota do Blog S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103132.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19204, 1247, 'A Garota do Blog S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103133.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19205, 1247, 'A Garota do Blog S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103134.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19206, 1247, 'A Garota do Blog S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103135.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19207, 1247, 'A Garota do Blog S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103136.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19208, 1247, 'A Garota do Blog S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103137.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19209, 1247, 'A Garota do Blog S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103138.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19210, 1247, 'A Garota do Blog S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103139.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19211, 1247, 'A Garota do Blog S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/103140.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19212, 1247, 'A Garota do Blog S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/103141.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19213, 1247, 'A Garota do Blog S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/103142.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19214, 1247, 'A Garota do Blog S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/103143.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19215, 1247, 'A Garota do Blog S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/103144.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19216, 1247, 'A Garota do Blog S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/103145.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19217, 1247, 'A Garota do Blog S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/103146.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19218, 1247, 'A Garota do Blog S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/103147.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19219, 1247, 'A Garota do Blog S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/103148.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19220, 1247, 'A Garota do Blog S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/103149.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19221, 1247, 'A Garota do Blog S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/103150.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19222, 1247, 'A Garota do Blog S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/103151.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19223, 1247, 'A Garota do Blog S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/103152.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19224, 1247, 'A Garota do Blog S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/103153.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19225, 1248, 'A Garota do Blog S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103154.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19226, 1248, 'A Garota do Blog S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103155.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19227, 1248, 'A Garota do Blog S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103156.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19228, 1248, 'A Garota do Blog S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103157.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19229, 1248, 'A Garota do Blog S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103158.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19230, 1248, 'A Garota do Blog S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103159.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19231, 1248, 'A Garota do Blog S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103160.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19232, 1248, 'A Garota do Blog S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103161.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19233, 1248, 'A Garota do Blog S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103162.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19234, 1248, 'A Garota do Blog S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103163.mp4', 'http://gstaticontent.com/images/fa00f155a88b1e1ec37e267e6db49255.jpg'),
(19235, 1249, 'Irmãos a Obra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191483.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19236, 1249, 'Irmãos a Obra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191484.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19237, 1249, 'Irmãos a Obra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191485.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19238, 1249, 'Irmãos a Obra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191486.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19239, 1249, 'Irmãos a Obra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191487.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19240, 1249, 'Irmãos a Obra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191488.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19241, 1249, 'Irmãos a Obra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191489.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19242, 1249, 'Irmãos a Obra S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191490.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19243, 1249, 'Irmãos a Obra S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191491.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19244, 1249, 'Irmãos a Obra S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191492.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19245, 1249, 'Irmãos a Obra S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191493.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19246, 1249, 'Irmãos a Obra S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/191494.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19247, 1250, 'Irmãos a Obra S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191495.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19248, 1250, 'Irmãos a Obra S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191496.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19249, 1250, 'Irmãos a Obra S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191497.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19250, 1250, 'Irmãos a Obra S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191498.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19251, 1250, 'Irmãos a Obra S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191499.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19252, 1250, 'Irmãos a Obra S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191500.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19253, 1250, 'Irmãos a Obra S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191501.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19254, 1250, 'Irmãos a Obra S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191502.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19255, 1250, 'Irmãos a Obra S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191503.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19256, 1250, 'Irmãos a Obra S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191504.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19257, 1250, 'Irmãos a Obra S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191505.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19258, 1250, 'Irmãos a Obra S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/191506.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19259, 1250, 'Irmãos a Obra S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/191507.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19260, 1250, 'Irmãos a Obra S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/191508.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19261, 1250, 'Irmãos a Obra S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/191509.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19262, 1250, 'Irmãos a Obra S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/191510.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19263, 1250, 'Irmãos a Obra S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/191511.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19264, 1250, 'Irmãos a Obra S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/191512.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19265, 1250, 'Irmãos a Obra S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/191513.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19266, 1250, 'Irmãos a Obra S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/191514.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19267, 1250, 'Irmãos a Obra S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/191515.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19268, 1250, 'Irmãos a Obra S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/191516.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19269, 1250, 'Irmãos a Obra S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/191517.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19270, 1250, 'Irmãos a Obra S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/191518.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19271, 1250, 'Irmãos a Obra S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/191519.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19272, 1250, 'Irmãos a Obra S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/191520.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19273, 1251, 'Irmãos a Obra S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191521.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19274, 1251, 'Irmãos a Obra S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191522.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19275, 1251, 'Irmãos a Obra S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191523.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19276, 1251, 'Irmãos a Obra S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191524.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19277, 1251, 'Irmãos a Obra S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191525.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19278, 1251, 'Irmãos a Obra S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191526.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19279, 1251, 'Irmãos a Obra S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191527.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19280, 1251, 'Irmãos a Obra S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191528.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19281, 1251, 'Irmãos a Obra S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191529.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19282, 1251, 'Irmãos a Obra S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191530.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19283, 1251, 'Irmãos a Obra S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191531.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19284, 1251, 'Irmãos a Obra S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/191532.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19285, 1251, 'Irmãos a Obra S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/191533.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19286, 1251, 'Irmãos a Obra S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/191534.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19287, 1251, 'Irmãos a Obra S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/191535.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19288, 1251, 'Irmãos a Obra S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/191536.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19289, 1251, 'Irmãos a Obra S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/191537.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19290, 1251, 'Irmãos a Obra S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/191538.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19291, 1251, 'Irmãos a Obra S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/191539.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19292, 1251, 'Irmãos a Obra S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/191540.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19293, 1251, 'Irmãos a Obra S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/191541.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19294, 1251, 'Irmãos a Obra S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/191542.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19295, 1251, 'Irmãos a Obra S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/191543.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19296, 1251, 'Irmãos a Obra S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/191544.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19297, 1251, 'Irmãos a Obra S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/191545.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19298, 1251, 'Irmãos a Obra S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/191546.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19299, 1252, 'Irmãos a Obra S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191547.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19300, 1252, 'Irmãos a Obra S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191548.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19301, 1252, 'Irmãos a Obra S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191549.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19302, 1252, 'Irmãos a Obra S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191550.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19303, 1252, 'Irmãos a Obra S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191551.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19304, 1252, 'Irmãos a Obra S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191552.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19305, 1252, 'Irmãos a Obra S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191553.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19306, 1252, 'Irmãos a Obra S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191554.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19307, 1252, 'Irmãos a Obra S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191555.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19308, 1252, 'Irmãos a Obra S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191556.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19309, 1252, 'Irmãos a Obra S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191557.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19310, 1252, 'Irmãos a Obra S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/191558.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19311, 1252, 'Irmãos a Obra S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/191559.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19312, 1252, 'Irmãos a Obra S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/191560.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19313, 1252, 'Irmãos a Obra S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/191561.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19314, 1252, 'Irmãos a Obra S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/191562.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19315, 1252, 'Irmãos a Obra S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/191563.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19316, 1252, 'Irmãos a Obra S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/191564.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19317, 1252, 'Irmãos a Obra S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/191565.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19318, 1252, 'Irmãos a Obra S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/191566.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19319, 1252, 'Irmãos a Obra S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/191567.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19320, 1252, 'Irmãos a Obra S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/191568.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19321, 1252, 'Irmãos a Obra S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/191569.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19322, 1252, 'Irmãos a Obra S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/191570.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19323, 1252, 'Irmãos a Obra S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/191571.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19324, 1253, 'Irmãos a Obra S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191572.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19325, 1253, 'Irmãos a Obra S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191573.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19326, 1253, 'Irmãos a Obra S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191574.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19327, 1253, 'Irmãos a Obra S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191575.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19328, 1253, 'Irmãos a Obra S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191576.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19329, 1253, 'Irmãos a Obra S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191577.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19330, 1253, 'Irmãos a Obra S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191578.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19331, 1253, 'Irmãos a Obra S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191579.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19332, 1253, 'Irmãos a Obra S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191580.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19333, 1253, 'Irmãos a Obra S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191581.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19334, 1253, 'Irmãos a Obra S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191582.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19335, 1253, 'Irmãos a Obra S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/191583.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19336, 1253, 'Irmãos a Obra S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/191584.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19337, 1253, 'Irmãos a Obra S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/191585.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19338, 1253, 'Irmãos a Obra S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/191586.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19339, 1253, 'Irmãos a Obra S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/191587.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19340, 1253, 'Irmãos a Obra S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/191588.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19341, 1253, 'Irmãos a Obra S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/191589.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19342, 1253, 'Irmãos a Obra S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/191590.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19343, 1253, 'Irmãos a Obra S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/191591.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19344, 1253, 'Irmãos a Obra S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/191592.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19345, 1253, 'Irmãos a Obra S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/191593.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19346, 1253, 'Irmãos a Obra S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/191594.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19347, 1253, 'Irmãos a Obra S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/191595.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19348, 1253, 'Irmãos a Obra S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/191596.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19349, 1253, 'Irmãos a Obra S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/191597.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19350, 1254, 'Irmãos a Obra S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191598.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19351, 1254, 'Irmãos a Obra S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191599.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19352, 1254, 'Irmãos a Obra S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191600.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19353, 1254, 'Irmãos a Obra S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191601.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19354, 1254, 'Irmãos a Obra S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191602.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19355, 1254, 'Irmãos a Obra S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191603.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19356, 1254, 'Irmãos a Obra S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191604.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19357, 1254, 'Irmãos a Obra S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191605.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19358, 1254, 'Irmãos a Obra S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191606.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19359, 1254, 'Irmãos a Obra S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191607.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19360, 1254, 'Irmãos a Obra S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191608.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19361, 1254, 'Irmãos a Obra S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/191609.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19362, 1254, 'Irmãos a Obra S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/191610.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19363, 1254, 'Irmãos a Obra S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/191611.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19364, 1254, 'Irmãos a Obra S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/191612.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19365, 1254, 'Irmãos a Obra S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/191613.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19366, 1254, 'Irmãos a Obra S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/191614.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19367, 1254, 'Irmãos a Obra S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/191615.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19368, 1254, 'Irmãos a Obra S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/191616.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19369, 1254, 'Irmãos a Obra S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/191617.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19370, 1254, 'Irmãos a Obra S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/191618.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19371, 1254, 'Irmãos a Obra S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/191619.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19372, 1254, 'Irmãos a Obra S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/191620.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19373, 1254, 'Irmãos a Obra S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/191621.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19374, 1254, 'Irmãos a Obra S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/191622.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19375, 1254, 'Irmãos a Obra S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/191623.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19376, 1255, 'Irmãos a Obra S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191624.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19377, 1255, 'Irmãos a Obra S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191625.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19378, 1255, 'Irmãos a Obra S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191626.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19379, 1255, 'Irmãos a Obra S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191627.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19380, 1255, 'Irmãos a Obra S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191628.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19381, 1255, 'Irmãos a Obra S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191629.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19382, 1255, 'Irmãos a Obra S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191630.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19383, 1255, 'Irmãos a Obra S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191631.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19384, 1255, 'Irmãos a Obra S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191632.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19385, 1255, 'Irmãos a Obra S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191633.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19386, 1255, 'Irmãos a Obra S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191634.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19387, 1255, 'Irmãos a Obra S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/191635.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19388, 1255, 'Irmãos a Obra S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/191636.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19389, 1255, 'Irmãos a Obra S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/191637.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19390, 1255, 'Irmãos a Obra S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/191638.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19391, 1255, 'Irmãos a Obra S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/191639.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19392, 1255, 'Irmãos a Obra S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/191640.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19393, 1255, 'Irmãos a Obra S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/191641.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19394, 1255, 'Irmãos a Obra S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/191642.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19395, 1255, 'Irmãos a Obra S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/191643.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19396, 1255, 'Irmãos a Obra S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/191644.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19397, 1255, 'Irmãos a Obra S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/191645.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19398, 1255, 'Irmãos a Obra S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/191646.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19399, 1255, 'Irmãos a Obra S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/191647.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19400, 1255, 'Irmãos a Obra S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/191648.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19401, 1255, 'Irmãos a Obra S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/191649.mp4', 'http://gstaticontent.com/images/TX1Db47fS1DF2QBiWAXsNq7kGd_big.jpg'),
(19402, 1256, 'Love Alarm S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140405.mp4', 'http://gstaticontent.com/images/ncJ7naaHoGabVHB4FriUXP9IW3t_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(19403, 1256, 'Love Alarm S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140406.mp4', 'http://gstaticontent.com/images/ncJ7naaHoGabVHB4FriUXP9IW3t_big.jpg'),
(19404, 1256, 'Love Alarm S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140407.mp4', 'http://gstaticontent.com/images/ncJ7naaHoGabVHB4FriUXP9IW3t_big.jpg'),
(19405, 1256, 'Love Alarm S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140408.mp4', 'http://gstaticontent.com/images/ncJ7naaHoGabVHB4FriUXP9IW3t_big.jpg'),
(19406, 1256, 'Love Alarm S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140409.mp4', 'http://gstaticontent.com/images/ncJ7naaHoGabVHB4FriUXP9IW3t_big.jpg'),
(19407, 1256, 'Love Alarm S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140410.mp4', 'http://gstaticontent.com/images/ncJ7naaHoGabVHB4FriUXP9IW3t_big.jpg'),
(19408, 1256, 'Love Alarm S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140411.mp4', 'http://gstaticontent.com/images/ncJ7naaHoGabVHB4FriUXP9IW3t_big.jpg'),
(19409, 1256, 'Love Alarm S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140412.mp4', 'http://gstaticontent.com/images/ncJ7naaHoGabVHB4FriUXP9IW3t_big.jpg'),
(19410, 1257, 'Love Alarm S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140413.mp4', 'http://gstaticontent.com/images/ncJ7naaHoGabVHB4FriUXP9IW3t_big.jpg'),
(19411, 1257, 'Love Alarm S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140414.mp4', 'http://gstaticontent.com/images/ncJ7naaHoGabVHB4FriUXP9IW3t_big.jpg'),
(19412, 1257, 'Love Alarm S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140415.mp4', 'http://gstaticontent.com/images/ncJ7naaHoGabVHB4FriUXP9IW3t_big.jpg'),
(19413, 1257, 'Love Alarm S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140416.mp4', 'http://gstaticontent.com/images/ncJ7naaHoGabVHB4FriUXP9IW3t_big.jpg'),
(19414, 1257, 'Love Alarm S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140417.mp4', 'http://gstaticontent.com/images/ncJ7naaHoGabVHB4FriUXP9IW3t_big.jpg'),
(19415, 1257, 'Love Alarm S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140418.mp4', 'http://gstaticontent.com/images/ncJ7naaHoGabVHB4FriUXP9IW3t_big.jpg'),
(19416, 1258, 'Somebody Feed Phil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103031.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19417, 1258, 'Somebody Feed Phil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103032.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19418, 1258, 'Somebody Feed Phil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103033.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19419, 1258, 'Somebody Feed Phil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103034.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19420, 1258, 'Somebody Feed Phil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103035.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19421, 1258, 'Somebody Feed Phil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103036.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19422, 1259, 'Somebody Feed Phil S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103037.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19423, 1259, 'Somebody Feed Phil S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103038.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19424, 1259, 'Somebody Feed Phil S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103039.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19425, 1259, 'Somebody Feed Phil S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103040.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19426, 1259, 'Somebody Feed Phil S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103041.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19427, 1259, 'Somebody Feed Phil S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103042.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19428, 1260, 'Somebody Feed Phil S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290529.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19429, 1260, 'Somebody Feed Phil S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290530.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19430, 1260, 'Somebody Feed Phil S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290531.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19431, 1260, 'Somebody Feed Phil S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290532.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19432, 1260, 'Somebody Feed Phil S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/290533.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19433, 1261, 'Somebody Feed Phil S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290534.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19434, 1261, 'Somebody Feed Phil S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290535.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19435, 1261, 'Somebody Feed Phil S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290536.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19436, 1261, 'Somebody Feed Phil S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290537.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19437, 1261, 'Somebody Feed Phil S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/290538.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19438, 1262, 'Somebody Feed Phil S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290539.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19439, 1262, 'Somebody Feed Phil S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290540.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19440, 1262, 'Somebody Feed Phil S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290541.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19441, 1262, 'Somebody Feed Phil S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290542.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19442, 1262, 'Somebody Feed Phil S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/290543.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19443, 1263, 'Somebody Feed Phil S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290544.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19444, 1263, 'Somebody Feed Phil S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290545.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19445, 1263, 'Somebody Feed Phil S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290546.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19446, 1263, 'Somebody Feed Phil S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290547.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19447, 1263, 'Somebody Feed Phil S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/290548.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19448, 1263, 'Somebody Feed Phil S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/290549.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19449, 1264, 'Somebody Feed Phil S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290550.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19450, 1264, 'Somebody Feed Phil S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290551.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19451, 1264, 'Somebody Feed Phil S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290552.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19452, 1264, 'Somebody Feed Phil S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290553.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19453, 1264, 'Somebody Feed Phil S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/290554.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19454, 1264, 'Somebody Feed Phil S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/290555.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19455, 1264, 'Somebody Feed Phil S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/290556.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19456, 1264, 'Somebody Feed Phil S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/290557.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19457, 1265, 'Somebody Feed Phil S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/847044.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19458, 1265, 'Somebody Feed Phil S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/847045.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19459, 1265, 'Somebody Feed Phil S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/847046.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19460, 1265, 'Somebody Feed Phil S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/847047.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19461, 1265, 'Somebody Feed Phil S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/847048.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19462, 1265, 'Somebody Feed Phil S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/847049.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19463, 1265, 'Somebody Feed Phil S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/847050.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19464, 1265, 'Somebody Feed Phil S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/847051.mp4', 'http://gstaticontent.com/images/pgIIJXnGHG62POiGnn4BXNTG0eG_big.jpg'),
(19465, 1266, 'Final Space S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106730.mp4', 'http://gstaticontent.com/images/zT6tXWsJoBOWJT1PeUEKLTFOoHh_big.jpg'),
(19466, 1266, 'Final Space S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106731.mp4', 'http://gstaticontent.com/images/zT6tXWsJoBOWJT1PeUEKLTFOoHh_big.jpg'),
(19467, 1266, 'Final Space S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106732.mp4', 'http://gstaticontent.com/images/zT6tXWsJoBOWJT1PeUEKLTFOoHh_big.jpg'),
(19468, 1266, 'Final Space S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106733.mp4', 'http://gstaticontent.com/images/zT6tXWsJoBOWJT1PeUEKLTFOoHh_big.jpg'),
(19469, 1266, 'Final Space S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106734.mp4', 'http://gstaticontent.com/images/zT6tXWsJoBOWJT1PeUEKLTFOoHh_big.jpg'),
(19470, 1266, 'Final Space S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106735.mp4', 'http://gstaticontent.com/images/zT6tXWsJoBOWJT1PeUEKLTFOoHh_big.jpg'),
(19471, 1266, 'Final Space S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106736.mp4', 'http://gstaticontent.com/images/zT6tXWsJoBOWJT1PeUEKLTFOoHh_big.jpg'),
(19472, 1266, 'Final Space S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106737.mp4', 'http://gstaticontent.com/images/zT6tXWsJoBOWJT1PeUEKLTFOoHh_big.jpg'),
(19473, 1266, 'Final Space S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106738.mp4', 'http://gstaticontent.com/images/zT6tXWsJoBOWJT1PeUEKLTFOoHh_big.jpg'),
(19474, 1266, 'Final Space S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106739.mp4', 'http://gstaticontent.com/images/zT6tXWsJoBOWJT1PeUEKLTFOoHh_big.jpg'),
(19475, 1267, 'Final Space S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106740.mp4', 'http://timg.bdta.pro/images/873a9145e371340a9cfc596c42dcdd0e.jpg'),
(19476, 1267, 'Final Space S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106741.mp4', 'http://timg.bdta.pro/images/342ddf3239d78b6732a8a48c3228215e.jpg'),
(19477, 1267, 'Final Space S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106742.mp4', 'http://timg.bdta.pro/images/f9fe1ae1feb4d3c3b52b8154be881ae2.jpg'),
(19478, 1267, 'Final Space S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106743.mp4', 'http://timg.bdta.pro/images/06c17a189f6f02be4f6b8662326623ba.jpg'),
(19479, 1267, 'Final Space S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106744.mp4', 'http://timg.bdta.pro/images/c91ad34d335ac63264fbcb49e7ff2728.jpg'),
(19480, 1267, 'Final Space S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106745.mp4', 'http://timg.bdta.pro/images/039467c6e0bc2761c895d9d7cdf8708f.jpg'),
(19481, 1267, 'Final Space S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106746.mp4', 'http://timg.bdta.pro/images/4f72454c6b9a342fa7adebe1fa457308.jpg'),
(19482, 1267, 'Final Space S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106747.mp4', 'http://timg.bdta.pro/images/895e900ffb7edd6164994c520c6f6dd1.jpg'),
(19483, 1267, 'Final Space S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106748.mp4', 'http://timg.bdta.pro/images/ad30785fffdf08598b1e8c776a0c6959.jpg'),
(19484, 1267, 'Final Space S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106749.mp4', 'http://timg.bdta.pro/images/99ece09628cb26246e676c001cccb902.jpg'),
(19485, 1267, 'Final Space S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106750.mp4', 'http://timg.bdta.pro/images/d3f0a8e0cd14661c2ea26e4f445a00be.jpg'),
(19486, 1267, 'Final Space S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/106751.mp4', 'http://timg.bdta.pro/images/ea502d471327aa26b84612601b14b873.jpg'),
(19487, 1267, 'Final Space S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/106752.mp4', 'http://gstaticontent.com/images/zT6tXWsJoBOWJT1PeUEKLTFOoHh_big.jpg'),
(19488, 1268, 'The Rookie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248505.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19489, 1268, 'The Rookie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248506.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19490, 1268, 'The Rookie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248507.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19491, 1268, 'The Rookie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248508.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19492, 1268, 'The Rookie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248509.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19493, 1268, 'The Rookie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248510.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19494, 1268, 'The Rookie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248511.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19495, 1268, 'The Rookie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248512.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19496, 1268, 'The Rookie S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248513.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19497, 1268, 'The Rookie S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248514.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19498, 1268, 'The Rookie S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248515.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19499, 1268, 'The Rookie S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248516.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19500, 1268, 'The Rookie S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248517.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19501, 1268, 'The Rookie S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/248518.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19502, 1268, 'The Rookie S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/248519.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19503, 1268, 'The Rookie S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/248520.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19504, 1268, 'The Rookie S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/248521.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19505, 1268, 'The Rookie S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/248522.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19506, 1268, 'The Rookie S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/248523.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19507, 1268, 'The Rookie S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/248524.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19508, 1269, 'The Rookie S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248525.mp4', 'http://timg.bdta.pro/images/5dd15a56c290036f64c278f22b73c531.jpg'),
(19509, 1269, 'The Rookie S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248526.mp4', 'http://timg.bdta.pro/images/21bc52825fcb206eaeebfc00ab648778.jpg'),
(19510, 1269, 'The Rookie S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248527.mp4', 'http://timg.bdta.pro/images/a1341d43778b6777e373692c50f6a287.jpg'),
(19511, 1269, 'The Rookie S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248528.mp4', 'http://timg.bdta.pro/images/e294462b64002670ccd29ec5d1902ee1.jpg'),
(19512, 1269, 'The Rookie S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248529.mp4', 'http://timg.bdta.pro/images/255fb8fd7cc79831f18668805143d303.jpg'),
(19513, 1269, 'The Rookie S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248530.mp4', 'http://timg.bdta.pro/images/03f9d222bd58670fedbf364aabe50805.jpg'),
(19514, 1269, 'The Rookie S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248531.mp4', 'http://timg.bdta.pro/images/0ae084fcf3eeb3a07bd91f980dcd9948.jpg'),
(19515, 1269, 'The Rookie S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248532.mp4', 'http://timg.bdta.pro/images/34a11b8b2615607ba7ebf170228c3413.jpg'),
(19516, 1269, 'The Rookie S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248533.mp4', 'http://timg.bdta.pro/images/886a8b728182f590cb34b7b17259f4fc.jpg'),
(19517, 1269, 'The Rookie S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248534.mp4', 'http://timg.bdta.pro/images/aa3b78350f70ba3783e056c5a944c80e.jpg'),
(19518, 1269, 'The Rookie S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248535.mp4', 'http://timg.bdta.pro/images/ab7fe7f4056afa85cf2608822b3b45fc.jpg'),
(19519, 1269, 'The Rookie S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248536.mp4', 'http://timg.bdta.pro/images/9ed8b96604144580747316e1e2c8814e.jpg'),
(19520, 1269, 'The Rookie S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248537.mp4', 'http://timg.bdta.pro/images/e44297334efa0f1bc1a898cce707f8aa.jpg'),
(19521, 1269, 'The Rookie S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/248538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oGT9dkA7dckWQdBuMGMXhnCv3k2.jpg'),
(19522, 1269, 'The Rookie S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/248539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDT3ykGiF6KB0sazNvxtAU2ZkPZ.jpg'),
(19523, 1269, 'The Rookie S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/248540.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19524, 1269, 'The Rookie S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/248541.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19525, 1269, 'The Rookie S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/248542.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19526, 1269, 'The Rookie S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/248543.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19527, 1269, 'The Rookie S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/248544.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19528, 1270, 'The Rookie S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248545.mp4', 'http://timg.bdta.pro/images/f79425f5f06c9aaebf408e630d0e2a42.jpg'),
(19529, 1270, 'The Rookie S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248546.mp4', 'http://timg.bdta.pro/images/8f0cf6105ef15aa930d386a2897945ad.jpg'),
(19530, 1270, 'The Rookie S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248547.mp4', 'http://timg.bdta.pro/images/8c596bfa5d495b07bd747f1c1a0dcb19.jpg'),
(19531, 1270, 'The Rookie S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248548.mp4', 'http://timg.bdta.pro/images/a8279aed9d51b5f685764f8c465f5888.jpg'),
(19532, 1270, 'The Rookie S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248549.mp4', 'http://timg.bdta.pro/images/9f52ddae390913ae2dad16039a1c2898.jpg'),
(19533, 1270, 'The Rookie S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248550.mp4', 'http://timg.bdta.pro/images/09601568826ade4aebcf1a7b2445e404.jpg'),
(19534, 1270, 'The Rookie S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248551.mp4', 'http://image.tmdb.org/t/p/w1280/6J4UTvKrPpEC9CSJP8vUKdNpK4o.jpg'),
(19535, 1270, 'The Rookie S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248552.mp4', 'http://image.tmdb.org/t/p/w1280/5z05FOcANCgPPJaqhYenc9RMVH1.jpg'),
(19536, 1270, 'The Rookie S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248553.mp4', 'http://image.tmdb.org/t/p/w1280/lunLrX7aVNhtcXQlpKR68CsWlhx.jpg'),
(19537, 1270, 'The Rookie S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248554.mp4', 'http://image.tmdb.org/t/p/w1280/lWvHCnlC0GBCEmxCapdzXSu6d8.jpg'),
(19538, 1270, 'The Rookie S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248555.mp4', 'http://image.tmdb.org/t/p/w1280/4xwPqSnOijTSOH5z4sBfLfAjYg4.jpg'),
(19539, 1270, 'The Rookie S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l3OxZIRvlFhzOwzEZKBqWBstvON.jpg'),
(19540, 1270, 'The Rookie S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2AYUayLhx2c0echVMu7E9sqMkq1.jpg'),
(19541, 1270, 'The Rookie S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/248558.mp4', 'http://image.tmdb.org/t/p/w1280/hK2tj9qwUMPntWY2R7QP3X4TpoU.jpg'),
(19542, 1271, 'The Rookie S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248559.mp4', 'http://timg.bdta.pro/images/a9c308e74e980c896176c88c2d641c78.jpg'),
(19543, 1271, 'The Rookie S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248560.mp4', 'http://timg.bdta.pro/images/c94fc9d88efc8ba1da07700a73804532.jpg'),
(19544, 1271, 'The Rookie S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248561.mp4', 'http://timg.bdta.pro/images/646ebd670cfe2708adb6fedaa23be1d8.jpg'),
(19545, 1271, 'The Rookie S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248562.mp4', 'http://timg.bdta.pro/images/37de518482ca8a5eb5195f56d10b8cf1.jpg'),
(19546, 1271, 'The Rookie S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248563.mp4', 'http://timg.bdta.pro/images/2972dea84af5704df73269af3e4bc5ba.jpg'),
(19547, 1271, 'The Rookie S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248564.mp4', 'http://timg.bdta.pro/images/16c4b68e3ffb645b314103312147eec0.jpg'),
(19548, 1271, 'The Rookie S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248565.mp4', 'http://timg.bdta.pro/images/c34eb8e517a837b53aa676ed63952eda.jpg'),
(19549, 1271, 'The Rookie S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248566.mp4', 'http://timg.bdta.pro/images/1bfa66c0ea424b10414a6770e158fab4.jpg'),
(19550, 1271, 'The Rookie S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248567.mp4', 'http://timg.bdta.pro/images/d7cba786464993683139d4b102031925.jpg'),
(19551, 1271, 'The Rookie S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248568.mp4', 'http://timg.bdta.pro/images/cab641b63c5c7e9e466c5e09dc145fa9.jpg'),
(19552, 1271, 'The Rookie S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248569.mp4', 'http://timg.bdta.pro/images/bad50743fbcc5ebd2db2ad174101cf5d.jpg'),
(19553, 1271, 'The Rookie S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248570.mp4', 'http://timg.bdta.pro/images/d057cdb1dd681b152f4a7ed90d5837e9.jpg'),
(19554, 1271, 'The Rookie S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248571.mp4', 'http://timg.bdta.pro/images/9bc642e21387c2ab69b669fab58b262f.jpg'),
(19555, 1271, 'The Rookie S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/248572.mp4', 'http://timg.bdta.pro/images/38997725ca84ca00df3c37c6e0605094.jpg'),
(19556, 1271, 'The Rookie S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/248573.mp4', 'http://timg.bdta.pro/images/500f42c368280f97088bce5953c9c6ca.jpg'),
(19557, 1271, 'The Rookie S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/248574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/12f4OISm5KWFaFdTVoRQ8DyFALy.jpg'),
(19558, 1271, 'The Rookie S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/248575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eEIeUk8391XEryUQE3MHH2C2DR8.jpg'),
(19559, 1271, 'The Rookie S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/248576.mp4', 'http://image.tmdb.org/t/p/w1280/5DtXCemNww3FmBNTfQBuOVeaUKZ.jpg'),
(19560, 1271, 'The Rookie S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/248577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ZZXWahNMOWpk3qBzbK7YpUQKw2.jpg'),
(19561, 1271, 'The Rookie S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/248578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9IZlJV7Ksm4fFKLqrqBiDZtTMvN.jpg'),
(19562, 1271, 'The Rookie S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/248579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wq3SIpUoZnlMz014HY4I8pqRoqo.jpg'),
(19563, 1271, 'The Rookie S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/248580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/85nJxRvmny8LfoSGKcOyniXDDla.jpg'),
(19564, 1272, 'The Rookie S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248581.mp4', 'http://image.tmdb.org/t/p/w1280/ahVj4nzgMgQYTyfOh8iopcdXCnl.jpg'),
(19565, 1272, 'The Rookie S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248582.mp4', 'http://image.tmdb.org/t/p/w1280/suffC65r34IqtNK1D2y3RP8ulSt.jpg'),
(19566, 1272, 'The Rookie S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248583.mp4', 'http://image.tmdb.org/t/p/w1280/empgv75ak0w9FqAGanTtAQMkzlk.jpg'),
(19567, 1272, 'The Rookie S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248584.mp4', 'http://image.tmdb.org/t/p/w1280/tUT0ZdnMgd5rWp7jAyoqTdrJram.jpg'),
(19568, 1272, 'The Rookie S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248585.mp4', 'http://image.tmdb.org/t/p/w1280/9b8Gz1y7t2WZq6lpXjaJ1U071Hh.jpg'),
(19569, 1272, 'The Rookie S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248586.mp4', 'http://image.tmdb.org/t/p/w1280/kjb5UtqxUF4lDiaOeIqHBURN6PR.jpg'),
(19570, 1272, 'The Rookie S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248587.mp4', 'http://image.tmdb.org/t/p/w1280/wXUwbSOUMYtXso9nv8SLa58CgId.jpg'),
(19571, 1272, 'The Rookie S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248588.mp4', 'http://image.tmdb.org/t/p/w1280/oj6C0S79kyy2gT73jVxjTvEQU6D.jpg'),
(19572, 1272, 'The Rookie S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248589.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19573, 1272, 'The Rookie S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248590.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19574, 1272, 'The Rookie S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248591.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19575, 1272, 'The Rookie S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248592.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19576, 1272, 'The Rookie S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248593.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19577, 1272, 'The Rookie S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/248594.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19578, 1272, 'The Rookie S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/248595.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19579, 1272, 'The Rookie S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/248596.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19580, 1272, 'The Rookie S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/248597.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19581, 1272, 'The Rookie S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/248598.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19582, 1272, 'The Rookie S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/248599.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19583, 1272, 'The Rookie S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/248600.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19584, 1272, 'The Rookie S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/248601.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19585, 1272, 'The Rookie S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/248602.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19586, 1273, 'The Rookie S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/428580.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19587, 1273, 'The Rookie S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438600.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19588, 1273, 'The Rookie S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440771.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19589, 1273, 'The Rookie S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449918.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19590, 1273, 'The Rookie S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/454197.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19591, 1273, 'The Rookie S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/458890.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19592, 1273, 'The Rookie S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/463604.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19593, 1273, 'The Rookie S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/469132.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19594, 1273, 'The Rookie S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/480869.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19595, 1273, 'The Rookie S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/480870.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19596, 1274, 'The Rookie S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/726088.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19597, 1274, 'The Rookie S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/732115.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19598, 1274, 'The Rookie S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/740966.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19599, 1274, 'The Rookie S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/753391.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19600, 1274, 'The Rookie S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/763186.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19601, 1274, 'The Rookie S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/771621.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19602, 1274, 'The Rookie S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/778500.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19603, 1274, 'The Rookie S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/786492.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19604, 1274, 'The Rookie S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/811332.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19605, 1274, 'The Rookie S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/811333.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19606, 1274, 'The Rookie S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/811334.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19607, 1274, 'The Rookie S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/820336.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19608, 1274, 'The Rookie S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/823375.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19609, 1274, 'The Rookie S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/835120.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19610, 1274, 'The Rookie S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/844210.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19611, 1274, 'The Rookie S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/850026.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19612, 1274, 'The Rookie S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/863783.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19613, 1274, 'The Rookie S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/863784.mp4', 'http://gstaticontent.com/images/arPUIveaNTdlZeSrOPrgof6UvhQ_big.jpg'),
(19614, 1275, 'Hyperdrive S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/103021.mp4', 'http://gstaticontent.com/images/g3tIsbySSQj9GnDjhAAW7p5DmLU_big.jpg'),
(19615, 1275, 'Hyperdrive S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/103022.mp4', 'http://gstaticontent.com/images/g3tIsbySSQj9GnDjhAAW7p5DmLU_big.jpg'),
(19616, 1275, 'Hyperdrive S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/103023.mp4', 'http://gstaticontent.com/images/g3tIsbySSQj9GnDjhAAW7p5DmLU_big.jpg'),
(19617, 1275, 'Hyperdrive S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/103024.mp4', 'http://gstaticontent.com/images/g3tIsbySSQj9GnDjhAAW7p5DmLU_big.jpg'),
(19618, 1275, 'Hyperdrive S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/103025.mp4', 'http://gstaticontent.com/images/g3tIsbySSQj9GnDjhAAW7p5DmLU_big.jpg'),
(19619, 1275, 'Hyperdrive S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/103026.mp4', 'http://gstaticontent.com/images/g3tIsbySSQj9GnDjhAAW7p5DmLU_big.jpg'),
(19620, 1275, 'Hyperdrive S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/103027.mp4', 'http://gstaticontent.com/images/g3tIsbySSQj9GnDjhAAW7p5DmLU_big.jpg'),
(19621, 1275, 'Hyperdrive S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/103028.mp4', 'http://gstaticontent.com/images/g3tIsbySSQj9GnDjhAAW7p5DmLU_big.jpg'),
(19622, 1275, 'Hyperdrive S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/103029.mp4', 'http://gstaticontent.com/images/g3tIsbySSQj9GnDjhAAW7p5DmLU_big.jpg'),
(19623, 1275, 'Hyperdrive S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/103030.mp4', 'http://gstaticontent.com/images/g3tIsbySSQj9GnDjhAAW7p5DmLU_big.jpg'),
(19624, 1276, 'Rio Heroes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102896.mp4', 'http://gstaticontent.com/images/6QqB9WxeV9htZTr4LQ9VThIrUNh_big.jpg'),
(19625, 1276, 'Rio Heroes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102897.mp4', 'http://gstaticontent.com/images/6QqB9WxeV9htZTr4LQ9VThIrUNh_big.jpg'),
(19626, 1276, 'Rio Heroes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102898.mp4', 'http://gstaticontent.com/images/6QqB9WxeV9htZTr4LQ9VThIrUNh_big.jpg'),
(19627, 1276, 'Rio Heroes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102899.mp4', 'http://gstaticontent.com/images/6QqB9WxeV9htZTr4LQ9VThIrUNh_big.jpg'),
(19628, 1276, 'Rio Heroes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102900.mp4', 'http://gstaticontent.com/images/6QqB9WxeV9htZTr4LQ9VThIrUNh_big.jpg'),
(19629, 1277, 'Workin Moms S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102870.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19630, 1277, 'Workin Moms S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102871.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19631, 1277, 'Workin Moms S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102872.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19632, 1277, 'Workin Moms S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102873.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19633, 1277, 'Workin Moms S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102874.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19634, 1277, 'Workin Moms S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102875.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19635, 1277, 'Workin Moms S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102876.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19636, 1277, 'Workin Moms S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102877.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19637, 1277, 'Workin Moms S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102878.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19638, 1277, 'Workin Moms S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102879.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19639, 1277, 'Workin Moms S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102880.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19640, 1277, 'Workin Moms S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102881.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19641, 1277, 'Workin Moms S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102882.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19642, 1278, 'Workin Moms S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102883.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19643, 1278, 'Workin Moms S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102884.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19644, 1278, 'Workin Moms S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102885.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19645, 1278, 'Workin Moms S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102886.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19646, 1278, 'Workin Moms S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102887.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19647, 1278, 'Workin Moms S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102888.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19648, 1278, 'Workin Moms S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102889.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19649, 1278, 'Workin Moms S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102890.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19650, 1278, 'Workin Moms S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102891.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19651, 1278, 'Workin Moms S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102892.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19652, 1278, 'Workin Moms S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102893.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19653, 1278, 'Workin Moms S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102894.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19654, 1278, 'Workin Moms S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102895.mp4', 'http://gstaticontent.com/images/tUfiXSF6jPhs3BIpHqinhM3CSnf_big.jpg'),
(19655, 1279, 'Disjointed S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102850.mp4', 'http://gstaticontent.com/images/gMVzoGfyFNew1RTn4UaMjn3iHCT_big.jpg'),
(19656, 1279, 'Disjointed S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102851.mp4', 'http://gstaticontent.com/images/gMVzoGfyFNew1RTn4UaMjn3iHCT_big.jpg'),
(19657, 1279, 'Disjointed S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102852.mp4', 'http://gstaticontent.com/images/gMVzoGfyFNew1RTn4UaMjn3iHCT_big.jpg'),
(19658, 1279, 'Disjointed S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102853.mp4', 'http://gstaticontent.com/images/gMVzoGfyFNew1RTn4UaMjn3iHCT_big.jpg'),
(19659, 1279, 'Disjointed S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102854.mp4', 'http://gstaticontent.com/images/gMVzoGfyFNew1RTn4UaMjn3iHCT_big.jpg'),
(19660, 1279, 'Disjointed S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102855.mp4', 'http://gstaticontent.com/images/gMVzoGfyFNew1RTn4UaMjn3iHCT_big.jpg'),
(19661, 1279, 'Disjointed S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102856.mp4', 'http://gstaticontent.com/images/gMVzoGfyFNew1RTn4UaMjn3iHCT_big.jpg'),
(19662, 1279, 'Disjointed S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102857.mp4', 'http://gstaticontent.com/images/gMVzoGfyFNew1RTn4UaMjn3iHCT_big.jpg'),
(19663, 1279, 'Disjointed S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102858.mp4', 'http://gstaticontent.com/images/gMVzoGfyFNew1RTn4UaMjn3iHCT_big.jpg'),
(19664, 1279, 'Disjointed S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102859.mp4', 'http://gstaticontent.com/images/gMVzoGfyFNew1RTn4UaMjn3iHCT_big.jpg'),
(19665, 1279, 'Disjointed S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102860.mp4', 'http://gstaticontent.com/images/gMVzoGfyFNew1RTn4UaMjn3iHCT_big.jpg'),
(19666, 1279, 'Disjointed S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102861.mp4', 'http://gstaticontent.com/images/gMVzoGfyFNew1RTn4UaMjn3iHCT_big.jpg'),
(19667, 1279, 'Disjointed S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102862.mp4', 'http://gstaticontent.com/images/gMVzoGfyFNew1RTn4UaMjn3iHCT_big.jpg'),
(19668, 1279, 'Disjointed S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/102863.mp4', 'http://gstaticontent.com/images/gMVzoGfyFNew1RTn4UaMjn3iHCT_big.jpg'),
(19669, 1279, 'Disjointed S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/102864.mp4', 'http://gstaticontent.com/images/gMVzoGfyFNew1RTn4UaMjn3iHCT_big.jpg'),
(19670, 1279, 'Disjointed S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/102865.mp4', 'http://gstaticontent.com/images/gMVzoGfyFNew1RTn4UaMjn3iHCT_big.jpg'),
(19671, 1279, 'Disjointed S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/102866.mp4', 'http://gstaticontent.com/images/gMVzoGfyFNew1RTn4UaMjn3iHCT_big.jpg'),
(19672, 1279, 'Disjointed S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/102867.mp4', 'http://gstaticontent.com/images/gMVzoGfyFNew1RTn4UaMjn3iHCT_big.jpg'),
(19673, 1279, 'Disjointed S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/102868.mp4', 'http://gstaticontent.com/images/gMVzoGfyFNew1RTn4UaMjn3iHCT_big.jpg'),
(19674, 1279, 'Disjointed S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/102869.mp4', 'http://gstaticontent.com/images/gMVzoGfyFNew1RTn4UaMjn3iHCT_big.jpg'),
(19675, 1280, 'Fastest Car S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114972.mp4', 'http://gstaticontent.com/images/6nDW5jb7G1TN4S7zviZDvhbyx0f_big.jpg'),
(19676, 1280, 'Fastest Car S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114973.mp4', 'http://gstaticontent.com/images/6nDW5jb7G1TN4S7zviZDvhbyx0f_big.jpg'),
(19677, 1280, 'Fastest Car S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114974.mp4', 'http://gstaticontent.com/images/6nDW5jb7G1TN4S7zviZDvhbyx0f_big.jpg'),
(19678, 1280, 'Fastest Car S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114975.mp4', 'http://gstaticontent.com/images/6nDW5jb7G1TN4S7zviZDvhbyx0f_big.jpg'),
(19679, 1280, 'Fastest Car S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114976.mp4', 'http://gstaticontent.com/images/6nDW5jb7G1TN4S7zviZDvhbyx0f_big.jpg'),
(19680, 1280, 'Fastest Car S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114977.mp4', 'http://gstaticontent.com/images/6nDW5jb7G1TN4S7zviZDvhbyx0f_big.jpg'),
(19681, 1280, 'Fastest Car S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114978.mp4', 'http://gstaticontent.com/images/6nDW5jb7G1TN4S7zviZDvhbyx0f_big.jpg'),
(19682, 1280, 'Fastest Car S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114979.mp4', 'http://gstaticontent.com/images/6nDW5jb7G1TN4S7zviZDvhbyx0f_big.jpg'),
(19683, 1281, 'Fastest Car S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114980.mp4', 'http://timg.bdta.pro/images/2dbe2e48c178c2a8ffcd8fda05efa8b7.jpg'),
(19684, 1281, 'Fastest Car S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114981.mp4', 'http://timg.bdta.pro/images/f1aba6d92023adbe5974a900c10abd33.jpg'),
(19685, 1281, 'Fastest Car S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114982.mp4', 'http://timg.bdta.pro/images/c8de3c9ed852d8b4049a6813afb4b7f0.jpg'),
(19686, 1281, 'Fastest Car S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114983.mp4', 'http://timg.bdta.pro/images/7dde8066902ed244c618220013825b55.jpg'),
(19687, 1281, 'Fastest Car S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114984.mp4', 'http://timg.bdta.pro/images/598cafe289a17134f2084b8054e45a38.jpg'),
(19688, 1281, 'Fastest Car S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114985.mp4', 'http://timg.bdta.pro/images/c5a307df0d80dfbae78f2401bcae7b4b.jpg'),
(19689, 1281, 'Fastest Car S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114986.mp4', 'http://timg.bdta.pro/images/f5a827f5c703876742d7a4f8ddb4aee9.jpg'),
(19690, 1282, 'Succession S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219342.mp4', 'http://gstaticontent.com/images/z0XiwdrCQ9yVIr4O0pxzaAYRxdW_big.jpg'),
(19691, 1282, 'Succession S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219343.mp4', 'http://gstaticontent.com/images/z0XiwdrCQ9yVIr4O0pxzaAYRxdW_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(19692, 1282, 'Succession S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219344.mp4', 'http://gstaticontent.com/images/z0XiwdrCQ9yVIr4O0pxzaAYRxdW_big.jpg'),
(19693, 1282, 'Succession S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219345.mp4', 'http://gstaticontent.com/images/z0XiwdrCQ9yVIr4O0pxzaAYRxdW_big.jpg'),
(19694, 1282, 'Succession S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219346.mp4', 'http://gstaticontent.com/images/z0XiwdrCQ9yVIr4O0pxzaAYRxdW_big.jpg'),
(19695, 1282, 'Succession S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219347.mp4', 'http://gstaticontent.com/images/z0XiwdrCQ9yVIr4O0pxzaAYRxdW_big.jpg'),
(19696, 1282, 'Succession S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219348.mp4', 'http://gstaticontent.com/images/z0XiwdrCQ9yVIr4O0pxzaAYRxdW_big.jpg'),
(19697, 1282, 'Succession S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219349.mp4', 'http://gstaticontent.com/images/z0XiwdrCQ9yVIr4O0pxzaAYRxdW_big.jpg'),
(19698, 1282, 'Succession S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219350.mp4', 'http://gstaticontent.com/images/z0XiwdrCQ9yVIr4O0pxzaAYRxdW_big.jpg'),
(19699, 1282, 'Succession S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219351.mp4', 'http://gstaticontent.com/images/z0XiwdrCQ9yVIr4O0pxzaAYRxdW_big.jpg'),
(19700, 1283, 'Succession S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219352.mp4', 'http://gstaticontent.com/images/z0XiwdrCQ9yVIr4O0pxzaAYRxdW_big.jpg'),
(19701, 1283, 'Succession S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219353.mp4', 'http://gstaticontent.com/images/z0XiwdrCQ9yVIr4O0pxzaAYRxdW_big.jpg'),
(19702, 1283, 'Succession S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219354.mp4', 'http://gstaticontent.com/images/z0XiwdrCQ9yVIr4O0pxzaAYRxdW_big.jpg'),
(19703, 1283, 'Succession S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219355.mp4', 'http://gstaticontent.com/images/z0XiwdrCQ9yVIr4O0pxzaAYRxdW_big.jpg'),
(19704, 1283, 'Succession S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219356.mp4', 'http://gstaticontent.com/images/z0XiwdrCQ9yVIr4O0pxzaAYRxdW_big.jpg'),
(19705, 1283, 'Succession S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219357.mp4', 'http://timg.bdta.pro/images/09b6531db24332bee839539bd020d603.jpg'),
(19706, 1283, 'Succession S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219358.mp4', 'http://timg.bdta.pro/images/ad23e545425fdfc2831957e2c6be99b3.jpg'),
(19707, 1283, 'Succession S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219359.mp4', 'http://timg.bdta.pro/images/9e6f504aa04d1a0d2a52c0fae1b6110f.jpg'),
(19708, 1283, 'Succession S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219360.mp4', 'http://timg.bdta.pro/images/477bf9d7bd30550f8bf6bb8146f2cfd6.jpg'),
(19709, 1283, 'Succession S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219361.mp4', 'http://timg.bdta.pro/images/a613eb2981eb363c54ba47a40f947ece.jpg'),
(19710, 1284, 'Succession S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yXL37lmPhwTRg71CvMjkK9C8vZM.jpg'),
(19711, 1284, 'Succession S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i8XEjQlE1rhLxZb1knjxkNQtrXf.jpg'),
(19712, 1284, 'Succession S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kNr0xiy8PSVUTff7feUD5nj0pqF.jpg'),
(19713, 1284, 'Succession S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mP4pvN58nyBsFhUGPjW18os7zRU.jpg'),
(19714, 1284, 'Succession S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rRBERiQvUcpWgj9wJ6ZU8DZCIQJ.jpg'),
(19715, 1284, 'Succession S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xeS6vKMy6PWaQzugGlIRsen0poF.jpg'),
(19716, 1284, 'Succession S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqvLgaO1MgdfrZK47Nb0nw5ehvE.jpg'),
(19717, 1284, 'Succession S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cPTzIDuP4nFrmYTOsR30bLh1V8a.jpg'),
(19718, 1284, 'Succession S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqkAvMmfeBminpC0QVygFpNnQ3j.jpg'),
(19719, 1285, 'Succession S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6sPirsptcGhKK8Lzy0o0Tx9s5Mf.jpg'),
(19720, 1285, 'Succession S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uSRuin2gyKhEA4QmYQP4UmPDAhX.jpg'),
(19721, 1285, 'Succession S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/enyCR8jTTgpAvYtENKm8xZX20NH.jpg'),
(19722, 1285, 'Succession S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sPrLwDsnPO5vXldhsPmkfRKGcoQ.jpg'),
(19723, 1285, 'Succession S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/klsgNgg8JOEXXCfXnZZ9lCe5nFP.jpg'),
(19724, 1285, 'Succession S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Ut45xIXiKhupEEIlPoKnhb69Kh.jpg'),
(19725, 1285, 'Succession S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AequFivGIhmbcFeKWG5tjve8amq.jpg'),
(19726, 1285, 'Succession S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cWDU2UZmZZDiQkA7eKR8AQyAIV3.jpg'),
(19727, 1285, 'Succession S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aRlJ64Bb2mItzi55nvBj7f2N2in.jpg'),
(19728, 1285, 'Succession S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wwa4WFrOfCSOT5ozJIgZhJA47Os.jpg'),
(19729, 1286, 'The Flemish Bandits S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102840.mp4', 'http://gstaticontent.com/images/tNAFSZyLXGtydSExjGeZ1B544UE_big.jpg'),
(19730, 1286, 'The Flemish Bandits S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102841.mp4', 'http://gstaticontent.com/images/tNAFSZyLXGtydSExjGeZ1B544UE_big.jpg'),
(19731, 1286, 'The Flemish Bandits S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102842.mp4', 'http://gstaticontent.com/images/tNAFSZyLXGtydSExjGeZ1B544UE_big.jpg'),
(19732, 1286, 'The Flemish Bandits S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102843.mp4', 'http://gstaticontent.com/images/tNAFSZyLXGtydSExjGeZ1B544UE_big.jpg'),
(19733, 1286, 'The Flemish Bandits S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102844.mp4', 'http://gstaticontent.com/images/tNAFSZyLXGtydSExjGeZ1B544UE_big.jpg'),
(19734, 1286, 'The Flemish Bandits S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102845.mp4', 'http://gstaticontent.com/images/tNAFSZyLXGtydSExjGeZ1B544UE_big.jpg'),
(19735, 1286, 'The Flemish Bandits S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102846.mp4', 'http://gstaticontent.com/images/tNAFSZyLXGtydSExjGeZ1B544UE_big.jpg'),
(19736, 1286, 'The Flemish Bandits S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102847.mp4', 'http://gstaticontent.com/images/tNAFSZyLXGtydSExjGeZ1B544UE_big.jpg'),
(19737, 1286, 'The Flemish Bandits S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102848.mp4', 'http://gstaticontent.com/images/tNAFSZyLXGtydSExjGeZ1B544UE_big.jpg'),
(19738, 1286, 'The Flemish Bandits S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102849.mp4', 'http://gstaticontent.com/images/tNAFSZyLXGtydSExjGeZ1B544UE_big.jpg'),
(19739, 1287, 'The Last Kingdom S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177712.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19740, 1287, 'The Last Kingdom S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177713.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19741, 1287, 'The Last Kingdom S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177714.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19742, 1287, 'The Last Kingdom S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177715.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19743, 1287, 'The Last Kingdom S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177716.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19744, 1287, 'The Last Kingdom S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177717.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19745, 1287, 'The Last Kingdom S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177718.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19746, 1287, 'The Last Kingdom S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177719.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19747, 1288, 'The Last Kingdom S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177720.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19748, 1288, 'The Last Kingdom S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177721.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19749, 1288, 'The Last Kingdom S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177722.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19750, 1288, 'The Last Kingdom S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177723.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19751, 1288, 'The Last Kingdom S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177724.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19752, 1288, 'The Last Kingdom S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177725.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19753, 1288, 'The Last Kingdom S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177726.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19754, 1288, 'The Last Kingdom S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177727.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19755, 1289, 'The Last Kingdom S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177728.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19756, 1289, 'The Last Kingdom S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177729.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19757, 1289, 'The Last Kingdom S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177730.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19758, 1289, 'The Last Kingdom S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177731.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19759, 1289, 'The Last Kingdom S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177732.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19760, 1289, 'The Last Kingdom S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177733.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19761, 1289, 'The Last Kingdom S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177734.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19762, 1289, 'The Last Kingdom S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177735.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19763, 1289, 'The Last Kingdom S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177736.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19764, 1289, 'The Last Kingdom S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177737.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19765, 1290, 'The Last Kingdom S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177738.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19766, 1290, 'The Last Kingdom S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177739.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19767, 1290, 'The Last Kingdom S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177740.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19768, 1290, 'The Last Kingdom S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177741.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19769, 1290, 'The Last Kingdom S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177742.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19770, 1290, 'The Last Kingdom S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177743.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19771, 1290, 'The Last Kingdom S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177744.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19772, 1290, 'The Last Kingdom S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177745.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19773, 1290, 'The Last Kingdom S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177746.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19774, 1290, 'The Last Kingdom S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177747.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19775, 1291, 'The Last Kingdom S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177748.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19776, 1291, 'The Last Kingdom S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177749.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19777, 1291, 'The Last Kingdom S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177750.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19778, 1291, 'The Last Kingdom S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177751.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19779, 1291, 'The Last Kingdom S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177752.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19780, 1291, 'The Last Kingdom S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177753.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19781, 1291, 'The Last Kingdom S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177754.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19782, 1291, 'The Last Kingdom S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177755.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19783, 1291, 'The Last Kingdom S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177756.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19784, 1291, 'The Last Kingdom S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177757.mp4', 'http://gstaticontent.com/images/c03QKlxQWg743GrQGKGrhmVsdVE_big.jpg'),
(19785, 1292, 'The A List S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102827.mp4', 'http://gstaticontent.com/images/5mq15W77lMH8uigtKRiKJ0wyzbE_big.jpg'),
(19786, 1292, 'The A List S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102828.mp4', 'http://gstaticontent.com/images/5mq15W77lMH8uigtKRiKJ0wyzbE_big.jpg'),
(19787, 1292, 'The A List S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102829.mp4', 'http://gstaticontent.com/images/5mq15W77lMH8uigtKRiKJ0wyzbE_big.jpg'),
(19788, 1292, 'The A List S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102830.mp4', 'http://gstaticontent.com/images/5mq15W77lMH8uigtKRiKJ0wyzbE_big.jpg'),
(19789, 1292, 'The A List S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102831.mp4', 'http://gstaticontent.com/images/5mq15W77lMH8uigtKRiKJ0wyzbE_big.jpg'),
(19790, 1292, 'The A List S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102832.mp4', 'http://gstaticontent.com/images/5mq15W77lMH8uigtKRiKJ0wyzbE_big.jpg'),
(19791, 1292, 'The A List S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102833.mp4', 'http://gstaticontent.com/images/5mq15W77lMH8uigtKRiKJ0wyzbE_big.jpg'),
(19792, 1292, 'The A List S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102834.mp4', 'http://gstaticontent.com/images/5mq15W77lMH8uigtKRiKJ0wyzbE_big.jpg'),
(19793, 1292, 'The A List S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102835.mp4', 'http://gstaticontent.com/images/5mq15W77lMH8uigtKRiKJ0wyzbE_big.jpg'),
(19794, 1292, 'The A List S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102836.mp4', 'http://gstaticontent.com/images/5mq15W77lMH8uigtKRiKJ0wyzbE_big.jpg'),
(19795, 1292, 'The A List S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/102837.mp4', 'http://gstaticontent.com/images/5mq15W77lMH8uigtKRiKJ0wyzbE_big.jpg'),
(19796, 1292, 'The A List S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/102838.mp4', 'http://gstaticontent.com/images/5mq15W77lMH8uigtKRiKJ0wyzbE_big.jpg'),
(19797, 1292, 'The A List S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/102839.mp4', 'http://gstaticontent.com/images/5mq15W77lMH8uigtKRiKJ0wyzbE_big.jpg'),
(19798, 1293, 'Section Zero S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102820.mp4', 'http://gstaticontent.com/images/ceBTU9JqcWDgpsPaS7kQ3oI1CSR_big.jpg'),
(19799, 1293, 'Section Zero S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102821.mp4', 'http://gstaticontent.com/images/ceBTU9JqcWDgpsPaS7kQ3oI1CSR_big.jpg'),
(19800, 1293, 'Section Zero S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102822.mp4', 'http://gstaticontent.com/images/ceBTU9JqcWDgpsPaS7kQ3oI1CSR_big.jpg'),
(19801, 1293, 'Section Zero S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102823.mp4', 'http://gstaticontent.com/images/ceBTU9JqcWDgpsPaS7kQ3oI1CSR_big.jpg'),
(19802, 1293, 'Section Zero S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102824.mp4', 'http://gstaticontent.com/images/ceBTU9JqcWDgpsPaS7kQ3oI1CSR_big.jpg'),
(19803, 1293, 'Section Zero S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102825.mp4', 'http://gstaticontent.com/images/ceBTU9JqcWDgpsPaS7kQ3oI1CSR_big.jpg'),
(19804, 1293, 'Section Zero S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102826.mp4', 'http://gstaticontent.com/images/ceBTU9JqcWDgpsPaS7kQ3oI1CSR_big.jpg'),
(19805, 1294, 'Restauradores De Rust Valley S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102812.mp4', 'http://gstaticontent.com/images/hbY0j0oAGEjXHBNBXmCM6SqpZVT_big.jpg'),
(19806, 1294, 'Restauradores De Rust Valley S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102813.mp4', 'http://gstaticontent.com/images/hbY0j0oAGEjXHBNBXmCM6SqpZVT_big.jpg'),
(19807, 1294, 'Restauradores De Rust Valley S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102814.mp4', 'http://gstaticontent.com/images/hbY0j0oAGEjXHBNBXmCM6SqpZVT_big.jpg'),
(19808, 1294, 'Restauradores De Rust Valley S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102815.mp4', 'http://gstaticontent.com/images/hbY0j0oAGEjXHBNBXmCM6SqpZVT_big.jpg'),
(19809, 1294, 'Restauradores De Rust Valley S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102816.mp4', 'http://gstaticontent.com/images/hbY0j0oAGEjXHBNBXmCM6SqpZVT_big.jpg'),
(19810, 1294, 'Restauradores De Rust Valley S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102817.mp4', 'http://gstaticontent.com/images/hbY0j0oAGEjXHBNBXmCM6SqpZVT_big.jpg'),
(19811, 1294, 'Restauradores De Rust Valley S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102818.mp4', 'http://gstaticontent.com/images/hbY0j0oAGEjXHBNBXmCM6SqpZVT_big.jpg'),
(19812, 1294, 'Restauradores De Rust Valley S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102819.mp4', 'http://gstaticontent.com/images/hbY0j0oAGEjXHBNBXmCM6SqpZVT_big.jpg'),
(19813, 1295, 'Pesadelo na Cozinha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144339.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19814, 1295, 'Pesadelo na Cozinha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144340.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19815, 1295, 'Pesadelo na Cozinha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144341.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19816, 1295, 'Pesadelo na Cozinha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144342.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19817, 1295, 'Pesadelo na Cozinha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144343.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19818, 1295, 'Pesadelo na Cozinha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144344.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19819, 1295, 'Pesadelo na Cozinha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144345.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19820, 1295, 'Pesadelo na Cozinha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144346.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19821, 1295, 'Pesadelo na Cozinha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144347.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19822, 1295, 'Pesadelo na Cozinha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144348.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19823, 1295, 'Pesadelo na Cozinha S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144349.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19824, 1295, 'Pesadelo na Cozinha S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144350.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19825, 1295, 'Pesadelo na Cozinha S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144351.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19826, 1296, 'Pesadelo na Cozinha S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144352.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19827, 1296, 'Pesadelo na Cozinha S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144353.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19828, 1296, 'Pesadelo na Cozinha S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144354.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19829, 1296, 'Pesadelo na Cozinha S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144355.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19830, 1296, 'Pesadelo na Cozinha S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144356.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19831, 1296, 'Pesadelo na Cozinha S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144357.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19832, 1296, 'Pesadelo na Cozinha S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144358.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19833, 1297, 'Pesadelo na Cozinha S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144359.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19834, 1297, 'Pesadelo na Cozinha S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144360.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19835, 1297, 'Pesadelo na Cozinha S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144361.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19836, 1297, 'Pesadelo na Cozinha S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144362.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19837, 1298, 'Pesadelo na Cozinha S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/687216.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19838, 1298, 'Pesadelo na Cozinha S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/697586.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19839, 1298, 'Pesadelo na Cozinha S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/704360.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19840, 1298, 'Pesadelo na Cozinha S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/713495.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19841, 1298, 'Pesadelo na Cozinha S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/717689.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19842, 1298, 'Pesadelo na Cozinha S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/723877.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19843, 1298, 'Pesadelo na Cozinha S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/730442.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19844, 1298, 'Pesadelo na Cozinha S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/751029.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19845, 1298, 'Pesadelo na Cozinha S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/758711.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19846, 1298, 'Pesadelo na Cozinha S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/764405.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19847, 1298, 'Pesadelo na Cozinha S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/772823.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19848, 1298, 'Pesadelo na Cozinha S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/778912.mp4', 'http://gstaticontent.com/images/8KA33hJQ8jCnjcs6bK6gjVTUUoj_big.jpg'),
(19849, 1299, 'Peaky Blinders S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179534.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19850, 1299, 'Peaky Blinders S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179535.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19851, 1299, 'Peaky Blinders S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179536.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19852, 1299, 'Peaky Blinders S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179537.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19853, 1299, 'Peaky Blinders S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179538.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19854, 1299, 'Peaky Blinders S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179539.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19855, 1300, 'Peaky Blinders S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179540.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19856, 1300, 'Peaky Blinders S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179541.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19857, 1300, 'Peaky Blinders S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179542.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19858, 1300, 'Peaky Blinders S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179543.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19859, 1300, 'Peaky Blinders S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179544.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19860, 1300, 'Peaky Blinders S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179545.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19861, 1301, 'Peaky Blinders S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179546.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19862, 1301, 'Peaky Blinders S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179547.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19863, 1301, 'Peaky Blinders S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179548.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19864, 1301, 'Peaky Blinders S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179549.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19865, 1301, 'Peaky Blinders S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179550.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19866, 1301, 'Peaky Blinders S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179551.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19867, 1302, 'Peaky Blinders S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179552.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19868, 1302, 'Peaky Blinders S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179553.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19869, 1302, 'Peaky Blinders S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179554.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19870, 1302, 'Peaky Blinders S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179555.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19871, 1302, 'Peaky Blinders S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179556.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19872, 1302, 'Peaky Blinders S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179557.mp4', 'http://gstaticontent.com/images/i0uajcHH9yogXMfDHpOXexIukG9_big.jpg'),
(19873, 1303, 'Peaky Blinders S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179558.mp4', 'http://timg.bdta.pro/images/876d3f96fba6a202e9a7456b5f0fe53a.jpg'),
(19874, 1303, 'Peaky Blinders S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179559.mp4', 'http://timg.bdta.pro/images/d25e8c4687bfe1157cf681454900ebe4.jpg'),
(19875, 1303, 'Peaky Blinders S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179560.mp4', 'http://timg.bdta.pro/images/fcee9d3687db7f29bd26334faf961f54.jpg'),
(19876, 1303, 'Peaky Blinders S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179561.mp4', 'http://timg.bdta.pro/images/26d74a3a4bf6128d931a5d154b9b707e.jpg'),
(19877, 1303, 'Peaky Blinders S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179562.mp4', 'http://timg.bdta.pro/images/203c5c1389f14957c987b93a04e0544d.jpg'),
(19878, 1303, 'Peaky Blinders S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179563.mp4', 'http://timg.bdta.pro/images/a230cc720634297a7c82dfca085b119c.jpg'),
(19879, 1304, 'Peaky Blinders S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179564.mp4', 'http://timg.bdta.pro/images/8512b1678a6a4ee7f129383f0b158a8e.jpg'),
(19880, 1304, 'Peaky Blinders S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179565.mp4', 'http://timg.bdta.pro/images/9f00a0b1110d09fc8f363174644327a3.jpg'),
(19881, 1304, 'Peaky Blinders S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179566.mp4', 'http://timg.bdta.pro/images/4ab8fe1988534f6a21a46784ff8d81e1.jpg'),
(19882, 1304, 'Peaky Blinders S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179567.mp4', 'http://timg.bdta.pro/images/30f0776d9c63b5814c4897cb3f9cfbac.jpg'),
(19883, 1304, 'Peaky Blinders S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179568.mp4', 'http://timg.bdta.pro/images/5a5a5fd50cf1f2413646f78da45b54a5.jpg'),
(19884, 1304, 'Peaky Blinders S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179569.mp4', 'http://timg.bdta.pro/images/457740e941fe250b2e75fac01ce3f6ad.jpg'),
(19885, 1305, 'O Doutrinador A Série S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107091.mp4', 'http://gstaticontent.com/images/25o85eA6EnlRVYhqg5waNkmr9Mz_big.jpg'),
(19886, 1305, 'O Doutrinador A Série S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107092.mp4', 'http://gstaticontent.com/images/25o85eA6EnlRVYhqg5waNkmr9Mz_big.jpg'),
(19887, 1305, 'O Doutrinador A Série S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107093.mp4', 'http://gstaticontent.com/images/25o85eA6EnlRVYhqg5waNkmr9Mz_big.jpg'),
(19888, 1305, 'O Doutrinador A Série S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107094.mp4', 'http://gstaticontent.com/images/25o85eA6EnlRVYhqg5waNkmr9Mz_big.jpg'),
(19889, 1305, 'O Doutrinador A Série S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107095.mp4', 'http://gstaticontent.com/images/25o85eA6EnlRVYhqg5waNkmr9Mz_big.jpg'),
(19890, 1305, 'O Doutrinador A Série S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107096.mp4', 'http://gstaticontent.com/images/25o85eA6EnlRVYhqg5waNkmr9Mz_big.jpg'),
(19891, 1305, 'O Doutrinador A Série S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107097.mp4', 'http://gstaticontent.com/images/25o85eA6EnlRVYhqg5waNkmr9Mz_big.jpg'),
(19892, 1306, 'O Cristal Encantado A Era Da Resistencia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102802.mp4', 'http://gstaticontent.com/images/rG6bC26xi10i8Mx0ZTyJ7nBkeWv_big.jpg'),
(19893, 1306, 'O Cristal Encantado A Era Da Resistencia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102803.mp4', 'http://gstaticontent.com/images/rG6bC26xi10i8Mx0ZTyJ7nBkeWv_big.jpg'),
(19894, 1306, 'O Cristal Encantado A Era Da Resistencia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102804.mp4', 'http://gstaticontent.com/images/rG6bC26xi10i8Mx0ZTyJ7nBkeWv_big.jpg'),
(19895, 1306, 'O Cristal Encantado A Era Da Resistencia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102805.mp4', 'http://gstaticontent.com/images/rG6bC26xi10i8Mx0ZTyJ7nBkeWv_big.jpg'),
(19896, 1306, 'O Cristal Encantado A Era Da Resistencia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102806.mp4', 'http://gstaticontent.com/images/rG6bC26xi10i8Mx0ZTyJ7nBkeWv_big.jpg'),
(19897, 1306, 'O Cristal Encantado A Era Da Resistencia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102807.mp4', 'http://gstaticontent.com/images/rG6bC26xi10i8Mx0ZTyJ7nBkeWv_big.jpg'),
(19898, 1306, 'O Cristal Encantado A Era Da Resistencia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/102808.mp4', 'http://gstaticontent.com/images/rG6bC26xi10i8Mx0ZTyJ7nBkeWv_big.jpg'),
(19899, 1306, 'O Cristal Encantado A Era Da Resistencia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/102809.mp4', 'http://gstaticontent.com/images/rG6bC26xi10i8Mx0ZTyJ7nBkeWv_big.jpg'),
(19900, 1306, 'O Cristal Encantado A Era Da Resistencia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/102810.mp4', 'http://gstaticontent.com/images/rG6bC26xi10i8Mx0ZTyJ7nBkeWv_big.jpg'),
(19901, 1306, 'O Cristal Encantado A Era Da Resistencia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/102811.mp4', 'http://gstaticontent.com/images/rG6bC26xi10i8Mx0ZTyJ7nBkeWv_big.jpg'),
(19902, 1307, 'Coroner S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196892.mp4', 'http://gstaticontent.com/images/58fkjd5o295CRLPywxIlyiukfSw_big.jpg'),
(19903, 1307, 'Coroner S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196893.mp4', 'http://gstaticontent.com/images/58fkjd5o295CRLPywxIlyiukfSw_big.jpg'),
(19904, 1307, 'Coroner S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196894.mp4', 'http://gstaticontent.com/images/58fkjd5o295CRLPywxIlyiukfSw_big.jpg'),
(19905, 1307, 'Coroner S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196895.mp4', 'http://gstaticontent.com/images/58fkjd5o295CRLPywxIlyiukfSw_big.jpg'),
(19906, 1307, 'Coroner S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196896.mp4', 'http://gstaticontent.com/images/58fkjd5o295CRLPywxIlyiukfSw_big.jpg'),
(19907, 1307, 'Coroner S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196897.mp4', 'http://gstaticontent.com/images/58fkjd5o295CRLPywxIlyiukfSw_big.jpg'),
(19908, 1307, 'Coroner S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196898.mp4', 'http://gstaticontent.com/images/58fkjd5o295CRLPywxIlyiukfSw_big.jpg'),
(19909, 1307, 'Coroner S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196899.mp4', 'http://gstaticontent.com/images/58fkjd5o295CRLPywxIlyiukfSw_big.jpg'),
(19910, 1308, 'Coroner S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196900.mp4', 'http://timg.bdta.pro/images/12618fc0d11c86327d3d3a1029c85749.jpg'),
(19911, 1308, 'Coroner S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196901.mp4', 'http://timg.bdta.pro/images/fcf0421129430110baab120b63f97f5a.jpg'),
(19912, 1308, 'Coroner S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196902.mp4', 'http://timg.bdta.pro/images/83e935ba71b1ea72e4578e4931517221.jpg'),
(19913, 1308, 'Coroner S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196903.mp4', 'http://timg.bdta.pro/images/9ac87c48fc9fdba96844844dee9ce733.jpg'),
(19914, 1308, 'Coroner S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196904.mp4', 'http://timg.bdta.pro/images/a95e4faa5b34a04f5658dee676ad4bc3.jpg'),
(19915, 1308, 'Coroner S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196905.mp4', 'http://timg.bdta.pro/images/106b4fb5be993fe099991ff15730e591.jpg'),
(19916, 1308, 'Coroner S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196906.mp4', 'http://timg.bdta.pro/images/4fffdb85372260b89afe75ea10d9226a.jpg'),
(19917, 1309, 'Coroner S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196907.mp4', 'http://timg.bdta.pro/images/523d469a756f8c645138724174dfddad.jpg'),
(19918, 1309, 'Coroner S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196908.mp4', 'http://timg.bdta.pro/images/cc331cd894c6303fd0dffc43125c372a.jpg'),
(19919, 1309, 'Coroner S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196909.mp4', 'http://timg.bdta.pro/images/620729ba5b1879330e58cd6284e492ea.jpg'),
(19920, 1309, 'Coroner S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196910.mp4', 'http://timg.bdta.pro/images/d8eb2b6680dddd5d03aef4a9baba6783.jpg'),
(19921, 1309, 'Coroner S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196911.mp4', 'http://timg.bdta.pro/images/b1f419b4c4f8ebd43bc7548f9af8e3ca.jpg'),
(19922, 1309, 'Coroner S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196912.mp4', 'http://timg.bdta.pro/images/e3a34504d0df5a6e188d2ec653655b5f.jpg'),
(19923, 1309, 'Coroner S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196913.mp4', 'http://image.tmdb.org/t/p/w1280/hmeF4OMC83b0IDDxjgQIGyJuMvu.jpg'),
(19924, 1309, 'Coroner S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196914.mp4', 'http://image.tmdb.org/t/p/w1280/hIUxSaV7sAK9qeelfuxlyLd9wd5.jpg'),
(19925, 1309, 'Coroner S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196915.mp4', 'http://image.tmdb.org/t/p/w1280/5a49S0pMEqwuLAwi96VwrlUWpYC.jpg'),
(19926, 1309, 'Coroner S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196916.mp4', 'http://image.tmdb.org/t/p/w1280/v4fDOnVi8ob1ZD9TFJGKIXXCGoo.jpg'),
(19927, 1310, 'Coroner S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196917.mp4', 'http://timg.bdta.pro/images/85d5ef4b99ac54fbe8e13e5e0d582225.jpg'),
(19928, 1310, 'Coroner S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196918.mp4', 'http://timg.bdta.pro/images/e23ee40b691bd7d3be43a7af14967dcd.jpg'),
(19929, 1310, 'Coroner S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196919.mp4', 'http://timg.bdta.pro/images/5485a543074ea521f874d346a6f653a4.jpg'),
(19930, 1310, 'Coroner S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196920.mp4', 'http://timg.bdta.pro/images/41a5e6061c0c66cd3811097b34c92f4a.jpg'),
(19931, 1310, 'Coroner S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196921.mp4', 'http://timg.bdta.pro/images/f7afe312eebc6e4140381baea603b64c.jpg'),
(19932, 1310, 'Coroner S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196922.mp4', 'http://timg.bdta.pro/images/50fc8878bbf996aa4b30763485f51061.jpg'),
(19933, 1310, 'Coroner S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196923.mp4', 'http://timg.bdta.pro/images/d9cbaf563cae3e138aca5b029a632d29.jpg'),
(19934, 1310, 'Coroner S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196924.mp4', 'http://timg.bdta.pro/images/0a8b5dbf35dc0b6275eaa1859a3dd31a.jpg'),
(19935, 1310, 'Coroner S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196925.mp4', 'http://timg.bdta.pro/images/dde895ff12948edae93438c90b1f30a1.jpg'),
(19936, 1310, 'Coroner S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196926.mp4', 'http://timg.bdta.pro/images/3d9acb82a103a6281fa01c96a86f1345.jpg'),
(19937, 1310, 'Coroner S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196927.mp4', 'http://timg.bdta.pro/images/20620774f640e7877bee2a6269e63e6a.jpg'),
(19938, 1310, 'Coroner S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196928.mp4', 'http://timg.bdta.pro/images/b085ff37fa6728b5bf9f0612e234d1d0.jpg'),
(19939, 1311, 'Elite S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240789.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19940, 1311, 'Elite S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240790.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19941, 1311, 'Elite S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240791.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19942, 1311, 'Elite S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240792.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19943, 1311, 'Elite S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240793.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19944, 1311, 'Elite S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240794.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19945, 1311, 'Elite S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240795.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19946, 1311, 'Elite S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240796.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19947, 1312, 'Elite S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240797.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19948, 1312, 'Elite S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240798.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19949, 1312, 'Elite S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240799.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19950, 1312, 'Elite S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240800.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19951, 1312, 'Elite S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240801.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19952, 1312, 'Elite S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240802.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19953, 1312, 'Elite S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240803.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19954, 1312, 'Elite S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240804.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19955, 1313, 'Elite S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240805.mp4', 'http://timg.bdta.pro/images/910918263259ab4933be77d2f7f9282e.jpg'),
(19956, 1313, 'Elite S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240806.mp4', 'http://timg.bdta.pro/images/2b064e61f557f03d7e776026c8213840.jpg'),
(19957, 1313, 'Elite S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240807.mp4', 'http://timg.bdta.pro/images/e2dd8a36878f90d7b1ca32173cfb409c.jpg'),
(19958, 1313, 'Elite S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240808.mp4', 'http://timg.bdta.pro/images/36409f396b1552df2e64fd1135c3dd59.jpg'),
(19959, 1313, 'Elite S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240809.mp4', 'http://timg.bdta.pro/images/7e3afff448f52780608d7cd25419c30d.jpg'),
(19960, 1313, 'Elite S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240810.mp4', 'http://timg.bdta.pro/images/b8d345eb13e5d4a86b1704f02bb0ba75.jpg'),
(19961, 1313, 'Elite S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240811.mp4', 'http://timg.bdta.pro/images/8a602b56ba2120e7b7ad1269f448754b.jpg'),
(19962, 1313, 'Elite S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240812.mp4', 'http://timg.bdta.pro/images/78f42ba45c293578ce438b5dbd148995.jpg'),
(19963, 1314, 'Elite S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240813.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19964, 1314, 'Elite S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240814.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19965, 1314, 'Elite S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240815.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19966, 1314, 'Elite S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240816.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19967, 1314, 'Elite S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240817.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19968, 1314, 'Elite S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240818.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19969, 1314, 'Elite S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240819.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19970, 1314, 'Elite S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240820.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19971, 1315, 'Elite S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240821.mp4', 'http://timg.bdta.pro/images/e2c0ca73fcd1b1c70e1ba766357409c3.jpg'),
(19972, 1315, 'Elite S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240822.mp4', 'http://timg.bdta.pro/images/dbb3dedfd904bb107d13560f87dcef4f.jpg'),
(19973, 1315, 'Elite S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240823.mp4', 'http://timg.bdta.pro/images/fb4bd48d986023cd42b5639ac9c3dd1b.jpg'),
(19974, 1315, 'Elite S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240824.mp4', 'http://timg.bdta.pro/images/1ff59f4716ac25471d4834580414cd0c.jpg'),
(19975, 1315, 'Elite S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240825.mp4', 'http://timg.bdta.pro/images/9de0e345ec6a76b2714d016ed2c878e8.jpg'),
(19976, 1315, 'Elite S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240826.mp4', 'http://timg.bdta.pro/images/9f21a67ae5ff385204b56f5342363140.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(19977, 1315, 'Elite S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240827.mp4', 'http://timg.bdta.pro/images/9e31ed49b1f815b624f4bd0c0f839dce.jpg'),
(19978, 1315, 'Elite S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240828.mp4', 'http://timg.bdta.pro/images/bcaee7e0084a6a65f670489b1fbe6f58.jpg'),
(19979, 1316, 'Elite S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h2bpmjnMbvyXMyxyXiefViRCdGn.jpg'),
(19980, 1316, 'Elite S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCDgHBcvy3bZXLXTMtPohpGl2w.jpg'),
(19981, 1316, 'Elite S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fNs76l27c1iosYZ6KvqBDaYD2p3.jpg'),
(19982, 1316, 'Elite S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c0OezTktkp4A24ruG4QOUt1C9hK.jpg'),
(19983, 1316, 'Elite S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oSlO9SjA5TvJsGIvb3TSdKLapRZ.jpg'),
(19984, 1316, 'Elite S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/outYuldZSyUpDE8g23hHW0MSgIS.jpg'),
(19985, 1316, 'Elite S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9HVJ4pO0DGxvGq6DTWfscgx83kV.jpg'),
(19986, 1316, 'Elite S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJBnPDLpCz3uZ9fvvYcybT6VJGZ.jpg'),
(19987, 1317, 'Elite S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240837.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19988, 1317, 'Elite S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240838.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19989, 1317, 'Elite S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240839.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19990, 1317, 'Elite S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240840.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19991, 1317, 'Elite S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240841.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19992, 1317, 'Elite S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240842.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19993, 1317, 'Elite S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240843.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19994, 1317, 'Elite S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240844.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19995, 1318, 'Elite S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/419683.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19996, 1318, 'Elite S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/419684.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19997, 1318, 'Elite S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/419685.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19998, 1318, 'Elite S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/419686.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(19999, 1318, 'Elite S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/419687.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(20000, 1318, 'Elite S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/419688.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(20001, 1318, 'Elite S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/419689.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(20002, 1318, 'Elite S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/419690.mp4', 'http://gstaticontent.com/images/f4YhTnCQQlGDohhq9AEQDA4B54C_big.jpg'),
(20003, 1319, 'Years and Years S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136220.mp4', 'http://gstaticontent.com/images/u1FBsyMH9Tx7K5yzMnJsYRvNEKQ_big.jpg'),
(20004, 1319, 'Years and Years S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136221.mp4', 'http://gstaticontent.com/images/u1FBsyMH9Tx7K5yzMnJsYRvNEKQ_big.jpg'),
(20005, 1319, 'Years and Years S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136222.mp4', 'http://gstaticontent.com/images/u1FBsyMH9Tx7K5yzMnJsYRvNEKQ_big.jpg'),
(20006, 1319, 'Years and Years S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136223.mp4', 'http://gstaticontent.com/images/u1FBsyMH9Tx7K5yzMnJsYRvNEKQ_big.jpg'),
(20007, 1319, 'Years and Years S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136224.mp4', 'http://gstaticontent.com/images/u1FBsyMH9Tx7K5yzMnJsYRvNEKQ_big.jpg'),
(20008, 1319, 'Years and Years S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136225.mp4', 'http://gstaticontent.com/images/u1FBsyMH9Tx7K5yzMnJsYRvNEKQ_big.jpg'),
(20009, 1320, 'O Espiao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/102796.mp4', 'http://gstaticontent.com/images/bCGC6cAEKzm45J7SPsApAnp9mNx_big.jpg'),
(20010, 1320, 'O Espiao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/102797.mp4', 'http://gstaticontent.com/images/bCGC6cAEKzm45J7SPsApAnp9mNx_big.jpg'),
(20011, 1320, 'O Espiao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/102798.mp4', 'http://gstaticontent.com/images/bCGC6cAEKzm45J7SPsApAnp9mNx_big.jpg'),
(20012, 1320, 'O Espiao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/102799.mp4', 'http://gstaticontent.com/images/bCGC6cAEKzm45J7SPsApAnp9mNx_big.jpg'),
(20013, 1320, 'O Espiao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/102800.mp4', 'http://gstaticontent.com/images/bCGC6cAEKzm45J7SPsApAnp9mNx_big.jpg'),
(20014, 1320, 'O Espiao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/102801.mp4', 'http://gstaticontent.com/images/bCGC6cAEKzm45J7SPsApAnp9mNx_big.jpg'),
(20015, 1321, 'Death & Robots S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/184295.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20016, 1321, 'Death & Robots S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/184296.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20017, 1321, 'Death & Robots S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/184297.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20018, 1321, 'Death & Robots S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/184298.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20019, 1321, 'Death & Robots S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/184299.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20020, 1321, 'Death & Robots S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/184300.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20021, 1321, 'Death & Robots S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/184301.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20022, 1321, 'Death & Robots S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/184302.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20023, 1321, 'Death & Robots S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/184303.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20024, 1321, 'Death & Robots S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/184304.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20025, 1321, 'Death & Robots S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/184305.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20026, 1321, 'Death & Robots S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/184306.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20027, 1321, 'Death & Robots S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/184307.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20028, 1321, 'Death & Robots S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/184308.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20029, 1321, 'Death & Robots S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/184309.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20030, 1321, 'Death & Robots S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/184310.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20031, 1321, 'Death & Robots S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/184311.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20032, 1321, 'Death & Robots S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/184312.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20033, 1322, 'Death & Robots S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/184313.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20034, 1322, 'Death & Robots S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/184314.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20035, 1322, 'Death & Robots S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/184315.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20036, 1322, 'Death & Robots S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/184316.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20037, 1322, 'Death & Robots S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/184317.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20038, 1322, 'Death & Robots S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/184318.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20039, 1322, 'Death & Robots S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/184319.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20040, 1322, 'Death & Robots S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/184320.mp4', 'http://gstaticontent.com/images/rlrRI2b6RvM9I9xOBTKqcTaehkE_big.jpg'),
(20041, 1323, 'Death & Robots S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/184321.mp4', 'http://timg.bdta.pro/images/6b49271518840d90e856c834bcbeca5f.jpg'),
(20042, 1323, 'Death & Robots S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/184322.mp4', 'http://timg.bdta.pro/images/b59d54c256555451d8d9b79f4923b3e1.jpg'),
(20043, 1323, 'Death & Robots S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/184323.mp4', 'http://timg.bdta.pro/images/ad01bb69581911a5532b8349d6043125.jpg'),
(20044, 1323, 'Death & Robots S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/184324.mp4', 'http://timg.bdta.pro/images/295cf6d9cbeb0dd3cbe6867971288568.jpg'),
(20045, 1323, 'Death & Robots S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/184325.mp4', 'http://timg.bdta.pro/images/b3ee3cbb51790c5bc33e2b66f076bbdc.jpg'),
(20046, 1323, 'Death & Robots S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/184326.mp4', 'http://timg.bdta.pro/images/ee754b758f93ae0fdf16c78a47509a0c.jpg'),
(20047, 1323, 'Death & Robots S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/184327.mp4', 'http://timg.bdta.pro/images/063daa3cb65502a2ba9871920b6fba12.jpg'),
(20048, 1323, 'Death & Robots S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/184328.mp4', 'http://timg.bdta.pro/images/31c029dd416721eb13cc8c417b038036.jpg'),
(20049, 1323, 'Death & Robots S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/184329.mp4', 'http://timg.bdta.pro/images/7c00a88d91e041aa7ccd6224a510cd69.jpg'),
(20050, 1324, 'Death & Robots S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/852414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lPFKSqL7EDAfupeUPmud6cTULWs.jpg'),
(20051, 1324, 'Death & Robots S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/852415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zU2jlC15Ug8e7VbA9tAUrHs6q8L.jpg'),
(20052, 1324, 'Death & Robots S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/852416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRBoKhCAtATNDCdjIyfK82I72I0.jpg'),
(20053, 1324, 'Death & Robots S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/852417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m5jU2Jp3i2orNph3SmdjKc9QYnz.jpg'),
(20054, 1324, 'Death & Robots S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/852418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/taZ6BiMOYyPlONlE4wLX2xIu7D2.jpg'),
(20055, 1324, 'Death & Robots S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/852419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LYYsDxBXsckTAfufmK5rUZsTWn.jpg'),
(20056, 1324, 'Death & Robots S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/852420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hT9IsRDbf4nQm3xCZTX9bWbpXDG.jpg'),
(20057, 1324, 'Death & Robots S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/852421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pKUS3m0hiEvKyde7iqjUnxor9ti.jpg'),
(20058, 1324, 'Death & Robots S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/852422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ghLOPrbgqVwGIMjVLTYIILPPaov.jpg'),
(20059, 1324, 'Death & Robots S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/852423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5nihYKgO2WbSO2yWDvOqkbHEAFS.jpg'),
(20060, 1325, 'A Garota da Moto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108784.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20061, 1325, 'A Garota da Moto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108785.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20062, 1325, 'A Garota da Moto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108786.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20063, 1325, 'A Garota da Moto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108787.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20064, 1325, 'A Garota da Moto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108788.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20065, 1325, 'A Garota da Moto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108789.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20066, 1325, 'A Garota da Moto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108790.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20067, 1325, 'A Garota da Moto S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108791.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20068, 1325, 'A Garota da Moto S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108792.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20069, 1325, 'A Garota da Moto S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108793.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20070, 1325, 'A Garota da Moto S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108794.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20071, 1325, 'A Garota da Moto S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108795.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20072, 1325, 'A Garota da Moto S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108796.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20073, 1325, 'A Garota da Moto S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108797.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20074, 1325, 'A Garota da Moto S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108798.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20075, 1325, 'A Garota da Moto S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108799.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20076, 1325, 'A Garota da Moto S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108800.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20077, 1325, 'A Garota da Moto S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108801.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20078, 1325, 'A Garota da Moto S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108802.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20079, 1325, 'A Garota da Moto S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108803.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20080, 1325, 'A Garota da Moto S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/108804.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20081, 1325, 'A Garota da Moto S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/108805.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20082, 1325, 'A Garota da Moto S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/108806.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20083, 1325, 'A Garota da Moto S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/108807.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20084, 1325, 'A Garota da Moto S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/108808.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20085, 1325, 'A Garota da Moto S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/108809.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20086, 1326, 'A Garota da Moto S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108810.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20087, 1326, 'A Garota da Moto S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108811.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20088, 1326, 'A Garota da Moto S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108812.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20089, 1326, 'A Garota da Moto S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108813.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20090, 1326, 'A Garota da Moto S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108814.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20091, 1326, 'A Garota da Moto S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108815.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20092, 1326, 'A Garota da Moto S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108816.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20093, 1326, 'A Garota da Moto S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108817.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20094, 1326, 'A Garota da Moto S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108818.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20095, 1326, 'A Garota da Moto S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108819.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20096, 1326, 'A Garota da Moto S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108820.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20097, 1326, 'A Garota da Moto S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108821.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20098, 1326, 'A Garota da Moto S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108822.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20099, 1326, 'A Garota da Moto S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108823.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20100, 1326, 'A Garota da Moto S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108824.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20101, 1326, 'A Garota da Moto S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108825.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20102, 1326, 'A Garota da Moto S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108826.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20103, 1326, 'A Garota da Moto S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108827.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20104, 1326, 'A Garota da Moto S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108828.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20105, 1326, 'A Garota da Moto S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108829.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20106, 1326, 'A Garota da Moto S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/108830.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20107, 1326, 'A Garota da Moto S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/108831.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20108, 1326, 'A Garota da Moto S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/108832.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20109, 1326, 'A Garota da Moto S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/108833.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20110, 1326, 'A Garota da Moto S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/108834.mp4', 'http://gstaticontent.com/images/9QQsXr8d67IjUgynt3B7sN9D94S_big.jpg'),
(20111, 1327, 'The Deuce S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130654.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20112, 1327, 'The Deuce S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130655.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20113, 1327, 'The Deuce S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130656.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20114, 1327, 'The Deuce S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130657.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20115, 1327, 'The Deuce S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130658.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20116, 1327, 'The Deuce S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130659.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20117, 1327, 'The Deuce S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130660.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20118, 1327, 'The Deuce S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130661.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20119, 1328, 'The Deuce S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130662.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20120, 1328, 'The Deuce S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130663.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20121, 1328, 'The Deuce S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130664.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20122, 1328, 'The Deuce S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130665.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20123, 1328, 'The Deuce S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130666.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20124, 1328, 'The Deuce S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130667.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20125, 1328, 'The Deuce S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130668.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20126, 1328, 'The Deuce S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130669.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20127, 1328, 'The Deuce S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130670.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20128, 1329, 'The Deuce S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130671.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20129, 1329, 'The Deuce S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130672.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20130, 1329, 'The Deuce S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130673.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20131, 1329, 'The Deuce S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130674.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20132, 1329, 'The Deuce S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130675.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20133, 1329, 'The Deuce S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130676.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20134, 1329, 'The Deuce S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130677.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20135, 1329, 'The Deuce S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130678.mp4', 'http://gstaticontent.com/images/tKFUwmue5g45rthZOyYWd7l931y_big.jpg'),
(20136, 1330, 'Sherlock S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107379.mp4', 'http://gstaticontent.com/images/7WTsnHkbA0FaG6R9twfFde0I9hl_big.jpg'),
(20137, 1330, 'Sherlock S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107380.mp4', 'http://gstaticontent.com/images/7WTsnHkbA0FaG6R9twfFde0I9hl_big.jpg'),
(20138, 1330, 'Sherlock S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107381.mp4', 'http://gstaticontent.com/images/7WTsnHkbA0FaG6R9twfFde0I9hl_big.jpg'),
(20139, 1331, 'Sherlock S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107382.mp4', 'http://gstaticontent.com/images/7WTsnHkbA0FaG6R9twfFde0I9hl_big.jpg'),
(20140, 1331, 'Sherlock S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107383.mp4', 'http://gstaticontent.com/images/7WTsnHkbA0FaG6R9twfFde0I9hl_big.jpg'),
(20141, 1331, 'Sherlock S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107384.mp4', 'http://gstaticontent.com/images/7WTsnHkbA0FaG6R9twfFde0I9hl_big.jpg'),
(20142, 1332, 'Sherlock S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107385.mp4', 'http://gstaticontent.com/images/7WTsnHkbA0FaG6R9twfFde0I9hl_big.jpg'),
(20143, 1332, 'Sherlock S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107386.mp4', 'http://gstaticontent.com/images/7WTsnHkbA0FaG6R9twfFde0I9hl_big.jpg'),
(20144, 1332, 'Sherlock S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107387.mp4', 'http://gstaticontent.com/images/7WTsnHkbA0FaG6R9twfFde0I9hl_big.jpg'),
(20145, 1332, 'Sherlock S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107388.mp4', 'http://gstaticontent.com/images/7WTsnHkbA0FaG6R9twfFde0I9hl_big.jpg'),
(20146, 1333, 'Sherlock S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107389.mp4', 'http://gstaticontent.com/images/7WTsnHkbA0FaG6R9twfFde0I9hl_big.jpg'),
(20147, 1333, 'Sherlock S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107390.mp4', 'http://gstaticontent.com/images/7WTsnHkbA0FaG6R9twfFde0I9hl_big.jpg'),
(20148, 1333, 'Sherlock S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107391.mp4', 'http://gstaticontent.com/images/7WTsnHkbA0FaG6R9twfFde0I9hl_big.jpg'),
(20149, 1334, 'O Homem do Castelo Alto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136757.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20150, 1334, 'O Homem do Castelo Alto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136758.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20151, 1334, 'O Homem do Castelo Alto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136759.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20152, 1334, 'O Homem do Castelo Alto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136760.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20153, 1334, 'O Homem do Castelo Alto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136761.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20154, 1334, 'O Homem do Castelo Alto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136762.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20155, 1334, 'O Homem do Castelo Alto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136763.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20156, 1334, 'O Homem do Castelo Alto S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136764.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20157, 1334, 'O Homem do Castelo Alto S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136765.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20158, 1334, 'O Homem do Castelo Alto S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136766.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20159, 1335, 'O Homem do Castelo Alto S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136767.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20160, 1335, 'O Homem do Castelo Alto S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136768.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20161, 1335, 'O Homem do Castelo Alto S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136769.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20162, 1335, 'O Homem do Castelo Alto S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136770.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20163, 1335, 'O Homem do Castelo Alto S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136771.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20164, 1335, 'O Homem do Castelo Alto S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136772.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20165, 1335, 'O Homem do Castelo Alto S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136773.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20166, 1335, 'O Homem do Castelo Alto S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136774.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20167, 1335, 'O Homem do Castelo Alto S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136775.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20168, 1335, 'O Homem do Castelo Alto S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136776.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20169, 1336, 'O Homem do Castelo Alto S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136777.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20170, 1336, 'O Homem do Castelo Alto S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136778.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20171, 1336, 'O Homem do Castelo Alto S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136779.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20172, 1336, 'O Homem do Castelo Alto S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136780.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20173, 1336, 'O Homem do Castelo Alto S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136781.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20174, 1336, 'O Homem do Castelo Alto S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136782.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20175, 1336, 'O Homem do Castelo Alto S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136783.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20176, 1336, 'O Homem do Castelo Alto S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136784.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20177, 1336, 'O Homem do Castelo Alto S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136785.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20178, 1336, 'O Homem do Castelo Alto S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136786.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20179, 1337, 'O Homem do Castelo Alto S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136787.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20180, 1337, 'O Homem do Castelo Alto S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136788.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20181, 1337, 'O Homem do Castelo Alto S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136789.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20182, 1337, 'O Homem do Castelo Alto S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136790.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20183, 1337, 'O Homem do Castelo Alto S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136791.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20184, 1337, 'O Homem do Castelo Alto S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136792.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20185, 1337, 'O Homem do Castelo Alto S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136793.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20186, 1337, 'O Homem do Castelo Alto S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136794.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20187, 1337, 'O Homem do Castelo Alto S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136795.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20188, 1337, 'O Homem do Castelo Alto S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136796.mp4', 'http://gstaticontent.com/images/22Ig8twy2ZGxy9KxRKyGMrJcXNu_big.jpg'),
(20189, 1338, 'Marianne S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107371.mp4', 'http://gstaticontent.com/images/vORXihb6o0UvzHZfikBSD7H13Qk_big.jpg'),
(20190, 1338, 'Marianne S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107372.mp4', 'http://gstaticontent.com/images/vORXihb6o0UvzHZfikBSD7H13Qk_big.jpg'),
(20191, 1338, 'Marianne S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107373.mp4', 'http://gstaticontent.com/images/vORXihb6o0UvzHZfikBSD7H13Qk_big.jpg'),
(20192, 1338, 'Marianne S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107374.mp4', 'http://gstaticontent.com/images/vORXihb6o0UvzHZfikBSD7H13Qk_big.jpg'),
(20193, 1338, 'Marianne S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107375.mp4', 'http://gstaticontent.com/images/vORXihb6o0UvzHZfikBSD7H13Qk_big.jpg'),
(20194, 1338, 'Marianne S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107376.mp4', 'http://gstaticontent.com/images/vORXihb6o0UvzHZfikBSD7H13Qk_big.jpg'),
(20195, 1338, 'Marianne S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107377.mp4', 'http://gstaticontent.com/images/vORXihb6o0UvzHZfikBSD7H13Qk_big.jpg'),
(20196, 1338, 'Marianne S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107378.mp4', 'http://gstaticontent.com/images/vORXihb6o0UvzHZfikBSD7H13Qk_big.jpg'),
(20197, 1339, 'Os Imortais do Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107363.mp4', 'https://a.imagem.app/dr602.jpg'),
(20198, 1339, 'Os Imortais do Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107364.mp4', 'https://a.imagem.app/dr602.jpg'),
(20199, 1339, 'Os Imortais do Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107365.mp4', 'https://a.imagem.app/dr602.jpg'),
(20200, 1339, 'Os Imortais do Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107366.mp4', 'https://a.imagem.app/dr602.jpg'),
(20201, 1339, 'Os Imortais do Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107367.mp4', 'https://a.imagem.app/dr602.jpg'),
(20202, 1339, 'Os Imortais do Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107368.mp4', 'https://a.imagem.app/dr602.jpg'),
(20203, 1339, 'Os Imortais do Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107369.mp4', 'https://a.imagem.app/dr602.jpg'),
(20204, 1339, 'Os Imortais do Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107370.mp4', 'https://a.imagem.app/dr602.jpg'),
(20205, 1340, 'Inacreditavel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107355.mp4', 'http://gstaticontent.com/images/ylea3gd9gSvPYaiLqYst17p8NiO_big.jpg'),
(20206, 1340, 'Inacreditavel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107356.mp4', 'http://gstaticontent.com/images/ylea3gd9gSvPYaiLqYst17p8NiO_big.jpg'),
(20207, 1340, 'Inacreditavel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107357.mp4', 'http://gstaticontent.com/images/ylea3gd9gSvPYaiLqYst17p8NiO_big.jpg'),
(20208, 1340, 'Inacreditavel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107358.mp4', 'http://gstaticontent.com/images/ylea3gd9gSvPYaiLqYst17p8NiO_big.jpg'),
(20209, 1340, 'Inacreditavel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107359.mp4', 'http://gstaticontent.com/images/ylea3gd9gSvPYaiLqYst17p8NiO_big.jpg'),
(20210, 1340, 'Inacreditavel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107360.mp4', 'http://gstaticontent.com/images/ylea3gd9gSvPYaiLqYst17p8NiO_big.jpg'),
(20211, 1340, 'Inacreditavel S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107361.mp4', 'http://gstaticontent.com/images/ylea3gd9gSvPYaiLqYst17p8NiO_big.jpg'),
(20212, 1340, 'Inacreditavel S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107362.mp4', 'http://gstaticontent.com/images/ylea3gd9gSvPYaiLqYst17p8NiO_big.jpg'),
(20213, 1341, 'Undone S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107347.mp4', 'http://gstaticontent.com/images/wwCclQaT9tIAHVbAkGwQvnNUSm6_big.jpg'),
(20214, 1341, 'Undone S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107348.mp4', 'http://gstaticontent.com/images/wwCclQaT9tIAHVbAkGwQvnNUSm6_big.jpg'),
(20215, 1341, 'Undone S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107349.mp4', 'http://gstaticontent.com/images/wwCclQaT9tIAHVbAkGwQvnNUSm6_big.jpg'),
(20216, 1341, 'Undone S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107350.mp4', 'http://gstaticontent.com/images/wwCclQaT9tIAHVbAkGwQvnNUSm6_big.jpg'),
(20217, 1341, 'Undone S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107351.mp4', 'http://gstaticontent.com/images/wwCclQaT9tIAHVbAkGwQvnNUSm6_big.jpg'),
(20218, 1341, 'Undone S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107352.mp4', 'http://gstaticontent.com/images/wwCclQaT9tIAHVbAkGwQvnNUSm6_big.jpg'),
(20219, 1341, 'Undone S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107353.mp4', 'http://gstaticontent.com/images/wwCclQaT9tIAHVbAkGwQvnNUSm6_big.jpg'),
(20220, 1341, 'Undone S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107354.mp4', 'http://gstaticontent.com/images/wwCclQaT9tIAHVbAkGwQvnNUSm6_big.jpg'),
(20221, 1342, 'Futurama S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235691.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20222, 1342, 'Futurama S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235692.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20223, 1342, 'Futurama S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235693.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20224, 1342, 'Futurama S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235694.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20225, 1342, 'Futurama S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235695.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20226, 1342, 'Futurama S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235696.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20227, 1342, 'Futurama S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235697.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20228, 1342, 'Futurama S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235698.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20229, 1342, 'Futurama S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235699.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20230, 1342, 'Futurama S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235700.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20231, 1342, 'Futurama S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235701.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20232, 1342, 'Futurama S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235702.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20233, 1342, 'Futurama S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235703.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20234, 1343, 'Futurama S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235704.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20235, 1343, 'Futurama S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235705.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20236, 1343, 'Futurama S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235706.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20237, 1343, 'Futurama S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235707.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20238, 1343, 'Futurama S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235708.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20239, 1343, 'Futurama S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235709.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20240, 1343, 'Futurama S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235710.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20241, 1343, 'Futurama S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235711.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20242, 1343, 'Futurama S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235712.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20243, 1343, 'Futurama S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235713.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20244, 1343, 'Futurama S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235714.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20245, 1343, 'Futurama S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235715.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20246, 1343, 'Futurama S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235716.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20247, 1343, 'Futurama S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/235717.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20248, 1343, 'Futurama S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/235718.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20249, 1343, 'Futurama S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/235719.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20250, 1343, 'Futurama S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/235720.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20251, 1343, 'Futurama S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/235721.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20252, 1343, 'Futurama S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/235722.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20253, 1344, 'Futurama S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235723.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20254, 1344, 'Futurama S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235724.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20255, 1344, 'Futurama S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235725.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20256, 1344, 'Futurama S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235726.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20257, 1344, 'Futurama S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235727.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20258, 1344, 'Futurama S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235728.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20259, 1344, 'Futurama S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235729.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20260, 1344, 'Futurama S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235730.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20261, 1344, 'Futurama S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235731.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20262, 1344, 'Futurama S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235732.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20263, 1344, 'Futurama S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235733.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(20264, 1344, 'Futurama S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235734.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20265, 1344, 'Futurama S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235735.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20266, 1344, 'Futurama S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/235736.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20267, 1344, 'Futurama S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/235737.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20268, 1344, 'Futurama S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/235738.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20269, 1344, 'Futurama S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/235739.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20270, 1344, 'Futurama S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/235740.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20271, 1344, 'Futurama S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/235741.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20272, 1344, 'Futurama S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/235742.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20273, 1344, 'Futurama S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/235743.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20274, 1344, 'Futurama S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/235744.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20275, 1345, 'Futurama S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235745.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20276, 1345, 'Futurama S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235746.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20277, 1345, 'Futurama S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235747.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20278, 1345, 'Futurama S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235748.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20279, 1345, 'Futurama S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235749.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20280, 1345, 'Futurama S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235750.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20281, 1345, 'Futurama S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235751.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20282, 1345, 'Futurama S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235752.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20283, 1345, 'Futurama S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235753.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20284, 1345, 'Futurama S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235754.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20285, 1345, 'Futurama S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235755.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20286, 1345, 'Futurama S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235756.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20287, 1345, 'Futurama S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235757.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20288, 1345, 'Futurama S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/235758.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20289, 1345, 'Futurama S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/235759.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20290, 1345, 'Futurama S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/235760.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20291, 1345, 'Futurama S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/235761.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20292, 1345, 'Futurama S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/235762.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20293, 1346, 'Futurama S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235763.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20294, 1346, 'Futurama S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235764.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20295, 1346, 'Futurama S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235765.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20296, 1346, 'Futurama S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235766.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20297, 1346, 'Futurama S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235767.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20298, 1346, 'Futurama S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235768.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20299, 1346, 'Futurama S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235769.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20300, 1346, 'Futurama S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235770.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20301, 1346, 'Futurama S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235771.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20302, 1346, 'Futurama S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235772.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20303, 1346, 'Futurama S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235773.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20304, 1346, 'Futurama S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235774.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20305, 1346, 'Futurama S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235775.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20306, 1346, 'Futurama S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/235776.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20307, 1346, 'Futurama S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/235777.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20308, 1346, 'Futurama S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/235778.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20309, 1347, 'Futurama S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235779.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20310, 1347, 'Futurama S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235780.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20311, 1347, 'Futurama S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235781.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20312, 1347, 'Futurama S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235782.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20313, 1347, 'Futurama S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235783.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20314, 1347, 'Futurama S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235784.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20315, 1347, 'Futurama S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235785.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20316, 1347, 'Futurama S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235786.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20317, 1347, 'Futurama S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235787.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20318, 1347, 'Futurama S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235788.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20319, 1347, 'Futurama S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235789.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20320, 1347, 'Futurama S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235790.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20321, 1347, 'Futurama S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235791.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20322, 1347, 'Futurama S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/235792.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20323, 1348, 'Futurama S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235793.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20324, 1348, 'Futurama S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235794.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20325, 1348, 'Futurama S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235795.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20326, 1348, 'Futurama S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235796.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20327, 1348, 'Futurama S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235797.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20328, 1348, 'Futurama S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235798.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20329, 1348, 'Futurama S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235799.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20330, 1348, 'Futurama S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235800.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20331, 1348, 'Futurama S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235801.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20332, 1348, 'Futurama S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235802.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20333, 1348, 'Futurama S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235803.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20334, 1348, 'Futurama S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235804.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20335, 1348, 'Futurama S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235805.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20336, 1348, 'Futurama S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/235806.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20337, 1348, 'Futurama S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/235807.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20338, 1348, 'Futurama S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/235808.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20339, 1348, 'Futurama S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/235809.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20340, 1348, 'Futurama S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/235810.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20341, 1348, 'Futurama S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/235811.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20342, 1348, 'Futurama S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/235812.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20343, 1348, 'Futurama S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/235813.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20344, 1348, 'Futurama S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/235814.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20345, 1348, 'Futurama S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/235815.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20346, 1348, 'Futurama S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/235816.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20347, 1348, 'Futurama S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/235817.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20348, 1348, 'Futurama S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/235818.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20349, 1349, 'Futurama S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235819.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20350, 1349, 'Futurama S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235820.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20351, 1349, 'Futurama S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235821.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20352, 1349, 'Futurama S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235822.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20353, 1349, 'Futurama S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235823.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20354, 1349, 'Futurama S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235824.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20355, 1349, 'Futurama S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235825.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20356, 1349, 'Futurama S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235826.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20357, 1349, 'Futurama S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235827.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20358, 1349, 'Futurama S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235828.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20359, 1349, 'Futurama S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235829.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20360, 1349, 'Futurama S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235830.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20361, 1349, 'Futurama S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235831.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20362, 1350, 'Futurama S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235832.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20363, 1350, 'Futurama S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235833.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20364, 1350, 'Futurama S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235834.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20365, 1350, 'Futurama S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235835.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20366, 1350, 'Futurama S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235836.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20367, 1350, 'Futurama S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235837.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20368, 1350, 'Futurama S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235838.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20369, 1350, 'Futurama S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235839.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20370, 1350, 'Futurama S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235840.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20371, 1350, 'Futurama S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235841.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20372, 1350, 'Futurama S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235842.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20373, 1350, 'Futurama S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235843.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20374, 1350, 'Futurama S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235844.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20375, 1351, 'Futurama S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235845.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20376, 1351, 'Futurama S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235846.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20377, 1351, 'Futurama S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235847.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20378, 1351, 'Futurama S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235848.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20379, 1351, 'Futurama S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235849.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20380, 1351, 'Futurama S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235850.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20381, 1351, 'Futurama S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235851.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20382, 1351, 'Futurama S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235852.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20383, 1351, 'Futurama S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235853.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20384, 1351, 'Futurama S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235854.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20385, 1351, 'Futurama S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235855.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20386, 1351, 'Futurama S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235856.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20387, 1351, 'Futurama S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235857.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20388, 1352, 'Futurama S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235858.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20389, 1352, 'Futurama S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235859.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20390, 1352, 'Futurama S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235860.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20391, 1352, 'Futurama S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235861.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20392, 1352, 'Futurama S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235862.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20393, 1352, 'Futurama S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235863.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20394, 1352, 'Futurama S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235864.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20395, 1352, 'Futurama S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235865.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20396, 1352, 'Futurama S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235866.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20397, 1352, 'Futurama S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235867.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20398, 1353, 'Futurama S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/422286.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20399, 1353, 'Futurama S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/424993.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20400, 1353, 'Futurama S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/432453.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20401, 1353, 'Futurama S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/434903.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20402, 1353, 'Futurama S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/442490.mp4', 'http://gstaticontent.com/images/4olv2DdNUdg7oE6zoevbZbgEPsB_big.jpg'),
(20403, 1354, 'Irmandade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181064.mp4', 'http://timg.bdta.pro/images/7bd08909c21d792a72665f52a0b49d70.jpg'),
(20404, 1354, 'Irmandade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181065.mp4', 'http://timg.bdta.pro/images/e49d098be4ef0fb1ca27aebb16fb6a40.jpg'),
(20405, 1354, 'Irmandade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181066.mp4', 'http://timg.bdta.pro/images/eb980af26d4ca8dfe402767fe80ec0ee.jpg'),
(20406, 1354, 'Irmandade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181067.mp4', 'http://timg.bdta.pro/images/9cc00a9b62b344a191ec1a20a6d8e803.jpg'),
(20407, 1354, 'Irmandade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181068.mp4', 'http://timg.bdta.pro/images/2fae25efafa3c4742ae87d5d1e34604a.jpg'),
(20408, 1354, 'Irmandade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181069.mp4', 'http://timg.bdta.pro/images/41d52ac82c10f82830ccc384e6d0f9ab.jpg'),
(20409, 1354, 'Irmandade S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181070.mp4', 'http://timg.bdta.pro/images/2f60cca0c0b968067a03a2f9c6c8cc86.jpg'),
(20410, 1354, 'Irmandade S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181071.mp4', 'http://timg.bdta.pro/images/7df93252ef3ba05a2ebe3ba81254cd4d.jpg'),
(20411, 1355, 'Irmandade S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181072.mp4', 'http://timg.bdta.pro/images/5fa1fe983cd0ac0569ab1082d5d8c82d.jpg'),
(20412, 1355, 'Irmandade S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181073.mp4', 'http://timg.bdta.pro/images/b798c539e5c008e6e61daf1c7f5ca971.jpg'),
(20413, 1355, 'Irmandade S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181074.mp4', 'http://timg.bdta.pro/images/1eedf96ab3c252152f986a143227f473.jpg'),
(20414, 1355, 'Irmandade S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181075.mp4', 'http://timg.bdta.pro/images/5ca7d5ecf1b1b84a4de36e2323f8fd09.jpg'),
(20415, 1355, 'Irmandade S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181076.mp4', 'http://timg.bdta.pro/images/b51ccdb9b069577fe9d293776d16eb15.jpg'),
(20416, 1355, 'Irmandade S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181077.mp4', 'http://timg.bdta.pro/images/c387bda990896d52a0b4691734ea45a2.jpg'),
(20417, 1356, 'Manifest S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229569.mp4', 'http://timg.bdta.pro/images/59275fb8ba33945d7b9f6e7bfcbdce92.jpg'),
(20418, 1356, 'Manifest S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229570.mp4', 'http://timg.bdta.pro/images/89a96e3936241ca387259b9275b870a9.jpg'),
(20419, 1356, 'Manifest S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229571.mp4', 'http://timg.bdta.pro/images/135827d3d8d828a1c33c882c3a92d0d8.jpg'),
(20420, 1356, 'Manifest S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229572.mp4', 'http://timg.bdta.pro/images/ac2f4b7783f659f79f59c973d250dadb.jpg'),
(20421, 1356, 'Manifest S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229573.mp4', 'http://timg.bdta.pro/images/2e4122695a5415fabe6edd8d5f962159.jpg'),
(20422, 1356, 'Manifest S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229574.mp4', 'http://timg.bdta.pro/images/f74e6adc97742b90dd4d197ca409f30c.jpg'),
(20423, 1356, 'Manifest S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229575.mp4', 'http://timg.bdta.pro/images/67d2af28723dfb174a44f1d2c76bfc5b.jpg'),
(20424, 1356, 'Manifest S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229576.mp4', 'http://timg.bdta.pro/images/265b621236b300ef37eff13370f15c00.jpg'),
(20425, 1356, 'Manifest S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229577.mp4', 'http://timg.bdta.pro/images/597222837fc68d666ca19f1649af45b2.jpg'),
(20426, 1356, 'Manifest S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229578.mp4', 'http://timg.bdta.pro/images/de5f3123c3e2020dca946b57d7d6b6ad.jpg'),
(20427, 1356, 'Manifest S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/229579.mp4', 'http://timg.bdta.pro/images/e181b97af6c95724b98d153121e61395.jpg'),
(20428, 1356, 'Manifest S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/229580.mp4', 'http://timg.bdta.pro/images/3a87b4019e515669a05d29586651c505.jpg'),
(20429, 1356, 'Manifest S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/229581.mp4', 'http://timg.bdta.pro/images/653ae484c4cd64a47fc62d862bfb94be.jpg'),
(20430, 1356, 'Manifest S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/229582.mp4', 'http://timg.bdta.pro/images/1af0c1880dcea6f5d42a2900c66cac3d.jpg'),
(20431, 1356, 'Manifest S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/229583.mp4', 'http://timg.bdta.pro/images/c03953394d6e5ce1a3dbb2c9081eb300.jpg'),
(20432, 1356, 'Manifest S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/229584.mp4', 'http://timg.bdta.pro/images/b68b4a5e5d30fd6ed7a88217f547a679.jpg'),
(20433, 1357, 'Manifest S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229585.mp4', 'http://timg.bdta.pro/images/e9d0b65b285a8c4217b0644dfa380f9b.jpg'),
(20434, 1357, 'Manifest S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229586.mp4', 'http://timg.bdta.pro/images/ace240d16c7036174229bafbff4aacd0.jpg'),
(20435, 1357, 'Manifest S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229587.mp4', 'http://timg.bdta.pro/images/91fccb845c6a89cc02bc820f05f8f36a.jpg'),
(20436, 1357, 'Manifest S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229588.mp4', 'http://timg.bdta.pro/images/870df785d12c8cbb96fe4b160c19a4dc.jpg'),
(20437, 1357, 'Manifest S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229589.mp4', 'http://timg.bdta.pro/images/ba5cc6d6b3da8618549fee4c2a239545.jpg'),
(20438, 1357, 'Manifest S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229590.mp4', 'http://timg.bdta.pro/images/468dc58c492a7f84c5ab14ca19a93536.jpg'),
(20439, 1357, 'Manifest S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229591.mp4', 'http://timg.bdta.pro/images/0a329eda4232dedbbe8df7703c3e2ab1.jpg'),
(20440, 1357, 'Manifest S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229592.mp4', 'http://timg.bdta.pro/images/f046efca64f524a9e41b67ebd237b1ac.jpg'),
(20441, 1357, 'Manifest S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229593.mp4', 'http://timg.bdta.pro/images/bca2d313fdb9164d3e9f6415e6605e3b.jpg'),
(20442, 1357, 'Manifest S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229594.mp4', 'http://timg.bdta.pro/images/f88a5b7c99b82c6f91f21e4e1a1ae883.jpg'),
(20443, 1357, 'Manifest S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/229595.mp4', 'http://timg.bdta.pro/images/f336cc31ef9a8051a245e9d4bfe0cc0a.jpg'),
(20444, 1357, 'Manifest S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/229596.mp4', 'http://timg.bdta.pro/images/6342c7afe932c30dcf25ccf88488f736.jpg'),
(20445, 1357, 'Manifest S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/229597.mp4', 'http://timg.bdta.pro/images/ed56f0358da4df507a06c87444682487.jpg'),
(20446, 1358, 'Manifest S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229598.mp4', 'http://timg.bdta.pro/images/03ca5a16551bfdfed61f04870c8e0fec.jpg'),
(20447, 1358, 'Manifest S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229599.mp4', 'http://timg.bdta.pro/images/61d62cae79d9e6b2ea14056ac7417635.jpg'),
(20448, 1358, 'Manifest S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229600.mp4', 'http://timg.bdta.pro/images/6c7dfe46126ec4f37f1211a3f9748d14.jpg'),
(20449, 1358, 'Manifest S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229601.mp4', 'http://timg.bdta.pro/images/959ade655677a79e3abf3d69c2d66089.jpg'),
(20450, 1358, 'Manifest S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229602.mp4', 'http://timg.bdta.pro/images/3179b3d1c78f9fe853599de858b96688.jpg'),
(20451, 1358, 'Manifest S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229603.mp4', 'http://timg.bdta.pro/images/8a2476150d6406de10dca082d0a91e0c.jpg'),
(20452, 1358, 'Manifest S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229604.mp4', 'http://timg.bdta.pro/images/8601a32a671d6f82ac6cfc5dd7154578.jpg'),
(20453, 1358, 'Manifest S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229605.mp4', 'http://timg.bdta.pro/images/285bf4adcc334d79aa9e96a12e21660c.jpg'),
(20454, 1358, 'Manifest S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229606.mp4', 'http://timg.bdta.pro/images/fcae3561bdeb9b78e4f5aba8dde80b1a.jpg'),
(20455, 1358, 'Manifest S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229607.mp4', 'http://timg.bdta.pro/images/c599d5a07c688c61d21a5ecceef1a7a3.jpg'),
(20456, 1358, 'Manifest S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/229608.mp4', 'http://timg.bdta.pro/images/914ad290eb671df05604ff5e7d677999.jpg'),
(20457, 1358, 'Manifest S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/229609.mp4', 'http://timg.bdta.pro/images/a3afb8b1624391e5d839f7e8479e1043.jpg'),
(20458, 1358, 'Manifest S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/229610.mp4', 'http://timg.bdta.pro/images/42992193babd984ebac9f48edc8b5ed8.jpg'),
(20459, 1359, 'Manifest S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s6I9hoEfPyBAXkub174yMCyDzwT.jpg'),
(20460, 1359, 'Manifest S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybwiosu2NyMWEB42IRhnOclmV2d.jpg'),
(20461, 1359, 'Manifest S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7jNnQbeUJTiShYxfyT6nTwgqXHG.jpg'),
(20462, 1359, 'Manifest S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bpDbLqn8HqXpj9QqLbreCuycUNV.jpg'),
(20463, 1359, 'Manifest S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o8Wv1VzsRheeUSJKqY654U8mO2L.jpg'),
(20464, 1359, 'Manifest S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kop5fHo5D5BmVdO13D68EzFKsDK.jpg'),
(20465, 1359, 'Manifest S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oNg8KRrp5gYWWnwMe56gAOXGV71.jpg'),
(20466, 1359, 'Manifest S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3KeTNNz3azU0yLC7b0F6WMbfdbP.jpg'),
(20467, 1359, 'Manifest S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8wDScH3EsG9YZ7cOwaysiepBps.jpg'),
(20468, 1359, 'Manifest S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3llnwQyJhKUtiYzGEzoRWyJM4aH.jpg'),
(20469, 1359, 'Manifest S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/229621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFjI5At1qCPsqctqO6YirFtuIJL.jpg'),
(20470, 1359, 'Manifest S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/229622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Ozah5VhFaFK1Q2nIDN5mpIqlsI.jpg'),
(20471, 1359, 'Manifest S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/229623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uvFB5BMPPuAcWHzkaQRrlL1e5YX.jpg'),
(20472, 1359, 'Manifest S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/229624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1iRwwz9EnsSzQSOQiHudG2oEJM0.jpg'),
(20473, 1359, 'Manifest S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/229625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v8GkWSX8zIc0nNVUvJUHBdP0sSD.jpg'),
(20474, 1359, 'Manifest S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/229626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b6r9IR94tCTxf4QWIPcNaouLKlB.jpg'),
(20475, 1359, 'Manifest S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/229627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iaD2qEHJtliETgWenqyFtkmqyNC.jpg'),
(20476, 1359, 'Manifest S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/229628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l8A4avwdMjn4nJIKtbXcpSiGoMD.jpg'),
(20477, 1359, 'Manifest S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/229629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6jGzaF5qUFGEXApneGdCpo2uavD.jpg'),
(20478, 1359, 'Manifest S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/229630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bqi0LHlmJPOWAdVedTWKM9CYZM1.jpg'),
(20479, 1360, '11.22.63 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107339.mp4', 'http://timg.bdta.pro/images/960598a2e83bb83d328d00938458b32b.jpg'),
(20480, 1360, '11.22.63 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107340.mp4', 'http://timg.bdta.pro/images/5a1d936fc467f6812cd3033749939ae5.jpg'),
(20481, 1360, '11.22.63 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107341.mp4', 'http://timg.bdta.pro/images/e0bc62f08ce818068ec8f8ee63c7fc2b.jpg'),
(20482, 1360, '11.22.63 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107342.mp4', 'http://timg.bdta.pro/images/c3531d0223ad2ae78965634c384e32b3.jpg'),
(20483, 1360, '11.22.63 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107343.mp4', 'http://timg.bdta.pro/images/198e109668cd68d84fa1dd52a7694218.jpg'),
(20484, 1360, '11.22.63 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107344.mp4', 'http://timg.bdta.pro/images/69ffa0c7247244d28bb3c89acea2276a.jpg'),
(20485, 1360, '11.22.63 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107345.mp4', 'http://timg.bdta.pro/images/c4ac89363d5b5326562a0abfff35a400.jpg'),
(20486, 1360, '11.22.63 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107346.mp4', 'http://timg.bdta.pro/images/b1a12596b2e1ff0dbcd1032109b6b80d.jpg'),
(20487, 1361, 'Baby S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128142.mp4', 'http://timg.bdta.pro/images/0482b6e6257c10ba8bc161e6df08cdd4.jpg'),
(20488, 1361, 'Baby S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128143.mp4', 'http://timg.bdta.pro/images/fed72820432451e5f27752e31ab54f42.jpg'),
(20489, 1361, 'Baby S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128144.mp4', 'http://timg.bdta.pro/images/edb142033d16ce04647c41f1c2bce51d.jpg'),
(20490, 1361, 'Baby S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128145.mp4', 'http://timg.bdta.pro/images/d1f3cf09541af257f0e2178b7e0e4169.jpg'),
(20491, 1361, 'Baby S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128146.mp4', 'http://timg.bdta.pro/images/e8cca142f0c8f1608f4b6143c8868187.jpg'),
(20492, 1361, 'Baby S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128147.mp4', 'http://timg.bdta.pro/images/2854ee74222831bfebe96073b229dfa2.jpg'),
(20493, 1362, 'Baby S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128148.mp4', 'http://timg.bdta.pro/images/d32a0e65dc739b5e1494d7b3b12ceac8.jpg'),
(20494, 1362, 'Baby S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128149.mp4', 'http://timg.bdta.pro/images/cb60ba188b2e2f6d6fc2138864bbfb3f.jpg'),
(20495, 1362, 'Baby S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128150.mp4', 'http://timg.bdta.pro/images/940d32b3d4bd045c43a13a7915667e72.jpg'),
(20496, 1362, 'Baby S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128151.mp4', 'http://timg.bdta.pro/images/e3dd97a90d54f3e2c3e147bbf91bbc1d.jpg'),
(20497, 1362, 'Baby S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128152.mp4', 'http://timg.bdta.pro/images/eb33fa64453a60d0c9b0b4c2c9e8c85a.jpg'),
(20498, 1362, 'Baby S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128153.mp4', 'http://timg.bdta.pro/images/4a7ec28cea9bc389bf758380ba0fb4cb.jpg'),
(20499, 1363, 'Baby S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128154.mp4', 'http://timg.bdta.pro/images/e6dcd9bb69b6dbda6979b841635ba955.jpg'),
(20500, 1363, 'Baby S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128155.mp4', 'http://timg.bdta.pro/images/47571c8064179ae6e7c15924442b0e4e.jpg'),
(20501, 1363, 'Baby S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128156.mp4', 'http://timg.bdta.pro/images/565a5a7f8e85b72536ca0b1cc0d0a726.jpg'),
(20502, 1363, 'Baby S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128157.mp4', 'http://timg.bdta.pro/images/b1d07cf218f7a264e4d701f2717007e9.jpg'),
(20503, 1363, 'Baby S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128158.mp4', 'http://timg.bdta.pro/images/4b179e340c54d2dc601b0e3a1f076d61.jpg'),
(20504, 1363, 'Baby S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128159.mp4', 'http://timg.bdta.pro/images/1652e9bf7c983bd02b1c91e085115c2c.jpg'),
(20505, 1364, 'Batwoman [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163393.mp4', 'http://timg.bdta.pro/images/899f9ceefba4ee0a07ce3a12941f25bd.jpg'),
(20506, 1364, 'Batwoman [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163394.mp4', 'http://timg.bdta.pro/images/3cfc9eb41ee02a3ec71dce115cb366ac.jpg'),
(20507, 1364, 'Batwoman [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163395.mp4', 'http://timg.bdta.pro/images/f0375ae41c755ef012cfcb67c83a2e52.jpg'),
(20508, 1364, 'Batwoman [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163396.mp4', 'http://timg.bdta.pro/images/3e709ce55a55496b9b961cfaeea8f7c8.jpg'),
(20509, 1364, 'Batwoman [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163397.mp4', 'http://timg.bdta.pro/images/3c63dc60b9d9353235be10a6ebbc0c74.jpg'),
(20510, 1364, 'Batwoman [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163398.mp4', 'http://timg.bdta.pro/images/ba7132b891fb896e2c20a2f4f28bc463.jpg'),
(20511, 1364, 'Batwoman [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163399.mp4', 'http://timg.bdta.pro/images/1c43f6ab88f1367aa10d3edf203c67ee.jpg'),
(20512, 1364, 'Batwoman [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163400.mp4', 'http://timg.bdta.pro/images/06c65a25901c01a0ea73cdc1cc079330.jpg'),
(20513, 1364, 'Batwoman [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163401.mp4', 'http://timg.bdta.pro/images/7252c36a53405911a2d38dfa3e0d6c25.jpg'),
(20514, 1364, 'Batwoman [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163402.mp4', 'http://timg.bdta.pro/images/0b1bf8fe10daa528ffea6da119184b9e.jpg'),
(20515, 1364, 'Batwoman [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163403.mp4', 'http://timg.bdta.pro/images/b9aea3de0a5010cc224f3589b843b344.jpg'),
(20516, 1364, 'Batwoman [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163404.mp4', 'http://timg.bdta.pro/images/a6252a344c030ac0240892f7e8a04261.jpg'),
(20517, 1364, 'Batwoman [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163405.mp4', 'http://timg.bdta.pro/images/c4fe5f8218014c0c484185afe7a77ea5.jpg'),
(20518, 1364, 'Batwoman [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163406.mp4', 'http://timg.bdta.pro/images/8d894731115e194ff6c5dd930881b453.jpg'),
(20519, 1364, 'Batwoman [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163407.mp4', 'http://timg.bdta.pro/images/22b1fa190397c5666f5a86d7330944d4.jpg'),
(20520, 1364, 'Batwoman [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163408.mp4', 'http://timg.bdta.pro/images/d76b99b22da97ea64cbbe8c02e6a8095.jpg'),
(20521, 1364, 'Batwoman [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163409.mp4', 'http://timg.bdta.pro/images/012b8c5e96b3ddc64ce513c58994c4ea.jpg'),
(20522, 1364, 'Batwoman [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163410.mp4', 'http://timg.bdta.pro/images/2233c4927585f5db102e37c2ff826970.jpg'),
(20523, 1364, 'Batwoman [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163411.mp4', 'http://timg.bdta.pro/images/4bcef334e2e9edba45d63dbdb0203e1d.jpg'),
(20524, 1364, 'Batwoman [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163412.mp4', 'http://timg.bdta.pro/images/def5b613616773afc684a1455d9dcd19.jpg'),
(20525, 1365, 'Batwoman [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163413.mp4', 'http://gstaticontent.com/images/jnaimWkIVSD9IInmZPyLYarSvvc_big.jpg'),
(20526, 1365, 'Batwoman [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163414.mp4', 'http://gstaticontent.com/images/jnaimWkIVSD9IInmZPyLYarSvvc_big.jpg'),
(20527, 1365, 'Batwoman [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163415.mp4', 'http://gstaticontent.com/images/jnaimWkIVSD9IInmZPyLYarSvvc_big.jpg'),
(20528, 1365, 'Batwoman [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163416.mp4', 'http://gstaticontent.com/images/jnaimWkIVSD9IInmZPyLYarSvvc_big.jpg'),
(20529, 1365, 'Batwoman [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163417.mp4', 'http://gstaticontent.com/images/jnaimWkIVSD9IInmZPyLYarSvvc_big.jpg'),
(20530, 1365, 'Batwoman [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163418.mp4', 'http://gstaticontent.com/images/jnaimWkIVSD9IInmZPyLYarSvvc_big.jpg'),
(20531, 1365, 'Batwoman [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163419.mp4', 'http://gstaticontent.com/images/jnaimWkIVSD9IInmZPyLYarSvvc_big.jpg'),
(20532, 1365, 'Batwoman [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163420.mp4', 'http://gstaticontent.com/images/jnaimWkIVSD9IInmZPyLYarSvvc_big.jpg'),
(20533, 1365, 'Batwoman [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163421.mp4', 'http://gstaticontent.com/images/jnaimWkIVSD9IInmZPyLYarSvvc_big.jpg'),
(20534, 1365, 'Batwoman [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163422.mp4', 'http://gstaticontent.com/images/jnaimWkIVSD9IInmZPyLYarSvvc_big.jpg'),
(20535, 1365, 'Batwoman [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163423.mp4', 'http://gstaticontent.com/images/jnaimWkIVSD9IInmZPyLYarSvvc_big.jpg'),
(20536, 1365, 'Batwoman [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163424.mp4', 'http://gstaticontent.com/images/jnaimWkIVSD9IInmZPyLYarSvvc_big.jpg'),
(20537, 1365, 'Batwoman [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163425.mp4', 'http://gstaticontent.com/images/jnaimWkIVSD9IInmZPyLYarSvvc_big.jpg'),
(20538, 1365, 'Batwoman [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163426.mp4', 'http://gstaticontent.com/images/jnaimWkIVSD9IInmZPyLYarSvvc_big.jpg'),
(20539, 1365, 'Batwoman [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163427.mp4', 'http://gstaticontent.com/images/jnaimWkIVSD9IInmZPyLYarSvvc_big.jpg'),
(20540, 1365, 'Batwoman [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163428.mp4', 'http://gstaticontent.com/images/jnaimWkIVSD9IInmZPyLYarSvvc_big.jpg'),
(20541, 1365, 'Batwoman [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163429.mp4', 'http://gstaticontent.com/images/jnaimWkIVSD9IInmZPyLYarSvvc_big.jpg'),
(20542, 1365, 'Batwoman [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163430.mp4', 'http://image.tmdb.org/t/p/w1280/tirFuyqF4MA19Vu0N9bhjwi2xZ1.jpg'),
(20543, 1366, 'Batwoman [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2bnaVaFm3eJppPNSkibEb7nm8dJ.jpg'),
(20544, 1366, 'Batwoman [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLTMcm1rAqFZiJI3s0h49kJOtcH.jpg'),
(20545, 1367, 'Brigada Costa del Sol S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107326.mp4', 'http://timg.bdta.pro/images/778fd983707ddd6ab64e96589362b0ab.jpg'),
(20546, 1367, 'Brigada Costa del Sol S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107327.mp4', 'http://timg.bdta.pro/images/de88cae65dbb56422668c856481b2b8d.jpg'),
(20547, 1367, 'Brigada Costa del Sol S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107328.mp4', 'http://timg.bdta.pro/images/63f125bd8be94db0d2b691d8af0bf083.jpg'),
(20548, 1367, 'Brigada Costa del Sol S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107329.mp4', 'http://timg.bdta.pro/images/1542ac2aca0448c10d770fc2fdd2d134.jpg'),
(20549, 1367, 'Brigada Costa del Sol S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107330.mp4', 'http://timg.bdta.pro/images/f6a27cab8a82b17c3edad91737787244.jpg'),
(20550, 1367, 'Brigada Costa del Sol S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107331.mp4', 'http://timg.bdta.pro/images/b92f1c49c5275cffd188fa1b8fdad984.jpg'),
(20551, 1367, 'Brigada Costa del Sol S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107332.mp4', 'http://timg.bdta.pro/images/d577c7162a042b17a384ebca3adff3c1.jpg'),
(20552, 1367, 'Brigada Costa del Sol S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107333.mp4', 'http://timg.bdta.pro/images/26e22f826525b03fb6407cae9a121219.jpg'),
(20553, 1367, 'Brigada Costa del Sol S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107334.mp4', 'http://timg.bdta.pro/images/030e3191fc61aadee73c4b2bc904a969.jpg'),
(20554, 1367, 'Brigada Costa del Sol S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107335.mp4', 'http://timg.bdta.pro/images/670417b7375484a9032eddee7a268065.jpg'),
(20555, 1367, 'Brigada Costa del Sol S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107336.mp4', 'http://timg.bdta.pro/images/54cdcfc87a1b22335fb014782891a3b6.jpg'),
(20556, 1367, 'Brigada Costa del Sol S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107337.mp4', 'http://timg.bdta.pro/images/e587c815da2398406d0dd86afff40a80.jpg'),
(20557, 1367, 'Brigada Costa del Sol S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107338.mp4', 'http://timg.bdta.pro/images/779d41ee3f1ef67e51a329ac8210bb89.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(20558, 1368, 'Carnival Row S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212669.mp4', 'http://timg.bdta.pro/images/e300bcebb5a2bacb986cd1cef690443c.jpg'),
(20559, 1368, 'Carnival Row S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212670.mp4', 'http://timg.bdta.pro/images/2f8fa1c030a6b345a3c3f863bc0ef84e.jpg'),
(20560, 1368, 'Carnival Row S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212671.mp4', 'http://timg.bdta.pro/images/740f1d37c87de6036025a76407be44ed.jpg'),
(20561, 1368, 'Carnival Row S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212672.mp4', 'http://timg.bdta.pro/images/27236b9a19b92e3ead086208280d01f2.jpg'),
(20562, 1368, 'Carnival Row S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212673.mp4', 'http://timg.bdta.pro/images/d658f20d17c431869d10ab9107e10d43.jpg'),
(20563, 1368, 'Carnival Row S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212674.mp4', 'http://timg.bdta.pro/images/b1440cbd4b7c5a0d8f06aaeb2cba6cbf.jpg'),
(20564, 1368, 'Carnival Row S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212675.mp4', 'http://timg.bdta.pro/images/d5c0b70b54ca2cfca13124c7fc44663b.jpg'),
(20565, 1368, 'Carnival Row S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212676.mp4', 'http://timg.bdta.pro/images/ca0941448ff36bb46c66bb9a4bb34a93.jpg'),
(20566, 1369, 'Carnival Row S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A551ih78C4hYWXjLq2tCwKY0QMk.jpg'),
(20567, 1369, 'Carnival Row S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zIJ1eDCmjkqRN4a6CHt0tF8WPLS.jpg'),
(20568, 1369, 'Carnival Row S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pcZvqAuPYaNbvwjxA2hnWHahNo9.jpg'),
(20569, 1369, 'Carnival Row S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lHFa2J5YsCtr5A1zMPSSCjvln8F.jpg'),
(20570, 1369, 'Carnival Row S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kEzM7dwdtMtQtHRFlh2LDyhtYuu.jpg'),
(20571, 1369, 'Carnival Row S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/GqwIOSddBJM9MqWtypKPDx1m7N.jpg'),
(20572, 1369, 'Carnival Row S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jvVbMY0ss7faB8YShYXrNe2hdyJ.jpg'),
(20573, 1369, 'Carnival Row S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rgXxm9ydzr06FgyPZA3fOsZiRuG.jpg'),
(20574, 1369, 'Carnival Row S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8kJOilyX3V0pue4eGCI9poHZ0Ii.jpg'),
(20575, 1369, 'Carnival Row S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bGCazyN5DmDS7A5PnJVDBv7XdV7.jpg'),
(20576, 1370, 'Castle Rock S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108647.mp4', 'http://timg.bdta.pro/images/240762ae9fd78a64115401a1ea10dec9.jpg'),
(20577, 1370, 'Castle Rock S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108648.mp4', 'http://timg.bdta.pro/images/8852bb54ca5731459120805c2d8999f6.jpg'),
(20578, 1370, 'Castle Rock S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108649.mp4', 'http://timg.bdta.pro/images/7c5b4c46f530c95c997a65b9471b24dc.jpg'),
(20579, 1370, 'Castle Rock S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108650.mp4', 'http://timg.bdta.pro/images/60df6f9dc42b2d5146598568e6905005.jpg'),
(20580, 1370, 'Castle Rock S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108651.mp4', 'http://timg.bdta.pro/images/9ac9130a17b030b08b3ebda5d8c2488a.jpg'),
(20581, 1370, 'Castle Rock S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108652.mp4', 'http://timg.bdta.pro/images/5190c29f1607754827882dfb2d12d891.jpg'),
(20582, 1370, 'Castle Rock S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108653.mp4', 'http://timg.bdta.pro/images/5684fb25ac6c35dc13c8499064100624.jpg'),
(20583, 1370, 'Castle Rock S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/530971.mp4', 'http://gstaticontent.com/images/576bfa720fcfe9a1ce3c4c0b8c1845c4.jpg'),
(20584, 1370, 'Castle Rock S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108656.mp4', 'http://timg.bdta.pro/images/ff59c993a32d5e7103d537c151125501.jpg'),
(20585, 1371, 'Castle Rock S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108657.mp4', 'http://timg.bdta.pro/images/d24e227d813ce76645e441fed595b357.jpg'),
(20586, 1371, 'Castle Rock S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108658.mp4', 'http://timg.bdta.pro/images/5355b5b37b5142ce372c216480a77c90.jpg'),
(20587, 1371, 'Castle Rock S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108659.mp4', 'http://timg.bdta.pro/images/daeb13fa09110771241e9008f652b14c.jpg'),
(20588, 1371, 'Castle Rock S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108660.mp4', 'http://timg.bdta.pro/images/4c1915cef03aea26044871868b0f329a.jpg'),
(20589, 1371, 'Castle Rock S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108661.mp4', 'http://timg.bdta.pro/images/e8083cd888a53da7825c7608db60440d.jpg'),
(20590, 1371, 'Castle Rock S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108662.mp4', 'http://timg.bdta.pro/images/af4a2ba6d537ff8d9d63f11c688dc64c.jpg'),
(20591, 1371, 'Castle Rock S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108663.mp4', 'http://timg.bdta.pro/images/a247b773bf504a25c58df9a9c01f155a.jpg'),
(20592, 1371, 'Castle Rock S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108664.mp4', 'http://timg.bdta.pro/images/be9004f6a2eda9a283f6597aa549e7f5.jpg'),
(20593, 1371, 'Castle Rock S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108665.mp4', 'http://timg.bdta.pro/images/611e8e723bbe50fa5e8b359c990b21cc.jpg'),
(20594, 1371, 'Castle Rock S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108666.mp4', 'http://timg.bdta.pro/images/1c0c7cd3c46f7ce33c284903fd3fe029.jpg'),
(20595, 1372, 'Coisa Mais Linda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113096.mp4', 'http://timg.bdta.pro/images/88698044e782349d78c3e23ed0b947cb.jpg'),
(20596, 1372, 'Coisa Mais Linda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113097.mp4', 'http://timg.bdta.pro/images/6023a9fa6a713a53cc04bea2a11992fb.jpg'),
(20597, 1372, 'Coisa Mais Linda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113098.mp4', 'http://timg.bdta.pro/images/c62c91a715417ffad7558f8d634038fd.jpg'),
(20598, 1372, 'Coisa Mais Linda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113099.mp4', 'http://timg.bdta.pro/images/0b1b8445aa4ac572a724e7949d4b9f0c.jpg'),
(20599, 1372, 'Coisa Mais Linda S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113100.mp4', 'http://timg.bdta.pro/images/a52e9799de6bb8cdddc1304e68829835.jpg'),
(20600, 1372, 'Coisa Mais Linda S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113101.mp4', 'http://timg.bdta.pro/images/c2c4530363bad7bc1d25b2fa2c48db96.jpg'),
(20601, 1372, 'Coisa Mais Linda S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113102.mp4', 'http://timg.bdta.pro/images/abee4e358fb2b5f03bc09a3ccd20568d.jpg'),
(20602, 1373, 'Coisa Mais Linda S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113103.mp4', 'http://timg.bdta.pro/images/c76376dfe9654ebad5a64d395b2d32b1.jpg'),
(20603, 1373, 'Coisa Mais Linda S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113104.mp4', 'http://timg.bdta.pro/images/7429fb6dec1012a1572913863f9e4a58.jpg'),
(20604, 1373, 'Coisa Mais Linda S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113105.mp4', 'http://timg.bdta.pro/images/606639726983500ce3a6d1110c08f98f.jpg'),
(20605, 1373, 'Coisa Mais Linda S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113106.mp4', 'http://timg.bdta.pro/images/15d6bc12b26afdff11c4a02bfa8b8cab.jpg'),
(20606, 1373, 'Coisa Mais Linda S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113107.mp4', 'http://timg.bdta.pro/images/62775f24b057a031a2b42b0a0cfbd87b.jpg'),
(20607, 1373, 'Coisa Mais Linda S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113108.mp4', 'http://timg.bdta.pro/images/228b201fc54c9097417897b6d157cc2c.jpg'),
(20608, 1374, 'Criminal: França S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107234.mp4', 'http://timg.bdta.pro/images/9b59205f3d9e4c59d3850bc8122969fe.jpg'),
(20609, 1374, 'Criminal: França S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107235.mp4', 'http://timg.bdta.pro/images/d7a16d8a08d3d8ab6d2cf043932ee018.jpg'),
(20610, 1374, 'Criminal: França S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107236.mp4', 'http://timg.bdta.pro/images/f0f4a2471aa97a03aabef7639fab0a13.jpg'),
(20611, 1375, 'Criminal: Alemanha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107231.mp4', 'http://timg.bdta.pro/images/8b18b03fc78bdf9daae5545839497ae2.jpg'),
(20612, 1375, 'Criminal: Alemanha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107232.mp4', 'http://timg.bdta.pro/images/53590ffc2bca64e5f68f338c5c1b9050.jpg'),
(20613, 1375, 'Criminal: Alemanha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107233.mp4', 'http://timg.bdta.pro/images/dfe131ac776acad30a4ce4199bc1e72f.jpg'),
(20614, 1376, 'Criminal: Espanha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107228.mp4', 'http://timg.bdta.pro/images/853bf8f8e5938f7e1f0d873a7a8c265b.jpg'),
(20615, 1376, 'Criminal: Espanha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107229.mp4', 'http://timg.bdta.pro/images/1b7dfa5c817265b2f23445dfffacf9fb.jpg'),
(20616, 1376, 'Criminal: Espanha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107230.mp4', 'http://timg.bdta.pro/images/f898ed11152d2854af5984d4e7fad965.jpg'),
(20617, 1377, 'Criminal: UK S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128135.mp4', 'http://timg.bdta.pro/images/f4861e7744d8ec654ae018577f5751bb.jpg'),
(20618, 1377, 'Criminal: UK S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128136.mp4', 'http://timg.bdta.pro/images/d57c051f193c92ba9f3916cc58696648.jpg'),
(20619, 1377, 'Criminal: UK S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128137.mp4', 'http://timg.bdta.pro/images/bef0c0ec09fd1ee37086c93bf8b4634f.jpg'),
(20620, 1378, 'Criminal: UK S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128138.mp4', 'http://timg.bdta.pro/images/07c381bf0ae4b7b639487c4e0289c667.jpg'),
(20621, 1378, 'Criminal: UK S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128139.mp4', 'http://timg.bdta.pro/images/3f08246a9fe1d86b7b9745fd25840ca8.jpg'),
(20622, 1378, 'Criminal: UK S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128140.mp4', 'http://timg.bdta.pro/images/b0ee3d1184e6bbc3eb866363b3084a7e.jpg'),
(20623, 1378, 'Criminal: UK S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128141.mp4', 'http://timg.bdta.pro/images/2b3a580c8df2aad36feabad485197fbb.jpg'),
(20624, 1379, 'Dani Who? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107218.mp4', 'http://gstaticontent.com/images/Ro8UFt3a8nm7hJ3fq9hjQgHSMh_big.jpg'),
(20625, 1379, 'Dani Who? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107219.mp4', 'http://gstaticontent.com/images/Ro8UFt3a8nm7hJ3fq9hjQgHSMh_big.jpg'),
(20626, 1379, 'Dani Who? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107220.mp4', 'http://gstaticontent.com/images/Ro8UFt3a8nm7hJ3fq9hjQgHSMh_big.jpg'),
(20627, 1379, 'Dani Who? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107221.mp4', 'http://gstaticontent.com/images/Ro8UFt3a8nm7hJ3fq9hjQgHSMh_big.jpg'),
(20628, 1379, 'Dani Who? S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107222.mp4', 'http://gstaticontent.com/images/Ro8UFt3a8nm7hJ3fq9hjQgHSMh_big.jpg'),
(20629, 1379, 'Dani Who? S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107223.mp4', 'http://gstaticontent.com/images/Ro8UFt3a8nm7hJ3fq9hjQgHSMh_big.jpg'),
(20630, 1379, 'Dani Who? S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107224.mp4', 'http://gstaticontent.com/images/Ro8UFt3a8nm7hJ3fq9hjQgHSMh_big.jpg'),
(20631, 1379, 'Dani Who? S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107225.mp4', 'http://gstaticontent.com/images/Ro8UFt3a8nm7hJ3fq9hjQgHSMh_big.jpg'),
(20632, 1379, 'Dani Who? S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107226.mp4', 'http://gstaticontent.com/images/Ro8UFt3a8nm7hJ3fq9hjQgHSMh_big.jpg'),
(20633, 1379, 'Dani Who? S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107227.mp4', 'http://gstaticontent.com/images/Ro8UFt3a8nm7hJ3fq9hjQgHSMh_big.jpg'),
(20634, 1380, 'Daybreak S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107208.mp4', 'http://timg.bdta.pro/images/9d474e279499d5608016de22800f464c.jpg'),
(20635, 1380, 'Daybreak S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107209.mp4', 'http://timg.bdta.pro/images/5d9ca522884b683a411a0e5e9d40d11c.jpg'),
(20636, 1380, 'Daybreak S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107210.mp4', 'http://timg.bdta.pro/images/ce86e92f3d32afe06b2fda48f7344613.jpg'),
(20637, 1380, 'Daybreak S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107211.mp4', 'http://timg.bdta.pro/images/8d405c0ba0812b2a65e654fbce0c5bd3.jpg'),
(20638, 1380, 'Daybreak S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107212.mp4', 'http://timg.bdta.pro/images/f78c093eeb91e9c6b0d109d75df3ee9d.jpg'),
(20639, 1380, 'Daybreak S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107213.mp4', 'http://timg.bdta.pro/images/01d2937bd57d706d4a1e6bb4c9cfa832.jpg'),
(20640, 1380, 'Daybreak S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107214.mp4', 'http://timg.bdta.pro/images/77db15bf48275a24e663d180c13c4dc5.jpg'),
(20641, 1380, 'Daybreak S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107215.mp4', 'http://timg.bdta.pro/images/03750c7df7076d720373b68f50ed1ab3.jpg'),
(20642, 1380, 'Daybreak S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107216.mp4', 'http://timg.bdta.pro/images/eb36a261d850d0a739085e92e954ddf9.jpg'),
(20643, 1380, 'Daybreak S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107217.mp4', 'http://timg.bdta.pro/images/fb6733ca80c365d76aced8d3725689e4.jpg'),
(20644, 1381, 'Deep Water [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107202.mp4', 'http://timg.bdta.pro/images/040d822cfb55353cb925b968f005d756.jpg'),
(20645, 1381, 'Deep Water [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107203.mp4', 'http://timg.bdta.pro/images/43ceb325eaa69b0cb83e4f2d592611e6.jpg'),
(20646, 1381, 'Deep Water [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107204.mp4', 'http://timg.bdta.pro/images/aa25067bea5b2bf6a774b625d00f03d4.jpg'),
(20647, 1381, 'Deep Water [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107205.mp4', 'http://timg.bdta.pro/images/852c913d2bd9bf5d7373edd99156e2a7.jpg'),
(20648, 1381, 'Deep Water [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107206.mp4', 'http://timg.bdta.pro/images/25d6430c2b25c5190ef6691db57c2929.jpg'),
(20649, 1381, 'Deep Water [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107207.mp4', 'http://timg.bdta.pro/images/d4ad9496fdfa908b3e184713229759b3.jpg'),
(20650, 1382, 'Dickinson S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168860.mp4', 'http://timg.bdta.pro/images/8d412c13fd6cf52ca77935ca95e6a7ae.jpg'),
(20651, 1382, 'Dickinson S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168861.mp4', 'http://timg.bdta.pro/images/de364aea64bc7083a72ac5cbd170e319.jpg'),
(20652, 1382, 'Dickinson S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168862.mp4', 'http://timg.bdta.pro/images/a23f053d5ad9d968bcfb3291138e14e2.jpg'),
(20653, 1382, 'Dickinson S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168863.mp4', 'http://timg.bdta.pro/images/2e9fb6cc38d806937e468bdab738ee38.jpg'),
(20654, 1382, 'Dickinson S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168864.mp4', 'http://timg.bdta.pro/images/e2935421590558433380f0add09ac492.jpg'),
(20655, 1382, 'Dickinson S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168865.mp4', 'http://timg.bdta.pro/images/47b29577947519bfc0d4818ac8cdd80d.jpg'),
(20656, 1382, 'Dickinson S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168866.mp4', 'http://timg.bdta.pro/images/c3aadf0f87177b04c3d62ad9eb395789.jpg'),
(20657, 1382, 'Dickinson S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168867.mp4', 'http://timg.bdta.pro/images/8bd85f6fb6af8f61198275899ce7a62f.jpg'),
(20658, 1382, 'Dickinson S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/168868.mp4', 'http://timg.bdta.pro/images/1caa712ac6d9e61e7082b102e8472364.jpg'),
(20659, 1382, 'Dickinson S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/168869.mp4', 'http://timg.bdta.pro/images/b5915091014ea54cb98d5f25a707f75a.jpg'),
(20660, 1383, 'Dickinson S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b9QVpKgzQ53fcbuN6m2uSJqLihg.jpg'),
(20661, 1383, 'Dickinson S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8dN9TZnNiG0ApupcuFj4DVphelP.jpg'),
(20662, 1383, 'Dickinson S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5J4TRX7ZKUHR6n0xwY1snmuUiTn.jpg'),
(20663, 1383, 'Dickinson S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dlNQKgZCSG0RPRry9VrviCBjviv.jpg'),
(20664, 1383, 'Dickinson S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c2jFZ9iBUlCWn1fOTfxRiOMdLba.jpg'),
(20665, 1383, 'Dickinson S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bUyQqCfdKbSrRMMcuwcMahNfBOQ.jpg'),
(20666, 1383, 'Dickinson S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u9YEYOl4YmfyA0FJ6Z6cG8FdBU4.jpg'),
(20667, 1383, 'Dickinson S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eWOXIaez62p4YehQEa5RRfgPSlo.jpg'),
(20668, 1383, 'Dickinson S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/168878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oLPZXz0sLELSH1JQvJfPuGCkw20.jpg'),
(20669, 1383, 'Dickinson S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/168879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqBLnrHvcbIvSx6X0p9EPBBvdNf.jpg'),
(20670, 1384, 'Dickinson S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mzkplUzKn63i0LkMCfEVNkkYtPv.jpg'),
(20671, 1384, 'Dickinson S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kNn9yvzkazHKGaXAQ2DvhC32gxV.jpg'),
(20672, 1384, 'Dickinson S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFMvxwobv5rdtFQNA5sZtlcH17h.jpg'),
(20673, 1384, 'Dickinson S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aAO6CfMIkgTbauTRnCLuPtXzsmS.jpg'),
(20674, 1384, 'Dickinson S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/phig6vlw9BwVACVTnBfEqJOYNy9.jpg'),
(20675, 1384, 'Dickinson S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5xZ6DYJNBRRcyZBaLYLZ4Oom3Tw.jpg'),
(20676, 1384, 'Dickinson S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5UbVt3wNDUv8Jj7kE5A2TbaX5gC.jpg'),
(20677, 1384, 'Dickinson S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tcHbmsgfgEa0KYQaUn8iB2zzN4o.jpg'),
(20678, 1384, 'Dickinson S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/168888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y3Fxv7ZF3dAArZNd9iEw2Iz983J.jpg'),
(20679, 1384, 'Dickinson S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/168889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/54ZdazhQvbIKcbMlrNcZvewcIJA.jpg'),
(20680, 1385, 'Dino Girl Gauko S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108525.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20681, 1385, 'Dino Girl Gauko S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108526.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20682, 1385, 'Dino Girl Gauko S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108527.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20683, 1385, 'Dino Girl Gauko S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108528.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20684, 1385, 'Dino Girl Gauko S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108529.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20685, 1385, 'Dino Girl Gauko S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108530.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20686, 1385, 'Dino Girl Gauko S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108531.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20687, 1385, 'Dino Girl Gauko S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108532.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20688, 1385, 'Dino Girl Gauko S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108533.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20689, 1385, 'Dino Girl Gauko S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108534.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20690, 1385, 'Dino Girl Gauko S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108535.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20691, 1385, 'Dino Girl Gauko S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108536.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20692, 1385, 'Dino Girl Gauko S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108537.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20693, 1385, 'Dino Girl Gauko S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108538.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20694, 1385, 'Dino Girl Gauko S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108539.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20695, 1385, 'Dino Girl Gauko S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108540.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20696, 1385, 'Dino Girl Gauko S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108541.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20697, 1385, 'Dino Girl Gauko S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108542.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20698, 1385, 'Dino Girl Gauko S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108543.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20699, 1385, 'Dino Girl Gauko S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108544.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20700, 1386, 'Dino Girl Gauko S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108545.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20701, 1386, 'Dino Girl Gauko S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108546.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20702, 1386, 'Dino Girl Gauko S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108547.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20703, 1386, 'Dino Girl Gauko S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108548.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20704, 1386, 'Dino Girl Gauko S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108549.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20705, 1386, 'Dino Girl Gauko S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108550.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20706, 1386, 'Dino Girl Gauko S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108551.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20707, 1386, 'Dino Girl Gauko S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108552.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20708, 1386, 'Dino Girl Gauko S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108553.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20709, 1386, 'Dino Girl Gauko S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108554.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20710, 1386, 'Dino Girl Gauko S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108555.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20711, 1386, 'Dino Girl Gauko S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108556.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20712, 1386, 'Dino Girl Gauko S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108557.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20713, 1386, 'Dino Girl Gauko S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108558.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20714, 1386, 'Dino Girl Gauko S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108559.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20715, 1386, 'Dino Girl Gauko S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108560.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20716, 1386, 'Dino Girl Gauko S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108561.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20717, 1386, 'Dino Girl Gauko S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108562.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20718, 1386, 'Dino Girl Gauko S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108563.mp4', 'http://gstaticontent.com/images/cH7utN2b5YbqPTcz9p24YVUf1Za_big.jpg'),
(20719, 1387, 'Filhos da Pátria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107190.mp4', 'http://gstaticontent.com/images/zRfgNJProIuPDY2wbVTiizmprnn_big.jpg'),
(20720, 1387, 'Filhos da Pátria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107191.mp4', 'http://gstaticontent.com/images/zRfgNJProIuPDY2wbVTiizmprnn_big.jpg'),
(20721, 1387, 'Filhos da Pátria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107192.mp4', 'http://gstaticontent.com/images/zRfgNJProIuPDY2wbVTiizmprnn_big.jpg'),
(20722, 1387, 'Filhos da Pátria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107193.mp4', 'http://gstaticontent.com/images/zRfgNJProIuPDY2wbVTiizmprnn_big.jpg'),
(20723, 1387, 'Filhos da Pátria S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107194.mp4', 'http://gstaticontent.com/images/zRfgNJProIuPDY2wbVTiizmprnn_big.jpg'),
(20724, 1387, 'Filhos da Pátria S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107195.mp4', 'http://gstaticontent.com/images/zRfgNJProIuPDY2wbVTiizmprnn_big.jpg'),
(20725, 1387, 'Filhos da Pátria S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107196.mp4', 'http://gstaticontent.com/images/zRfgNJProIuPDY2wbVTiizmprnn_big.jpg'),
(20726, 1387, 'Filhos da Pátria S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107197.mp4', 'http://gstaticontent.com/images/zRfgNJProIuPDY2wbVTiizmprnn_big.jpg'),
(20727, 1387, 'Filhos da Pátria S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107198.mp4', 'http://gstaticontent.com/images/zRfgNJProIuPDY2wbVTiizmprnn_big.jpg'),
(20728, 1387, 'Filhos da Pátria S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107199.mp4', 'http://gstaticontent.com/images/zRfgNJProIuPDY2wbVTiizmprnn_big.jpg'),
(20729, 1387, 'Filhos da Pátria S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107200.mp4', 'http://gstaticontent.com/images/zRfgNJProIuPDY2wbVTiizmprnn_big.jpg'),
(20730, 1387, 'Filhos da Pátria S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107201.mp4', 'http://gstaticontent.com/images/zRfgNJProIuPDY2wbVTiizmprnn_big.jpg'),
(20731, 1388, 'Glitch S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107172.mp4', 'http://timg.bdta.pro/images/703ad7a7008f1632255252b4059871f7.jpg'),
(20732, 1388, 'Glitch S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107173.mp4', 'http://timg.bdta.pro/images/28b53edb6599e44b5da8e2e72a5dabeb.jpg'),
(20733, 1388, 'Glitch S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107174.mp4', 'http://timg.bdta.pro/images/3ca224e3ca999b1892d320ba3d9397de.jpg'),
(20734, 1388, 'Glitch S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107175.mp4', 'http://timg.bdta.pro/images/c3525c7fa807f46d42ce0d9b4b0b3d45.jpg'),
(20735, 1388, 'Glitch S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107176.mp4', 'http://timg.bdta.pro/images/fb370df92be251ae92b6d67b880b01c2.jpg'),
(20736, 1388, 'Glitch S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107177.mp4', 'http://timg.bdta.pro/images/de78b2426a08af73f8b180530b9062e7.jpg'),
(20737, 1389, 'Glitch S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107178.mp4', 'http://timg.bdta.pro/images/d72dd1b165cd2c0a31abe35fa0cab1a2.jpg'),
(20738, 1389, 'Glitch S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107179.mp4', 'http://timg.bdta.pro/images/c8a3b8808fb5428c28b90863afd016d8.jpg'),
(20739, 1389, 'Glitch S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107180.mp4', 'http://timg.bdta.pro/images/0be95d347938cf51d14b7d830ae2e8e4.jpg'),
(20740, 1389, 'Glitch S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107181.mp4', 'http://timg.bdta.pro/images/b4cfd8aea38f3f2cad9bc6e9cbe5371d.jpg'),
(20741, 1389, 'Glitch S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107182.mp4', 'http://timg.bdta.pro/images/700d4493af16a2073b9dd5cb76a7b204.jpg'),
(20742, 1389, 'Glitch S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107183.mp4', 'http://timg.bdta.pro/images/7e3a01459dac69107ad4e22f2384eb84.jpg'),
(20743, 1390, 'Glitch S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107184.mp4', 'http://timg.bdta.pro/images/e83c082f7f173984339869a7b78b1bfa.jpg'),
(20744, 1390, 'Glitch S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107185.mp4', 'http://timg.bdta.pro/images/fac83625089d818be48f1e96efa53f4f.jpg'),
(20745, 1390, 'Glitch S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107186.mp4', 'http://timg.bdta.pro/images/87002ef90f91a2786d7a1b0810e1eeac.jpg'),
(20746, 1390, 'Glitch S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107187.mp4', 'http://timg.bdta.pro/images/4627f73353df8a5da00eaa99abd3893f.jpg'),
(20747, 1390, 'Glitch S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107188.mp4', 'http://timg.bdta.pro/images/000ebe6546832f6980e5691337e38d5b.jpg'),
(20748, 1390, 'Glitch S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107189.mp4', 'http://timg.bdta.pro/images/b82358199f61cf13cf176e8412c263fc.jpg'),
(20749, 1391, 'His Dark Materials S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202546.mp4', 'http://timg.bdta.pro/images/d06b170c3fe579eef2b931256f25255c.jpg'),
(20750, 1391, 'His Dark Materials S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202547.mp4', 'http://timg.bdta.pro/images/d877e25eb57b9721041f3ea8110718d8.jpg'),
(20751, 1391, 'His Dark Materials S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202548.mp4', 'http://timg.bdta.pro/images/f5f3e877707809228b12e8af86f51501.jpg'),
(20752, 1391, 'His Dark Materials S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202549.mp4', 'http://timg.bdta.pro/images/4bc8eae090bef918f0437e927f74eb2e.jpg'),
(20753, 1391, 'His Dark Materials S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202550.mp4', 'http://timg.bdta.pro/images/43abc4f6516540bb9d5b8e8d788fdc6a.jpg'),
(20754, 1391, 'His Dark Materials S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202551.mp4', 'http://timg.bdta.pro/images/9533bd5cd182ee3711fc9e5a0dfdd4aa.jpg'),
(20755, 1391, 'His Dark Materials S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202552.mp4', 'http://timg.bdta.pro/images/62dce399b08995904a26d8df2f1cbf19.jpg'),
(20756, 1391, 'His Dark Materials S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202553.mp4', 'http://timg.bdta.pro/images/6e7a5d446bdd1078863b34adf4f4c982.jpg'),
(20757, 1392, 'His Dark Materials S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202554.mp4', 'http://gstaticontent.com/images/oY31VAullCnEcazY24ryRe1CZyk_big.jpg'),
(20758, 1392, 'His Dark Materials S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202555.mp4', 'http://gstaticontent.com/images/oY31VAullCnEcazY24ryRe1CZyk_big.jpg'),
(20759, 1392, 'His Dark Materials S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202556.mp4', 'http://gstaticontent.com/images/oY31VAullCnEcazY24ryRe1CZyk_big.jpg'),
(20760, 1392, 'His Dark Materials S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202557.mp4', 'http://gstaticontent.com/images/oY31VAullCnEcazY24ryRe1CZyk_big.jpg'),
(20761, 1392, 'His Dark Materials S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202558.mp4', 'http://gstaticontent.com/images/oY31VAullCnEcazY24ryRe1CZyk_big.jpg'),
(20762, 1392, 'His Dark Materials S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202559.mp4', 'http://gstaticontent.com/images/oY31VAullCnEcazY24ryRe1CZyk_big.jpg'),
(20763, 1392, 'His Dark Materials S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202560.mp4', 'http://gstaticontent.com/images/oY31VAullCnEcazY24ryRe1CZyk_big.jpg'),
(20764, 1393, 'His Dark Materials S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hb0wGxQwck2JlLHCbENPDRchLI1.jpg'),
(20765, 1393, 'His Dark Materials S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sXrBjGu48gTEGeUxqMMH4yQ57eN.jpg'),
(20766, 1393, 'His Dark Materials S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSELRvUirliSuGErLFWCYZEuEEp.jpg'),
(20767, 1393, 'His Dark Materials S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y0u60bAdpxbc7YnPE4AsJ3pKrIr.jpg'),
(20768, 1393, 'His Dark Materials S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A4jpLR4cOFc2L1plTzHRZPykHyR.jpg'),
(20769, 1393, 'His Dark Materials S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/di1qPnbZdEKM8Y6LMQz2u3dHX7G.jpg'),
(20770, 1393, 'His Dark Materials S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Ltsu1h07V7ghQ4Yf35Y5BFNsrk.jpg'),
(20771, 1393, 'His Dark Materials S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rDJTSQOJ9srQ1GR6DeFxUtvUEod.jpg'),
(20772, 1394, 'Holiday Secrets S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107169.mp4', 'http://timg.bdta.pro/images/49f18a0108379ac2f0e1cfe1a3934c5b.jpg'),
(20773, 1394, 'Holiday Secrets S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107170.mp4', 'http://timg.bdta.pro/images/f9452c7a824801edbcf5ff5930628fc1.jpg'),
(20774, 1394, 'Holiday Secrets S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107171.mp4', 'http://timg.bdta.pro/images/08c7b5172e5f56117e0412085b9473c6.jpg'),
(20775, 1395, 'Irmãos Freitas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106666.mp4', 'http://gstaticontent.com/images/n9qHNVRDBBWcReIo8tOfe4j3806_big.jpg'),
(20776, 1395, 'Irmãos Freitas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106667.mp4', 'http://gstaticontent.com/images/n9qHNVRDBBWcReIo8tOfe4j3806_big.jpg'),
(20777, 1395, 'Irmãos Freitas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106668.mp4', 'http://gstaticontent.com/images/n9qHNVRDBBWcReIo8tOfe4j3806_big.jpg'),
(20778, 1395, 'Irmãos Freitas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106669.mp4', 'http://gstaticontent.com/images/n9qHNVRDBBWcReIo8tOfe4j3806_big.jpg'),
(20779, 1395, 'Irmãos Freitas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106670.mp4', 'http://gstaticontent.com/images/n9qHNVRDBBWcReIo8tOfe4j3806_big.jpg'),
(20780, 1395, 'Irmãos Freitas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106671.mp4', 'http://gstaticontent.com/images/n9qHNVRDBBWcReIo8tOfe4j3806_big.jpg'),
(20781, 1395, 'Irmãos Freitas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106672.mp4', 'http://gstaticontent.com/images/n9qHNVRDBBWcReIo8tOfe4j3806_big.jpg'),
(20782, 1395, 'Irmãos Freitas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106673.mp4', 'http://gstaticontent.com/images/n9qHNVRDBBWcReIo8tOfe4j3806_big.jpg'),
(20783, 1396, 'María Madalena S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107109.mp4', 'http://timg.bdta.pro/images/52cb440305024584698602bcc120c60f.jpg'),
(20784, 1396, 'María Madalena S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107110.mp4', 'http://timg.bdta.pro/images/56c74233cde036af808ca9ec3050f5f7.jpg'),
(20785, 1396, 'María Madalena S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107111.mp4', 'http://timg.bdta.pro/images/07e7a498727c0a5b1ad59f903a284709.jpg'),
(20786, 1396, 'María Madalena S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107112.mp4', 'http://timg.bdta.pro/images/364b0df9e4c47ce78ca0767cc950e52d.jpg'),
(20787, 1396, 'María Madalena S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107113.mp4', 'http://timg.bdta.pro/images/285bcd6cc52c710abfd66967c2e63e13.jpg'),
(20788, 1396, 'María Madalena S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107114.mp4', 'http://timg.bdta.pro/images/3cd7dcdb9cd9da3c6d34bcaec5674d5f.jpg'),
(20789, 1396, 'María Madalena S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107115.mp4', 'http://timg.bdta.pro/images/39c5ab84962d6679f03c1ae49e5ab00d.jpg'),
(20790, 1396, 'María Madalena S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107116.mp4', 'http://timg.bdta.pro/images/3713d6f2fed472a8545d1c4d2e9e6aa6.jpg'),
(20791, 1396, 'María Madalena S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107117.mp4', 'http://timg.bdta.pro/images/15a452c535016b2ce66b4d1320731355.jpg'),
(20792, 1396, 'María Madalena S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107118.mp4', 'http://timg.bdta.pro/images/88fe81b8cf80d77f58bc064a772800fa.jpg'),
(20793, 1396, 'María Madalena S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107119.mp4', 'http://timg.bdta.pro/images/2e896d0a8bcf134b9f1d59786cb365e9.jpg'),
(20794, 1396, 'María Madalena S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107120.mp4', 'http://timg.bdta.pro/images/136d6a7c1bf3ed72ddce324ecceb8b60.jpg'),
(20795, 1396, 'María Madalena S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107121.mp4', 'http://timg.bdta.pro/images/aa4279cf373675837fdb1d9038cf2d22.jpg'),
(20796, 1396, 'María Madalena S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/107122.mp4', 'http://timg.bdta.pro/images/7bb2494a9724d6d4310018c102527560.jpg'),
(20797, 1396, 'María Madalena S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/107123.mp4', 'http://timg.bdta.pro/images/349bc182fcffdae065eb4ec1f5360407.jpg'),
(20798, 1396, 'María Madalena S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/107124.mp4', 'http://timg.bdta.pro/images/9eba0620dfcac1c65a53b3571d6b7dba.jpg'),
(20799, 1396, 'María Madalena S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/107125.mp4', 'http://timg.bdta.pro/images/8da5d03b701fcb346c23dcbe29a159b8.jpg'),
(20800, 1396, 'María Madalena S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/107126.mp4', 'http://timg.bdta.pro/images/077d4af612fe454df77fb61e54880f7f.jpg'),
(20801, 1396, 'María Madalena S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/107127.mp4', 'http://timg.bdta.pro/images/0dbf64d7a9851ac1f136f377c11ee340.jpg'),
(20802, 1396, 'María Madalena S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/107128.mp4', 'http://timg.bdta.pro/images/76d64cbd1bfd6c61d97976fe8a32c663.jpg'),
(20803, 1396, 'María Madalena S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/107129.mp4', 'http://timg.bdta.pro/images/aadbd97c11c29c895a7be26b3088e281.jpg'),
(20804, 1396, 'María Madalena S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/107130.mp4', 'http://timg.bdta.pro/images/f0614064c812b9036cea41aef5722717.jpg'),
(20805, 1396, 'María Madalena S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/107131.mp4', 'http://timg.bdta.pro/images/03ef2bf8c4bae5c8cc466f3c64f0d098.jpg'),
(20806, 1396, 'María Madalena S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/107132.mp4', 'http://timg.bdta.pro/images/d78d4e28e1b03785251e09c4c51f2d6b.jpg'),
(20807, 1396, 'María Madalena S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/107133.mp4', 'http://timg.bdta.pro/images/61c0a56f9cf470050916c9d8699ff831.jpg'),
(20808, 1396, 'María Madalena S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/107134.mp4', 'http://timg.bdta.pro/images/1e3965b192386898ed4eca199c845a0b.jpg'),
(20809, 1396, 'María Madalena S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/107135.mp4', 'http://timg.bdta.pro/images/4316458c7941aef71adbbddf8bcbc268.jpg'),
(20810, 1396, 'María Madalena S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/107136.mp4', 'http://timg.bdta.pro/images/d3b1f65f85eb40ec3346fc0f7093e401.jpg'),
(20811, 1396, 'María Madalena S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/107137.mp4', 'http://timg.bdta.pro/images/07d59d209abd13730a37275d4a49d124.jpg'),
(20812, 1396, 'María Madalena S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/107138.mp4', 'http://timg.bdta.pro/images/56ce5df78364d6b1ce3af716e7b85ac3.jpg'),
(20813, 1396, 'María Madalena S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/107139.mp4', 'http://timg.bdta.pro/images/d8926864d605de4d0b45e9b0ee35fc99.jpg'),
(20814, 1396, 'María Madalena S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/107140.mp4', 'http://timg.bdta.pro/images/eb6014244bbf731a37350fb9f9c1aa53.jpg'),
(20815, 1396, 'María Madalena S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/107141.mp4', 'http://timg.bdta.pro/images/f520ea71d038a4f6dfd879de4b15d42c.jpg'),
(20816, 1396, 'María Madalena S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/107142.mp4', 'http://timg.bdta.pro/images/c98ffd896fee1c15d40b54ffdcf5d12b.jpg'),
(20817, 1396, 'María Madalena S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/107143.mp4', 'http://timg.bdta.pro/images/de6a135626809836fd27be1d4b970161.jpg'),
(20818, 1396, 'María Madalena S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/107144.mp4', 'http://timg.bdta.pro/images/8cf1b0f9f9a8e76e502afd0dcb084501.jpg'),
(20819, 1396, 'María Madalena S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/107145.mp4', 'http://timg.bdta.pro/images/7df613ed60f2d37cd58c2e5097ce4cb4.jpg'),
(20820, 1396, 'María Madalena S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/107146.mp4', 'http://timg.bdta.pro/images/fb072010d9441d600467771d24767e93.jpg'),
(20821, 1396, 'María Madalena S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/107147.mp4', 'http://timg.bdta.pro/images/9331c09099f78cda5267f383ffa7e78b.jpg'),
(20822, 1396, 'María Madalena S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/107148.mp4', 'http://timg.bdta.pro/images/9f1b2a610a8416b3b3b638431f55db16.jpg'),
(20823, 1396, 'María Madalena S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/107149.mp4', 'http://timg.bdta.pro/images/b7365935fb0fb540add9b1f3c6ceb7a6.jpg'),
(20824, 1396, 'María Madalena S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/107150.mp4', 'http://timg.bdta.pro/images/00b4730a2188119af70cab85eea1e6d4.jpg'),
(20825, 1396, 'María Madalena S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/107151.mp4', 'http://timg.bdta.pro/images/aabacac171790c35e605c8e1f911d237.jpg'),
(20826, 1396, 'María Madalena S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/107152.mp4', 'http://timg.bdta.pro/images/56fd24a15a7a29253e2faf936312d8b2.jpg'),
(20827, 1396, 'María Madalena S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/107153.mp4', 'http://timg.bdta.pro/images/85c7a63ced74e32c4a1f142e1de85308.jpg'),
(20828, 1396, 'María Madalena S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/107154.mp4', 'http://timg.bdta.pro/images/a94a92639ef49d5e392a22421ccdbce6.jpg'),
(20829, 1396, 'María Madalena S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/107155.mp4', 'http://timg.bdta.pro/images/afd3a9ec353f9749115322760cd8058d.jpg'),
(20830, 1396, 'María Madalena S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/107156.mp4', 'http://timg.bdta.pro/images/e2d313db027500bd5b19837f5358ddae.jpg'),
(20831, 1396, 'María Madalena S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/107157.mp4', 'http://timg.bdta.pro/images/eed39909cbbda019c054cc38cc907d68.jpg'),
(20832, 1396, 'María Madalena S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/107158.mp4', 'http://timg.bdta.pro/images/8cea7eb63e7ac491f0ac20aa9103eee7.jpg'),
(20833, 1396, 'María Madalena S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/107159.mp4', 'http://timg.bdta.pro/images/0065527c3735829d37ec3d133ac8ff73.jpg'),
(20834, 1396, 'María Madalena S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/107160.mp4', 'http://timg.bdta.pro/images/2976d8edfa061f5535543cab066ae322.jpg'),
(20835, 1396, 'María Madalena S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/107161.mp4', 'http://timg.bdta.pro/images/24b78a1bb98c1c9dced4cc2277d2e624.jpg'),
(20836, 1396, 'María Madalena S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/107162.mp4', 'http://timg.bdta.pro/images/51b45f28e981588e46cca3585452c6da.jpg'),
(20837, 1396, 'María Madalena S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/107163.mp4', 'http://timg.bdta.pro/images/f04ccfc582ec22e2028b4f557ef48082.jpg'),
(20838, 1396, 'María Madalena S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/107164.mp4', 'http://timg.bdta.pro/images/bbebde00a622610c1e2655370372b8a9.jpg'),
(20839, 1396, 'María Madalena S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/107165.mp4', 'http://timg.bdta.pro/images/9b3debe35fa9ba2660e71279c4e7d730.jpg'),
(20840, 1396, 'María Madalena S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/107166.mp4', 'http://timg.bdta.pro/images/ff0295597a7bde66fb7c1118e8434410.jpg'),
(20841, 1396, 'María Madalena S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/107167.mp4', 'http://timg.bdta.pro/images/a503b5cf6d8cf3dc5541df83013eb1bb.jpg'),
(20842, 1396, 'María Madalena S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/107168.mp4', 'http://timg.bdta.pro/images/9e9b0112e3145fac19c0217a659075b3.jpg'),
(20843, 1397, 'Mayans M.C. S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231712.mp4', 'http://timg.bdta.pro/images/3d9a645a73d0916aadeaac9a3a97bf52.jpg'),
(20844, 1397, 'Mayans M.C. S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231713.mp4', 'http://timg.bdta.pro/images/80d5761ca1999da63c17bff9bf421191.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(20845, 1397, 'Mayans M.C. S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231714.mp4', 'http://timg.bdta.pro/images/adaf8d38aaa349fa51dc4afc253213e9.jpg'),
(20846, 1397, 'Mayans M.C. S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231715.mp4', 'http://timg.bdta.pro/images/cc7fcce66fe553c8346ecd189ddce237.jpg'),
(20847, 1397, 'Mayans M.C. S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231716.mp4', 'http://timg.bdta.pro/images/1d4685dc2d83e9140afc346d4aa2ae6c.jpg'),
(20848, 1397, 'Mayans M.C. S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231717.mp4', 'http://timg.bdta.pro/images/1c5b3503f407206918110d075525259a.jpg'),
(20849, 1397, 'Mayans M.C. S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231718.mp4', 'http://timg.bdta.pro/images/4e45a9da070ada69c00525b9450fd0e3.jpg'),
(20850, 1397, 'Mayans M.C. S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231719.mp4', 'http://timg.bdta.pro/images/fcf4dc71aaed3dbe45d3977bff2a9815.jpg'),
(20851, 1397, 'Mayans M.C. S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231720.mp4', 'http://timg.bdta.pro/images/2d97400d3f42e471a25d3a586b8cb45e.jpg'),
(20852, 1397, 'Mayans M.C. S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231721.mp4', 'http://timg.bdta.pro/images/7ab5f65f5908a34c272f8ff213be89c0.jpg'),
(20853, 1398, 'Mayans M.C. S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231722.mp4', 'http://timg.bdta.pro/images/e305060741d1983de999d250ca758709.jpg'),
(20854, 1398, 'Mayans M.C. S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231723.mp4', 'http://timg.bdta.pro/images/bfa89066c592718785eb361b9df97452.jpg'),
(20855, 1398, 'Mayans M.C. S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231724.mp4', 'http://timg.bdta.pro/images/d0a55dde2ccb438a7c98899554bc120d.jpg'),
(20856, 1398, 'Mayans M.C. S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231725.mp4', 'http://timg.bdta.pro/images/9e784fed89c8b380b52d6ad5085be194.jpg'),
(20857, 1398, 'Mayans M.C. S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231726.mp4', 'http://timg.bdta.pro/images/3a8b266fb3a8a6471020fa4f83505b66.jpg'),
(20858, 1398, 'Mayans M.C. S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231727.mp4', 'http://timg.bdta.pro/images/c728f89ce73da4430ada5957adc022fa.jpg'),
(20859, 1398, 'Mayans M.C. S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231728.mp4', 'http://timg.bdta.pro/images/7ccd058be2aab2b97b0dd95d461c252f.jpg'),
(20860, 1398, 'Mayans M.C. S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231729.mp4', 'http://timg.bdta.pro/images/16c888af3269557ab89819275f0f2312.jpg'),
(20861, 1398, 'Mayans M.C. S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231730.mp4', 'http://timg.bdta.pro/images/304505db298dc15f736f589ee784cc6c.jpg'),
(20862, 1398, 'Mayans M.C. S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231731.mp4', 'http://timg.bdta.pro/images/1fbea47416535ac40309ddb3969959ed.jpg'),
(20863, 1399, 'Mayans M.C. S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231732.mp4', 'http://gstaticontent.com/images/y8PYGJ7TGjtMxwPA5Mhwa9svTRJ_big.jpg'),
(20864, 1399, 'Mayans M.C. S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231733.mp4', 'http://gstaticontent.com/images/y8PYGJ7TGjtMxwPA5Mhwa9svTRJ_big.jpg'),
(20865, 1399, 'Mayans M.C. S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231734.mp4', 'http://gstaticontent.com/images/y8PYGJ7TGjtMxwPA5Mhwa9svTRJ_big.jpg'),
(20866, 1399, 'Mayans M.C. S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231735.mp4', 'http://gstaticontent.com/images/y8PYGJ7TGjtMxwPA5Mhwa9svTRJ_big.jpg'),
(20867, 1399, 'Mayans M.C. S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231736.mp4', 'http://gstaticontent.com/images/y8PYGJ7TGjtMxwPA5Mhwa9svTRJ_big.jpg'),
(20868, 1399, 'Mayans M.C. S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231737.mp4', 'http://gstaticontent.com/images/y8PYGJ7TGjtMxwPA5Mhwa9svTRJ_big.jpg'),
(20869, 1399, 'Mayans M.C. S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231738.mp4', 'http://gstaticontent.com/images/y8PYGJ7TGjtMxwPA5Mhwa9svTRJ_big.jpg'),
(20870, 1399, 'Mayans M.C. S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231739.mp4', 'http://gstaticontent.com/images/y8PYGJ7TGjtMxwPA5Mhwa9svTRJ_big.jpg'),
(20871, 1399, 'Mayans M.C. S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231740.mp4', 'http://gstaticontent.com/images/y8PYGJ7TGjtMxwPA5Mhwa9svTRJ_big.jpg'),
(20872, 1399, 'Mayans M.C. S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231741.mp4', 'http://gstaticontent.com/images/y8PYGJ7TGjtMxwPA5Mhwa9svTRJ_big.jpg'),
(20873, 1400, 'Mayans M.C. S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dr1zmOdq40Dsd8oWkWXYawsjZoH.jpg'),
(20874, 1400, 'Mayans M.C. S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xH0RUC7rlDt46nQCmBrjTFUcwa9.jpg'),
(20875, 1400, 'Mayans M.C. S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7cXDKS7UzzzlwauRdEz2FTX5Hy.jpg'),
(20876, 1400, 'Mayans M.C. S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mHzn8u4o4b077lH7cRGlYr5HSYz.jpg'),
(20877, 1400, 'Mayans M.C. S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ckpPr5bx4cf2UkSlrud4out6ao7.jpg'),
(20878, 1400, 'Mayans M.C. S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qz71gm2CxNV39aX05k1riXJz34g.jpg'),
(20879, 1400, 'Mayans M.C. S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Y7SsVgi2O230XaHC7MS2kQq8HD.jpg'),
(20880, 1400, 'Mayans M.C. S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mHzXXeFCNGNndYjWZuRO82ieh2W.jpg'),
(20881, 1400, 'Mayans M.C. S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nc6sGnrMfh0nmMSrw9awrYzjPpT.jpg'),
(20882, 1400, 'Mayans M.C. S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/18dNeOrPWGsRzPxCLwxJlakDuGy.jpg'),
(20883, 1401, 'Mayans M.C. S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9J9Str45fFtGTGzgGu2RoPHcmxV.jpg'),
(20884, 1401, 'Mayans M.C. S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x2sRx9XWFMK0kqJRQxczZaiwzYd.jpg'),
(20885, 1401, 'Mayans M.C. S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sJglOcXunDGRwsrBtUNncdyoZwT.jpg'),
(20886, 1401, 'Mayans M.C. S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8dbopAg6Xbm3KG4wFlu4zJetqEW.jpg'),
(20887, 1401, 'Mayans M.C. S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231756.mp4', 'http://image.tmdb.org/t/p/w1280/1L0O2hAmXpYpleWYpvD6N8tCs7a.jpg'),
(20888, 1401, 'Mayans M.C. S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231757.mp4', 'http://image.tmdb.org/t/p/w1280/44YQwAx4wRs9QlV83Fwhz7RjFMj.jpg'),
(20889, 1401, 'Mayans M.C. S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231758.mp4', 'http://image.tmdb.org/t/p/w1280/etdiOHLRXHJin5Hx84pSsL8j6wU.jpg'),
(20890, 1401, 'Mayans M.C. S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231759.mp4', 'http://image.tmdb.org/t/p/w1280/a3IzP0EVH8bBERs8eZlzgbkhY5E.jpg'),
(20891, 1401, 'Mayans M.C. S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231760.mp4', 'http://image.tmdb.org/t/p/w1280/z4SsjrSyeBt1lAdyuWJLEpCmv57.jpg'),
(20892, 1401, 'Mayans M.C. S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231761.mp4', 'http://gstaticontent.com/images/y8PYGJ7TGjtMxwPA5Mhwa9svTRJ_big.jpg'),
(20893, 1402, 'Monarca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135108.mp4', 'http://gstaticontent.com/images/rn83wKCiDgJlHNwcEop8fwJUFLc_big.jpg'),
(20894, 1402, 'Monarca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135109.mp4', 'http://gstaticontent.com/images/rn83wKCiDgJlHNwcEop8fwJUFLc_big.jpg'),
(20895, 1402, 'Monarca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135110.mp4', 'http://gstaticontent.com/images/rn83wKCiDgJlHNwcEop8fwJUFLc_big.jpg'),
(20896, 1402, 'Monarca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135111.mp4', 'http://gstaticontent.com/images/rn83wKCiDgJlHNwcEop8fwJUFLc_big.jpg'),
(20897, 1402, 'Monarca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135112.mp4', 'http://gstaticontent.com/images/rn83wKCiDgJlHNwcEop8fwJUFLc_big.jpg'),
(20898, 1402, 'Monarca S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135113.mp4', 'http://gstaticontent.com/images/rn83wKCiDgJlHNwcEop8fwJUFLc_big.jpg'),
(20899, 1402, 'Monarca S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135114.mp4', 'http://gstaticontent.com/images/rn83wKCiDgJlHNwcEop8fwJUFLc_big.jpg'),
(20900, 1402, 'Monarca S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135115.mp4', 'http://gstaticontent.com/images/rn83wKCiDgJlHNwcEop8fwJUFLc_big.jpg'),
(20901, 1402, 'Monarca S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135116.mp4', 'http://gstaticontent.com/images/rn83wKCiDgJlHNwcEop8fwJUFLc_big.jpg'),
(20902, 1402, 'Monarca S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135117.mp4', 'http://gstaticontent.com/images/rn83wKCiDgJlHNwcEop8fwJUFLc_big.jpg'),
(20903, 1403, 'Mr. Mercedes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/112845.mp4', 'http://timg.bdta.pro/images/2afbdb61e31d4241d994d63b647add92.jpg'),
(20904, 1403, 'Mr. Mercedes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/112846.mp4', 'http://timg.bdta.pro/images/4d6ffa60505c05c61a27c70dcab19fa1.jpg'),
(20905, 1403, 'Mr. Mercedes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/112847.mp4', 'http://timg.bdta.pro/images/7fcfe8b35e6b8bbf70c053d57edc6adf.jpg'),
(20906, 1403, 'Mr. Mercedes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/112848.mp4', 'http://timg.bdta.pro/images/143f37fd0593709c608c41fb3f22da03.jpg'),
(20907, 1403, 'Mr. Mercedes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/112849.mp4', 'http://timg.bdta.pro/images/0b447769026c2a1fbcfa30e4cc3e9d37.jpg'),
(20908, 1403, 'Mr. Mercedes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/112850.mp4', 'http://timg.bdta.pro/images/33947b7ba3dc5c298553b1bdfbfb4925.jpg'),
(20909, 1403, 'Mr. Mercedes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/112851.mp4', 'http://timg.bdta.pro/images/49db4ea9d3eba03d5dcd71dff0b39837.jpg'),
(20910, 1403, 'Mr. Mercedes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/112852.mp4', 'http://timg.bdta.pro/images/10c6b689787faae76d1710c59974b9ca.jpg'),
(20911, 1403, 'Mr. Mercedes S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/112853.mp4', 'http://timg.bdta.pro/images/2894e38dab9325cfb44737f9dd8557a4.jpg'),
(20912, 1403, 'Mr. Mercedes S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/112854.mp4', 'http://timg.bdta.pro/images/bdc3cd1b2d261702b1c1979cab599888.jpg'),
(20913, 1404, 'Mr. Mercedes S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/112855.mp4', 'http://timg.bdta.pro/images/d28fe0cead3b4979ac448c6079543961.jpg'),
(20914, 1404, 'Mr. Mercedes S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/112856.mp4', 'http://timg.bdta.pro/images/01ebe5fe43b24efac95bd94f3d24a713.jpg'),
(20915, 1404, 'Mr. Mercedes S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/112857.mp4', 'http://timg.bdta.pro/images/def24fda71634876ea807de6c54bf01a.jpg'),
(20916, 1404, 'Mr. Mercedes S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/112858.mp4', 'http://timg.bdta.pro/images/5ca8f8742030a01f3c2501595799b8b9.jpg'),
(20917, 1404, 'Mr. Mercedes S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/112859.mp4', 'http://timg.bdta.pro/images/4f0124b420519d7361ef70e52d2fb4ae.jpg'),
(20918, 1404, 'Mr. Mercedes S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/112860.mp4', 'http://timg.bdta.pro/images/bcf54b8b3775be9fe24d09399cc2b5c5.jpg'),
(20919, 1404, 'Mr. Mercedes S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/112861.mp4', 'http://timg.bdta.pro/images/71a5d798b9b91b940033ea73c7493940.jpg'),
(20920, 1404, 'Mr. Mercedes S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/112862.mp4', 'http://timg.bdta.pro/images/d3f999168702e70d1fc59ed280dfce1e.jpg'),
(20921, 1404, 'Mr. Mercedes S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/112863.mp4', 'http://timg.bdta.pro/images/140db89a3078ad9ecb28f9c89236988f.jpg'),
(20922, 1404, 'Mr. Mercedes S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/112864.mp4', 'http://timg.bdta.pro/images/78b8289eb375fe4dcc2fd869705315dc.jpg'),
(20923, 1405, 'Mr. Mercedes S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/112865.mp4', 'http://timg.bdta.pro/images/c4f4d6ba8687de18c33499fd7b59b130.jpg'),
(20924, 1405, 'Mr. Mercedes S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/112866.mp4', 'http://timg.bdta.pro/images/1bbb46ae1f13a345b28425c6d241da24.jpg'),
(20925, 1405, 'Mr. Mercedes S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/112867.mp4', 'http://timg.bdta.pro/images/1f475adf44b37b5627b83ad62afc2355.jpg'),
(20926, 1405, 'Mr. Mercedes S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/112868.mp4', 'http://timg.bdta.pro/images/169ef99b378430cc97f45bae865535a0.jpg'),
(20927, 1405, 'Mr. Mercedes S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/112869.mp4', 'http://timg.bdta.pro/images/8c807a70ccf804c824c151e93dc9c5ca.jpg'),
(20928, 1405, 'Mr. Mercedes S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/112870.mp4', 'http://timg.bdta.pro/images/7da1034099403b2461a178585602829a.jpg'),
(20929, 1405, 'Mr. Mercedes S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/112871.mp4', 'http://timg.bdta.pro/images/270c5461be8d2c9edcfe8bd0e14a4180.jpg'),
(20930, 1405, 'Mr. Mercedes S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/112872.mp4', 'http://timg.bdta.pro/images/2ddb7b869e19a6e8bc31b1399bdb6355.jpg'),
(20931, 1405, 'Mr. Mercedes S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/112873.mp4', 'http://timg.bdta.pro/images/88a20ba731fb0dbec071f1fd7685444a.jpg'),
(20932, 1405, 'Mr. Mercedes S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/112874.mp4', 'http://timg.bdta.pro/images/873aca6171476985f9bb05f0770669cc.jpg'),
(20933, 1406, 'Ninguém Tá Olhando S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107101.mp4', 'http://timg.bdta.pro/images/1efeca909eb15a41982cf1afba01ca32.jpg'),
(20934, 1406, 'Ninguém Tá Olhando S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107102.mp4', 'http://timg.bdta.pro/images/76422ed233844168610f0898660b1040.jpg'),
(20935, 1406, 'Ninguém Tá Olhando S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107103.mp4', 'http://timg.bdta.pro/images/e885114013a05da6690213b03c76e4dc.jpg'),
(20936, 1406, 'Ninguém Tá Olhando S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107104.mp4', 'http://timg.bdta.pro/images/b0eba75dc2c9d21f4a023abafc3e8d45.jpg'),
(20937, 1406, 'Ninguém Tá Olhando S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107105.mp4', 'http://timg.bdta.pro/images/84628027bb1b86a4bb8e832ed7d8982b.jpg'),
(20938, 1406, 'Ninguém Tá Olhando S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107106.mp4', 'http://timg.bdta.pro/images/5bea86c9f8a676e06057c4703304982f.jpg'),
(20939, 1406, 'Ninguém Tá Olhando S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107107.mp4', 'http://timg.bdta.pro/images/2941f5d2a5e199e5bea21bb7bdaaa06e.jpg'),
(20940, 1406, 'Ninguém Tá Olhando S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107108.mp4', 'http://timg.bdta.pro/images/24a4075208755d5d3e510c0239be932a.jpg'),
(20941, 1407, 'O Codigo Bill Gates S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107098.mp4', 'http://timg.bdta.pro/images/f86df4dc19b36c6e79dda42904512ba1.jpg'),
(20942, 1407, 'O Codigo Bill Gates S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107099.mp4', 'http://timg.bdta.pro/images/6b88aa45cceb5697f86308fb66f47d67.jpg'),
(20943, 1407, 'O Codigo Bill Gates S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107100.mp4', 'http://timg.bdta.pro/images/ca6fab46aa41084be2e41898feadec22.jpg'),
(20944, 1408, 'Os Agentes Secretos De Churchill Novos Recrutas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107086.mp4', 'http://timg.bdta.pro/images/716d34dcf7a8129308519448b59eb7a4.jpg'),
(20945, 1408, 'Os Agentes Secretos De Churchill Novos Recrutas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107087.mp4', 'http://timg.bdta.pro/images/6eafb16a42ec41e84adb465509744bca.jpg'),
(20946, 1408, 'Os Agentes Secretos De Churchill Novos Recrutas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107088.mp4', 'http://timg.bdta.pro/images/36b574d35bdb3f9ec4b20856f05032c9.jpg'),
(20947, 1408, 'Os Agentes Secretos De Churchill Novos Recrutas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107089.mp4', 'http://timg.bdta.pro/images/078bbfc306ed9e541ea57fb971183dfc.jpg'),
(20948, 1408, 'Os Agentes Secretos De Churchill Novos Recrutas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107090.mp4', 'http://timg.bdta.pro/images/13b21ba3de458c5f5f96d38356083aa0.jpg'),
(20949, 1409, 'Pennyworth: A Origem do Mordomo do Batman S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200876.mp4', 'http://timg.bdta.pro/images/c1c13282e044fb4bbaa2b7bb85b904a3.jpg'),
(20950, 1409, 'Pennyworth: A Origem do Mordomo do Batman S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200877.mp4', 'http://timg.bdta.pro/images/918cfe8d5a40eedc477e6c153c9de130.jpg'),
(20951, 1409, 'Pennyworth: A Origem do Mordomo do Batman S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200878.mp4', 'http://timg.bdta.pro/images/939e5144a95d831345e447c427b26d90.jpg'),
(20952, 1409, 'Pennyworth: A Origem do Mordomo do Batman S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200879.mp4', 'http://timg.bdta.pro/images/90a49170811b6b28fa7eadc69001a1f1.jpg'),
(20953, 1409, 'Pennyworth: A Origem do Mordomo do Batman S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200880.mp4', 'http://timg.bdta.pro/images/a4339209cca8be2151da6a6ad5359420.jpg'),
(20954, 1409, 'Pennyworth: A Origem do Mordomo do Batman S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200881.mp4', 'http://timg.bdta.pro/images/fb9b7a11ba4c665c2034f3c1f79929c0.jpg'),
(20955, 1409, 'Pennyworth: A Origem do Mordomo do Batman S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200882.mp4', 'http://timg.bdta.pro/images/4c52bb31df4f97c3e25534deb3a3b59e.jpg'),
(20956, 1409, 'Pennyworth: A Origem do Mordomo do Batman S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200883.mp4', 'http://timg.bdta.pro/images/b6c1f85bbf52d08f24789c95319d2b3c.jpg'),
(20957, 1409, 'Pennyworth: A Origem do Mordomo do Batman S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/564359.mp4', 'http://gstaticontent.com/images/11671ef71a071362e59f40431fdd1996.jpg'),
(20958, 1409, 'Pennyworth: A Origem do Mordomo do Batman S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/564361.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m2ODj9sFPZ7ffqPE07rsDlcgylD.jpg'),
(20959, 1410, 'Pennyworth: A Origem do Mordomo do Batman S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200888.mp4', 'http://gstaticontent.com/images/94bf5080f1e702f470e32f5b90a1b58b.jpg'),
(20960, 1410, 'Pennyworth: A Origem do Mordomo do Batman S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200889.mp4', 'http://gstaticontent.com/images/94bf5080f1e702f470e32f5b90a1b58b.jpg'),
(20961, 1410, 'Pennyworth: A Origem do Mordomo do Batman S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200890.mp4', 'http://gstaticontent.com/images/94bf5080f1e702f470e32f5b90a1b58b.jpg'),
(20962, 1410, 'Pennyworth: A Origem do Mordomo do Batman S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200891.mp4', 'http://gstaticontent.com/images/94bf5080f1e702f470e32f5b90a1b58b.jpg'),
(20963, 1410, 'Pennyworth: A Origem do Mordomo do Batman S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200892.mp4', 'http://gstaticontent.com/images/94bf5080f1e702f470e32f5b90a1b58b.jpg'),
(20964, 1410, 'Pennyworth: A Origem do Mordomo do Batman S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200893.mp4', 'http://gstaticontent.com/images/94bf5080f1e702f470e32f5b90a1b58b.jpg'),
(20965, 1410, 'Pennyworth: A Origem do Mordomo do Batman S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200894.mp4', 'http://gstaticontent.com/images/94bf5080f1e702f470e32f5b90a1b58b.jpg'),
(20966, 1410, 'Pennyworth: A Origem do Mordomo do Batman S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200895.mp4', 'http://gstaticontent.com/images/94bf5080f1e702f470e32f5b90a1b58b.jpg'),
(20967, 1410, 'Pennyworth: A Origem do Mordomo do Batman S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200896.mp4', 'http://gstaticontent.com/images/94bf5080f1e702f470e32f5b90a1b58b.jpg'),
(20968, 1410, 'Pennyworth: A Origem do Mordomo do Batman S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200897.mp4', 'http://gstaticontent.com/images/94bf5080f1e702f470e32f5b90a1b58b.jpg'),
(20969, 1411, 'Pennyworth: A Origem do Mordomo do Batman S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200898.mp4', 'http://timg.bdta.pro/images/1c3cfcd6884520c007f32f8b126bb0d8.jpg'),
(20970, 1411, 'Pennyworth: A Origem do Mordomo do Batman S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200899.mp4', 'http://timg.bdta.pro/images/147465f4d7d82a2bb2e66ceeec8b8750.jpg'),
(20971, 1411, 'Pennyworth: A Origem do Mordomo do Batman S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200900.mp4', 'http://timg.bdta.pro/images/92cd10ed82b72b4496a59925a4ea605f.jpg'),
(20972, 1411, 'Pennyworth: A Origem do Mordomo do Batman S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200901.mp4', 'http://timg.bdta.pro/images/0a21bac496e25de671245a912368e861.jpg'),
(20973, 1411, 'Pennyworth: A Origem do Mordomo do Batman S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200902.mp4', 'http://timg.bdta.pro/images/f81cfac839bbcd7def0e06775a467f01.jpg'),
(20974, 1411, 'Pennyworth: A Origem do Mordomo do Batman S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rsDubjpw5HIwHF12e5HazpUErQ7.jpg'),
(20975, 1411, 'Pennyworth: A Origem do Mordomo do Batman S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e3liajxsWP6FjAEprx2qmjxxyDp.jpg'),
(20976, 1411, 'Pennyworth: A Origem do Mordomo do Batman S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200905.mp4', 'http://image.tmdb.org/t/p/w1280/bIpvcjvQJ3C30o4eLq8ZN7ErjEI.jpg'),
(20977, 1412, 'Proven Innocent [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107020.mp4', 'http://timg.bdta.pro/images/91570a170f74dcc506a4e1a350431d57.jpg'),
(20978, 1412, 'Proven Innocent [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107021.mp4', 'http://timg.bdta.pro/images/7f52d6bb660ceca6861707ee3296350e.jpg'),
(20979, 1412, 'Proven Innocent [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107022.mp4', 'http://timg.bdta.pro/images/9a9ad7ac940e1b60434cb0edd048fbc0.jpg'),
(20980, 1412, 'Proven Innocent [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107023.mp4', 'http://timg.bdta.pro/images/d415f25aaedd0d8eca365f4421ca5cd0.jpg'),
(20981, 1412, 'Proven Innocent [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107024.mp4', 'http://timg.bdta.pro/images/0ea8b13f9a11af37e4166b4cbe745193.jpg'),
(20982, 1412, 'Proven Innocent [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107025.mp4', 'http://timg.bdta.pro/images/ecc88ee0d2bf4d1bad37e22e87483d42.jpg'),
(20983, 1412, 'Proven Innocent [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107026.mp4', 'http://timg.bdta.pro/images/c55095b5d98b6168eba9ffc18e425579.jpg'),
(20984, 1412, 'Proven Innocent [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107027.mp4', 'http://timg.bdta.pro/images/64f1a3cdd3df7bcbaef6634c30677d43.jpg'),
(20985, 1412, 'Proven Innocent [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107028.mp4', 'http://timg.bdta.pro/images/5c0d9f1448433919f51fcd2a95f4f54f.jpg'),
(20986, 1412, 'Proven Innocent [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107029.mp4', 'http://timg.bdta.pro/images/7f1641a9897d7df5f5a4be713b92f8df.jpg'),
(20987, 1412, 'Proven Innocent [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107030.mp4', 'http://timg.bdta.pro/images/8ba5d55bca0f1652455d503ee34b1d66.jpg'),
(20988, 1412, 'Proven Innocent [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107031.mp4', 'http://timg.bdta.pro/images/b9650fb90ccb7513cbc84c05052316d0.jpg'),
(20989, 1412, 'Proven Innocent [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107032.mp4', 'http://timg.bdta.pro/images/92886a00e1fecae128252454b621a8fd.jpg'),
(20990, 1413, 'Retaliacao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107009.mp4', 'http://timg.bdta.pro/images/84ebe8af5624a00e341cc6457582a42d.jpg'),
(20991, 1413, 'Retaliacao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107010.mp4', 'http://timg.bdta.pro/images/886213784cfbf8499f7a77d2fa54a571.jpg'),
(20992, 1413, 'Retaliacao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107011.mp4', 'http://timg.bdta.pro/images/cb78f8b8f118c1152ede75a593f729e9.jpg'),
(20993, 1413, 'Retaliacao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107012.mp4', 'http://timg.bdta.pro/images/2c231daf2010dc4f781476c8893f2cda.jpg'),
(20994, 1413, 'Retaliacao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107013.mp4', 'http://timg.bdta.pro/images/b42f0f9cf05469a03f15b481fe2c5460.jpg'),
(20995, 1413, 'Retaliacao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107014.mp4', 'http://timg.bdta.pro/images/1e41e9a1a87df865a003c17de5933423.jpg'),
(20996, 1413, 'Retaliacao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107015.mp4', 'http://timg.bdta.pro/images/b812e26c6ca0bfe5f0647191b890b0e0.jpg'),
(20997, 1413, 'Retaliacao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107016.mp4', 'http://timg.bdta.pro/images/9ff61d784eb63452072eab314c1ff8c1.jpg'),
(20998, 1413, 'Retaliacao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107017.mp4', 'http://timg.bdta.pro/images/8002c1e248744b72012e4b16c89a92b9.jpg'),
(20999, 1413, 'Retaliacao S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107018.mp4', 'http://timg.bdta.pro/images/83edf6639980a063c6689380156e1a6d.jpg'),
(21000, 1413, 'Retaliacao S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107019.mp4', 'http://timg.bdta.pro/images/74e254bb3feede2b3e298873c19c4fd9.jpg'),
(21001, 1414, 'See S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200167.mp4', 'http://timg.bdta.pro/images/5211035b5776e04d085ab9214794eb18.jpg'),
(21002, 1414, 'See S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200168.mp4', 'http://timg.bdta.pro/images/1f5c2d25aeec88c7b55690a52b477c77.jpg'),
(21003, 1414, 'See S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200169.mp4', 'http://timg.bdta.pro/images/3433b3cfa536bfad1709e09638fbc56c.jpg'),
(21004, 1414, 'See S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200170.mp4', 'http://timg.bdta.pro/images/10cdf6aba31dcd8513cbba53c3afac84.jpg'),
(21005, 1414, 'See S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200171.mp4', 'http://timg.bdta.pro/images/a1ce6ca626d9d4da748d697e37e96fb1.jpg'),
(21006, 1414, 'See S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200172.mp4', 'http://timg.bdta.pro/images/bf2fb152fd6d447ccc7fb9ba210a6931.jpg'),
(21007, 1414, 'See S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200173.mp4', 'http://timg.bdta.pro/images/94c71ddd21cf964980c3dcf73da9ec51.jpg'),
(21008, 1414, 'See S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200174.mp4', 'http://timg.bdta.pro/images/7956704af3977ea0bfccbdd73a671d4e.jpg'),
(21009, 1415, 'See S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200175.mp4', 'http://timg.bdta.pro/images/6e6b9f36b9feb73158c802f0e7bc17de.jpg'),
(21010, 1415, 'See S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200176.mp4', 'http://timg.bdta.pro/images/187a66fc81ec1b75cf4d1c6e347c599c.jpg'),
(21011, 1415, 'See S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200177.mp4', 'http://timg.bdta.pro/images/50e39e5345d828a7a779cfa1c0af3399.jpg'),
(21012, 1415, 'See S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200178.mp4', 'http://timg.bdta.pro/images/01b67674e23f963fe4453406774dc2c9.jpg'),
(21013, 1415, 'See S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200179.mp4', 'http://image.tmdb.org/t/p/w1280/hUrDDzcx3WKjJD4o7itMuxgZ195.jpg'),
(21014, 1415, 'See S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200180.mp4', 'http://image.tmdb.org/t/p/w1280/vqN8j3m8tyRYfGSJCazkWm9KAya.jpg'),
(21015, 1415, 'See S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200181.mp4', 'http://image.tmdb.org/t/p/w1280/16z9I068CbNtD9ux4etfaZXswGt.jpg'),
(21016, 1415, 'See S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200182.mp4', 'http://image.tmdb.org/t/p/w1280/r5NgxarUrc2KYr8MAIacokIkU4S.jpg'),
(21017, 1416, 'See S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200183.mp4', 'http://timg.bdta.pro/images/5e40af7892a9d25e7c44d9d6dfd06f2f.jpg'),
(21018, 1416, 'See S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200184.mp4', 'http://timg.bdta.pro/images/d787a32b723eb86790d17e5326abc0fe.jpg'),
(21019, 1416, 'See S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200185.mp4', 'http://timg.bdta.pro/images/c2c47f8abafcb1651204f738694a758d.jpg'),
(21020, 1416, 'See S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200186.mp4', 'http://timg.bdta.pro/images/0e6b70c92e29e4ebd071867209fe380d.jpg'),
(21021, 1416, 'See S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200187.mp4', 'http://timg.bdta.pro/images/03030b9976ca5510adb8662850ba3e76.jpg'),
(21022, 1416, 'See S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200188.mp4', 'http://timg.bdta.pro/images/623355d8711824c446b09b0fa81259f0.jpg'),
(21023, 1416, 'See S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200189.mp4', 'http://timg.bdta.pro/images/dafd5e7ca0b591ffb3293901a370bd54.jpg'),
(21024, 1416, 'See S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200190.mp4', 'http://timg.bdta.pro/images/cba26d8139c6b1b1134c7f3032e49480.jpg'),
(21025, 1417, 'Segunda Chamada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194810.mp4', 'http://timg.bdta.pro/images/a1fe561400b5e0851c7097ef99eca72b.jpg'),
(21026, 1417, 'Segunda Chamada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194811.mp4', 'http://timg.bdta.pro/images/5e4560834ee279ed0073d56723a4528e.jpg'),
(21027, 1417, 'Segunda Chamada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194812.mp4', 'http://timg.bdta.pro/images/e4293fa69be11a2bdff26e0ed61cd101.jpg'),
(21028, 1417, 'Segunda Chamada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194813.mp4', 'http://timg.bdta.pro/images/b67708f8e43132a778c8101b3da4722a.jpg'),
(21029, 1417, 'Segunda Chamada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194814.mp4', 'http://timg.bdta.pro/images/7d0538b3658c006304741f1eecc3a495.jpg'),
(21030, 1417, 'Segunda Chamada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194815.mp4', 'http://timg.bdta.pro/images/ea0e21e22c5b8a94a04415b52d75a28e.jpg'),
(21031, 1417, 'Segunda Chamada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194816.mp4', 'http://timg.bdta.pro/images/53acab6a56097d827a217acb63097707.jpg'),
(21032, 1417, 'Segunda Chamada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194817.mp4', 'http://timg.bdta.pro/images/5c9fd2028b97ba10ad4a1d67acee028f.jpg'),
(21033, 1417, 'Segunda Chamada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194818.mp4', 'http://gstaticontent.com/images/loVlwMYVqV1svNgxyGh15S2EaXG_big.jpg'),
(21034, 1417, 'Segunda Chamada S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194819.mp4', 'http://gstaticontent.com/images/loVlwMYVqV1svNgxyGh15S2EaXG_big.jpg'),
(21035, 1418, 'Segunda Chamada S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194820.mp4', 'http://gstaticontent.com/images/loVlwMYVqV1svNgxyGh15S2EaXG_big.jpg'),
(21036, 1418, 'Segunda Chamada S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194821.mp4', 'http://gstaticontent.com/images/loVlwMYVqV1svNgxyGh15S2EaXG_big.jpg'),
(21037, 1418, 'Segunda Chamada S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194822.mp4', 'http://gstaticontent.com/images/loVlwMYVqV1svNgxyGh15S2EaXG_big.jpg'),
(21038, 1418, 'Segunda Chamada S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194823.mp4', 'http://gstaticontent.com/images/loVlwMYVqV1svNgxyGh15S2EaXG_big.jpg'),
(21039, 1418, 'Segunda Chamada S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194824.mp4', 'http://gstaticontent.com/images/loVlwMYVqV1svNgxyGh15S2EaXG_big.jpg'),
(21040, 1418, 'Segunda Chamada S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194825.mp4', 'http://gstaticontent.com/images/loVlwMYVqV1svNgxyGh15S2EaXG_big.jpg'),
(21041, 1419, 'Seis Manos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107001.mp4', 'http://timg.bdta.pro/images/1748968a6cb9c6a33947fdc9c20ab0c0.jpg'),
(21042, 1419, 'Seis Manos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107002.mp4', 'http://timg.bdta.pro/images/aa508e76edae28e38e93fcfe515c1e56.jpg'),
(21043, 1419, 'Seis Manos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107003.mp4', 'http://timg.bdta.pro/images/a2bd399d0f99b93512ba33ac28488663.jpg'),
(21044, 1419, 'Seis Manos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107004.mp4', 'http://timg.bdta.pro/images/e5e20d253826019f5e8a43f2ac186ef9.jpg'),
(21045, 1419, 'Seis Manos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107005.mp4', 'http://timg.bdta.pro/images/a480ac67b26993191d22a02c0bed7056.jpg'),
(21046, 1419, 'Seis Manos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107006.mp4', 'http://timg.bdta.pro/images/33420f09567e739248370d528960bc42.jpg'),
(21047, 1419, 'Seis Manos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107007.mp4', 'http://timg.bdta.pro/images/af1edd97d395e1a076d82770952be936.jpg'),
(21048, 1419, 'Seis Manos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107008.mp4', 'http://timg.bdta.pro/images/4c38845a7be0eb734a55aa09308f3b03.jpg'),
(21049, 1420, 'The Act S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106859.mp4', 'http://gstaticontent.com/images/vb1sQLC2MqfCPOFqHd8SyVsyDVB_big.jpg'),
(21050, 1420, 'The Act S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106860.mp4', 'http://gstaticontent.com/images/vb1sQLC2MqfCPOFqHd8SyVsyDVB_big.jpg'),
(21051, 1420, 'The Act S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106861.mp4', 'http://gstaticontent.com/images/vb1sQLC2MqfCPOFqHd8SyVsyDVB_big.jpg'),
(21052, 1420, 'The Act S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106862.mp4', 'http://gstaticontent.com/images/vb1sQLC2MqfCPOFqHd8SyVsyDVB_big.jpg'),
(21053, 1420, 'The Act S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106863.mp4', 'http://gstaticontent.com/images/vb1sQLC2MqfCPOFqHd8SyVsyDVB_big.jpg'),
(21054, 1420, 'The Act S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106864.mp4', 'http://gstaticontent.com/images/vb1sQLC2MqfCPOFqHd8SyVsyDVB_big.jpg'),
(21055, 1420, 'The Act S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106865.mp4', 'http://gstaticontent.com/images/vb1sQLC2MqfCPOFqHd8SyVsyDVB_big.jpg'),
(21056, 1420, 'The Act S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106866.mp4', 'http://gstaticontent.com/images/vb1sQLC2MqfCPOFqHd8SyVsyDVB_big.jpg'),
(21057, 1421, 'The Feed S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106833.mp4', 'http://gstaticontent.com/images/cOq7f7d4iIIipY5s50dVbIsxlY1_big.jpg'),
(21058, 1421, 'The Feed S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106834.mp4', 'http://gstaticontent.com/images/cOq7f7d4iIIipY5s50dVbIsxlY1_big.jpg'),
(21059, 1421, 'The Feed S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106835.mp4', 'http://gstaticontent.com/images/cOq7f7d4iIIipY5s50dVbIsxlY1_big.jpg'),
(21060, 1421, 'The Feed S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106836.mp4', 'http://gstaticontent.com/images/cOq7f7d4iIIipY5s50dVbIsxlY1_big.jpg'),
(21061, 1421, 'The Feed S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106837.mp4', 'http://gstaticontent.com/images/cOq7f7d4iIIipY5s50dVbIsxlY1_big.jpg'),
(21062, 1421, 'The Feed S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106838.mp4', 'http://gstaticontent.com/images/cOq7f7d4iIIipY5s50dVbIsxlY1_big.jpg'),
(21063, 1421, 'The Feed S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106839.mp4', 'http://gstaticontent.com/images/cOq7f7d4iIIipY5s50dVbIsxlY1_big.jpg'),
(21064, 1421, 'The Feed S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106840.mp4', 'http://gstaticontent.com/images/cOq7f7d4iIIipY5s50dVbIsxlY1_big.jpg'),
(21065, 1421, 'The Feed S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106841.mp4', 'http://gstaticontent.com/images/cOq7f7d4iIIipY5s50dVbIsxlY1_big.jpg'),
(21066, 1421, 'The Feed S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106842.mp4', 'http://gstaticontent.com/images/cOq7f7d4iIIipY5s50dVbIsxlY1_big.jpg'),
(21067, 1422, 'The Good Place S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/165988.mp4', 'http://timg.bdta.pro/images/5f748c90c9274e86cd64cbb8bb2a7d1f.jpg'),
(21068, 1422, 'The Good Place S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/165989.mp4', 'http://timg.bdta.pro/images/bc516dea82148fa94208a7c752ded6c6.jpg'),
(21069, 1422, 'The Good Place S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/165990.mp4', 'http://timg.bdta.pro/images/8933ecf78c579149e2ea7362712a641f.jpg'),
(21070, 1422, 'The Good Place S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/165991.mp4', 'http://timg.bdta.pro/images/41feb3861a20439b5440b57b68bd25c5.jpg'),
(21071, 1422, 'The Good Place S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/165992.mp4', 'http://timg.bdta.pro/images/5d64e362855b633c5eb5d2c12aebbe82.jpg'),
(21072, 1422, 'The Good Place S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/165993.mp4', 'http://timg.bdta.pro/images/9fa90d4961e106b3efc35541f4fdc355.jpg'),
(21073, 1422, 'The Good Place S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/165994.mp4', 'http://timg.bdta.pro/images/534b608d44c1a782636c42265fbba1f1.jpg'),
(21074, 1422, 'The Good Place S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/165995.mp4', 'http://timg.bdta.pro/images/dd5f826dfa25f8f63f828699668bca78.jpg'),
(21075, 1422, 'The Good Place S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/165996.mp4', 'http://timg.bdta.pro/images/b5026e2cf2f34f85eefc031b34a0f294.jpg'),
(21076, 1422, 'The Good Place S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/165997.mp4', 'http://timg.bdta.pro/images/9f0c36005d6c699ff89df2e4158e19b6.jpg'),
(21077, 1422, 'The Good Place S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/165998.mp4', 'http://timg.bdta.pro/images/f4e171caa021ca7c6a29ca6a83c3ce9d.jpg'),
(21078, 1422, 'The Good Place S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/165999.mp4', 'http://timg.bdta.pro/images/734968ca024ad707c5e19c674f462074.jpg'),
(21079, 1422, 'The Good Place S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166000.mp4', 'http://timg.bdta.pro/images/ac67ebde7ba512504f307a483afe1a39.jpg'),
(21080, 1423, 'The Good Place S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166001.mp4', 'http://timg.bdta.pro/images/00ec438bf1c7a080c5f21c65f645fa03.jpg'),
(21081, 1423, 'The Good Place S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166002.mp4', 'http://timg.bdta.pro/images/fe3a21379396dc99136d27bfa99a8f7e.jpg'),
(21082, 1423, 'The Good Place S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166003.mp4', 'http://timg.bdta.pro/images/9c70376d58f76844ec2b0b096fe7dae7.jpg'),
(21083, 1423, 'The Good Place S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166004.mp4', 'http://timg.bdta.pro/images/5518bb6551e5df3487e4b22cac77b440.jpg'),
(21084, 1423, 'The Good Place S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166005.mp4', 'http://timg.bdta.pro/images/99ed289b4f19cd5dcf53b6ef121ca5f2.jpg'),
(21085, 1423, 'The Good Place S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166006.mp4', 'http://timg.bdta.pro/images/615c3503a826086e813e09184ee14452.jpg'),
(21086, 1423, 'The Good Place S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166007.mp4', 'http://timg.bdta.pro/images/2c00af9a6833c105a7eab7aa52aae632.jpg'),
(21087, 1423, 'The Good Place S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166008.mp4', 'http://timg.bdta.pro/images/35b2f765699b872e653c6ed953a464c6.jpg'),
(21088, 1423, 'The Good Place S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166009.mp4', 'http://timg.bdta.pro/images/d1e535ad2fc4fb19c64020b3feeff538.jpg'),
(21089, 1423, 'The Good Place S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166010.mp4', 'http://timg.bdta.pro/images/5758c4bac7870b65c4ee7e879de7b428.jpg'),
(21090, 1423, 'The Good Place S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166011.mp4', 'http://timg.bdta.pro/images/89cebe877ec23a6068d0e4e2a3eb034c.jpg'),
(21091, 1423, 'The Good Place S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166012.mp4', 'http://timg.bdta.pro/images/e512b5d9d4113613201f0c720d9ff9f8.jpg'),
(21092, 1424, 'The Good Place S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166013.mp4', 'http://timg.bdta.pro/images/86ecd03dd99d00ef92dc5f9a59ec494b.jpg'),
(21093, 1424, 'The Good Place S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166014.mp4', 'http://timg.bdta.pro/images/3b98ed9d60a1cd777048b9208506660b.jpg'),
(21094, 1424, 'The Good Place S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166015.mp4', 'http://timg.bdta.pro/images/d1fb2ba4291b2700309bfdd1c54a959b.jpg'),
(21095, 1424, 'The Good Place S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166016.mp4', 'http://timg.bdta.pro/images/588072c0979c7ccba894e81168ee3fd9.jpg'),
(21096, 1424, 'The Good Place S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166017.mp4', 'http://timg.bdta.pro/images/017b7a65d74bd8ecda69b9a9a9e05b12.jpg'),
(21097, 1424, 'The Good Place S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166018.mp4', 'http://timg.bdta.pro/images/09670db1d967492a6366d348d1dc4801.jpg'),
(21098, 1424, 'The Good Place S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166019.mp4', 'http://timg.bdta.pro/images/96c356c7e7d6ef8c7a05ac5213895a81.jpg'),
(21099, 1424, 'The Good Place S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166020.mp4', 'http://timg.bdta.pro/images/01a4acf623cd946a919fa78b66c4e76c.jpg'),
(21100, 1424, 'The Good Place S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166021.mp4', 'http://timg.bdta.pro/images/9b6e5e961dc1614ef991412ffdd0f18e.jpg'),
(21101, 1424, 'The Good Place S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166022.mp4', 'http://timg.bdta.pro/images/fc8d503676174a3164714d66ae539010.jpg'),
(21102, 1424, 'The Good Place S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166023.mp4', 'http://timg.bdta.pro/images/3a92b91ddd51491f3f8c0552ccf0571c.jpg'),
(21103, 1424, 'The Good Place S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166024.mp4', 'http://timg.bdta.pro/images/dbcd26dd27374efa030bf8bb40078d71.jpg'),
(21104, 1425, 'The Good Place S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cMrP2toJrRXaNImOZMdKEE3HfIX.jpg'),
(21105, 1425, 'The Good Place S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3UVbQPsEUOZqzpiXI1NvtbZHpMf.jpg'),
(21106, 1425, 'The Good Place S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xGDrTow3WPmbvDAuYpF6vYslIMi.jpg'),
(21107, 1425, 'The Good Place S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXW9gxatlSN9VihDlS1CPVRfB5b.jpg'),
(21108, 1425, 'The Good Place S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xMq7wm38ilhnRxvwH6vwYjYWJbP.jpg'),
(21109, 1425, 'The Good Place S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3pSdLpffmDiamyDc5xDivZIRVIR.jpg'),
(21110, 1425, 'The Good Place S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZsniCB6pxJ2nQcNZhnAr58LHSu.jpg'),
(21111, 1425, 'The Good Place S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mcooiyoDWbBYINWaCHAfcPUHhbb.jpg'),
(21112, 1425, 'The Good Place S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qAx6TENa7FQFnFm71JwbaFFzR81.jpg'),
(21113, 1425, 'The Good Place S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pGDPx8OrsAYHyycGKwx3nSEyTyC.jpg'),
(21114, 1425, 'The Good Place S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mEvhZ0NkwKWogkA3E4CpAVJps1L.jpg'),
(21115, 1425, 'The Good Place S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1VmkQpM81dzwg0xOQBjKd3JUwEA.jpg'),
(21116, 1425, 'The Good Place S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/40JOgMD6JTSP3ohjg9L4mSkIOOY.jpg'),
(21117, 1426, 'The Little Drummer Girl S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106827.mp4', 'http://timg.bdta.pro/images/f20936548bfc84440a48f6af8ba67ee3.jpg'),
(21118, 1426, 'The Little Drummer Girl S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106828.mp4', 'http://timg.bdta.pro/images/9252ad0e1f35a74c9008278fda9b305e.jpg'),
(21119, 1426, 'The Little Drummer Girl S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106829.mp4', 'http://timg.bdta.pro/images/0a8a64738f099cc2c793d36167dfdfd8.jpg'),
(21120, 1426, 'The Little Drummer Girl S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106830.mp4', 'http://timg.bdta.pro/images/8304bb5f3f0e8a8f36377e3309e0dd7c.jpg'),
(21121, 1426, 'The Little Drummer Girl S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106831.mp4', 'http://timg.bdta.pro/images/88a1c6931bd9d0f04587aedb6a909183.jpg'),
(21122, 1426, 'The Little Drummer Girl S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106832.mp4', 'http://timg.bdta.pro/images/b58fccd31a9d74ed9f47cce4b4b7c2b2.jpg'),
(21123, 1427, 'The Mandalorian S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211421.mp4', 'http://timg.bdta.pro/images/7ce0f2197600b78ff4da187f5f13044b.jpg'),
(21124, 1427, 'The Mandalorian S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211422.mp4', 'http://timg.bdta.pro/images/51c5a67344311fb875a4e3e2e5517f0e.jpg'),
(21125, 1427, 'The Mandalorian S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211423.mp4', 'http://timg.bdta.pro/images/9e2cdd4a4f1b0899926e1e46c3ce316b.jpg'),
(21126, 1427, 'The Mandalorian S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211424.mp4', 'http://timg.bdta.pro/images/5150cd47450399c8db5e99fcdd8f3506.jpg'),
(21127, 1427, 'The Mandalorian S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211425.mp4', 'http://timg.bdta.pro/images/e68af17777c8fa31cd4f30b5a16e4dfc.jpg'),
(21128, 1427, 'The Mandalorian S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211426.mp4', 'http://timg.bdta.pro/images/5eddebf36c33e998b32c8189777c8a93.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(21129, 1427, 'The Mandalorian S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211427.mp4', 'http://timg.bdta.pro/images/f3f6b44f7f0df6d7fe79f1b7f636d87b.jpg'),
(21130, 1427, 'The Mandalorian S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211428.mp4', 'http://timg.bdta.pro/images/2f7e2cb70b57807a804a3d650b4b4327.jpg'),
(21131, 1428, 'The Mandalorian S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211429.mp4', 'http://timg.bdta.pro/images/3a6c7d64e481ce77c98e7f3138810e8e.jpg'),
(21132, 1428, 'The Mandalorian S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kAuS7h8qVLokHcKpSwZMum4PhC2.jpg'),
(21133, 1428, 'The Mandalorian S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8rnZcWzD0XHt6c15zyVkeV2bc1.jpg'),
(21134, 1428, 'The Mandalorian S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211432.mp4', 'http://gstaticontent.com/images/BbNvKCuEF4SRzFXR16aK6ISFtR_big.jpg'),
(21135, 1428, 'The Mandalorian S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211433.mp4', 'http://gstaticontent.com/images/BbNvKCuEF4SRzFXR16aK6ISFtR_big.jpg'),
(21136, 1428, 'The Mandalorian S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211434.mp4', 'http://gstaticontent.com/images/BbNvKCuEF4SRzFXR16aK6ISFtR_big.jpg'),
(21137, 1428, 'The Mandalorian S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211435.mp4', 'http://gstaticontent.com/images/BbNvKCuEF4SRzFXR16aK6ISFtR_big.jpg'),
(21138, 1428, 'The Mandalorian S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211436.mp4', 'http://gstaticontent.com/images/BbNvKCuEF4SRzFXR16aK6ISFtR_big.jpg'),
(21139, 1429, 'The Mandalorian S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211437.mp4', 'http://image.tmdb.org/t/p/w1280/8XeuJls7qlTsPiDAK0qarvBrmb2.jpg'),
(21140, 1429, 'The Mandalorian S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211438.mp4', 'http://image.tmdb.org/t/p/w1280/yR3pIsArgHpyeGScXHKqj8hGRBo.jpg'),
(21141, 1429, 'The Mandalorian S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211439.mp4', 'http://image.tmdb.org/t/p/w1280/zgj0iZUYNIZh0NbPVdNEdTacfwv.jpg'),
(21142, 1429, 'The Mandalorian S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211440.mp4', 'http://image.tmdb.org/t/p/w1280/jtH7v1yusbC0Lj3jAT8W2aEbbW3.jpg'),
(21143, 1429, 'The Mandalorian S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211441.mp4', 'http://image.tmdb.org/t/p/w1280/nMAlfiKOxWsf7hcHzxqBjLbApda.jpg'),
(21144, 1429, 'The Mandalorian S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211442.mp4', 'http://image.tmdb.org/t/p/w1280/wxV2jJ0VsGdBCJIlgCHhBHq5dIn.jpg'),
(21145, 1429, 'The Mandalorian S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211443.mp4', 'http://image.tmdb.org/t/p/w1280/38blBPXRWevBgwa4XPVZkc2mMCO.jpg'),
(21146, 1429, 'The Mandalorian S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211444.mp4', 'http://image.tmdb.org/t/p/w1280/blG9C2voVSQlC8M1JkJZgo7BvCL.jpg'),
(21147, 1430, 'Vida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129873.mp4', 'http://timg.bdta.pro/images/b0368df4ac3b1d613c274bfcd89d311e.jpg'),
(21148, 1430, 'Vida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129874.mp4', 'http://timg.bdta.pro/images/8481e372d3a4ba0a6ac6a7495be306db.jpg'),
(21149, 1430, 'Vida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129875.mp4', 'http://timg.bdta.pro/images/90555c5644cfa3ee36ce803972ea86d6.jpg'),
(21150, 1430, 'Vida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129876.mp4', 'http://timg.bdta.pro/images/69a5d636d0282392fa11c80d9fd8e9ce.jpg'),
(21151, 1430, 'Vida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129877.mp4', 'http://timg.bdta.pro/images/cc22d4b49a2bec7e89efff3947bcddd9.jpg'),
(21152, 1430, 'Vida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129878.mp4', 'http://timg.bdta.pro/images/7debbad3a4c2d8a99c98e26b9e8c34c8.jpg'),
(21153, 1431, 'Vida S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129879.mp4', 'http://timg.bdta.pro/images/5a5fe2bb03f3a2257a80b8883ef5bc25.jpg'),
(21154, 1431, 'Vida S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129880.mp4', 'http://timg.bdta.pro/images/e1a9acd95c0793b545243484a675df24.jpg'),
(21155, 1431, 'Vida S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129881.mp4', 'http://timg.bdta.pro/images/95610b67810962d234d3e3c3e2d5e9c0.jpg'),
(21156, 1431, 'Vida S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129882.mp4', 'http://timg.bdta.pro/images/763befcf80153a63452a5e92f3f000d0.jpg'),
(21157, 1431, 'Vida S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129883.mp4', 'http://timg.bdta.pro/images/50fa1baf652294224d4d7b95b25645dc.jpg'),
(21158, 1431, 'Vida S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129884.mp4', 'http://timg.bdta.pro/images/c81c17f8acaa4a40ac69d56e6f390471.jpg'),
(21159, 1431, 'Vida S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129885.mp4', 'http://timg.bdta.pro/images/86eaccee067e5cbd41d03bcf0b29fe4b.jpg'),
(21160, 1431, 'Vida S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129886.mp4', 'http://timg.bdta.pro/images/1196e231029200424bd6c5f121881697.jpg'),
(21161, 1431, 'Vida S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129887.mp4', 'http://timg.bdta.pro/images/db88bdcab92103e942802ce7b7169748.jpg'),
(21162, 1431, 'Vida S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129888.mp4', 'http://timg.bdta.pro/images/d11a700131db9c67c32faa62ff3da8f5.jpg'),
(21163, 1432, 'Vida S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129889.mp4', 'http://timg.bdta.pro/images/3e8cf7052e173c0e115fc49d3404d04b.jpg'),
(21164, 1432, 'Vida S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129890.mp4', 'http://timg.bdta.pro/images/aecc98413b0e133941b88e8f5233beb8.jpg'),
(21165, 1432, 'Vida S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129891.mp4', 'http://timg.bdta.pro/images/5e907801327312972287906a3afa0c98.jpg'),
(21166, 1432, 'Vida S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129892.mp4', 'http://timg.bdta.pro/images/b3ff1ea0c10dd1d123565c0e44582eae.jpg'),
(21167, 1432, 'Vida S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129893.mp4', 'http://timg.bdta.pro/images/c487569260914caedcbb5e8528f75718.jpg'),
(21168, 1432, 'Vida S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129894.mp4', 'http://timg.bdta.pro/images/fd2472e965efd4814f5d4b72c2c69230.jpg'),
(21169, 1433, 'Watchmen S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126611.mp4', 'http://timg.bdta.pro/images/a898d57c8c42de7018f731d0cbe89370.jpg'),
(21170, 1433, 'Watchmen S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126612.mp4', 'http://timg.bdta.pro/images/85b9d40d1d3101513a684d5ffb9bf6b2.jpg'),
(21171, 1433, 'Watchmen S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126613.mp4', 'http://timg.bdta.pro/images/a6941e52dec604afa8bc9aa4bf2e88fa.jpg'),
(21172, 1433, 'Watchmen S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126614.mp4', 'http://timg.bdta.pro/images/8a8423458ff09e90793be464010eaf2b.jpg'),
(21173, 1433, 'Watchmen S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126615.mp4', 'http://timg.bdta.pro/images/d4b5afc93b239cda0d0c98655290db7f.jpg'),
(21174, 1433, 'Watchmen S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126616.mp4', 'http://timg.bdta.pro/images/fd9f820df4802e4afbf6459c2bc1fc72.jpg'),
(21175, 1433, 'Watchmen S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126617.mp4', 'http://timg.bdta.pro/images/1027e313e2c85c32009233d010570c03.jpg'),
(21176, 1433, 'Watchmen S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126618.mp4', 'http://timg.bdta.pro/images/4cf640a2746f5173ccb4cd50f0231a16.jpg'),
(21177, 1433, 'Watchmen S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126619.mp4', 'http://timg.bdta.pro/images/f2815b102e5e0e97d0bd087f04066d4f.jpg'),
(21178, 1434, 'Distrito Selvagem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106767.mp4', 'http://timg.bdta.pro/images/f5e007f11f76841c4e19053ec14d9e75.jpg'),
(21179, 1434, 'Distrito Selvagem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106768.mp4', 'http://timg.bdta.pro/images/03636740976e0476ca513a190efddf2e.jpg'),
(21180, 1434, 'Distrito Selvagem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106769.mp4', 'http://timg.bdta.pro/images/dfdfe910395a4be4589fa759919362a6.jpg'),
(21181, 1434, 'Distrito Selvagem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106770.mp4', 'http://timg.bdta.pro/images/7487b88e7b50950ff24283eebf9cc38c.jpg'),
(21182, 1434, 'Distrito Selvagem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106771.mp4', 'http://timg.bdta.pro/images/ee457ab7dc497c0a179d08680d7b5a19.jpg'),
(21183, 1434, 'Distrito Selvagem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106772.mp4', 'http://timg.bdta.pro/images/c816fe851e12d6f69b779bd8b4affa66.jpg'),
(21184, 1434, 'Distrito Selvagem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106773.mp4', 'http://timg.bdta.pro/images/7d4c26e06cbb64ca17a7dc31408ccf7a.jpg'),
(21185, 1434, 'Distrito Selvagem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106774.mp4', 'http://timg.bdta.pro/images/32e8eb39d2dd6cfcc52a4d5dbad87d9a.jpg'),
(21186, 1434, 'Distrito Selvagem S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106775.mp4', 'http://timg.bdta.pro/images/f5d42bc395d8ff60d0c17a053d0b3eea.jpg'),
(21187, 1434, 'Distrito Selvagem S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106776.mp4', 'http://timg.bdta.pro/images/692ead6155854361da09ab7d4a112432.jpg'),
(21188, 1435, 'Distrito Selvagem S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106777.mp4', 'http://timg.bdta.pro/images/bd42eeb54f291443cc9d9cd1b146e5a8.jpg'),
(21189, 1435, 'Distrito Selvagem S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106778.mp4', 'http://timg.bdta.pro/images/9fc2141bcf23771ca501dee4ca7df6c1.jpg'),
(21190, 1435, 'Distrito Selvagem S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106779.mp4', 'http://timg.bdta.pro/images/5c769fea47f920a3e1ec71127ac899af.jpg'),
(21191, 1435, 'Distrito Selvagem S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106780.mp4', 'http://timg.bdta.pro/images/7c4542e116deebcc5ba56ec20491b7f6.jpg'),
(21192, 1435, 'Distrito Selvagem S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106781.mp4', 'http://timg.bdta.pro/images/fd5668722543155f24908687ff453e0a.jpg'),
(21193, 1435, 'Distrito Selvagem S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106782.mp4', 'http://timg.bdta.pro/images/1ab6d8bee6483fe77eebca2ef313c14b.jpg'),
(21194, 1435, 'Distrito Selvagem S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106783.mp4', 'http://timg.bdta.pro/images/c78f0479a825f2837ae3e50df480bcd3.jpg'),
(21195, 1435, 'Distrito Selvagem S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106784.mp4', 'http://timg.bdta.pro/images/a2ccc35bfd1fff2bd5bf45fb04a2fe21.jpg'),
(21196, 1435, 'Distrito Selvagem S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106785.mp4', 'http://timg.bdta.pro/images/42c6cb6500b5c80175431826f050028b.jpg'),
(21197, 1435, 'Distrito Selvagem S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106786.mp4', 'http://timg.bdta.pro/images/33408880e1f7506d30ab1dce01fa3bae.jpg'),
(21198, 1436, 'Santos Dumont S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106618.mp4', 'http://timg.bdta.pro/images/eb3beb86db5eaf03c66f189355f9ce7f.jpg'),
(21199, 1436, 'Santos Dumont S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106619.mp4', 'http://timg.bdta.pro/images/d7513835f24d26207a5f91db903a2b9c.jpg'),
(21200, 1436, 'Santos Dumont S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106620.mp4', 'http://timg.bdta.pro/images/93f016282d85dc7ac01a91a3e622a322.jpg'),
(21201, 1436, 'Santos Dumont S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106621.mp4', 'http://gstaticontent.com/images/4yVtl6XcxT2kaFel8YP8o0l0yf2_big.jpg'),
(21202, 1436, 'Santos Dumont S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106622.mp4', 'http://gstaticontent.com/images/4yVtl6XcxT2kaFel8YP8o0l0yf2_big.jpg'),
(21203, 1437, '60 Dias Infiltrados Na Prisao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106753.mp4', 'http://timg.bdta.pro/images/e2e8fa40076c8e9cb92cc06c83910ca5.jpg'),
(21204, 1437, '60 Dias Infiltrados Na Prisao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106754.mp4', 'http://timg.bdta.pro/images/56a54cfaa0771abb6886038a54e4c3e0.jpg'),
(21205, 1437, '60 Dias Infiltrados Na Prisao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106755.mp4', 'http://timg.bdta.pro/images/7c4e4f6417a4b546c610135897d46a1b.jpg'),
(21206, 1437, '60 Dias Infiltrados Na Prisao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106756.mp4', 'http://timg.bdta.pro/images/af148e4935b8de72ffe37e67b02b0e2f.jpg'),
(21207, 1437, '60 Dias Infiltrados Na Prisao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106757.mp4', 'http://timg.bdta.pro/images/477f08c4582d2d2f1a40e08818efdad2.jpg'),
(21208, 1437, '60 Dias Infiltrados Na Prisao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106758.mp4', 'http://timg.bdta.pro/images/a2b4c32e9849cb1c8d87999a6c1429de.jpg'),
(21209, 1437, '60 Dias Infiltrados Na Prisao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106759.mp4', 'http://timg.bdta.pro/images/7651f89ac37229e7d0e4806840acb2f3.jpg'),
(21210, 1437, '60 Dias Infiltrados Na Prisao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106760.mp4', 'http://timg.bdta.pro/images/0cdace761930faa7b4f9a05596275554.jpg'),
(21211, 1437, '60 Dias Infiltrados Na Prisao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106761.mp4', 'http://timg.bdta.pro/images/893273f02c53d0930a732913e020d1c0.jpg'),
(21212, 1437, '60 Dias Infiltrados Na Prisao S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106762.mp4', 'http://timg.bdta.pro/images/068fe30e92404a45deb07d06d12d19e9.jpg'),
(21213, 1437, '60 Dias Infiltrados Na Prisao S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106763.mp4', 'http://timg.bdta.pro/images/be1d4c6ebba86070817cc754b00f8c3a.jpg'),
(21214, 1437, '60 Dias Infiltrados Na Prisao S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/106764.mp4', 'http://timg.bdta.pro/images/de63aac57a1663b7e47986470c5a1e71.jpg'),
(21215, 1437, '60 Dias Infiltrados Na Prisao S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/106765.mp4', 'http://timg.bdta.pro/images/6502186606c9841b0f99363bc489e2f4.jpg'),
(21216, 1437, '60 Dias Infiltrados Na Prisao S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/106766.mp4', 'http://timg.bdta.pro/images/a902b55e3f19189b0a4e5fbf49a34cad.jpg'),
(21217, 1438, 'Mortel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106724.mp4', 'http://timg.bdta.pro/images/41eac1b69f5568c5ac0a68f61aa82396.jpg'),
(21218, 1438, 'Mortel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106725.mp4', 'http://timg.bdta.pro/images/9420b04782dd6de2c45ddbb9a9b3f61c.jpg'),
(21219, 1438, 'Mortel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106726.mp4', 'http://timg.bdta.pro/images/382c0f09bc299348a53ae50c05044281.jpg'),
(21220, 1438, 'Mortel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106727.mp4', 'http://timg.bdta.pro/images/72a110a25936666dc8ea0b9b509ff76a.jpg'),
(21221, 1438, 'Mortel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106728.mp4', 'http://timg.bdta.pro/images/960091a55e0146c7990b096d941a77da.jpg'),
(21222, 1438, 'Mortel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106729.mp4', 'http://timg.bdta.pro/images/24bba9e2a71bbab04c4534c80a3bc9b1.jpg'),
(21223, 1439, 'Mythomaniac S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106718.mp4', 'http://gstaticontent.com/images/qLTYhndA8cFTRcEyNRSrY1GexmE_big.jpg'),
(21224, 1439, 'Mythomaniac S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106719.mp4', 'http://gstaticontent.com/images/qLTYhndA8cFTRcEyNRSrY1GexmE_big.jpg'),
(21225, 1439, 'Mythomaniac S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106720.mp4', 'http://gstaticontent.com/images/qLTYhndA8cFTRcEyNRSrY1GexmE_big.jpg'),
(21226, 1439, 'Mythomaniac S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106721.mp4', 'http://gstaticontent.com/images/qLTYhndA8cFTRcEyNRSrY1GexmE_big.jpg'),
(21227, 1439, 'Mythomaniac S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106722.mp4', 'http://gstaticontent.com/images/qLTYhndA8cFTRcEyNRSrY1GexmE_big.jpg'),
(21228, 1439, 'Mythomaniac S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106723.mp4', 'http://gstaticontent.com/images/qLTYhndA8cFTRcEyNRSrY1GexmE_big.jpg'),
(21229, 1440, 'Desservico Ao Consumidor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106714.mp4', 'http://timg.bdta.pro/images/002139f3ae778b7bd3d9907c4681aa0a.jpg'),
(21230, 1440, 'Desservico Ao Consumidor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106715.mp4', 'http://timg.bdta.pro/images/89a712f35880b28689cb6af915f7b99d.jpg'),
(21231, 1440, 'Desservico Ao Consumidor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106716.mp4', 'http://timg.bdta.pro/images/2273b3a57d4e11d11f70d8ffc8d38650.jpg'),
(21232, 1440, 'Desservico Ao Consumidor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106717.mp4', 'http://timg.bdta.pro/images/78c55909611adcaa24921e6a8741be57.jpg'),
(21233, 1441, 'Levius S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106702.mp4', 'http://timg.bdta.pro/images/d8810a6d8b960b90c85ec2cdead49a13.jpg'),
(21234, 1441, 'Levius S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106703.mp4', 'http://timg.bdta.pro/images/ed192155b7ec5bd38d161cc2ec27a2dd.jpg'),
(21235, 1441, 'Levius S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106704.mp4', 'http://timg.bdta.pro/images/af96730f6a1acac002f6cb118bb74af4.jpg'),
(21236, 1441, 'Levius S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106705.mp4', 'http://timg.bdta.pro/images/da06d30c17779b2fbe0828da1cce2b2d.jpg'),
(21237, 1441, 'Levius S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106706.mp4', 'http://timg.bdta.pro/images/d2aabd1d27ff99e2f9ce51ea33c6ffd5.jpg'),
(21238, 1441, 'Levius S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106707.mp4', 'http://timg.bdta.pro/images/8678acf55bd7d3a5006574d70bcba62d.jpg'),
(21239, 1441, 'Levius S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106708.mp4', 'http://timg.bdta.pro/images/b65dbd07d9852f2b127230034b2cdf44.jpg'),
(21240, 1441, 'Levius S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106709.mp4', 'http://timg.bdta.pro/images/a939c93a504cec3316710516aafd874b.jpg'),
(21241, 1441, 'Levius S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106710.mp4', 'http://timg.bdta.pro/images/0f62b029d83b2fb9b0f90d08d5ecbb29.jpg'),
(21242, 1441, 'Levius S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106711.mp4', 'http://timg.bdta.pro/images/476849b6d14b4b67b262c05026e32b54.jpg'),
(21243, 1441, 'Levius S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106712.mp4', 'http://timg.bdta.pro/images/857219f0ae99da430bfc7bfa54a54b5a.jpg'),
(21244, 1441, 'Levius S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/106713.mp4', 'http://timg.bdta.pro/images/6c3ab0c417df221f55409ce43613a660.jpg'),
(21245, 1442, 'Feliz Natal e Tal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106694.mp4', 'http://timg.bdta.pro/images/3b8cc7619f1d413fb6c42e99147c414e.jpg'),
(21246, 1442, 'Feliz Natal e Tal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106695.mp4', 'http://timg.bdta.pro/images/008b5ff357e6144f5294c0a950062a34.jpg'),
(21247, 1442, 'Feliz Natal e Tal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106696.mp4', 'http://timg.bdta.pro/images/8581ff79d49b70fceaa869925ba7742a.jpg'),
(21248, 1442, 'Feliz Natal e Tal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106697.mp4', 'http://timg.bdta.pro/images/a86850019cd095a02549cef175f72846.jpg'),
(21249, 1442, 'Feliz Natal e Tal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106698.mp4', 'http://timg.bdta.pro/images/d199ebdffef59ab6f227602e4bf0be54.jpg'),
(21250, 1442, 'Feliz Natal e Tal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106699.mp4', 'http://timg.bdta.pro/images/97e4443ace3d1e51a40334a2ae286797.jpg'),
(21251, 1442, 'Feliz Natal e Tal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106700.mp4', 'http://timg.bdta.pro/images/350cff7f1697b89d9567f46e010eda04.jpg'),
(21252, 1442, 'Feliz Natal e Tal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106701.mp4', 'http://timg.bdta.pro/images/9d33463916f2fa848165a2e2c40802eb.jpg'),
(21253, 1443, 'O Grande Gonzalez S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106684.mp4', 'http://timg.bdta.pro/images/bf2c728feabd9d5b5f5fef37c10c2146.jpg'),
(21254, 1443, 'O Grande Gonzalez S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106685.mp4', 'http://timg.bdta.pro/images/3109e3a2860ce75b6674133bcbe9ccc7.jpg'),
(21255, 1443, 'O Grande Gonzalez S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106686.mp4', 'http://timg.bdta.pro/images/6a2a065701d6af01e4591b436efa4762.jpg'),
(21256, 1443, 'O Grande Gonzalez S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106687.mp4', 'http://timg.bdta.pro/images/f4206d2048d5091805109bf293de8021.jpg'),
(21257, 1443, 'O Grande Gonzalez S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106688.mp4', 'http://timg.bdta.pro/images/f0d5cb0365d9712019bb31b88d1dfc41.jpg'),
(21258, 1443, 'O Grande Gonzalez S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106689.mp4', 'http://timg.bdta.pro/images/055128fd49e7d8a117e23cb295139bf3.jpg'),
(21259, 1443, 'O Grande Gonzalez S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106690.mp4', 'http://timg.bdta.pro/images/2d36ed3aab01723267e955511b1db36e.jpg'),
(21260, 1443, 'O Grande Gonzalez S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106691.mp4', 'http://timg.bdta.pro/images/81d7013be6f8aad0a1bb78673148bb02.jpg'),
(21261, 1443, 'O Grande Gonzalez S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106692.mp4', 'http://timg.bdta.pro/images/569b0312b2f46d0af966a39d259527cb.jpg'),
(21262, 1443, 'O Grande Gonzalez S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106693.mp4', 'http://timg.bdta.pro/images/5d3187661ada31c77080d7143476d2c7.jpg'),
(21263, 1444, 'Namorado de Natal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139068.mp4', 'http://timg.bdta.pro/images/942f2db0babf9fbee55dd4e0e48e24df.jpg'),
(21264, 1444, 'Namorado de Natal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139069.mp4', 'http://timg.bdta.pro/images/6a3b16051f91ecb68d501bcb1afb9ad6.jpg'),
(21265, 1444, 'Namorado de Natal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139070.mp4', 'http://timg.bdta.pro/images/fb3e707fa8bfed7013a6420bf6ea677e.jpg'),
(21266, 1444, 'Namorado de Natal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139071.mp4', 'http://timg.bdta.pro/images/79b81d0edff09931530f8e41ab87b509.jpg'),
(21267, 1444, 'Namorado de Natal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139072.mp4', 'http://timg.bdta.pro/images/69b51e2443968315375262a29044efb7.jpg'),
(21268, 1444, 'Namorado de Natal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139073.mp4', 'http://timg.bdta.pro/images/b6665fe4e61e589e6e17d96cd97d9db6.jpg'),
(21269, 1445, 'Namorado de Natal S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139074.mp4', 'http://gstaticontent.com/images/zY1IdRI75vpTxGZWz88r4Py9pX_big.jpg'),
(21270, 1445, 'Namorado de Natal S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139075.mp4', 'http://gstaticontent.com/images/zY1IdRI75vpTxGZWz88r4Py9pX_big.jpg'),
(21271, 1445, 'Namorado de Natal S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139076.mp4', 'http://gstaticontent.com/images/zY1IdRI75vpTxGZWz88r4Py9pX_big.jpg'),
(21272, 1445, 'Namorado de Natal S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139077.mp4', 'http://gstaticontent.com/images/zY1IdRI75vpTxGZWz88r4Py9pX_big.jpg'),
(21273, 1445, 'Namorado de Natal S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139078.mp4', 'http://gstaticontent.com/images/zY1IdRI75vpTxGZWz88r4Py9pX_big.jpg'),
(21274, 1445, 'Namorado de Natal S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139079.mp4', 'http://gstaticontent.com/images/zY1IdRI75vpTxGZWz88r4Py9pX_big.jpg'),
(21275, 1446, 'V Wars S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106674.mp4', 'http://timg.bdta.pro/images/3a2b8281d815b2d6d465d7dcf24acc44.jpg'),
(21276, 1446, 'V Wars S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106675.mp4', 'http://timg.bdta.pro/images/17e06ebee9e27a77d9b6b2524ff83dc4.jpg'),
(21277, 1446, 'V Wars S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106676.mp4', 'http://timg.bdta.pro/images/bfe1e14240016bd5a19211613f321a86.jpg'),
(21278, 1446, 'V Wars S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106677.mp4', 'http://timg.bdta.pro/images/ce59e7e69cb081f1908b966731db413b.jpg'),
(21279, 1446, 'V Wars S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106678.mp4', 'http://timg.bdta.pro/images/45242bfcb49e09e6c97e1afdb7f35148.jpg'),
(21280, 1446, 'V Wars S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106679.mp4', 'http://timg.bdta.pro/images/16682cf00008def900bd0b47fd844236.jpg'),
(21281, 1446, 'V Wars S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106680.mp4', 'http://timg.bdta.pro/images/cd09d79fbb97a23f0d781b659bb47487.jpg'),
(21282, 1446, 'V Wars S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106681.mp4', 'http://timg.bdta.pro/images/b0e451a3a0b4e317655bf28e8df2b64c.jpg'),
(21283, 1446, 'V Wars S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106682.mp4', 'http://timg.bdta.pro/images/13f30c09737c055dd1854334af5e274e.jpg'),
(21284, 1446, 'V Wars S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106683.mp4', 'http://timg.bdta.pro/images/29a4865c93b30071e9694ca827709c64.jpg'),
(21285, 1447, 'Maravilhosa Sra. Maisel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176078.mp4', 'http://timg.bdta.pro/images/04f2717cd3d0fe6144957c3b7bd8a509.jpg'),
(21286, 1447, 'Maravilhosa Sra. Maisel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176079.mp4', 'http://timg.bdta.pro/images/d84a6e77fa6764aa39372a71b6275191.jpg'),
(21287, 1447, 'Maravilhosa Sra. Maisel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176080.mp4', 'http://timg.bdta.pro/images/990a892dd3414bdbf2f518ec0a9384ed.jpg'),
(21288, 1447, 'Maravilhosa Sra. Maisel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176081.mp4', 'http://timg.bdta.pro/images/ddd3e15ba2315a32a1a0dacb1d24b3df.jpg'),
(21289, 1447, 'Maravilhosa Sra. Maisel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176082.mp4', 'http://timg.bdta.pro/images/11c43e44f07542c26c435961ec22044e.jpg'),
(21290, 1447, 'Maravilhosa Sra. Maisel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176083.mp4', 'http://timg.bdta.pro/images/8a99d9bd9355db9ff92fda7827259fb3.jpg'),
(21291, 1447, 'Maravilhosa Sra. Maisel S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176084.mp4', 'http://timg.bdta.pro/images/84f709f456e7fd5eb7f27bfb218885b8.jpg'),
(21292, 1447, 'Maravilhosa Sra. Maisel S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176085.mp4', 'http://timg.bdta.pro/images/2cf6d8b80b9ed0f151a9673c3d07422f.jpg'),
(21293, 1448, 'Maravilhosa Sra. Maisel S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176086.mp4', 'http://timg.bdta.pro/images/4b3c2bd780e0e0ff773190673e4fa7ea.jpg'),
(21294, 1448, 'Maravilhosa Sra. Maisel S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176087.mp4', 'http://timg.bdta.pro/images/ad113c26e30416b77f2c28d9779de66d.jpg'),
(21295, 1448, 'Maravilhosa Sra. Maisel S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176088.mp4', 'http://timg.bdta.pro/images/e1e8fc39988ea5324dc4e0d839292d9d.jpg'),
(21296, 1448, 'Maravilhosa Sra. Maisel S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176089.mp4', 'http://timg.bdta.pro/images/fd15633685ac8ef7e4148e44d09b473c.jpg'),
(21297, 1448, 'Maravilhosa Sra. Maisel S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176090.mp4', 'http://timg.bdta.pro/images/6246665f8c10352c938188d54cdb6ca7.jpg'),
(21298, 1448, 'Maravilhosa Sra. Maisel S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176091.mp4', 'http://timg.bdta.pro/images/33af00d2b94c97178d8ab94391bc9a74.jpg'),
(21299, 1448, 'Maravilhosa Sra. Maisel S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176092.mp4', 'http://timg.bdta.pro/images/dfa8826ed20fb4efe669923609e20b10.jpg'),
(21300, 1448, 'Maravilhosa Sra. Maisel S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176093.mp4', 'http://timg.bdta.pro/images/0bb298f4683c896bbc7e70895de67c75.jpg'),
(21301, 1448, 'Maravilhosa Sra. Maisel S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176094.mp4', 'http://timg.bdta.pro/images/b93af537fae5dc7f7edc51d6896eb90e.jpg'),
(21302, 1448, 'Maravilhosa Sra. Maisel S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176095.mp4', 'http://timg.bdta.pro/images/ff4b5e8faa9f99ec5a15f0fd85863ca3.jpg'),
(21303, 1449, 'Maravilhosa Sra. Maisel S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176096.mp4', 'http://timg.bdta.pro/images/91067bfd7435550fbe68679c58c05bd5.jpg'),
(21304, 1449, 'Maravilhosa Sra. Maisel S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176097.mp4', 'http://timg.bdta.pro/images/b101ee4e2b65fedaaadc123de594d540.jpg'),
(21305, 1449, 'Maravilhosa Sra. Maisel S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176098.mp4', 'http://timg.bdta.pro/images/8058b7c578c43f0246408ce93fc0fd1a.jpg'),
(21306, 1449, 'Maravilhosa Sra. Maisel S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176099.mp4', 'http://timg.bdta.pro/images/b4a8911d5b45dcf00933909359ff1d27.jpg'),
(21307, 1449, 'Maravilhosa Sra. Maisel S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176100.mp4', 'http://timg.bdta.pro/images/4bf4fbfc156e225dd4266f35c5b571a8.jpg'),
(21308, 1449, 'Maravilhosa Sra. Maisel S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176101.mp4', 'http://timg.bdta.pro/images/405a6e933f12113c7174009eb0adfc37.jpg'),
(21309, 1449, 'Maravilhosa Sra. Maisel S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176102.mp4', 'http://timg.bdta.pro/images/56cc3842e6bd688121258b67ddd13926.jpg'),
(21310, 1449, 'Maravilhosa Sra. Maisel S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176103.mp4', 'http://timg.bdta.pro/images/f08fb7b4b69bc9b6ea3de7c4cd923294.jpg'),
(21311, 1450, 'Maravilhosa Sra. Maisel S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176104.mp4', 'http://timg.bdta.pro/images/3f2a31271d2627c55ad0b5e55012bf3a.jpg'),
(21312, 1450, 'Maravilhosa Sra. Maisel S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176105.mp4', 'http://timg.bdta.pro/images/60ea16ef00477cf8ac31666d7e29519d.jpg'),
(21313, 1450, 'Maravilhosa Sra. Maisel S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176106.mp4', 'http://timg.bdta.pro/images/4e813c62420894eaf4ebc178c2f1367b.jpg'),
(21314, 1450, 'Maravilhosa Sra. Maisel S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176107.mp4', 'http://timg.bdta.pro/images/737b40181953e510fa1180554a7c11e8.jpg'),
(21315, 1450, 'Maravilhosa Sra. Maisel S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176108.mp4', 'http://timg.bdta.pro/images/3778d67abbacd8219c000ea690182b20.jpg'),
(21316, 1450, 'Maravilhosa Sra. Maisel S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176109.mp4', 'http://timg.bdta.pro/images/8e5cabb0437bbe9db6e623f54d4419ae.jpg'),
(21317, 1450, 'Maravilhosa Sra. Maisel S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176110.mp4', 'http://timg.bdta.pro/images/729026970e3013524c3a7c4b8c1c6887.jpg'),
(21318, 1450, 'Maravilhosa Sra. Maisel S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176111.mp4', 'http://timg.bdta.pro/images/746c00ef8b7f15154b35669f808a0efa.jpg'),
(21319, 1451, 'Maravilhosa Sra. Maisel S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AsslIoWDva5OeQi15iWUJ9sOUBa.jpg'),
(21320, 1451, 'Maravilhosa Sra. Maisel S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k21v2548HxSyDcH0KPxafBzDOU4.jpg'),
(21321, 1451, 'Maravilhosa Sra. Maisel S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/405805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ugHUKWOF0cfxWFaTGu5mPAuIAj9.jpg'),
(21322, 1451, 'Maravilhosa Sra. Maisel S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/405806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zSEt9MUm8rf9inzGjMfhWSptAoS.jpg'),
(21323, 1451, 'Maravilhosa Sra. Maisel S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/405807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/czwUIA3p2gBtEZ9i4AEGrT2EqGM.jpg'),
(21324, 1451, 'Maravilhosa Sra. Maisel S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/405808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nT0l0wyyYSEVnot5TvzBOVLcTwL.jpg'),
(21325, 1451, 'Maravilhosa Sra. Maisel S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/405809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qDzeWTyLdlfJnlCL5dOsYWkY6pS.jpg'),
(21326, 1451, 'Maravilhosa Sra. Maisel S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/405810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9KOLE0kgzkydJQzbpsQzQiZab1N.jpg'),
(21327, 1451, 'Maravilhosa Sra. Maisel S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/405811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xHtvNNKqj1oURqZj9bp77pTDGV2.jpg'),
(21328, 1452, 'Matador S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106631.mp4', 'http://timg.bdta.pro/images/2d1e50c15f6ba8eaee8950943d2e9698.jpg'),
(21329, 1452, 'Matador S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106632.mp4', 'http://timg.bdta.pro/images/e07d18087334044613d68f4a31fa8c00.jpg'),
(21330, 1452, 'Matador S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106633.mp4', 'http://timg.bdta.pro/images/e04112ccc701e35d2ae95c24c7e5c95c.jpg'),
(21331, 1452, 'Matador S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106634.mp4', 'http://timg.bdta.pro/images/88961034488f45c4c4706156e97f6198.jpg'),
(21332, 1452, 'Matador S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106635.mp4', 'http://timg.bdta.pro/images/4c78bdb2e5257424b7fd5d1e820e06e1.jpg'),
(21333, 1452, 'Matador S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106636.mp4', 'http://timg.bdta.pro/images/2662de011ce2a7467b78d819945135a8.jpg'),
(21334, 1452, 'Matador S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106637.mp4', 'http://timg.bdta.pro/images/2c5058cac21ebc6927565eb1013e69fa.jpg'),
(21335, 1452, 'Matador S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106638.mp4', 'http://timg.bdta.pro/images/487c6e0368ce4e9704c4e3990caf72c5.jpg'),
(21336, 1452, 'Matador S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106639.mp4', 'http://timg.bdta.pro/images/46d5a3a967ddb6c7a55621229f9e56a4.jpg'),
(21337, 1452, 'Matador S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106640.mp4', 'http://timg.bdta.pro/images/3050e4d434f5696d322f0d700a8b9e98.jpg'),
(21338, 1452, 'Matador S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106641.mp4', 'http://timg.bdta.pro/images/4ca0ae07bcfee6df47a8136b41df69f3.jpg'),
(21339, 1452, 'Matador S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/106642.mp4', 'http://timg.bdta.pro/images/8a1e3a6375a4eed4c19798b8fd1095d0.jpg'),
(21340, 1452, 'Matador S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/106643.mp4', 'http://gstaticontent.com/images/edI13v30mL7Hpx9QjOI6HqakxDy_big.jpg'),
(21341, 1453, 'Apache a Vida de Carlos Tevez S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106623.mp4', 'http://timg.bdta.pro/images/132e68376360270a2c29f0636231da0b.jpg'),
(21342, 1453, 'Apache a Vida de Carlos Tevez S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106624.mp4', 'http://timg.bdta.pro/images/67940ca2a6977faa9ff744bd72bf75c8.jpg'),
(21343, 1453, 'Apache a Vida de Carlos Tevez S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106625.mp4', 'http://timg.bdta.pro/images/1c03bd2d15353bc63ffcdcf263d80ab7.jpg'),
(21344, 1453, 'Apache a Vida de Carlos Tevez S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106626.mp4', 'http://timg.bdta.pro/images/140f23043de16037edbbf68430c1d8a9.jpg'),
(21345, 1453, 'Apache a Vida de Carlos Tevez S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106627.mp4', 'http://timg.bdta.pro/images/b3e24f1888da7131fdaf08a424f9de4c.jpg'),
(21346, 1453, 'Apache a Vida de Carlos Tevez S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106628.mp4', 'http://timg.bdta.pro/images/b05f71d79ad895e1a0290bf6199ab265.jpg'),
(21347, 1453, 'Apache a Vida de Carlos Tevez S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106629.mp4', 'http://timg.bdta.pro/images/b8ee14f76e05c3bc6286d8efca6b3da5.jpg'),
(21348, 1453, 'Apache a Vida de Carlos Tevez S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106630.mp4', 'http://timg.bdta.pro/images/93ce43f00fa4f2b271d7e3861c3253b4.jpg'),
(21349, 1454, 'O Píer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124691.mp4', 'http://timg.bdta.pro/images/a36183ba88818e36aa7a2d3a87aa5d44.jpg'),
(21350, 1454, 'O Píer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124692.mp4', 'http://timg.bdta.pro/images/1411d3a3157cb87a55157f87cfbb7ac5.jpg'),
(21351, 1454, 'O Píer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124693.mp4', 'http://timg.bdta.pro/images/686c15c5eba18cd8abefa3524aa00890.jpg'),
(21352, 1454, 'O Píer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124694.mp4', 'http://timg.bdta.pro/images/ab98eb8365adb3e5ac6cd58b0789664e.jpg'),
(21353, 1454, 'O Píer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124695.mp4', 'http://timg.bdta.pro/images/f9a1ab28a1052b3b3102409fc687be51.jpg'),
(21354, 1454, 'O Píer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124696.mp4', 'http://timg.bdta.pro/images/e68b17de7bb96a44e02f8c0b1d1afc30.jpg'),
(21355, 1454, 'O Píer S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124697.mp4', 'http://timg.bdta.pro/images/0a7e6a43ccc69898fc95ac02ab91b6d3.jpg'),
(21356, 1454, 'O Píer S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124698.mp4', 'http://timg.bdta.pro/images/4b344ad18fc362709c4c124e8b69d330.jpg'),
(21357, 1455, 'O Píer S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124699.mp4', 'http://timg.bdta.pro/images/8fb3770245a681d82d7b37885f4c4b27.jpg'),
(21358, 1455, 'O Píer S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124700.mp4', 'http://timg.bdta.pro/images/4f530b7d1ec4406accfe6b5c200f0988.jpg'),
(21359, 1455, 'O Píer S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124701.mp4', 'http://timg.bdta.pro/images/8d4a6868de96b067ade5620944caa198.jpg'),
(21360, 1455, 'O Píer S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124702.mp4', 'http://timg.bdta.pro/images/b1f02dc315b3c8ba5a9d5faa13c2ae76.jpg'),
(21361, 1455, 'O Píer S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124703.mp4', 'http://timg.bdta.pro/images/bafd3681f6ffdbbcae8c6deb1dbd018a.jpg'),
(21362, 1455, 'O Píer S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124704.mp4', 'http://timg.bdta.pro/images/6d9bdd5085a154400b6c2e65464590b5.jpg'),
(21363, 1455, 'O Píer S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124705.mp4', 'http://timg.bdta.pro/images/832c646c7c5daf65bc4c4e88796e0412.jpg'),
(21364, 1455, 'O Píer S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124706.mp4', 'http://timg.bdta.pro/images/86abef7e4b8c1d2072c4133b6125424f.jpg'),
(21365, 1456, 'The Crown S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254139.mp4', 'http://timg.bdta.pro/images/e3d5f526cda542a164a36a06b9019048.jpg'),
(21366, 1456, 'The Crown S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254140.mp4', 'http://timg.bdta.pro/images/8a2400dc7ed89c75b5fab0e99c30fd34.jpg'),
(21367, 1456, 'The Crown S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254141.mp4', 'http://timg.bdta.pro/images/fb700a9a5c6bb83e391cfc437739fde2.jpg'),
(21368, 1456, 'The Crown S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254142.mp4', 'http://timg.bdta.pro/images/2f1d755698928aed0ea0c1b23384a26b.jpg'),
(21369, 1456, 'The Crown S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254143.mp4', 'http://timg.bdta.pro/images/0baea5665bc8b48598b079278f969e70.jpg'),
(21370, 1456, 'The Crown S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254144.mp4', 'http://timg.bdta.pro/images/d59a840885dce00a29961595c5690172.jpg'),
(21371, 1456, 'The Crown S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254145.mp4', 'http://timg.bdta.pro/images/b5a8db7cf003787f56e1b6cf6b0ebe78.jpg'),
(21372, 1456, 'The Crown S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254146.mp4', 'http://timg.bdta.pro/images/959114000f3cb011087625209f7b6f44.jpg'),
(21373, 1456, 'The Crown S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254147.mp4', 'http://timg.bdta.pro/images/aa09d43f8f31ba837498a6ad126c63ac.jpg'),
(21374, 1456, 'The Crown S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254148.mp4', 'http://timg.bdta.pro/images/f5392d55ee2d4b6438d3dbdf68dd1275.jpg'),
(21375, 1457, 'The Crown S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254149.mp4', 'http://timg.bdta.pro/images/08e002d4b3c607d414f266afbbc30d62.jpg'),
(21376, 1457, 'The Crown S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254150.mp4', 'http://timg.bdta.pro/images/cbaed0d81266892fc209bbf32c67c6d3.jpg'),
(21377, 1457, 'The Crown S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254151.mp4', 'http://timg.bdta.pro/images/08563c29e46325fc31e8cca8e934831c.jpg'),
(21378, 1457, 'The Crown S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254152.mp4', 'http://timg.bdta.pro/images/06a6fade55bbaf6d92820543f1cda63c.jpg'),
(21379, 1457, 'The Crown S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254153.mp4', 'http://timg.bdta.pro/images/5697abdc9421235194d6bc55ccede8c7.jpg'),
(21380, 1457, 'The Crown S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254154.mp4', 'http://timg.bdta.pro/images/0e4c41ba05dfeb078ea3d87a9450ece9.jpg'),
(21381, 1457, 'The Crown S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254155.mp4', 'http://timg.bdta.pro/images/cbc9ee04f98a8f53924e73a49d1fe002.jpg'),
(21382, 1457, 'The Crown S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254156.mp4', 'http://timg.bdta.pro/images/ea3e22ae6eab42ba1dda35d4ec1a7c9a.jpg'),
(21383, 1457, 'The Crown S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254157.mp4', 'http://timg.bdta.pro/images/04d53688a53a0979b665d9906792d79b.jpg'),
(21384, 1457, 'The Crown S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254158.mp4', 'http://timg.bdta.pro/images/7d810511269124269530db9ed701c1da.jpg'),
(21385, 1458, 'The Crown S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254159.mp4', 'http://timg.bdta.pro/images/5c61a497e4d5dd97c5d48ca5b1d4c1aa.jpg'),
(21386, 1458, 'The Crown S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254160.mp4', 'http://timg.bdta.pro/images/e72f4f38e9c109b11199b680b52e0994.jpg'),
(21387, 1458, 'The Crown S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254161.mp4', 'http://timg.bdta.pro/images/42b3fa6fe2a9eef84b81e6553101818c.jpg'),
(21388, 1458, 'The Crown S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254162.mp4', 'http://timg.bdta.pro/images/95128670c5ce6e6b4dcbb2b63fb66486.jpg'),
(21389, 1458, 'The Crown S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254163.mp4', 'http://timg.bdta.pro/images/e718154f9ebb245e3b0f414497fc9b80.jpg'),
(21390, 1458, 'The Crown S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254164.mp4', 'http://timg.bdta.pro/images/2dbacec7e496508e1f7aee026176a261.jpg'),
(21391, 1458, 'The Crown S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254165.mp4', 'http://timg.bdta.pro/images/47e0d4f630eaf05bb22e84d87e39bf30.jpg'),
(21392, 1458, 'The Crown S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254166.mp4', 'http://timg.bdta.pro/images/208eb67994975e8503f90db2d0c9f017.jpg'),
(21393, 1458, 'The Crown S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254167.mp4', 'http://timg.bdta.pro/images/ae47ab4f88eec2389f75c54d40dffe14.jpg'),
(21394, 1458, 'The Crown S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254168.mp4', 'http://timg.bdta.pro/images/bf843350de048920d1635a8eb8aa78d1.jpg'),
(21395, 1459, 'The Crown S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254169.mp4', 'http://gstaticontent.com/images/hWhUtIaieHMBqjOLxudgdnprWse_big.jpg'),
(21396, 1459, 'The Crown S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254170.mp4', 'http://gstaticontent.com/images/hWhUtIaieHMBqjOLxudgdnprWse_big.jpg'),
(21397, 1459, 'The Crown S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254171.mp4', 'http://gstaticontent.com/images/hWhUtIaieHMBqjOLxudgdnprWse_big.jpg'),
(21398, 1459, 'The Crown S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254172.mp4', 'http://gstaticontent.com/images/hWhUtIaieHMBqjOLxudgdnprWse_big.jpg'),
(21399, 1459, 'The Crown S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254173.mp4', 'http://gstaticontent.com/images/hWhUtIaieHMBqjOLxudgdnprWse_big.jpg'),
(21400, 1459, 'The Crown S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254174.mp4', 'http://gstaticontent.com/images/hWhUtIaieHMBqjOLxudgdnprWse_big.jpg'),
(21401, 1459, 'The Crown S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254175.mp4', 'http://gstaticontent.com/images/hWhUtIaieHMBqjOLxudgdnprWse_big.jpg'),
(21402, 1459, 'The Crown S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254176.mp4', 'http://gstaticontent.com/images/hWhUtIaieHMBqjOLxudgdnprWse_big.jpg'),
(21403, 1459, 'The Crown S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254177.mp4', 'http://gstaticontent.com/images/hWhUtIaieHMBqjOLxudgdnprWse_big.jpg'),
(21404, 1459, 'The Crown S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254178.mp4', 'http://gstaticontent.com/images/hWhUtIaieHMBqjOLxudgdnprWse_big.jpg'),
(21405, 1460, 'The Crown S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDXIMOOhm0XiMGLwjlCGNwmlM7C.jpg'),
(21406, 1460, 'The Crown S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l7yDTcVV2qBlxYva6oDMAQZYo2t.jpg'),
(21407, 1460, 'The Crown S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4A6N0maeU8v0wVRWrts3qS07AuP.jpg'),
(21408, 1460, 'The Crown S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vuO5GRwqK5QaTY6kcxtJnIGRluT.jpg'),
(21409, 1460, 'The Crown S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v1Md2OB8Iv4JSoni3cE1nLyU9Gc.jpg'),
(21410, 1460, 'The Crown S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xu4DhncgI7un5myULM95AioleDN.jpg'),
(21411, 1460, 'The Crown S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oTaurB4XjoRGixKtT2qL6RF7IHU.jpg'),
(21412, 1460, 'The Crown S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9kZOBIAFA2sk9Xc0n0tnp11oJW.jpg'),
(21413, 1460, 'The Crown S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rMfaBo7WNgoTiuM9lvdDbj5AbqP.jpg'),
(21414, 1460, 'The Crown S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZdPe6ss4ZMc7tANxUrwVZOja0I.jpg'),
(21415, 1461, 'The Crown S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254189.mp4', 'http://gstaticontent.com/images/hWhUtIaieHMBqjOLxudgdnprWse_big.jpg'),
(21416, 1461, 'The Crown S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254190.mp4', 'http://gstaticontent.com/images/hWhUtIaieHMBqjOLxudgdnprWse_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(21417, 1461, 'The Crown S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254191.mp4', 'http://gstaticontent.com/images/hWhUtIaieHMBqjOLxudgdnprWse_big.jpg'),
(21418, 1461, 'The Crown S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254192.mp4', 'http://gstaticontent.com/images/hWhUtIaieHMBqjOLxudgdnprWse_big.jpg'),
(21419, 1461, 'The Crown S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254193.mp4', 'http://gstaticontent.com/images/hWhUtIaieHMBqjOLxudgdnprWse_big.jpg'),
(21420, 1461, 'The Crown S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254194.mp4', 'http://gstaticontent.com/images/hWhUtIaieHMBqjOLxudgdnprWse_big.jpg'),
(21421, 1461, 'The Crown S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254195.mp4', 'http://gstaticontent.com/images/hWhUtIaieHMBqjOLxudgdnprWse_big.jpg'),
(21422, 1461, 'The Crown S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254196.mp4', 'http://gstaticontent.com/images/hWhUtIaieHMBqjOLxudgdnprWse_big.jpg'),
(21423, 1461, 'The Crown S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254197.mp4', 'http://gstaticontent.com/images/hWhUtIaieHMBqjOLxudgdnprWse_big.jpg'),
(21424, 1461, 'The Crown S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254198.mp4', 'http://gstaticontent.com/images/hWhUtIaieHMBqjOLxudgdnprWse_big.jpg'),
(21425, 1462, 'Charmed: Nova Geração S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197449.mp4', 'http://timg.bdta.pro/images/314fe75417d0ab7266d46021db6d93be.jpg'),
(21426, 1462, 'Charmed: Nova Geração S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197450.mp4', 'http://timg.bdta.pro/images/faad69962b77dda8e3a05c746d491d57.jpg'),
(21427, 1462, 'Charmed: Nova Geração S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197451.mp4', 'http://timg.bdta.pro/images/08f955e6e9eec178dcec3cfee614e742.jpg'),
(21428, 1462, 'Charmed: Nova Geração S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197452.mp4', 'http://timg.bdta.pro/images/4649106edba9c5875ef9e2e432ef1f60.jpg'),
(21429, 1462, 'Charmed: Nova Geração S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197453.mp4', 'http://timg.bdta.pro/images/9d1b17ef8baa21ff21205cda8e3fd837.jpg'),
(21430, 1462, 'Charmed: Nova Geração S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197454.mp4', 'http://timg.bdta.pro/images/c3e95d27f1d6dd5dc7a34cadbc235cdb.jpg'),
(21431, 1462, 'Charmed: Nova Geração S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197455.mp4', 'http://timg.bdta.pro/images/d034faf830d0ff96174d4e7a36cc15b1.jpg'),
(21432, 1462, 'Charmed: Nova Geração S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197456.mp4', 'http://timg.bdta.pro/images/166eef9214a4ac46b979fa0247752be1.jpg'),
(21433, 1462, 'Charmed: Nova Geração S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/197457.mp4', 'http://timg.bdta.pro/images/facf04548e078a30868bacaf1d8f8ebf.jpg'),
(21434, 1462, 'Charmed: Nova Geração S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/197458.mp4', 'http://timg.bdta.pro/images/2d16282d068166d6e9567b77d71585a2.jpg'),
(21435, 1462, 'Charmed: Nova Geração S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/197459.mp4', 'http://timg.bdta.pro/images/f27993e79e4114a6100b3dbaa9561f44.jpg'),
(21436, 1462, 'Charmed: Nova Geração S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/197460.mp4', 'http://timg.bdta.pro/images/9f6e2a0a830c042909be91019cdec7a3.jpg'),
(21437, 1462, 'Charmed: Nova Geração S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/197461.mp4', 'http://timg.bdta.pro/images/8553204d57c4724c0bfd2b46a83bfc4e.jpg'),
(21438, 1462, 'Charmed: Nova Geração S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/197462.mp4', 'http://timg.bdta.pro/images/133a48bbe94a413df1bfec65f4dd989d.jpg'),
(21439, 1462, 'Charmed: Nova Geração S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/197463.mp4', 'http://timg.bdta.pro/images/843e4e02f0c4c279474e7b8e47119ee9.jpg'),
(21440, 1462, 'Charmed: Nova Geração S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/197464.mp4', 'http://timg.bdta.pro/images/94422c4c04f4576b011f836912ae4c2e.jpg'),
(21441, 1462, 'Charmed: Nova Geração S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/197465.mp4', 'http://timg.bdta.pro/images/65ddf47cc381cfc373e1cecf3914742f.jpg'),
(21442, 1462, 'Charmed: Nova Geração S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/197466.mp4', 'http://timg.bdta.pro/images/74943f9b70dd79ffa30d607270469e66.jpg'),
(21443, 1462, 'Charmed: Nova Geração S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/197467.mp4', 'http://timg.bdta.pro/images/eb63ac3c1a580c2c51c159199e1ca07f.jpg'),
(21444, 1462, 'Charmed: Nova Geração S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/197468.mp4', 'http://timg.bdta.pro/images/66effab26145cf8e591bd9a3720c4dab.jpg'),
(21445, 1462, 'Charmed: Nova Geração S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/197469.mp4', 'http://timg.bdta.pro/images/dde625cd38038b6a518eae529c7be4ff.jpg'),
(21446, 1462, 'Charmed: Nova Geração S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/197470.mp4', 'http://timg.bdta.pro/images/52f9eaf16ccf3f6226d5633845fdd63f.jpg'),
(21447, 1463, 'Charmed: Nova Geração S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197471.mp4', 'http://timg.bdta.pro/images/d4e05e5341bb33754c0e31b4bc07e52b.jpg'),
(21448, 1463, 'Charmed: Nova Geração S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197472.mp4', 'http://timg.bdta.pro/images/f03ce6a0b0a090c22e8760482968249f.jpg'),
(21449, 1463, 'Charmed: Nova Geração S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197473.mp4', 'http://timg.bdta.pro/images/7ada60bff3d45b7bc8188b3d883adfe4.jpg'),
(21450, 1463, 'Charmed: Nova Geração S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197474.mp4', 'http://timg.bdta.pro/images/979ccbbf0f31bfc3145a5e11addbd1e7.jpg'),
(21451, 1463, 'Charmed: Nova Geração S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197475.mp4', 'http://timg.bdta.pro/images/03e21535f37f6b35bc880d73e6a0c95f.jpg'),
(21452, 1463, 'Charmed: Nova Geração S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197476.mp4', 'http://timg.bdta.pro/images/f2ebcf1b91ab6197d232bd2b224d8b6c.jpg'),
(21453, 1463, 'Charmed: Nova Geração S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197477.mp4', 'http://timg.bdta.pro/images/f2d5b110409bfae9cb7535efa35b85ed.jpg'),
(21454, 1463, 'Charmed: Nova Geração S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197478.mp4', 'http://timg.bdta.pro/images/9a4f7a27de39afbdc51e69435f2d363e.jpg'),
(21455, 1463, 'Charmed: Nova Geração S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/197479.mp4', 'http://timg.bdta.pro/images/5dfb2265a5ebf037d25dc29783c7d9b5.jpg'),
(21456, 1463, 'Charmed: Nova Geração S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/197480.mp4', 'http://timg.bdta.pro/images/a75354cef3f73094d22ac5ce0a7e2ad2.jpg'),
(21457, 1463, 'Charmed: Nova Geração S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/197481.mp4', 'http://timg.bdta.pro/images/cf6790553f8f53316724832f837a444e.jpg'),
(21458, 1463, 'Charmed: Nova Geração S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/197482.mp4', 'http://timg.bdta.pro/images/cdd955a175b96c21f0751159b8cd42e9.jpg'),
(21459, 1463, 'Charmed: Nova Geração S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/197483.mp4', 'http://timg.bdta.pro/images/fa45d56f3628e9618126edfe5afe78a5.jpg'),
(21460, 1463, 'Charmed: Nova Geração S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/197484.mp4', 'http://timg.bdta.pro/images/e3c06b17a5ae14d27ad361fb21fa2d25.jpg'),
(21461, 1463, 'Charmed: Nova Geração S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/197485.mp4', 'http://timg.bdta.pro/images/c679140fd6e85c2ca9a67af2337d6abe.jpg'),
(21462, 1463, 'Charmed: Nova Geração S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/197486.mp4', 'http://timg.bdta.pro/images/210ea6a94ef0c6e47ce22bf3576ab61f.jpg'),
(21463, 1463, 'Charmed: Nova Geração S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/197487.mp4', 'http://timg.bdta.pro/images/3e1361323ba41b7ec557a20fad397de8.jpg'),
(21464, 1463, 'Charmed: Nova Geração S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/197488.mp4', 'http://timg.bdta.pro/images/e23ae42721bb661705753b9af98140f5.jpg'),
(21465, 1464, 'Charmed: Nova Geração S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i0VFkMbr4kN3MUzE6wvAcSYNm3N.jpg'),
(21466, 1464, 'Charmed: Nova Geração S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j0KIwSORJ9lds9BkPqeWIDkJEX3.jpg'),
(21467, 1464, 'Charmed: Nova Geração S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zQomsXeqY2Xy5SMkhC8lW9TqQ5L.jpg'),
(21468, 1464, 'Charmed: Nova Geração S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bozXNm82gTzS2zDOYb6IKvhANni.jpg'),
(21469, 1464, 'Charmed: Nova Geração S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rSz0JELMj7yZppC8DGZvpijVlrq.jpg'),
(21470, 1464, 'Charmed: Nova Geração S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hpI6Ve6514nlHMVIIqZpz53rEK8.jpg'),
(21471, 1464, 'Charmed: Nova Geração S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n9xFQVFRGuPvbZZlXXGW5l8qwjr.jpg'),
(21472, 1464, 'Charmed: Nova Geração S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/W95lZxu7LKBIpBW5BPZIySG4Ee.jpg'),
(21473, 1464, 'Charmed: Nova Geração S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/197497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/83T2efqKEI2tQ8FCQQlR8SKfkrf.jpg'),
(21474, 1464, 'Charmed: Nova Geração S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/197498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/LzAYAggehOEkw5ySDroCoyBToy.jpg'),
(21475, 1464, 'Charmed: Nova Geração S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/197499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ed4eYhDhn48lgUcz9bo9LdwH28i.jpg'),
(21476, 1464, 'Charmed: Nova Geração S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/197500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oF6jSMx1OE2hLvWFiQaekMPV8wl.jpg'),
(21477, 1464, 'Charmed: Nova Geração S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/197501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y8ghdy6zdwiIZ5zqvtS6zG3DDkd.jpg'),
(21478, 1464, 'Charmed: Nova Geração S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/197502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mV7CHFjAW2ZWhbj38Vt7UrmRiGD.jpg'),
(21479, 1464, 'Charmed: Nova Geração S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/197503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o22kZVKAaD0MH9kK9FOcf2ztTHB.jpg'),
(21480, 1464, 'Charmed: Nova Geração S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/197504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/amW9MxAOd895WkAiaINnboOEsTx.jpg'),
(21481, 1464, 'Charmed: Nova Geração S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/197505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qqK3OFIT9TJkkhx3ZkGmrUvXssU.jpg'),
(21482, 1464, 'Charmed: Nova Geração S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/197506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6RT3qXxSuzccmx5mWE7I2eIk7dQ.jpg'),
(21483, 1465, 'Charmed: Nova Geração S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197507.mp4', 'http://timg.bdta.pro/images/9ab7c67952d74be87c7ee797801a4d9c.jpg'),
(21484, 1465, 'Charmed: Nova Geração S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197508.mp4', 'http://timg.bdta.pro/images/d653c1af6d675421332a2af3fee3be71.jpg'),
(21485, 1465, 'Charmed: Nova Geração S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197509.mp4', 'http://timg.bdta.pro/images/2f3216742306f9cac5d1c846e2fff796.jpg'),
(21486, 1465, 'Charmed: Nova Geração S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197510.mp4', 'http://timg.bdta.pro/images/0bc5ce3aaf1f23e8c93d840d103a1dab.jpg'),
(21487, 1465, 'Charmed: Nova Geração S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197511.mp4', 'http://timg.bdta.pro/images/8cc6974f5ac51f701a67c260f636fb81.jpg'),
(21488, 1465, 'Charmed: Nova Geração S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197512.mp4', 'http://timg.bdta.pro/images/4c8802f7385fb838880bc899df5b7d7c.jpg'),
(21489, 1465, 'Charmed: Nova Geração S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197513.mp4', 'http://timg.bdta.pro/images/0241119945fc495d322c530131c3f4a4.jpg'),
(21490, 1465, 'Charmed: Nova Geração S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197514.mp4', 'http://timg.bdta.pro/images/80d69a0b1a37be748bdcb971b7c67313.jpg'),
(21491, 1465, 'Charmed: Nova Geração S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/197515.mp4', 'http://timg.bdta.pro/images/31f326437be46b918f2df8e3e70f32f8.jpg'),
(21492, 1465, 'Charmed: Nova Geração S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/197516.mp4', 'http://timg.bdta.pro/images/b9caf4afedcb95a14dbeefe8c60e6292.jpg'),
(21493, 1465, 'Charmed: Nova Geração S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/197517.mp4', 'http://timg.bdta.pro/images/70a2545baf3f48d677d9ef9b2d816140.jpg'),
(21494, 1465, 'Charmed: Nova Geração S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/197518.mp4', 'http://timg.bdta.pro/images/b06e722d807d42774c272b15feca3214.jpg'),
(21495, 1465, 'Charmed: Nova Geração S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/197519.mp4', 'http://timg.bdta.pro/images/9bc1dbea4897ccab7f10975d6532ae60.jpg'),
(21496, 1466, 'The Witcher S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227340.mp4', 'http://timg.bdta.pro/images/f5bd22f5e81da671c2690cbc87bcc36b.jpg'),
(21497, 1466, 'The Witcher S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227341.mp4', 'http://timg.bdta.pro/images/94a95914b8b8684bf6e0cafa510f8da3.jpg'),
(21498, 1466, 'The Witcher S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227342.mp4', 'http://timg.bdta.pro/images/c695cb92c5994942e6ac16b3519b488a.jpg'),
(21499, 1466, 'The Witcher S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227343.mp4', 'http://timg.bdta.pro/images/f63ea31d0fa900adaadd46b237b6b8e2.jpg'),
(21500, 1466, 'The Witcher S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227344.mp4', 'http://timg.bdta.pro/images/7ba7fc642ec4879a70e1fce0be295f2e.jpg'),
(21501, 1466, 'The Witcher S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227345.mp4', 'http://timg.bdta.pro/images/fd4500e1e85d94af8d7c09c72c1e4cb8.jpg'),
(21502, 1466, 'The Witcher S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227346.mp4', 'http://timg.bdta.pro/images/07391d0826624ed26f5862008895055e.jpg'),
(21503, 1466, 'The Witcher S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227347.mp4', 'http://timg.bdta.pro/images/8430d1a04f05bb33e0f734976eab8615.jpg'),
(21504, 1467, 'The Witcher S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7i3iA3BjH88wnDiQ0o1rBtEkQS8.jpg'),
(21505, 1467, 'The Witcher S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wJwfyZQtTYkW0eV0jbZuJjAuiOV.jpg'),
(21506, 1467, 'The Witcher S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmDVFqLK9GbeDgAgAR4Fu3P7XoF.jpg'),
(21507, 1467, 'The Witcher S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yXupATkh5yVWpyClLa9c3sZbGpj.jpg'),
(21508, 1467, 'The Witcher S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kpJrLQQZl4RgPGCbuKFjf1T0JTI.jpg'),
(21509, 1467, 'The Witcher S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ZHaDFstWaMpHy9GG8w9iFHbeAL.jpg'),
(21510, 1467, 'The Witcher S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aIJ2CmwggH11QxfdmfL2ShM6sST.jpg'),
(21511, 1467, 'The Witcher S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qEfDFrmsF3L9EfnUkniXmEtXITm.jpg'),
(21512, 1468, 'The Witcher S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8dCUiThX5DoE53leCLhpcoJEhL.jpg'),
(21513, 1468, 'The Witcher S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBHEDZ84PmVQEJHp0V0AjyZnvrZ.jpg'),
(21514, 1468, 'The Witcher S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rgKiXuzNpRCm8TT5tNUx4jtPFd3.jpg'),
(21515, 1468, 'The Witcher S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q4vdiuiL36B7lGqzQvmm1NkUMpO.jpg'),
(21516, 1468, 'The Witcher S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ePpQeSYtWPZdyIOPCUTFQQqtsXU.jpg'),
(21517, 1468, 'The Witcher S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jPc4g8j7zv70FQXbMEMsFaGyeLX.jpg'),
(21518, 1468, 'The Witcher S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nbTpbjnQ4eZVsaNjDAPFpZ6jzKv.jpg'),
(21519, 1468, 'The Witcher S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/chb4gfrM1MMEp9hPo0j4Lb6pCZ2.jpg'),
(21520, 1469, 'The Witcher S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/890638.mp4', 'http://gstaticontent.com/images/A2oBYUKgjdy0UeIP88kkdyjw8z6_big.jpg'),
(21521, 1469, 'The Witcher S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/890639.mp4', 'http://gstaticontent.com/images/A2oBYUKgjdy0UeIP88kkdyjw8z6_big.jpg'),
(21522, 1469, 'The Witcher S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/890640.mp4', 'http://gstaticontent.com/images/A2oBYUKgjdy0UeIP88kkdyjw8z6_big.jpg'),
(21523, 1469, 'The Witcher S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/890641.mp4', 'http://gstaticontent.com/images/A2oBYUKgjdy0UeIP88kkdyjw8z6_big.jpg'),
(21524, 1469, 'The Witcher S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/890642.mp4', 'http://gstaticontent.com/images/A2oBYUKgjdy0UeIP88kkdyjw8z6_big.jpg'),
(21525, 1469, 'The Witcher S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/890643.mp4', 'http://gstaticontent.com/images/A2oBYUKgjdy0UeIP88kkdyjw8z6_big.jpg'),
(21526, 1469, 'The Witcher S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/890644.mp4', 'http://gstaticontent.com/images/A2oBYUKgjdy0UeIP88kkdyjw8z6_big.jpg'),
(21527, 1469, 'The Witcher S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/890645.mp4', 'http://gstaticontent.com/images/A2oBYUKgjdy0UeIP88kkdyjw8z6_big.jpg'),
(21528, 1470, 'Filmes Que Marcam Época S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210100.mp4', 'http://timg.bdta.pro/images/005a690cdaeb4e5782a81114619b3d5f.jpg'),
(21529, 1470, 'Filmes Que Marcam Época S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210101.mp4', 'http://timg.bdta.pro/images/419be59dea61a7c49bcac6aef64def7d.jpg'),
(21530, 1470, 'Filmes Que Marcam Época S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210102.mp4', 'http://timg.bdta.pro/images/8a3325b47c85df114f8ec957e001c593.jpg'),
(21531, 1470, 'Filmes Que Marcam Época S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210103.mp4', 'http://timg.bdta.pro/images/05dc51ac43fcc83b813d784e012aa04b.jpg'),
(21532, 1471, 'Hebe S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106604.mp4', 'http://timg.bdta.pro/images/e646542567afa5a737ce02f7eb4fd5cc.jpg'),
(21533, 1471, 'Hebe S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106605.mp4', 'http://gstaticontent.com/images/7QBzwpXXmF46pEhWfZS1m8SEbjS_big.jpg'),
(21534, 1471, 'Hebe S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106606.mp4', 'http://timg.bdta.pro/images/018e902a10ffff932b9a9006bef25653.jpg'),
(21535, 1471, 'Hebe S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106607.mp4', 'http://timg.bdta.pro/images/e86a2d289ec2591c9d28aea6be715c7a.jpg'),
(21536, 1471, 'Hebe S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106608.mp4', 'http://gstaticontent.com/images/7QBzwpXXmF46pEhWfZS1m8SEbjS_big.jpg'),
(21537, 1471, 'Hebe S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106609.mp4', 'http://timg.bdta.pro/images/c5e5f761488b47e7761d7b57adfbfbd2.jpg'),
(21538, 1471, 'Hebe S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106610.mp4', 'http://timg.bdta.pro/images/c49178f600f654d5168ea24817df9d37.jpg'),
(21539, 1471, 'Hebe S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106611.mp4', 'http://timg.bdta.pro/images/5797142ff3d4b42b36ee7a69107d8d95.jpg'),
(21540, 1471, 'Hebe S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106612.mp4', 'http://timg.bdta.pro/images/82a98c0e9a3bf51a16943daf98ee4983.jpg'),
(21541, 1471, 'Hebe S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106613.mp4', 'http://timg.bdta.pro/images/a8bbd126388de480d9d65879ef84ddbd.jpg'),
(21542, 1472, 'L.A.s Finest S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137862.mp4', 'http://timg.bdta.pro/images/351b9863ff008987d060f310161349c5.jpg'),
(21543, 1472, 'L.A.s Finest S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137863.mp4', 'http://timg.bdta.pro/images/e8a1e3bfa6701212be28e0c0f7bc40e0.jpg'),
(21544, 1472, 'L.A.s Finest S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137864.mp4', 'http://timg.bdta.pro/images/ca020d19862eea23bd1b6b5ccfb1ea85.jpg'),
(21545, 1472, 'L.A.s Finest S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137865.mp4', 'http://timg.bdta.pro/images/0a8af3d3c1f7968a495a34509ae38ede.jpg'),
(21546, 1472, 'L.A.s Finest S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137866.mp4', 'http://timg.bdta.pro/images/0fff40f85bb65b27f44b47775a92c5f6.jpg'),
(21547, 1472, 'L.A.s Finest S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137867.mp4', 'http://timg.bdta.pro/images/b1d2e87f8c38d017f9c077f3af59572f.jpg'),
(21548, 1472, 'L.A.s Finest S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137868.mp4', 'http://timg.bdta.pro/images/2f90042cdfcc91030b0bdf7d828133eb.jpg'),
(21549, 1472, 'L.A.s Finest S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137869.mp4', 'http://timg.bdta.pro/images/684fa03a7eb962f9966234be28a7b287.jpg'),
(21550, 1472, 'L.A.s Finest S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137870.mp4', 'http://timg.bdta.pro/images/6d67665c7b53094531b6e0bb7acb59a1.jpg'),
(21551, 1472, 'L.A.s Finest S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137871.mp4', 'http://timg.bdta.pro/images/6dd259118d1e53ec279ac2eda758a19d.jpg'),
(21552, 1472, 'L.A.s Finest S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137872.mp4', 'http://timg.bdta.pro/images/bbe8b889d61a35d6ee149b2253eee8e7.jpg'),
(21553, 1472, 'L.A.s Finest S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137873.mp4', 'http://timg.bdta.pro/images/fb31527ab6012d2ae70f7acaf10264b5.jpg'),
(21554, 1472, 'L.A.s Finest S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137874.mp4', 'http://timg.bdta.pro/images/177d84140a745dd642d3f1e2c3b3ccd9.jpg'),
(21555, 1473, 'L.A.s Finest S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137875.mp4', 'http://timg.bdta.pro/images/0110fa91851f0dc5dc910839272b1f18.jpg'),
(21556, 1473, 'L.A.s Finest S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137876.mp4', 'http://timg.bdta.pro/images/0dca6b65e81b5745dabc8b143381382f.jpg'),
(21557, 1473, 'L.A.s Finest S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137877.mp4', 'http://timg.bdta.pro/images/ed2ac46c464a1edabb2075d7cc005df1.jpg'),
(21558, 1473, 'L.A.s Finest S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137878.mp4', 'http://timg.bdta.pro/images/0f22633edd31042b15b34663da936022.jpg'),
(21559, 1473, 'L.A.s Finest S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137879.mp4', 'http://timg.bdta.pro/images/0c0f64473bfe03d8d604708389ba41ba.jpg'),
(21560, 1473, 'L.A.s Finest S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137880.mp4', 'http://timg.bdta.pro/images/832153b5e9360d8ddce388e987c7354e.jpg'),
(21561, 1473, 'L.A.s Finest S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6eLfe0WPWtAqEiT3rCzCtT9fB97.jpg'),
(21562, 1473, 'L.A.s Finest S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137882.mp4', 'http://gstaticontent.com/images/3pHuGAtXMvksADRfd7AIdi4Kkin_big.jpg'),
(21563, 1473, 'L.A.s Finest S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137883.mp4', 'http://gstaticontent.com/images/3pHuGAtXMvksADRfd7AIdi4Kkin_big.jpg'),
(21564, 1473, 'L.A.s Finest S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137884.mp4', 'http://gstaticontent.com/images/3pHuGAtXMvksADRfd7AIdi4Kkin_big.jpg'),
(21565, 1473, 'L.A.s Finest S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137885.mp4', 'http://gstaticontent.com/images/3pHuGAtXMvksADRfd7AIdi4Kkin_big.jpg'),
(21566, 1473, 'L.A.s Finest S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137886.mp4', 'http://gstaticontent.com/images/3pHuGAtXMvksADRfd7AIdi4Kkin_big.jpg'),
(21567, 1473, 'L.A.s Finest S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137887.mp4', 'http://gstaticontent.com/images/3pHuGAtXMvksADRfd7AIdi4Kkin_big.jpg'),
(21568, 1474, 'Legion S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106559.mp4', 'http://timg.bdta.pro/images/d7dd9bcdd45cefd6d3c25800f46e8f85.jpg'),
(21569, 1474, 'Legion S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106560.mp4', 'http://timg.bdta.pro/images/3c7d729a5264611480d1ee1e702adbbb.jpg'),
(21570, 1474, 'Legion S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106561.mp4', 'http://timg.bdta.pro/images/43876375219beb2418994877af643b31.jpg'),
(21571, 1474, 'Legion S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106562.mp4', 'http://timg.bdta.pro/images/d8cbf62e76772b26956b700969b729f2.jpg'),
(21572, 1474, 'Legion S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106563.mp4', 'http://timg.bdta.pro/images/54e613439c43ed2ca49893b97e1e25f4.jpg'),
(21573, 1474, 'Legion S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106564.mp4', 'http://timg.bdta.pro/images/6b5e0c9bf3b0df4f3f445b3b2273f042.jpg'),
(21574, 1474, 'Legion S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106565.mp4', 'http://timg.bdta.pro/images/d11940e4f92bc9214d8b0705aa2257e9.jpg'),
(21575, 1474, 'Legion S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106566.mp4', 'http://timg.bdta.pro/images/7be049745e87d7c5d00b7efec88f8c87.jpg'),
(21576, 1475, 'Legion S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106567.mp4', 'http://timg.bdta.pro/images/15e7860e88564e96f2fd7bdf662311f1.jpg'),
(21577, 1475, 'Legion S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106568.mp4', 'http://timg.bdta.pro/images/8d855b4115b90d7b5ffe3a28ce7fcd18.jpg'),
(21578, 1475, 'Legion S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106569.mp4', 'http://timg.bdta.pro/images/5848a2b8f554b25db724b716d12e4486.jpg'),
(21579, 1475, 'Legion S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106570.mp4', 'http://timg.bdta.pro/images/c2cf74267ff243e56669ad025af3d4d1.jpg'),
(21580, 1475, 'Legion S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106571.mp4', 'http://timg.bdta.pro/images/05dc455fcd0531b3462944f5af1d24b8.jpg'),
(21581, 1475, 'Legion S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106572.mp4', 'http://timg.bdta.pro/images/ee836e5ae4a0a74fd9972e705da662be.jpg'),
(21582, 1475, 'Legion S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106573.mp4', 'http://timg.bdta.pro/images/3bcb6cc87c74ff1674311a39e6abda87.jpg'),
(21583, 1475, 'Legion S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106574.mp4', 'http://timg.bdta.pro/images/090ea778dd8f5730445f6a889fc8f614.jpg'),
(21584, 1475, 'Legion S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106575.mp4', 'http://timg.bdta.pro/images/825cab05d114824df9a3ebfbda4a01b0.jpg'),
(21585, 1475, 'Legion S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106576.mp4', 'http://timg.bdta.pro/images/4905f5c5880f0bdbb05b354e67b06125.jpg'),
(21586, 1475, 'Legion S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106577.mp4', 'http://timg.bdta.pro/images/54996529ad7b320c869d2e03a2a822c1.jpg'),
(21587, 1476, 'Legion S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/527390.mp4', 'http://gstaticontent.com/images/7149eddf6b9e5bf50a3427eb6b8f04bf.jpg'),
(21588, 1476, 'Legion S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/527391.mp4', 'http://gstaticontent.com/images/7b7b123e62bde69a053b534c76e15695.jpg'),
(21589, 1476, 'Legion S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/527392.mp4', 'http://gstaticontent.com/images/4e6e46f8985c5d73d40fa0504801858a.jpg'),
(21590, 1476, 'Legion S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/527393.mp4', 'http://gstaticontent.com/images/ad541f06dd627fd13fc6303b9400e99a.jpg'),
(21591, 1476, 'Legion S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/527394.mp4', 'http://gstaticontent.com/images/b05d52412c6e59d52b79424ddb629fc8.jpg'),
(21592, 1476, 'Legion S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/527395.mp4', 'http://gstaticontent.com/images/349e52bef3a5b679e7e17b507d04ff55.jpg'),
(21593, 1476, 'Legion S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/527396.mp4', 'http://gstaticontent.com/images/6e880855b641c8e54390d7dfd26c2f44.jpg'),
(21594, 1476, 'Legion S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/527397.mp4', 'http://gstaticontent.com/images/cc47105ba9a4035d21aad180d3da8eb5.jpg'),
(21595, 1477, 'Lugar de Mulher S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106555.mp4', 'http://gstaticontent.com/images/9VUh1tbBubznBdjV5OomzupyCgL_big.jpg'),
(21596, 1477, 'Lugar de Mulher S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106556.mp4', 'http://gstaticontent.com/images/9VUh1tbBubznBdjV5OomzupyCgL_big.jpg'),
(21597, 1477, 'Lugar de Mulher S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106557.mp4', 'http://gstaticontent.com/images/9VUh1tbBubznBdjV5OomzupyCgL_big.jpg'),
(21598, 1477, 'Lugar de Mulher S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106558.mp4', 'http://gstaticontent.com/images/9VUh1tbBubznBdjV5OomzupyCgL_big.jpg'),
(21599, 1478, 'Amor Moderno S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160269.mp4', 'http://timg.bdta.pro/images/69d2075f3ac08eb28fbb2c2f5238dd06.jpg'),
(21600, 1478, 'Amor Moderno S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160270.mp4', 'http://timg.bdta.pro/images/043cb815ee6f789c61cd64dcf1a52bf2.jpg'),
(21601, 1478, 'Amor Moderno S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160271.mp4', 'http://timg.bdta.pro/images/036ab371ec9c0f3296abda3dcb4a51f2.jpg'),
(21602, 1478, 'Amor Moderno S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160272.mp4', 'http://timg.bdta.pro/images/5353e5de457cfe91795c0e9e0b9e0786.jpg'),
(21603, 1478, 'Amor Moderno S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160273.mp4', 'http://timg.bdta.pro/images/e41da5becfc85e426759e7463a2d78a4.jpg'),
(21604, 1478, 'Amor Moderno S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160274.mp4', 'http://timg.bdta.pro/images/bb2e96eb2e0043bd60881a2114db6e3c.jpg'),
(21605, 1478, 'Amor Moderno S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160275.mp4', 'http://timg.bdta.pro/images/04af40a06043707443cf76745ed59166.jpg'),
(21606, 1478, 'Amor Moderno S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160276.mp4', 'http://timg.bdta.pro/images/6b155c2427a0c3744828ec7e6f96b0fd.jpg'),
(21607, 1479, 'Amor Moderno S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1jBqXQbVntKEIPVFmQT7UOJUYTA.jpg'),
(21608, 1479, 'Amor Moderno S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b7AVlclYrRDzZjsw68mNdfgYI5z.jpg'),
(21609, 1479, 'Amor Moderno S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6SRT4wL3mcT4KRDKLHVuUfgvb2m.jpg'),
(21610, 1479, 'Amor Moderno S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n62JFZBAzQa5S37Xh0TRcLkU5eI.jpg'),
(21611, 1479, 'Amor Moderno S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/79nKmPZoute20rOttMrP6XlYcaX.jpg'),
(21612, 1479, 'Amor Moderno S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ounMQqutcC5pemP088YNnMlARZS.jpg'),
(21613, 1479, 'Amor Moderno S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/orMNqQQWNQCJjPZjbRXHT0RulJZ.jpg'),
(21614, 1479, 'Amor Moderno S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nBOBmty9k5QqIsMHa6aUf1ivJzW.jpg'),
(21615, 1480, 'Mágica para a Humanidade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106511.mp4', 'http://timg.bdta.pro/images/1c0650e813099d432d7d02dc3966caef.jpg'),
(21616, 1480, 'Mágica para a Humanidade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106512.mp4', 'http://timg.bdta.pro/images/29bf3552dd90716914fd2e3f2d9cbe32.jpg'),
(21617, 1480, 'Mágica para a Humanidade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106513.mp4', 'http://timg.bdta.pro/images/981c8f95617545d5b54d80ee07b928d9.jpg'),
(21618, 1480, 'Mágica para a Humanidade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106514.mp4', 'http://timg.bdta.pro/images/483e9fc41cb882a5b0d0104f871fa683.jpg'),
(21619, 1480, 'Mágica para a Humanidade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106515.mp4', 'http://timg.bdta.pro/images/ae091c5e4119416261cb2304bd1cc1e7.jpg'),
(21620, 1480, 'Mágica para a Humanidade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106516.mp4', 'http://timg.bdta.pro/images/ba3e0125195729b5c29528648a7ed2c8.jpg'),
(21621, 1481, 'Mágica para a Humanidade S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106517.mp4', 'http://timg.bdta.pro/images/abf0e5824ce38c97f8f3f71b0020fc3c.jpg'),
(21622, 1481, 'Mágica para a Humanidade S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106518.mp4', 'http://timg.bdta.pro/images/686eb092e4286491e47b45e8cb761614.jpg'),
(21623, 1481, 'Mágica para a Humanidade S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106519.mp4', 'http://timg.bdta.pro/images/61f99ddc70e229f5a587fa0cf8d25f42.jpg'),
(21624, 1481, 'Mágica para a Humanidade S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106520.mp4', 'http://timg.bdta.pro/images/ce59ec96c3f06662bf63a9a658cc4172.jpg'),
(21625, 1481, 'Mágica para a Humanidade S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106521.mp4', 'http://timg.bdta.pro/images/14b8774723d4834a314b6992d6eb0c35.jpg'),
(21626, 1481, 'Mágica para a Humanidade S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106522.mp4', 'http://timg.bdta.pro/images/bab463190ceea7c084240120802ac75b.jpg'),
(21627, 1482, 'Narcoworld: Histórias do Tráfico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106507.mp4', 'http://timg.bdta.pro/images/1f8419049c3522c6b3fa5222e3f6a02c.jpg'),
(21628, 1482, 'Narcoworld: Histórias do Tráfico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106508.mp4', 'http://timg.bdta.pro/images/d1991f553b82cbbcf2434c8d89335c09.jpg'),
(21629, 1482, 'Narcoworld: Histórias do Tráfico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106509.mp4', 'http://timg.bdta.pro/images/620b9e9a671f7e5dce85a23c308fc49f.jpg'),
(21630, 1482, 'Narcoworld: Histórias do Tráfico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106510.mp4', 'http://timg.bdta.pro/images/0a27574c773057fe6e87505c84c34c0d.jpg'),
(21631, 1483, 'O Assassino Confesso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106502.mp4', 'http://timg.bdta.pro/images/2d8065be29dd1e02f8fef8c6132384c3.jpg'),
(21632, 1483, 'O Assassino Confesso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106503.mp4', 'http://timg.bdta.pro/images/18201d525a5e310942e63ff350ccbd87.jpg'),
(21633, 1483, 'O Assassino Confesso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106504.mp4', 'http://timg.bdta.pro/images/4be48d76a7b98645305d4a45635472ae.jpg'),
(21634, 1483, 'O Assassino Confesso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106505.mp4', 'http://timg.bdta.pro/images/c5e40198812ba1a2442d90a21a4b0f35.jpg'),
(21635, 1483, 'O Assassino Confesso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106506.mp4', 'http://timg.bdta.pro/images/3d14d34787b1be1b73bbac199396d6d9.jpg'),
(21636, 1484, 'O Toque Do Silencio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106496.mp4', 'http://timg.bdta.pro/images/a524db8d2d1d89028c3095d03c5835fc.jpg'),
(21637, 1484, 'O Toque Do Silencio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106497.mp4', 'http://timg.bdta.pro/images/1cd6c8849ffbb73c1eb7ed04522e2113.jpg'),
(21638, 1484, 'O Toque Do Silencio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106498.mp4', 'http://timg.bdta.pro/images/9126478b8c835180c23df7014773a01b.jpg'),
(21639, 1484, 'O Toque Do Silencio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106499.mp4', 'http://timg.bdta.pro/images/b48fcbf6af5d14f7dde07074bdcb63f7.jpg'),
(21640, 1484, 'O Toque Do Silencio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106500.mp4', 'http://timg.bdta.pro/images/176751c45d007c1ea38c423e6ef00a6d.jpg'),
(21641, 1484, 'O Toque Do Silencio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106501.mp4', 'http://timg.bdta.pro/images/2014a0227961c64556a91925400e0ffb.jpg'),
(21642, 1485, 'Pensamentos Impuros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106490.mp4', 'http://timg.bdta.pro/images/7248d95726eb00bc4b7fa28399711ca5.jpg'),
(21643, 1485, 'Pensamentos Impuros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106491.mp4', 'http://timg.bdta.pro/images/9b83c6187219398a0646083600e18a3e.jpg'),
(21644, 1485, 'Pensamentos Impuros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106492.mp4', 'http://timg.bdta.pro/images/2267281439b1714f1343f171bee210bf.jpg'),
(21645, 1485, 'Pensamentos Impuros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106493.mp4', 'http://timg.bdta.pro/images/1346366acbe2f8fead1b1223baeecda9.jpg'),
(21646, 1485, 'Pensamentos Impuros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106494.mp4', 'http://timg.bdta.pro/images/009f6dd5e9157ffd3aa787e92f716bad.jpg'),
(21647, 1485, 'Pensamentos Impuros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106495.mp4', 'http://timg.bdta.pro/images/d9b3f2d2105d3af694353bfc95ffce97.jpg'),
(21648, 1486, 'Sem Filtro: Flamengo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106483.mp4', 'http://gstaticontent.com/images/10FVVr12KfaSPQuxqsRMihstHA9_big.jpg'),
(21649, 1486, 'Sem Filtro: Flamengo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106484.mp4', 'http://gstaticontent.com/images/10FVVr12KfaSPQuxqsRMihstHA9_big.jpg'),
(21650, 1486, 'Sem Filtro: Flamengo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106485.mp4', 'http://gstaticontent.com/images/10FVVr12KfaSPQuxqsRMihstHA9_big.jpg'),
(21651, 1486, 'Sem Filtro: Flamengo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106486.mp4', 'http://gstaticontent.com/images/10FVVr12KfaSPQuxqsRMihstHA9_big.jpg'),
(21652, 1486, 'Sem Filtro: Flamengo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106487.mp4', 'http://gstaticontent.com/images/10FVVr12KfaSPQuxqsRMihstHA9_big.jpg'),
(21653, 1486, 'Sem Filtro: Flamengo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106488.mp4', 'http://gstaticontent.com/images/10FVVr12KfaSPQuxqsRMihstHA9_big.jpg'),
(21654, 1486, 'Sem Filtro: Flamengo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106489.mp4', 'http://gstaticontent.com/images/10FVVr12KfaSPQuxqsRMihstHA9_big.jpg'),
(21655, 1487, 'Servant S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209624.mp4', 'http://timg.bdta.pro/images/09584b9ca86a3f6607f655b578449592.jpg'),
(21656, 1487, 'Servant S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209625.mp4', 'http://timg.bdta.pro/images/d144ed083913c9138e208c86dae531c0.jpg'),
(21657, 1487, 'Servant S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209626.mp4', 'http://timg.bdta.pro/images/e00ea2070850c468ec7a6777184463e6.jpg'),
(21658, 1487, 'Servant S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209627.mp4', 'http://timg.bdta.pro/images/e421c311a136d24a88550b904378618e.jpg'),
(21659, 1487, 'Servant S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209628.mp4', 'http://timg.bdta.pro/images/0907ba8d93c6b2ddccab195333131537.jpg'),
(21660, 1487, 'Servant S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209629.mp4', 'http://timg.bdta.pro/images/4197cfaa27d50ceda68d951f5cc89987.jpg'),
(21661, 1487, 'Servant S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209630.mp4', 'http://timg.bdta.pro/images/275d1a8eb291840ecfe035069acd68ff.jpg'),
(21662, 1487, 'Servant S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209631.mp4', 'http://timg.bdta.pro/images/1f99477883ab9c4e0bc03da162637f6b.jpg'),
(21663, 1487, 'Servant S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209632.mp4', 'http://timg.bdta.pro/images/c0ca7ca4368f25a5b2a92f982cdcc22f.jpg'),
(21664, 1487, 'Servant S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209633.mp4', 'http://timg.bdta.pro/images/4db6f10c49764ff3b8d7cf5ada2e8fb4.jpg'),
(21665, 1488, 'Servant S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209634.mp4', 'http://gstaticontent.com/images/8yfkkAeoI77opqAvB9fyf4knftS_big.jpg'),
(21666, 1488, 'Servant S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209635.mp4', 'http://gstaticontent.com/images/8yfkkAeoI77opqAvB9fyf4knftS_big.jpg'),
(21667, 1488, 'Servant S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209636.mp4', 'http://gstaticontent.com/images/8yfkkAeoI77opqAvB9fyf4knftS_big.jpg'),
(21668, 1488, 'Servant S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209637.mp4', 'http://gstaticontent.com/images/8yfkkAeoI77opqAvB9fyf4knftS_big.jpg'),
(21669, 1488, 'Servant S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209638.mp4', 'http://gstaticontent.com/images/8yfkkAeoI77opqAvB9fyf4knftS_big.jpg'),
(21670, 1488, 'Servant S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209639.mp4', 'http://gstaticontent.com/images/8yfkkAeoI77opqAvB9fyf4knftS_big.jpg'),
(21671, 1488, 'Servant S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209640.mp4', 'http://gstaticontent.com/images/8yfkkAeoI77opqAvB9fyf4knftS_big.jpg'),
(21672, 1488, 'Servant S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209641.mp4', 'http://gstaticontent.com/images/8yfkkAeoI77opqAvB9fyf4knftS_big.jpg'),
(21673, 1488, 'Servant S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209642.mp4', 'http://gstaticontent.com/images/8yfkkAeoI77opqAvB9fyf4knftS_big.jpg'),
(21674, 1488, 'Servant S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209643.mp4', 'http://gstaticontent.com/images/8yfkkAeoI77opqAvB9fyf4knftS_big.jpg'),
(21675, 1489, 'Servant S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209644.mp4', 'http://timg.bdta.pro/images/0cda4f5a8a653cc9a8673e428a1aa765.jpg'),
(21676, 1489, 'Servant S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209645.mp4', 'http://timg.bdta.pro/images/dc854751ad21ef51ce1ba48c1bc1e0b6.jpg'),
(21677, 1489, 'Servant S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209646.mp4', 'http://timg.bdta.pro/images/6d70945ab71966f0853f8298a382109a.jpg'),
(21678, 1489, 'Servant S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209647.mp4', 'http://timg.bdta.pro/images/fef298bba91b0ea8b7f234d2ec871744.jpg'),
(21679, 1489, 'Servant S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209648.mp4', 'http://timg.bdta.pro/images/cdb08fc001f5cc8ff46dcd67ea4f964c.jpg'),
(21680, 1489, 'Servant S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209649.mp4', 'http://timg.bdta.pro/images/a245ba1a0929938191e0883a91ebc735.jpg'),
(21681, 1489, 'Servant S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209650.mp4', 'http://timg.bdta.pro/images/4340a8576d86822161b72bb8b65a0663.jpg'),
(21682, 1489, 'Servant S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209651.mp4', 'http://timg.bdta.pro/images/cce5a69eb968b1b74e6f49107952459a.jpg'),
(21683, 1489, 'Servant S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209652.mp4', 'http://timg.bdta.pro/images/b2af14e12fd40ff170b8d4832613c4c4.jpg'),
(21684, 1489, 'Servant S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209653.mp4', 'http://timg.bdta.pro/images/30f212782107549b2fbdea0f5659615f.jpg'),
(21685, 1490, 'Servant S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209654.mp4', 'http://image.tmdb.org/t/p/w1280/95ou0DRwlyd89VsFGFWNlb2Y9Yn.jpg'),
(21686, 1490, 'Servant S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209655.mp4', 'http://image.tmdb.org/t/p/w1280/fVzLTAf8NjXVhrhimOXR4aM7t4v.jpg'),
(21687, 1490, 'Servant S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209656.mp4', 'http://image.tmdb.org/t/p/w1280/yBB5uJZ7uHARLNudD4khENLtohs.jpg'),
(21688, 1490, 'Servant S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209657.mp4', 'http://image.tmdb.org/t/p/w1280/uVuhmry8zR4Yy1LKVrh6H2p9q5K.jpg'),
(21689, 1490, 'Servant S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209658.mp4', 'http://image.tmdb.org/t/p/w1280/aXJZdgyvyJbTYLATCfXWtimgnzt.jpg'),
(21690, 1490, 'Servant S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209659.mp4', 'http://image.tmdb.org/t/p/w1280/sEWDkfppIM2x6ZeRc2tnq9Q5fdF.jpg'),
(21691, 1490, 'Servant S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209660.mp4', 'http://image.tmdb.org/t/p/w1280/egWr4J3hKPkRfOKc5w6AAZYeHFd.jpg'),
(21692, 1490, 'Servant S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209661.mp4', 'http://image.tmdb.org/t/p/w1280/tV1vmdhEI7GPayAJJydOTUIKbZU.jpg'),
(21693, 1490, 'Servant S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209662.mp4', 'http://image.tmdb.org/t/p/w1280/waOM6QEkId7GxGdd1zu85ZhbRoj.jpg'),
(21694, 1490, 'Servant S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209663.mp4', 'http://image.tmdb.org/t/p/w1280/opT5PXRfmzflwRzVCGFlkq12Klu.jpg'),
(21695, 1491, 'Sigmund e os Monstros Marinhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106476.mp4', 'http://timg.bdta.pro/images/a2a4f63105b3f6f10efc8d012a625e61.jpg'),
(21696, 1491, 'Sigmund e os Monstros Marinhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106477.mp4', 'http://timg.bdta.pro/images/bca81b8f2c9f96fa70bc56bd989a5f36.jpg'),
(21697, 1491, 'Sigmund e os Monstros Marinhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106478.mp4', 'http://timg.bdta.pro/images/308ecb6458b8bd6a22162833ed12f6e9.jpg'),
(21698, 1491, 'Sigmund e os Monstros Marinhos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106479.mp4', 'http://timg.bdta.pro/images/a8a57438c29d76c24425d10f9a7089d7.jpg'),
(21699, 1491, 'Sigmund e os Monstros Marinhos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106480.mp4', 'http://timg.bdta.pro/images/1210159cb8b3a7a1bddc9264ac03c4e3.jpg'),
(21700, 1491, 'Sigmund e os Monstros Marinhos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106481.mp4', 'http://timg.bdta.pro/images/8cd7bbbc0779a5a2c9fe71f34f5fc51b.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(21701, 1491, 'Sigmund e os Monstros Marinhos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106482.mp4', 'http://timg.bdta.pro/images/7d6756f4f7de48623f51105385207d5d.jpg'),
(21702, 1492, 'The Expanse S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170848.mp4', 'http://timg.bdta.pro/images/63e25a4ed5074cb1ce57f493a8b6efe9.jpg'),
(21703, 1492, 'The Expanse S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170849.mp4', 'http://timg.bdta.pro/images/d6fdd28a9d11083392a324f086d394de.jpg'),
(21704, 1492, 'The Expanse S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170850.mp4', 'http://timg.bdta.pro/images/4b3560c4c85e6134aa7216b8d4f8e7cd.jpg'),
(21705, 1492, 'The Expanse S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170851.mp4', 'http://timg.bdta.pro/images/d957aa6762c96fdc58928f25c29c07b6.jpg'),
(21706, 1492, 'The Expanse S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170852.mp4', 'http://timg.bdta.pro/images/d4942dce6b3ff17b42ccc080dd9f2a5e.jpg'),
(21707, 1492, 'The Expanse S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170853.mp4', 'http://timg.bdta.pro/images/5d3c34843191c817009853a56cddb784.jpg'),
(21708, 1492, 'The Expanse S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170854.mp4', 'http://timg.bdta.pro/images/bcc737d8c8f38afe88278f70e619abfb.jpg'),
(21709, 1492, 'The Expanse S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170855.mp4', 'http://timg.bdta.pro/images/ee2cd532dcaa3b484bb12cb198020cb3.jpg'),
(21710, 1492, 'The Expanse S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170856.mp4', 'http://timg.bdta.pro/images/61c1ce3cae58e0bc88298441caa9b915.jpg'),
(21711, 1492, 'The Expanse S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170857.mp4', 'http://timg.bdta.pro/images/aeb9e300ea366d1c7c3d668da050297d.jpg'),
(21712, 1493, 'The Expanse S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170858.mp4', 'http://timg.bdta.pro/images/de7c6f83ae6049a23f860b0551e6046e.jpg'),
(21713, 1493, 'The Expanse S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170859.mp4', 'http://timg.bdta.pro/images/a882180b2874e787a68f67103450f3fe.jpg'),
(21714, 1493, 'The Expanse S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170860.mp4', 'http://timg.bdta.pro/images/f2ccb785b02668156be3a37de3834d11.jpg'),
(21715, 1493, 'The Expanse S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170861.mp4', 'http://timg.bdta.pro/images/cb7365c252c465154214e59676d58872.jpg'),
(21716, 1493, 'The Expanse S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170862.mp4', 'http://timg.bdta.pro/images/8e16d330b37557c1d5e3aef62b3623f8.jpg'),
(21717, 1493, 'The Expanse S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170863.mp4', 'http://timg.bdta.pro/images/bd09893df089cf25b3808aecbe6f7e30.jpg'),
(21718, 1493, 'The Expanse S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170864.mp4', 'http://timg.bdta.pro/images/52fe34347afd6b367120086525b1b2fc.jpg'),
(21719, 1493, 'The Expanse S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170865.mp4', 'http://timg.bdta.pro/images/81531d81eb51a5a5173729905ac4c212.jpg'),
(21720, 1493, 'The Expanse S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170866.mp4', 'http://timg.bdta.pro/images/b5fd5d69ef216f76d8d5c3f225afcc1e.jpg'),
(21721, 1493, 'The Expanse S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170867.mp4', 'http://timg.bdta.pro/images/c2ce1622b24d1f24320cadb85f9ef80f.jpg'),
(21722, 1493, 'The Expanse S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170868.mp4', 'http://timg.bdta.pro/images/ad15c7476e00ffe0448b22615f9139dc.jpg'),
(21723, 1493, 'The Expanse S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170869.mp4', 'http://timg.bdta.pro/images/9a243abb8c6605b68f7493e48dae0b9e.jpg'),
(21724, 1493, 'The Expanse S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/170870.mp4', 'http://timg.bdta.pro/images/080463887ddfe5bae41c50635c87cfa1.jpg'),
(21725, 1494, 'The Expanse S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170871.mp4', 'http://timg.bdta.pro/images/a55d140c67f498574a1404333c04ba27.jpg'),
(21726, 1494, 'The Expanse S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170872.mp4', 'http://timg.bdta.pro/images/04452dd7f626b12e64154027b349fa07.jpg'),
(21727, 1494, 'The Expanse S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170873.mp4', 'http://timg.bdta.pro/images/068aaff54b3c3b2f56e053e3362cd465.jpg'),
(21728, 1494, 'The Expanse S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170874.mp4', 'http://timg.bdta.pro/images/e3d8fc9e7daca2bb984668752932c919.jpg'),
(21729, 1494, 'The Expanse S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170875.mp4', 'http://timg.bdta.pro/images/faf1a9609c936e164c4459b4644d6899.jpg'),
(21730, 1494, 'The Expanse S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170876.mp4', 'http://timg.bdta.pro/images/8252ab7399aee48591424f2850497dff.jpg'),
(21731, 1494, 'The Expanse S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170877.mp4', 'http://timg.bdta.pro/images/47746b2e13f485497ec63693c1588082.jpg'),
(21732, 1494, 'The Expanse S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170878.mp4', 'http://timg.bdta.pro/images/9b3a4725805fb114c337792714a77806.jpg'),
(21733, 1494, 'The Expanse S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170879.mp4', 'http://timg.bdta.pro/images/a3f9158d4cb9627ca78ae137165303d0.jpg'),
(21734, 1494, 'The Expanse S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170880.mp4', 'http://timg.bdta.pro/images/84d505d6df67a90da333dc94ecb9c0a8.jpg'),
(21735, 1494, 'The Expanse S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170881.mp4', 'http://timg.bdta.pro/images/126c2ef0b3868941caf76fc4417156c1.jpg'),
(21736, 1494, 'The Expanse S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170882.mp4', 'http://timg.bdta.pro/images/1cab69b47552e10f69241141c5c93ede.jpg'),
(21737, 1495, 'The Expanse S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170883.mp4', 'http://timg.bdta.pro/images/72f21ca6463e3d7bfa9567ad69f0efb3.jpg'),
(21738, 1495, 'The Expanse S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170884.mp4', 'http://timg.bdta.pro/images/17fadd2772c57738fe1e68aaa177ed67.jpg'),
(21739, 1495, 'The Expanse S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170885.mp4', 'http://timg.bdta.pro/images/43e6b50abf80cf932003a8b79a653a36.jpg'),
(21740, 1495, 'The Expanse S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170886.mp4', 'http://timg.bdta.pro/images/9b2bc6d15b1c1828661127cb407a7557.jpg'),
(21741, 1495, 'The Expanse S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170887.mp4', 'http://timg.bdta.pro/images/20a875bc0e9451da604f06535b5d3af1.jpg'),
(21742, 1495, 'The Expanse S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170888.mp4', 'http://timg.bdta.pro/images/f248a222e8ff7c66945b7f1b0ee3b48c.jpg'),
(21743, 1495, 'The Expanse S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170889.mp4', 'http://timg.bdta.pro/images/a5f4f2fb4fcd6caa5fcb8119df681bb4.jpg'),
(21744, 1495, 'The Expanse S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170890.mp4', 'http://timg.bdta.pro/images/44b6fde91ff2dddc1225bffb4b12f8d0.jpg'),
(21745, 1495, 'The Expanse S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170891.mp4', 'http://timg.bdta.pro/images/62b83bf56dc3d609912724885f2237d3.jpg'),
(21746, 1495, 'The Expanse S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170892.mp4', 'http://timg.bdta.pro/images/1c038a90e0b80aac0d422ca04d39f603.jpg'),
(21747, 1496, 'The Expanse S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170893.mp4', 'http://gstaticontent.com/images/wikmaI7OVqmq2O9HfknkzxX6Ygu_big.jpg'),
(21748, 1496, 'The Expanse S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170894.mp4', 'http://gstaticontent.com/images/wikmaI7OVqmq2O9HfknkzxX6Ygu_big.jpg'),
(21749, 1496, 'The Expanse S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170895.mp4', 'http://gstaticontent.com/images/wikmaI7OVqmq2O9HfknkzxX6Ygu_big.jpg'),
(21750, 1496, 'The Expanse S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170896.mp4', 'http://gstaticontent.com/images/wikmaI7OVqmq2O9HfknkzxX6Ygu_big.jpg'),
(21751, 1496, 'The Expanse S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170897.mp4', 'http://gstaticontent.com/images/wikmaI7OVqmq2O9HfknkzxX6Ygu_big.jpg'),
(21752, 1496, 'The Expanse S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170898.mp4', 'http://gstaticontent.com/images/wikmaI7OVqmq2O9HfknkzxX6Ygu_big.jpg'),
(21753, 1496, 'The Expanse S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170899.mp4', 'http://gstaticontent.com/images/wikmaI7OVqmq2O9HfknkzxX6Ygu_big.jpg'),
(21754, 1496, 'The Expanse S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170900.mp4', 'http://gstaticontent.com/images/wikmaI7OVqmq2O9HfknkzxX6Ygu_big.jpg'),
(21755, 1496, 'The Expanse S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170901.mp4', 'http://gstaticontent.com/images/wikmaI7OVqmq2O9HfknkzxX6Ygu_big.jpg'),
(21756, 1496, 'The Expanse S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170902.mp4', 'http://gstaticontent.com/images/wikmaI7OVqmq2O9HfknkzxX6Ygu_big.jpg'),
(21757, 1497, 'The Expanse S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170903.mp4', 'http://image.tmdb.org/t/p/w1280/sl1vTgXrZwh9ZfWhj2uBcNEvUYW.jpg'),
(21758, 1497, 'The Expanse S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vyT1EYwM1gs1pOgvSlKsQGFBjJQ.jpg'),
(21759, 1497, 'The Expanse S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t20lW6sKFgLLYdNE2AJweJcKjrO.jpg'),
(21760, 1497, 'The Expanse S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2mUFeFhgaLkrFD4URs56LZeuu1J.jpg'),
(21761, 1497, 'The Expanse S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170907.mp4', 'http://image.tmdb.org/t/p/w1280/8gPJZHVzieleYuBXyb7nNhnblAV.jpg'),
(21762, 1497, 'The Expanse S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170908.mp4', 'http://image.tmdb.org/t/p/w1280/tzXQdklwgEGOOHSE4ynN4imjz0K.jpg'),
(21763, 1498, 'The Royals S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106436.mp4', 'http://timg.bdta.pro/images/bdd33f992d5a58a9e77c3443c751d74f.jpg'),
(21764, 1498, 'The Royals S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106437.mp4', 'http://timg.bdta.pro/images/5f5a77d2a61269f0804195df152203d2.jpg'),
(21765, 1498, 'The Royals S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106438.mp4', 'http://timg.bdta.pro/images/d5e1567c89cc07867af46249c4642569.jpg'),
(21766, 1498, 'The Royals S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106439.mp4', 'http://timg.bdta.pro/images/2d9781330feb6a7867fb9b367892d102.jpg'),
(21767, 1498, 'The Royals S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106440.mp4', 'http://timg.bdta.pro/images/c141084fb9c850f9aaef7cb39bea474a.jpg'),
(21768, 1498, 'The Royals S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106441.mp4', 'http://timg.bdta.pro/images/917255e62192f05cb2527f335a0cbc88.jpg'),
(21769, 1498, 'The Royals S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106442.mp4', 'http://timg.bdta.pro/images/bfa938b33ec607b5188149a7b0fead13.jpg'),
(21770, 1498, 'The Royals S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106443.mp4', 'http://timg.bdta.pro/images/f2915e548a644f8ff0f2468fc58e80bc.jpg'),
(21771, 1498, 'The Royals S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106444.mp4', 'http://timg.bdta.pro/images/3d72f51100980369496882194807863e.jpg'),
(21772, 1498, 'The Royals S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106445.mp4', 'http://timg.bdta.pro/images/8bbb2e4b5ad434e361717902edc7dd5c.jpg'),
(21773, 1499, 'The Royals S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106446.mp4', 'http://timg.bdta.pro/images/2b956a4d304cec1f0ac3184e7104b0ff.jpg'),
(21774, 1499, 'The Royals S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106447.mp4', 'http://timg.bdta.pro/images/d22a8b4c6ca48d462c1be5450b547c28.jpg'),
(21775, 1499, 'The Royals S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106448.mp4', 'http://timg.bdta.pro/images/a7e7f17965b9c8c4f9c0487bf0e36c0f.jpg'),
(21776, 1499, 'The Royals S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106449.mp4', 'http://timg.bdta.pro/images/469bdc0c7ca74528938771d8b6d0a67f.jpg'),
(21777, 1499, 'The Royals S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106450.mp4', 'http://timg.bdta.pro/images/927e79ed7e62fe984dd7349c5a43cdc3.jpg'),
(21778, 1499, 'The Royals S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106451.mp4', 'http://timg.bdta.pro/images/3eb7cc0ee151b372116248a60a809e25.jpg'),
(21779, 1499, 'The Royals S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106452.mp4', 'http://timg.bdta.pro/images/183ee93e9c4b1601c8f857fa81fea2c1.jpg'),
(21780, 1499, 'The Royals S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106453.mp4', 'http://timg.bdta.pro/images/fc124bc7b8cf749fc5f18959fd8fc051.jpg'),
(21781, 1499, 'The Royals S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106454.mp4', 'http://timg.bdta.pro/images/b6b454f8f59449cf4e5ba39f5e70ef27.jpg'),
(21782, 1499, 'The Royals S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106455.mp4', 'http://timg.bdta.pro/images/bca0747148cc936d71d5396f2a0a464b.jpg'),
(21783, 1500, 'The Royals S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106456.mp4', 'http://timg.bdta.pro/images/b0331d42a4f40fd78ecf63ae10528727.jpg'),
(21784, 1500, 'The Royals S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106457.mp4', 'http://timg.bdta.pro/images/562deb4237c586b79fed087271c779e0.jpg'),
(21785, 1500, 'The Royals S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106458.mp4', 'http://timg.bdta.pro/images/f467d12a59f8d8b709fdc68b212c2fd2.jpg'),
(21786, 1500, 'The Royals S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106459.mp4', 'http://timg.bdta.pro/images/6c60f4b42cfbf5157509681b70da61dc.jpg'),
(21787, 1500, 'The Royals S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106460.mp4', 'http://timg.bdta.pro/images/bdeb1074155901fa25b311f8ded20898.jpg'),
(21788, 1500, 'The Royals S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106461.mp4', 'http://timg.bdta.pro/images/a8594d8f336c91599494f807c1acee29.jpg'),
(21789, 1500, 'The Royals S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106462.mp4', 'http://timg.bdta.pro/images/a1875990ea03d2230a41ec9bdf208795.jpg'),
(21790, 1500, 'The Royals S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106463.mp4', 'http://gstaticontent.com/images/5XLmgVS3HPWE2gpTVOyD4c9mQ7D_big.jpg'),
(21791, 1500, 'The Royals S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106464.mp4', 'http://gstaticontent.com/images/5XLmgVS3HPWE2gpTVOyD4c9mQ7D_big.jpg'),
(21792, 1500, 'The Royals S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106465.mp4', 'http://gstaticontent.com/images/5XLmgVS3HPWE2gpTVOyD4c9mQ7D_big.jpg'),
(21793, 1501, 'The Royals S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106466.mp4', 'http://gstaticontent.com/images/5XLmgVS3HPWE2gpTVOyD4c9mQ7D_big.jpg'),
(21794, 1501, 'The Royals S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106467.mp4', 'http://gstaticontent.com/images/5XLmgVS3HPWE2gpTVOyD4c9mQ7D_big.jpg'),
(21795, 1501, 'The Royals S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106468.mp4', 'http://gstaticontent.com/images/5XLmgVS3HPWE2gpTVOyD4c9mQ7D_big.jpg'),
(21796, 1501, 'The Royals S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106469.mp4', 'http://gstaticontent.com/images/5XLmgVS3HPWE2gpTVOyD4c9mQ7D_big.jpg'),
(21797, 1501, 'The Royals S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106470.mp4', 'http://gstaticontent.com/images/5XLmgVS3HPWE2gpTVOyD4c9mQ7D_big.jpg'),
(21798, 1501, 'The Royals S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106471.mp4', 'http://gstaticontent.com/images/5XLmgVS3HPWE2gpTVOyD4c9mQ7D_big.jpg'),
(21799, 1501, 'The Royals S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106472.mp4', 'http://gstaticontent.com/images/5XLmgVS3HPWE2gpTVOyD4c9mQ7D_big.jpg'),
(21800, 1501, 'The Royals S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106473.mp4', 'http://gstaticontent.com/images/5XLmgVS3HPWE2gpTVOyD4c9mQ7D_big.jpg'),
(21801, 1501, 'The Royals S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106474.mp4', 'http://gstaticontent.com/images/5XLmgVS3HPWE2gpTVOyD4c9mQ7D_big.jpg'),
(21802, 1501, 'The Royals S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106475.mp4', 'http://gstaticontent.com/images/5XLmgVS3HPWE2gpTVOyD4c9mQ7D_big.jpg'),
(21803, 1502, 'Brilhante Victória S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139362.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21804, 1502, 'Brilhante Victória S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139363.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21805, 1502, 'Brilhante Victória S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139364.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21806, 1502, 'Brilhante Victória S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139365.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21807, 1502, 'Brilhante Victória S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139366.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21808, 1502, 'Brilhante Victória S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139367.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21809, 1502, 'Brilhante Victória S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139368.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21810, 1502, 'Brilhante Victória S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139369.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21811, 1502, 'Brilhante Victória S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139370.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21812, 1502, 'Brilhante Victória S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139371.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21813, 1502, 'Brilhante Victória S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139372.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21814, 1502, 'Brilhante Victória S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139373.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21815, 1502, 'Brilhante Victória S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139374.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21816, 1502, 'Brilhante Victória S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139375.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21817, 1502, 'Brilhante Victória S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139376.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21818, 1502, 'Brilhante Victória S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139377.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21819, 1502, 'Brilhante Victória S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/139378.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21820, 1502, 'Brilhante Victória S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/139379.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21821, 1502, 'Brilhante Victória S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/139380.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21822, 1503, 'Brilhante Victória S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/547146.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21823, 1503, 'Brilhante Victória S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139383.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21824, 1503, 'Brilhante Victória S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139384.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21825, 1503, 'Brilhante Victória S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139385.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21826, 1503, 'Brilhante Victória S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139386.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21827, 1503, 'Brilhante Victória S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139387.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21828, 1503, 'Brilhante Victória S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139388.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21829, 1503, 'Brilhante Victória S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139389.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21830, 1503, 'Brilhante Victória S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139390.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21831, 1503, 'Brilhante Victória S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139391.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21832, 1503, 'Brilhante Victória S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139392.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21833, 1503, 'Brilhante Victória S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139393.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21834, 1504, 'Brilhante Victória S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139394.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21835, 1504, 'Brilhante Victória S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139395.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21836, 1504, 'Brilhante Victória S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139396.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21837, 1504, 'Brilhante Victória S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139397.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21838, 1504, 'Brilhante Victória S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139398.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21839, 1504, 'Brilhante Victória S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139399.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21840, 1504, 'Brilhante Victória S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139400.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21841, 1504, 'Brilhante Victória S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139401.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21842, 1504, 'Brilhante Victória S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139402.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21843, 1504, 'Brilhante Victória S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139403.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21844, 1504, 'Brilhante Victória S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139404.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21845, 1504, 'Brilhante Victória S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139405.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21846, 1504, 'Brilhante Victória S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139406.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21847, 1505, 'Brilhante Victória S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139407.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21848, 1505, 'Brilhante Victória S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139408.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21849, 1505, 'Brilhante Victória S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139409.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21850, 1505, 'Brilhante Victória S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139410.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21851, 1505, 'Brilhante Victória S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139411.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21852, 1505, 'Brilhante Victória S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139412.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21853, 1505, 'Brilhante Victória S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139413.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21854, 1505, 'Brilhante Victória S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139414.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21855, 1505, 'Brilhante Victória S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139415.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21856, 1505, 'Brilhante Victória S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139416.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21857, 1505, 'Brilhante Victória S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139417.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21858, 1505, 'Brilhante Victória S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139418.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21859, 1505, 'Brilhante Victória S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139419.mp4', 'http://gstaticontent.com/images/oCgSDWg7KoTUa8EyfQhbUcImEQ1_big.jpg'),
(21860, 1506, 'Vitimas Digitais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106429.mp4', 'http://gstaticontent.com/images/67c615cb01e18e2bc9f8c15fc5a64c53.jpg'),
(21861, 1506, 'Vitimas Digitais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106430.mp4', 'http://gstaticontent.com/images/67c615cb01e18e2bc9f8c15fc5a64c53.jpg'),
(21862, 1506, 'Vitimas Digitais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106431.mp4', 'http://gstaticontent.com/images/67c615cb01e18e2bc9f8c15fc5a64c53.jpg'),
(21863, 1506, 'Vitimas Digitais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106432.mp4', 'http://gstaticontent.com/images/67c615cb01e18e2bc9f8c15fc5a64c53.jpg'),
(21864, 1506, 'Vitimas Digitais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106433.mp4', 'http://gstaticontent.com/images/67c615cb01e18e2bc9f8c15fc5a64c53.jpg'),
(21865, 1506, 'Vitimas Digitais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106434.mp4', 'http://gstaticontent.com/images/67c615cb01e18e2bc9f8c15fc5a64c53.jpg'),
(21866, 1506, 'Vitimas Digitais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106435.mp4', 'http://gstaticontent.com/images/67c615cb01e18e2bc9f8c15fc5a64c53.jpg'),
(21867, 1507, 'Naruto Clássico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106209.mp4', 'http://timg.bdta.pro/images/df3d61370e43dec59f401e5846380509.jpg'),
(21868, 1507, 'Naruto Clássico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106210.mp4', 'http://timg.bdta.pro/images/ca672342747b53851106dbc5451f4ed6.jpg'),
(21869, 1507, 'Naruto Clássico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106211.mp4', 'http://timg.bdta.pro/images/7b3d4b1c87d5d46774e80137ed658131.jpg'),
(21870, 1507, 'Naruto Clássico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106212.mp4', 'http://timg.bdta.pro/images/c2b8d631552883d726e5db258f74d927.jpg'),
(21871, 1507, 'Naruto Clássico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106213.mp4', 'http://timg.bdta.pro/images/b36f0e54f6a01e5f594d630e67368ae0.jpg'),
(21872, 1507, 'Naruto Clássico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106214.mp4', 'http://timg.bdta.pro/images/bde1857f4343c7fa4f7ba5136b57f00e.jpg'),
(21873, 1507, 'Naruto Clássico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106215.mp4', 'http://timg.bdta.pro/images/867898ceae547bd393105bcaba9e25ae.jpg'),
(21874, 1507, 'Naruto Clássico S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106216.mp4', 'http://timg.bdta.pro/images/cb2b1a9eb0e398fda9e97f385839caea.jpg'),
(21875, 1507, 'Naruto Clássico S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106217.mp4', 'http://timg.bdta.pro/images/5ca3d291ca2293c42f7d6f30c3ebd224.jpg'),
(21876, 1507, 'Naruto Clássico S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106218.mp4', 'http://timg.bdta.pro/images/c94286e0b4c28a950ab35b17909405c9.jpg'),
(21877, 1507, 'Naruto Clássico S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106219.mp4', 'http://timg.bdta.pro/images/04e165276e9d6db6ed87136187060f16.jpg'),
(21878, 1507, 'Naruto Clássico S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/106220.mp4', 'http://timg.bdta.pro/images/091db276e232d7da3b77304e55536123.jpg'),
(21879, 1507, 'Naruto Clássico S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/106221.mp4', 'http://timg.bdta.pro/images/2bb125bd28023f34d3fa5e49ea0bcc98.jpg'),
(21880, 1507, 'Naruto Clássico S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/106222.mp4', 'http://timg.bdta.pro/images/6b2ffaaecf1e84adb3f8207b5919a546.jpg'),
(21881, 1507, 'Naruto Clássico S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/106223.mp4', 'http://timg.bdta.pro/images/1832e2ced31417af27ddd3b06d952c63.jpg'),
(21882, 1507, 'Naruto Clássico S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/106224.mp4', 'http://timg.bdta.pro/images/ee2e4c8dda9ce8d6c11cb331a10285bf.jpg'),
(21883, 1507, 'Naruto Clássico S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/106225.mp4', 'http://timg.bdta.pro/images/f96fcddfb23dc02a14079501437b8197.jpg'),
(21884, 1507, 'Naruto Clássico S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/106226.mp4', 'http://timg.bdta.pro/images/b398bbab0c1d771bc0c854e880e5b060.jpg'),
(21885, 1507, 'Naruto Clássico S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/106227.mp4', 'http://timg.bdta.pro/images/87ce099eb610096eb557e9a4b39a239e.jpg'),
(21886, 1507, 'Naruto Clássico S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/106228.mp4', 'http://timg.bdta.pro/images/393ae12e8793bf672e7185b526a0cc9d.jpg'),
(21887, 1507, 'Naruto Clássico S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/106229.mp4', 'http://timg.bdta.pro/images/a98a2d06074d8c84504a28939f6ded1a.jpg'),
(21888, 1507, 'Naruto Clássico S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/106230.mp4', 'http://timg.bdta.pro/images/4dad270bb08854150dd3f28718ff6dc3.jpg'),
(21889, 1507, 'Naruto Clássico S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/106231.mp4', 'http://timg.bdta.pro/images/79ed262e95b0c4dd982c7696915f4b11.jpg'),
(21890, 1507, 'Naruto Clássico S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/106232.mp4', 'http://timg.bdta.pro/images/abe7d70fbd7d988e64083c7bea322cb9.jpg'),
(21891, 1507, 'Naruto Clássico S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/106233.mp4', 'http://timg.bdta.pro/images/3c7496cf1ec81c366b3caa5424d65ac6.jpg'),
(21892, 1507, 'Naruto Clássico S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/106234.mp4', 'http://timg.bdta.pro/images/7b2d89212778e43af0bd3bf18b87a655.jpg'),
(21893, 1507, 'Naruto Clássico S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/106235.mp4', 'http://timg.bdta.pro/images/3b3bba62abef534f1e5bf379ffaa8020.jpg'),
(21894, 1507, 'Naruto Clássico S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/106236.mp4', 'http://timg.bdta.pro/images/f776c717d10cb317fe3ac3591598d008.jpg'),
(21895, 1507, 'Naruto Clássico S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/106237.mp4', 'http://timg.bdta.pro/images/918284ed6a6e522f5e104786ae07f5d2.jpg'),
(21896, 1507, 'Naruto Clássico S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/106238.mp4', 'http://timg.bdta.pro/images/f95d481db5071a5e9f722055f14ca98c.jpg'),
(21897, 1507, 'Naruto Clássico S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/106239.mp4', 'http://timg.bdta.pro/images/1592dc2bfe868a06cfd5df2bc2bcfd5e.jpg'),
(21898, 1507, 'Naruto Clássico S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/106240.mp4', 'http://timg.bdta.pro/images/45fd6df0af2be43bf47fa09d5a2b66dc.jpg'),
(21899, 1507, 'Naruto Clássico S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/106241.mp4', 'http://timg.bdta.pro/images/0cf8ad007c303705088e4315868e0333.jpg'),
(21900, 1507, 'Naruto Clássico S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/106242.mp4', 'http://timg.bdta.pro/images/b3f1aa224264acabd61fb14765374627.jpg'),
(21901, 1507, 'Naruto Clássico S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/106243.mp4', 'http://timg.bdta.pro/images/fc8b1a6d595657e1acd06d98a80b945f.jpg'),
(21902, 1507, 'Naruto Clássico S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/106244.mp4', 'http://timg.bdta.pro/images/4cc17eee635e246b1152426d50fb1e93.jpg'),
(21903, 1507, 'Naruto Clássico S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/106245.mp4', 'http://timg.bdta.pro/images/e702cf01898bd9a8f0c97d497c0b3c2e.jpg'),
(21904, 1507, 'Naruto Clássico S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/106246.mp4', 'http://timg.bdta.pro/images/87da19d7963e6351210c6d57efaa261f.jpg'),
(21905, 1507, 'Naruto Clássico S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/106247.mp4', 'http://timg.bdta.pro/images/ce36a06597282b70cd89da2eb21aae54.jpg'),
(21906, 1507, 'Naruto Clássico S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/106248.mp4', 'http://timg.bdta.pro/images/f9112e8d628ed7240ad5efef52a46c08.jpg'),
(21907, 1507, 'Naruto Clássico S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/106249.mp4', 'http://timg.bdta.pro/images/85db3bca7827879687501d71b4eaf272.jpg'),
(21908, 1507, 'Naruto Clássico S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/106250.mp4', 'http://timg.bdta.pro/images/0f861809c2e5fe5122a0b4df37874e29.jpg'),
(21909, 1507, 'Naruto Clássico S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/106251.mp4', 'http://timg.bdta.pro/images/0636f0009e7e5b2ad3c395ca64d65c93.jpg'),
(21910, 1507, 'Naruto Clássico S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/106252.mp4', 'http://timg.bdta.pro/images/5083fffb808a0ad45411c6e0debb325e.jpg'),
(21911, 1507, 'Naruto Clássico S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/106253.mp4', 'http://timg.bdta.pro/images/a30b7a817ee9a34033f1fb0bcf508302.jpg'),
(21912, 1507, 'Naruto Clássico S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/106254.mp4', 'http://timg.bdta.pro/images/5acc8d25ecd209d7677634b835750de8.jpg'),
(21913, 1507, 'Naruto Clássico S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/106255.mp4', 'http://timg.bdta.pro/images/eed945d9aba44edea67111bbbf9600f7.jpg'),
(21914, 1507, 'Naruto Clássico S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/106256.mp4', 'http://timg.bdta.pro/images/8351c2be4a44468488a597bba75d42f5.jpg'),
(21915, 1507, 'Naruto Clássico S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/106257.mp4', 'http://timg.bdta.pro/images/0041184f72cbe39255df42c6561fcf5c.jpg'),
(21916, 1507, 'Naruto Clássico S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/106258.mp4', 'http://timg.bdta.pro/images/dd590ea99787d2fc274b2f10c94cfdf2.jpg'),
(21917, 1507, 'Naruto Clássico S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/106259.mp4', 'http://timg.bdta.pro/images/c1f6098f807793fdddb6c4e84fcbc8a4.jpg'),
(21918, 1507, 'Naruto Clássico S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/106260.mp4', 'http://timg.bdta.pro/images/5006de66f00c32033d0bd1cfc4437e0f.jpg'),
(21919, 1508, 'Naruto Clássico S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106261.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21920, 1508, 'Naruto Clássico S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106262.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21921, 1508, 'Naruto Clássico S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106263.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21922, 1508, 'Naruto Clássico S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106264.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21923, 1508, 'Naruto Clássico S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106265.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21924, 1508, 'Naruto Clássico S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106266.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21925, 1508, 'Naruto Clássico S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106267.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21926, 1508, 'Naruto Clássico S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106268.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21927, 1508, 'Naruto Clássico S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106269.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21928, 1508, 'Naruto Clássico S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106270.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21929, 1508, 'Naruto Clássico S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106271.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21930, 1508, 'Naruto Clássico S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/106272.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21931, 1508, 'Naruto Clássico S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/106273.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21932, 1508, 'Naruto Clássico S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/106274.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21933, 1508, 'Naruto Clássico S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/106275.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21934, 1508, 'Naruto Clássico S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/106276.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21935, 1508, 'Naruto Clássico S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/106277.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21936, 1508, 'Naruto Clássico S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/106278.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21937, 1508, 'Naruto Clássico S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/106279.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21938, 1508, 'Naruto Clássico S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/106280.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21939, 1508, 'Naruto Clássico S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/106281.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21940, 1508, 'Naruto Clássico S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/106282.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21941, 1508, 'Naruto Clássico S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/106283.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21942, 1508, 'Naruto Clássico S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/106284.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21943, 1508, 'Naruto Clássico S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/106285.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21944, 1508, 'Naruto Clássico S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/106286.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21945, 1508, 'Naruto Clássico S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/106287.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21946, 1508, 'Naruto Clássico S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/106288.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21947, 1508, 'Naruto Clássico S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/106289.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21948, 1508, 'Naruto Clássico S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/106290.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21949, 1508, 'Naruto Clássico S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/106291.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21950, 1508, 'Naruto Clássico S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/106292.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21951, 1508, 'Naruto Clássico S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/106293.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21952, 1508, 'Naruto Clássico S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/106294.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21953, 1508, 'Naruto Clássico S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/106295.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21954, 1508, 'Naruto Clássico S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/106296.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21955, 1508, 'Naruto Clássico S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/106297.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21956, 1508, 'Naruto Clássico S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/106298.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21957, 1508, 'Naruto Clássico S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/106299.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21958, 1508, 'Naruto Clássico S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/106300.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21959, 1508, 'Naruto Clássico S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/106301.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21960, 1508, 'Naruto Clássico S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/106302.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21961, 1508, 'Naruto Clássico S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/106303.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21962, 1508, 'Naruto Clássico S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/106304.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21963, 1508, 'Naruto Clássico S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/106305.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21964, 1508, 'Naruto Clássico S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/106306.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21965, 1508, 'Naruto Clássico S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/106307.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21966, 1508, 'Naruto Clássico S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/106308.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21967, 1508, 'Naruto Clássico S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/106309.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21968, 1508, 'Naruto Clássico S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/106310.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21969, 1508, 'Naruto Clássico S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/106311.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21970, 1508, 'Naruto Clássico S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/106312.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21971, 1509, 'Naruto Clássico S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106313.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21972, 1509, 'Naruto Clássico S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106314.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21973, 1509, 'Naruto Clássico S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106315.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21974, 1509, 'Naruto Clássico S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106316.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21975, 1509, 'Naruto Clássico S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106317.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21976, 1509, 'Naruto Clássico S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106318.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21977, 1509, 'Naruto Clássico S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106319.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21978, 1509, 'Naruto Clássico S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106320.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21979, 1509, 'Naruto Clássico S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106321.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21980, 1509, 'Naruto Clássico S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106322.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21981, 1509, 'Naruto Clássico S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106323.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21982, 1509, 'Naruto Clássico S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/106324.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21983, 1509, 'Naruto Clássico S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/106325.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21984, 1509, 'Naruto Clássico S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/106326.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21985, 1509, 'Naruto Clássico S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/106327.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21986, 1509, 'Naruto Clássico S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/106328.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21987, 1509, 'Naruto Clássico S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/106329.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(21988, 1509, 'Naruto Clássico S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/106330.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21989, 1509, 'Naruto Clássico S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/106331.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21990, 1509, 'Naruto Clássico S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/106332.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21991, 1509, 'Naruto Clássico S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/106333.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21992, 1509, 'Naruto Clássico S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/106334.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21993, 1509, 'Naruto Clássico S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/106335.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21994, 1509, 'Naruto Clássico S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/106336.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21995, 1509, 'Naruto Clássico S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/106337.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21996, 1509, 'Naruto Clássico S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/106338.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21997, 1509, 'Naruto Clássico S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/106339.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21998, 1509, 'Naruto Clássico S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/106340.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(21999, 1509, 'Naruto Clássico S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/106341.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22000, 1509, 'Naruto Clássico S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/106342.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22001, 1509, 'Naruto Clássico S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/106343.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22002, 1509, 'Naruto Clássico S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/106344.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22003, 1509, 'Naruto Clássico S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/106345.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22004, 1509, 'Naruto Clássico S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/106346.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22005, 1509, 'Naruto Clássico S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/106347.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22006, 1509, 'Naruto Clássico S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/106348.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22007, 1509, 'Naruto Clássico S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/106349.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22008, 1509, 'Naruto Clássico S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/106350.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22009, 1509, 'Naruto Clássico S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/106351.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22010, 1509, 'Naruto Clássico S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/106352.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22011, 1509, 'Naruto Clássico S03 E41', 'http://sinalprivado.info:80/series/1533784/1533784/106353.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22012, 1509, 'Naruto Clássico S03 E42', 'http://sinalprivado.info:80/series/1533784/1533784/106354.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22013, 1509, 'Naruto Clássico S03 E43', 'http://sinalprivado.info:80/series/1533784/1533784/106355.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22014, 1509, 'Naruto Clássico S03 E44', 'http://sinalprivado.info:80/series/1533784/1533784/106356.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22015, 1509, 'Naruto Clássico S03 E45', 'http://sinalprivado.info:80/series/1533784/1533784/106357.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22016, 1509, 'Naruto Clássico S03 E46', 'http://sinalprivado.info:80/series/1533784/1533784/106358.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22017, 1509, 'Naruto Clássico S03 E47', 'http://sinalprivado.info:80/series/1533784/1533784/106359.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22018, 1509, 'Naruto Clássico S03 E48', 'http://sinalprivado.info:80/series/1533784/1533784/106360.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22019, 1509, 'Naruto Clássico S03 E49', 'http://sinalprivado.info:80/series/1533784/1533784/106361.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22020, 1509, 'Naruto Clássico S03 E50', 'http://sinalprivado.info:80/series/1533784/1533784/106362.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22021, 1509, 'Naruto Clássico S03 E51', 'http://sinalprivado.info:80/series/1533784/1533784/106363.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22022, 1509, 'Naruto Clássico S03 E52', 'http://sinalprivado.info:80/series/1533784/1533784/106364.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22023, 1509, 'Naruto Clássico S03 E53', 'http://sinalprivado.info:80/series/1533784/1533784/106365.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22024, 1509, 'Naruto Clássico S03 E54', 'http://sinalprivado.info:80/series/1533784/1533784/106366.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22025, 1510, 'Naruto Clássico S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106367.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22026, 1510, 'Naruto Clássico S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106368.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22027, 1510, 'Naruto Clássico S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106369.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22028, 1510, 'Naruto Clássico S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106370.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22029, 1510, 'Naruto Clássico S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106371.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22030, 1510, 'Naruto Clássico S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106372.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22031, 1510, 'Naruto Clássico S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106373.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22032, 1510, 'Naruto Clássico S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106374.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22033, 1510, 'Naruto Clássico S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106375.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22034, 1510, 'Naruto Clássico S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106376.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22035, 1510, 'Naruto Clássico S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106377.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22036, 1510, 'Naruto Clássico S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/106378.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22037, 1510, 'Naruto Clássico S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/106379.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22038, 1510, 'Naruto Clássico S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/106380.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22039, 1510, 'Naruto Clássico S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/106381.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22040, 1510, 'Naruto Clássico S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/106382.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22041, 1510, 'Naruto Clássico S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/106383.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22042, 1510, 'Naruto Clássico S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/106384.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22043, 1510, 'Naruto Clássico S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/106385.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22044, 1510, 'Naruto Clássico S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/106386.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22045, 1510, 'Naruto Clássico S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/106387.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22046, 1510, 'Naruto Clássico S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/106388.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22047, 1510, 'Naruto Clássico S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/106389.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22048, 1510, 'Naruto Clássico S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/106390.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22049, 1510, 'Naruto Clássico S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/106391.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22050, 1510, 'Naruto Clássico S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/106392.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22051, 1510, 'Naruto Clássico S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/106393.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22052, 1510, 'Naruto Clássico S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/106394.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22053, 1510, 'Naruto Clássico S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/106395.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22054, 1510, 'Naruto Clássico S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/106396.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22055, 1510, 'Naruto Clássico S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/106397.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22056, 1510, 'Naruto Clássico S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/106398.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22057, 1510, 'Naruto Clássico S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/106399.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22058, 1510, 'Naruto Clássico S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/106400.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22059, 1510, 'Naruto Clássico S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/106401.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22060, 1510, 'Naruto Clássico S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/106402.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22061, 1510, 'Naruto Clássico S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/106403.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22062, 1510, 'Naruto Clássico S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/106404.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22063, 1510, 'Naruto Clássico S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/106405.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22064, 1510, 'Naruto Clássico S04 E40', 'http://sinalprivado.info:80/series/1533784/1533784/106406.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22065, 1510, 'Naruto Clássico S04 E41', 'http://sinalprivado.info:80/series/1533784/1533784/106407.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22066, 1510, 'Naruto Clássico S04 E42', 'http://sinalprivado.info:80/series/1533784/1533784/106408.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22067, 1510, 'Naruto Clássico S04 E43', 'http://sinalprivado.info:80/series/1533784/1533784/106409.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22068, 1510, 'Naruto Clássico S04 E44', 'http://sinalprivado.info:80/series/1533784/1533784/106410.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22069, 1510, 'Naruto Clássico S04 E45', 'http://sinalprivado.info:80/series/1533784/1533784/106411.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22070, 1510, 'Naruto Clássico S04 E46', 'http://sinalprivado.info:80/series/1533784/1533784/106412.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22071, 1510, 'Naruto Clássico S04 E47', 'http://sinalprivado.info:80/series/1533784/1533784/106413.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22072, 1510, 'Naruto Clássico S04 E48', 'http://sinalprivado.info:80/series/1533784/1533784/106414.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22073, 1510, 'Naruto Clássico S04 E49', 'http://sinalprivado.info:80/series/1533784/1533784/106415.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22074, 1510, 'Naruto Clássico S04 E50', 'http://sinalprivado.info:80/series/1533784/1533784/106416.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22075, 1510, 'Naruto Clássico S04 E51', 'http://sinalprivado.info:80/series/1533784/1533784/106417.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22076, 1510, 'Naruto Clássico S04 E52', 'http://sinalprivado.info:80/series/1533784/1533784/106418.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22077, 1510, 'Naruto Clássico S04 E53', 'http://sinalprivado.info:80/series/1533784/1533784/106419.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22078, 1510, 'Naruto Clássico S04 E54', 'http://sinalprivado.info:80/series/1533784/1533784/106420.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22079, 1510, 'Naruto Clássico S04 E55', 'http://sinalprivado.info:80/series/1533784/1533784/106421.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22080, 1510, 'Naruto Clássico S04 E56', 'http://sinalprivado.info:80/series/1533784/1533784/106422.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22081, 1510, 'Naruto Clássico S04 E57', 'http://sinalprivado.info:80/series/1533784/1533784/106423.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22082, 1510, 'Naruto Clássico S04 E58', 'http://sinalprivado.info:80/series/1533784/1533784/106424.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22083, 1510, 'Naruto Clássico S04 E59', 'http://sinalprivado.info:80/series/1533784/1533784/106425.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22084, 1510, 'Naruto Clássico S04 E60', 'http://sinalprivado.info:80/series/1533784/1533784/106426.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22085, 1510, 'Naruto Clássico S04 E61', 'http://sinalprivado.info:80/series/1533784/1533784/106427.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22086, 1510, 'Naruto Clássico S04 E62', 'http://sinalprivado.info:80/series/1533784/1533784/106428.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22087, 1511, 'Naruto Clássico S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/728067.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22088, 1511, 'Naruto Clássico S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/728069.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22089, 1511, 'Naruto Clássico S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/728070.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22090, 1511, 'Naruto Clássico S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/728071.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22091, 1511, 'Naruto Clássico S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/728073.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22092, 1511, 'Naruto Clássico S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/728074.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22093, 1511, 'Naruto Clássico S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/728075.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22094, 1511, 'Naruto Clássico S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/728076.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22095, 1511, 'Naruto Clássico S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/728077.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22096, 1511, 'Naruto Clássico S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/728078.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22097, 1511, 'Naruto Clássico S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/728079.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22098, 1511, 'Naruto Clássico S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/728080.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22099, 1511, 'Naruto Clássico S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/728081.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22100, 1511, 'Naruto Clássico S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/728082.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22101, 1511, 'Naruto Clássico S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/728083.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22102, 1511, 'Naruto Clássico S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/728084.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22103, 1511, 'Naruto Clássico S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/728086.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22104, 1511, 'Naruto Clássico S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/728087.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22105, 1511, 'Naruto Clássico S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/728088.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22106, 1511, 'Naruto Clássico S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/728089.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22107, 1511, 'Naruto Clássico S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/728090.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22108, 1511, 'Naruto Clássico S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/728091.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22109, 1512, 'Naruto Clássico S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/728092.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22110, 1512, 'Naruto Clássico S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/728093.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22111, 1512, 'Naruto Clássico S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/728094.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22112, 1512, 'Naruto Clássico S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/728095.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22113, 1512, 'Naruto Clássico S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/728096.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22114, 1512, 'Naruto Clássico S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/728097.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22115, 1512, 'Naruto Clássico S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/728098.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22116, 1512, 'Naruto Clássico S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/728099.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22117, 1512, 'Naruto Clássico S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/728100.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22118, 1512, 'Naruto Clássico S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/728101.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22119, 1512, 'Naruto Clássico S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/728102.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22120, 1512, 'Naruto Clássico S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/728103.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22121, 1512, 'Naruto Clássico S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/728104.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22122, 1512, 'Naruto Clássico S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/728105.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22123, 1512, 'Naruto Clássico S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/728106.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22124, 1512, 'Naruto Clássico S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/728107.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22125, 1512, 'Naruto Clássico S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/728108.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22126, 1512, 'Naruto Clássico S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/728109.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22127, 1512, 'Naruto Clássico S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/728110.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22128, 1512, 'Naruto Clássico S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/728111.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22129, 1512, 'Naruto Clássico S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/728112.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22130, 1512, 'Naruto Clássico S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/728113.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22131, 1512, 'Naruto Clássico S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/728114.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22132, 1512, 'Naruto Clássico S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/728115.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22133, 1512, 'Naruto Clássico S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/728116.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22134, 1513, 'Naruto Clássico S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/728117.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22135, 1513, 'Naruto Clássico S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/728118.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22136, 1513, 'Naruto Clássico S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/728119.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22137, 1513, 'Naruto Clássico S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/728120.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22138, 1513, 'Naruto Clássico S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/728121.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22139, 1513, 'Naruto Clássico S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/728122.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22140, 1513, 'Naruto Clássico S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/728123.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22141, 1513, 'Naruto Clássico S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/728124.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22142, 1513, 'Naruto Clássico S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/728125.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22143, 1513, 'Naruto Clássico S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/728126.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22144, 1513, 'Naruto Clássico S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/728127.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22145, 1513, 'Naruto Clássico S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/728128.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22146, 1513, 'Naruto Clássico S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/728129.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22147, 1513, 'Naruto Clássico S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/728130.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22148, 1513, 'Naruto Clássico S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/728131.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22149, 1513, 'Naruto Clássico S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/728132.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22150, 1513, 'Naruto Clássico S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/728134.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22151, 1513, 'Naruto Clássico S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/728135.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22152, 1513, 'Naruto Clássico S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/728136.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22153, 1513, 'Naruto Clássico S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/728137.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22154, 1513, 'Naruto Clássico S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/728138.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22155, 1513, 'Naruto Clássico S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/728139.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22156, 1513, 'Naruto Clássico S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/728140.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22157, 1513, 'Naruto Clássico S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/728141.mp4', 'http://gstaticontent.com/images/mErFfyQuQ9kkbsR30d8CkZf0Z6s_big.jpg'),
(22158, 1514, 'O Segredo do Templo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128241.mp4', 'http://timg.bdta.pro/images/f62840590b0ad5ffac6a9b69356e1e66.jpg'),
(22159, 1514, 'O Segredo do Templo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128242.mp4', 'http://timg.bdta.pro/images/4eb68849909f14797cdfa88924df74f3.jpg'),
(22160, 1514, 'O Segredo do Templo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128243.mp4', 'http://timg.bdta.pro/images/17d2b6e00a13e448ffe627e26800392e.jpg'),
(22161, 1514, 'O Segredo do Templo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128244.mp4', 'http://timg.bdta.pro/images/8031f02a93e530da7068455fd46a5db0.jpg'),
(22162, 1514, 'O Segredo do Templo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128245.mp4', 'http://timg.bdta.pro/images/7fc94ecc783eafce24024ef829f6735c.jpg'),
(22163, 1514, 'O Segredo do Templo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128246.mp4', 'http://timg.bdta.pro/images/d7d6beaeab260e5b047ca3901c819f93.jpg'),
(22164, 1514, 'O Segredo do Templo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128247.mp4', 'http://timg.bdta.pro/images/b136aa59d604b5b984a84eeefbdda3ee.jpg'),
(22165, 1514, 'O Segredo do Templo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128248.mp4', 'http://timg.bdta.pro/images/6dfad309d9e51e03bade0dcb92690f49.jpg'),
(22166, 1515, 'O Segredo do Templo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128249.mp4', 'http://timg.bdta.pro/images/489a0d3136ec9e5da6d5d4226c4ab178.jpg'),
(22167, 1515, 'O Segredo do Templo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128250.mp4', 'http://timg.bdta.pro/images/d7db52ebcb714746a522497656a48eaa.jpg'),
(22168, 1515, 'O Segredo do Templo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128251.mp4', 'http://timg.bdta.pro/images/b7c98323c0c5c37045a91698e7563c3c.jpg'),
(22169, 1515, 'O Segredo do Templo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128252.mp4', 'http://timg.bdta.pro/images/8c42da7d810a679d4140d8136506dd67.jpg'),
(22170, 1515, 'O Segredo do Templo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128253.mp4', 'http://timg.bdta.pro/images/9f952369b49ce420b90615f3757bcbc3.jpg'),
(22171, 1515, 'O Segredo do Templo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128254.mp4', 'http://timg.bdta.pro/images/27d93b026f22621dde9516dc2a5d1367.jpg'),
(22172, 1515, 'O Segredo do Templo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128255.mp4', 'http://timg.bdta.pro/images/d689e68f60f8eec0c20de7d72209ea2d.jpg'),
(22173, 1515, 'O Segredo do Templo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128256.mp4', 'http://timg.bdta.pro/images/75dc8a4ee6c89242a897fe1d2e015c89.jpg'),
(22174, 1516, 'O Segredo do Templo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/676337.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7In6dD8xgFCKl4Pyj8cFdKn3jrV.jpg'),
(22175, 1516, 'O Segredo do Templo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/676338.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b13DI5fyzJNrWog5BAkopANFoFM.jpg'),
(22176, 1516, 'O Segredo do Templo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/676339.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/36hMk4hYWYr6wx47ssU37Ko4xcF.jpg'),
(22177, 1516, 'O Segredo do Templo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/676340.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h35SlUUdEg183Q6qV6nXaO8teMJ.jpg'),
(22178, 1516, 'O Segredo do Templo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/676341.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mn2eRdx5uYMjneQtgGCRDlYoqdt.jpg'),
(22179, 1516, 'O Segredo do Templo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/676342.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o9F26Qs2Qpi5tgCyzMMBvztmRwi.jpg'),
(22180, 1516, 'O Segredo do Templo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/676343.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lwn1t9UkJ9eOz1Go5SnAZ3SsfAn.jpg'),
(22181, 1516, 'O Segredo do Templo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/676344.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fbpSMCsZ4PPDCgzIjNTOO5pQYto.jpg'),
(22182, 1517, 'Chica Vampiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106089.mp4', 'http://timg.bdta.pro/images/ec528763df69d89d6dc29fb67c30cbed.jpg'),
(22183, 1517, 'Chica Vampiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106090.mp4', 'http://timg.bdta.pro/images/581ddc58b031d1af6ef61fbbba438cee.jpg'),
(22184, 1517, 'Chica Vampiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106091.mp4', 'http://timg.bdta.pro/images/2eb764b3c2f914c446364566912a916d.jpg'),
(22185, 1517, 'Chica Vampiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106092.mp4', 'http://timg.bdta.pro/images/d8813f0adb23368d19ff30f277d6ed0e.jpg'),
(22186, 1517, 'Chica Vampiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106093.mp4', 'http://timg.bdta.pro/images/f8acad3a7e83e8dbc464b2cf14364f43.jpg'),
(22187, 1517, 'Chica Vampiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106094.mp4', 'http://timg.bdta.pro/images/ba62a169e484555e318c03f3b49e09c1.jpg'),
(22188, 1517, 'Chica Vampiro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106095.mp4', 'http://timg.bdta.pro/images/f1e44b18089aa3b47eae52cec4148ab7.jpg'),
(22189, 1517, 'Chica Vampiro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106096.mp4', 'http://timg.bdta.pro/images/ffa7d851c19083eb6cf2402d82e5da43.jpg'),
(22190, 1517, 'Chica Vampiro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106097.mp4', 'http://timg.bdta.pro/images/fc52c9ee85965bd08fc9db87bfe9b128.jpg'),
(22191, 1517, 'Chica Vampiro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106098.mp4', 'http://timg.bdta.pro/images/4b5cfccb784ba1561125a06790d41d63.jpg'),
(22192, 1517, 'Chica Vampiro S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106099.mp4', 'http://timg.bdta.pro/images/b612c9175cb42dc771e25176b89882af.jpg'),
(22193, 1517, 'Chica Vampiro S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/106100.mp4', 'http://timg.bdta.pro/images/6b3cb87a3d8d0dc96fe2f23f104605d1.jpg'),
(22194, 1517, 'Chica Vampiro S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/106101.mp4', 'http://timg.bdta.pro/images/0c2536a76037abe256d54b6d50dd89c4.jpg'),
(22195, 1517, 'Chica Vampiro S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/106102.mp4', 'http://timg.bdta.pro/images/5b500d05eacb925bf1d10b191ef1f23c.jpg'),
(22196, 1517, 'Chica Vampiro S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/106103.mp4', 'http://timg.bdta.pro/images/faaf0a35d55902f64c7d6463c1286e0b.jpg'),
(22197, 1517, 'Chica Vampiro S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/106104.mp4', 'http://timg.bdta.pro/images/6ec0d732ddcf27d3d4976972a0cd4098.jpg'),
(22198, 1517, 'Chica Vampiro S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/106105.mp4', 'http://timg.bdta.pro/images/701307f68799c40e280f5d1e26892034.jpg'),
(22199, 1517, 'Chica Vampiro S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/106106.mp4', 'http://timg.bdta.pro/images/cafbc35f5e856347fdb45bf0414ac4dc.jpg'),
(22200, 1517, 'Chica Vampiro S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/106107.mp4', 'http://timg.bdta.pro/images/200c3180d9faacecf24785dc32660384.jpg'),
(22201, 1517, 'Chica Vampiro S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/106108.mp4', 'http://timg.bdta.pro/images/51134aad7313bd823deb3a1329b1de47.jpg'),
(22202, 1517, 'Chica Vampiro S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/106109.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22203, 1517, 'Chica Vampiro S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/106110.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22204, 1517, 'Chica Vampiro S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/106111.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22205, 1517, 'Chica Vampiro S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/106112.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22206, 1517, 'Chica Vampiro S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/106113.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22207, 1517, 'Chica Vampiro S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/106114.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22208, 1517, 'Chica Vampiro S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/106115.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22209, 1517, 'Chica Vampiro S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/106116.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22210, 1517, 'Chica Vampiro S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/106117.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22211, 1517, 'Chica Vampiro S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/106118.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22212, 1517, 'Chica Vampiro S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/106119.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22213, 1517, 'Chica Vampiro S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/106120.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22214, 1517, 'Chica Vampiro S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/106121.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22215, 1517, 'Chica Vampiro S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/106122.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22216, 1517, 'Chica Vampiro S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/106123.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22217, 1517, 'Chica Vampiro S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/106124.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22218, 1517, 'Chica Vampiro S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/106125.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22219, 1517, 'Chica Vampiro S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/106126.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22220, 1517, 'Chica Vampiro S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/106127.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22221, 1517, 'Chica Vampiro S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/106128.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22222, 1517, 'Chica Vampiro S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/106129.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22223, 1517, 'Chica Vampiro S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/106130.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22224, 1517, 'Chica Vampiro S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/106131.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22225, 1517, 'Chica Vampiro S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/106132.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22226, 1517, 'Chica Vampiro S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/106133.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22227, 1517, 'Chica Vampiro S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/106134.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22228, 1517, 'Chica Vampiro S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/106135.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22229, 1517, 'Chica Vampiro S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/106136.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22230, 1517, 'Chica Vampiro S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/106137.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22231, 1517, 'Chica Vampiro S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/106138.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22232, 1517, 'Chica Vampiro S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/106139.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22233, 1517, 'Chica Vampiro S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/106140.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22234, 1517, 'Chica Vampiro S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/106141.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22235, 1517, 'Chica Vampiro S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/106142.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22236, 1517, 'Chica Vampiro S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/106143.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22237, 1517, 'Chica Vampiro S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/106144.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22238, 1517, 'Chica Vampiro S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/106145.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22239, 1517, 'Chica Vampiro S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/106146.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22240, 1517, 'Chica Vampiro S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/106147.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22241, 1517, 'Chica Vampiro S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/106148.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22242, 1517, 'Chica Vampiro S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/106149.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22243, 1517, 'Chica Vampiro S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/106150.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22244, 1517, 'Chica Vampiro S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/106151.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22245, 1517, 'Chica Vampiro S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/106152.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22246, 1517, 'Chica Vampiro S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/106153.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22247, 1517, 'Chica Vampiro S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/106154.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22248, 1517, 'Chica Vampiro S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/106155.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22249, 1517, 'Chica Vampiro S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/106156.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22250, 1517, 'Chica Vampiro S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/106157.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22251, 1517, 'Chica Vampiro S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/106158.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22252, 1517, 'Chica Vampiro S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/106159.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22253, 1517, 'Chica Vampiro S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/106160.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22254, 1517, 'Chica Vampiro S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/106161.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22255, 1517, 'Chica Vampiro S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/106162.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22256, 1517, 'Chica Vampiro S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/106163.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22257, 1517, 'Chica Vampiro S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/106164.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22258, 1517, 'Chica Vampiro S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/106165.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22259, 1517, 'Chica Vampiro S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/106166.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22260, 1517, 'Chica Vampiro S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/106167.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22261, 1517, 'Chica Vampiro S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/106168.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22262, 1517, 'Chica Vampiro S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/106169.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22263, 1517, 'Chica Vampiro S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/106170.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22264, 1517, 'Chica Vampiro S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/106171.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22265, 1517, 'Chica Vampiro S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/106172.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22266, 1517, 'Chica Vampiro S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/106173.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22267, 1517, 'Chica Vampiro S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/106174.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22268, 1517, 'Chica Vampiro S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/106175.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22269, 1517, 'Chica Vampiro S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/106176.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22270, 1517, 'Chica Vampiro S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/106177.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22271, 1517, 'Chica Vampiro S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/106178.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(22272, 1517, 'Chica Vampiro S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/106179.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22273, 1517, 'Chica Vampiro S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/106180.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22274, 1517, 'Chica Vampiro S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/106181.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22275, 1517, 'Chica Vampiro S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/106182.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22276, 1517, 'Chica Vampiro S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/106183.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22277, 1517, 'Chica Vampiro S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/106184.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22278, 1517, 'Chica Vampiro S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/106185.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22279, 1517, 'Chica Vampiro S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/106186.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22280, 1517, 'Chica Vampiro S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/106187.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22281, 1517, 'Chica Vampiro S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/106188.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22282, 1517, 'Chica Vampiro S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/106189.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22283, 1517, 'Chica Vampiro S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/106190.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22284, 1517, 'Chica Vampiro S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/106191.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22285, 1517, 'Chica Vampiro S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/106192.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22286, 1517, 'Chica Vampiro S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/106193.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22287, 1517, 'Chica Vampiro S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/106194.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22288, 1517, 'Chica Vampiro S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/106195.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22289, 1517, 'Chica Vampiro S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/106196.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22290, 1517, 'Chica Vampiro S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/106197.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22291, 1517, 'Chica Vampiro S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/106198.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22292, 1517, 'Chica Vampiro S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/106199.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22293, 1517, 'Chica Vampiro S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/106200.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22294, 1517, 'Chica Vampiro S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/106201.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22295, 1517, 'Chica Vampiro S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/106202.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22296, 1517, 'Chica Vampiro S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/106203.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22297, 1517, 'Chica Vampiro S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/106204.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22298, 1517, 'Chica Vampiro S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/106205.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22299, 1517, 'Chica Vampiro S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/106206.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22300, 1517, 'Chica Vampiro S01 E119', 'http://sinalprivado.info:80/series/1533784/1533784/106207.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22301, 1517, 'Chica Vampiro S01 E120', 'http://sinalprivado.info:80/series/1533784/1533784/106208.mp4', 'http://gstaticontent.com/images/ctlcyYZB0j2iIg7iK4a1l6lDIGm_big.jpg'),
(22302, 1518, 'Club 57 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106029.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22303, 1518, 'Club 57 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106030.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22304, 1518, 'Club 57 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106031.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22305, 1518, 'Club 57 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106032.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22306, 1518, 'Club 57 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106033.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22307, 1518, 'Club 57 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106034.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22308, 1518, 'Club 57 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106035.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22309, 1518, 'Club 57 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106036.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22310, 1518, 'Club 57 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106037.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22311, 1518, 'Club 57 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106038.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22312, 1518, 'Club 57 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106039.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22313, 1518, 'Club 57 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/106040.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22314, 1518, 'Club 57 S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/106041.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22315, 1518, 'Club 57 S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/106042.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22316, 1518, 'Club 57 S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/106043.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22317, 1518, 'Club 57 S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/106044.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22318, 1518, 'Club 57 S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/106045.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22319, 1518, 'Club 57 S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/106046.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22320, 1518, 'Club 57 S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/106047.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22321, 1518, 'Club 57 S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/106048.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22322, 1518, 'Club 57 S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/106049.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22323, 1518, 'Club 57 S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/106050.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22324, 1518, 'Club 57 S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/106051.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22325, 1518, 'Club 57 S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/106052.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22326, 1518, 'Club 57 S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/106053.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22327, 1518, 'Club 57 S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/106054.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22328, 1518, 'Club 57 S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/106055.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22329, 1518, 'Club 57 S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/106056.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22330, 1518, 'Club 57 S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/106057.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22331, 1518, 'Club 57 S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/106058.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22332, 1518, 'Club 57 S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/106059.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22333, 1518, 'Club 57 S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/106060.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22334, 1518, 'Club 57 S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/106061.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22335, 1518, 'Club 57 S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/106062.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22336, 1518, 'Club 57 S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/106063.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22337, 1518, 'Club 57 S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/106064.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22338, 1518, 'Club 57 S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/106065.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22339, 1518, 'Club 57 S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/106066.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22340, 1518, 'Club 57 S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/106067.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22341, 1518, 'Club 57 S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/106068.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22342, 1518, 'Club 57 S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/106069.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22343, 1518, 'Club 57 S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/106070.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22344, 1518, 'Club 57 S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/106071.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22345, 1518, 'Club 57 S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/106072.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22346, 1518, 'Club 57 S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/106073.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22347, 1518, 'Club 57 S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/106074.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22348, 1518, 'Club 57 S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/106075.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22349, 1518, 'Club 57 S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/106076.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22350, 1518, 'Club 57 S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/106077.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22351, 1518, 'Club 57 S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/106078.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22352, 1518, 'Club 57 S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/106079.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22353, 1518, 'Club 57 S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/106080.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22354, 1518, 'Club 57 S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/106081.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22355, 1518, 'Club 57 S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/106082.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22356, 1518, 'Club 57 S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/106083.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22357, 1518, 'Club 57 S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/106084.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22358, 1518, 'Club 57 S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/106085.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22359, 1518, 'Club 57 S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/106086.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22360, 1518, 'Club 57 S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/106087.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22361, 1518, 'Club 57 S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/106088.mp4', 'http://gstaticontent.com/images/3Pj88mhO1q0LhDwyoIbFcqbmLa1_big.jpg'),
(22362, 1519, 'Damages S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105970.mp4', 'http://timg.bdta.pro/images/dc05ffe7945709d8d22e7afb23ff7e9d.jpg'),
(22363, 1519, 'Damages S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105971.mp4', 'http://timg.bdta.pro/images/ebc0c69aa59fe1f87915fdf2a5b67d40.jpg'),
(22364, 1519, 'Damages S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105972.mp4', 'http://timg.bdta.pro/images/22a3687351b0daf02c63ca5afe805c83.jpg'),
(22365, 1519, 'Damages S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105973.mp4', 'http://timg.bdta.pro/images/bc5a11c80d2d7f2e46a963498a854b06.jpg'),
(22366, 1519, 'Damages S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105974.mp4', 'http://timg.bdta.pro/images/f174af6baa678789f28cabaf35173803.jpg'),
(22367, 1519, 'Damages S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105975.mp4', 'http://timg.bdta.pro/images/76a5439e1be6034b4eb25a708f355749.jpg'),
(22368, 1519, 'Damages S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105976.mp4', 'http://timg.bdta.pro/images/5f2ef2838bce209661496e6fc96705b4.jpg'),
(22369, 1519, 'Damages S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105977.mp4', 'http://timg.bdta.pro/images/18b9f47695cf685089b2c54900e046bd.jpg'),
(22370, 1519, 'Damages S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105978.mp4', 'http://timg.bdta.pro/images/4d8570769f1324f708532d511251e81d.jpg'),
(22371, 1519, 'Damages S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105979.mp4', 'http://timg.bdta.pro/images/bc513e7cce26560bb6be7ea42e652120.jpg'),
(22372, 1519, 'Damages S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105980.mp4', 'http://timg.bdta.pro/images/dd8434d9facce2849dad99f3bb7ac81d.jpg'),
(22373, 1519, 'Damages S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105981.mp4', 'http://timg.bdta.pro/images/370456ebf1ffd4a99717b5714be48806.jpg'),
(22374, 1519, 'Damages S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/105982.mp4', 'http://timg.bdta.pro/images/29e1f1f3f8afac84f523ffe8569282db.jpg'),
(22375, 1520, 'Damages S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105983.mp4', 'http://timg.bdta.pro/images/e3baee70ced1658fed28c42ceba92aa8.jpg'),
(22376, 1520, 'Damages S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105984.mp4', 'http://timg.bdta.pro/images/f2d97010752e3d0921d11697c0b8cb6e.jpg'),
(22377, 1520, 'Damages S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105985.mp4', 'http://timg.bdta.pro/images/984e03640fad3ec7fccdfc24cc7e5834.jpg'),
(22378, 1520, 'Damages S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105986.mp4', 'http://timg.bdta.pro/images/d4ad1156662e7a3ae400dc3df64b71a2.jpg'),
(22379, 1520, 'Damages S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105987.mp4', 'http://timg.bdta.pro/images/c6fc878d8fcd8cf57ca3f6030d86e32c.jpg'),
(22380, 1520, 'Damages S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105988.mp4', 'http://timg.bdta.pro/images/6b6a98f05cd1de5401d2d3ac4774e980.jpg'),
(22381, 1520, 'Damages S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105989.mp4', 'http://timg.bdta.pro/images/6b595a857efc0c7c7af534e2a6aaaa4f.jpg'),
(22382, 1520, 'Damages S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105990.mp4', 'http://timg.bdta.pro/images/fc2dd65cf0bf38839cc7e1a4aba4d41d.jpg'),
(22383, 1520, 'Damages S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105991.mp4', 'http://timg.bdta.pro/images/28a6e3337e53e1e540c4f026f98c2588.jpg'),
(22384, 1520, 'Damages S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105992.mp4', 'http://timg.bdta.pro/images/3569c6143c6e2b45e7964e6a038f78c6.jpg'),
(22385, 1520, 'Damages S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105993.mp4', 'http://timg.bdta.pro/images/9b5235675598647316ffb76ac74aa3c5.jpg'),
(22386, 1520, 'Damages S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105994.mp4', 'http://timg.bdta.pro/images/78ad2b21d7c74448fd9f34df40474d4c.jpg'),
(22387, 1520, 'Damages S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/105995.mp4', 'http://timg.bdta.pro/images/8aafd2cd1a4896e8d7a7b8f765f1ffce.jpg'),
(22388, 1521, 'Damages S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105996.mp4', 'http://timg.bdta.pro/images/df15c802a289ff39e860b9781665a88c.jpg'),
(22389, 1521, 'Damages S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105997.mp4', 'http://timg.bdta.pro/images/ea33d5845e50e719595e59bc54fddac7.jpg'),
(22390, 1521, 'Damages S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105998.mp4', 'http://timg.bdta.pro/images/6f81bfb90014df416edb8538a1ec81cc.jpg'),
(22391, 1521, 'Damages S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105999.mp4', 'http://timg.bdta.pro/images/e2a6bd4ed813286b6211a63d356f1724.jpg'),
(22392, 1521, 'Damages S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106000.mp4', 'http://timg.bdta.pro/images/64ca13a0f018c4de4d6e7ae1cce5acdc.jpg'),
(22393, 1521, 'Damages S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106001.mp4', 'http://timg.bdta.pro/images/afa4f6a8755bd8aa16512cdb0cb7d378.jpg'),
(22394, 1521, 'Damages S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106002.mp4', 'http://timg.bdta.pro/images/e3b13c65a0a5b702a94436fc93b44566.jpg'),
(22395, 1521, 'Damages S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106003.mp4', 'http://timg.bdta.pro/images/5ce4d6ba78505a4c7b127f4eaf54da88.jpg'),
(22396, 1521, 'Damages S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106004.mp4', 'http://timg.bdta.pro/images/0ee71a09eccf445deb56b429605f3c69.jpg'),
(22397, 1521, 'Damages S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106005.mp4', 'http://timg.bdta.pro/images/9a88c39ccbadd25aa5c567b4e56ffc84.jpg'),
(22398, 1521, 'Damages S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/106006.mp4', 'http://timg.bdta.pro/images/813ce76060809508fbcae76fc7f48a42.jpg'),
(22399, 1521, 'Damages S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/106007.mp4', 'http://timg.bdta.pro/images/2048c16308e029736869ef9a2d1e45f1.jpg'),
(22400, 1521, 'Damages S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/106008.mp4', 'http://timg.bdta.pro/images/9048c0ae337b69eebb3673ffb41df848.jpg'),
(22401, 1522, 'Damages S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106009.mp4', 'http://timg.bdta.pro/images/94016ecfd6534b20b761a65382773b37.jpg'),
(22402, 1522, 'Damages S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106010.mp4', 'http://timg.bdta.pro/images/d0485f4f6dc2a59260313091b56779c1.jpg'),
(22403, 1522, 'Damages S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106011.mp4', 'http://timg.bdta.pro/images/1c75ad82873249fb3c6f94630a1b82fc.jpg'),
(22404, 1522, 'Damages S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106012.mp4', 'http://timg.bdta.pro/images/b9e2f0c593b0a15ed510649d3900e145.jpg'),
(22405, 1522, 'Damages S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106013.mp4', 'http://timg.bdta.pro/images/e2a56c0cb147488ecabe5aa002b8eed9.jpg'),
(22406, 1522, 'Damages S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106014.mp4', 'http://timg.bdta.pro/images/7116c5cedef5f1ee95256dc9fee69fa1.jpg'),
(22407, 1522, 'Damages S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106015.mp4', 'http://timg.bdta.pro/images/8b396216e037f8bd302f01410c5f2c74.jpg'),
(22408, 1522, 'Damages S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106016.mp4', 'http://timg.bdta.pro/images/7d9bc1e4d3319b8ef1020fd7a6cee98a.jpg'),
(22409, 1522, 'Damages S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106017.mp4', 'http://timg.bdta.pro/images/149a61f5309c74a5414c635f4b49137e.jpg'),
(22410, 1522, 'Damages S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106018.mp4', 'http://timg.bdta.pro/images/52a8d43c3a378fe81b366716420a3d33.jpg'),
(22411, 1523, 'Damages S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/106019.mp4', 'http://timg.bdta.pro/images/2c90eac0bfec8aba934b30ea38dc02a3.jpg'),
(22412, 1523, 'Damages S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/106020.mp4', 'http://timg.bdta.pro/images/86ed117883d0830c8efab6941546dba8.jpg'),
(22413, 1523, 'Damages S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/106021.mp4', 'http://timg.bdta.pro/images/f72e8cd7db1d76ee62edcb1bbebd689c.jpg'),
(22414, 1523, 'Damages S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/106022.mp4', 'http://timg.bdta.pro/images/0bffa51efdf73f151228179dd9c82238.jpg'),
(22415, 1523, 'Damages S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/106023.mp4', 'http://timg.bdta.pro/images/2e44820ca9b73d1d0ed5a6504e57d6eb.jpg'),
(22416, 1523, 'Damages S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/106024.mp4', 'http://timg.bdta.pro/images/4c3ccce9647175cec8556c91a25eaff6.jpg'),
(22417, 1523, 'Damages S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/106025.mp4', 'http://timg.bdta.pro/images/81424f4487488d9a0ec542a6e2fa9ee5.jpg'),
(22418, 1523, 'Damages S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/106026.mp4', 'http://timg.bdta.pro/images/04f30162daeddd3886d14712b7e4b20d.jpg'),
(22419, 1523, 'Damages S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/106027.mp4', 'http://timg.bdta.pro/images/498fb66b6689da0eadc7419aac44981c.jpg'),
(22420, 1523, 'Damages S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/106028.mp4', 'http://timg.bdta.pro/images/19b4304f69528e0022b1dd6ece102607.jpg'),
(22421, 1524, 'For all Mankind S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258239.mp4', 'http://timg.bdta.pro/images/aeb8c0ab5d1048f2f13b43ccd74a2563.jpg'),
(22422, 1524, 'For all Mankind S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258240.mp4', 'http://timg.bdta.pro/images/9a9590bba9c09e39eb33868b263d55f6.jpg'),
(22423, 1524, 'For all Mankind S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258241.mp4', 'http://timg.bdta.pro/images/e7e925f0ee77e503e082b303d54a6b9f.jpg'),
(22424, 1524, 'For all Mankind S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258242.mp4', 'http://timg.bdta.pro/images/ae412c9fae968a70b89592c84455489e.jpg'),
(22425, 1524, 'For all Mankind S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258243.mp4', 'http://timg.bdta.pro/images/b76b860fadd9d8b945f6d6094b988a37.jpg'),
(22426, 1524, 'For all Mankind S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258244.mp4', 'http://timg.bdta.pro/images/87ad9c1392c53c92651423a4d7700d11.jpg'),
(22427, 1524, 'For all Mankind S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258245.mp4', 'http://timg.bdta.pro/images/5e8eb0f22246f7692c69642f7c082d48.jpg'),
(22428, 1524, 'For all Mankind S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258246.mp4', 'http://timg.bdta.pro/images/2ef58e847ce66cb7616a0936d3fb3300.jpg'),
(22429, 1524, 'For all Mankind S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258247.mp4', 'http://timg.bdta.pro/images/2bd8fcb0e800c5186698e3aa5d36ff62.jpg'),
(22430, 1524, 'For all Mankind S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258248.mp4', 'http://timg.bdta.pro/images/4b73356350ef5fcbd9b54cfbf12a6bd0.jpg'),
(22431, 1525, 'For all Mankind S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258249.mp4', 'http://gstaticontent.com/images/lvYajilzbVUkj5QBmAD8v1qz0g4_big.jpg'),
(22432, 1525, 'For all Mankind S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258250.mp4', 'http://gstaticontent.com/images/lvYajilzbVUkj5QBmAD8v1qz0g4_big.jpg'),
(22433, 1525, 'For all Mankind S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258251.mp4', 'http://gstaticontent.com/images/lvYajilzbVUkj5QBmAD8v1qz0g4_big.jpg'),
(22434, 1525, 'For all Mankind S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258252.mp4', 'http://gstaticontent.com/images/lvYajilzbVUkj5QBmAD8v1qz0g4_big.jpg'),
(22435, 1525, 'For all Mankind S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258253.mp4', 'http://gstaticontent.com/images/lvYajilzbVUkj5QBmAD8v1qz0g4_big.jpg'),
(22436, 1525, 'For all Mankind S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258254.mp4', 'http://gstaticontent.com/images/lvYajilzbVUkj5QBmAD8v1qz0g4_big.jpg'),
(22437, 1525, 'For all Mankind S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258255.mp4', 'http://gstaticontent.com/images/lvYajilzbVUkj5QBmAD8v1qz0g4_big.jpg'),
(22438, 1525, 'For all Mankind S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258256.mp4', 'http://gstaticontent.com/images/lvYajilzbVUkj5QBmAD8v1qz0g4_big.jpg'),
(22439, 1525, 'For all Mankind S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258257.mp4', 'http://gstaticontent.com/images/lvYajilzbVUkj5QBmAD8v1qz0g4_big.jpg'),
(22440, 1525, 'For all Mankind S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258258.mp4', 'http://gstaticontent.com/images/lvYajilzbVUkj5QBmAD8v1qz0g4_big.jpg'),
(22441, 1526, 'For all Mankind S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258259.mp4', 'http://timg.bdta.pro/images/a7377de2ea6804e088db9fa0114a2bde.jpg'),
(22442, 1526, 'For all Mankind S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258260.mp4', 'http://timg.bdta.pro/images/8e158622c2042487c2ac9987642df55e.jpg'),
(22443, 1526, 'For all Mankind S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258261.mp4', 'http://timg.bdta.pro/images/9c377c5411edf6837340a5de2ddd4b1d.jpg'),
(22444, 1526, 'For all Mankind S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258262.mp4', 'http://timg.bdta.pro/images/b9fda75ed1cc0abd417d7ae23bf743e7.jpg'),
(22445, 1526, 'For all Mankind S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258263.mp4', 'http://timg.bdta.pro/images/3a8da0ff6bc86a473a7b65e2b13544d5.jpg'),
(22446, 1526, 'For all Mankind S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258264.mp4', 'http://timg.bdta.pro/images/220ffd537ce7611fc72534401c35c1ec.jpg'),
(22447, 1526, 'For all Mankind S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258265.mp4', 'http://timg.bdta.pro/images/840bb2e92ae2ffb62a97de730b61b7c7.jpg'),
(22448, 1526, 'For all Mankind S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258266.mp4', 'http://timg.bdta.pro/images/0ddb9530cb6a0f1fee633fe18f5c929a.jpg'),
(22449, 1526, 'For all Mankind S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258267.mp4', 'http://timg.bdta.pro/images/73f462fc9c03748527cf6499fe41de12.jpg'),
(22450, 1526, 'For all Mankind S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258268.mp4', 'http://timg.bdta.pro/images/30b223a8c7dfe6e4d34ef0cdc68741fc.jpg'),
(22451, 1527, 'For all Mankind S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258269.mp4', 'http://gstaticontent.com/images/lvYajilzbVUkj5QBmAD8v1qz0g4_big.jpg'),
(22452, 1527, 'For all Mankind S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258270.mp4', 'http://gstaticontent.com/images/lvYajilzbVUkj5QBmAD8v1qz0g4_big.jpg'),
(22453, 1527, 'For all Mankind S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258271.mp4', 'http://gstaticontent.com/images/lvYajilzbVUkj5QBmAD8v1qz0g4_big.jpg'),
(22454, 1527, 'For all Mankind S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258272.mp4', 'http://gstaticontent.com/images/lvYajilzbVUkj5QBmAD8v1qz0g4_big.jpg'),
(22455, 1527, 'For all Mankind S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258273.mp4', 'http://gstaticontent.com/images/lvYajilzbVUkj5QBmAD8v1qz0g4_big.jpg'),
(22456, 1527, 'For all Mankind S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258274.mp4', 'http://gstaticontent.com/images/lvYajilzbVUkj5QBmAD8v1qz0g4_big.jpg'),
(22457, 1527, 'For all Mankind S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258275.mp4', 'http://gstaticontent.com/images/lvYajilzbVUkj5QBmAD8v1qz0g4_big.jpg'),
(22458, 1527, 'For all Mankind S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258276.mp4', 'http://gstaticontent.com/images/lvYajilzbVUkj5QBmAD8v1qz0g4_big.jpg'),
(22459, 1527, 'For all Mankind S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258277.mp4', 'http://gstaticontent.com/images/lvYajilzbVUkj5QBmAD8v1qz0g4_big.jpg'),
(22460, 1527, 'For all Mankind S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258278.mp4', 'http://gstaticontent.com/images/lvYajilzbVUkj5QBmAD8v1qz0g4_big.jpg'),
(22461, 1528, 'Les Miserables S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105962.mp4', 'http://timg.bdta.pro/images/a119f95396df803a1273c2d6473c213b.jpg'),
(22462, 1528, 'Les Miserables S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105963.mp4', 'http://timg.bdta.pro/images/c664934c53ae40499d5b993ca12f32e0.jpg'),
(22463, 1528, 'Les Miserables S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105964.mp4', 'http://timg.bdta.pro/images/7a3f798c5b4a6270e0f6f81994878e78.jpg'),
(22464, 1528, 'Les Miserables S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105965.mp4', 'http://timg.bdta.pro/images/22d2d25e6424a47d794f91fa7b608179.jpg'),
(22465, 1528, 'Les Miserables S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105966.mp4', 'http://timg.bdta.pro/images/d853f6a5fe72ec34e161fbdde5f44bab.jpg'),
(22466, 1528, 'Les Miserables S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105967.mp4', 'http://timg.bdta.pro/images/861550f38981fab8cbc5cca3678ff610.jpg'),
(22467, 1528, 'Les Miserables S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105968.mp4', 'http://gstaticontent.com/images/vD5gUfFYEuYXwfOVJQjLIQTGs0s_big.jpg'),
(22468, 1528, 'Les Miserables S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105969.mp4', 'http://gstaticontent.com/images/vD5gUfFYEuYXwfOVJQjLIQTGs0s_big.jpg'),
(22469, 1529, 'Chamas do Destino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105954.mp4', 'http://timg.bdta.pro/images/6f937b6e27f8d647b871a3277a1d19b5.jpg'),
(22470, 1529, 'Chamas do Destino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105955.mp4', 'http://timg.bdta.pro/images/8d94de8934f4a8b5f6bdafdb9d51330e.jpg'),
(22471, 1529, 'Chamas do Destino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105956.mp4', 'http://timg.bdta.pro/images/9f0584166ff6d2a84a73788204045382.jpg'),
(22472, 1529, 'Chamas do Destino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105957.mp4', 'http://timg.bdta.pro/images/f649e38daf8764ce59b6edc92f1b067d.jpg'),
(22473, 1529, 'Chamas do Destino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105958.mp4', 'http://timg.bdta.pro/images/63929ed6653c1c9c259aff0a3bad25e9.jpg'),
(22474, 1529, 'Chamas do Destino S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105959.mp4', 'http://timg.bdta.pro/images/13cfb9535260f57b13964e0df8d52236.jpg'),
(22475, 1529, 'Chamas do Destino S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105960.mp4', 'http://timg.bdta.pro/images/a51062c1e07173cb5834d95f3178d5cb.jpg'),
(22476, 1529, 'Chamas do Destino S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105961.mp4', 'http://timg.bdta.pro/images/5ff20f3c5484b2866889f28a2b214e8d.jpg'),
(22477, 1530, 'Velozes e Furiosos - Espiões do Asfalto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144307.mp4', 'http://timg.bdta.pro/images/9d00a31267a900f4a451b748c6bdd404.jpg'),
(22478, 1530, 'Velozes e Furiosos - Espiões do Asfalto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144308.mp4', 'http://timg.bdta.pro/images/8b3b38871fef0729d02b8b24e4715aea.jpg'),
(22479, 1530, 'Velozes e Furiosos - Espiões do Asfalto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144309.mp4', 'http://timg.bdta.pro/images/fe798e559162d677dcb3aef0fccdb0af.jpg'),
(22480, 1530, 'Velozes e Furiosos - Espiões do Asfalto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144310.mp4', 'http://timg.bdta.pro/images/1d8a4a3363ab79efaf99745c7652e639.jpg'),
(22481, 1530, 'Velozes e Furiosos - Espiões do Asfalto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144311.mp4', 'http://timg.bdta.pro/images/b64b5c15176ac8b079fceadb900c8471.jpg'),
(22482, 1530, 'Velozes e Furiosos - Espiões do Asfalto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144312.mp4', 'http://timg.bdta.pro/images/1431b0efbc81747e194a4d74ae699959.jpg'),
(22483, 1530, 'Velozes e Furiosos - Espiões do Asfalto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144313.mp4', 'http://timg.bdta.pro/images/0accbec7bd191ac23034badc9173cf88.jpg'),
(22484, 1530, 'Velozes e Furiosos - Espiões do Asfalto S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144314.mp4', 'http://timg.bdta.pro/images/78ff5a7515d5d5260b5ca1b9d09d637b.jpg'),
(22485, 1531, 'Velozes e Furiosos - Espiões do Asfalto S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144315.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22486, 1531, 'Velozes e Furiosos - Espiões do Asfalto S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144316.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22487, 1531, 'Velozes e Furiosos - Espiões do Asfalto S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144317.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22488, 1531, 'Velozes e Furiosos - Espiões do Asfalto S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144318.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22489, 1531, 'Velozes e Furiosos - Espiões do Asfalto S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144319.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22490, 1531, 'Velozes e Furiosos - Espiões do Asfalto S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144320.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22491, 1531, 'Velozes e Furiosos - Espiões do Asfalto S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144321.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22492, 1531, 'Velozes e Furiosos - Espiões do Asfalto S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144322.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22493, 1532, 'Velozes e Furiosos - Espiões do Asfalto S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144323.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22494, 1532, 'Velozes e Furiosos - Espiões do Asfalto S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144324.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22495, 1532, 'Velozes e Furiosos - Espiões do Asfalto S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144325.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22496, 1532, 'Velozes e Furiosos - Espiões do Asfalto S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144326.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22497, 1532, 'Velozes e Furiosos - Espiões do Asfalto S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144327.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22498, 1532, 'Velozes e Furiosos - Espiões do Asfalto S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144328.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22499, 1532, 'Velozes e Furiosos - Espiões do Asfalto S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144329.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22500, 1532, 'Velozes e Furiosos - Espiões do Asfalto S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144330.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22501, 1533, 'Velozes e Furiosos - Espiões do Asfalto S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144331.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22502, 1533, 'Velozes e Furiosos - Espiões do Asfalto S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144332.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22503, 1533, 'Velozes e Furiosos - Espiões do Asfalto S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144333.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22504, 1533, 'Velozes e Furiosos - Espiões do Asfalto S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144334.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22505, 1533, 'Velozes e Furiosos - Espiões do Asfalto S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144335.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22506, 1533, 'Velozes e Furiosos - Espiões do Asfalto S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144336.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22507, 1533, 'Velozes e Furiosos - Espiões do Asfalto S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144337.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22508, 1533, 'Velozes e Furiosos - Espiões do Asfalto S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144338.mp4', 'http://gstaticontent.com/images/lgDUoqzVuqGm4Yzp7BHmV0Dhpgu_big.jpg'),
(22509, 1534, 'Messiah S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105944.mp4', 'http://timg.bdta.pro/images/a0648e7b623798f0e8b1e38770a6863b.jpg'),
(22510, 1534, 'Messiah S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105945.mp4', 'http://timg.bdta.pro/images/c49e62b34bb05d0a93e5b2e7e1a6ba3e.jpg'),
(22511, 1534, 'Messiah S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105946.mp4', 'http://timg.bdta.pro/images/6aeee3815fb8a74f89f740053887bc39.jpg'),
(22512, 1534, 'Messiah S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105947.mp4', 'http://timg.bdta.pro/images/7aad688c2770d41cf037a5b7011a8cc6.jpg'),
(22513, 1534, 'Messiah S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105948.mp4', 'http://timg.bdta.pro/images/b81c44c86f696f99f91d3deca379f9fb.jpg'),
(22514, 1534, 'Messiah S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105949.mp4', 'http://timg.bdta.pro/images/deb49f581b73baef9d8f6ca03bc25121.jpg'),
(22515, 1534, 'Messiah S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105950.mp4', 'http://timg.bdta.pro/images/1ac9561b99553460e723fb4156cce951.jpg'),
(22516, 1534, 'Messiah S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105951.mp4', 'http://timg.bdta.pro/images/30d62772867dfcbe2306e7b850cd4297.jpg'),
(22517, 1534, 'Messiah S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105952.mp4', 'http://timg.bdta.pro/images/8647dd386519a7f48a86ac52cc8b41c7.jpg'),
(22518, 1534, 'Messiah S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105953.mp4', 'http://timg.bdta.pro/images/15f893827d209d51db53d3811435b91b.jpg'),
(22519, 1535, 'Travelers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132604.mp4', 'http://timg.bdta.pro/images/7364eab4d7afcf313ba4cd01ee264a63.jpg'),
(22520, 1535, 'Travelers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132605.mp4', 'http://timg.bdta.pro/images/6b3ae8acde6a50df85ebabaaeef67f6c.jpg'),
(22521, 1535, 'Travelers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132606.mp4', 'http://timg.bdta.pro/images/e351ba1abf84089e9ca04e9e194b21b4.jpg'),
(22522, 1535, 'Travelers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132607.mp4', 'http://timg.bdta.pro/images/1b132ec8b0f157102773a35fc55be279.jpg'),
(22523, 1535, 'Travelers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132608.mp4', 'http://timg.bdta.pro/images/f20787a997cc4fce4a236769de2b8b5a.jpg'),
(22524, 1535, 'Travelers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132609.mp4', 'http://timg.bdta.pro/images/cac2c38b0272eb47bb1e3c1b92d35b26.jpg'),
(22525, 1535, 'Travelers S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132610.mp4', 'http://timg.bdta.pro/images/7e591f87d0e7931207752f6f908b83a8.jpg'),
(22526, 1535, 'Travelers S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132611.mp4', 'http://timg.bdta.pro/images/ba1b39a500966d65e4fd57bb7d210441.jpg'),
(22527, 1535, 'Travelers S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132612.mp4', 'http://timg.bdta.pro/images/4918f67176a47911fbd3067fbf901585.jpg'),
(22528, 1535, 'Travelers S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132613.mp4', 'http://timg.bdta.pro/images/bb98b069556c2a4e3f3dadef4a1582c2.jpg'),
(22529, 1536, 'Travelers S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132614.mp4', 'http://timg.bdta.pro/images/8e577aa58531a8db1eefb1b55026a16a.jpg'),
(22530, 1536, 'Travelers S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132615.mp4', 'http://timg.bdta.pro/images/ba84a5bdf6dc188179833822472bbe32.jpg'),
(22531, 1536, 'Travelers S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132616.mp4', 'http://timg.bdta.pro/images/e1cd41ca90f96a7271f8e124cb40d443.jpg'),
(22532, 1536, 'Travelers S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132617.mp4', 'http://timg.bdta.pro/images/9c9962302a5a7501a6d018da09776dea.jpg'),
(22533, 1536, 'Travelers S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132618.mp4', 'http://timg.bdta.pro/images/240c6e34e7a50cba8ce4971de929d5a0.jpg'),
(22534, 1536, 'Travelers S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132619.mp4', 'http://timg.bdta.pro/images/dee2b5cebc1549262916e14d76e99316.jpg'),
(22535, 1536, 'Travelers S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132620.mp4', 'http://timg.bdta.pro/images/13f248a78fc50ed62c2e1751bb0c7d5c.jpg'),
(22536, 1536, 'Travelers S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132621.mp4', 'http://timg.bdta.pro/images/02eafc6d0cdd39d49e91e709871eded0.jpg'),
(22537, 1536, 'Travelers S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132622.mp4', 'http://timg.bdta.pro/images/247fa3285ec24b08db9645e8ea653796.jpg'),
(22538, 1536, 'Travelers S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132623.mp4', 'http://timg.bdta.pro/images/6509beea6063bb7a116bdc53135a5d22.jpg'),
(22539, 1536, 'Travelers S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132624.mp4', 'http://timg.bdta.pro/images/eae16cb83b74256c3427b4647b117c41.jpg'),
(22540, 1536, 'Travelers S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132625.mp4', 'http://timg.bdta.pro/images/01d390e8c3d816a5b3d97abf9bdd9bc1.jpg'),
(22541, 1537, 'Travelers S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132626.mp4', 'http://timg.bdta.pro/images/8663e65e40f80381e19fab5e9052c11d.jpg'),
(22542, 1537, 'Travelers S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132627.mp4', 'http://timg.bdta.pro/images/727e90b3bb419032ca32eb41d086f071.jpg'),
(22543, 1537, 'Travelers S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132628.mp4', 'http://timg.bdta.pro/images/d2a735b3bd72828129f915d6d94eede6.jpg'),
(22544, 1537, 'Travelers S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132629.mp4', 'http://timg.bdta.pro/images/e65075331cc132c06cb03cc93386ed30.jpg'),
(22545, 1537, 'Travelers S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132630.mp4', 'http://timg.bdta.pro/images/b26db1c1df89f3bb4495867e4d4d9ce5.jpg'),
(22546, 1537, 'Travelers S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132631.mp4', 'http://timg.bdta.pro/images/06a824f512bfd341a3dc8424b72acc51.jpg'),
(22547, 1537, 'Travelers S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132632.mp4', 'http://timg.bdta.pro/images/681229b6901fc07d336b367b9e003add.jpg'),
(22548, 1537, 'Travelers S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132633.mp4', 'http://timg.bdta.pro/images/ef2f36d9cab98a05c5207c3a66351ca6.jpg'),
(22549, 1537, 'Travelers S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132634.mp4', 'http://timg.bdta.pro/images/c6977d160e07cc7a63868847c369e48f.jpg'),
(22550, 1537, 'Travelers S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132635.mp4', 'http://timg.bdta.pro/images/3b5d399325ccfccf0d19e80620636508.jpg'),
(22551, 1538, 'Spinning Out S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105934.mp4', 'http://timg.bdta.pro/images/518e72e7a47a99a664bcc96deba6da57.jpg'),
(22552, 1538, 'Spinning Out S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105935.mp4', 'http://timg.bdta.pro/images/c4c67156612625467bc4ba84f245d9b6.jpg'),
(22553, 1538, 'Spinning Out S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105936.mp4', 'http://timg.bdta.pro/images/981b30a4f93d59f3c85c2fe0f885e199.jpg'),
(22554, 1538, 'Spinning Out S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105937.mp4', 'http://timg.bdta.pro/images/b4091afa15804770f19a7478de0e0c1f.jpg'),
(22555, 1538, 'Spinning Out S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105938.mp4', 'http://timg.bdta.pro/images/587532e4ea5e03d02823e66d4e5c6f39.jpg'),
(22556, 1538, 'Spinning Out S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105939.mp4', 'http://timg.bdta.pro/images/ac28df08069354c1b7c32a5853416fbf.jpg'),
(22557, 1538, 'Spinning Out S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105940.mp4', 'http://timg.bdta.pro/images/3886da8851938bdb4d9216234d177e7e.jpg'),
(22558, 1538, 'Spinning Out S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105941.mp4', 'http://timg.bdta.pro/images/0425386c8499b7351071a624059f6bec.jpg'),
(22559, 1538, 'Spinning Out S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105942.mp4', 'http://timg.bdta.pro/images/f91fac42eb7cc5ebfa0d3c83d9b18c0b.jpg'),
(22560, 1538, 'Spinning Out S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105943.mp4', 'http://timg.bdta.pro/images/dd5ca3192cd76a1cea4d52641ea92825.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(22561, 1539, 'The L Word: Generation Q [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256035.mp4', 'http://timg.bdta.pro/images/3d147b6691a7945a7b1e06de4ed55c5b.jpg'),
(22562, 1539, 'The L Word: Generation Q [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256036.mp4', 'http://timg.bdta.pro/images/223a386941ee4bedec17cf539fce6f4f.jpg'),
(22563, 1539, 'The L Word: Generation Q [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256037.mp4', 'http://timg.bdta.pro/images/dbfbed7e41ce1da752f152cac2936282.jpg'),
(22564, 1539, 'The L Word: Generation Q [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256038.mp4', 'http://timg.bdta.pro/images/c0e00fd612f64b7105a4b273549be52d.jpg'),
(22565, 1539, 'The L Word: Generation Q [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256039.mp4', 'http://gstaticontent.com/images/yJi4XF31vgIaI1J34RAOlFFo3Pv_big.jpg'),
(22566, 1539, 'The L Word: Generation Q [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256040.mp4', 'http://gstaticontent.com/images/yJi4XF31vgIaI1J34RAOlFFo3Pv_big.jpg'),
(22567, 1539, 'The L Word: Generation Q [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256041.mp4', 'http://timg.bdta.pro/images/9a2fc0172111230684b73bdece84033e.jpg'),
(22568, 1539, 'The L Word: Generation Q [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256042.mp4', 'http://timg.bdta.pro/images/6454e7cb7276776ce2bef532143d5685.jpg'),
(22569, 1540, 'The L Word: Generation Q [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k5UwXdIwNhTxEOGCUl7TwLZ7nd3.jpg'),
(22570, 1540, 'The L Word: Generation Q [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6aXd8RZ6m5B0yK7JcQB0NYe6xBT.jpg'),
(22571, 1540, 'The L Word: Generation Q [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y5FpFIMXitgymyd4LWHn0GfTMsI.jpg'),
(22572, 1540, 'The L Word: Generation Q [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jFGg5zPxqrwVaTBu1LvWytngLM3.jpg'),
(22573, 1540, 'The L Word: Generation Q [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Vyr9NhNw34QrHUSeKIeKhWbegM.jpg'),
(22574, 1540, 'The L Word: Generation Q [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rB4ObpQHoL78zGeICQwmnx08vek.jpg'),
(22575, 1540, 'The L Word: Generation Q [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tQsL8E1WkQWmzyQv43deCPaNGnz.jpg'),
(22576, 1540, 'The L Word: Generation Q [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s9IPu0jvKD3nZZQX22msYRPpiGo.jpg'),
(22577, 1540, 'The L Word: Generation Q [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vikzDXXAVlvB1F4tZxo8FlzpwTk.jpg'),
(22578, 1540, 'The L Word: Generation Q [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dVojz7Ro8oxXIaIpw5aPagcgrOI.jpg'),
(22579, 1541, 'Chacrinha - A Minissérie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105910.mp4', 'http://gstaticontent.com/images/zHdoe1Z6tWDrBnHOdZjjjsthIVA_big.jpg'),
(22580, 1541, 'Chacrinha - A Minissérie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105911.mp4', 'http://gstaticontent.com/images/zHdoe1Z6tWDrBnHOdZjjjsthIVA_big.jpg'),
(22581, 1541, 'Chacrinha - A Minissérie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105912.mp4', 'http://gstaticontent.com/images/zHdoe1Z6tWDrBnHOdZjjjsthIVA_big.jpg'),
(22582, 1541, 'Chacrinha - A Minissérie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105913.mp4', 'http://gstaticontent.com/images/zHdoe1Z6tWDrBnHOdZjjjsthIVA_big.jpg'),
(22583, 1542, 'Explicando O Sexo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105905.mp4', 'http://gstaticontent.com/images/kqSFFExFwVChd00k1n3fk89zgi0_big.jpg'),
(22584, 1542, 'Explicando O Sexo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105906.mp4', 'http://gstaticontent.com/images/kqSFFExFwVChd00k1n3fk89zgi0_big.jpg'),
(22585, 1542, 'Explicando O Sexo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105907.mp4', 'http://gstaticontent.com/images/kqSFFExFwVChd00k1n3fk89zgi0_big.jpg'),
(22586, 1542, 'Explicando O Sexo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105908.mp4', 'http://gstaticontent.com/images/kqSFFExFwVChd00k1n3fk89zgi0_big.jpg'),
(22587, 1542, 'Explicando O Sexo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105909.mp4', 'http://gstaticontent.com/images/kqSFFExFwVChd00k1n3fk89zgi0_big.jpg'),
(22588, 1543, 'Deus Me Adicionou S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144393.mp4', 'http://timg.bdta.pro/images/1b10d6d260ca1079ac280ec5b7cb8b11.jpg'),
(22589, 1543, 'Deus Me Adicionou S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144394.mp4', 'http://timg.bdta.pro/images/0c34f1d4cd86040240370b29a88fc079.jpg'),
(22590, 1543, 'Deus Me Adicionou S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144395.mp4', 'http://timg.bdta.pro/images/f1f287a7b771be4018a01bd07a19c25f.jpg'),
(22591, 1543, 'Deus Me Adicionou S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144396.mp4', 'http://timg.bdta.pro/images/243f80dac7a5c17dab057c40183aeefc.jpg'),
(22592, 1543, 'Deus Me Adicionou S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144397.mp4', 'http://timg.bdta.pro/images/488c4878248e4c0ea0b69ab8c2404b88.jpg'),
(22593, 1543, 'Deus Me Adicionou S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144398.mp4', 'http://timg.bdta.pro/images/475b6d00d8b45bc5f06fa1173748dad7.jpg'),
(22594, 1543, 'Deus Me Adicionou S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144399.mp4', 'http://timg.bdta.pro/images/c54e811738ede08bb7a23ac5eb2efbca.jpg'),
(22595, 1543, 'Deus Me Adicionou S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144400.mp4', 'http://timg.bdta.pro/images/a6a93a0476b53d958eeee6f02d70f5ef.jpg'),
(22596, 1543, 'Deus Me Adicionou S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144401.mp4', 'http://timg.bdta.pro/images/f40a4a43f5f88a37e82f58c7ddcc88e9.jpg'),
(22597, 1543, 'Deus Me Adicionou S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144402.mp4', 'http://timg.bdta.pro/images/093e6672806450d624626fd631f5727c.jpg'),
(22598, 1543, 'Deus Me Adicionou S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144403.mp4', 'http://timg.bdta.pro/images/0a8949579c5745bb36bec84370c7d141.jpg'),
(22599, 1543, 'Deus Me Adicionou S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144404.mp4', 'http://timg.bdta.pro/images/cf867be2eb80301236d9833f7529eb03.jpg'),
(22600, 1543, 'Deus Me Adicionou S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144405.mp4', 'http://timg.bdta.pro/images/e00d3f91c28d76495279dfca0f7922c8.jpg'),
(22601, 1543, 'Deus Me Adicionou S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144406.mp4', 'http://timg.bdta.pro/images/059c7f3cfba36d1640097da62256f6cc.jpg'),
(22602, 1543, 'Deus Me Adicionou S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144407.mp4', 'http://timg.bdta.pro/images/76f5e027913520a445f2f1d2e294672d.jpg'),
(22603, 1543, 'Deus Me Adicionou S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144408.mp4', 'http://timg.bdta.pro/images/ad7725f10c6863303fcb9a50bf875f9a.jpg'),
(22604, 1543, 'Deus Me Adicionou S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144409.mp4', 'http://timg.bdta.pro/images/36f75583e323af0f5463a362b1340b52.jpg'),
(22605, 1543, 'Deus Me Adicionou S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/144410.mp4', 'http://timg.bdta.pro/images/4771acc33a84624cfa0b314215548d49.jpg'),
(22606, 1543, 'Deus Me Adicionou S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/144411.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22607, 1543, 'Deus Me Adicionou S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144412.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22608, 1544, 'Deus Me Adicionou S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144413.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22609, 1544, 'Deus Me Adicionou S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144414.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22610, 1544, 'Deus Me Adicionou S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144415.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22611, 1544, 'Deus Me Adicionou S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144416.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22612, 1544, 'Deus Me Adicionou S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144417.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22613, 1544, 'Deus Me Adicionou S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144418.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22614, 1544, 'Deus Me Adicionou S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144419.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22615, 1544, 'Deus Me Adicionou S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144420.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22616, 1544, 'Deus Me Adicionou S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144421.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22617, 1544, 'Deus Me Adicionou S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144422.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22618, 1544, 'Deus Me Adicionou S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144423.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22619, 1544, 'Deus Me Adicionou S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144424.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22620, 1544, 'Deus Me Adicionou S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144425.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22621, 1544, 'Deus Me Adicionou S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144426.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22622, 1544, 'Deus Me Adicionou S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144427.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22623, 1544, 'Deus Me Adicionou S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144428.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22624, 1544, 'Deus Me Adicionou S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144429.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22625, 1544, 'Deus Me Adicionou S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/144430.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22626, 1544, 'Deus Me Adicionou S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/144431.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22627, 1544, 'Deus Me Adicionou S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144432.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22628, 1544, 'Deus Me Adicionou S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/144433.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22629, 1544, 'Deus Me Adicionou S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/144434.mp4', 'http://gstaticontent.com/images/u2LsYYVniqK95fKHid85x2kngRT_big.jpg'),
(22630, 1545, 'Kipo E Os Animonstros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105895.mp4', 'http://timg.bdta.pro/images/31988371419beea7d398dc322d1208b6.jpg'),
(22631, 1545, 'Kipo E Os Animonstros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105896.mp4', 'http://timg.bdta.pro/images/50b829515689e83d5bf914c78e829d2b.jpg'),
(22632, 1545, 'Kipo E Os Animonstros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105897.mp4', 'http://timg.bdta.pro/images/5c800eb1041e9b0cb4acc19baead92b9.jpg'),
(22633, 1545, 'Kipo E Os Animonstros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105898.mp4', 'http://timg.bdta.pro/images/839c94ef095e128c24aba28607374c14.jpg'),
(22634, 1545, 'Kipo E Os Animonstros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105899.mp4', 'http://timg.bdta.pro/images/dfd3a837b6187bd1e1dfc3f40eddeadd.jpg'),
(22635, 1545, 'Kipo E Os Animonstros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105900.mp4', 'http://timg.bdta.pro/images/0d8973d0489f01d14d8b7abf0ec20812.jpg'),
(22636, 1545, 'Kipo E Os Animonstros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105901.mp4', 'http://timg.bdta.pro/images/336da1ea420e8db971111f0a6fdf3f09.jpg'),
(22637, 1545, 'Kipo E Os Animonstros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105902.mp4', 'http://timg.bdta.pro/images/455aad809fc675bb7bc4e20ed17ffb08.jpg'),
(22638, 1545, 'Kipo E Os Animonstros S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105903.mp4', 'http://timg.bdta.pro/images/c1c62c69d489e246b4d845dc35148506.jpg'),
(22639, 1545, 'Kipo E Os Animonstros S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105904.mp4', 'http://timg.bdta.pro/images/2f5cc08b8828f45b2a729db7c86cba28.jpg'),
(22640, 1546, 'Power S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170909.mp4', 'http://timg.bdta.pro/images/8ff43382c7be1416e13767dcd23047a8.jpg'),
(22641, 1546, 'Power S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170910.mp4', 'http://timg.bdta.pro/images/1c1397731b736e6d1f0e1977e00dcdec.jpg'),
(22642, 1546, 'Power S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170911.mp4', 'http://timg.bdta.pro/images/66b20f68d28de318acbbd523c9d76f93.jpg'),
(22643, 1546, 'Power S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170912.mp4', 'http://timg.bdta.pro/images/8d4854bd4b0a5c829ba9f44f173ea3ee.jpg'),
(22644, 1546, 'Power S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170913.mp4', 'http://timg.bdta.pro/images/6e765b34cb9014e41c6a4dd910301810.jpg'),
(22645, 1546, 'Power S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170914.mp4', 'http://timg.bdta.pro/images/65bfdbd3a07b7338dc3c35aea52a3970.jpg'),
(22646, 1546, 'Power S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170915.mp4', 'http://timg.bdta.pro/images/4fa4119de230c861d654a23f7d4c82f6.jpg'),
(22647, 1546, 'Power S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170916.mp4', 'http://timg.bdta.pro/images/3e38fbebee68cb8a7a1635f115ad7f8a.jpg'),
(22648, 1547, 'Power S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170917.mp4', 'http://timg.bdta.pro/images/6ff09a0dd5c7945b04dcc42501f12484.jpg'),
(22649, 1547, 'Power S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170918.mp4', 'http://timg.bdta.pro/images/83401c85be31356ce47f6a86cbaff3a2.jpg'),
(22650, 1547, 'Power S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170919.mp4', 'http://timg.bdta.pro/images/ee61e1187a345e415a05e91915bc7d90.jpg'),
(22651, 1547, 'Power S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170920.mp4', 'http://timg.bdta.pro/images/62563ca457e853e7fd79cebbe7c229c1.jpg'),
(22652, 1547, 'Power S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170921.mp4', 'http://timg.bdta.pro/images/f331a54a0563cc38ca95469d5e3f121a.jpg'),
(22653, 1547, 'Power S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170922.mp4', 'http://timg.bdta.pro/images/1056b8d611524ead29c8e2b4298893fb.jpg'),
(22654, 1547, 'Power S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170923.mp4', 'http://timg.bdta.pro/images/ee69bc36549d1cec67eb629e4490c6bf.jpg'),
(22655, 1547, 'Power S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170924.mp4', 'http://timg.bdta.pro/images/831da7d10ff16c95983d3a84639a0995.jpg'),
(22656, 1547, 'Power S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170925.mp4', 'http://timg.bdta.pro/images/45f8fb1bd9c28dc942df42c2990dbbd6.jpg'),
(22657, 1547, 'Power S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170926.mp4', 'http://timg.bdta.pro/images/91f1275599e98529d670aedd234a89d5.jpg'),
(22658, 1548, 'Power S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170927.mp4', 'http://timg.bdta.pro/images/e3f2334033051c23b13e148e69ab781f.jpg'),
(22659, 1548, 'Power S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170928.mp4', 'http://timg.bdta.pro/images/bd8b60106e02fb2c34db3001e058f3a6.jpg'),
(22660, 1548, 'Power S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170929.mp4', 'http://timg.bdta.pro/images/ce958c260a69884fc3850ae705d96462.jpg'),
(22661, 1548, 'Power S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170930.mp4', 'http://timg.bdta.pro/images/4ec5d075f9758f953ef34853a95cf957.jpg'),
(22662, 1548, 'Power S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170931.mp4', 'http://timg.bdta.pro/images/f7257f27b8e9dcfe5f5b501730a7f2c0.jpg'),
(22663, 1548, 'Power S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170932.mp4', 'http://timg.bdta.pro/images/b9e313cf4f042bff4520098579ef1cd4.jpg'),
(22664, 1548, 'Power S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170933.mp4', 'http://timg.bdta.pro/images/72d00000de14df2cc71749f787e8dfee.jpg'),
(22665, 1548, 'Power S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170934.mp4', 'http://timg.bdta.pro/images/258c8d51feb027c4639cd2f11c4161e8.jpg'),
(22666, 1548, 'Power S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170935.mp4', 'http://timg.bdta.pro/images/aa8f2f820c576a351302027715d9aa32.jpg'),
(22667, 1548, 'Power S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170936.mp4', 'http://timg.bdta.pro/images/4be376c05d3dbe6486b617aa684f5c98.jpg'),
(22668, 1549, 'Power S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170937.mp4', 'http://timg.bdta.pro/images/0ab5faa65dfa29a58965aaa3c0bf7c45.jpg'),
(22669, 1549, 'Power S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170938.mp4', 'http://timg.bdta.pro/images/7fd2666dc8b40b0744f447fb370d793d.jpg'),
(22670, 1549, 'Power S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170939.mp4', 'http://timg.bdta.pro/images/e7c4e9b2d3991cf34c1bd3eeeeadab17.jpg'),
(22671, 1549, 'Power S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170940.mp4', 'http://timg.bdta.pro/images/1d0e09662b88cedb066e860ece325ff7.jpg'),
(22672, 1549, 'Power S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170941.mp4', 'http://timg.bdta.pro/images/7235e79e0f70c71738e2f71d49e1e0be.jpg'),
(22673, 1549, 'Power S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170942.mp4', 'http://timg.bdta.pro/images/e0cc532880c05a5cff031e9499218154.jpg'),
(22674, 1549, 'Power S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170943.mp4', 'http://timg.bdta.pro/images/fb7f6f5fc9ae695017a5cd85d1936668.jpg'),
(22675, 1549, 'Power S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170944.mp4', 'http://timg.bdta.pro/images/9dfb47f017da2ca41d4048048ef16881.jpg'),
(22676, 1549, 'Power S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170945.mp4', 'http://timg.bdta.pro/images/236c4248b12f578d6222b37ced49e5b5.jpg'),
(22677, 1549, 'Power S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170946.mp4', 'http://timg.bdta.pro/images/75e0ba56670d45149eceb54e8b1dcc86.jpg'),
(22678, 1550, 'Power S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170947.mp4', 'http://timg.bdta.pro/images/75c22502cc62762af964983d83c8b2cb.jpg'),
(22679, 1550, 'Power S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170948.mp4', 'http://timg.bdta.pro/images/ca56ffca64ca746284b56049344d9ba2.jpg'),
(22680, 1550, 'Power S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170949.mp4', 'http://timg.bdta.pro/images/5f40d9f26db37ce242f7d50517a8cc68.jpg'),
(22681, 1550, 'Power S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170950.mp4', 'http://timg.bdta.pro/images/6a02d7c7bdc84344909b16c81f18dd9a.jpg'),
(22682, 1550, 'Power S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170951.mp4', 'http://timg.bdta.pro/images/3a49fbf5eafe15315c95d9031a05d2bb.jpg'),
(22683, 1550, 'Power S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170952.mp4', 'http://timg.bdta.pro/images/fa6789701c25dc635c576eed2227b216.jpg'),
(22684, 1550, 'Power S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170953.mp4', 'http://timg.bdta.pro/images/ba2c37a0930d29230222e55a6bbcf1f6.jpg'),
(22685, 1550, 'Power S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170954.mp4', 'http://timg.bdta.pro/images/a1969bffb42f795bdde60698300e9842.jpg'),
(22686, 1550, 'Power S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170955.mp4', 'http://timg.bdta.pro/images/e8d158d81bd4b4eaa3da13f1625a189c.jpg'),
(22687, 1550, 'Power S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170956.mp4', 'http://timg.bdta.pro/images/8c949101e3481f5946053afbaaa30f80.jpg'),
(22688, 1551, 'Power S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170957.mp4', 'http://timg.bdta.pro/images/7c4c6e4060de02c252752d8c60b621b8.jpg'),
(22689, 1551, 'Power S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170958.mp4', 'http://timg.bdta.pro/images/34fcbf90135b21260d38ba00bf94d74b.jpg'),
(22690, 1551, 'Power S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170959.mp4', 'http://timg.bdta.pro/images/1ee95fcbcd24bf8efc7004765da298c2.jpg'),
(22691, 1551, 'Power S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170960.mp4', 'http://timg.bdta.pro/images/ec0db4a62aca3d76f314306fb58d9e1a.jpg'),
(22692, 1551, 'Power S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170961.mp4', 'http://timg.bdta.pro/images/38ad08bfac1b1acf3eb1f3810e2e0e04.jpg'),
(22693, 1551, 'Power S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170962.mp4', 'http://timg.bdta.pro/images/6a9e68f70c1b47b6ebe7d6711a82074d.jpg'),
(22694, 1551, 'Power S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170963.mp4', 'http://timg.bdta.pro/images/58b39b67d943b9e8110bb3a212e27962.jpg'),
(22695, 1551, 'Power S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170964.mp4', 'http://timg.bdta.pro/images/7f8fdbe96a32e76723d332b252aa9103.jpg'),
(22696, 1551, 'Power S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170965.mp4', 'http://timg.bdta.pro/images/9d61310c920f16fbde74b861e4c36a1a.jpg'),
(22697, 1551, 'Power S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170966.mp4', 'http://timg.bdta.pro/images/def625e21c2bf5da60d03d72a48ce2c1.jpg'),
(22698, 1551, 'Power S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j6avAAWdWo1eOJUjTcmJgRW1hbL.jpg'),
(22699, 1551, 'Power S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zGI80XuXHFPPRf1x5tzSYJjyjHA.jpg'),
(22700, 1551, 'Power S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/170969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cXeyrUhGZVYe3D1QSqTiZtf7LPr.jpg'),
(22701, 1551, 'Power S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/170970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9IiETUktmiccpO4xPeq5voga7zK.jpg'),
(22702, 1551, 'Power S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/170971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A9ntIVQY6bwLnmEEIkCWa6H2T9u.jpg'),
(22703, 1552, 'Dude O Caopanheiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105887.mp4', 'http://gstaticontent.com/images/oM3TaNKBnq8O8cDcuhrDUtY6pDk_big.jpg'),
(22704, 1552, 'Dude O Caopanheiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105888.mp4', 'http://gstaticontent.com/images/oM3TaNKBnq8O8cDcuhrDUtY6pDk_big.jpg'),
(22705, 1552, 'Dude O Caopanheiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105889.mp4', 'http://gstaticontent.com/images/oM3TaNKBnq8O8cDcuhrDUtY6pDk_big.jpg'),
(22706, 1552, 'Dude O Caopanheiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105890.mp4', 'http://gstaticontent.com/images/oM3TaNKBnq8O8cDcuhrDUtY6pDk_big.jpg'),
(22707, 1552, 'Dude O Caopanheiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105891.mp4', 'http://gstaticontent.com/images/oM3TaNKBnq8O8cDcuhrDUtY6pDk_big.jpg'),
(22708, 1552, 'Dude O Caopanheiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105892.mp4', 'http://gstaticontent.com/images/oM3TaNKBnq8O8cDcuhrDUtY6pDk_big.jpg'),
(22709, 1552, 'Dude O Caopanheiro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105893.mp4', 'http://gstaticontent.com/images/oM3TaNKBnq8O8cDcuhrDUtY6pDk_big.jpg'),
(22710, 1552, 'Dude O Caopanheiro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105894.mp4', 'http://gstaticontent.com/images/oM3TaNKBnq8O8cDcuhrDUtY6pDk_big.jpg'),
(22711, 1553, 'Truth Be Told S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208785.mp4', 'http://timg.bdta.pro/images/10308e04c6a8c5eccc3a2bad6676e279.jpg'),
(22712, 1553, 'Truth Be Told S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208786.mp4', 'http://timg.bdta.pro/images/cf1ba5de0da806d27dc56d38a6a469d4.jpg'),
(22713, 1553, 'Truth Be Told S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208787.mp4', 'http://timg.bdta.pro/images/6cb8aedb229042a612c3d34912f95f4a.jpg'),
(22714, 1553, 'Truth Be Told S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208788.mp4', 'http://timg.bdta.pro/images/aabdc0fb1695a31231d58aad77804bcd.jpg'),
(22715, 1553, 'Truth Be Told S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208789.mp4', 'http://timg.bdta.pro/images/0a53f0a0dcce40f6d2170b0563bea7d6.jpg'),
(22716, 1553, 'Truth Be Told S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208790.mp4', 'http://timg.bdta.pro/images/9cb98f696e3d3d0ee8b83549f7a63a47.jpg'),
(22717, 1553, 'Truth Be Told S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208791.mp4', 'http://timg.bdta.pro/images/aacb5ab1cc0ef32066de114d30295c43.jpg'),
(22718, 1553, 'Truth Be Told S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208792.mp4', 'http://timg.bdta.pro/images/c1dd73f9fd4f73b908695c4d84d3f8dc.jpg'),
(22719, 1554, 'Truth Be Told S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fzURHZBMq5Lr1Ez6PZy8iBDjwFn.jpg'),
(22720, 1554, 'Truth Be Told S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Yw7LEG5zUi3uaXZ9HinATkcYQG.jpg'),
(22721, 1554, 'Truth Be Told S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1skaIoJXZaVdSQIz89tszDO32Aj.jpg'),
(22722, 1554, 'Truth Be Told S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8JYOgZTj7TNdM5wR8TlFNkcsZdE.jpg'),
(22723, 1554, 'Truth Be Told S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZ0iI33Q7ghe1PtVmKxigKuGZf.jpg'),
(22724, 1554, 'Truth Be Told S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dMc9JaClUTKktfgrYyZYRknF0hj.jpg'),
(22725, 1554, 'Truth Be Told S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ehg3eXyNEYA7OWiB9YWTd0VyYEU.jpg'),
(22726, 1554, 'Truth Be Told S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jvxvQd6lNtartoi7xJGbgFDBvKt.jpg'),
(22727, 1554, 'Truth Be Told S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zZduboUqisx9tZhqWguyrz6fnuq.jpg'),
(22728, 1554, 'Truth Be Told S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Alx2t1qzL2tjjzhYizwBJx45G7L.jpg'),
(22729, 1555, 'Truth Be Told S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208803.mp4', 'http://image.tmdb.org/t/p/w1280/bnLPmor1sQmtCaYZZ57UslJjR4R.jpg'),
(22730, 1555, 'Truth Be Told S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208804.mp4', 'http://image.tmdb.org/t/p/w1280/p2C1OuwZKW7RC3JHpsojkJARAXh.jpg'),
(22731, 1555, 'Truth Be Told S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208805.mp4', 'http://image.tmdb.org/t/p/w1280/dVRrSXu1M09o2daZsjw8OuTkoNd.jpg'),
(22732, 1555, 'Truth Be Told S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208806.mp4', 'http://image.tmdb.org/t/p/w1280/twwqe41FBbVSbfKSGLiWVGMlY6l.jpg'),
(22733, 1555, 'Truth Be Told S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208807.mp4', 'http://image.tmdb.org/t/p/w1280/8kSpP9hmpSVC21E24gcEDodwuDk.jpg'),
(22734, 1555, 'Truth Be Told S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208808.mp4', 'http://image.tmdb.org/t/p/w1280/9utIgv8tlLFspZbb8qANh1iSCQb.jpg'),
(22735, 1555, 'Truth Be Told S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208809.mp4', 'http://image.tmdb.org/t/p/w1280/zaZ64Cjnpwywt2pECHTYZlirGtP.jpg'),
(22736, 1555, 'Truth Be Told S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208810.mp4', 'http://image.tmdb.org/t/p/w1280/c7Q6i6xRQqQOedjUcJ5GgH9a4nX.jpg'),
(22737, 1555, 'Truth Be Told S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208811.mp4', 'http://image.tmdb.org/t/p/w1280/ccWrL6P4z8QRVON2i9LHb9Lb1YG.jpg'),
(22738, 1555, 'Truth Be Told S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208812.mp4', 'http://image.tmdb.org/t/p/w1280/qYdj8LAPEZythQZ1EXwgD9VRF9H.jpg'),
(22739, 1556, 'Ray Donovan S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172372.mp4', 'http://timg.bdta.pro/images/bed7ac198ebe12bbd8cb3ae8191643c5.jpg'),
(22740, 1556, 'Ray Donovan S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172373.mp4', 'http://timg.bdta.pro/images/9ba5908b78fe52eaf52a43aa77936e46.jpg'),
(22741, 1556, 'Ray Donovan S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172374.mp4', 'http://timg.bdta.pro/images/5ebd3ffe7ee5830e6194540225d34011.jpg'),
(22742, 1556, 'Ray Donovan S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172375.mp4', 'http://timg.bdta.pro/images/2c650b39707d7051e6092d0f418013ee.jpg'),
(22743, 1556, 'Ray Donovan S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172376.mp4', 'http://timg.bdta.pro/images/b22d2b3cdd797c2a4f0dfe38cd43090d.jpg'),
(22744, 1556, 'Ray Donovan S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172377.mp4', 'http://timg.bdta.pro/images/fde23f5575bf4a60d50590e835d043d6.jpg'),
(22745, 1556, 'Ray Donovan S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172378.mp4', 'http://timg.bdta.pro/images/de687a8290af4d4df43d77be1a22ab7f.jpg'),
(22746, 1556, 'Ray Donovan S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172379.mp4', 'http://timg.bdta.pro/images/9d0443f47a585fd6de1ebf1819c5e0e8.jpg'),
(22747, 1556, 'Ray Donovan S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172380.mp4', 'http://timg.bdta.pro/images/0666f3805431babfb68f13d4f793fc75.jpg'),
(22748, 1556, 'Ray Donovan S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172381.mp4', 'http://timg.bdta.pro/images/979544d6b9fac5d952bff0c88171fb36.jpg'),
(22749, 1556, 'Ray Donovan S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172382.mp4', 'http://timg.bdta.pro/images/874eec9e751af9a5bfc728f43af82eab.jpg'),
(22750, 1556, 'Ray Donovan S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172383.mp4', 'http://timg.bdta.pro/images/98776c00ffac51469a3eff76f185d81f.jpg'),
(22751, 1557, 'Ray Donovan S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172384.mp4', 'http://timg.bdta.pro/images/a7921e1c11acf98bef0221c74887ddf4.jpg'),
(22752, 1557, 'Ray Donovan S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172385.mp4', 'http://timg.bdta.pro/images/79d19bc50209b158ced59e4f81ef490f.jpg'),
(22753, 1557, 'Ray Donovan S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172386.mp4', 'http://timg.bdta.pro/images/3ad73021fc53eb5b1d8a88452b534b68.jpg'),
(22754, 1557, 'Ray Donovan S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172387.mp4', 'http://timg.bdta.pro/images/15100f48fb6fda1692f8bf492471ce6a.jpg'),
(22755, 1557, 'Ray Donovan S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172388.mp4', 'http://timg.bdta.pro/images/6d201970a63d228b07bfb1d2c4b0b933.jpg'),
(22756, 1557, 'Ray Donovan S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172389.mp4', 'http://timg.bdta.pro/images/81a0d284ff68a1bcd977c920fb69840f.jpg'),
(22757, 1557, 'Ray Donovan S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172390.mp4', 'http://timg.bdta.pro/images/7c99ddd683daf471cc4bf47b3f7b1f67.jpg'),
(22758, 1557, 'Ray Donovan S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172391.mp4', 'http://timg.bdta.pro/images/50a95042beae6811dbe2877645ab62a2.jpg'),
(22759, 1557, 'Ray Donovan S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172392.mp4', 'http://timg.bdta.pro/images/1dc42817514cc086cdbcea63bbe0b423.jpg'),
(22760, 1557, 'Ray Donovan S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172393.mp4', 'http://timg.bdta.pro/images/28b12aefce1697ba33c8baeba6794a5b.jpg'),
(22761, 1557, 'Ray Donovan S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172394.mp4', 'http://timg.bdta.pro/images/00a34fea8303f671dafb6fbd66915a3c.jpg'),
(22762, 1557, 'Ray Donovan S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172395.mp4', 'http://timg.bdta.pro/images/b73bcc2341887fbe647ab6950d9fce4b.jpg'),
(22763, 1558, 'Ray Donovan S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172396.mp4', 'http://timg.bdta.pro/images/2334fef0c0fc684393fc0787cab61ef1.jpg'),
(22764, 1558, 'Ray Donovan S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172397.mp4', 'http://timg.bdta.pro/images/9ea9e8964e546fc8b58b90c3fc750dcc.jpg'),
(22765, 1558, 'Ray Donovan S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172398.mp4', 'http://timg.bdta.pro/images/50b767cd55d18cf14f7b85d2b98db949.jpg'),
(22766, 1558, 'Ray Donovan S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172399.mp4', 'http://timg.bdta.pro/images/e93647f10e9fe0a0ac05290915dc74b1.jpg'),
(22767, 1558, 'Ray Donovan S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172400.mp4', 'http://timg.bdta.pro/images/66b5429bb29b115c3f44baf0a0605443.jpg'),
(22768, 1558, 'Ray Donovan S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172401.mp4', 'http://timg.bdta.pro/images/635e8de46c5e1a5898eb69a08e38c9a5.jpg'),
(22769, 1558, 'Ray Donovan S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172402.mp4', 'http://timg.bdta.pro/images/e6a14c5e344d1d267a1b88f0d816cb23.jpg'),
(22770, 1558, 'Ray Donovan S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172403.mp4', 'http://timg.bdta.pro/images/e6685558329aca07c2f2d10f683b13ac.jpg'),
(22771, 1558, 'Ray Donovan S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172404.mp4', 'http://timg.bdta.pro/images/5e00a224f7a3e4ac55186ebeb3227047.jpg'),
(22772, 1558, 'Ray Donovan S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172405.mp4', 'http://timg.bdta.pro/images/b03781879b75b18dd8de30ef5206e523.jpg'),
(22773, 1558, 'Ray Donovan S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172406.mp4', 'http://timg.bdta.pro/images/8d37869d3d9f1bcafb553f667923bc4e.jpg'),
(22774, 1558, 'Ray Donovan S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172407.mp4', 'http://timg.bdta.pro/images/55e41ac2acdb3d934f28d3b50813eeb0.jpg'),
(22775, 1559, 'Ray Donovan S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172408.mp4', 'http://timg.bdta.pro/images/720df1d42d43244658eaf9032ddbc09c.jpg'),
(22776, 1559, 'Ray Donovan S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172409.mp4', 'http://timg.bdta.pro/images/4baf7cd03f5de5b6c05c834f8ba6e331.jpg'),
(22777, 1559, 'Ray Donovan S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172410.mp4', 'http://timg.bdta.pro/images/78dae65263af09a176619f0b79ee4288.jpg'),
(22778, 1559, 'Ray Donovan S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172411.mp4', 'http://timg.bdta.pro/images/0a90f66f848415b0147abe35ed78f60a.jpg'),
(22779, 1559, 'Ray Donovan S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172412.mp4', 'http://timg.bdta.pro/images/34a967c5e58c07c7e9599addb838b699.jpg'),
(22780, 1559, 'Ray Donovan S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172413.mp4', 'http://timg.bdta.pro/images/a3625b540c174c9d32c6d243c54b66b7.jpg'),
(22781, 1559, 'Ray Donovan S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172414.mp4', 'http://timg.bdta.pro/images/423265ba5b76cae2f6acb4d7c4bacfd7.jpg'),
(22782, 1559, 'Ray Donovan S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172415.mp4', 'http://timg.bdta.pro/images/1e3db10a005fcf2d468b61be4ebb6a5a.jpg'),
(22783, 1559, 'Ray Donovan S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172416.mp4', 'http://timg.bdta.pro/images/24d38abf7602896c3036e913cc562e22.jpg'),
(22784, 1559, 'Ray Donovan S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172417.mp4', 'http://timg.bdta.pro/images/c5321b16df97d665aa5bf46eaf9d311a.jpg'),
(22785, 1559, 'Ray Donovan S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172418.mp4', 'http://timg.bdta.pro/images/e8863dee3c8a6d2ea6e51fb768e13de4.jpg'),
(22786, 1559, 'Ray Donovan S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172419.mp4', 'http://timg.bdta.pro/images/334ddebc7bcae8b055bbe55e417046df.jpg'),
(22787, 1560, 'Ray Donovan S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172420.mp4', 'http://timg.bdta.pro/images/fd1ab3632402054ed31cb2b90b97849a.jpg'),
(22788, 1560, 'Ray Donovan S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172421.mp4', 'http://timg.bdta.pro/images/8dd9e1df931e7becc8315f5732d0c60e.jpg'),
(22789, 1560, 'Ray Donovan S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172422.mp4', 'http://timg.bdta.pro/images/7d4cd991202c830e2d97dfb38098c352.jpg'),
(22790, 1560, 'Ray Donovan S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172423.mp4', 'http://timg.bdta.pro/images/5f30df32a48102e22cf804e3f7913975.jpg'),
(22791, 1560, 'Ray Donovan S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172424.mp4', 'http://timg.bdta.pro/images/9c059238acd1408c8383d7b8b3aeeee1.jpg'),
(22792, 1560, 'Ray Donovan S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172425.mp4', 'http://timg.bdta.pro/images/619c7f81c3691083cbe10502a3816152.jpg'),
(22793, 1560, 'Ray Donovan S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172426.mp4', 'http://timg.bdta.pro/images/a3c9ac736d8898aa4f2d223b338a0874.jpg'),
(22794, 1560, 'Ray Donovan S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172427.mp4', 'http://timg.bdta.pro/images/77dd0363717f852b557a7e763495363f.jpg'),
(22795, 1560, 'Ray Donovan S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172428.mp4', 'http://timg.bdta.pro/images/662f63c5c722d869fdea02d448917c19.jpg'),
(22796, 1560, 'Ray Donovan S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172429.mp4', 'http://timg.bdta.pro/images/25b4b0b4264bfe88d832313d9bd43935.jpg'),
(22797, 1560, 'Ray Donovan S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172430.mp4', 'http://timg.bdta.pro/images/c852c38ceb4a08cec1982438f25eb2c4.jpg'),
(22798, 1560, 'Ray Donovan S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172431.mp4', 'http://timg.bdta.pro/images/3036c491ec504e798d200e6236eaf5a4.jpg'),
(22799, 1561, 'Ray Donovan S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172432.mp4', 'http://timg.bdta.pro/images/b44d9aaadd08d965807903a19bbaabc8.jpg'),
(22800, 1561, 'Ray Donovan S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172433.mp4', 'http://timg.bdta.pro/images/095092b6723b35a75b65f7f070cdffef.jpg'),
(22801, 1561, 'Ray Donovan S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172434.mp4', 'http://timg.bdta.pro/images/d832ec433d4ee4381a9fd1d2f9c5fd2a.jpg'),
(22802, 1561, 'Ray Donovan S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172435.mp4', 'http://timg.bdta.pro/images/47a0843e90dde99b2d32dae0d9bac347.jpg'),
(22803, 1561, 'Ray Donovan S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172436.mp4', 'http://timg.bdta.pro/images/70c997e9e2c983b1101cae52e39f4a97.jpg'),
(22804, 1561, 'Ray Donovan S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172437.mp4', 'http://timg.bdta.pro/images/f1af023aa5a99120e5530b1fef1323f5.jpg'),
(22805, 1561, 'Ray Donovan S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172438.mp4', 'http://timg.bdta.pro/images/b8bc34572f7449b7d2ad95aa3925f03f.jpg'),
(22806, 1561, 'Ray Donovan S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172439.mp4', 'http://gstaticontent.com/images/a3aR1VcaqP4nG3khMjMUu0Berhl_big.jpg'),
(22807, 1561, 'Ray Donovan S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172440.mp4', 'http://gstaticontent.com/images/a3aR1VcaqP4nG3khMjMUu0Berhl_big.jpg'),
(22808, 1561, 'Ray Donovan S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172441.mp4', 'http://gstaticontent.com/images/a3aR1VcaqP4nG3khMjMUu0Berhl_big.jpg'),
(22809, 1561, 'Ray Donovan S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172442.mp4', 'http://gstaticontent.com/images/a3aR1VcaqP4nG3khMjMUu0Berhl_big.jpg'),
(22810, 1561, 'Ray Donovan S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172443.mp4', 'http://gstaticontent.com/images/a3aR1VcaqP4nG3khMjMUu0Berhl_big.jpg'),
(22811, 1562, 'Ray Donovan S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172444.mp4', 'http://timg.bdta.pro/images/ec9d2a95f93c7cc23e32bdaad1637988.jpg'),
(22812, 1562, 'Ray Donovan S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172445.mp4', 'http://timg.bdta.pro/images/64eeae59d0587f2080399edfe83a355d.jpg'),
(22813, 1562, 'Ray Donovan S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172446.mp4', 'http://timg.bdta.pro/images/c07c271404c968f6749a9614357d3172.jpg'),
(22814, 1562, 'Ray Donovan S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172447.mp4', 'http://timg.bdta.pro/images/cbb2b500aa314fa58b688a968415344a.jpg'),
(22815, 1562, 'Ray Donovan S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172448.mp4', 'http://timg.bdta.pro/images/b63d8240cbde1b4fcc5116f8b010fe96.jpg'),
(22816, 1562, 'Ray Donovan S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172449.mp4', 'http://timg.bdta.pro/images/b1957bea14c662284dea2cb164659cc2.jpg'),
(22817, 1562, 'Ray Donovan S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172450.mp4', 'http://timg.bdta.pro/images/3b46e4292da3af92548b855e5b7229cd.jpg'),
(22818, 1562, 'Ray Donovan S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172451.mp4', 'http://timg.bdta.pro/images/f103e11b14d1049498cfe0ead6a5299b.jpg'),
(22819, 1562, 'Ray Donovan S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172452.mp4', 'http://timg.bdta.pro/images/af5543df6cddb7237d86fe19757e9796.jpg'),
(22820, 1562, 'Ray Donovan S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172453.mp4', 'http://timg.bdta.pro/images/23e336c7f3194cf557985aa14e5ae3f8.jpg'),
(22821, 1563, 'One Strange Rock S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105866.mp4', 'http://timg.bdta.pro/images/7ad6eafbb1bebfc79e65e6a149210f1e.jpg'),
(22822, 1563, 'One Strange Rock S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105867.mp4', 'http://timg.bdta.pro/images/7643a341015fbdfc9c43e12f2829b058.jpg'),
(22823, 1563, 'One Strange Rock S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105868.mp4', 'http://timg.bdta.pro/images/88dbf50586cfc3ab1c3053f8f3ad8c8f.jpg'),
(22824, 1563, 'One Strange Rock S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105869.mp4', 'http://timg.bdta.pro/images/7b27bb42d810390000df2e60568c7e43.jpg'),
(22825, 1563, 'One Strange Rock S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105870.mp4', 'http://timg.bdta.pro/images/d5b340ece0a7910428caeb1dd994eb57.jpg'),
(22826, 1563, 'One Strange Rock S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105871.mp4', 'http://timg.bdta.pro/images/89f91a27c55f3dda4047fb677ae69a08.jpg'),
(22827, 1563, 'One Strange Rock S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105872.mp4', 'http://timg.bdta.pro/images/0f27c775de117d476cf73aaddeff0362.jpg'),
(22828, 1563, 'One Strange Rock S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105873.mp4', 'http://timg.bdta.pro/images/1e662187d51c150b7390176eb955b366.jpg'),
(22829, 1563, 'One Strange Rock S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105874.mp4', 'http://timg.bdta.pro/images/926fff01d8dea3cd505dd70938583f64.jpg'),
(22830, 1563, 'One Strange Rock S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105875.mp4', 'http://timg.bdta.pro/images/605ff352dc5b2f29abe26448fcbba749.jpg'),
(22831, 1564, 'Patrulha Medica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105856.mp4', 'http://timg.bdta.pro/images/8a806940ff69cb90b93ab98c5746edaa.jpg'),
(22832, 1564, 'Patrulha Medica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105857.mp4', 'http://timg.bdta.pro/images/aa81694dcd4c69b01e13325726091c7c.jpg'),
(22833, 1564, 'Patrulha Medica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105858.mp4', 'http://timg.bdta.pro/images/6aca4081190502266df40de3b61f9069.jpg'),
(22834, 1564, 'Patrulha Medica S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105859.mp4', 'http://timg.bdta.pro/images/451fcae3c0c8964d899cf39ff775f820.jpg'),
(22835, 1564, 'Patrulha Medica S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105860.mp4', 'http://timg.bdta.pro/images/0f4495752c31e60f267884fe22982449.jpg'),
(22836, 1564, 'Patrulha Medica S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105861.mp4', 'http://timg.bdta.pro/images/67fff83e75f417262fb164cb0c95e19d.jpg'),
(22837, 1564, 'Patrulha Medica S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105862.mp4', 'http://timg.bdta.pro/images/73ffb416e7f1b50fafcd9565002517d1.jpg'),
(22838, 1564, 'Patrulha Medica S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105863.mp4', 'http://timg.bdta.pro/images/61b289df244eedd1654b9018c981f00b.jpg'),
(22839, 1564, 'Patrulha Medica S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105864.mp4', 'http://timg.bdta.pro/images/d1ff47989b0e77a5a805df6d40febb44.jpg'),
(22840, 1564, 'Patrulha Medica S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105865.mp4', 'http://timg.bdta.pro/images/53c1abbd8dd096a949c6ba9b2e30e6c9.jpg'),
(22841, 1565, 'Giri/Haji S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105848.mp4', 'http://timg.bdta.pro/images/c3af66f26f5590b6332454c3f1461afc.jpg'),
(22842, 1565, 'Giri/Haji S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105849.mp4', 'http://timg.bdta.pro/images/000de0e96209af1da13aa52d2f26e5cc.jpg'),
(22843, 1565, 'Giri/Haji S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105850.mp4', 'http://timg.bdta.pro/images/9dfe480730c04edb7cc142fc439f3273.jpg'),
(22844, 1565, 'Giri/Haji S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105851.mp4', 'http://timg.bdta.pro/images/aaab310e2a227a9239aecfc87ab92edc.jpg'),
(22845, 1565, 'Giri/Haji S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105852.mp4', 'http://timg.bdta.pro/images/3066588f9205dfa2eac3006c0b2aeaa9.jpg'),
(22846, 1565, 'Giri/Haji S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105853.mp4', 'http://timg.bdta.pro/images/cffa77eb6921adc725829ff26d0931d5.jpg'),
(22847, 1565, 'Giri/Haji S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105854.mp4', 'http://timg.bdta.pro/images/e5794ac8ac9b394917166d17122a5811.jpg'),
(22848, 1565, 'Giri/Haji S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105855.mp4', 'http://timg.bdta.pro/images/9feea2b3e9792b2866379fa85a7c857e.jpg'),
(22849, 1566, 'Clique S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105658.mp4', 'http://gstaticontent.com/images/4xvuHbroZNZlp2QHvGpmc6gI8dv_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(22850, 1566, 'Clique S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105659.mp4', 'http://gstaticontent.com/images/4xvuHbroZNZlp2QHvGpmc6gI8dv_big.jpg'),
(22851, 1566, 'Clique S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105660.mp4', 'http://gstaticontent.com/images/4xvuHbroZNZlp2QHvGpmc6gI8dv_big.jpg'),
(22852, 1566, 'Clique S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105661.mp4', 'http://gstaticontent.com/images/4xvuHbroZNZlp2QHvGpmc6gI8dv_big.jpg'),
(22853, 1566, 'Clique S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105662.mp4', 'http://gstaticontent.com/images/4xvuHbroZNZlp2QHvGpmc6gI8dv_big.jpg'),
(22854, 1566, 'Clique S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105663.mp4', 'http://gstaticontent.com/images/4xvuHbroZNZlp2QHvGpmc6gI8dv_big.jpg'),
(22855, 1567, 'Clique S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105664.mp4', 'http://gstaticontent.com/images/4xvuHbroZNZlp2QHvGpmc6gI8dv_big.jpg'),
(22856, 1567, 'Clique S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105665.mp4', 'http://gstaticontent.com/images/4xvuHbroZNZlp2QHvGpmc6gI8dv_big.jpg'),
(22857, 1567, 'Clique S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105666.mp4', 'http://gstaticontent.com/images/4xvuHbroZNZlp2QHvGpmc6gI8dv_big.jpg'),
(22858, 1567, 'Clique S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105667.mp4', 'http://gstaticontent.com/images/4xvuHbroZNZlp2QHvGpmc6gI8dv_big.jpg'),
(22859, 1567, 'Clique S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105668.mp4', 'http://gstaticontent.com/images/4xvuHbroZNZlp2QHvGpmc6gI8dv_big.jpg'),
(22860, 1567, 'Clique S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105669.mp4', 'http://gstaticontent.com/images/4xvuHbroZNZlp2QHvGpmc6gI8dv_big.jpg'),
(22861, 1568, 'AJ and the Queen S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105838.mp4', 'http://timg.bdta.pro/images/50a61e88d4c33eb2128e483b05076d76.jpg'),
(22862, 1568, 'AJ and the Queen S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105839.mp4', 'http://timg.bdta.pro/images/297098844876f512b5c0960221b5d2b1.jpg'),
(22863, 1568, 'AJ and the Queen S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105840.mp4', 'http://timg.bdta.pro/images/0ce6af1eb3315ef96c398d096e31ab20.jpg'),
(22864, 1568, 'AJ and the Queen S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105841.mp4', 'http://timg.bdta.pro/images/4137ff71b88da8675fc859db241847a3.jpg'),
(22865, 1568, 'AJ and the Queen S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105842.mp4', 'http://timg.bdta.pro/images/1c6a8c4ea8599b88d33f4bcaaddf0f79.jpg'),
(22866, 1568, 'AJ and the Queen S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105843.mp4', 'http://timg.bdta.pro/images/da1d8db5c60879701bac16242de941e9.jpg'),
(22867, 1568, 'AJ and the Queen S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105844.mp4', 'http://timg.bdta.pro/images/789688dd85153900d2c69dee9a3e4fe3.jpg'),
(22868, 1568, 'AJ and the Queen S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105845.mp4', 'http://timg.bdta.pro/images/3030f113ad36ae4e276b4c6f25c5dd5c.jpg'),
(22869, 1568, 'AJ and the Queen S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105846.mp4', 'http://timg.bdta.pro/images/bea65c0ead76a3091722d63373af69a4.jpg'),
(22870, 1568, 'AJ and the Queen S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105847.mp4', 'http://timg.bdta.pro/images/6b32d316bf83947a42e73af12ddd2ee7.jpg'),
(22871, 1569, 'Ares S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105830.mp4', 'http://timg.bdta.pro/images/0a50b6ac113a8f8bc28642c0a41ef834.jpg'),
(22872, 1569, 'Ares S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105831.mp4', 'http://timg.bdta.pro/images/0d0dc37c86b97ffc5ce5384934db8bb4.jpg'),
(22873, 1569, 'Ares S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105832.mp4', 'http://timg.bdta.pro/images/f7da4dbbee4085ab66ed8dacaf573752.jpg'),
(22874, 1569, 'Ares S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105833.mp4', 'http://timg.bdta.pro/images/d355e6ea9dafc79d8f03b2c05394265e.jpg'),
(22875, 1569, 'Ares S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105834.mp4', 'http://timg.bdta.pro/images/77d5bc52d0f801c74ae3ac38fcd28266.jpg'),
(22876, 1569, 'Ares S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105835.mp4', 'http://timg.bdta.pro/images/b7dfe308f5f930ed30b87f6d65f27ca8.jpg'),
(22877, 1569, 'Ares S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105836.mp4', 'http://timg.bdta.pro/images/ddf5bd68728a6675067c1a18d29ff1c4.jpg'),
(22878, 1569, 'Ares S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105837.mp4', 'http://timg.bdta.pro/images/1c94f13517d3ecdd1656bdc7ba1aeb3a.jpg'),
(22879, 1570, 'Little America S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105822.mp4', 'http://timg.bdta.pro/images/dfbf4fc0696899c30c5ba8e96a5130ce.jpg'),
(22880, 1570, 'Little America S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105823.mp4', 'http://timg.bdta.pro/images/59c98793a81fbf42a353617f5af1864c.jpg'),
(22881, 1570, 'Little America S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105824.mp4', 'http://timg.bdta.pro/images/1f4c75f7559ad50364c466a90023b4cc.jpg'),
(22882, 1570, 'Little America S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105825.mp4', 'http://timg.bdta.pro/images/989d25028d97ffe4b969cd60711e7ef2.jpg'),
(22883, 1570, 'Little America S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105826.mp4', 'http://timg.bdta.pro/images/81adfb106ca32542bfd5dd9dab94580c.jpg'),
(22884, 1570, 'Little America S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105827.mp4', 'http://timg.bdta.pro/images/f42c7531182abac0a9af52f7fe464af0.jpg'),
(22885, 1570, 'Little America S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105828.mp4', 'http://timg.bdta.pro/images/c9e4e276db5a863a3fbd1e4d5af3810a.jpg'),
(22886, 1570, 'Little America S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105829.mp4', 'http://timg.bdta.pro/images/0556b9d61c6cbb6a50be8c2d9d63aaa5.jpg'),
(22887, 1571, 'Avatar: A Lenda De Korra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105770.mp4', 'http://timg.bdta.pro/images/a08acd7e5953e3c3a0d89f2c4211c748.jpg'),
(22888, 1571, 'Avatar: A Lenda De Korra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105771.mp4', 'http://timg.bdta.pro/images/f50675639a9b60f90a0505b7ea770ec7.jpg'),
(22889, 1571, 'Avatar: A Lenda De Korra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105772.mp4', 'http://timg.bdta.pro/images/5b7041105d559c2b1284ca8fee92ce51.jpg'),
(22890, 1571, 'Avatar: A Lenda De Korra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105773.mp4', 'http://timg.bdta.pro/images/1c8148c3c1e3ea647437c22c020a45c1.jpg'),
(22891, 1571, 'Avatar: A Lenda De Korra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105774.mp4', 'http://timg.bdta.pro/images/2497860dacd2722f8b43fa57d800d437.jpg'),
(22892, 1571, 'Avatar: A Lenda De Korra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105775.mp4', 'http://timg.bdta.pro/images/201654fdb8c1a010939b5ee32ad42dac.jpg'),
(22893, 1571, 'Avatar: A Lenda De Korra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105776.mp4', 'http://timg.bdta.pro/images/7bc16cf4f890c337eee9733eb74a8904.jpg'),
(22894, 1571, 'Avatar: A Lenda De Korra S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105777.mp4', 'http://timg.bdta.pro/images/9a096cea8621fdc3e9f24cc2677f3a88.jpg'),
(22895, 1571, 'Avatar: A Lenda De Korra S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105778.mp4', 'http://timg.bdta.pro/images/13f81bde4bbbe0c9acab4d6930b40470.jpg'),
(22896, 1571, 'Avatar: A Lenda De Korra S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105779.mp4', 'http://timg.bdta.pro/images/c178863b51de8e4c414c0fdee8400585.jpg'),
(22897, 1571, 'Avatar: A Lenda De Korra S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105780.mp4', 'http://timg.bdta.pro/images/41d1f10204ad4e477b4d4bb12f170d4b.jpg'),
(22898, 1571, 'Avatar: A Lenda De Korra S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105781.mp4', 'http://timg.bdta.pro/images/f9ae7f67e1f9cf44880279906376a696.jpg'),
(22899, 1572, 'Avatar: A Lenda De Korra S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105782.mp4', 'http://timg.bdta.pro/images/cbca300dc5ec9b95c1f736e9f880bb6a.jpg'),
(22900, 1572, 'Avatar: A Lenda De Korra S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105783.mp4', 'http://timg.bdta.pro/images/fa5c45fabe98cf4a613fdea1bf544bca.jpg'),
(22901, 1572, 'Avatar: A Lenda De Korra S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105784.mp4', 'http://timg.bdta.pro/images/c726913e42f66b2f146f96a981846eb5.jpg'),
(22902, 1572, 'Avatar: A Lenda De Korra S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105785.mp4', 'http://timg.bdta.pro/images/3c2c04b371172328992a5a3f71b2cddd.jpg'),
(22903, 1572, 'Avatar: A Lenda De Korra S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105786.mp4', 'http://timg.bdta.pro/images/176b32aa55456076211db885492a374b.jpg'),
(22904, 1572, 'Avatar: A Lenda De Korra S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105787.mp4', 'http://timg.bdta.pro/images/7710d0bf676f33cd190792f53e016284.jpg'),
(22905, 1572, 'Avatar: A Lenda De Korra S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105788.mp4', 'http://timg.bdta.pro/images/29b76a7e21d048d89db822360fab4a84.jpg'),
(22906, 1572, 'Avatar: A Lenda De Korra S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105789.mp4', 'http://timg.bdta.pro/images/a4eef9eb8b10b5cfbda8227d3cd3f4c9.jpg'),
(22907, 1572, 'Avatar: A Lenda De Korra S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105790.mp4', 'http://timg.bdta.pro/images/ccb980f946d430ed8a2995f854f582e4.jpg'),
(22908, 1572, 'Avatar: A Lenda De Korra S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105791.mp4', 'http://timg.bdta.pro/images/3af18f8ee8cbdfd4e3ceda200a9e4e5c.jpg'),
(22909, 1572, 'Avatar: A Lenda De Korra S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105792.mp4', 'http://timg.bdta.pro/images/558d111000887e16837fc12a9f588acf.jpg'),
(22910, 1572, 'Avatar: A Lenda De Korra S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105793.mp4', 'http://timg.bdta.pro/images/dd45ce0820a1b115db0c16aae2cf7af2.jpg'),
(22911, 1572, 'Avatar: A Lenda De Korra S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/105794.mp4', 'http://timg.bdta.pro/images/e86b169b200fa9249cdf8a4b62fb0fbc.jpg'),
(22912, 1572, 'Avatar: A Lenda De Korra S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/105795.mp4', 'http://timg.bdta.pro/images/8c8cb1e66a2cbe3fea0ed0b861c01e93.jpg'),
(22913, 1573, 'Avatar: A Lenda De Korra S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105796.mp4', 'http://timg.bdta.pro/images/7ea96f5228c57e365cb351b186929030.jpg'),
(22914, 1573, 'Avatar: A Lenda De Korra S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105797.mp4', 'http://timg.bdta.pro/images/91fd2c28552ac1953d98643f655f8e39.jpg'),
(22915, 1573, 'Avatar: A Lenda De Korra S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105798.mp4', 'http://timg.bdta.pro/images/78bfb5e086d34fe678c41c1ebb14ebe6.jpg'),
(22916, 1573, 'Avatar: A Lenda De Korra S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105799.mp4', 'http://timg.bdta.pro/images/5603545a62d7e2fcf7c1fb7fea03cfaf.jpg'),
(22917, 1573, 'Avatar: A Lenda De Korra S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105800.mp4', 'http://timg.bdta.pro/images/295ae131dcf3a6347ee345cab2e1738e.jpg'),
(22918, 1573, 'Avatar: A Lenda De Korra S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105801.mp4', 'http://timg.bdta.pro/images/0eb0325d41a56ba10b53e01d51c10d93.jpg'),
(22919, 1573, 'Avatar: A Lenda De Korra S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105802.mp4', 'http://timg.bdta.pro/images/86ee9ff9e5ece31d0ca76828815afe15.jpg'),
(22920, 1573, 'Avatar: A Lenda De Korra S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105803.mp4', 'http://timg.bdta.pro/images/e203e7b28665d0a562af800690c962b3.jpg'),
(22921, 1573, 'Avatar: A Lenda De Korra S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105804.mp4', 'http://timg.bdta.pro/images/c85558ae621c25fa1ed74bae26e1bb6a.jpg'),
(22922, 1573, 'Avatar: A Lenda De Korra S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105805.mp4', 'http://timg.bdta.pro/images/1779db8d0d54f547ebc9621e1b2a5df9.jpg'),
(22923, 1573, 'Avatar: A Lenda De Korra S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105806.mp4', 'http://timg.bdta.pro/images/7473583e0b5ddb0cc0477234f18f1c1e.jpg'),
(22924, 1573, 'Avatar: A Lenda De Korra S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105807.mp4', 'http://timg.bdta.pro/images/69f32c71de2354e5b59f02e154ffcede.jpg'),
(22925, 1573, 'Avatar: A Lenda De Korra S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/105808.mp4', 'http://timg.bdta.pro/images/580278c28aaaeb08290293160a455335.jpg'),
(22926, 1574, 'Avatar: A Lenda De Korra S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105809.mp4', 'http://timg.bdta.pro/images/f8ed08a52c052156dca08716d6b5080d.jpg'),
(22927, 1574, 'Avatar: A Lenda De Korra S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105810.mp4', 'http://timg.bdta.pro/images/465ed0b3597220f3a80cac53220869cf.jpg'),
(22928, 1574, 'Avatar: A Lenda De Korra S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105811.mp4', 'http://timg.bdta.pro/images/d36a55f7a6777ac8d639e399552b58e5.jpg'),
(22929, 1574, 'Avatar: A Lenda De Korra S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105812.mp4', 'http://timg.bdta.pro/images/09ce8b5d1c91cc0cb425cf1c8f7c76ae.jpg'),
(22930, 1574, 'Avatar: A Lenda De Korra S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105813.mp4', 'http://timg.bdta.pro/images/1e58d1f98ac166b02dc979d26028b16f.jpg'),
(22931, 1574, 'Avatar: A Lenda De Korra S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105814.mp4', 'http://timg.bdta.pro/images/ef06f0b52e8525b445005c78ed2b2871.jpg'),
(22932, 1574, 'Avatar: A Lenda De Korra S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105815.mp4', 'http://timg.bdta.pro/images/c299ecb5cbbd43848f96a99a08cf1ec2.jpg'),
(22933, 1574, 'Avatar: A Lenda De Korra S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105816.mp4', 'http://timg.bdta.pro/images/7acb9e000d33e6c0d8977c9001913269.jpg'),
(22934, 1574, 'Avatar: A Lenda De Korra S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105817.mp4', 'http://timg.bdta.pro/images/c439cf2d39dc18f151e6e8e4d3b58a8d.jpg'),
(22935, 1574, 'Avatar: A Lenda De Korra S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105818.mp4', 'http://timg.bdta.pro/images/c0854786af0e9b98d2d96b07b99a2a81.jpg'),
(22936, 1574, 'Avatar: A Lenda De Korra S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105819.mp4', 'http://timg.bdta.pro/images/2d84ec788f7250cd1ff76229943f8963.jpg'),
(22937, 1574, 'Avatar: A Lenda De Korra S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105820.mp4', 'http://timg.bdta.pro/images/27894ba47bd2bc905253d9f08fe46d46.jpg'),
(22938, 1574, 'Avatar: A Lenda De Korra S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/105821.mp4', 'http://timg.bdta.pro/images/db47f76f4b32af4df8d27e8f7f6d5d48.jpg'),
(22939, 1575, 'Arrow S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108016.mp4', 'http://timg.bdta.pro/images/4f29448f61103b5c7b11d96aab67b464.jpg'),
(22940, 1575, 'Arrow S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108017.mp4', 'http://timg.bdta.pro/images/fe6d01c09657e85621cf619494746869.jpg'),
(22941, 1575, 'Arrow S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108018.mp4', 'http://timg.bdta.pro/images/e9eac3f3aaea70a5470e8d43bf78b240.jpg'),
(22942, 1575, 'Arrow S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108019.mp4', 'http://timg.bdta.pro/images/d93c279f50fc7db8d0f1ea9c570983c9.jpg'),
(22943, 1575, 'Arrow S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108020.mp4', 'http://timg.bdta.pro/images/a1185bcec51b91f9fb425d6dd4934d44.jpg'),
(22944, 1575, 'Arrow S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108021.mp4', 'http://timg.bdta.pro/images/f4e8d5f1d68800c58f093172fbaac399.jpg'),
(22945, 1575, 'Arrow S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108022.mp4', 'http://timg.bdta.pro/images/b572cd83c896915c2cb986f720f42bfb.jpg'),
(22946, 1575, 'Arrow S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108023.mp4', 'http://timg.bdta.pro/images/04e7c312b3e2e84171a66954ca5ca4b3.jpg'),
(22947, 1575, 'Arrow S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108024.mp4', 'http://timg.bdta.pro/images/8bfbcf2c5d83fe9a5c15a86f16cc15f6.jpg'),
(22948, 1575, 'Arrow S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108025.mp4', 'http://timg.bdta.pro/images/8356d55eeb08c46594449632bda609f1.jpg'),
(22949, 1575, 'Arrow S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108026.mp4', 'http://timg.bdta.pro/images/cf26b13cab0fe09778ef9898966fa28f.jpg'),
(22950, 1575, 'Arrow S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108027.mp4', 'http://timg.bdta.pro/images/dc5861b970f62084b62799393bbd9b48.jpg'),
(22951, 1575, 'Arrow S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108028.mp4', 'http://timg.bdta.pro/images/dde5fe8ab18c699e1af42576f56374e9.jpg'),
(22952, 1575, 'Arrow S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108029.mp4', 'http://timg.bdta.pro/images/10921a062287f100f40f1ed157258b98.jpg'),
(22953, 1575, 'Arrow S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108030.mp4', 'http://timg.bdta.pro/images/384d8523a69c93670df9769bf93504b3.jpg'),
(22954, 1575, 'Arrow S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108031.mp4', 'http://timg.bdta.pro/images/0ace6a504009636a751ab772ef2ed326.jpg'),
(22955, 1575, 'Arrow S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108032.mp4', 'http://timg.bdta.pro/images/4cddbf088d130656873983c7759053f6.jpg'),
(22956, 1575, 'Arrow S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108033.mp4', 'http://timg.bdta.pro/images/593c5e0a8d0046a1523f44cc8784c86a.jpg'),
(22957, 1575, 'Arrow S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108034.mp4', 'http://timg.bdta.pro/images/f7a4c70cb130ff84e7242fea71f9d892.jpg'),
(22958, 1575, 'Arrow S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108035.mp4', 'http://timg.bdta.pro/images/a12d1e45b56126e3025dfb383fe41158.jpg'),
(22959, 1575, 'Arrow S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/108036.mp4', 'http://timg.bdta.pro/images/9cbd07518e41196cdc1bc82f6be21c83.jpg'),
(22960, 1575, 'Arrow S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/108037.mp4', 'http://timg.bdta.pro/images/70088d928a7dd0e70df8de65b3816926.jpg'),
(22961, 1575, 'Arrow S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/108038.mp4', 'http://timg.bdta.pro/images/b9d46b3dd9641497548913d75a5f38ff.jpg'),
(22962, 1576, 'Arrow S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108039.mp4', 'http://timg.bdta.pro/images/ef2113760c793f9106a4cde66b9645a8.jpg'),
(22963, 1576, 'Arrow S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108040.mp4', 'http://timg.bdta.pro/images/74b0818647b58101420fb256267fac84.jpg'),
(22964, 1576, 'Arrow S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108041.mp4', 'http://timg.bdta.pro/images/e2f16700a874ff8dde4f49e471bbd67b.jpg'),
(22965, 1576, 'Arrow S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108042.mp4', 'http://timg.bdta.pro/images/bea1ad7a522ad292b00a3f2966c92fce.jpg'),
(22966, 1576, 'Arrow S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108043.mp4', 'http://timg.bdta.pro/images/91bc546ddeccf760c4b220be858a390f.jpg'),
(22967, 1576, 'Arrow S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108044.mp4', 'http://timg.bdta.pro/images/1d5f92e27be3c0f79fe793e41aba6ec0.jpg'),
(22968, 1576, 'Arrow S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108045.mp4', 'http://timg.bdta.pro/images/2771848db068e8873b0e693b8029d0d0.jpg'),
(22969, 1576, 'Arrow S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108046.mp4', 'http://timg.bdta.pro/images/cce6ad63e4de223462267b6fd06c4841.jpg'),
(22970, 1576, 'Arrow S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108047.mp4', 'http://timg.bdta.pro/images/44246b38f7f1ce9eeb4086366c4097d8.jpg'),
(22971, 1576, 'Arrow S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108048.mp4', 'http://timg.bdta.pro/images/34357d67d12d25dde90b840902753e05.jpg'),
(22972, 1576, 'Arrow S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108049.mp4', 'http://timg.bdta.pro/images/beb21cce9d994142b9a326a180c1cea6.jpg'),
(22973, 1576, 'Arrow S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108050.mp4', 'http://timg.bdta.pro/images/31d13a392e19dff19bdf5793cdafff71.jpg'),
(22974, 1576, 'Arrow S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108051.mp4', 'http://timg.bdta.pro/images/96582d8d600d68dc78c3889a82edd8c6.jpg'),
(22975, 1576, 'Arrow S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108052.mp4', 'http://timg.bdta.pro/images/caeadb9d1a0a98811082876d1ed0a778.jpg'),
(22976, 1576, 'Arrow S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108053.mp4', 'http://timg.bdta.pro/images/0b2911ce6fe6c502bf5472385bdfdf79.jpg'),
(22977, 1576, 'Arrow S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108054.mp4', 'http://timg.bdta.pro/images/c1c88cb231c53f4b5e15d60caac82706.jpg'),
(22978, 1576, 'Arrow S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108055.mp4', 'http://timg.bdta.pro/images/3b7079258af38447ec97181acab2713a.jpg'),
(22979, 1576, 'Arrow S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108056.mp4', 'http://timg.bdta.pro/images/0cc52cfc46213785fc76acca0258aefe.jpg'),
(22980, 1576, 'Arrow S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108057.mp4', 'http://timg.bdta.pro/images/d7637ace03736691c6e4bd32a57c5031.jpg'),
(22981, 1576, 'Arrow S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108058.mp4', 'http://timg.bdta.pro/images/30e0993a8a64b489ed9a0994d5198c53.jpg'),
(22982, 1576, 'Arrow S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/108059.mp4', 'http://timg.bdta.pro/images/e1b2e1042856bec7c92af5f97f34137c.jpg'),
(22983, 1576, 'Arrow S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/108060.mp4', 'http://timg.bdta.pro/images/ea6cba7bd8c602d5c5ca836c262002f9.jpg'),
(22984, 1576, 'Arrow S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/108061.mp4', 'http://timg.bdta.pro/images/b92e9d20c73b6d0ae642cd16e568f69f.jpg'),
(22985, 1577, 'Arrow S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108062.mp4', 'http://timg.bdta.pro/images/3830eadda2bf151d99c6a1d722ac7e9b.jpg'),
(22986, 1577, 'Arrow S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108063.mp4', 'http://timg.bdta.pro/images/5fbb051065c2576ffa32959f55fd0088.jpg'),
(22987, 1577, 'Arrow S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108064.mp4', 'http://timg.bdta.pro/images/06a5a0b987517decff5432940ed80abb.jpg'),
(22988, 1577, 'Arrow S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108065.mp4', 'http://timg.bdta.pro/images/eced7bf1fabdf783ef596ed6b11b161e.jpg'),
(22989, 1577, 'Arrow S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108066.mp4', 'http://timg.bdta.pro/images/2705efa8ea7d87cd70fd85c664ce0f54.jpg'),
(22990, 1577, 'Arrow S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108067.mp4', 'http://timg.bdta.pro/images/a26a19e083b5054a9705727ae0e7dbd4.jpg'),
(22991, 1577, 'Arrow S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108068.mp4', 'http://timg.bdta.pro/images/531f431f152f8c20a3c0dbd8f3a3395f.jpg'),
(22992, 1577, 'Arrow S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108069.mp4', 'http://timg.bdta.pro/images/33519ffe2d8645f32ee49d3d10363ff3.jpg'),
(22993, 1577, 'Arrow S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108070.mp4', 'http://timg.bdta.pro/images/3aff65896994f3f7ac88c3cfff79c946.jpg'),
(22994, 1577, 'Arrow S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108071.mp4', 'http://timg.bdta.pro/images/cad046ef4ed5f515c39e79a4a54327bd.jpg'),
(22995, 1577, 'Arrow S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108072.mp4', 'http://timg.bdta.pro/images/f94415ff0d89517e080b46efe3317065.jpg'),
(22996, 1577, 'Arrow S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108073.mp4', 'http://timg.bdta.pro/images/1f3107c764768ab716db1626e887b8ba.jpg'),
(22997, 1577, 'Arrow S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108074.mp4', 'http://timg.bdta.pro/images/89c016cc209cec2fce09f13402ff9955.jpg'),
(22998, 1577, 'Arrow S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108075.mp4', 'http://timg.bdta.pro/images/5f5bf81ab0dc8153fcfe65290fe3b112.jpg'),
(22999, 1577, 'Arrow S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108076.mp4', 'http://timg.bdta.pro/images/23a5851acfd94a0da8d0fea04feb702d.jpg'),
(23000, 1577, 'Arrow S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108077.mp4', 'http://timg.bdta.pro/images/712a171dc5c713083c06b61250afbd92.jpg'),
(23001, 1577, 'Arrow S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108078.mp4', 'http://timg.bdta.pro/images/948da1d87d59364982d34a5225e512f8.jpg'),
(23002, 1577, 'Arrow S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108079.mp4', 'http://timg.bdta.pro/images/6e7d5f6de8e099c17ba403e3489437c3.jpg'),
(23003, 1577, 'Arrow S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108080.mp4', 'http://timg.bdta.pro/images/98adba2daa9491f016e8739889190ef8.jpg'),
(23004, 1577, 'Arrow S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108081.mp4', 'http://timg.bdta.pro/images/a2b4c60d2dd40b5637e4ddfaa872ceed.jpg'),
(23005, 1577, 'Arrow S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/108082.mp4', 'http://timg.bdta.pro/images/55506740a849644b4edbdb69cb8a1ba7.jpg'),
(23006, 1577, 'Arrow S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/108083.mp4', 'http://timg.bdta.pro/images/29ce954b1353ac29018c5a6fed292d6f.jpg'),
(23007, 1577, 'Arrow S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/108084.mp4', 'http://timg.bdta.pro/images/8e58d55a1cdbbbb547912a1d6c915438.jpg'),
(23008, 1578, 'Arrow S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108085.mp4', 'http://timg.bdta.pro/images/f8be4d0a13e9e0c55173daf5c843ee71.jpg'),
(23009, 1578, 'Arrow S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108086.mp4', 'http://timg.bdta.pro/images/e7a89a1f8ec26e744d0b81bc570902c1.jpg'),
(23010, 1578, 'Arrow S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108087.mp4', 'http://timg.bdta.pro/images/9b07ae3285ba408cc0b942b0fcce467b.jpg'),
(23011, 1578, 'Arrow S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108088.mp4', 'http://timg.bdta.pro/images/eb0eca7d718ec5e961e562f8f7745f0d.jpg'),
(23012, 1578, 'Arrow S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108089.mp4', 'http://timg.bdta.pro/images/c67c47a9765faa659ada2812f3a44c79.jpg'),
(23013, 1578, 'Arrow S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108090.mp4', 'http://timg.bdta.pro/images/54521ecb271c3f3151f92dc7fea913b8.jpg'),
(23014, 1578, 'Arrow S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108091.mp4', 'http://timg.bdta.pro/images/8bf8c8849be23d8a47d3ce92860c7bc5.jpg'),
(23015, 1578, 'Arrow S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108092.mp4', 'http://timg.bdta.pro/images/11d6938a85e4266cdacaca328df96215.jpg'),
(23016, 1578, 'Arrow S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108093.mp4', 'http://timg.bdta.pro/images/6dc144981237547d3f61dee7ad55ae44.jpg'),
(23017, 1578, 'Arrow S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108094.mp4', 'http://timg.bdta.pro/images/6760c754a733a7f9f2c85de06b95ca2d.jpg'),
(23018, 1578, 'Arrow S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108095.mp4', 'http://timg.bdta.pro/images/2863aad27db5d681ebb320581a5dae92.jpg'),
(23019, 1578, 'Arrow S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108096.mp4', 'http://timg.bdta.pro/images/510386f2aa2dfe81c322d3cc889f310f.jpg'),
(23020, 1578, 'Arrow S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108097.mp4', 'http://timg.bdta.pro/images/f027b65942938d1963585695093e3c29.jpg'),
(23021, 1578, 'Arrow S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108098.mp4', 'http://timg.bdta.pro/images/b57ba93530327dc4b5374eb1983135dd.jpg'),
(23022, 1578, 'Arrow S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108099.mp4', 'http://timg.bdta.pro/images/ab7a2e6dcd43cafb2f0ff0317744cbef.jpg'),
(23023, 1578, 'Arrow S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108100.mp4', 'http://timg.bdta.pro/images/743a958e87a64ffd93954217af4e4d9a.jpg'),
(23024, 1578, 'Arrow S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108101.mp4', 'http://timg.bdta.pro/images/3e6dccbc9579860a31c9a3bd8e40e06e.jpg'),
(23025, 1578, 'Arrow S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108102.mp4', 'http://timg.bdta.pro/images/7af73d137284887c10f81af57fdde0b5.jpg'),
(23026, 1578, 'Arrow S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108103.mp4', 'http://timg.bdta.pro/images/1af6aa08ef309f341396e5b429c0daaa.jpg'),
(23027, 1578, 'Arrow S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108104.mp4', 'http://timg.bdta.pro/images/d31b56320e9f10aaaa2a7cb142e1cf5e.jpg'),
(23028, 1578, 'Arrow S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/108105.mp4', 'http://timg.bdta.pro/images/b0cbf40872dc18eaf9a198bed4b44637.jpg'),
(23029, 1578, 'Arrow S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/108106.mp4', 'http://timg.bdta.pro/images/2e8d6ddca948cde151912df427b328f2.jpg'),
(23030, 1578, 'Arrow S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/108107.mp4', 'http://timg.bdta.pro/images/6eb5750b66bbe1fb3d1e2c8ce6c81be7.jpg'),
(23031, 1579, 'Arrow S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108108.mp4', 'http://timg.bdta.pro/images/47b7d39fb1007b29ad6759219e74b7c6.jpg'),
(23032, 1579, 'Arrow S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108109.mp4', 'http://timg.bdta.pro/images/c09ec56a8865bc4288b350d551b0e402.jpg'),
(23033, 1579, 'Arrow S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108110.mp4', 'http://timg.bdta.pro/images/9d96af68f5f545024ea4641bd9d5397a.jpg'),
(23034, 1579, 'Arrow S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108111.mp4', 'http://timg.bdta.pro/images/2cbbb779e6d0654917adcbae9365b554.jpg'),
(23035, 1579, 'Arrow S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108112.mp4', 'http://timg.bdta.pro/images/ae6ebeabc49ae38240585b8b0fce44a2.jpg'),
(23036, 1579, 'Arrow S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108113.mp4', 'http://timg.bdta.pro/images/dd869e99c0b021ae4a2c5a3b73154487.jpg'),
(23037, 1579, 'Arrow S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108114.mp4', 'http://timg.bdta.pro/images/cd83ae91b6228fdef3553ee9c14ef3d7.jpg'),
(23038, 1579, 'Arrow S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108115.mp4', 'http://timg.bdta.pro/images/1539f53742bae4c0d60c02e4e349af4a.jpg'),
(23039, 1579, 'Arrow S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108116.mp4', 'http://timg.bdta.pro/images/a8f03dba892c519b2a886680124b87f3.jpg'),
(23040, 1579, 'Arrow S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108117.mp4', 'http://timg.bdta.pro/images/f574cf6377748a8b3b26af46eee46095.jpg'),
(23041, 1579, 'Arrow S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108118.mp4', 'http://timg.bdta.pro/images/06edbe8cd722bbc96b608e9c0d1ae01b.jpg'),
(23042, 1579, 'Arrow S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108119.mp4', 'http://timg.bdta.pro/images/e3fb44e8275651fb54c8a3518a461a35.jpg'),
(23043, 1579, 'Arrow S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108120.mp4', 'http://timg.bdta.pro/images/5b1984013c8a6c0a3f596e32b20d0552.jpg'),
(23044, 1579, 'Arrow S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108121.mp4', 'http://timg.bdta.pro/images/546a7961c467a225302deca471629dde.jpg'),
(23045, 1579, 'Arrow S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108122.mp4', 'http://timg.bdta.pro/images/15050f49d432564c77d541973d682ba1.jpg'),
(23046, 1579, 'Arrow S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108123.mp4', 'http://timg.bdta.pro/images/795e5768cbdb9b8b5df2d083ddbe9e6f.jpg'),
(23047, 1579, 'Arrow S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108124.mp4', 'http://timg.bdta.pro/images/6186e343d78f47f7ee13069221115a22.jpg'),
(23048, 1579, 'Arrow S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108125.mp4', 'http://timg.bdta.pro/images/f24939dd87f35bbcfc1c1d2fab127ab8.jpg'),
(23049, 1579, 'Arrow S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108126.mp4', 'http://timg.bdta.pro/images/264635b37009a7b0841e32a142c64390.jpg'),
(23050, 1579, 'Arrow S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108127.mp4', 'http://timg.bdta.pro/images/ea3121f5d292c9b310c1f46da8374bbc.jpg'),
(23051, 1579, 'Arrow S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/108128.mp4', 'http://timg.bdta.pro/images/b080399958f167ff36e368204de3fa65.jpg'),
(23052, 1579, 'Arrow S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/108129.mp4', 'http://timg.bdta.pro/images/fc67d407900860d3b872cd3c1839fe5f.jpg'),
(23053, 1579, 'Arrow S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/108130.mp4', 'http://timg.bdta.pro/images/be93e4490e816bcef110b67203a6a3ad.jpg'),
(23054, 1580, 'Arrow S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108131.mp4', 'http://timg.bdta.pro/images/64834b505351165266d3c113f67a72a3.jpg'),
(23055, 1580, 'Arrow S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108132.mp4', 'http://timg.bdta.pro/images/1a27793e3f36f68280ee0168da1b7dd8.jpg'),
(23056, 1580, 'Arrow S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108133.mp4', 'http://timg.bdta.pro/images/654c33fafb33902a635257b9ff663ad4.jpg'),
(23057, 1580, 'Arrow S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108134.mp4', 'http://timg.bdta.pro/images/d4d338721bd8b7c23bf5ddac71fc6daf.jpg'),
(23058, 1580, 'Arrow S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108135.mp4', 'http://timg.bdta.pro/images/c34f725ada0be572b434d489fca6b29f.jpg'),
(23059, 1580, 'Arrow S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108136.mp4', 'http://timg.bdta.pro/images/2f3ba8ce759d95ae7b6f5f9e95493583.jpg'),
(23060, 1580, 'Arrow S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108137.mp4', 'http://timg.bdta.pro/images/6685931ef43ca62d82f0a2112ea25dc9.jpg'),
(23061, 1580, 'Arrow S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108138.mp4', 'http://timg.bdta.pro/images/86741b72a10218d1f3a9069da6260278.jpg'),
(23062, 1580, 'Arrow S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108139.mp4', 'http://timg.bdta.pro/images/11422a8f2009656c710d1103f704c528.jpg'),
(23063, 1580, 'Arrow S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108140.mp4', 'http://timg.bdta.pro/images/a6c144dc99ef0bf0fa13ac9db8bd1a0b.jpg'),
(23064, 1580, 'Arrow S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108141.mp4', 'http://timg.bdta.pro/images/cdfbbb3a73aea9698130fbbb029adc9b.jpg'),
(23065, 1580, 'Arrow S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108142.mp4', 'http://timg.bdta.pro/images/3e09c18d203385dfcca58e3f1c07d045.jpg'),
(23066, 1580, 'Arrow S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108143.mp4', 'http://timg.bdta.pro/images/ef0ff7602dff382b1ed68a2bf989abe8.jpg'),
(23067, 1580, 'Arrow S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108144.mp4', 'http://timg.bdta.pro/images/9813495b9c8215eeddf764d3095ea2e8.jpg'),
(23068, 1580, 'Arrow S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108145.mp4', 'http://timg.bdta.pro/images/807c660ca37a2e3550a13490ecf3d5d2.jpg'),
(23069, 1580, 'Arrow S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108146.mp4', 'http://timg.bdta.pro/images/b52e95405b6554cdfb3f261247bd817b.jpg'),
(23070, 1580, 'Arrow S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108147.mp4', 'http://timg.bdta.pro/images/f7a5e484476ca8f28f578e20ec6bff1c.jpg'),
(23071, 1580, 'Arrow S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108148.mp4', 'http://timg.bdta.pro/images/c99c4edaa7c2b1eb2f184bbfae615043.jpg'),
(23072, 1580, 'Arrow S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108149.mp4', 'http://timg.bdta.pro/images/9c14d8a62bbb59aa5a6753eb3ac7cd34.jpg'),
(23073, 1580, 'Arrow S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108150.mp4', 'http://timg.bdta.pro/images/82c4b139d364b13f86d514a04d4476cb.jpg'),
(23074, 1580, 'Arrow S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/108151.mp4', 'http://timg.bdta.pro/images/63ba2bfb8a42d365e086c58a1b627a3e.jpg'),
(23075, 1580, 'Arrow S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/108152.mp4', 'http://timg.bdta.pro/images/df91ea8891d498e37cfef80013e660c6.jpg'),
(23076, 1580, 'Arrow S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/108153.mp4', 'http://timg.bdta.pro/images/2eee19ce899e956df43b8f732c3d0299.jpg'),
(23077, 1581, 'Arrow S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108154.mp4', 'http://timg.bdta.pro/images/22b9447ae515e5d139a3a2475c97993f.jpg'),
(23078, 1581, 'Arrow S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108155.mp4', 'http://timg.bdta.pro/images/bf7b6b7e6712ce839bc52bd3a1a7cf13.jpg'),
(23079, 1581, 'Arrow S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108156.mp4', 'http://timg.bdta.pro/images/0797b54da60155911889e0a4370493d3.jpg'),
(23080, 1581, 'Arrow S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108157.mp4', 'http://timg.bdta.pro/images/b93fdba892b9ce1696de41e786480186.jpg'),
(23081, 1581, 'Arrow S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108158.mp4', 'http://timg.bdta.pro/images/7c3f850885bab2f4982745aeacd37985.jpg'),
(23082, 1581, 'Arrow S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108159.mp4', 'http://timg.bdta.pro/images/79de90dde35f2649fb955f6b9527875b.jpg'),
(23083, 1581, 'Arrow S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108160.mp4', 'http://timg.bdta.pro/images/ec453700b1cb84e562128858a39d9ed4.jpg'),
(23084, 1581, 'Arrow S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108161.mp4', 'http://timg.bdta.pro/images/de9d378b3d77e040ea264bb18c348bab.jpg'),
(23085, 1581, 'Arrow S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108162.mp4', 'http://timg.bdta.pro/images/945eb413ef4b3b131600e5d7950723b6.jpg'),
(23086, 1581, 'Arrow S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108163.mp4', 'http://timg.bdta.pro/images/486354c69e5f57d1965ee1b27b62145f.jpg'),
(23087, 1581, 'Arrow S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108164.mp4', 'http://timg.bdta.pro/images/d123bf0b1933aa8cfe9193fd24a839dd.jpg'),
(23088, 1581, 'Arrow S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108165.mp4', 'http://timg.bdta.pro/images/d12307ae93d70da39fdc0623b63195e3.jpg'),
(23089, 1581, 'Arrow S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108166.mp4', 'http://timg.bdta.pro/images/30911236a212e4402fc07d6d98a1287f.jpg'),
(23090, 1581, 'Arrow S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108167.mp4', 'http://timg.bdta.pro/images/d79ec42455233e9730c1a172207436c8.jpg'),
(23091, 1581, 'Arrow S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108168.mp4', 'http://timg.bdta.pro/images/e3a23dc0b2a200c7967d42cae48b191c.jpg'),
(23092, 1581, 'Arrow S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108169.mp4', 'http://timg.bdta.pro/images/b04ab765c76b226efec84fa811e5ed27.jpg'),
(23093, 1581, 'Arrow S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108170.mp4', 'http://timg.bdta.pro/images/a4b6ab38ccfa6b846879501670f24ce4.jpg'),
(23094, 1581, 'Arrow S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108171.mp4', 'http://timg.bdta.pro/images/a78be4a074cd56ef56bf0ee28927f3cd.jpg'),
(23095, 1581, 'Arrow S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108172.mp4', 'http://timg.bdta.pro/images/174e00c9a1317660fdf9e9795692ff5f.jpg'),
(23096, 1581, 'Arrow S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108173.mp4', 'http://timg.bdta.pro/images/922a18699d532be3cc8cc72e122fb745.jpg'),
(23097, 1581, 'Arrow S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/108174.mp4', 'http://timg.bdta.pro/images/cf46b222ba4cad963cb57a3926579cc8.jpg'),
(23098, 1581, 'Arrow S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/108175.mp4', 'http://timg.bdta.pro/images/8f95432540af121f532d9c3cfb7e940d.jpg'),
(23099, 1582, 'Arrow S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108176.mp4', 'http://timg.bdta.pro/images/5918ae5a031b59d95d5b4196b7184e3e.jpg'),
(23100, 1582, 'Arrow S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108177.mp4', 'http://timg.bdta.pro/images/43f2eaa2d82edca627eb331a75c5fb20.jpg'),
(23101, 1582, 'Arrow S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108178.mp4', 'http://timg.bdta.pro/images/09f6a4beac0069549c6722b7afd18d4f.jpg'),
(23102, 1582, 'Arrow S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108179.mp4', 'http://timg.bdta.pro/images/3375164feae13a216b967a025c83f6d7.jpg'),
(23103, 1582, 'Arrow S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108180.mp4', 'http://timg.bdta.pro/images/19491710b904b54e22767777ebf04cd9.jpg'),
(23104, 1582, 'Arrow S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108181.mp4', 'http://timg.bdta.pro/images/8047c088ecb8cb44d7c764eac43a0ff8.jpg'),
(23105, 1582, 'Arrow S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108182.mp4', 'http://timg.bdta.pro/images/e10a522f9fb826a4adbb7ec9146586cc.jpg'),
(23106, 1582, 'Arrow S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108183.mp4', 'http://timg.bdta.pro/images/e2065919176944765939722e87154ef7.jpg'),
(23107, 1582, 'Arrow S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108184.mp4', 'http://timg.bdta.pro/images/03d0ede9c1f186137d44ddfe5168c601.jpg'),
(23108, 1582, 'Arrow S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108185.mp4', 'http://timg.bdta.pro/images/c653f7437f17182cc3f22d26db5da274.jpg'),
(23109, 1583, 'Me Encontra em Paris S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174730.mp4', 'http://timg.bdta.pro/images/fea314cedd895bb74c40e5e88af609db.jpg'),
(23110, 1583, 'Me Encontra em Paris S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174731.mp4', 'http://timg.bdta.pro/images/f6cefdcf835522fc6d5fa7c5f4ba60ff.jpg'),
(23111, 1583, 'Me Encontra em Paris S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174732.mp4', 'http://timg.bdta.pro/images/0205772b5af4949b699432476c7d1378.jpg'),
(23112, 1583, 'Me Encontra em Paris S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174733.mp4', 'http://timg.bdta.pro/images/ddf473df905be3a6f1bdda53b9b28cf7.jpg'),
(23113, 1583, 'Me Encontra em Paris S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174734.mp4', 'http://timg.bdta.pro/images/f4fa549e8d6d5a2905fe4a035bed98a8.jpg'),
(23114, 1583, 'Me Encontra em Paris S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174735.mp4', 'http://timg.bdta.pro/images/521f431bb2b57d43be285867e9133bfc.jpg'),
(23115, 1583, 'Me Encontra em Paris S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174736.mp4', 'http://timg.bdta.pro/images/6a2bab4b717ebd5a1f7fca56caa51ea8.jpg'),
(23116, 1583, 'Me Encontra em Paris S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174737.mp4', 'http://timg.bdta.pro/images/f1b31ef0666937e6b883cefe5b98e7f9.jpg'),
(23117, 1583, 'Me Encontra em Paris S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174738.mp4', 'http://timg.bdta.pro/images/9b0142dcb891194dea724fc05ebe6c75.jpg'),
(23118, 1583, 'Me Encontra em Paris S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174739.mp4', 'http://timg.bdta.pro/images/a3ff8f34d39aad69ca4b3f6c3b1cdedb.jpg'),
(23119, 1583, 'Me Encontra em Paris S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/174740.mp4', 'http://timg.bdta.pro/images/c9eb4834a49d0c4d4ed0e54fc8ef1fbf.jpg'),
(23120, 1583, 'Me Encontra em Paris S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/174741.mp4', 'http://timg.bdta.pro/images/a5cf5304e852f04b332c2627cf771f94.jpg'),
(23121, 1583, 'Me Encontra em Paris S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/174742.mp4', 'http://timg.bdta.pro/images/bd50af5ed7297fddf0b5dcc2100ec1e7.jpg'),
(23122, 1583, 'Me Encontra em Paris S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/174743.mp4', 'http://timg.bdta.pro/images/23d48e0717d8a2f31e4b8b69ef6f29e0.jpg'),
(23123, 1583, 'Me Encontra em Paris S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/174744.mp4', 'http://timg.bdta.pro/images/eadb38f24b38dc9e63073898e4912ab3.jpg'),
(23124, 1583, 'Me Encontra em Paris S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/174745.mp4', 'http://timg.bdta.pro/images/989ec275e6527022a1aca16dd6c3c964.jpg'),
(23125, 1583, 'Me Encontra em Paris S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/174746.mp4', 'http://timg.bdta.pro/images/88629f394040b8e9d4fe2474c69bab7e.jpg'),
(23126, 1583, 'Me Encontra em Paris S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/174747.mp4', 'http://timg.bdta.pro/images/dd5e6f4a4eb009acf990042d05925278.jpg'),
(23127, 1583, 'Me Encontra em Paris S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/174748.mp4', 'http://timg.bdta.pro/images/b5afe7fb1c6f0c2124427988916d3105.jpg'),
(23128, 1583, 'Me Encontra em Paris S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/174749.mp4', 'http://timg.bdta.pro/images/26b23538ad7974f75d983be1c6cb8598.jpg'),
(23129, 1583, 'Me Encontra em Paris S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/174750.mp4', 'http://timg.bdta.pro/images/480da47c68bee75548f0343d39fba53b.jpg'),
(23130, 1583, 'Me Encontra em Paris S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/174751.mp4', 'http://timg.bdta.pro/images/045a34462c9c49e181568acbec22343e.jpg'),
(23131, 1583, 'Me Encontra em Paris S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/174752.mp4', 'http://timg.bdta.pro/images/b2d50ddae9ed2386fbff733d4c46b533.jpg'),
(23132, 1583, 'Me Encontra em Paris S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/174753.mp4', 'http://timg.bdta.pro/images/856d4b98b4e2c7439d2d10e1448b6255.jpg'),
(23133, 1583, 'Me Encontra em Paris S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/174754.mp4', 'http://gstaticontent.com/images/13T3LlQp2aRpKl6l1cZF1lXzpnT_big.jpg'),
(23134, 1583, 'Me Encontra em Paris S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/174755.mp4', 'http://gstaticontent.com/images/13T3LlQp2aRpKl6l1cZF1lXzpnT_big.jpg'),
(23135, 1584, 'Me Encontra em Paris S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174756.mp4', 'http://timg.bdta.pro/images/8801e0d05ef755f0869d6420807f9458.jpg'),
(23136, 1584, 'Me Encontra em Paris S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174757.mp4', 'http://timg.bdta.pro/images/216336e3f407d163116b3a1d9ee0222d.jpg'),
(23137, 1584, 'Me Encontra em Paris S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174758.mp4', 'http://timg.bdta.pro/images/3bdf535f411c84cb93b357d187d52beb.jpg'),
(23138, 1584, 'Me Encontra em Paris S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174759.mp4', 'http://timg.bdta.pro/images/6c4e0ab996e9b04e78f7eb4aab804599.jpg'),
(23139, 1584, 'Me Encontra em Paris S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174760.mp4', 'http://timg.bdta.pro/images/470f36349b4838e23b29af0f617ce13d.jpg'),
(23140, 1584, 'Me Encontra em Paris S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174761.mp4', 'http://timg.bdta.pro/images/aee19a86e5ccf53431c8fd531e3aef97.jpg'),
(23141, 1584, 'Me Encontra em Paris S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174762.mp4', 'http://timg.bdta.pro/images/d026c3790c07f06daa9111bcfdcd47b0.jpg'),
(23142, 1584, 'Me Encontra em Paris S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174763.mp4', 'http://timg.bdta.pro/images/6db64d8cd03e0cb93bd76b54170c5607.jpg'),
(23143, 1584, 'Me Encontra em Paris S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174764.mp4', 'http://timg.bdta.pro/images/ce52d981fb1abe1ba26fdb3909a4c6c5.jpg'),
(23144, 1584, 'Me Encontra em Paris S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174765.mp4', 'http://timg.bdta.pro/images/21abfb2e15428d3923c2a09d945ef24b.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(23145, 1584, 'Me Encontra em Paris S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/174766.mp4', 'http://timg.bdta.pro/images/105aa46a3093d5c4b298ca3ed5525cbb.jpg'),
(23146, 1584, 'Me Encontra em Paris S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/174767.mp4', 'http://timg.bdta.pro/images/eba791116b1e0f2060b49d6fe21b013b.jpg'),
(23147, 1584, 'Me Encontra em Paris S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/174768.mp4', 'http://timg.bdta.pro/images/ef9c3ffb36b3358c3b4fb61f15889917.jpg'),
(23148, 1584, 'Me Encontra em Paris S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/174769.mp4', 'http://timg.bdta.pro/images/f401fc8621ec79f309c26863fa8507a7.jpg'),
(23149, 1584, 'Me Encontra em Paris S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/174770.mp4', 'http://timg.bdta.pro/images/1f37422e9c947b3ee7ff0fc4a60b5868.jpg'),
(23150, 1584, 'Me Encontra em Paris S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/174771.mp4', 'http://timg.bdta.pro/images/09f00318c876f9515121c71b0314f9bd.jpg'),
(23151, 1584, 'Me Encontra em Paris S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/174772.mp4', 'http://timg.bdta.pro/images/e3f34120ad01938396e38860745226fa.jpg'),
(23152, 1584, 'Me Encontra em Paris S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/174773.mp4', 'http://timg.bdta.pro/images/313735de4fea6f4b34237cd1ebb6c7f2.jpg'),
(23153, 1584, 'Me Encontra em Paris S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/174774.mp4', 'http://timg.bdta.pro/images/7fe628f1cde48d8dc3778bfec1af9b4e.jpg'),
(23154, 1584, 'Me Encontra em Paris S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/174775.mp4', 'http://timg.bdta.pro/images/b5f0b36955c97ca97a22394a2de8b3aa.jpg'),
(23155, 1584, 'Me Encontra em Paris S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/174776.mp4', 'http://timg.bdta.pro/images/43ab7cab1fe4272c85f43bb4a8b0d2f2.jpg'),
(23156, 1584, 'Me Encontra em Paris S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/174777.mp4', 'http://timg.bdta.pro/images/625aa3d7d0ca64eac0d118b10875e2b3.jpg'),
(23157, 1584, 'Me Encontra em Paris S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/174778.mp4', 'http://timg.bdta.pro/images/59a4dbe10be456a3383fe165f3732502.jpg'),
(23158, 1584, 'Me Encontra em Paris S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/174779.mp4', 'http://timg.bdta.pro/images/864890cdfe055fa4eda3bac3e6547ad9.jpg'),
(23159, 1584, 'Me Encontra em Paris S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/174780.mp4', 'http://timg.bdta.pro/images/672c4fea2571754fcef8167eda1c299e.jpg'),
(23160, 1584, 'Me Encontra em Paris S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/174781.mp4', 'http://timg.bdta.pro/images/ad827d15a19ad29386e4628c1a3f7333.jpg'),
(23161, 1585, 'Me Encontra em Paris S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174782.mp4', 'http://timg.bdta.pro/images/43059ae584256c224a7bafa700b02ccd.jpg'),
(23162, 1585, 'Me Encontra em Paris S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174783.mp4', 'http://timg.bdta.pro/images/cea785e1ce0ff671b620f326d8d24f8e.jpg'),
(23163, 1585, 'Me Encontra em Paris S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174784.mp4', 'http://timg.bdta.pro/images/96f291462594814de76cc5da72c86cbd.jpg'),
(23164, 1585, 'Me Encontra em Paris S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174785.mp4', 'http://timg.bdta.pro/images/331d29e763c4f5377e29237771777aa3.jpg'),
(23165, 1585, 'Me Encontra em Paris S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174786.mp4', 'http://timg.bdta.pro/images/8c492516bc8eccea0a08b2292148878b.jpg'),
(23166, 1585, 'Me Encontra em Paris S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174787.mp4', 'http://timg.bdta.pro/images/8c492516bc8eccea0a08b2292148878b.jpg'),
(23167, 1585, 'Me Encontra em Paris S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174788.mp4', 'http://timg.bdta.pro/images/dec37d92ffa072f373a33df35ce75224.jpg'),
(23168, 1585, 'Me Encontra em Paris S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174789.mp4', 'http://timg.bdta.pro/images/a99632c7f8c4f2cd28e5ff38c3200460.jpg'),
(23169, 1585, 'Me Encontra em Paris S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174790.mp4', 'http://timg.bdta.pro/images/00e35e50641cd6aed929eadae3c122b7.jpg'),
(23170, 1585, 'Me Encontra em Paris S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174791.mp4', 'http://timg.bdta.pro/images/76308d5ad3862fea5711408f0537e0e2.jpg'),
(23171, 1585, 'Me Encontra em Paris S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/174792.mp4', 'http://timg.bdta.pro/images/e679455efc46666890ba2aa703cff405.jpg'),
(23172, 1585, 'Me Encontra em Paris S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/174793.mp4', 'http://timg.bdta.pro/images/f7792c5fba8cbde572c27616db4056b9.jpg'),
(23173, 1585, 'Me Encontra em Paris S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/174794.mp4', 'http://timg.bdta.pro/images/a158c0542b56bf13d67bc5c69f7e8cf6.jpg'),
(23174, 1585, 'Me Encontra em Paris S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/174795.mp4', 'http://timg.bdta.pro/images/1602c1a1643c3faf54f2fb8a24e43bc9.jpg'),
(23175, 1585, 'Me Encontra em Paris S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/174796.mp4', 'http://timg.bdta.pro/images/984a2478c69da450f25550d986b64604.jpg'),
(23176, 1585, 'Me Encontra em Paris S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/174797.mp4', 'http://timg.bdta.pro/images/2eaa25b469fdb7c9a9c594dd4696df66.jpg'),
(23177, 1585, 'Me Encontra em Paris S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/174798.mp4', 'http://timg.bdta.pro/images/8db3624a9dad3b1c495512c89509f82b.jpg'),
(23178, 1585, 'Me Encontra em Paris S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/174799.mp4', 'http://timg.bdta.pro/images/53a0ec8cdbeed45dd67525297e50098e.jpg'),
(23179, 1585, 'Me Encontra em Paris S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/174800.mp4', 'http://timg.bdta.pro/images/b513e22eb5a74e2b3b7e19d7239645cc.jpg'),
(23180, 1585, 'Me Encontra em Paris S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/174801.mp4', 'http://timg.bdta.pro/images/8de82b283c5beb037a1e56edd46f21db.jpg'),
(23181, 1585, 'Me Encontra em Paris S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/174802.mp4', 'http://timg.bdta.pro/images/a14cc6b133cd38fa9d8c65aa085fe4b3.jpg'),
(23182, 1585, 'Me Encontra em Paris S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/174803.mp4', 'http://timg.bdta.pro/images/679560ab807b38bc58f2815dae5abb26.jpg'),
(23183, 1585, 'Me Encontra em Paris S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/174804.mp4', 'http://timg.bdta.pro/images/4e94c4c539678475042d732076298b44.jpg'),
(23184, 1585, 'Me Encontra em Paris S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/174805.mp4', 'http://timg.bdta.pro/images/447ec5c5eb2e1ecb910deac00d51a6d8.jpg'),
(23185, 1585, 'Me Encontra em Paris S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/174806.mp4', 'http://timg.bdta.pro/images/9166c89ead4bc0835dbb7d8d0e7ffd98.jpg'),
(23186, 1585, 'Me Encontra em Paris S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/174807.mp4', 'http://timg.bdta.pro/images/2de482972591b76c4157f005405c856f.jpg'),
(23187, 1586, 'Legacies S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183803.mp4', 'http://timg.bdta.pro/images/3dfd71e32d250008afc237ce2d8b5996.jpg'),
(23188, 1586, 'Legacies S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183804.mp4', 'http://timg.bdta.pro/images/e7a00dfbbbdbbde3b66808fc5f639059.jpg'),
(23189, 1586, 'Legacies S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183805.mp4', 'http://timg.bdta.pro/images/dd59547dcfe9cee13ee54ae7e06654d5.jpg'),
(23190, 1586, 'Legacies S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183806.mp4', 'http://timg.bdta.pro/images/b114b2a3c022be394a8774d311cc4657.jpg'),
(23191, 1586, 'Legacies S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183807.mp4', 'http://timg.bdta.pro/images/2fa7df23e5ecaf07c271074e5ef31934.jpg'),
(23192, 1586, 'Legacies S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183808.mp4', 'http://timg.bdta.pro/images/156f468bd0507c611ef7c450db184b68.jpg'),
(23193, 1586, 'Legacies S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183809.mp4', 'http://timg.bdta.pro/images/c8245d85225712347dad4ff12ca01dc6.jpg'),
(23194, 1586, 'Legacies S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183810.mp4', 'http://timg.bdta.pro/images/952a5d7c59060e6dd38844f8ec2575d5.jpg'),
(23195, 1586, 'Legacies S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183811.mp4', 'http://timg.bdta.pro/images/8987c6e83335f91b78e9b1dc8f15a52c.jpg'),
(23196, 1586, 'Legacies S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183812.mp4', 'http://timg.bdta.pro/images/d79c0ff86540df387ee14fb7fe03e28d.jpg'),
(23197, 1586, 'Legacies S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183813.mp4', 'http://timg.bdta.pro/images/594bbcb3606e6a31ebaf168c3abb8158.jpg'),
(23198, 1586, 'Legacies S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183814.mp4', 'http://timg.bdta.pro/images/f617b9bb0c8e69a706e2daf78c8cc1b5.jpg'),
(23199, 1586, 'Legacies S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/183815.mp4', 'http://timg.bdta.pro/images/5846a019f7c088226684e5cc52ec9d4d.jpg'),
(23200, 1586, 'Legacies S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/183816.mp4', 'http://timg.bdta.pro/images/90d8b27b15b304c63d5502fde6f9dad6.jpg'),
(23201, 1586, 'Legacies S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/183817.mp4', 'http://timg.bdta.pro/images/545e0c1e8a88d413a45394ec67157980.jpg'),
(23202, 1586, 'Legacies S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/183818.mp4', 'http://timg.bdta.pro/images/89ca156db78fd339dea38594e2745e0c.jpg'),
(23203, 1587, 'Legacies S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183819.mp4', 'http://timg.bdta.pro/images/370c895eb28459bbbb5ccf89ea093c72.jpg'),
(23204, 1587, 'Legacies S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183820.mp4', 'http://timg.bdta.pro/images/79b0250b7da178cc68b29f52886fcf56.jpg'),
(23205, 1587, 'Legacies S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183821.mp4', 'http://timg.bdta.pro/images/14e88c7162d9710a8c8cfea1d8f2a574.jpg'),
(23206, 1587, 'Legacies S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183822.mp4', 'http://timg.bdta.pro/images/a6bff5c470ec87eb50f758637481062f.jpg'),
(23207, 1587, 'Legacies S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183823.mp4', 'http://timg.bdta.pro/images/8b35353efbf4e4fc26e6455d4d40418f.jpg'),
(23208, 1587, 'Legacies S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183824.mp4', 'http://timg.bdta.pro/images/ecb7f29c9f6a0bbc904e4e6f8491e8ae.jpg'),
(23209, 1587, 'Legacies S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183825.mp4', 'http://timg.bdta.pro/images/b8704e0f9c3cdb57bee62b7f4ee3c2ae.jpg'),
(23210, 1587, 'Legacies S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183826.mp4', 'http://timg.bdta.pro/images/a4923921ed7f0099546a02d549903a01.jpg'),
(23211, 1587, 'Legacies S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183827.mp4', 'http://timg.bdta.pro/images/8c188c7599a514d3132758ad15c53540.jpg'),
(23212, 1587, 'Legacies S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183828.mp4', 'http://timg.bdta.pro/images/f83fa5998c8d9ad6f27b18ae7eb6a39d.jpg'),
(23213, 1587, 'Legacies S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183829.mp4', 'http://timg.bdta.pro/images/bb1392d2ffc2652a8ed024502d68665d.jpg'),
(23214, 1587, 'Legacies S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183830.mp4', 'http://timg.bdta.pro/images/da2e5e86e97025a92164f37d9f0c3f51.jpg'),
(23215, 1587, 'Legacies S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/183831.mp4', 'http://timg.bdta.pro/images/c584f069b8c64c8f1ed8d75baabcfc44.jpg'),
(23216, 1587, 'Legacies S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/183832.mp4', 'http://timg.bdta.pro/images/fff83bd961bb3e6927d17b8e69b56661.jpg'),
(23217, 1587, 'Legacies S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/183833.mp4', 'http://timg.bdta.pro/images/e72a9c8964e76a8da3bdbc74e4691fd0.jpg'),
(23218, 1587, 'Legacies S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/183834.mp4', 'http://timg.bdta.pro/images/4299dcd4c69b828cb62bc65bf7768ccd.jpg'),
(23219, 1588, 'Legacies S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183835.mp4', 'http://timg.bdta.pro/images/3f77a2232083a03954f8be252b320aa9.jpg'),
(23220, 1588, 'Legacies S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183836.mp4', 'http://timg.bdta.pro/images/f4ac18a0e1b64ccd9ab33acb3ce5ce66.jpg'),
(23221, 1588, 'Legacies S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183837.mp4', 'http://timg.bdta.pro/images/1b4f1b5b7947d61a149e9bfa115e1d66.jpg'),
(23222, 1588, 'Legacies S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183838.mp4', 'http://timg.bdta.pro/images/1b988ff8fe76c3c98d801ec986af51f1.jpg'),
(23223, 1588, 'Legacies S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183839.mp4', 'http://timg.bdta.pro/images/b872d429cc23e00b6e045ecbe2bbff3d.jpg'),
(23224, 1588, 'Legacies S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183840.mp4', 'http://timg.bdta.pro/images/3efa68b34bcab83a704f1c9a25c9faac.jpg'),
(23225, 1588, 'Legacies S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183841.mp4', 'http://timg.bdta.pro/images/4badb8022a928fbea186a3992aaad62d.jpg'),
(23226, 1588, 'Legacies S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183842.mp4', 'http://timg.bdta.pro/images/4b43e27bef34635a2ff241fbc4b3212b.jpg'),
(23227, 1588, 'Legacies S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183843.mp4', 'http://timg.bdta.pro/images/e53e85b497419dd922fd5aac8533b984.jpg'),
(23228, 1588, 'Legacies S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183844.mp4', 'http://timg.bdta.pro/images/5dd236edc83ed7af4f1ad04c08387b7e.jpg'),
(23229, 1588, 'Legacies S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183845.mp4', 'http://timg.bdta.pro/images/ad6629dd59acd874f29dc9aad141f386.jpg'),
(23230, 1588, 'Legacies S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183846.mp4', 'http://timg.bdta.pro/images/cc5fe98ae8c9efff09164d8aa0ab17a8.jpg'),
(23231, 1588, 'Legacies S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/183847.mp4', 'http://timg.bdta.pro/images/950128614a2451461d1c044440296f39.jpg'),
(23232, 1588, 'Legacies S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/183848.mp4', 'http://timg.bdta.pro/images/eda9efd78b93dc7eb5d1bc38745b1252.jpg'),
(23233, 1588, 'Legacies S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/183849.mp4', 'http://timg.bdta.pro/images/b6d258fa61727faa650aaaa5b0f0feb0.jpg'),
(23234, 1588, 'Legacies S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/183850.mp4', 'http://timg.bdta.pro/images/9923152fdd7d773d91b6b49aa246bae0.jpg'),
(23235, 1589, 'Legacies S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183851.mp4', 'http://image.tmdb.org/t/p/w1280/3PvbDYSIU2V9HeK7xSGdj3JeAL6.jpg'),
(23236, 1589, 'Legacies S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5sjdQHXRCXIYsemCPQ0cSfuTUm.jpg'),
(23237, 1589, 'Legacies S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p0oZImtRDBxcqgHTffKI48FVwIu.jpg'),
(23238, 1589, 'Legacies S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wTISJUCgQqpH4pLWJXL1lXkN9BU.jpg'),
(23239, 1589, 'Legacies S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5lMwRSUs7NFp0sFbFtaePl5Msh.jpg'),
(23240, 1589, 'Legacies S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w11WAPwkKPWxdgoMf9ZqBHM0s2x.jpg'),
(23241, 1589, 'Legacies S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183857.mp4', 'http://timg.bdta.pro/images/877935898155f56723f3b0d51d02adc0.jpg'),
(23242, 1589, 'Legacies S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183858.mp4', 'http://timg.bdta.pro/images/4052fd8409da53a6e74fc3d3e21a2c04.jpg'),
(23243, 1589, 'Legacies S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183859.mp4', 'http://timg.bdta.pro/images/4def6424d465671f22a01f767c7ae198.jpg'),
(23244, 1589, 'Legacies S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183860.mp4', 'http://timg.bdta.pro/images/dec1c21920d66c8a0cea3fffda8605d2.jpg'),
(23245, 1589, 'Legacies S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183861.mp4', 'http://timg.bdta.pro/images/913dd8159a9d1652208fae3e0f6f86be.jpg'),
(23246, 1589, 'Legacies S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183862.mp4', 'http://timg.bdta.pro/images/8ef0dc339d85e5ed9539b6105eb55144.jpg'),
(23247, 1589, 'Legacies S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/183863.mp4', 'http://timg.bdta.pro/images/8d8d6a0919470cceebda376a13c04dc8.jpg'),
(23248, 1589, 'Legacies S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/183864.mp4', 'http://timg.bdta.pro/images/6dfb6eaf3ed06a1f84892f5f3dd6ce9e.jpg'),
(23249, 1589, 'Legacies S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/183865.mp4', 'http://timg.bdta.pro/images/90b9b1bafaedfb33ddb049d0ffe04a65.jpg'),
(23250, 1589, 'Legacies S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/183866.mp4', 'http://timg.bdta.pro/images/cde45c09fd780369ad75a643481690fd.jpg'),
(23251, 1589, 'Legacies S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/183867.mp4', 'http://timg.bdta.pro/images/638fc7ed17a02d73c7fc5e1953707773.jpg'),
(23252, 1589, 'Legacies S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/183868.mp4', 'http://timg.bdta.pro/images/583fc734d448005a79fcdd736dba0b93.jpg'),
(23253, 1589, 'Legacies S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/183869.mp4', 'http://timg.bdta.pro/images/ac4dd4d24ced6051fa8f802f25c5706a.jpg'),
(23254, 1589, 'Legacies S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/183870.mp4', 'http://timg.bdta.pro/images/27516a781aa5a18edd29850799f1db94.jpg'),
(23255, 1590, 'Fleabag S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155486.mp4', 'http://timg.bdta.pro/images/8830d3ce26ba420fe39afcad0dfc8d7d.jpg'),
(23256, 1590, 'Fleabag S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155487.mp4', 'http://timg.bdta.pro/images/e59f8ce1ab1aa405c6b9ad0cf6816d9f.jpg'),
(23257, 1590, 'Fleabag S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155488.mp4', 'http://timg.bdta.pro/images/331f3836512a4a953042dbabbb5ade9c.jpg'),
(23258, 1590, 'Fleabag S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155489.mp4', 'http://timg.bdta.pro/images/e569e450bcbae6dc6ccef60afb7bb165.jpg'),
(23259, 1590, 'Fleabag S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155490.mp4', 'http://timg.bdta.pro/images/ab432ce44b0bbb67389d9af56009c9c3.jpg'),
(23260, 1590, 'Fleabag S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155491.mp4', 'http://timg.bdta.pro/images/d3846c04fa9474ef3cb6806552de7069.jpg'),
(23261, 1591, 'Fleabag S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155492.mp4', 'http://timg.bdta.pro/images/e6b9761c69171ce695df795e07890cf1.jpg'),
(23262, 1591, 'Fleabag S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155493.mp4', 'http://timg.bdta.pro/images/62749e6f58ee03143c098c42a9aa0400.jpg'),
(23263, 1591, 'Fleabag S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155494.mp4', 'http://timg.bdta.pro/images/0c9f4d08f8aa9d815643b81f61f32cdc.jpg'),
(23264, 1591, 'Fleabag S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155495.mp4', 'http://timg.bdta.pro/images/9123590fb0c664459395303ef95df767.jpg'),
(23265, 1591, 'Fleabag S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155496.mp4', 'http://timg.bdta.pro/images/ef3cd40790ba2cdd93e752bd124ce03c.jpg'),
(23266, 1591, 'Fleabag S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155497.mp4', 'http://timg.bdta.pro/images/ce054fabaf99c9ce577e59061ecf87df.jpg'),
(23267, 1592, 'Boneca Russa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182528.mp4', 'http://timg.bdta.pro/images/7972ec0d2dbf0b050a96a7a0d690d601.jpg'),
(23268, 1592, 'Boneca Russa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182529.mp4', 'http://timg.bdta.pro/images/7fd07c46ef782683ef0110c3a367417e.jpg'),
(23269, 1592, 'Boneca Russa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182530.mp4', 'http://timg.bdta.pro/images/846c3eb65d975db23cf1c28d89294324.jpg'),
(23270, 1592, 'Boneca Russa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182531.mp4', 'http://timg.bdta.pro/images/822306ab218898cdf24daad248dd0fb2.jpg'),
(23271, 1592, 'Boneca Russa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182532.mp4', 'http://timg.bdta.pro/images/e5d4bd7b312d1d302a42e20d3eafd996.jpg'),
(23272, 1592, 'Boneca Russa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182533.mp4', 'http://timg.bdta.pro/images/5ed8aed67b8a56a891359bd6a64eac54.jpg'),
(23273, 1592, 'Boneca Russa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182534.mp4', 'http://timg.bdta.pro/images/c2da88dafbc61a14472c2d5883fb7fbf.jpg'),
(23274, 1592, 'Boneca Russa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182535.mp4', 'http://timg.bdta.pro/images/c3172a1ddb9393bbc57c79a3603123b1.jpg'),
(23275, 1593, 'Boneca Russa S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182536.mp4', 'http://timg.bdta.pro/images/bc5a9c3161a446305b4019f18fa3a640.jpg'),
(23276, 1593, 'Boneca Russa S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182537.mp4', 'http://timg.bdta.pro/images/d22204dc6976fe25da086443727b99d9.jpg'),
(23277, 1593, 'Boneca Russa S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182538.mp4', 'http://timg.bdta.pro/images/fe606c2e897d5b95b0c5bce53350528f.jpg'),
(23278, 1593, 'Boneca Russa S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182539.mp4', 'http://timg.bdta.pro/images/05e61d5259654cc54dbecc9ec73d5581.jpg'),
(23279, 1593, 'Boneca Russa S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182540.mp4', 'http://timg.bdta.pro/images/1ff386d0420b5a5eb391f876d774bc52.jpg'),
(23280, 1593, 'Boneca Russa S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182541.mp4', 'http://timg.bdta.pro/images/d59e712dc658c7c58d18c244e0a1aae4.jpg'),
(23281, 1593, 'Boneca Russa S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182542.mp4', 'http://timg.bdta.pro/images/d824950d1fa3a0ab13b5380dae682851.jpg'),
(23282, 1594, 'Hotel Transylvania: A Série S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163275.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23283, 1594, 'Hotel Transylvania: A Série S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163276.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23284, 1594, 'Hotel Transylvania: A Série S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163277.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23285, 1594, 'Hotel Transylvania: A Série S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163278.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23286, 1594, 'Hotel Transylvania: A Série S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163279.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23287, 1594, 'Hotel Transylvania: A Série S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163280.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23288, 1594, 'Hotel Transylvania: A Série S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163281.mp4', 'http://timg.bdta.pro/images/561a455157f5750bdd3dfb348dd7aaac.jpg'),
(23289, 1594, 'Hotel Transylvania: A Série S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163282.mp4', 'http://timg.bdta.pro/images/561a455157f5750bdd3dfb348dd7aaac.jpg'),
(23290, 1594, 'Hotel Transylvania: A Série S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163283.mp4', 'http://timg.bdta.pro/images/17faa76be731a65fb83b20268b15b1a4.jpg'),
(23291, 1594, 'Hotel Transylvania: A Série S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163284.mp4', 'http://timg.bdta.pro/images/17faa76be731a65fb83b20268b15b1a4.jpg'),
(23292, 1594, 'Hotel Transylvania: A Série S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163285.mp4', 'http://timg.bdta.pro/images/ca3c7561e873ece7a2fab014ace71c3e.jpg'),
(23293, 1594, 'Hotel Transylvania: A Série S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163286.mp4', 'http://timg.bdta.pro/images/ca3c7561e873ece7a2fab014ace71c3e.jpg'),
(23294, 1594, 'Hotel Transylvania: A Série S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163287.mp4', 'http://timg.bdta.pro/images/ca3c7561e873ece7a2fab014ace71c3e.jpg'),
(23295, 1594, 'Hotel Transylvania: A Série S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163288.mp4', 'http://timg.bdta.pro/images/ca3c7561e873ece7a2fab014ace71c3e.jpg'),
(23296, 1594, 'Hotel Transylvania: A Série S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163289.mp4', 'http://timg.bdta.pro/images/ca3c7561e873ece7a2fab014ace71c3e.jpg'),
(23297, 1594, 'Hotel Transylvania: A Série S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163290.mp4', 'http://timg.bdta.pro/images/ca3c7561e873ece7a2fab014ace71c3e.jpg'),
(23298, 1594, 'Hotel Transylvania: A Série S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163291.mp4', 'http://timg.bdta.pro/images/ca3c7561e873ece7a2fab014ace71c3e.jpg'),
(23299, 1594, 'Hotel Transylvania: A Série S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163292.mp4', 'http://timg.bdta.pro/images/ca3c7561e873ece7a2fab014ace71c3e.jpg'),
(23300, 1594, 'Hotel Transylvania: A Série S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163293.mp4', 'http://timg.bdta.pro/images/ca3c7561e873ece7a2fab014ace71c3e.jpg'),
(23301, 1594, 'Hotel Transylvania: A Série S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163294.mp4', 'http://timg.bdta.pro/images/ca3c7561e873ece7a2fab014ace71c3e.jpg'),
(23302, 1594, 'Hotel Transylvania: A Série S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/163295.mp4', 'http://timg.bdta.pro/images/ca3c7561e873ece7a2fab014ace71c3e.jpg'),
(23303, 1594, 'Hotel Transylvania: A Série S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/163296.mp4', 'http://timg.bdta.pro/images/ca3c7561e873ece7a2fab014ace71c3e.jpg'),
(23304, 1594, 'Hotel Transylvania: A Série S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/163297.mp4', 'http://timg.bdta.pro/images/ca3c7561e873ece7a2fab014ace71c3e.jpg'),
(23305, 1594, 'Hotel Transylvania: A Série S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/163298.mp4', 'http://timg.bdta.pro/images/42befe58e803b7ea07a4c36fa1cdf684.jpg'),
(23306, 1594, 'Hotel Transylvania: A Série S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/163299.mp4', 'http://timg.bdta.pro/images/8d1a6e5738b9bd941f87609b645e6bc3.jpg'),
(23307, 1594, 'Hotel Transylvania: A Série S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/163300.mp4', 'http://timg.bdta.pro/images/8d1a6e5738b9bd941f87609b645e6bc3.jpg'),
(23308, 1595, 'Hotel Transylvania: A Série S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163301.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23309, 1595, 'Hotel Transylvania: A Série S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163302.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23310, 1595, 'Hotel Transylvania: A Série S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163303.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23311, 1595, 'Hotel Transylvania: A Série S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163304.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23312, 1595, 'Hotel Transylvania: A Série S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163305.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23313, 1595, 'Hotel Transylvania: A Série S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163306.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23314, 1595, 'Hotel Transylvania: A Série S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163307.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23315, 1595, 'Hotel Transylvania: A Série S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163308.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23316, 1595, 'Hotel Transylvania: A Série S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163309.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23317, 1595, 'Hotel Transylvania: A Série S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163310.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23318, 1595, 'Hotel Transylvania: A Série S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163311.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23319, 1595, 'Hotel Transylvania: A Série S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163312.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23320, 1595, 'Hotel Transylvania: A Série S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163313.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23321, 1595, 'Hotel Transylvania: A Série S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163314.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23322, 1595, 'Hotel Transylvania: A Série S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163315.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23323, 1595, 'Hotel Transylvania: A Série S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163316.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23324, 1595, 'Hotel Transylvania: A Série S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163317.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23325, 1595, 'Hotel Transylvania: A Série S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163318.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23326, 1595, 'Hotel Transylvania: A Série S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163319.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23327, 1595, 'Hotel Transylvania: A Série S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3v8WZoDTlEHmg2pskevE6bUtWp5.jpg'),
(23328, 1595, 'Hotel Transylvania: A Série S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/163321.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23329, 1595, 'Hotel Transylvania: A Série S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/163322.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23330, 1595, 'Hotel Transylvania: A Série S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/163323.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23331, 1595, 'Hotel Transylvania: A Série S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/163324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/itAjJCwz8CYmqXgQ7qimVMxeXyW.jpg'),
(23332, 1595, 'Hotel Transylvania: A Série S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/163325.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23333, 1595, 'Hotel Transylvania: A Série S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/163326.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23334, 1595, 'Hotel Transylvania: A Série S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/163327.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23335, 1595, 'Hotel Transylvania: A Série S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/163328.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23336, 1595, 'Hotel Transylvania: A Série S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/163329.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23337, 1595, 'Hotel Transylvania: A Série S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/163330.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23338, 1595, 'Hotel Transylvania: A Série S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/163331.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23339, 1595, 'Hotel Transylvania: A Série S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/163332.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23340, 1595, 'Hotel Transylvania: A Série S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/163333.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23341, 1595, 'Hotel Transylvania: A Série S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/163334.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23342, 1595, 'Hotel Transylvania: A Série S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/163335.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23343, 1595, 'Hotel Transylvania: A Série S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/163336.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23344, 1595, 'Hotel Transylvania: A Série S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/163337.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23345, 1595, 'Hotel Transylvania: A Série S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/163338.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23346, 1595, 'Hotel Transylvania: A Série S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/163339.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23347, 1595, 'Hotel Transylvania: A Série S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/163340.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23348, 1595, 'Hotel Transylvania: A Série S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/163341.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23349, 1595, 'Hotel Transylvania: A Série S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/163342.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23350, 1595, 'Hotel Transylvania: A Série S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/163343.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23351, 1595, 'Hotel Transylvania: A Série S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/163344.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23352, 1595, 'Hotel Transylvania: A Série S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/163345.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23353, 1595, 'Hotel Transylvania: A Série S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/163346.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23354, 1595, 'Hotel Transylvania: A Série S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/163347.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23355, 1595, 'Hotel Transylvania: A Série S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/163348.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23356, 1595, 'Hotel Transylvania: A Série S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/163349.mp4', 'http://gstaticontent.com/images/mdPDFNqO7NWUtZIt66nMOmji7hg_big.jpg'),
(23357, 1596, 'The Umbrella Academy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/184114.mp4', 'http://timg.bdta.pro/images/bcedbb47e660ed55f94903cf95e06028.jpg'),
(23358, 1596, 'The Umbrella Academy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/184115.mp4', 'http://timg.bdta.pro/images/abd2d77fc55dff24a8eff7d042b42f6e.jpg'),
(23359, 1596, 'The Umbrella Academy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/184116.mp4', 'http://timg.bdta.pro/images/52903a2216aea72f1a9602ebabd6dc6f.jpg'),
(23360, 1596, 'The Umbrella Academy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/184117.mp4', 'http://timg.bdta.pro/images/1d9aa30d5f191f6a815394be3f285457.jpg'),
(23361, 1596, 'The Umbrella Academy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/184118.mp4', 'http://timg.bdta.pro/images/3cddefe577ba83d3d66e6be49a04f700.jpg'),
(23362, 1596, 'The Umbrella Academy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/184119.mp4', 'http://timg.bdta.pro/images/52689ab1ae2bfa2f6418becf9ce92cbf.jpg'),
(23363, 1596, 'The Umbrella Academy S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/184120.mp4', 'http://timg.bdta.pro/images/d44a9df263705bec7b838ef3d341028d.jpg'),
(23364, 1596, 'The Umbrella Academy S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/184121.mp4', 'http://timg.bdta.pro/images/47f6bff5684e2b13a4a06f2766d345a1.jpg'),
(23365, 1596, 'The Umbrella Academy S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/184122.mp4', 'http://timg.bdta.pro/images/413188b6e51a7e3ba535cd2736bdfa7f.jpg'),
(23366, 1596, 'The Umbrella Academy S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/184123.mp4', 'http://timg.bdta.pro/images/1c8e86db030b9fe58844237f318d4a84.jpg'),
(23367, 1597, 'The Umbrella Academy S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/184124.mp4', 'http://timg.bdta.pro/images/d8a7390e91b1d860751142f8712b8ea4.jpg'),
(23368, 1597, 'The Umbrella Academy S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/184125.mp4', 'http://timg.bdta.pro/images/35789d4fefeec1d1061b2206e7996540.jpg'),
(23369, 1597, 'The Umbrella Academy S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/184126.mp4', 'http://timg.bdta.pro/images/271a9eff6a967a1a67d066f28e1f9e62.jpg'),
(23370, 1597, 'The Umbrella Academy S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/184127.mp4', 'http://timg.bdta.pro/images/4cb85817504c9b3062236ac80c45fe3b.jpg'),
(23371, 1597, 'The Umbrella Academy S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/184128.mp4', 'http://timg.bdta.pro/images/845c619abe1ca84b987db7c731fb8532.jpg'),
(23372, 1597, 'The Umbrella Academy S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/184129.mp4', 'http://timg.bdta.pro/images/d6f77ea8be133e2e18ba68855320a15d.jpg'),
(23373, 1597, 'The Umbrella Academy S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/184130.mp4', 'http://timg.bdta.pro/images/ea2461daae663022d9e70aeb16802e54.jpg'),
(23374, 1597, 'The Umbrella Academy S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/184131.mp4', 'http://timg.bdta.pro/images/bdcb8ac60483e23a0ca56e6bdda415f2.jpg'),
(23375, 1597, 'The Umbrella Academy S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/184132.mp4', 'http://timg.bdta.pro/images/b45ed7375dc229328d28c7e0932e9743.jpg'),
(23376, 1597, 'The Umbrella Academy S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/184133.mp4', 'http://timg.bdta.pro/images/69cbb277e7ea375dc68f90514f673515.jpg'),
(23377, 1598, 'The Umbrella Academy S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/184134.mp4', 'http://timg.bdta.pro/images/e5fc638ed461e25280e04c6cd86169cf.jpg'),
(23378, 1598, 'The Umbrella Academy S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/184135.mp4', 'http://timg.bdta.pro/images/ca304fe3e08c90a3e5da786134171e96.jpg'),
(23379, 1598, 'The Umbrella Academy S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/184136.mp4', 'http://timg.bdta.pro/images/51655847d483b58c320b8df8cfcabdbc.jpg'),
(23380, 1598, 'The Umbrella Academy S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/184137.mp4', 'http://timg.bdta.pro/images/9e9bc5ed6e600985533f694eb04c450d.jpg'),
(23381, 1598, 'The Umbrella Academy S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/184138.mp4', 'http://timg.bdta.pro/images/952db836afc12a5cbda73f375a2c0adb.jpg'),
(23382, 1598, 'The Umbrella Academy S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/184139.mp4', 'http://timg.bdta.pro/images/aca75f8ca1e4f948afa36b8bb64f9885.jpg'),
(23383, 1598, 'The Umbrella Academy S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/184140.mp4', 'http://timg.bdta.pro/images/f962941ceef9c668bba054647aa6287d.jpg'),
(23384, 1598, 'The Umbrella Academy S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/184141.mp4', 'http://timg.bdta.pro/images/b04460edb3452130bb654b7859d41edb.jpg'),
(23385, 1598, 'The Umbrella Academy S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/184142.mp4', 'http://timg.bdta.pro/images/7eea53b0800d7e85cdd396f47cc0c9c1.jpg'),
(23386, 1598, 'The Umbrella Academy S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/184143.mp4', 'http://timg.bdta.pro/images/62f9f8afed9ccc80bce5fd88c4c45eab.jpg'),
(23387, 1599, 'The Umbrella Academy S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435814.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bEWi0TlXEhTGkSwwIWzVV6jHqvM.jpg'),
(23388, 1599, 'The Umbrella Academy S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435815.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8VSjRZkI5ojRBmreoM4v1YLTFUX.jpg'),
(23389, 1599, 'The Umbrella Academy S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435816.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f054NdZFSDnBjuIGBdzBHDT1mPp.jpg'),
(23390, 1599, 'The Umbrella Academy S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435817.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v32S52gVwsuagt8ctz3kYCOjSxt.jpg'),
(23391, 1599, 'The Umbrella Academy S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435818.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5oPftPwK1wPXDN1eDzeCWYD2bzx.jpg'),
(23392, 1599, 'The Umbrella Academy S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435819.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ayvyG61em6h9mRQO7CiTAXbzYLv.jpg'),
(23393, 1600, 'The Outsider S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110529.mp4', 'http://timg.bdta.pro/images/abeac47fdbf44e009508f407491e62a4.jpg'),
(23394, 1600, 'The Outsider S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110530.mp4', 'http://timg.bdta.pro/images/07435e34d46d842dac63f088f975aecb.jpg'),
(23395, 1600, 'The Outsider S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110531.mp4', 'http://timg.bdta.pro/images/57b134ffdc6cfc87cbd2998bf78c0622.jpg'),
(23396, 1600, 'The Outsider S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110532.mp4', 'http://timg.bdta.pro/images/31d21cf47eabd5cabc550481a1981561.jpg'),
(23397, 1600, 'The Outsider S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110533.mp4', 'http://timg.bdta.pro/images/44c277f9fcd7b2c5391c800cd460221d.jpg'),
(23398, 1600, 'The Outsider S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110534.mp4', 'http://timg.bdta.pro/images/4c80c921ba02c3dd8c5909800cda32fb.jpg'),
(23399, 1600, 'The Outsider S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110535.mp4', 'http://timg.bdta.pro/images/a74fbddacd930cc4aa749de5b1664568.jpg'),
(23400, 1600, 'The Outsider S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110536.mp4', 'http://timg.bdta.pro/images/b974f4707f9a68cab05683c61ed38507.jpg'),
(23401, 1600, 'The Outsider S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/110537.mp4', 'http://timg.bdta.pro/images/2d68a110ef7754f4ad2e8912614e1050.jpg'),
(23402, 1600, 'The Outsider S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/110538.mp4', 'http://timg.bdta.pro/images/b38f1077e9d80653f40e4b145f182f4f.jpg'),
(23403, 1601, 'Projeto Livro Azul S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/112825.mp4', 'http://timg.bdta.pro/images/d45b9f1660570dd6a0da849421398efa.jpg'),
(23404, 1601, 'Projeto Livro Azul S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/112826.mp4', 'http://timg.bdta.pro/images/7b32e3b961eae2b079d901e31c371f5e.jpg'),
(23405, 1601, 'Projeto Livro Azul S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/112827.mp4', 'http://timg.bdta.pro/images/04c22462b1e0b16744c4dd8260807476.jpg'),
(23406, 1601, 'Projeto Livro Azul S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/112828.mp4', 'http://timg.bdta.pro/images/8c8a1a5ffe44ca35df7b8f714ef81189.jpg'),
(23407, 1601, 'Projeto Livro Azul S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/112829.mp4', 'http://timg.bdta.pro/images/db14a0727e2fd2fa233b6f8b3df40085.jpg'),
(23408, 1601, 'Projeto Livro Azul S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/112830.mp4', 'http://timg.bdta.pro/images/7f8a792c724a03e199bb840eacb92ef5.jpg'),
(23409, 1601, 'Projeto Livro Azul S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/112831.mp4', 'http://timg.bdta.pro/images/1b4e4b1aa0164801ef228dd78001c661.jpg'),
(23410, 1601, 'Projeto Livro Azul S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/112832.mp4', 'http://timg.bdta.pro/images/3e9d98e4ad683752b5f8b4adb0e42f0b.jpg'),
(23411, 1601, 'Projeto Livro Azul S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/112833.mp4', 'http://timg.bdta.pro/images/82a78d043e1c80fdb88eba316a7ab306.jpg'),
(23412, 1601, 'Projeto Livro Azul S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/112834.mp4', 'http://timg.bdta.pro/images/89f7d000ad5c4d3be9f83b3b951fdbeb.jpg'),
(23413, 1602, 'Projeto Livro Azul S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/112835.mp4', 'http://timg.bdta.pro/images/e8e64c412e4ff0cf5f396b48279ace8a.jpg'),
(23414, 1602, 'Projeto Livro Azul S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/112836.mp4', 'http://timg.bdta.pro/images/bab9552a27150ba32d4efe82f37a4630.jpg'),
(23415, 1602, 'Projeto Livro Azul S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/112837.mp4', 'http://timg.bdta.pro/images/2e9b73d120e077b3969f276ce517455f.jpg'),
(23416, 1602, 'Projeto Livro Azul S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/112838.mp4', 'http://timg.bdta.pro/images/86a0740c3116f8789f8c152e8aa77f6c.jpg'),
(23417, 1602, 'Projeto Livro Azul S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/112839.mp4', 'http://timg.bdta.pro/images/1b9723fbab595a65c4da4268dd03dec2.jpg'),
(23418, 1602, 'Projeto Livro Azul S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/112840.mp4', 'http://timg.bdta.pro/images/cb0927c1b53ce3a544b3b4e4eea1082b.jpg'),
(23419, 1602, 'Projeto Livro Azul S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/112841.mp4', 'http://timg.bdta.pro/images/055391dcce333a16b8c89976b7533ed7.jpg'),
(23420, 1602, 'Projeto Livro Azul S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/112842.mp4', 'http://timg.bdta.pro/images/fb3ec652dd748cc82bf0abecfb01bec4.jpg'),
(23421, 1602, 'Projeto Livro Azul S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/112843.mp4', 'http://timg.bdta.pro/images/4a59c7594f9412478f281c5cdd25ba55.jpg'),
(23422, 1602, 'Projeto Livro Azul S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/112844.mp4', 'http://timg.bdta.pro/images/21e71e666c2a63a0fc582ff45cb22a12.jpg'),
(23423, 1603, 'October Faction S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105648.mp4', 'http://timg.bdta.pro/images/7122d5a034b1485753764951c1c62119.jpg'),
(23424, 1603, 'October Faction S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105649.mp4', 'http://timg.bdta.pro/images/0bb37bfebf4c8fcf11adafaaa077d575.jpg'),
(23425, 1603, 'October Faction S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105650.mp4', 'http://timg.bdta.pro/images/3ed9b4bd0991940057b4a722e6e456c0.jpg'),
(23426, 1603, 'October Faction S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105651.mp4', 'http://timg.bdta.pro/images/ce5eb32de06bdd0eac7896041f699ca8.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(23427, 1603, 'October Faction S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105652.mp4', 'http://timg.bdta.pro/images/b32c59dafcde406cc8a0636073fc0423.jpg'),
(23428, 1603, 'October Faction S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105653.mp4', 'http://timg.bdta.pro/images/2f6163a4a2ea2b599252eb899f3e0ae1.jpg'),
(23429, 1603, 'October Faction S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105654.mp4', 'http://timg.bdta.pro/images/94bb3837cd4b0a3d13b3bd268598c4c8.jpg'),
(23430, 1603, 'October Faction S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105655.mp4', 'http://timg.bdta.pro/images/d228058d603ad68317786db9a9a7ab97.jpg'),
(23431, 1603, 'October Faction S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105656.mp4', 'http://timg.bdta.pro/images/a58a310bcc350c85f4f9648ed3046b4c.jpg'),
(23432, 1603, 'October Faction S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105657.mp4', 'http://timg.bdta.pro/images/99d3a80c278dc47628cc189475ba3b9f.jpg'),
(23433, 1604, 'Jornada nas Estrelas: Picard S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211445.mp4', 'http://timg.bdta.pro/images/18cdaf1dff7fe0e0fa86fac66c6e732a.jpg'),
(23434, 1604, 'Jornada nas Estrelas: Picard S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211446.mp4', 'http://timg.bdta.pro/images/62becba1097a193f8c8807c0c570b0d8.jpg'),
(23435, 1604, 'Jornada nas Estrelas: Picard S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211447.mp4', 'http://timg.bdta.pro/images/aef7f0bad55dd6958bcad3102e2d60fa.jpg'),
(23436, 1604, 'Jornada nas Estrelas: Picard S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211448.mp4', 'http://timg.bdta.pro/images/388195a394a98e9621b8bdc915d32e81.jpg'),
(23437, 1604, 'Jornada nas Estrelas: Picard S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211449.mp4', 'http://timg.bdta.pro/images/5a155c67cd79f32ecd6852c17c92ab96.jpg'),
(23438, 1604, 'Jornada nas Estrelas: Picard S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211450.mp4', 'http://timg.bdta.pro/images/bf68a7d1a39003ff150426c15708d8db.jpg'),
(23439, 1604, 'Jornada nas Estrelas: Picard S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211451.mp4', 'http://timg.bdta.pro/images/377c580dd1eddcfd32fd86c151120419.jpg'),
(23440, 1604, 'Jornada nas Estrelas: Picard S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211452.mp4', 'http://timg.bdta.pro/images/7d61ab16baf7f88f03cd4350af8d8fcc.jpg'),
(23441, 1604, 'Jornada nas Estrelas: Picard S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211453.mp4', 'http://timg.bdta.pro/images/f45e0f6794b717edaadb3cc53e66a412.jpg'),
(23442, 1604, 'Jornada nas Estrelas: Picard S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211454.mp4', 'http://timg.bdta.pro/images/09d648695a35a8d351a10def7f78021f.jpg'),
(23443, 1605, 'Jornada nas Estrelas: Picard S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211455.mp4', 'http://timg.bdta.pro/images/a3cf0f22334dc71436135056cea81613.jpg'),
(23444, 1605, 'Jornada nas Estrelas: Picard S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211456.mp4', 'http://timg.bdta.pro/images/2b4427183635a76383afc61904938204.jpg'),
(23445, 1605, 'Jornada nas Estrelas: Picard S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211457.mp4', 'http://timg.bdta.pro/images/abf6f860cd26035b6b1435c84df80155.jpg'),
(23446, 1605, 'Jornada nas Estrelas: Picard S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211458.mp4', 'http://timg.bdta.pro/images/2bf24ea03ef5952871edc8051a109e31.jpg'),
(23447, 1605, 'Jornada nas Estrelas: Picard S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211459.mp4', 'http://timg.bdta.pro/images/4c4cf8d0f062b48d60aa6353426912c0.jpg'),
(23448, 1605, 'Jornada nas Estrelas: Picard S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211460.mp4', 'http://timg.bdta.pro/images/8e146f9d454ff841af8d903b615ab144.jpg'),
(23449, 1605, 'Jornada nas Estrelas: Picard S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211461.mp4', 'http://timg.bdta.pro/images/e5679b609d643a74ab0d68741753238d.jpg'),
(23450, 1605, 'Jornada nas Estrelas: Picard S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211462.mp4', 'http://timg.bdta.pro/images/44aba18bfdfc6d13a85d46b603b7c4bd.jpg'),
(23451, 1605, 'Jornada nas Estrelas: Picard S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211463.mp4', 'http://timg.bdta.pro/images/1490e0d354028d574163adc29f676290.jpg'),
(23452, 1605, 'Jornada nas Estrelas: Picard S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211464.mp4', 'http://timg.bdta.pro/images/8b211e301b9f430d043da6e53db14af7.jpg'),
(23453, 1606, 'Jornada nas Estrelas: Picard S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211465.mp4', 'http://image.tmdb.org/t/p/w1280/hzJTE9upcJ9Mj1aZ4OEBB4E3HPt.jpg'),
(23454, 1606, 'Jornada nas Estrelas: Picard S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211466.mp4', 'http://image.tmdb.org/t/p/w1280/xZX5x1OVz6uMxx5jg2yDqor1PZe.jpg'),
(23455, 1606, 'Jornada nas Estrelas: Picard S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211467.mp4', 'http://image.tmdb.org/t/p/w1280/6NcB1l37laa9gAEaks5hYJzIH4A.jpg'),
(23456, 1606, 'Jornada nas Estrelas: Picard S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211468.mp4', 'http://image.tmdb.org/t/p/w1280/b5J9q6byFSTnsrbnGu2mtULHm31.jpg'),
(23457, 1606, 'Jornada nas Estrelas: Picard S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211469.mp4', 'http://image.tmdb.org/t/p/w1280/3xEOIVFQIuo93Wd71xvDf5CiLDv.jpg'),
(23458, 1606, 'Jornada nas Estrelas: Picard S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211470.mp4', 'http://image.tmdb.org/t/p/w1280/tUPFKtRIf8F9i2svf3LE5bqR9Ax.jpg'),
(23459, 1606, 'Jornada nas Estrelas: Picard S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211471.mp4', 'http://image.tmdb.org/t/p/w1280/uZgKNVPOYtOhn5VTJrYXSPdKbHv.jpg'),
(23460, 1606, 'Jornada nas Estrelas: Picard S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211472.mp4', 'http://image.tmdb.org/t/p/w1280/fMgCEUa1H1f0VmUfVSgcRU1MpEA.jpg'),
(23461, 1606, 'Jornada nas Estrelas: Picard S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211473.mp4', 'http://image.tmdb.org/t/p/w1280/oMAZoWEZQ2OKCKpL26PmUw6NMZM.jpg'),
(23462, 1606, 'Jornada nas Estrelas: Picard S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211474.mp4', 'http://image.tmdb.org/t/p/w1280/47WcAv4SUpUrgvI2hQ92p8ZJbXK.jpg'),
(23463, 1607, 'Henry Danger S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105546.mp4', 'http://timg.bdta.pro/images/b163c65c62c3ba761cf531573c9d94a7.jpg'),
(23464, 1607, 'Henry Danger S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105547.mp4', 'http://timg.bdta.pro/images/2664ba1d1a32ab5c23a81c514ad8228d.jpg'),
(23465, 1607, 'Henry Danger S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105548.mp4', 'http://timg.bdta.pro/images/1e79c2a926b6efe80af101b74e634c64.jpg'),
(23466, 1607, 'Henry Danger S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105549.mp4', 'http://timg.bdta.pro/images/8cf9552806cd6e523d52f766e1185cea.jpg'),
(23467, 1607, 'Henry Danger S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105550.mp4', 'http://timg.bdta.pro/images/0846aad227f6a71c3dfaeca032485559.jpg'),
(23468, 1607, 'Henry Danger S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105551.mp4', 'http://timg.bdta.pro/images/cb2dd2b52251560c7718396122d0ac75.jpg'),
(23469, 1607, 'Henry Danger S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105552.mp4', 'http://timg.bdta.pro/images/496aab222c1f60c209b88d12c7d65746.jpg'),
(23470, 1607, 'Henry Danger S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105553.mp4', 'http://timg.bdta.pro/images/cda615c04c9e71f9c98f129ef9a78f22.jpg'),
(23471, 1607, 'Henry Danger S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105554.mp4', 'http://timg.bdta.pro/images/223e004908b55e1c0d96522915ca6e8f.jpg'),
(23472, 1607, 'Henry Danger S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105555.mp4', 'http://timg.bdta.pro/images/f186870beb46fdf28774454ccc0b652a.jpg'),
(23473, 1607, 'Henry Danger S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105556.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23474, 1607, 'Henry Danger S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105557.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23475, 1607, 'Henry Danger S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/105558.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23476, 1607, 'Henry Danger S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/105559.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23477, 1607, 'Henry Danger S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/105560.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23478, 1607, 'Henry Danger S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/105561.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23479, 1607, 'Henry Danger S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/105562.mp4', 'http://timg.bdta.pro/images/372509eca96da1182e6706c00dd7c348.jpg'),
(23480, 1607, 'Henry Danger S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/105563.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23481, 1607, 'Henry Danger S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/105564.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23482, 1607, 'Henry Danger S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/105565.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23483, 1607, 'Henry Danger S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/105566.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23484, 1607, 'Henry Danger S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/105567.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23485, 1607, 'Henry Danger S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/105568.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23486, 1607, 'Henry Danger S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/105569.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23487, 1607, 'Henry Danger S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/105570.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23488, 1608, 'Henry Danger S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105571.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23489, 1608, 'Henry Danger S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105572.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23490, 1608, 'Henry Danger S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105573.mp4', 'http://timg.bdta.pro/images/eeebed35726f048c111872ecc11d6ba2.jpg'),
(23491, 1608, 'Henry Danger S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105574.mp4', 'http://timg.bdta.pro/images/418d7a5d4a9a071a45258eb3d9170459.jpg'),
(23492, 1608, 'Henry Danger S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105575.mp4', 'http://timg.bdta.pro/images/7ac7120f83f920eb02e808dfa5585e2c.jpg'),
(23493, 1608, 'Henry Danger S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105576.mp4', 'http://timg.bdta.pro/images/f48180a1cd23546bf78a1871d4f7a3a4.jpg'),
(23494, 1608, 'Henry Danger S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105577.mp4', 'http://timg.bdta.pro/images/08315332e93e736caf608c568c90bd13.jpg'),
(23495, 1608, 'Henry Danger S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105578.mp4', 'http://timg.bdta.pro/images/76d80d286701e3396c9bbc509112e78b.jpg'),
(23496, 1608, 'Henry Danger S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105579.mp4', 'http://timg.bdta.pro/images/d788455e66db7832a0d72089929ad5dc.jpg'),
(23497, 1608, 'Henry Danger S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105580.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23498, 1608, 'Henry Danger S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105581.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23499, 1608, 'Henry Danger S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105582.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23500, 1608, 'Henry Danger S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/105583.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23501, 1608, 'Henry Danger S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/105584.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23502, 1608, 'Henry Danger S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/105585.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23503, 1608, 'Henry Danger S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/105586.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23504, 1608, 'Henry Danger S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/105587.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23505, 1608, 'Henry Danger S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/105588.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23506, 1609, 'Henry Danger S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105589.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23507, 1609, 'Henry Danger S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105590.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23508, 1609, 'Henry Danger S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105591.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23509, 1609, 'Henry Danger S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105592.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23510, 1609, 'Henry Danger S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105593.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23511, 1609, 'Henry Danger S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105594.mp4', 'http://timg.bdta.pro/images/f6b6e3b7d94f65e97d5ca82cbcb9f41c.jpg'),
(23512, 1609, 'Henry Danger S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105595.mp4', 'http://timg.bdta.pro/images/ca20bf2739168720019bb0f5d4612c0a.jpg'),
(23513, 1609, 'Henry Danger S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105596.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23514, 1609, 'Henry Danger S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105597.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23515, 1609, 'Henry Danger S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105598.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23516, 1609, 'Henry Danger S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105599.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23517, 1609, 'Henry Danger S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105600.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23518, 1609, 'Henry Danger S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/105601.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23519, 1609, 'Henry Danger S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/105602.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23520, 1609, 'Henry Danger S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/105603.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23521, 1609, 'Henry Danger S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/105604.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23522, 1609, 'Henry Danger S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/105605.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23523, 1609, 'Henry Danger S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/105606.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23524, 1609, 'Henry Danger S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/105607.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23525, 1610, 'Henry Danger S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105608.mp4', 'http://timg.bdta.pro/images/64e460719d0d1977da6733514e6810c9.jpg'),
(23526, 1610, 'Henry Danger S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105609.mp4', 'http://timg.bdta.pro/images/417319813a6db4afe7955b4654ac48a4.jpg'),
(23527, 1610, 'Henry Danger S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105610.mp4', 'http://timg.bdta.pro/images/ee7618e692bee5fe4d19cab4dde013a6.jpg'),
(23528, 1610, 'Henry Danger S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105611.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23529, 1610, 'Henry Danger S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105612.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23530, 1610, 'Henry Danger S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105613.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23531, 1610, 'Henry Danger S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105614.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23532, 1610, 'Henry Danger S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105615.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23533, 1610, 'Henry Danger S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105616.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23534, 1610, 'Henry Danger S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105617.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23535, 1610, 'Henry Danger S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105618.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23536, 1610, 'Henry Danger S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105619.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23537, 1610, 'Henry Danger S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/105620.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23538, 1610, 'Henry Danger S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/105621.mp4', 'http://timg.bdta.pro/images/a3e054259ff92edf67be2acd88dec188.jpg'),
(23539, 1610, 'Henry Danger S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/105622.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23540, 1610, 'Henry Danger S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/105623.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23541, 1610, 'Henry Danger S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/105624.mp4', 'http://timg.bdta.pro/images/2ce885e8bfc91ea5ac0d0fdc396480fc.jpg'),
(23542, 1610, 'Henry Danger S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/105625.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23543, 1610, 'Henry Danger S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/105626.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23544, 1610, 'Henry Danger S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/105627.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23545, 1611, 'Henry Danger S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105628.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23546, 1611, 'Henry Danger S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105629.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23547, 1611, 'Henry Danger S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105630.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23548, 1611, 'Henry Danger S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105631.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23549, 1611, 'Henry Danger S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105632.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23550, 1611, 'Henry Danger S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105633.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23551, 1611, 'Henry Danger S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105634.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23552, 1611, 'Henry Danger S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105635.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23553, 1611, 'Henry Danger S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105636.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23554, 1611, 'Henry Danger S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105637.mp4', 'http://timg.bdta.pro/images/b4e9c7fe8de869d6d0f1ed75f2a44964.jpg'),
(23555, 1611, 'Henry Danger S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105638.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23556, 1611, 'Henry Danger S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105639.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23557, 1611, 'Henry Danger S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/105640.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23558, 1611, 'Henry Danger S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/105641.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23559, 1611, 'Henry Danger S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/105642.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23560, 1611, 'Henry Danger S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/105643.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23561, 1611, 'Henry Danger S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/105644.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23562, 1611, 'Henry Danger S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/105645.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23563, 1611, 'Henry Danger S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/105646.mp4', 'http://gstaticontent.com/images/lNLczVun5zP0a6ct5pZGghBpBkV_big.jpg'),
(23564, 1611, 'Henry Danger S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/105647.mp4', 'http://timg.bdta.pro/images/446263b2997219336845605e51d99caa.jpg'),
(23565, 1612, 'O Chefe da Casa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105490.mp4', 'http://timg.bdta.pro/images/43bffe7d28fea2b896856bac070e65c8.jpg'),
(23566, 1612, 'O Chefe da Casa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105491.mp4', 'http://timg.bdta.pro/images/7f0144d5d8a7e3185e198f8ad87ab6ab.jpg'),
(23567, 1612, 'O Chefe da Casa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105492.mp4', 'http://timg.bdta.pro/images/09d9d8f88153cc18c21967a61ae3807a.jpg'),
(23568, 1612, 'O Chefe da Casa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105493.mp4', 'http://timg.bdta.pro/images/dc5ac72a1bcbb76ded9ed03f079c707e.jpg'),
(23569, 1612, 'O Chefe da Casa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105494.mp4', 'http://timg.bdta.pro/images/01a4c5cf28028308d47a928dfeb44d3b.jpg'),
(23570, 1612, 'O Chefe da Casa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105495.mp4', 'http://timg.bdta.pro/images/3177ac81d9f0cb5f080c52cc4364a9b3.jpg'),
(23571, 1612, 'O Chefe da Casa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105496.mp4', 'http://timg.bdta.pro/images/f15254feca21b95a6b89787215c340bb.jpg'),
(23572, 1612, 'O Chefe da Casa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105497.mp4', 'http://timg.bdta.pro/images/9857ba784c1738d84a4ba4acb7e796c9.jpg'),
(23573, 1612, 'O Chefe da Casa S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105498.mp4', 'http://timg.bdta.pro/images/b3861eef85937358591e46c614a9119e.jpg'),
(23574, 1612, 'O Chefe da Casa S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105499.mp4', 'http://timg.bdta.pro/images/702fba611e526fa0631414532f714d2c.jpg'),
(23575, 1612, 'O Chefe da Casa S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105500.mp4', 'http://timg.bdta.pro/images/057c25f1c5abb77dc602b5dfe308e735.jpg'),
(23576, 1612, 'O Chefe da Casa S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105501.mp4', 'http://timg.bdta.pro/images/d5f56648389e5b95521a05efb963ba1b.jpg'),
(23577, 1612, 'O Chefe da Casa S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/105502.mp4', 'http://timg.bdta.pro/images/a51c5eb655a1d903eb463b20714c6a5b.jpg'),
(23578, 1612, 'O Chefe da Casa S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/105503.mp4', 'http://timg.bdta.pro/images/97969dad301bc459f337c4095473e136.jpg'),
(23579, 1612, 'O Chefe da Casa S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/105504.mp4', 'http://timg.bdta.pro/images/c202b311dc45d07933fba57608f2c5fc.jpg'),
(23580, 1612, 'O Chefe da Casa S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/105505.mp4', 'http://timg.bdta.pro/images/702c6d414a46abbd3a151f1b934a22c3.jpg'),
(23581, 1612, 'O Chefe da Casa S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/105506.mp4', 'http://timg.bdta.pro/images/8bd921cfba7b5e44bc64d5b8d6a2dc72.jpg'),
(23582, 1612, 'O Chefe da Casa S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/105507.mp4', 'http://timg.bdta.pro/images/61b2dad68bf5b8b545a090978d5af5d2.jpg'),
(23583, 1612, 'O Chefe da Casa S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/105508.mp4', 'http://timg.bdta.pro/images/4bbb804f8e1a4a2652d8c25bc77adf90.jpg'),
(23584, 1612, 'O Chefe da Casa S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/105509.mp4', 'http://timg.bdta.pro/images/068830d7c26e8967c741b79e6ee8259d.jpg'),
(23585, 1612, 'O Chefe da Casa S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/105510.mp4', 'http://timg.bdta.pro/images/6545ad1bdd4460235340c0c5bd2fea3d.jpg'),
(23586, 1612, 'O Chefe da Casa S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/105511.mp4', 'http://timg.bdta.pro/images/1572eba4e055d90f4ac119ecdf6a24a3.jpg'),
(23587, 1613, 'O Chefe da Casa S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105512.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23588, 1613, 'O Chefe da Casa S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105513.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23589, 1613, 'O Chefe da Casa S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105514.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23590, 1613, 'O Chefe da Casa S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105515.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23591, 1613, 'O Chefe da Casa S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105516.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23592, 1613, 'O Chefe da Casa S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105517.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23593, 1613, 'O Chefe da Casa S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105518.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23594, 1613, 'O Chefe da Casa S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105519.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23595, 1613, 'O Chefe da Casa S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105520.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23596, 1613, 'O Chefe da Casa S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105521.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23597, 1613, 'O Chefe da Casa S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105522.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23598, 1613, 'O Chefe da Casa S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105523.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23599, 1613, 'O Chefe da Casa S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/105524.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23600, 1613, 'O Chefe da Casa S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/105525.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23601, 1613, 'O Chefe da Casa S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/105526.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23602, 1613, 'O Chefe da Casa S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/105527.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23603, 1613, 'O Chefe da Casa S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/105528.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23604, 1613, 'O Chefe da Casa S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/105529.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23605, 1613, 'O Chefe da Casa S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/105530.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23606, 1613, 'O Chefe da Casa S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/105531.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23607, 1613, 'O Chefe da Casa S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/105532.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23608, 1614, 'O Chefe da Casa S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105533.mp4', 'http://timg.bdta.pro/images/a15a6915805c20c370681823f42c2147.jpg'),
(23609, 1614, 'O Chefe da Casa S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105534.mp4', 'http://timg.bdta.pro/images/49f47bf523df979a78e0e33597300bc8.jpg'),
(23610, 1614, 'O Chefe da Casa S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105535.mp4', 'http://timg.bdta.pro/images/f5968ee643843c07455941574f354328.jpg'),
(23611, 1614, 'O Chefe da Casa S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105536.mp4', 'http://timg.bdta.pro/images/301dc2b6cb2c9b75a46024bb4f0b97ca.jpg'),
(23612, 1614, 'O Chefe da Casa S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105537.mp4', 'http://timg.bdta.pro/images/49842fd92d539f4e23e2a6ccefa14b05.jpg'),
(23613, 1614, 'O Chefe da Casa S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105538.mp4', 'http://timg.bdta.pro/images/ff5053a26472ad539fd53c89fe351639.jpg'),
(23614, 1614, 'O Chefe da Casa S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105539.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23615, 1614, 'O Chefe da Casa S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105540.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23616, 1614, 'O Chefe da Casa S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105541.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23617, 1614, 'O Chefe da Casa S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105542.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23618, 1614, 'O Chefe da Casa S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105543.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23619, 1614, 'O Chefe da Casa S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105544.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23620, 1614, 'O Chefe da Casa S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/105545.mp4', 'http://gstaticontent.com/images/kKbPAoZl6HTKtgLAs82KBQHP84_big.jpg'),
(23621, 1615, 'Supermax S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105478.mp4', 'http://gstaticontent.com/images/6D3uwVKxv80DY5bggxFPHzXVD8D_big.jpg'),
(23622, 1615, 'Supermax S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105479.mp4', 'http://gstaticontent.com/images/6D3uwVKxv80DY5bggxFPHzXVD8D_big.jpg'),
(23623, 1615, 'Supermax S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105480.mp4', 'http://gstaticontent.com/images/6D3uwVKxv80DY5bggxFPHzXVD8D_big.jpg'),
(23624, 1615, 'Supermax S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105481.mp4', 'http://gstaticontent.com/images/6D3uwVKxv80DY5bggxFPHzXVD8D_big.jpg'),
(23625, 1615, 'Supermax S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105482.mp4', 'http://gstaticontent.com/images/6D3uwVKxv80DY5bggxFPHzXVD8D_big.jpg'),
(23626, 1615, 'Supermax S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105483.mp4', 'http://gstaticontent.com/images/6D3uwVKxv80DY5bggxFPHzXVD8D_big.jpg'),
(23627, 1615, 'Supermax S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105484.mp4', 'http://gstaticontent.com/images/6D3uwVKxv80DY5bggxFPHzXVD8D_big.jpg'),
(23628, 1615, 'Supermax S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105485.mp4', 'http://gstaticontent.com/images/6D3uwVKxv80DY5bggxFPHzXVD8D_big.jpg'),
(23629, 1615, 'Supermax S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105486.mp4', 'http://gstaticontent.com/images/6D3uwVKxv80DY5bggxFPHzXVD8D_big.jpg'),
(23630, 1615, 'Supermax S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105487.mp4', 'http://gstaticontent.com/images/6D3uwVKxv80DY5bggxFPHzXVD8D_big.jpg'),
(23631, 1615, 'Supermax S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105488.mp4', 'http://gstaticontent.com/images/6D3uwVKxv80DY5bggxFPHzXVD8D_big.jpg'),
(23632, 1615, 'Supermax S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105489.mp4', 'http://gstaticontent.com/images/6D3uwVKxv80DY5bggxFPHzXVD8D_big.jpg'),
(23633, 1616, 'Princesinha Sofia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129895.mp4', 'http://timg.bdta.pro/images/170446b04d178b523253246dc8ac6970.jpg'),
(23634, 1616, 'Princesinha Sofia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129896.mp4', 'http://timg.bdta.pro/images/364573edb8a970ff46d14c5e7af942af.jpg'),
(23635, 1616, 'Princesinha Sofia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129897.mp4', 'http://timg.bdta.pro/images/881b595b66eff25e3786b36b1ba3c08a.jpg'),
(23636, 1616, 'Princesinha Sofia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129898.mp4', 'http://timg.bdta.pro/images/e949f05346c8529a17b3051187adaa26.jpg'),
(23637, 1616, 'Princesinha Sofia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129899.mp4', 'http://timg.bdta.pro/images/ccb136e1f8d794bdd53e1c29203bc39f.jpg'),
(23638, 1616, 'Princesinha Sofia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129900.mp4', 'http://timg.bdta.pro/images/4382001c07134621fd7e773145c29c48.jpg'),
(23639, 1616, 'Princesinha Sofia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129901.mp4', 'http://timg.bdta.pro/images/00a1de5fe48b2ed310abea15f5080ee7.jpg'),
(23640, 1616, 'Princesinha Sofia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129902.mp4', 'http://timg.bdta.pro/images/f4ff14aa5aad9581a34b45476a3c0488.jpg'),
(23641, 1616, 'Princesinha Sofia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129903.mp4', 'http://timg.bdta.pro/images/d8ceae2367d4009394d5adde9c735ea2.jpg'),
(23642, 1616, 'Princesinha Sofia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129904.mp4', 'http://timg.bdta.pro/images/043bd8e81c420a855513890eb894f7e6.jpg'),
(23643, 1616, 'Princesinha Sofia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129905.mp4', 'http://timg.bdta.pro/images/959a26b54339a9049a863e7937368d4c.jpg'),
(23644, 1616, 'Princesinha Sofia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129906.mp4', 'http://timg.bdta.pro/images/9c5aed320ff30fd590d693f59d9d64f0.jpg'),
(23645, 1616, 'Princesinha Sofia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129907.mp4', 'http://timg.bdta.pro/images/c5874914ac735e91084e293f9b0b10d6.jpg'),
(23646, 1616, 'Princesinha Sofia S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129908.mp4', 'http://timg.bdta.pro/images/4a8cfc36250c2a776c63fb4c031e251c.jpg'),
(23647, 1616, 'Princesinha Sofia S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129909.mp4', 'http://timg.bdta.pro/images/4e2b9c5deac4a02c1dc6bc8ecf7cdeb7.jpg'),
(23648, 1616, 'Princesinha Sofia S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129910.mp4', 'http://timg.bdta.pro/images/91f5a5cf3f6860be025d8cf6caf51e35.jpg'),
(23649, 1616, 'Princesinha Sofia S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129911.mp4', 'http://timg.bdta.pro/images/928ec64fcd14cd5dcc0ef3f5ccb6b03a.jpg'),
(23650, 1616, 'Princesinha Sofia S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129912.mp4', 'http://timg.bdta.pro/images/e64c1f323a2b0b8eec7e25f1be2b44b5.jpg'),
(23651, 1616, 'Princesinha Sofia S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129913.mp4', 'http://timg.bdta.pro/images/f921fb1b28ee7c89fed994e6960cc73e.jpg'),
(23652, 1616, 'Princesinha Sofia S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129914.mp4', 'http://timg.bdta.pro/images/11f9006e6013edc9e00d07a98ef66338.jpg'),
(23653, 1616, 'Princesinha Sofia S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129915.mp4', 'http://timg.bdta.pro/images/bdecc61e81d04c436d6edb1f50b781cf.jpg'),
(23654, 1616, 'Princesinha Sofia S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129916.mp4', 'http://timg.bdta.pro/images/99b9257beba9df803fbb917814317f55.jpg'),
(23655, 1616, 'Princesinha Sofia S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/129917.mp4', 'http://timg.bdta.pro/images/99b9257beba9df803fbb917814317f55.jpg'),
(23656, 1616, 'Princesinha Sofia S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/129918.mp4', 'http://timg.bdta.pro/images/11ea7da34b6ac59bf5bbf9c0dddefa2a.jpg'),
(23657, 1617, 'Princesinha Sofia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129919.mp4', 'http://timg.bdta.pro/images/30efc0df60587da2288ce9dca956c985.jpg'),
(23658, 1617, 'Princesinha Sofia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129920.mp4', 'http://timg.bdta.pro/images/5022c0b81f77fe96fdc75c0596592ae4.jpg'),
(23659, 1617, 'Princesinha Sofia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129921.mp4', 'http://timg.bdta.pro/images/68f02301985e50b8959cbdbc5eb0f727.jpg'),
(23660, 1617, 'Princesinha Sofia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129922.mp4', 'http://timg.bdta.pro/images/840339a595c146c22367dd9865448e0c.jpg'),
(23661, 1617, 'Princesinha Sofia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129923.mp4', 'http://timg.bdta.pro/images/0672af385982532ab720c595f95ad4bd.jpg'),
(23662, 1617, 'Princesinha Sofia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129924.mp4', 'http://timg.bdta.pro/images/dfdeef8621c474a7c6d373c1261593a1.jpg'),
(23663, 1617, 'Princesinha Sofia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129925.mp4', 'http://timg.bdta.pro/images/880163c7087b37b1a91d124f450aed51.jpg'),
(23664, 1617, 'Princesinha Sofia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129926.mp4', 'http://timg.bdta.pro/images/15d4de429d09a433942dee05c9c38ba3.jpg'),
(23665, 1617, 'Princesinha Sofia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129927.mp4', 'http://timg.bdta.pro/images/921c5d7c6c5e68b28101f0f4a230bf05.jpg'),
(23666, 1617, 'Princesinha Sofia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129928.mp4', 'http://timg.bdta.pro/images/3236c07a13c22bcf5302e7ff654ad973.jpg'),
(23667, 1617, 'Princesinha Sofia S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129929.mp4', 'http://timg.bdta.pro/images/6eccded635f1ea278de2eab1e421f380.jpg'),
(23668, 1617, 'Princesinha Sofia S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129930.mp4', 'http://timg.bdta.pro/images/173d5d650522751eb2884c135044e257.jpg'),
(23669, 1617, 'Princesinha Sofia S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129931.mp4', 'http://timg.bdta.pro/images/a6a342363dc28f1559591c5b8a6af74a.jpg'),
(23670, 1617, 'Princesinha Sofia S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129932.mp4', 'http://timg.bdta.pro/images/db1aede97c397d4ae8bc980869743c77.jpg'),
(23671, 1617, 'Princesinha Sofia S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129933.mp4', 'http://timg.bdta.pro/images/b75caa717a986610175439df43824ec8.jpg'),
(23672, 1617, 'Princesinha Sofia S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129934.mp4', 'http://timg.bdta.pro/images/0c1a4e2319f75493f61e2283a10dfa39.jpg'),
(23673, 1617, 'Princesinha Sofia S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129935.mp4', 'http://timg.bdta.pro/images/592775bbf5cb8c636f93ee3ae117871e.jpg'),
(23674, 1617, 'Princesinha Sofia S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129936.mp4', 'http://timg.bdta.pro/images/bad64c113bd2b47bb143728a7d98c9e6.jpg'),
(23675, 1617, 'Princesinha Sofia S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129937.mp4', 'http://timg.bdta.pro/images/3e3911ba37ea3b2e2ab40341221aea0c.jpg'),
(23676, 1617, 'Princesinha Sofia S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129938.mp4', 'http://timg.bdta.pro/images/9cee48f4e25f12bdcecf8db5972cf11f.jpg'),
(23677, 1617, 'Princesinha Sofia S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129939.mp4', 'http://timg.bdta.pro/images/cea0655a0217090529840f0ca91de94a.jpg'),
(23678, 1617, 'Princesinha Sofia S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129940.mp4', 'http://timg.bdta.pro/images/d898ba3d96522f0e7cbd598bb5e6081f.jpg'),
(23679, 1617, 'Princesinha Sofia S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/129941.mp4', 'http://timg.bdta.pro/images/b684a0e835740bbbf4f482053062223a.jpg'),
(23680, 1617, 'Princesinha Sofia S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/129942.mp4', 'http://timg.bdta.pro/images/c4a624150299c10571fcb1a5b67fb5da.jpg'),
(23681, 1617, 'Princesinha Sofia S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/129943.mp4', 'http://timg.bdta.pro/images/a4640081757a9710a5f9eff775acd531.jpg'),
(23682, 1617, 'Princesinha Sofia S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/129944.mp4', 'http://timg.bdta.pro/images/8d26ab66f2760c2c07e7c5f99651d430.jpg'),
(23683, 1617, 'Princesinha Sofia S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/129945.mp4', 'http://timg.bdta.pro/images/704af5dfb741a6a20b21ced98f360af8.jpg'),
(23684, 1617, 'Princesinha Sofia S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/129946.mp4', 'http://timg.bdta.pro/images/0fa6bfeb1abaa5a626db497220652c3d.jpg'),
(23685, 1617, 'Princesinha Sofia S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/129947.mp4', 'http://gstaticontent.com/images/zGrjjxGQBdKV5uYQDx8llrC2sHL_big.jpg'),
(23686, 1617, 'Princesinha Sofia S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/129948.mp4', 'http://gstaticontent.com/images/zGrjjxGQBdKV5uYQDx8llrC2sHL_big.jpg'),
(23687, 1618, 'Princesinha Sofia S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129949.mp4', 'http://timg.bdta.pro/images/0fa6bfeb1abaa5a626db497220652c3d.jpg'),
(23688, 1618, 'Princesinha Sofia S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129950.mp4', 'http://timg.bdta.pro/images/0fa6bfeb1abaa5a626db497220652c3d.jpg'),
(23689, 1618, 'Princesinha Sofia S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129951.mp4', 'http://timg.bdta.pro/images/0fa6bfeb1abaa5a626db497220652c3d.jpg'),
(23690, 1618, 'Princesinha Sofia S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129952.mp4', 'http://timg.bdta.pro/images/0fa6bfeb1abaa5a626db497220652c3d.jpg'),
(23691, 1618, 'Princesinha Sofia S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129953.mp4', 'http://timg.bdta.pro/images/0fa6bfeb1abaa5a626db497220652c3d.jpg'),
(23692, 1618, 'Princesinha Sofia S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129954.mp4', 'http://timg.bdta.pro/images/1559bb2bd0100f9da9889be8db297887.jpg'),
(23693, 1618, 'Princesinha Sofia S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129955.mp4', 'http://timg.bdta.pro/images/001ee49aa49dc2b8a0e33f07a7cd847d.jpg'),
(23694, 1618, 'Princesinha Sofia S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129956.mp4', 'http://timg.bdta.pro/images/66d583ddb45d5319b96adb061377809e.jpg'),
(23695, 1618, 'Princesinha Sofia S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129957.mp4', 'http://timg.bdta.pro/images/66d583ddb45d5319b96adb061377809e.jpg'),
(23696, 1618, 'Princesinha Sofia S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129958.mp4', 'http://timg.bdta.pro/images/66d583ddb45d5319b96adb061377809e.jpg'),
(23697, 1618, 'Princesinha Sofia S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129959.mp4', 'http://timg.bdta.pro/images/66d583ddb45d5319b96adb061377809e.jpg'),
(23698, 1618, 'Princesinha Sofia S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129960.mp4', 'http://timg.bdta.pro/images/66d583ddb45d5319b96adb061377809e.jpg'),
(23699, 1618, 'Princesinha Sofia S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129961.mp4', 'http://timg.bdta.pro/images/66d583ddb45d5319b96adb061377809e.jpg'),
(23700, 1618, 'Princesinha Sofia S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129962.mp4', 'http://timg.bdta.pro/images/298b4b9fa83b1f24954fa096745a8f7a.jpg'),
(23701, 1618, 'Princesinha Sofia S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129963.mp4', 'http://timg.bdta.pro/images/298b4b9fa83b1f24954fa096745a8f7a.jpg'),
(23702, 1618, 'Princesinha Sofia S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129964.mp4', 'http://timg.bdta.pro/images/298b4b9fa83b1f24954fa096745a8f7a.jpg'),
(23703, 1618, 'Princesinha Sofia S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129965.mp4', 'http://timg.bdta.pro/images/298b4b9fa83b1f24954fa096745a8f7a.jpg'),
(23704, 1618, 'Princesinha Sofia S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129966.mp4', 'http://timg.bdta.pro/images/298b4b9fa83b1f24954fa096745a8f7a.jpg'),
(23705, 1618, 'Princesinha Sofia S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129967.mp4', 'http://timg.bdta.pro/images/298b4b9fa83b1f24954fa096745a8f7a.jpg'),
(23706, 1618, 'Princesinha Sofia S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129968.mp4', 'http://timg.bdta.pro/images/59555b1ec3f79301ec285c863b506f92.jpg'),
(23707, 1618, 'Princesinha Sofia S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129969.mp4', 'http://timg.bdta.pro/images/59555b1ec3f79301ec285c863b506f92.jpg'),
(23708, 1618, 'Princesinha Sofia S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129970.mp4', 'http://timg.bdta.pro/images/59555b1ec3f79301ec285c863b506f92.jpg'),
(23709, 1618, 'Princesinha Sofia S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/129971.mp4', 'http://timg.bdta.pro/images/59555b1ec3f79301ec285c863b506f92.jpg'),
(23710, 1618, 'Princesinha Sofia S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/129972.mp4', 'http://timg.bdta.pro/images/59555b1ec3f79301ec285c863b506f92.jpg'),
(23711, 1618, 'Princesinha Sofia S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/129973.mp4', 'http://timg.bdta.pro/images/59555b1ec3f79301ec285c863b506f92.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(23712, 1618, 'Princesinha Sofia S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/129974.mp4', 'http://timg.bdta.pro/images/59555b1ec3f79301ec285c863b506f92.jpg'),
(23713, 1618, 'Princesinha Sofia S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/129975.mp4', 'http://timg.bdta.pro/images/59555b1ec3f79301ec285c863b506f92.jpg'),
(23714, 1619, 'Princesinha Sofia S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129976.mp4', 'http://timg.bdta.pro/images/9f3ebcf5571de1a030a685bb2b7582a5.jpg'),
(23715, 1619, 'Princesinha Sofia S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129977.mp4', 'http://timg.bdta.pro/images/c029100eb01cd84181f9af3bd80aa922.jpg'),
(23716, 1619, 'Princesinha Sofia S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129978.mp4', 'http://timg.bdta.pro/images/ff94288d6c08160c9b0f4e5999ddfcc5.jpg'),
(23717, 1619, 'Princesinha Sofia S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129979.mp4', 'http://timg.bdta.pro/images/abb881de30bb19cb1fdf53956cea2605.jpg'),
(23718, 1619, 'Princesinha Sofia S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129980.mp4', 'http://timg.bdta.pro/images/5c2d35f227874633f0d7870eba288980.jpg'),
(23719, 1619, 'Princesinha Sofia S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129981.mp4', 'http://timg.bdta.pro/images/eb28345f7a0c5c091aa65345fa531947.jpg'),
(23720, 1619, 'Princesinha Sofia S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129982.mp4', 'http://timg.bdta.pro/images/9de248d895b35c4bf4e1b5254492c701.jpg'),
(23721, 1619, 'Princesinha Sofia S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129983.mp4', 'http://timg.bdta.pro/images/bf89da529d0ff1b807d18af93ac05b0c.jpg'),
(23722, 1619, 'Princesinha Sofia S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129984.mp4', 'http://timg.bdta.pro/images/87ff258d5b2501ff21b557ee9dc44236.jpg'),
(23723, 1619, 'Princesinha Sofia S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129985.mp4', 'http://timg.bdta.pro/images/c38be9f6b28d186a5ef637d0086a1301.jpg'),
(23724, 1619, 'Princesinha Sofia S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129986.mp4', 'http://timg.bdta.pro/images/c38be9f6b28d186a5ef637d0086a1301.jpg'),
(23725, 1619, 'Princesinha Sofia S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129987.mp4', 'http://timg.bdta.pro/images/c38be9f6b28d186a5ef637d0086a1301.jpg'),
(23726, 1619, 'Princesinha Sofia S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129988.mp4', 'http://timg.bdta.pro/images/c38be9f6b28d186a5ef637d0086a1301.jpg'),
(23727, 1619, 'Princesinha Sofia S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129989.mp4', 'http://timg.bdta.pro/images/c38be9f6b28d186a5ef637d0086a1301.jpg'),
(23728, 1619, 'Princesinha Sofia S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129990.mp4', 'http://timg.bdta.pro/images/c38be9f6b28d186a5ef637d0086a1301.jpg'),
(23729, 1619, 'Princesinha Sofia S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129991.mp4', 'http://timg.bdta.pro/images/c38be9f6b28d186a5ef637d0086a1301.jpg'),
(23730, 1619, 'Princesinha Sofia S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129992.mp4', 'http://timg.bdta.pro/images/c38be9f6b28d186a5ef637d0086a1301.jpg'),
(23731, 1619, 'Princesinha Sofia S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129993.mp4', 'http://timg.bdta.pro/images/c38be9f6b28d186a5ef637d0086a1301.jpg'),
(23732, 1619, 'Princesinha Sofia S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129994.mp4', 'http://timg.bdta.pro/images/c38be9f6b28d186a5ef637d0086a1301.jpg'),
(23733, 1619, 'Princesinha Sofia S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129995.mp4', 'http://timg.bdta.pro/images/c38be9f6b28d186a5ef637d0086a1301.jpg'),
(23734, 1619, 'Princesinha Sofia S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129996.mp4', 'http://timg.bdta.pro/images/c38be9f6b28d186a5ef637d0086a1301.jpg'),
(23735, 1619, 'Princesinha Sofia S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129997.mp4', 'http://timg.bdta.pro/images/c38be9f6b28d186a5ef637d0086a1301.jpg'),
(23736, 1619, 'Princesinha Sofia S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/129998.mp4', 'http://timg.bdta.pro/images/c38be9f6b28d186a5ef637d0086a1301.jpg'),
(23737, 1619, 'Princesinha Sofia S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/129999.mp4', 'http://timg.bdta.pro/images/c38be9f6b28d186a5ef637d0086a1301.jpg'),
(23738, 1619, 'Princesinha Sofia S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/130000.mp4', 'http://timg.bdta.pro/images/c38be9f6b28d186a5ef637d0086a1301.jpg'),
(23739, 1619, 'Princesinha Sofia S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/130001.mp4', 'http://timg.bdta.pro/images/4c98fe93b3d11dfe9d6d8c2e91983439.jpg'),
(23740, 1620, 'The Goop Lab S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105472.mp4', 'http://gstaticontent.com/images/du5ptsgI6QvB79EqaZInVZ5VuJJ_big.jpg'),
(23741, 1620, 'The Goop Lab S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105473.mp4', 'http://gstaticontent.com/images/du5ptsgI6QvB79EqaZInVZ5VuJJ_big.jpg'),
(23742, 1620, 'The Goop Lab S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105474.mp4', 'http://gstaticontent.com/images/du5ptsgI6QvB79EqaZInVZ5VuJJ_big.jpg'),
(23743, 1620, 'The Goop Lab S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105475.mp4', 'http://gstaticontent.com/images/du5ptsgI6QvB79EqaZInVZ5VuJJ_big.jpg'),
(23744, 1620, 'The Goop Lab S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105476.mp4', 'http://gstaticontent.com/images/du5ptsgI6QvB79EqaZInVZ5VuJJ_big.jpg'),
(23745, 1620, 'The Goop Lab S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105477.mp4', 'http://gstaticontent.com/images/du5ptsgI6QvB79EqaZInVZ5VuJJ_big.jpg'),
(23746, 1621, 'Onisciente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105466.mp4', 'http://timg.bdta.pro/images/4013dcb10959713d0f0fdf589a78d399.jpg'),
(23747, 1621, 'Onisciente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105467.mp4', 'http://gstaticontent.com/images/uajx43GJ7ACUIBDVgceGaKBd4tE_big.jpg'),
(23748, 1621, 'Onisciente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105468.mp4', 'http://gstaticontent.com/images/uajx43GJ7ACUIBDVgceGaKBd4tE_big.jpg'),
(23749, 1621, 'Onisciente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105469.mp4', 'http://timg.bdta.pro/images/ce179d16eb73b4aedad5f4d6b300aa6a.jpg'),
(23750, 1621, 'Onisciente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105470.mp4', 'http://timg.bdta.pro/images/b13ceafac11690ccbbdbb4c8b9129b57.jpg'),
(23751, 1621, 'Onisciente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105471.mp4', 'http://gstaticontent.com/images/uajx43GJ7ACUIBDVgceGaKBd4tE_big.jpg'),
(23752, 1622, 'Hell on Wheels S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105409.mp4', 'http://timg.bdta.pro/images/540b62fa0a1a426719a44cfbbf90c5cb.jpg'),
(23753, 1622, 'Hell on Wheels S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105410.mp4', 'http://timg.bdta.pro/images/26f1bfb1321dcac36e7ea73db58bc934.jpg'),
(23754, 1622, 'Hell on Wheels S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105411.mp4', 'http://timg.bdta.pro/images/da93f4419e44674044ab8807b4e5a644.jpg'),
(23755, 1622, 'Hell on Wheels S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105412.mp4', 'http://timg.bdta.pro/images/8966da9444899a02b54e24447acf9645.jpg'),
(23756, 1622, 'Hell on Wheels S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105413.mp4', 'http://timg.bdta.pro/images/9158f4d9ff3d8775a47c905275edf9dc.jpg'),
(23757, 1622, 'Hell on Wheels S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105414.mp4', 'http://timg.bdta.pro/images/0dc122d4486a464f80b49cc19cefc833.jpg'),
(23758, 1622, 'Hell on Wheels S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105415.mp4', 'http://timg.bdta.pro/images/264a4d10c07be535b04924b799cbc3df.jpg'),
(23759, 1622, 'Hell on Wheels S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105416.mp4', 'http://timg.bdta.pro/images/b6b47b18198061e5d181e83e969d9455.jpg'),
(23760, 1622, 'Hell on Wheels S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105417.mp4', 'http://timg.bdta.pro/images/98c0962d502d30a931ee0ce419b43977.jpg'),
(23761, 1622, 'Hell on Wheels S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105418.mp4', 'http://timg.bdta.pro/images/1b165dc3444d34ce0654422d9ef2d0eb.jpg'),
(23762, 1623, 'Hell on Wheels S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105419.mp4', 'http://timg.bdta.pro/images/ce22bdd1294dbf7b3ae20df56a437bea.jpg'),
(23763, 1623, 'Hell on Wheels S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105420.mp4', 'http://timg.bdta.pro/images/53b308be28be193b5cbc83eeea9bb576.jpg'),
(23764, 1623, 'Hell on Wheels S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105421.mp4', 'http://timg.bdta.pro/images/29280ef58f37df3910f869eea81cc56a.jpg'),
(23765, 1623, 'Hell on Wheels S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105422.mp4', 'http://timg.bdta.pro/images/2f5d8a449f7e376bce054e935faa2d3b.jpg'),
(23766, 1623, 'Hell on Wheels S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105423.mp4', 'http://timg.bdta.pro/images/73c4d37f6c3d43602dd60abe472233d5.jpg'),
(23767, 1623, 'Hell on Wheels S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105424.mp4', 'http://timg.bdta.pro/images/212933745a810e9de9ef6c1276ab4499.jpg'),
(23768, 1623, 'Hell on Wheels S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105425.mp4', 'http://timg.bdta.pro/images/bfc79f671f3067e9e214917a5f7780ea.jpg'),
(23769, 1623, 'Hell on Wheels S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105426.mp4', 'http://timg.bdta.pro/images/d6ffcc87d68e4eddbe1f3514e01d6514.jpg'),
(23770, 1623, 'Hell on Wheels S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105427.mp4', 'http://timg.bdta.pro/images/013de926458181014e1eead40545037d.jpg'),
(23771, 1623, 'Hell on Wheels S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105428.mp4', 'http://timg.bdta.pro/images/5a19ff20b8410ac9c87d00a62af25d04.jpg'),
(23772, 1624, 'Hell on Wheels S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105429.mp4', 'http://timg.bdta.pro/images/7ed0c52f97eeae3b6e49cc823b360fd4.jpg'),
(23773, 1624, 'Hell on Wheels S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105430.mp4', 'http://timg.bdta.pro/images/33d1b08333f05bfe2d94cf91fe3b18cd.jpg'),
(23774, 1624, 'Hell on Wheels S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105431.mp4', 'http://timg.bdta.pro/images/e47c4a59d280874714406a181ab81265.jpg'),
(23775, 1624, 'Hell on Wheels S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105432.mp4', 'http://timg.bdta.pro/images/f86c264ae7c0ac090399abe5a6792ce5.jpg'),
(23776, 1624, 'Hell on Wheels S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105433.mp4', 'http://timg.bdta.pro/images/5ff793fb14289d77209be822aef0c04f.jpg'),
(23777, 1624, 'Hell on Wheels S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105434.mp4', 'http://timg.bdta.pro/images/42ba1187e5b424e7cfe64d2af6f8e61d.jpg'),
(23778, 1624, 'Hell on Wheels S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105435.mp4', 'http://timg.bdta.pro/images/bd775c3670197f025b5ed859c81a9e78.jpg'),
(23779, 1624, 'Hell on Wheels S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105436.mp4', 'http://timg.bdta.pro/images/98782794ab792f630dded2191942394b.jpg'),
(23780, 1624, 'Hell on Wheels S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105437.mp4', 'http://timg.bdta.pro/images/96e62f24f36a99460c3a8c5f308c906f.jpg'),
(23781, 1624, 'Hell on Wheels S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105438.mp4', 'http://timg.bdta.pro/images/bc07be7b80da4b8b8ea06743ec816d4b.jpg'),
(23782, 1625, 'Hell on Wheels S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105439.mp4', 'http://timg.bdta.pro/images/00ef0356ba53e224df66020e3c582129.jpg'),
(23783, 1625, 'Hell on Wheels S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105440.mp4', 'http://timg.bdta.pro/images/daa832613c107779b009235b8e27468a.jpg'),
(23784, 1625, 'Hell on Wheels S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105441.mp4', 'http://timg.bdta.pro/images/e2ddcb2681e2aa792bd63228aeeedce7.jpg'),
(23785, 1625, 'Hell on Wheels S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105442.mp4', 'http://timg.bdta.pro/images/1cf4e2ca2c917d738d88a4c62f8a6f24.jpg'),
(23786, 1625, 'Hell on Wheels S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105443.mp4', 'http://timg.bdta.pro/images/ba34aac076aaa3863bf4fcb16d255b5a.jpg'),
(23787, 1625, 'Hell on Wheels S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105444.mp4', 'http://timg.bdta.pro/images/fb904702ef8e01084b22f4b9e9097abb.jpg'),
(23788, 1625, 'Hell on Wheels S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105445.mp4', 'http://timg.bdta.pro/images/2db5eeb88aec6f56e5411db3a1cf2df8.jpg'),
(23789, 1625, 'Hell on Wheels S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105446.mp4', 'http://timg.bdta.pro/images/fa4cecd2f8929377b768c0a2feb1150f.jpg'),
(23790, 1625, 'Hell on Wheels S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105447.mp4', 'http://timg.bdta.pro/images/ca005c5ae77b9515428f7323741ad0c0.jpg'),
(23791, 1625, 'Hell on Wheels S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105448.mp4', 'http://timg.bdta.pro/images/3e26cad6ef0667581c9f41506e44b6a8.jpg'),
(23792, 1625, 'Hell on Wheels S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105449.mp4', 'http://timg.bdta.pro/images/edc84a1cfe10ae43c7c56613a1132efe.jpg'),
(23793, 1625, 'Hell on Wheels S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105450.mp4', 'http://timg.bdta.pro/images/2be0059e3bed8b54e1d4b9c190b3453f.jpg'),
(23794, 1625, 'Hell on Wheels S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/105451.mp4', 'http://timg.bdta.pro/images/b336424ac985dcce05b2bfcd1e2bc824.jpg'),
(23795, 1626, 'Hell on Wheels S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105452.mp4', 'http://timg.bdta.pro/images/b9a4874a46c22499141022ad1bf22dc7.jpg'),
(23796, 1626, 'Hell on Wheels S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105453.mp4', 'http://timg.bdta.pro/images/46491ed6f77d52ca758e130a85f17774.jpg'),
(23797, 1626, 'Hell on Wheels S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105454.mp4', 'http://timg.bdta.pro/images/7d0358ef9f5eabddba336738ef07ab46.jpg'),
(23798, 1626, 'Hell on Wheels S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105455.mp4', 'http://timg.bdta.pro/images/f2cbd4f61e6c4569c319fda3554268c7.jpg'),
(23799, 1626, 'Hell on Wheels S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105456.mp4', 'http://timg.bdta.pro/images/1b60a8732acd4ca40a5001f2ecbc492e.jpg'),
(23800, 1626, 'Hell on Wheels S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105457.mp4', 'http://timg.bdta.pro/images/5cc180ee19b1bae1110937a4290ae841.jpg'),
(23801, 1626, 'Hell on Wheels S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105458.mp4', 'http://timg.bdta.pro/images/d066f34fd8a83b3b72789d9970d36120.jpg'),
(23802, 1626, 'Hell on Wheels S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105459.mp4', 'http://timg.bdta.pro/images/9b11da960540d0a771b95acd76070c30.jpg'),
(23803, 1626, 'Hell on Wheels S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105460.mp4', 'http://timg.bdta.pro/images/75760fea42009327722bc4344e5038db.jpg'),
(23804, 1626, 'Hell on Wheels S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105461.mp4', 'http://timg.bdta.pro/images/408a8dbfd642abcc6d6c5e4c6b9747a3.jpg'),
(23805, 1626, 'Hell on Wheels S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/105462.mp4', 'http://timg.bdta.pro/images/0277a8de3c3be820513815aefb8df392.jpg'),
(23806, 1626, 'Hell on Wheels S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/105463.mp4', 'http://timg.bdta.pro/images/95e4b08a7c8af69b870e1900e285c14f.jpg'),
(23807, 1626, 'Hell on Wheels S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/105464.mp4', 'http://timg.bdta.pro/images/b3c6f9af3496ff0fd4268cc1e306ae20.jpg'),
(23808, 1626, 'Hell on Wheels S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/105465.mp4', 'http://timg.bdta.pro/images/7ae5a5663d15563ddbff07c2505b52d9.jpg'),
(23809, 1627, 'The Grand Tour S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170806.mp4', 'http://timg.bdta.pro/images/bc05a3c4764b336e1d30d9532cbfb96c.jpg'),
(23810, 1627, 'The Grand Tour S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170807.mp4', 'http://timg.bdta.pro/images/3af0b5f0a9134d8d745742cb3340c0c0.jpg'),
(23811, 1627, 'The Grand Tour S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170808.mp4', 'http://timg.bdta.pro/images/06c1f62768af70a56a9694783f3dcecc.jpg'),
(23812, 1627, 'The Grand Tour S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170809.mp4', 'http://timg.bdta.pro/images/a32af283743ee699104cf1689992061f.jpg'),
(23813, 1627, 'The Grand Tour S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170810.mp4', 'http://timg.bdta.pro/images/e5f9b2bcd0b09d03003f77dae3e09b20.jpg'),
(23814, 1627, 'The Grand Tour S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170811.mp4', 'http://timg.bdta.pro/images/408783b0e1d8f5451084b38413dcd7ee.jpg'),
(23815, 1627, 'The Grand Tour S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170812.mp4', 'http://timg.bdta.pro/images/ec2ad8af79805f2decf0e095a1a702ad.jpg'),
(23816, 1627, 'The Grand Tour S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170813.mp4', 'http://timg.bdta.pro/images/49256ce4b8f5ee1a4e5758ecd234f105.jpg'),
(23817, 1627, 'The Grand Tour S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170814.mp4', 'http://timg.bdta.pro/images/e31799f3040d891933c608d1a33d35a4.jpg'),
(23818, 1627, 'The Grand Tour S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170815.mp4', 'http://timg.bdta.pro/images/f123b766fd6d9d143d3166286d865a5e.jpg'),
(23819, 1627, 'The Grand Tour S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170816.mp4', 'http://timg.bdta.pro/images/096a623ab7f0201df0956bb46351a632.jpg'),
(23820, 1627, 'The Grand Tour S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170817.mp4', 'http://timg.bdta.pro/images/75300f8c70e259e60a85792572f53381.jpg'),
(23821, 1627, 'The Grand Tour S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/170818.mp4', 'http://timg.bdta.pro/images/112eb1560c8ce776896964cfdffb6493.jpg'),
(23822, 1628, 'The Grand Tour S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170819.mp4', 'http://timg.bdta.pro/images/9a19385c701c324ca801590b4e9514a9.jpg'),
(23823, 1628, 'The Grand Tour S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170820.mp4', 'http://timg.bdta.pro/images/a82dfbcb33a7b4c0ddf7d4e1d2c00b15.jpg'),
(23824, 1628, 'The Grand Tour S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170821.mp4', 'http://timg.bdta.pro/images/5e0ae9f6c34e7e9a1084b8bd0d9d4ca3.jpg'),
(23825, 1628, 'The Grand Tour S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170822.mp4', 'http://timg.bdta.pro/images/eab23fc034fdb32d7e5b26b295d837cb.jpg'),
(23826, 1628, 'The Grand Tour S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170823.mp4', 'http://timg.bdta.pro/images/9450e145d65279279c137d0c219994b8.jpg'),
(23827, 1628, 'The Grand Tour S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170824.mp4', 'http://timg.bdta.pro/images/24bad02cd03355629a4c603c6cd79841.jpg'),
(23828, 1628, 'The Grand Tour S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170825.mp4', 'http://timg.bdta.pro/images/55a7b14d16d24353a28e77df876e7a79.jpg'),
(23829, 1628, 'The Grand Tour S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170826.mp4', 'http://timg.bdta.pro/images/f44eb7657208c0fa731ab4bb08b09a27.jpg'),
(23830, 1628, 'The Grand Tour S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170827.mp4', 'http://timg.bdta.pro/images/d491c4602e2093612d07ac19ddd93850.jpg'),
(23831, 1628, 'The Grand Tour S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170828.mp4', 'http://timg.bdta.pro/images/7166e8e71fcefc3fceb8d0434f0f39c4.jpg'),
(23832, 1628, 'The Grand Tour S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170829.mp4', 'http://timg.bdta.pro/images/c3483e238a72319d36eb49a0ed8c7992.jpg'),
(23833, 1629, 'The Grand Tour S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170830.mp4', 'http://timg.bdta.pro/images/be75cfc1c19350810450360f7e5b5e27.jpg'),
(23834, 1629, 'The Grand Tour S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170831.mp4', 'http://timg.bdta.pro/images/642760ef57a39e5d5d4c8b9306a4afe0.jpg'),
(23835, 1629, 'The Grand Tour S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170832.mp4', 'http://timg.bdta.pro/images/0fbaf11fee10117c9e63544d82624c1e.jpg'),
(23836, 1629, 'The Grand Tour S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170833.mp4', 'http://timg.bdta.pro/images/ca1a1571986ca897b460747040fedf74.jpg'),
(23837, 1629, 'The Grand Tour S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170834.mp4', 'http://timg.bdta.pro/images/0e74df60cfd995ae209f80b8c07428ef.jpg'),
(23838, 1629, 'The Grand Tour S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170835.mp4', 'http://timg.bdta.pro/images/ac0c0670b8a3355955348a415a978761.jpg'),
(23839, 1629, 'The Grand Tour S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170836.mp4', 'http://timg.bdta.pro/images/edd65b3ab60b0258b7eca44e8a9920cd.jpg'),
(23840, 1629, 'The Grand Tour S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170837.mp4', 'http://timg.bdta.pro/images/cd422287bbab4d5ed21163758842d02b.jpg'),
(23841, 1629, 'The Grand Tour S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170838.mp4', 'http://timg.bdta.pro/images/1495df3d7d3c61e8552f852127408732.jpg'),
(23842, 1629, 'The Grand Tour S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170839.mp4', 'http://timg.bdta.pro/images/cb429d03471c6b1036549bb720e87e88.jpg'),
(23843, 1629, 'The Grand Tour S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170840.mp4', 'http://timg.bdta.pro/images/aa86b2c96215d36f227efc749b18ae06.jpg'),
(23844, 1629, 'The Grand Tour S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170841.mp4', 'http://timg.bdta.pro/images/39bd1173c6b71d947a83559516bc49f1.jpg'),
(23845, 1629, 'The Grand Tour S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/170842.mp4', 'http://timg.bdta.pro/images/569210837a671e6c38ebf0639bafc274.jpg'),
(23846, 1629, 'The Grand Tour S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/170843.mp4', 'http://timg.bdta.pro/images/80fa13bc9faa031cabda98b31957090c.jpg'),
(23847, 1630, 'The Grand Tour S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170844.mp4', 'http://timg.bdta.pro/images/d79c9a2f776e96a9b19a1ecc7e505e12.jpg'),
(23848, 1630, 'The Grand Tour S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170845.mp4', 'http://timg.bdta.pro/images/a3d98bfe4446a6ea82e4b97fbd06b641.jpg'),
(23849, 1630, 'The Grand Tour S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170846.mp4', 'http://timg.bdta.pro/images/b932ccce9769cf3d79d6cfedafd22d25.jpg'),
(23850, 1630, 'The Grand Tour S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170847.mp4', 'http://image.tmdb.org/t/p/w1280/iUh276erB53XtsBQnFfaU50C4ei.jpg'),
(23851, 1631, 'The Grand Tour S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ZKmkE9ihZ4APgP3Hc6AW7Fglx7.jpg'),
(23852, 1631, 'The Grand Tour S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ePwNk9lS6h5fHAKn79DnZ23AMSq.jpg'),
(23853, 1631, 'The Grand Tour S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/275024.mp4', 'http://gstaticontent.com/images/ryuUHw2CNEdXafg4e5FuiUJpvVK_big.jpg'),
(23854, 1632, 'The Grand Tour S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/454252.mp4', 'http://gstaticontent.com/images/ryuUHw2CNEdXafg4e5FuiUJpvVK_big.jpg'),
(23855, 1633, 'Dinheiro Sujo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105405.mp4', 'http://timg.bdta.pro/images/ca11ae4029aa9fa5aff79c99e0294ee4.jpg'),
(23856, 1633, 'Dinheiro Sujo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105406.mp4', 'http://timg.bdta.pro/images/8aff1489f74f76b0eb9ab07b0dba8d64.jpg'),
(23857, 1633, 'Dinheiro Sujo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105407.mp4', 'http://timg.bdta.pro/images/d9a7bcf0865fb2247414242f5e4a80fa.jpg'),
(23858, 1633, 'Dinheiro Sujo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105408.mp4', 'http://timg.bdta.pro/images/950c1eed4c845ee7ba9644400170c45b.jpg'),
(23859, 1634, 'Além da Imaginação S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105395.mp4', 'http://timg.bdta.pro/images/0156d2d55dc735b211e7def10ea1d598.jpg'),
(23860, 1634, 'Além da Imaginação S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105396.mp4', 'http://timg.bdta.pro/images/8afc0a6c5f663e8498e4577eaa53b138.jpg'),
(23861, 1634, 'Além da Imaginação S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105397.mp4', 'http://timg.bdta.pro/images/3a512f26d197915f9088ec3537b810e2.jpg'),
(23862, 1634, 'Além da Imaginação S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105398.mp4', 'http://timg.bdta.pro/images/fcb39093b807c5ee1fa3e8de153f6e2e.jpg'),
(23863, 1634, 'Além da Imaginação S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105399.mp4', 'http://timg.bdta.pro/images/36d20581d0d309bfec285afcffadcd6d.jpg'),
(23864, 1634, 'Além da Imaginação S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105400.mp4', 'http://timg.bdta.pro/images/912f67e2e850817ef843c57cbed7462f.jpg'),
(23865, 1634, 'Além da Imaginação S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/105401.mp4', 'http://timg.bdta.pro/images/51fe54b1f5700647bc12ce6cc6432cfb.jpg'),
(23866, 1634, 'Além da Imaginação S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/105402.mp4', 'http://timg.bdta.pro/images/a0ed00a36c9fcbaf10fb4151d2167938.jpg'),
(23867, 1634, 'Além da Imaginação S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/105403.mp4', 'http://timg.bdta.pro/images/86b1eb07278fa52263687d28b5dd3a8a.jpg'),
(23868, 1634, 'Além da Imaginação S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/105404.mp4', 'http://timg.bdta.pro/images/bea17f018b80262332c00ce292ee8f0e.jpg'),
(23869, 1635, 'A Terra à Noite: Visão Noturna S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/105389.mp4', 'http://timg.bdta.pro/images/50d8dd5603a92515c6cac3b82da42939.jpg'),
(23870, 1635, 'A Terra à Noite: Visão Noturna S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/105390.mp4', 'http://timg.bdta.pro/images/7f9b6cd94e2a9ec7591107b909a94287.jpg'),
(23871, 1635, 'A Terra à Noite: Visão Noturna S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/105391.mp4', 'http://timg.bdta.pro/images/07200a5fc31ff407261067e824df9d5d.jpg'),
(23872, 1635, 'A Terra à Noite: Visão Noturna S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/105392.mp4', 'http://timg.bdta.pro/images/aa6991d23e4ea5e78e7208ee7688f5fd.jpg'),
(23873, 1635, 'A Terra à Noite: Visão Noturna S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/105393.mp4', 'http://timg.bdta.pro/images/854144991e02a0e06ced4b6db8b3ae4b.jpg'),
(23874, 1635, 'A Terra à Noite: Visão Noturna S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/105394.mp4', 'http://timg.bdta.pro/images/3d9331952bec93b99808dd89222373b2.jpg'),
(23875, 1636, 'A Guarda do Leão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113207.mp4', 'http://timg.bdta.pro/images/3ce4c536e6516687e2c0530574b02f83.jpg'),
(23876, 1636, 'A Guarda do Leão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113208.mp4', 'http://timg.bdta.pro/images/3bc76943601fea2f5b31c1bb962d13ee.jpg'),
(23877, 1636, 'A Guarda do Leão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113209.mp4', 'http://timg.bdta.pro/images/557dc6ea52a2c8cdb467832f5d2a2817.jpg'),
(23878, 1636, 'A Guarda do Leão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113210.mp4', 'http://timg.bdta.pro/images/bb15435c6b505a950875c757e125d913.jpg'),
(23879, 1636, 'A Guarda do Leão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113211.mp4', 'http://timg.bdta.pro/images/fe99a9c380b110a40a21bbf82402614a.jpg'),
(23880, 1636, 'A Guarda do Leão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113212.mp4', 'http://timg.bdta.pro/images/fac4b9b67d240bd1d9f490d41f22440f.jpg'),
(23881, 1636, 'A Guarda do Leão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113213.mp4', 'http://timg.bdta.pro/images/bd82c5d35782ade4ef7647300e4e8f8f.jpg'),
(23882, 1636, 'A Guarda do Leão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113214.mp4', 'http://timg.bdta.pro/images/bb0044c1ac3003ab1b9967131b26a0f3.jpg'),
(23883, 1636, 'A Guarda do Leão S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113215.mp4', 'http://timg.bdta.pro/images/f7db29390ef25486698c845893d374d9.jpg'),
(23884, 1636, 'A Guarda do Leão S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113216.mp4', 'http://timg.bdta.pro/images/c5ae086215e3a6f00add6a93af4d5c65.jpg'),
(23885, 1636, 'A Guarda do Leão S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113217.mp4', 'http://timg.bdta.pro/images/37574a16137af1c21d3f68915d1348ef.jpg'),
(23886, 1636, 'A Guarda do Leão S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113218.mp4', 'http://timg.bdta.pro/images/84a372526fd5d937a2bfd008468ec60d.jpg'),
(23887, 1636, 'A Guarda do Leão S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113219.mp4', 'http://timg.bdta.pro/images/3c71a12051656877c37487466def8215.jpg'),
(23888, 1636, 'A Guarda do Leão S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113220.mp4', 'http://timg.bdta.pro/images/a80a700a08986e6a10d8e7534510a5a1.jpg'),
(23889, 1636, 'A Guarda do Leão S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113221.mp4', 'http://timg.bdta.pro/images/0cf4fe45923ddc263fed3140d24fed54.jpg'),
(23890, 1636, 'A Guarda do Leão S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113222.mp4', 'http://timg.bdta.pro/images/32e3a0f331a6feb16b161755355fb13e.jpg'),
(23891, 1636, 'A Guarda do Leão S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113223.mp4', 'http://timg.bdta.pro/images/61db6b6cca10eafdf3f750436070b91f.jpg'),
(23892, 1636, 'A Guarda do Leão S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113224.mp4', 'http://timg.bdta.pro/images/15439014bb1d4bd7b1452e345b6e38ac.jpg'),
(23893, 1636, 'A Guarda do Leão S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113225.mp4', 'http://timg.bdta.pro/images/a7f92c7f147e56bb20d60c23a852e0da.jpg'),
(23894, 1636, 'A Guarda do Leão S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/113226.mp4', 'http://timg.bdta.pro/images/6ff9992d161acc0a71299bf9130fb76b.jpg'),
(23895, 1636, 'A Guarda do Leão S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/113227.mp4', 'http://timg.bdta.pro/images/12a75a5d4e5a48aa926f484302fde9b6.jpg'),
(23896, 1636, 'A Guarda do Leão S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/113228.mp4', 'http://timg.bdta.pro/images/fa6b7609f2a7422c85c230fdbddb22fd.jpg'),
(23897, 1636, 'A Guarda do Leão S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/113229.mp4', 'http://timg.bdta.pro/images/df7ec1260d63fee52a73ffaea2fe7ad6.jpg'),
(23898, 1636, 'A Guarda do Leão S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/113230.mp4', 'http://timg.bdta.pro/images/bb3732f34c4178ff318617465471ef55.jpg'),
(23899, 1636, 'A Guarda do Leão S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/113231.mp4', 'http://timg.bdta.pro/images/af46e8d008725f3a60c14de8063fe994.jpg'),
(23900, 1636, 'A Guarda do Leão S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/113232.mp4', 'http://timg.bdta.pro/images/0005f4b50327070f89a65f9451745a94.jpg'),
(23901, 1636, 'A Guarda do Leão S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/113233.mp4', 'http://gstaticontent.com/images/7hab4OnSLtgULjai9pHMQoo6Yap_big.jpg'),
(23902, 1636, 'A Guarda do Leão S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/113234.mp4', 'http://gstaticontent.com/images/7hab4OnSLtgULjai9pHMQoo6Yap_big.jpg'),
(23903, 1637, 'A Guarda do Leão S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113235.mp4', 'http://timg.bdta.pro/images/8ecf0c72afb540101f84ffb3ab461a6b.jpg'),
(23904, 1637, 'A Guarda do Leão S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113236.mp4', 'http://timg.bdta.pro/images/b8ab5cd5fd129d50f22b5fe21355665e.jpg'),
(23905, 1637, 'A Guarda do Leão S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113237.mp4', 'http://timg.bdta.pro/images/3504fd79c716c67de7c176dd3462d393.jpg'),
(23906, 1637, 'A Guarda do Leão S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113238.mp4', 'http://timg.bdta.pro/images/8ae24f91f39d5471775d83bc5f69c2dd.jpg'),
(23907, 1637, 'A Guarda do Leão S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113239.mp4', 'http://timg.bdta.pro/images/49dbe5a131f0d44a61678909aa7a22d6.jpg'),
(23908, 1637, 'A Guarda do Leão S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113240.mp4', 'http://timg.bdta.pro/images/79d1ff6eb34d0e1b96b816ad5073e306.jpg'),
(23909, 1637, 'A Guarda do Leão S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113241.mp4', 'http://timg.bdta.pro/images/1b3bc78573ab9e0f8477aa656e27dd14.jpg'),
(23910, 1637, 'A Guarda do Leão S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113242.mp4', 'http://timg.bdta.pro/images/41a5d3648eaeb4ef324bd3f0dba5a684.jpg'),
(23911, 1637, 'A Guarda do Leão S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113243.mp4', 'http://timg.bdta.pro/images/c678e34b4c681c0771720d6f8f6cf330.jpg'),
(23912, 1637, 'A Guarda do Leão S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113244.mp4', 'http://timg.bdta.pro/images/6d76d09405e2dabb18bace201e956072.jpg'),
(23913, 1637, 'A Guarda do Leão S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113245.mp4', 'http://timg.bdta.pro/images/101599b58ceb0099fa03e0930e61575c.jpg'),
(23914, 1637, 'A Guarda do Leão S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113246.mp4', 'http://timg.bdta.pro/images/e1641ef762064c0e72f2e7011e380cb3.jpg'),
(23915, 1637, 'A Guarda do Leão S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113247.mp4', 'http://timg.bdta.pro/images/fa1299094bfa8f52ec9ed783dca074d0.jpg'),
(23916, 1637, 'A Guarda do Leão S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113248.mp4', 'http://timg.bdta.pro/images/8c6e677a7e201cb4a8ec47ce171544c9.jpg'),
(23917, 1637, 'A Guarda do Leão S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113249.mp4', 'http://timg.bdta.pro/images/065d9f2110f3e5bbfa6f54a7279a8d1d.jpg'),
(23918, 1637, 'A Guarda do Leão S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113250.mp4', 'http://timg.bdta.pro/images/24df15c8ad6dfb55fe1e1cc4c6bf7fb0.jpg'),
(23919, 1637, 'A Guarda do Leão S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113251.mp4', 'http://timg.bdta.pro/images/c28a50e2b226bc97c3941be24b64049a.jpg'),
(23920, 1637, 'A Guarda do Leão S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113252.mp4', 'http://timg.bdta.pro/images/36b25d34a28519e85e1e96b4d8308e53.jpg'),
(23921, 1637, 'A Guarda do Leão S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113253.mp4', 'http://timg.bdta.pro/images/61b43d5df1ad0363bf9b795b36a32632.jpg'),
(23922, 1637, 'A Guarda do Leão S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/113254.mp4', 'http://timg.bdta.pro/images/295b9c8dd5ba918f59b1afa1daf6f760.jpg'),
(23923, 1637, 'A Guarda do Leão S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/113255.mp4', 'http://gstaticontent.com/images/7hab4OnSLtgULjai9pHMQoo6Yap_big.jpg'),
(23924, 1637, 'A Guarda do Leão S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/113256.mp4', 'http://gstaticontent.com/images/7hab4OnSLtgULjai9pHMQoo6Yap_big.jpg'),
(23925, 1637, 'A Guarda do Leão S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/113257.mp4', 'http://gstaticontent.com/images/7hab4OnSLtgULjai9pHMQoo6Yap_big.jpg'),
(23926, 1637, 'A Guarda do Leão S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/113258.mp4', 'http://gstaticontent.com/images/7hab4OnSLtgULjai9pHMQoo6Yap_big.jpg'),
(23927, 1637, 'A Guarda do Leão S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/113259.mp4', 'http://gstaticontent.com/images/7hab4OnSLtgULjai9pHMQoo6Yap_big.jpg'),
(23928, 1637, 'A Guarda do Leão S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/113260.mp4', 'http://gstaticontent.com/images/7hab4OnSLtgULjai9pHMQoo6Yap_big.jpg'),
(23929, 1638, 'A Guarda do Leão S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113261.mp4', 'http://timg.bdta.pro/images/ae58e32948610f8707b36c9689dadbc8.jpg'),
(23930, 1638, 'A Guarda do Leão S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113262.mp4', 'http://gstaticontent.com/images/7hab4OnSLtgULjai9pHMQoo6Yap_big.jpg'),
(23931, 1638, 'A Guarda do Leão S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113263.mp4', 'http://timg.bdta.pro/images/71285b2c035f6cc61016da8486e72a65.jpg'),
(23932, 1638, 'A Guarda do Leão S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113264.mp4', 'http://timg.bdta.pro/images/bdaca36699b3b6179a5ba238b533b68d.jpg'),
(23933, 1638, 'A Guarda do Leão S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113265.mp4', 'http://timg.bdta.pro/images/a00dd48aed9b6de12695af6505799287.jpg'),
(23934, 1638, 'A Guarda do Leão S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113266.mp4', 'http://timg.bdta.pro/images/dd8b867e411189d35ffde11bf80f6442.jpg'),
(23935, 1638, 'A Guarda do Leão S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113267.mp4', 'http://timg.bdta.pro/images/584cf68c32fbd998abfa3674ec1ad0cb.jpg'),
(23936, 1638, 'A Guarda do Leão S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113268.mp4', 'http://timg.bdta.pro/images/c08e7141de676e6da3825de23477241f.jpg'),
(23937, 1638, 'A Guarda do Leão S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113269.mp4', 'http://timg.bdta.pro/images/469fb5ba0a77816bfc707c167ad0ad58.jpg'),
(23938, 1638, 'A Guarda do Leão S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113270.mp4', 'http://timg.bdta.pro/images/60ce183f4d211d000e855adf95167075.jpg'),
(23939, 1638, 'A Guarda do Leão S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113271.mp4', 'http://timg.bdta.pro/images/b9e67104865a86ecf7713219d11e4215.jpg'),
(23940, 1638, 'A Guarda do Leão S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113272.mp4', 'http://timg.bdta.pro/images/b0486463f6bc1c51f8a9be2c597479ea.jpg'),
(23941, 1638, 'A Guarda do Leão S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113273.mp4', 'http://timg.bdta.pro/images/ca133341cde2716a92b60e701c3154f6.jpg'),
(23942, 1638, 'A Guarda do Leão S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113274.mp4', 'http://timg.bdta.pro/images/f749f4d557c6965e08415a1ead9b1e10.jpg'),
(23943, 1638, 'A Guarda do Leão S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113275.mp4', 'http://timg.bdta.pro/images/01d9ab0b90872c74b006c327bb8ef58b.jpg'),
(23944, 1638, 'A Guarda do Leão S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113276.mp4', 'http://timg.bdta.pro/images/058010c737ac02b2b1c5e95c7dfd71e4.jpg'),
(23945, 1638, 'A Guarda do Leão S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113277.mp4', 'http://timg.bdta.pro/images/d2fc818686ffd239dcbc9e2d530c48eb.jpg'),
(23946, 1638, 'A Guarda do Leão S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113278.mp4', 'http://timg.bdta.pro/images/266bb1eceb8b01df9531b2b0aa36579e.jpg'),
(23947, 1638, 'A Guarda do Leão S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113279.mp4', 'http://timg.bdta.pro/images/b9e7a902fcff6f9d64578b4ac3ae23d6.jpg'),
(23948, 1639, 'A Zona S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110539.mp4', 'http://timg.bdta.pro/images/8d6328130262d6030300dd3ce5720c70.jpg'),
(23949, 1639, 'A Zona S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110540.mp4', 'http://timg.bdta.pro/images/7c83fe5b3da24a4db43bc1f106f54889.jpg'),
(23950, 1639, 'A Zona S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110541.mp4', 'http://timg.bdta.pro/images/8d94fba6110ff0ff130f7f65b49946ca.jpg'),
(23951, 1639, 'A Zona S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110542.mp4', 'http://timg.bdta.pro/images/4e450706ada31b8c9a092c55203708c8.jpg'),
(23952, 1639, 'A Zona S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110543.mp4', 'http://timg.bdta.pro/images/0b89a3d62ab7e40db5d7aae7f189cd3b.jpg'),
(23953, 1639, 'A Zona S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110544.mp4', 'http://timg.bdta.pro/images/59f3d666a3cbe49b597af0bf4b859789.jpg'),
(23954, 1639, 'A Zona S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110545.mp4', 'http://timg.bdta.pro/images/820e910b4dff887a0102864456e6c23c.jpg'),
(23955, 1639, 'A Zona S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110546.mp4', 'http://timg.bdta.pro/images/6248369c70844dca39d790222affc959.jpg'),
(23956, 1640, 'O Exército Esquecido S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108507.mp4', 'http://timg.bdta.pro/images/5a35341a88bf299a44974dd867de9a97.jpg'),
(23957, 1640, 'O Exército Esquecido S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108508.mp4', 'http://timg.bdta.pro/images/5a79b6a4f437390c464f79d64ab6f2a6.jpg'),
(23958, 1640, 'O Exército Esquecido S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108509.mp4', 'http://timg.bdta.pro/images/8459e10ce118c5fcbf15ea015a344fd5.jpg'),
(23959, 1640, 'O Exército Esquecido S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108510.mp4', 'http://timg.bdta.pro/images/1c3cb125a6aeb85a152ad3bf83239c7b.jpg'),
(23960, 1640, 'O Exército Esquecido S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108511.mp4', 'http://timg.bdta.pro/images/5285995d59146993d62a71dd02d804fe.jpg'),
(23961, 1641, 'Chuck S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108423.mp4', 'http://timg.bdta.pro/images/5c30f3863676319cccacbd05f724375f.jpg'),
(23962, 1641, 'Chuck S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108424.mp4', 'http://timg.bdta.pro/images/2ece7a420193aa8090fdf1a60dfac6f6.jpg'),
(23963, 1641, 'Chuck S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108425.mp4', 'http://timg.bdta.pro/images/34c4ce2b5047c8a8e514c22e6ba4e2ca.jpg'),
(23964, 1641, 'Chuck S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108426.mp4', 'http://timg.bdta.pro/images/b11fb18cbb499ae6fd299af8700cf46d.jpg'),
(23965, 1641, 'Chuck S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108427.mp4', 'http://timg.bdta.pro/images/eb295ede8dfbbf66d1e43d7551ba0fef.jpg'),
(23966, 1641, 'Chuck S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108428.mp4', 'http://timg.bdta.pro/images/256310556a3c7009d7e19cc2578398d8.jpg'),
(23967, 1641, 'Chuck S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108429.mp4', 'http://timg.bdta.pro/images/3f8db4c7210d69ad3fb44cf1c1aea0b9.jpg'),
(23968, 1641, 'Chuck S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108430.mp4', 'http://timg.bdta.pro/images/c2a4c41906048fb08e802a5c03dc6e35.jpg'),
(23969, 1641, 'Chuck S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108431.mp4', 'http://timg.bdta.pro/images/ccd7df1dac57d44f4f5012d38aaef3c3.jpg'),
(23970, 1641, 'Chuck S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108432.mp4', 'http://timg.bdta.pro/images/ce2b0e4295f8f98f43db6a6e364bbe81.jpg'),
(23971, 1641, 'Chuck S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108433.mp4', 'http://timg.bdta.pro/images/bde7961d7f29c01b761cd797ca7f54d5.jpg'),
(23972, 1641, 'Chuck S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108434.mp4', 'http://timg.bdta.pro/images/798d60b3bdfc8d2f7155b290c0a41195.jpg'),
(23973, 1641, 'Chuck S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108435.mp4', 'http://timg.bdta.pro/images/de168740feb8de155c45609edc2075f4.jpg'),
(23974, 1642, 'Chuck S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108436.mp4', 'http://timg.bdta.pro/images/9fd5124f5d87c24766124a15ba8866f2.jpg'),
(23975, 1642, 'Chuck S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108437.mp4', 'http://timg.bdta.pro/images/fc17871b7b8e202d59b8ddfd1da69cb7.jpg'),
(23976, 1642, 'Chuck S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108438.mp4', 'http://timg.bdta.pro/images/cfafb697177b53664c841fdb14edfd9c.jpg'),
(23977, 1642, 'Chuck S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108439.mp4', 'http://timg.bdta.pro/images/ab9ebb2fa269081b74936c4f13e0b748.jpg'),
(23978, 1642, 'Chuck S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108440.mp4', 'http://timg.bdta.pro/images/12e2574f4d6548f2b0a15c801ac36e26.jpg'),
(23979, 1642, 'Chuck S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108441.mp4', 'http://timg.bdta.pro/images/91136a4c33fa5de664de9c29f00167a1.jpg'),
(23980, 1642, 'Chuck S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108442.mp4', 'http://timg.bdta.pro/images/5a72df6e0f52693b030d637e57db0762.jpg'),
(23981, 1642, 'Chuck S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108443.mp4', 'http://timg.bdta.pro/images/dd8f8670d140a59c444c53267c354c34.jpg'),
(23982, 1642, 'Chuck S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108444.mp4', 'http://timg.bdta.pro/images/8656791199a897e83addd5d1981bfbd4.jpg'),
(23983, 1642, 'Chuck S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108445.mp4', 'http://timg.bdta.pro/images/cc7b9088baf3dc48a6269a249acaae7f.jpg'),
(23984, 1642, 'Chuck S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108446.mp4', 'http://timg.bdta.pro/images/d20e13ec310da2026a2266cebdc459fe.jpg'),
(23985, 1642, 'Chuck S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108447.mp4', 'http://timg.bdta.pro/images/d9e46bc2ddc5b3cbeca37b99353fc4b1.jpg'),
(23986, 1642, 'Chuck S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108448.mp4', 'http://timg.bdta.pro/images/e89258ac67551660e80ce9dcbeaf09ab.jpg'),
(23987, 1642, 'Chuck S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108449.mp4', 'http://timg.bdta.pro/images/5c67da413eb1ad968ef6c3fdfbff4565.jpg'),
(23988, 1642, 'Chuck S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108450.mp4', 'http://timg.bdta.pro/images/b9ad05a422635d760d3a027613335ddf.jpg'),
(23989, 1643, 'Chuck S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108451.mp4', 'http://timg.bdta.pro/images/1624ce18339fc6a1c8bb5cac1960f603.jpg'),
(23990, 1643, 'Chuck S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108452.mp4', 'http://timg.bdta.pro/images/def9b421dc9e5262d9c5a1d6e4d7c9ea.jpg'),
(23991, 1643, 'Chuck S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108453.mp4', 'http://timg.bdta.pro/images/89815e53d9df402504481f2b0de3358e.jpg'),
(23992, 1643, 'Chuck S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108454.mp4', 'http://timg.bdta.pro/images/b55e2cd76e9654df8ea68b4d44342b9a.jpg'),
(23993, 1643, 'Chuck S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108455.mp4', 'http://timg.bdta.pro/images/ffdcbe67afb219a4790e5393700baf53.jpg'),
(23994, 1643, 'Chuck S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108456.mp4', 'http://timg.bdta.pro/images/4d8608ab6cb06fe576ba8666ff66f99c.jpg'),
(23995, 1643, 'Chuck S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108457.mp4', 'http://timg.bdta.pro/images/83677c321ac46a08ae87c667226bd980.jpg'),
(23996, 1643, 'Chuck S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108458.mp4', 'http://timg.bdta.pro/images/12c700ec594a5094e41e143366d091b7.jpg'),
(23997, 1643, 'Chuck S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108459.mp4', 'http://timg.bdta.pro/images/24d17363a3a621dd025f1055ef7e7e9f.jpg'),
(23998, 1643, 'Chuck S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108460.mp4', 'http://timg.bdta.pro/images/0cbcf28bc26760b89727355f36f56135.jpg'),
(23999, 1643, 'Chuck S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108461.mp4', 'http://timg.bdta.pro/images/a76d4267a5eeaf93d50c4c9bf557a723.jpg'),
(24000, 1643, 'Chuck S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108462.mp4', 'http://timg.bdta.pro/images/7abddab368906f11b39001fb024f8b75.jpg'),
(24001, 1643, 'Chuck S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108463.mp4', 'http://timg.bdta.pro/images/c5de5c5bf0c8eead69e019647fb6d95c.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(24002, 1643, 'Chuck S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108464.mp4', 'http://timg.bdta.pro/images/cfb3eb209fd11c594cb31b266ccdc5ec.jpg'),
(24003, 1643, 'Chuck S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108465.mp4', 'http://timg.bdta.pro/images/84e75ec461e7a193bb214e730b772248.jpg'),
(24004, 1643, 'Chuck S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108466.mp4', 'http://timg.bdta.pro/images/d93da6236f3473463c74af3c8e2c1985.jpg'),
(24005, 1643, 'Chuck S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108467.mp4', 'http://timg.bdta.pro/images/b843b1083490b892a534244cc1c1b024.jpg'),
(24006, 1643, 'Chuck S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108468.mp4', 'http://timg.bdta.pro/images/e95ab5192fe4567841d7c06027aa242c.jpg'),
(24007, 1643, 'Chuck S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108469.mp4', 'http://timg.bdta.pro/images/f1132201f7fdc66c69288def44cb36da.jpg'),
(24008, 1644, 'Chuck S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108470.mp4', 'http://timg.bdta.pro/images/36a8bb63841b02dcaf7bc2ff6e1cfd70.jpg'),
(24009, 1644, 'Chuck S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108471.mp4', 'http://timg.bdta.pro/images/6e35f8ca260fb297fa85842d2db9e85e.jpg'),
(24010, 1644, 'Chuck S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108472.mp4', 'http://timg.bdta.pro/images/1fc9ee8294254fdc4b4713960d16b742.jpg'),
(24011, 1644, 'Chuck S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108473.mp4', 'http://timg.bdta.pro/images/f8417272fd004a0e9fd8d1e34fc552b3.jpg'),
(24012, 1644, 'Chuck S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108474.mp4', 'http://timg.bdta.pro/images/e48cdebe6ece3a56e6530a1354a48a8c.jpg'),
(24013, 1644, 'Chuck S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108475.mp4', 'http://timg.bdta.pro/images/0b723d1a1ef94d2231db955bebc29fd7.jpg'),
(24014, 1644, 'Chuck S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108476.mp4', 'http://timg.bdta.pro/images/7cb9ce1b2863dd07e6d43de4a4289ee1.jpg'),
(24015, 1644, 'Chuck S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108477.mp4', 'http://timg.bdta.pro/images/9f17bebf0004559d4fc7c89778ef0d4b.jpg'),
(24016, 1644, 'Chuck S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108478.mp4', 'http://timg.bdta.pro/images/8b5ac85554b99b42f693a3befb9d0b8a.jpg'),
(24017, 1644, 'Chuck S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108479.mp4', 'http://timg.bdta.pro/images/7910f5f3777e815a6c0b86f74bb76290.jpg'),
(24018, 1644, 'Chuck S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108480.mp4', 'http://timg.bdta.pro/images/64662c4206d5cb8ad77c1abc07b0687a.jpg'),
(24019, 1644, 'Chuck S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108481.mp4', 'http://timg.bdta.pro/images/cc54a8d3214bfe9ec75adf028f94ff70.jpg'),
(24020, 1644, 'Chuck S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108482.mp4', 'http://timg.bdta.pro/images/5f1108c57a512f4993376738b51a5846.jpg'),
(24021, 1644, 'Chuck S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108483.mp4', 'http://timg.bdta.pro/images/bf1ca0f0aec34c866e118c7428754fbe.jpg'),
(24022, 1644, 'Chuck S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108484.mp4', 'http://timg.bdta.pro/images/c996e3f3d7f2c16fb1125f9c79b92c42.jpg'),
(24023, 1644, 'Chuck S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108485.mp4', 'http://timg.bdta.pro/images/cafccdedc8060c06f38ee6f00d8f77cd.jpg'),
(24024, 1644, 'Chuck S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108486.mp4', 'http://timg.bdta.pro/images/4a8828a37162574713cbdb5d0538d848.jpg'),
(24025, 1644, 'Chuck S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108487.mp4', 'http://timg.bdta.pro/images/1ee5284ff1a9f2ceece7889de4a993f3.jpg'),
(24026, 1644, 'Chuck S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108488.mp4', 'http://timg.bdta.pro/images/4a0f0d762a7b155b526e952f11d22646.jpg'),
(24027, 1644, 'Chuck S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108489.mp4', 'http://timg.bdta.pro/images/796f1b2073b1d54a2cb753497255334e.jpg'),
(24028, 1644, 'Chuck S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/108490.mp4', 'http://timg.bdta.pro/images/57c06829f31d62839fd886dd549b2a81.jpg'),
(24029, 1644, 'Chuck S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/108491.mp4', 'http://timg.bdta.pro/images/5231c5ff2d1a67981d302e2aeaa37ed0.jpg'),
(24030, 1644, 'Chuck S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/108492.mp4', 'http://timg.bdta.pro/images/60d48ae3f0cdfcbb51c7297a9b679d91.jpg'),
(24031, 1644, 'Chuck S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/108493.mp4', 'http://timg.bdta.pro/images/e443f31b9a51d0cdacbc50b48e5d9ed5.jpg'),
(24032, 1645, 'Chuck S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108494.mp4', 'http://timg.bdta.pro/images/7b64e56f844a0ced06240e12a415e765.jpg'),
(24033, 1645, 'Chuck S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108495.mp4', 'http://timg.bdta.pro/images/db643c8e596cf4e89c7a56db6e4e682d.jpg'),
(24034, 1645, 'Chuck S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108496.mp4', 'http://timg.bdta.pro/images/c99e719af5a7fe35469cb8c38a51eb1c.jpg'),
(24035, 1645, 'Chuck S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108497.mp4', 'http://timg.bdta.pro/images/939a0fcbc4dd8c2a1903ac765a89e690.jpg'),
(24036, 1645, 'Chuck S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108498.mp4', 'http://timg.bdta.pro/images/711f4ea3a093d8a554bc7b9b9d924f98.jpg'),
(24037, 1645, 'Chuck S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108499.mp4', 'http://timg.bdta.pro/images/a9e67cc97f6070d180b788d1e46bbd13.jpg'),
(24038, 1645, 'Chuck S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108500.mp4', 'http://timg.bdta.pro/images/bdc848166980945aeb19d757d4778922.jpg'),
(24039, 1645, 'Chuck S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108501.mp4', 'http://timg.bdta.pro/images/b669e2f2b7675ae140ea5f642e138188.jpg'),
(24040, 1645, 'Chuck S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108502.mp4', 'http://timg.bdta.pro/images/df0c7ea5848b8048cba1f1b319b16a91.jpg'),
(24041, 1645, 'Chuck S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108503.mp4', 'http://timg.bdta.pro/images/bf9d043b82fab1a6cac4c8c58b1d9087.jpg'),
(24042, 1645, 'Chuck S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108504.mp4', 'http://timg.bdta.pro/images/c0c27e9e6ad19f20dafaa0552cdcc156.jpg'),
(24043, 1645, 'Chuck S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108505.mp4', 'http://timg.bdta.pro/images/d50c08cad8180bab7c3849245ffc28ff.jpg'),
(24044, 1645, 'Chuck S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108506.mp4', 'http://timg.bdta.pro/images/21ad7d86b479c4f528bd2cbadf010b56.jpg'),
(24045, 1646, 'Ascensão: Império Otomano S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202586.mp4', 'http://timg.bdta.pro/images/e68a20428ec7a5a0bab664ba076be3d6.jpg'),
(24046, 1646, 'Ascensão: Império Otomano S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202587.mp4', 'http://timg.bdta.pro/images/9ee4412d53e9b637a3d9291a744537fc.jpg'),
(24047, 1646, 'Ascensão: Império Otomano S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202588.mp4', 'http://timg.bdta.pro/images/dd9a254024176c553bcbc0ebb1a1f584.jpg'),
(24048, 1646, 'Ascensão: Império Otomano S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202589.mp4', 'http://timg.bdta.pro/images/0df835485187adf495bb4d661052925f.jpg'),
(24049, 1646, 'Ascensão: Império Otomano S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202590.mp4', 'http://timg.bdta.pro/images/45a32eae148bb8d12245c30830af3eda.jpg'),
(24050, 1646, 'Ascensão: Império Otomano S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202591.mp4', 'http://gstaticontent.com/images/eyzWbv6zrtsRblqc90oUGyoTyl7_big.jpg'),
(24051, 1647, 'Ascensão: Império Otomano S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rMLL4xMk8tjZPRcUhHTmLpGXckM.jpg'),
(24052, 1647, 'Ascensão: Império Otomano S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9mljTEKfQjGPPQZdXHTjuSGhhr3.jpg'),
(24053, 1647, 'Ascensão: Império Otomano S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/39FAHlFXZjVF8sZZFvgLSTE7s83.jpg'),
(24054, 1647, 'Ascensão: Império Otomano S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tUDGDOtZDFzG5w5765jaa8LWrpr.jpg'),
(24055, 1647, 'Ascensão: Império Otomano S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c3Ow83kvruX8V2NxCLIXllUMFgW.jpg'),
(24056, 1647, 'Ascensão: Império Otomano S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tEw4os1NhICoWFQBKSvgeCdEzsK.jpg'),
(24057, 1648, '44 Gatos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108371.mp4', 'http://timg.bdta.pro/images/f799da8efeb9bdf7b722d0783238a05c.jpg'),
(24058, 1648, '44 Gatos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108372.mp4', 'http://timg.bdta.pro/images/73e2023d9877b916568477ba86030276.jpg'),
(24059, 1648, '44 Gatos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108373.mp4', 'http://timg.bdta.pro/images/69816a37588926974dd7db3799f07bc5.jpg'),
(24060, 1648, '44 Gatos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108374.mp4', 'http://timg.bdta.pro/images/b13993a135e0971f491bb33b4a2a55a1.jpg'),
(24061, 1648, '44 Gatos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108375.mp4', 'http://timg.bdta.pro/images/91aa4eae51b1224b1a799eb5bc95f309.jpg'),
(24062, 1648, '44 Gatos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108376.mp4', 'http://timg.bdta.pro/images/eb34a680a227bc8db0711d62c9f0b07a.jpg'),
(24063, 1648, '44 Gatos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108377.mp4', 'http://timg.bdta.pro/images/9648575d0d6e4060e15b2c05e3cbd4f9.jpg'),
(24064, 1648, '44 Gatos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108378.mp4', 'http://timg.bdta.pro/images/037fdb13dd2077bd317aa99a1a29b9e2.jpg'),
(24065, 1648, '44 Gatos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108379.mp4', 'http://timg.bdta.pro/images/fc91bd3be463918005234fc3d0fb0698.jpg'),
(24066, 1648, '44 Gatos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108380.mp4', 'http://timg.bdta.pro/images/c2104273ca66d655dcfc5b0131745934.jpg'),
(24067, 1648, '44 Gatos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108381.mp4', 'http://timg.bdta.pro/images/2b55375b9edeb7a47f30439704549b51.jpg'),
(24068, 1648, '44 Gatos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108382.mp4', 'http://timg.bdta.pro/images/f9bfc80cb22e31fd4fd6534e253734f0.jpg'),
(24069, 1648, '44 Gatos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108383.mp4', 'http://timg.bdta.pro/images/03383f94c70efa73f63b4d90c41a3e57.jpg'),
(24070, 1648, '44 Gatos S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108384.mp4', 'http://timg.bdta.pro/images/1babff714b1ca5ed9e0b7cfafbb8b00e.jpg'),
(24071, 1648, '44 Gatos S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108385.mp4', 'http://timg.bdta.pro/images/0812513fe7996b726dfe53a93c3c9ea6.jpg'),
(24072, 1648, '44 Gatos S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108386.mp4', 'http://timg.bdta.pro/images/ed7ea91c14c4737dd32ea9d223be81b4.jpg'),
(24073, 1648, '44 Gatos S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108387.mp4', 'http://timg.bdta.pro/images/2bbf3a9fa997467071ba33d7a74f9862.jpg'),
(24074, 1648, '44 Gatos S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108388.mp4', 'http://timg.bdta.pro/images/c27a6047605926288691e34ebdfb5d5e.jpg'),
(24075, 1648, '44 Gatos S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108389.mp4', 'http://timg.bdta.pro/images/c27a6047605926288691e34ebdfb5d5e.jpg'),
(24076, 1648, '44 Gatos S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108390.mp4', 'http://timg.bdta.pro/images/965a5845da0d22ff71f74ec1ee93380f.jpg'),
(24077, 1648, '44 Gatos S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/108391.mp4', 'http://timg.bdta.pro/images/ae1257cb892980d1d0ef667fbd250784.jpg'),
(24078, 1648, '44 Gatos S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/108392.mp4', 'http://timg.bdta.pro/images/64e873c290b594bb438bf01e60b0fb73.jpg'),
(24079, 1648, '44 Gatos S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/108393.mp4', 'http://timg.bdta.pro/images/1c7dcf4e559d05e43cca06bc876899f9.jpg'),
(24080, 1648, '44 Gatos S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/108394.mp4', 'http://timg.bdta.pro/images/fb33731d38d60ba4243abf1a6c51a4c5.jpg'),
(24081, 1648, '44 Gatos S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/108395.mp4', 'http://timg.bdta.pro/images/33013ce15d928de9499ce4bbebc1e24a.jpg'),
(24082, 1648, '44 Gatos S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/108396.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24083, 1648, '44 Gatos S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/108397.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24084, 1648, '44 Gatos S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/108398.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24085, 1648, '44 Gatos S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/108399.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24086, 1648, '44 Gatos S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/108400.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24087, 1648, '44 Gatos S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/108401.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24088, 1648, '44 Gatos S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/108402.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24089, 1648, '44 Gatos S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/108403.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24090, 1648, '44 Gatos S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/108404.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24091, 1648, '44 Gatos S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/108405.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24092, 1648, '44 Gatos S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/108406.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24093, 1648, '44 Gatos S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/108407.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24094, 1648, '44 Gatos S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/108408.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24095, 1648, '44 Gatos S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/108409.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24096, 1648, '44 Gatos S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/108410.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24097, 1648, '44 Gatos S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/108411.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24098, 1648, '44 Gatos S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/108412.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24099, 1648, '44 Gatos S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/108413.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24100, 1648, '44 Gatos S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/108414.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24101, 1648, '44 Gatos S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/108415.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24102, 1648, '44 Gatos S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/108416.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24103, 1648, '44 Gatos S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/108417.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24104, 1648, '44 Gatos S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/108418.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24105, 1648, '44 Gatos S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/108419.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24106, 1648, '44 Gatos S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/108420.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24107, 1648, '44 Gatos S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/108421.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24108, 1648, '44 Gatos S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/108422.mp4', 'http://gstaticontent.com/images/e6UxiKbdcPJr15eTZWiEbldAzlS_big.jpg'),
(24109, 1649, 'Tal Filha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108218.mp4', 'http://timg.bdta.pro/images/ba0e8f86041b8815a9b550492a0d1bdd.jpg'),
(24110, 1649, 'Tal Filha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108219.mp4', 'http://timg.bdta.pro/images/ddbabdd1a589c65441acdc1dbc872e2f.jpg'),
(24111, 1649, 'Tal Filha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108220.mp4', 'http://timg.bdta.pro/images/a6b618eb446f91b33be7a2cc2cfb32a7.jpg'),
(24112, 1649, 'Tal Filha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108221.mp4', 'http://timg.bdta.pro/images/efe8be7c8e4cb7e7ca32174bc67606e3.jpg'),
(24113, 1649, 'Tal Filha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108222.mp4', 'http://timg.bdta.pro/images/fc5c194b049387fe2e5787d75bbb1262.jpg'),
(24114, 1649, 'Tal Filha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108223.mp4', 'http://timg.bdta.pro/images/a28ae20e59f9a4260e894d52cd53436b.jpg'),
(24115, 1649, 'Tal Filha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108224.mp4', 'http://timg.bdta.pro/images/2415b7faea79dc512ad0413e13a69119.jpg'),
(24116, 1649, 'Tal Filha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108225.mp4', 'http://timg.bdta.pro/images/728a16508c18094cb5f58ffb250157bf.jpg'),
(24117, 1649, 'Tal Filha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108226.mp4', 'http://timg.bdta.pro/images/a8d0bdbf6d9b6cd611430052c6d8558b.jpg'),
(24118, 1649, 'Tal Filha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108227.mp4', 'http://timg.bdta.pro/images/929b71f382edc5de8e0cc0d3b2bf9a29.jpg'),
(24119, 1649, 'Tal Filha S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108228.mp4', 'http://timg.bdta.pro/images/bd13d724ce99380e54148dd4811e5cd6.jpg'),
(24120, 1649, 'Tal Filha S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108229.mp4', 'http://timg.bdta.pro/images/26ef445c9aeff3e555baffa38a186009.jpg'),
(24121, 1649, 'Tal Filha S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108230.mp4', 'http://timg.bdta.pro/images/a3442198baec9bfdf9dfdee7ba1ebb15.jpg'),
(24122, 1649, 'Tal Filha S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108231.mp4', 'http://timg.bdta.pro/images/f2f7e188e1ed4ccb999dcdf894b23814.jpg'),
(24123, 1649, 'Tal Filha S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108232.mp4', 'http://timg.bdta.pro/images/dea5a736d1d90e60f0ba0460834e5179.jpg'),
(24124, 1649, 'Tal Filha S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108233.mp4', 'http://timg.bdta.pro/images/90f486e90573d5478ef09539326533c1.jpg'),
(24125, 1649, 'Tal Filha S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108234.mp4', 'http://timg.bdta.pro/images/8128d182e5ae01bc060f84a131cc226a.jpg'),
(24126, 1649, 'Tal Filha S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108235.mp4', 'http://timg.bdta.pro/images/2d958d1aaeffd0c1e253dcefb8765256.jpg'),
(24127, 1649, 'Tal Filha S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108236.mp4', 'http://timg.bdta.pro/images/5ac9654803e6a6314b811ff713e3bc31.jpg'),
(24128, 1649, 'Tal Filha S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108237.mp4', 'http://timg.bdta.pro/images/82b6872070ff3ec3af9259c20bc8d421.jpg'),
(24129, 1649, 'Tal Filha S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/108238.mp4', 'http://timg.bdta.pro/images/cb25fe8e9f1f2a5cb1f961999ca95557.jpg'),
(24130, 1650, 'Tal Filha S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108239.mp4', 'http://timg.bdta.pro/images/87888eab81d5c4b5a32b57f5aa1e395e.jpg'),
(24131, 1650, 'Tal Filha S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108240.mp4', 'http://timg.bdta.pro/images/e998cdc091daafa624562bde6a7a6695.jpg'),
(24132, 1650, 'Tal Filha S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108241.mp4', 'http://timg.bdta.pro/images/d37403d750fc174c57a4d3516321a609.jpg'),
(24133, 1650, 'Tal Filha S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108242.mp4', 'http://timg.bdta.pro/images/99751ad3b28d58f1a8327c8765474436.jpg'),
(24134, 1650, 'Tal Filha S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108243.mp4', 'http://timg.bdta.pro/images/d3d9c639517269b28f71ffbf5d88ba08.jpg'),
(24135, 1650, 'Tal Filha S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108244.mp4', 'http://timg.bdta.pro/images/8bc3d3b729e16f992ce9969d18ae7635.jpg'),
(24136, 1650, 'Tal Filha S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108245.mp4', 'http://timg.bdta.pro/images/ca2fc1d18569ca295f312411edc7c204.jpg'),
(24137, 1650, 'Tal Filha S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108246.mp4', 'http://timg.bdta.pro/images/ffdabc50cbd855ebf474f3fe8edceb42.jpg'),
(24138, 1650, 'Tal Filha S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108247.mp4', 'http://timg.bdta.pro/images/1f0151e9f297fe1fe14d8e6af9704fb3.jpg'),
(24139, 1650, 'Tal Filha S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108248.mp4', 'http://timg.bdta.pro/images/d3f9cfe6c0ae6628dc4d029bdebf16a9.jpg'),
(24140, 1650, 'Tal Filha S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108249.mp4', 'http://timg.bdta.pro/images/d664d88011bd9139893ee72c4f99edc2.jpg'),
(24141, 1650, 'Tal Filha S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108250.mp4', 'http://timg.bdta.pro/images/fab707e9dd14f96b4a5c939255dd8b1f.jpg'),
(24142, 1650, 'Tal Filha S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108251.mp4', 'http://timg.bdta.pro/images/904ab4cc1ffa52863da513fc6f3e6028.jpg'),
(24143, 1650, 'Tal Filha S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108252.mp4', 'http://timg.bdta.pro/images/40b0b36bf618d7da4410e8468359ea61.jpg'),
(24144, 1650, 'Tal Filha S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108253.mp4', 'http://timg.bdta.pro/images/96c7ed2e377bf7f0ec1a01462c39c226.jpg'),
(24145, 1650, 'Tal Filha S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108254.mp4', 'http://timg.bdta.pro/images/d4ed7362820242bbc0718033c60045ea.jpg'),
(24146, 1650, 'Tal Filha S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108255.mp4', 'http://timg.bdta.pro/images/1cbd82d6018d4dff183c4cb66dc9e80d.jpg'),
(24147, 1650, 'Tal Filha S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108256.mp4', 'http://timg.bdta.pro/images/431dab45eadecf21b64ee8bcece5ce82.jpg'),
(24148, 1650, 'Tal Filha S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108257.mp4', 'http://timg.bdta.pro/images/a558293563868e7fb9a43d6ffa768b8c.jpg'),
(24149, 1650, 'Tal Filha S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108258.mp4', 'http://timg.bdta.pro/images/67e1511bf895321cf3ddc3186806f42a.jpg'),
(24150, 1650, 'Tal Filha S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/108259.mp4', 'http://timg.bdta.pro/images/b9358e5079df07e92e93f209c5c12b12.jpg'),
(24151, 1650, 'Tal Filha S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/108260.mp4', 'http://timg.bdta.pro/images/0a128e64506b46a273afd2f759b8fa96.jpg'),
(24152, 1651, 'Tal Filha S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108261.mp4', 'http://timg.bdta.pro/images/bd52ddf2eb39117c8d00a04d84c1dd15.jpg'),
(24153, 1651, 'Tal Filha S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108262.mp4', 'http://timg.bdta.pro/images/39d6e3c509486a50c6b558bdeeff2665.jpg'),
(24154, 1651, 'Tal Filha S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108263.mp4', 'http://timg.bdta.pro/images/72719efa8a4b57402e98d329748e7425.jpg'),
(24155, 1651, 'Tal Filha S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108264.mp4', 'http://timg.bdta.pro/images/c3fb369165f9a128fb5e45ba2b89f685.jpg'),
(24156, 1651, 'Tal Filha S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108265.mp4', 'http://timg.bdta.pro/images/ebed8a82e2206d934478e819dae94263.jpg'),
(24157, 1651, 'Tal Filha S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108266.mp4', 'http://timg.bdta.pro/images/745d029a537f895b52d92de4fbe8d7f0.jpg'),
(24158, 1651, 'Tal Filha S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108267.mp4', 'http://timg.bdta.pro/images/f6ce9cd4b6e67947bc0f1e20621cbbc3.jpg'),
(24159, 1651, 'Tal Filha S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108268.mp4', 'http://timg.bdta.pro/images/503b2ea5779e320401698a171970801e.jpg'),
(24160, 1651, 'Tal Filha S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108269.mp4', 'http://timg.bdta.pro/images/5aa2b6fc575d8302e1d952c7f3e86936.jpg'),
(24161, 1651, 'Tal Filha S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108270.mp4', 'http://timg.bdta.pro/images/a689a216d6197a87287d5872c90fc98f.jpg'),
(24162, 1651, 'Tal Filha S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108271.mp4', 'http://timg.bdta.pro/images/38679e162dd724c5233bf568a64c7692.jpg'),
(24163, 1651, 'Tal Filha S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108272.mp4', 'http://timg.bdta.pro/images/598a993e8ad9e909e984503c4333ec6b.jpg'),
(24164, 1651, 'Tal Filha S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108273.mp4', 'http://timg.bdta.pro/images/5046956c445791ee6bc49f3ee92a6f41.jpg'),
(24165, 1651, 'Tal Filha S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108274.mp4', 'http://timg.bdta.pro/images/83481f967d39545582cdd9e064c782fa.jpg'),
(24166, 1651, 'Tal Filha S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108275.mp4', 'http://timg.bdta.pro/images/02ce8c699d123a0fd9c693ed16feeae7.jpg'),
(24167, 1651, 'Tal Filha S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108276.mp4', 'http://timg.bdta.pro/images/21a8a4bc1c301317e5d597377a6cde2a.jpg'),
(24168, 1651, 'Tal Filha S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108277.mp4', 'http://timg.bdta.pro/images/79df3e060745345b9faa0036d3c213e4.jpg'),
(24169, 1651, 'Tal Filha S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108278.mp4', 'http://timg.bdta.pro/images/95431bee62266d5d7248b922e7905bb3.jpg'),
(24170, 1651, 'Tal Filha S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108279.mp4', 'http://timg.bdta.pro/images/1d546a62632d97468bb43d9e8e1d9be7.jpg'),
(24171, 1651, 'Tal Filha S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108280.mp4', 'http://timg.bdta.pro/images/d4ff95dc518c1bd36f128faa18d29c09.jpg'),
(24172, 1651, 'Tal Filha S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/108281.mp4', 'http://timg.bdta.pro/images/5888772509c589584a678a1cb800c706.jpg'),
(24173, 1651, 'Tal Filha S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/108282.mp4', 'http://timg.bdta.pro/images/af803ba04e872358515c9587c4d092e7.jpg'),
(24174, 1652, 'Tal Filha S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108283.mp4', 'http://timg.bdta.pro/images/3bc2b6c1076905a5f2023d21b6cc239d.jpg'),
(24175, 1652, 'Tal Filha S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108284.mp4', 'http://timg.bdta.pro/images/8f9ff3b03e46a1ac3815be39805b92ae.jpg'),
(24176, 1652, 'Tal Filha S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108285.mp4', 'http://timg.bdta.pro/images/4a1808163ea746d3ad6fad9accc321b7.jpg'),
(24177, 1652, 'Tal Filha S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108286.mp4', 'http://timg.bdta.pro/images/87cd397d8305676bd4d03cde878fba03.jpg'),
(24178, 1652, 'Tal Filha S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108287.mp4', 'http://timg.bdta.pro/images/1d56ec5481d2e8f99b64b53c67cdc51d.jpg'),
(24179, 1652, 'Tal Filha S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108288.mp4', 'http://timg.bdta.pro/images/9f184d7f522224461bb88162b382330d.jpg'),
(24180, 1652, 'Tal Filha S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108289.mp4', 'http://timg.bdta.pro/images/52a344c81cfdc10e94ece17ca5f7acbc.jpg'),
(24181, 1652, 'Tal Filha S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108290.mp4', 'http://timg.bdta.pro/images/5cf54e3bf629058d507d2392582bd90f.jpg'),
(24182, 1652, 'Tal Filha S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108291.mp4', 'http://timg.bdta.pro/images/b6df9ee7988be8947054eb2fb2aefe05.jpg'),
(24183, 1652, 'Tal Filha S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108292.mp4', 'http://timg.bdta.pro/images/288adc6535b9960cd5dd7a60c14d8626.jpg'),
(24184, 1652, 'Tal Filha S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108293.mp4', 'http://timg.bdta.pro/images/eea7177435949a941fd40cebba8ba581.jpg'),
(24185, 1652, 'Tal Filha S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108294.mp4', 'http://timg.bdta.pro/images/6dc38c45072daca391ca529eb1cd5011.jpg'),
(24186, 1652, 'Tal Filha S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108295.mp4', 'http://timg.bdta.pro/images/2b36a45a8d4b5d074c70bcaebf3e32fb.jpg'),
(24187, 1652, 'Tal Filha S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108296.mp4', 'http://timg.bdta.pro/images/d8686d447156f9f29227de3cea3a3ed1.jpg'),
(24188, 1652, 'Tal Filha S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108297.mp4', 'http://timg.bdta.pro/images/20dd24d34d0de4cea2ddb33d170a1b99.jpg'),
(24189, 1652, 'Tal Filha S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108298.mp4', 'http://timg.bdta.pro/images/c107e228de5bb343e05816d12f64e6b6.jpg'),
(24190, 1652, 'Tal Filha S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108299.mp4', 'http://timg.bdta.pro/images/62986d907e69533cbef5f60f32489c57.jpg'),
(24191, 1652, 'Tal Filha S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108300.mp4', 'http://timg.bdta.pro/images/716c69b62ce3f09b074558fd772f3b42.jpg'),
(24192, 1652, 'Tal Filha S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108301.mp4', 'http://timg.bdta.pro/images/9d63dc56eddcb9b3935377faa70d7635.jpg'),
(24193, 1652, 'Tal Filha S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108302.mp4', 'http://timg.bdta.pro/images/b7213ef1f0786dac621107da443b1768.jpg'),
(24194, 1652, 'Tal Filha S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/108303.mp4', 'http://timg.bdta.pro/images/4bc0b3ff30af3a9e499821edaccb610a.jpg'),
(24195, 1652, 'Tal Filha S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/108304.mp4', 'http://timg.bdta.pro/images/2bc3e598d52e7870ec223eda2cc13788.jpg'),
(24196, 1653, 'Tal Filha S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108305.mp4', 'http://timg.bdta.pro/images/43fc116539ed729e734179d85950e5d6.jpg'),
(24197, 1653, 'Tal Filha S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108306.mp4', 'http://timg.bdta.pro/images/0346c160cf609253c10fc9455d393900.jpg'),
(24198, 1653, 'Tal Filha S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108307.mp4', 'http://timg.bdta.pro/images/1da6749ab137ece3eff17b30d782ba59.jpg'),
(24199, 1653, 'Tal Filha S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108308.mp4', 'http://timg.bdta.pro/images/edc6bb06424ac67b9cd4437a8cdceb34.jpg'),
(24200, 1653, 'Tal Filha S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108309.mp4', 'http://timg.bdta.pro/images/b4d558e365aa47a4af09a5c6716c7521.jpg'),
(24201, 1653, 'Tal Filha S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108310.mp4', 'http://timg.bdta.pro/images/23f70a6c53d35876ba5a48b777793fc9.jpg'),
(24202, 1653, 'Tal Filha S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108311.mp4', 'http://timg.bdta.pro/images/d6e904796917cbaf5c2b9093623c2687.jpg'),
(24203, 1653, 'Tal Filha S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108312.mp4', 'http://timg.bdta.pro/images/42ef2fbfd3c1d222d79106f3ea53093e.jpg'),
(24204, 1653, 'Tal Filha S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108313.mp4', 'http://timg.bdta.pro/images/1bf034d1ad85f2ea84a3b83eb96bc4a0.jpg'),
(24205, 1653, 'Tal Filha S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108314.mp4', 'http://timg.bdta.pro/images/e186a9f342032f466c3eac180ce2e61d.jpg'),
(24206, 1653, 'Tal Filha S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108315.mp4', 'http://timg.bdta.pro/images/052bfd32fa38ff24a17dc9e6cb40ab77.jpg'),
(24207, 1653, 'Tal Filha S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108316.mp4', 'http://timg.bdta.pro/images/729ebc91d3f6ffe1880fa8b2edfb3911.jpg'),
(24208, 1653, 'Tal Filha S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108317.mp4', 'http://timg.bdta.pro/images/b4d51ab8d43a37b0b1f5ade27be934c4.jpg'),
(24209, 1653, 'Tal Filha S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108318.mp4', 'http://timg.bdta.pro/images/d3613ed64c4c1c1c8c298931b348ed1a.jpg'),
(24210, 1653, 'Tal Filha S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108319.mp4', 'http://timg.bdta.pro/images/063f23705d345b267cc167129f1d22b8.jpg'),
(24211, 1653, 'Tal Filha S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108320.mp4', 'http://timg.bdta.pro/images/c26d646b633febabf156308f9087dc98.jpg'),
(24212, 1653, 'Tal Filha S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108321.mp4', 'http://timg.bdta.pro/images/09022a49190d807285f6d59e11e8992f.jpg'),
(24213, 1653, 'Tal Filha S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108322.mp4', 'http://timg.bdta.pro/images/2dc6f54548b97b1bc6dd18f6bcb997f3.jpg'),
(24214, 1653, 'Tal Filha S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108323.mp4', 'http://timg.bdta.pro/images/2aea7af77c21a80ee4583b9fa945f0ed.jpg'),
(24215, 1653, 'Tal Filha S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108324.mp4', 'http://timg.bdta.pro/images/6bc80c3841de71824d088a2332ffb1a2.jpg'),
(24216, 1653, 'Tal Filha S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/108325.mp4', 'http://timg.bdta.pro/images/178073c0eb837aac6baae11d30d409ad.jpg'),
(24217, 1653, 'Tal Filha S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/108326.mp4', 'http://timg.bdta.pro/images/c7bb963615a3671f03993492d9f3de50.jpg'),
(24218, 1654, 'Tal Filha S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108327.mp4', 'http://timg.bdta.pro/images/d428f524667f746321e7494b9b73da20.jpg'),
(24219, 1654, 'Tal Filha S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108328.mp4', 'http://timg.bdta.pro/images/d54fd27acc9c0a56cdd84b3eb48868da.jpg'),
(24220, 1654, 'Tal Filha S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108329.mp4', 'http://timg.bdta.pro/images/2d003cb46fd2eb62132b5984992309ce.jpg'),
(24221, 1654, 'Tal Filha S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108331.mp4', 'http://timg.bdta.pro/images/2d5f03eb855212c07969e9b2757fb68b.jpg'),
(24222, 1654, 'Tal Filha S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108332.mp4', 'http://timg.bdta.pro/images/551aabcb83d1d2aa76c830f1a1ef30e0.jpg'),
(24223, 1654, 'Tal Filha S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108333.mp4', 'http://timg.bdta.pro/images/0d7243884a3d5c4014c0e2950431afd5.jpg'),
(24224, 1654, 'Tal Filha S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108334.mp4', 'http://timg.bdta.pro/images/fe7200ff27175ca9f4479483c95a9fee.jpg'),
(24225, 1654, 'Tal Filha S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108335.mp4', 'http://timg.bdta.pro/images/56f3b81106859b7bea689ea92b3db356.jpg'),
(24226, 1654, 'Tal Filha S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108336.mp4', 'http://timg.bdta.pro/images/2484e2d59f31c7450028ca9e1c9cc15e.jpg'),
(24227, 1654, 'Tal Filha S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108337.mp4', 'http://timg.bdta.pro/images/27bb42ae0c6c5870c2b6bece024e0cfa.jpg'),
(24228, 1654, 'Tal Filha S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108338.mp4', 'http://timg.bdta.pro/images/f356a3f5518910700bfdbc1c61e3c5ec.jpg'),
(24229, 1654, 'Tal Filha S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108339.mp4', 'http://timg.bdta.pro/images/60d225c47c9394ace8e921c185eae392.jpg'),
(24230, 1654, 'Tal Filha S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108340.mp4', 'http://timg.bdta.pro/images/6722e6ff2b8346b3b115ba686926fcad.jpg'),
(24231, 1654, 'Tal Filha S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108341.mp4', 'http://timg.bdta.pro/images/e79fc16086327f80c561e30a84841713.jpg'),
(24232, 1654, 'Tal Filha S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108342.mp4', 'http://timg.bdta.pro/images/c80600cc816fbe82c8bfad6d92b4c009.jpg'),
(24233, 1654, 'Tal Filha S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108343.mp4', 'http://timg.bdta.pro/images/d199fe98f9c9417cbbf4eaeb3a4e4d46.jpg'),
(24234, 1654, 'Tal Filha S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108344.mp4', 'http://timg.bdta.pro/images/25967ee7432e24b9cd131d9d4b78d01c.jpg'),
(24235, 1654, 'Tal Filha S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108345.mp4', 'http://timg.bdta.pro/images/5822985db2e2f1735d5bce2144719be3.jpg'),
(24236, 1654, 'Tal Filha S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108346.mp4', 'http://timg.bdta.pro/images/095e38b85df0a998000f47e3ad9c81c1.jpg'),
(24237, 1654, 'Tal Filha S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108347.mp4', 'http://timg.bdta.pro/images/b42b3a4d7fad5b21186871780dc3c429.jpg'),
(24238, 1654, 'Tal Filha S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/108348.mp4', 'http://timg.bdta.pro/images/1078885924dcf545486623ff7fae71a9.jpg'),
(24239, 1655, 'Tal Filha S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108349.mp4', 'http://timg.bdta.pro/images/856994a3be173e2a0c19e047afa121e4.jpg'),
(24240, 1655, 'Tal Filha S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108350.mp4', 'http://timg.bdta.pro/images/6be57f7e3f09cd53369532a7cc77fe17.jpg'),
(24241, 1655, 'Tal Filha S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108351.mp4', 'http://timg.bdta.pro/images/649306827c2b4315e07dec998ec2f450.jpg'),
(24242, 1655, 'Tal Filha S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108352.mp4', 'http://timg.bdta.pro/images/5eee536a9ce36f7e1ff3a4231ace0621.jpg'),
(24243, 1655, 'Tal Filha S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108353.mp4', 'http://timg.bdta.pro/images/b7726ea3893fd6651e649c0aabc0a0c5.jpg'),
(24244, 1655, 'Tal Filha S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108354.mp4', 'http://timg.bdta.pro/images/0009c47766147cdd2b5ff4467615a4a9.jpg'),
(24245, 1655, 'Tal Filha S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108355.mp4', 'http://timg.bdta.pro/images/b963f4f07def1a0fa0c629388a56a955.jpg'),
(24246, 1655, 'Tal Filha S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108356.mp4', 'http://timg.bdta.pro/images/437b004b45be18e4dee9b21da553ef53.jpg'),
(24247, 1655, 'Tal Filha S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108357.mp4', 'http://timg.bdta.pro/images/5e26dfeeea8395e2cc7073d1e8e4b75c.jpg'),
(24248, 1655, 'Tal Filha S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108358.mp4', 'http://timg.bdta.pro/images/5dd6c6c5feaa3b3b80bab614235e4131.jpg'),
(24249, 1655, 'Tal Filha S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108359.mp4', 'http://timg.bdta.pro/images/afbee65c03a3469dc7a2a7b2a37130c3.jpg'),
(24250, 1655, 'Tal Filha S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108360.mp4', 'http://timg.bdta.pro/images/a99bbbf70e2fd4eb8a8273cce7d3b813.jpg'),
(24251, 1655, 'Tal Filha S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108361.mp4', 'http://timg.bdta.pro/images/5ed9c5910e4771bad5b030317d0443ee.jpg'),
(24252, 1655, 'Tal Filha S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108362.mp4', 'http://timg.bdta.pro/images/05288cd9bb904f9eacfbbb957961ddc7.jpg'),
(24253, 1655, 'Tal Filha S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108363.mp4', 'http://timg.bdta.pro/images/19b98977c7826cc261ebb4e1d2a3a1a6.jpg'),
(24254, 1655, 'Tal Filha S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108364.mp4', 'http://timg.bdta.pro/images/352a138479a4e801653d5055c79d15ac.jpg'),
(24255, 1655, 'Tal Filha S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108365.mp4', 'http://timg.bdta.pro/images/d9c145b88f978eb2c3a190c94c3b0f5c.jpg'),
(24256, 1655, 'Tal Filha S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108366.mp4', 'http://timg.bdta.pro/images/d616cabbb7f30279cb49d2b49a712db4.jpg'),
(24257, 1655, 'Tal Filha S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108367.mp4', 'http://timg.bdta.pro/images/8f35e6d0e157a01622761c3baba35d7a.jpg'),
(24258, 1655, 'Tal Filha S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108368.mp4', 'http://timg.bdta.pro/images/19666aa5a5e6d8b0b919ebea96fd6fcb.jpg'),
(24259, 1655, 'Tal Filha S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/108369.mp4', 'http://timg.bdta.pro/images/eee89643206bedc5297130157a6e5fb7.jpg'),
(24260, 1655, 'Tal Filha S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/108370.mp4', 'http://timg.bdta.pro/images/3a12faaca831ec5f5e4f5303d03d92d9.jpg'),
(24261, 1656, 'A Mafia So Mata no Verao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108206.mp4', 'http://timg.bdta.pro/images/38fba63e466acd9f39ef77609671c4e4.jpg'),
(24262, 1656, 'A Mafia So Mata no Verao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108207.mp4', 'http://timg.bdta.pro/images/0142235fca8d5df388225719bf633bfc.jpg'),
(24263, 1656, 'A Mafia So Mata no Verao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108208.mp4', 'http://timg.bdta.pro/images/7587062d8eb79a4ac764aa1939064499.jpg'),
(24264, 1656, 'A Mafia So Mata no Verao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108209.mp4', 'http://timg.bdta.pro/images/1bf605efb1f03fc732dcbf08cec27a7c.jpg'),
(24265, 1656, 'A Mafia So Mata no Verao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108210.mp4', 'http://timg.bdta.pro/images/d4b2b0f7e31ad469660c56a2c8b68191.jpg'),
(24266, 1656, 'A Mafia So Mata no Verao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108211.mp4', 'http://timg.bdta.pro/images/16c228e88bb3b4ffa30c6c53dda6baaa.jpg'),
(24267, 1656, 'A Mafia So Mata no Verao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108212.mp4', 'http://timg.bdta.pro/images/fa03590b1e1061ed8284e11783b618b7.jpg'),
(24268, 1656, 'A Mafia So Mata no Verao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108213.mp4', 'http://timg.bdta.pro/images/e21697840bec8f89a30431bdb8964800.jpg'),
(24269, 1656, 'A Mafia So Mata no Verao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108214.mp4', 'http://timg.bdta.pro/images/a1bb3053a3635b7933963483d0ecebc0.jpg'),
(24270, 1656, 'A Mafia So Mata no Verao S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108215.mp4', 'http://timg.bdta.pro/images/928243a3db37f0e8344bbb4a0e9e5d32.jpg'),
(24271, 1656, 'A Mafia So Mata no Verao S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108216.mp4', 'http://timg.bdta.pro/images/f6e0b0d2c9d3d49fbea96810eee4e242.jpg'),
(24272, 1656, 'A Mafia So Mata no Verao S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108217.mp4', 'http://timg.bdta.pro/images/26f0d53df1cfd9190e1f68ac1c46487d.jpg'),
(24273, 1657, 'Amphibia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108186.mp4', 'http://timg.bdta.pro/images/5f3b5fe06e8bd2fcac5a12e11bdfc147.jpg'),
(24274, 1657, 'Amphibia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108187.mp4', 'http://timg.bdta.pro/images/28ded239971e71e577781dbdba1c54e1.jpg'),
(24275, 1657, 'Amphibia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108188.mp4', 'http://timg.bdta.pro/images/bed5f4de1ddd716b3321a83431745237.jpg'),
(24276, 1657, 'Amphibia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108189.mp4', 'http://timg.bdta.pro/images/bed5f4de1ddd716b3321a83431745237.jpg'),
(24277, 1657, 'Amphibia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108190.mp4', 'http://timg.bdta.pro/images/c6d5068dd05e5d4da6c9ae61a1a16878.jpg'),
(24278, 1657, 'Amphibia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108191.mp4', 'http://timg.bdta.pro/images/c6d5068dd05e5d4da6c9ae61a1a16878.jpg'),
(24279, 1657, 'Amphibia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108192.mp4', 'http://timg.bdta.pro/images/59a84693f35ab10566c697d860cbe350.jpg'),
(24280, 1657, 'Amphibia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108193.mp4', 'http://timg.bdta.pro/images/59a84693f35ab10566c697d860cbe350.jpg'),
(24281, 1657, 'Amphibia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108194.mp4', 'http://timg.bdta.pro/images/59a84693f35ab10566c697d860cbe350.jpg'),
(24282, 1657, 'Amphibia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108195.mp4', 'http://timg.bdta.pro/images/59a84693f35ab10566c697d860cbe350.jpg'),
(24283, 1657, 'Amphibia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108196.mp4', 'http://timg.bdta.pro/images/59a84693f35ab10566c697d860cbe350.jpg'),
(24284, 1657, 'Amphibia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108197.mp4', 'http://timg.bdta.pro/images/59a84693f35ab10566c697d860cbe350.jpg'),
(24285, 1657, 'Amphibia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108198.mp4', 'http://timg.bdta.pro/images/59a84693f35ab10566c697d860cbe350.jpg'),
(24286, 1657, 'Amphibia S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108199.mp4', 'http://timg.bdta.pro/images/59a84693f35ab10566c697d860cbe350.jpg'),
(24287, 1657, 'Amphibia S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108200.mp4', 'http://timg.bdta.pro/images/59a84693f35ab10566c697d860cbe350.jpg'),
(24288, 1657, 'Amphibia S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108201.mp4', 'http://timg.bdta.pro/images/59a84693f35ab10566c697d860cbe350.jpg'),
(24289, 1657, 'Amphibia S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108202.mp4', 'http://timg.bdta.pro/images/4e64dddb2e8ee3dd6ab80e24235395ab.jpg'),
(24290, 1657, 'Amphibia S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108203.mp4', 'http://timg.bdta.pro/images/4e64dddb2e8ee3dd6ab80e24235395ab.jpg'),
(24291, 1657, 'Amphibia S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108204.mp4', 'http://timg.bdta.pro/images/fea6ec67d56d88b1dbc3591c24cc4f2b.jpg'),
(24292, 1657, 'Amphibia S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108205.mp4', 'http://timg.bdta.pro/images/6ecdbad37290fa49443d02a3e9023ad6.jpg'),
(24293, 1658, 'Amphibia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/415436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1eDLAOHBl0EakH1NM1MFOO2Cjz4.jpg'),
(24294, 1658, 'Amphibia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/415437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13qhnn8nTNjCpaAv5YTijV1b2rB.jpg'),
(24295, 1658, 'Amphibia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/415438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ngKdHhNStIV5rPsVrT9moFa2YMO.jpg'),
(24296, 1658, 'Amphibia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/415439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q1H692sfgZnQD1oDYPBOGtmqHYE.jpg'),
(24297, 1658, 'Amphibia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/415440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a0zbhBWVw2UCj3Ji4jm9PVRCCH6.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(24298, 1658, 'Amphibia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/415441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wwl0ZVYPPQpKAs3OXbIreUBuBKQ.jpg'),
(24299, 1658, 'Amphibia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/415442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63qHCj3zNjrpGNqzJfeFog4Bri0.jpg'),
(24300, 1658, 'Amphibia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/415443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g6uGizgxXuD7curetDTOM6zk9OA.jpg'),
(24301, 1658, 'Amphibia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/415444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3H0EDnWJkwdg7CEcjNvBBYeTVM4.jpg'),
(24302, 1658, 'Amphibia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/415445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jyh3PX6wMi9jgBUON5X8rxP3ek3.jpg'),
(24303, 1658, 'Amphibia S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/415446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9EZ07aMFMjuqNp7wHwiWx1zJCad.jpg'),
(24304, 1658, 'Amphibia S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/415447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nS5c3GRiUebADBuwkNzmt0l0QWj.jpg'),
(24305, 1658, 'Amphibia S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/415448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lddUThnaAIyO8IwUa4nqEoDakSV.jpg'),
(24306, 1658, 'Amphibia S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/415449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iYzVoDT1hxjGqMajbEs2nI5BCvB.jpg'),
(24307, 1658, 'Amphibia S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/415450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3a1Fi3C6H9syxJNQ4N4yffbT1eI.jpg'),
(24308, 1658, 'Amphibia S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/415451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lpGhKU0PLvpMJf27BnIW4VxNsu.jpg'),
(24309, 1658, 'Amphibia S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/415452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fQPsoZjNAj0VXYFujnJtYq54AjX.jpg'),
(24310, 1658, 'Amphibia S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/415453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mCx8i0L8Sk6UIDm0wrpmrUsVNtB.jpg'),
(24311, 1658, 'Amphibia S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/415454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kOINeICx2eJXVnsCnDuC4NEad65.jpg'),
(24312, 1658, 'Amphibia S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/415455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5tfR9EfSFiHRbkI8Gs4tmJ8OUwp.jpg'),
(24313, 1659, 'Amphibia S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/415456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2DSrNch1F4CrowBPhR1yH6uBkrk.jpg'),
(24314, 1659, 'Amphibia S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/415457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cBYdPWfqJ9sPIUrXHjtJRew1X4I.jpg'),
(24315, 1659, 'Amphibia S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/415458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4b1ejRB9eYRSoz39ycCZyTU76Tk.jpg'),
(24316, 1659, 'Amphibia S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/415459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xDwJQus4ZrRZojsC0GuLBaH9SXQ.jpg'),
(24317, 1659, 'Amphibia S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/415460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/evq2L8boyTP7UweWZjNicdN3L19.jpg'),
(24318, 1659, 'Amphibia S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/415461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gfULoiddvnrYgJqpNcBNWGerrgw.jpg'),
(24319, 1659, 'Amphibia S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/415462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qDhJJQeELcc81Sd7A70sZSag5wl.jpg'),
(24320, 1659, 'Amphibia S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/415463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ss9RFiKp4Cjo4Z6MmAfk2xSLSBE.jpg'),
(24321, 1659, 'Amphibia S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/415464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4vUphWbEAATENuJpon9Ajq24g7V.jpg'),
(24322, 1659, 'Amphibia S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/415465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o3ZjJn576zXHb5cz1ha1FDQG9MK.jpg'),
(24323, 1659, 'Amphibia S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/415466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oXdULvb70P0pnoryEdZVkQ6tsJW.jpg'),
(24324, 1659, 'Amphibia S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/415467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5IeiNXkuqVRPyoJGlJVubYiLlxQ.jpg'),
(24325, 1659, 'Amphibia S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/415468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5BbqHYQwDzS3Jym5wlvs2SVWC0b.jpg'),
(24326, 1659, 'Amphibia S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/415469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qm65PUmQMfX7MDVDI9ORSQXt0RT.jpg'),
(24327, 1659, 'Amphibia S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/415470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3j9hyQ48ALWa4hm0oOZAqcLDEyw.jpg'),
(24328, 1659, 'Amphibia S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/415471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A1eunKbkumkjP4qMRqgtpzm7tw8.jpg'),
(24329, 1659, 'Amphibia S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/415472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cl43EUL92ydstD0eYJnFnow0NCZ.jpg'),
(24330, 1659, 'Amphibia S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/415473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bij1yhe6VyHip28uKKiy7IlGZsh.jpg'),
(24331, 1660, 'Arcanjo Renegado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192319.mp4', 'http://timg.bdta.pro/images/92d25c27e72cd1fb94342a5f27d3e3e6.jpg'),
(24332, 1660, 'Arcanjo Renegado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192320.mp4', 'http://timg.bdta.pro/images/adc020e3202148ce13da86d65d00a79f.jpg'),
(24333, 1660, 'Arcanjo Renegado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192321.mp4', 'http://timg.bdta.pro/images/26f56f42298c429955f43f7a0a57d893.jpg'),
(24334, 1660, 'Arcanjo Renegado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192322.mp4', 'http://timg.bdta.pro/images/b648a6f1b6519a2bbaea390a457c32ad.jpg'),
(24335, 1660, 'Arcanjo Renegado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192323.mp4', 'http://timg.bdta.pro/images/52990721415d68ac932b1fe091a483d1.jpg'),
(24336, 1660, 'Arcanjo Renegado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192324.mp4', 'http://timg.bdta.pro/images/c115ac2ff133c4e2888ec6fc38851868.jpg'),
(24337, 1660, 'Arcanjo Renegado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192325.mp4', 'http://timg.bdta.pro/images/3b783ba654c5c5e43eb49bb3206be4c2.jpg'),
(24338, 1660, 'Arcanjo Renegado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192326.mp4', 'http://timg.bdta.pro/images/d90556b3bff1ac62a239b9b5f90f83ba.jpg'),
(24339, 1660, 'Arcanjo Renegado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192327.mp4', 'http://timg.bdta.pro/images/54f6e81690ea2cba676b49f35e693846.jpg'),
(24340, 1660, 'Arcanjo Renegado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192328.mp4', 'http://timg.bdta.pro/images/463b0f75357f52d94d2ba5b324d19c7d.jpg'),
(24341, 1661, 'Arcanjo Renegado S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192329.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24342, 1661, 'Arcanjo Renegado S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192330.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24343, 1661, 'Arcanjo Renegado S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192331.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24344, 1661, 'Arcanjo Renegado S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192332.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24345, 1661, 'Arcanjo Renegado S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192333.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24346, 1661, 'Arcanjo Renegado S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192334.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24347, 1661, 'Arcanjo Renegado S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192335.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24348, 1661, 'Arcanjo Renegado S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192336.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24349, 1661, 'Arcanjo Renegado S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192337.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24350, 1661, 'Arcanjo Renegado S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192338.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24351, 1662, 'Arcanjo Renegado S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506534.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24352, 1662, 'Arcanjo Renegado S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506535.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24353, 1662, 'Arcanjo Renegado S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506536.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24354, 1662, 'Arcanjo Renegado S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506537.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24355, 1662, 'Arcanjo Renegado S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506538.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24356, 1662, 'Arcanjo Renegado S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/509149.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24357, 1662, 'Arcanjo Renegado S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/509150.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24358, 1662, 'Arcanjo Renegado S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/509151.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24359, 1662, 'Arcanjo Renegado S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/509152.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24360, 1662, 'Arcanjo Renegado S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/509153.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24361, 1663, 'Arcanjo Renegado S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/891905.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24362, 1663, 'Arcanjo Renegado S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/891906.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24363, 1663, 'Arcanjo Renegado S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/891907.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24364, 1663, 'Arcanjo Renegado S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/891908.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24365, 1663, 'Arcanjo Renegado S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/891909.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24366, 1663, 'Arcanjo Renegado S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/891910.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24367, 1663, 'Arcanjo Renegado S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/892485.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24368, 1663, 'Arcanjo Renegado S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/892486.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24369, 1663, 'Arcanjo Renegado S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/892487.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24370, 1663, 'Arcanjo Renegado S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/892488.mp4', 'http://gstaticontent.com/images/yboed6TwhCxHZm3SM3hpQtYIAxI_big.jpg'),
(24371, 1664, 'As Visões da Raven S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113109.mp4', 'http://timg.bdta.pro/images/d57949d3662a82fca64ee1e4ccc138c9.jpg'),
(24372, 1664, 'As Visões da Raven S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113110.mp4', 'http://timg.bdta.pro/images/0a4e15ac34521785df7130fc309428a3.jpg'),
(24373, 1664, 'As Visões da Raven S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113111.mp4', 'http://timg.bdta.pro/images/fdac08ceba3b39ada85f480f3d68106e.jpg'),
(24374, 1664, 'As Visões da Raven S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113112.mp4', 'http://timg.bdta.pro/images/5dd45c3a2382c0edaace00e8e305cfac.jpg'),
(24375, 1664, 'As Visões da Raven S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113113.mp4', 'http://timg.bdta.pro/images/e0994da421e12eddf5e1d188ecba4fa3.jpg'),
(24376, 1664, 'As Visões da Raven S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113114.mp4', 'http://timg.bdta.pro/images/1c469f4a47de339665a16823fde1aa45.jpg'),
(24377, 1664, 'As Visões da Raven S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113115.mp4', 'http://timg.bdta.pro/images/4c73974b0621c902c140fcb0043f4c8b.jpg'),
(24378, 1664, 'As Visões da Raven S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113116.mp4', 'http://timg.bdta.pro/images/4f5e1f1b9a15a18a4d4b06f8195b9118.jpg'),
(24379, 1664, 'As Visões da Raven S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113117.mp4', 'http://timg.bdta.pro/images/0f7a6bf1180e07daf0b5ef5af22b22a3.jpg'),
(24380, 1664, 'As Visões da Raven S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113118.mp4', 'http://timg.bdta.pro/images/d88da900a2c64d426f6f7874d7af795a.jpg'),
(24381, 1664, 'As Visões da Raven S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113119.mp4', 'http://timg.bdta.pro/images/3c8aa7dfe41cbf00119307651bec09d5.jpg'),
(24382, 1664, 'As Visões da Raven S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113120.mp4', 'http://timg.bdta.pro/images/2a70862ea9e4b23d7522529fa07bb075.jpg'),
(24383, 1664, 'As Visões da Raven S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113121.mp4', 'http://timg.bdta.pro/images/07af5b1cba81fef9a708c78b2c0f3905.jpg'),
(24384, 1664, 'As Visões da Raven S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113122.mp4', 'http://timg.bdta.pro/images/605bc30b53da0e3df1727d0f268778cd.jpg'),
(24385, 1664, 'As Visões da Raven S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113123.mp4', 'http://timg.bdta.pro/images/5196f4fac71f0b53a085646f037c4aa3.jpg'),
(24386, 1664, 'As Visões da Raven S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113124.mp4', 'http://timg.bdta.pro/images/2404fc455faa1d0fadd28783beb3e25a.jpg'),
(24387, 1664, 'As Visões da Raven S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113125.mp4', 'http://timg.bdta.pro/images/e5194f894d222b189abe35a9b6026a92.jpg'),
(24388, 1664, 'As Visões da Raven S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113126.mp4', 'http://timg.bdta.pro/images/53415017d3abfdb8f851a7ef6183d1ef.jpg'),
(24389, 1664, 'As Visões da Raven S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113127.mp4', 'http://timg.bdta.pro/images/ef985eed64d64cacb6527bdde7fa61da.jpg'),
(24390, 1664, 'As Visões da Raven S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/113128.mp4', 'http://timg.bdta.pro/images/27d315394499478e8af26faacdc82cd8.jpg'),
(24391, 1664, 'As Visões da Raven S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/113129.mp4', 'http://timg.bdta.pro/images/38cf0b9b92ba40d961638adbe938eccf.jpg'),
(24392, 1665, 'As Visões da Raven S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113130.mp4', 'http://timg.bdta.pro/images/09ef612020836385ed7fe0cadac246c5.jpg'),
(24393, 1665, 'As Visões da Raven S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113131.mp4', 'http://timg.bdta.pro/images/9d319a5850be190b1456af69c3b861f1.jpg'),
(24394, 1665, 'As Visões da Raven S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113132.mp4', 'http://timg.bdta.pro/images/bed9a9d61b6bf48ba0f9c4716ab837db.jpg'),
(24395, 1665, 'As Visões da Raven S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113133.mp4', 'http://timg.bdta.pro/images/178627fe305f637bc74ed1aa249d123f.jpg'),
(24396, 1665, 'As Visões da Raven S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113134.mp4', 'http://timg.bdta.pro/images/55335048e0182f5603e15ebaf569bc86.jpg'),
(24397, 1665, 'As Visões da Raven S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113135.mp4', 'http://timg.bdta.pro/images/eac4bb2a32f2d0559428242cd6e9fdcf.jpg'),
(24398, 1665, 'As Visões da Raven S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113136.mp4', 'http://timg.bdta.pro/images/26dc7f4e45737b5856a0dee2f16f5675.jpg'),
(24399, 1665, 'As Visões da Raven S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113137.mp4', 'http://timg.bdta.pro/images/47da6fd5076c65e7773e75d7282a3f9f.jpg'),
(24400, 1665, 'As Visões da Raven S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113138.mp4', 'http://timg.bdta.pro/images/4e372099db2f2c79f2866c674cb3d5f9.jpg'),
(24401, 1665, 'As Visões da Raven S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113139.mp4', 'http://timg.bdta.pro/images/f5a0411212fdf74c5aed2bc64ce37c94.jpg'),
(24402, 1665, 'As Visões da Raven S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113140.mp4', 'http://timg.bdta.pro/images/b47f785b698d419a479a0902083da93d.jpg'),
(24403, 1665, 'As Visões da Raven S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113141.mp4', 'http://timg.bdta.pro/images/e941e44c962ead3da6864f6cc2059545.jpg'),
(24404, 1665, 'As Visões da Raven S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113142.mp4', 'http://timg.bdta.pro/images/3006853f1e18fb8fc6e48ce78b8cc42d.jpg'),
(24405, 1665, 'As Visões da Raven S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113143.mp4', 'http://timg.bdta.pro/images/66af71be737a908a42439c213e416e76.jpg'),
(24406, 1665, 'As Visões da Raven S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113144.mp4', 'http://timg.bdta.pro/images/9d1adaa6c2f772322d2c5ddb8f06d694.jpg'),
(24407, 1665, 'As Visões da Raven S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113145.mp4', 'http://timg.bdta.pro/images/f6994854b359875abdcba086549b8a28.jpg'),
(24408, 1665, 'As Visões da Raven S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113146.mp4', 'http://timg.bdta.pro/images/86211f311c86ca9461962aad31fe03c6.jpg'),
(24409, 1665, 'As Visões da Raven S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113147.mp4', 'http://timg.bdta.pro/images/cd61015a154b7040bd9e7a844bf7b7bb.jpg'),
(24410, 1665, 'As Visões da Raven S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113148.mp4', 'http://timg.bdta.pro/images/2b3d0de2927da56036f7950900c36e54.jpg'),
(24411, 1665, 'As Visões da Raven S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/113149.mp4', 'http://timg.bdta.pro/images/5d429e7c5d2bb27549ea753eaf60fc29.jpg'),
(24412, 1665, 'As Visões da Raven S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/113150.mp4', 'http://timg.bdta.pro/images/c411e1c02b7319aeca8e787014f402ad.jpg'),
(24413, 1665, 'As Visões da Raven S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/113151.mp4', 'http://timg.bdta.pro/images/1f326892891cf9198d3afe12f183cee2.jpg'),
(24414, 1666, 'As Visões da Raven S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113152.mp4', 'http://timg.bdta.pro/images/b406690c5740148489d0c7fc1bf870f1.jpg'),
(24415, 1666, 'As Visões da Raven S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113153.mp4', 'http://timg.bdta.pro/images/df3b4f8e77ae984866f6621af41a21dc.jpg'),
(24416, 1666, 'As Visões da Raven S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113154.mp4', 'http://timg.bdta.pro/images/8e59f12266bf12af35d4acd0b4957610.jpg'),
(24417, 1666, 'As Visões da Raven S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113155.mp4', 'http://timg.bdta.pro/images/7c84db70036b2bf982c64b9e0866b967.jpg'),
(24418, 1666, 'As Visões da Raven S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113156.mp4', 'http://timg.bdta.pro/images/90ce014fdf623fa99de3f6c4696adf86.jpg'),
(24419, 1666, 'As Visões da Raven S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113157.mp4', 'http://timg.bdta.pro/images/d7503818daf633c80e10d105f4ee49d1.jpg'),
(24420, 1666, 'As Visões da Raven S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113158.mp4', 'http://timg.bdta.pro/images/eec839515ceb7b1c7928c16dbb08ca96.jpg'),
(24421, 1666, 'As Visões da Raven S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113159.mp4', 'http://timg.bdta.pro/images/7ea7a9625286c6533c424915a748e616.jpg'),
(24422, 1666, 'As Visões da Raven S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113160.mp4', 'http://timg.bdta.pro/images/05688f0b0ee016091c6e0acc5c076775.jpg'),
(24423, 1666, 'As Visões da Raven S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113161.mp4', 'http://timg.bdta.pro/images/b80264a33e9abc7d784faf5a2b1fbe51.jpg'),
(24424, 1666, 'As Visões da Raven S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113162.mp4', 'http://timg.bdta.pro/images/ecee311c33d585b106746c1378c6084c.jpg'),
(24425, 1666, 'As Visões da Raven S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113163.mp4', 'http://timg.bdta.pro/images/f9c3a92af466047d52d78e2cacff3f85.jpg'),
(24426, 1666, 'As Visões da Raven S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113164.mp4', 'http://timg.bdta.pro/images/8b689157f721c6c571a10cc6c9c12508.jpg'),
(24427, 1666, 'As Visões da Raven S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113165.mp4', 'http://timg.bdta.pro/images/c615a9af684fadc356b28e17e855773c.jpg'),
(24428, 1666, 'As Visões da Raven S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113166.mp4', 'http://timg.bdta.pro/images/be35dfcfd31c5abad5f3d423124db487.jpg'),
(24429, 1666, 'As Visões da Raven S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113167.mp4', 'http://timg.bdta.pro/images/f0dea65f47a85aa181cd6681a48a0457.jpg'),
(24430, 1666, 'As Visões da Raven S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113168.mp4', 'http://timg.bdta.pro/images/6463d080fb107add2f53f43b06347638.jpg'),
(24431, 1666, 'As Visões da Raven S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113169.mp4', 'http://timg.bdta.pro/images/7bfd6afefa88f7f65af37d3943874cdf.jpg'),
(24432, 1666, 'As Visões da Raven S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113170.mp4', 'http://timg.bdta.pro/images/f0ba17f80319647056ec883086ae042d.jpg'),
(24433, 1666, 'As Visões da Raven S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/113171.mp4', 'http://timg.bdta.pro/images/ac54535891ea3a9298e639bfdcd2e3ea.jpg'),
(24434, 1666, 'As Visões da Raven S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/113172.mp4', 'http://timg.bdta.pro/images/63660c3d79853aba9fd6e8c62fc7356b.jpg'),
(24435, 1666, 'As Visões da Raven S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/113173.mp4', 'http://timg.bdta.pro/images/9be0e466f23e2b752eac0ececc3aa390.jpg'),
(24436, 1666, 'As Visões da Raven S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/113174.mp4', 'http://timg.bdta.pro/images/7296fe4138b8de80a0796b71f2942a85.jpg'),
(24437, 1666, 'As Visões da Raven S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/113175.mp4', 'http://timg.bdta.pro/images/75e9b7445d15622daa6045829620cf42.jpg'),
(24438, 1666, 'As Visões da Raven S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/113176.mp4', 'http://timg.bdta.pro/images/d626b18e8e6f949090fd1961ef352009.jpg'),
(24439, 1666, 'As Visões da Raven S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/113177.mp4', 'http://timg.bdta.pro/images/dcd89205785b424573cb2d8dfb2f3732.jpg'),
(24440, 1666, 'As Visões da Raven S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/113178.mp4', 'http://timg.bdta.pro/images/adae3e847240fb7c80bc4f79ee71dbe9.jpg'),
(24441, 1666, 'As Visões da Raven S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/113179.mp4', 'http://timg.bdta.pro/images/0eeb327dfe21d1a5d864f23615da6554.jpg'),
(24442, 1666, 'As Visões da Raven S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/113180.mp4', 'http://timg.bdta.pro/images/e33ff2f23604fc78f4daa314af515af9.jpg'),
(24443, 1666, 'As Visões da Raven S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/113181.mp4', 'http://timg.bdta.pro/images/826528df0f1a83d48290c0fc22f3ecd1.jpg'),
(24444, 1666, 'As Visões da Raven S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/113182.mp4', 'http://timg.bdta.pro/images/e830cfe2f9eaba8facc3216b7eac27e1.jpg'),
(24445, 1666, 'As Visões da Raven S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/113183.mp4', 'http://timg.bdta.pro/images/2267e85cb5ab855a5b7a4a73e0b21fd3.jpg'),
(24446, 1666, 'As Visões da Raven S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/113184.mp4', 'http://timg.bdta.pro/images/550f0f0f87740354e5a80611de973184.jpg'),
(24447, 1666, 'As Visões da Raven S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/113185.mp4', 'http://timg.bdta.pro/images/802f3477a2faf53efcccfb6244f1e637.jpg'),
(24448, 1667, 'As Visões da Raven S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113186.mp4', 'http://timg.bdta.pro/images/9d8953e30a3bdf0daa3ac75e2e388ec6.jpg'),
(24449, 1667, 'As Visões da Raven S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113187.mp4', 'http://timg.bdta.pro/images/32175873b2656f977eb221d528b51117.jpg'),
(24450, 1667, 'As Visões da Raven S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113188.mp4', 'http://timg.bdta.pro/images/a3a395842feea902727fb1ea379e6561.jpg'),
(24451, 1667, 'As Visões da Raven S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113189.mp4', 'http://timg.bdta.pro/images/dd5fd9f56bd768a0aa71b3aae8cf87b9.jpg'),
(24452, 1667, 'As Visões da Raven S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113190.mp4', 'http://timg.bdta.pro/images/638399ae2d5174abbf1efaf1026c2649.jpg'),
(24453, 1667, 'As Visões da Raven S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113191.mp4', 'http://timg.bdta.pro/images/1329a83d1c5a7a0b7535c00a57c06565.jpg'),
(24454, 1667, 'As Visões da Raven S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113192.mp4', 'http://timg.bdta.pro/images/d86da983ad37ecb57ad54fba2fcf02b2.jpg'),
(24455, 1667, 'As Visões da Raven S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113193.mp4', 'http://timg.bdta.pro/images/7f39af0b4d35586ae6ecc8e5da413c08.jpg'),
(24456, 1667, 'As Visões da Raven S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113194.mp4', 'http://timg.bdta.pro/images/4a4a2aa43f3b4cfc7d120f9a8af4e6de.jpg'),
(24457, 1667, 'As Visões da Raven S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113195.mp4', 'http://timg.bdta.pro/images/9650c50d5416f26504635774a301e97b.jpg'),
(24458, 1667, 'As Visões da Raven S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113196.mp4', 'http://timg.bdta.pro/images/d9a0fb551688f7eb84cf0a14959afc0b.jpg'),
(24459, 1667, 'As Visões da Raven S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113197.mp4', 'http://timg.bdta.pro/images/344e5f7fbf2c802be7f8959a340591e5.jpg'),
(24460, 1667, 'As Visões da Raven S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113198.mp4', 'http://timg.bdta.pro/images/f1a2dad620ca1ef8551dc486965fe176.jpg'),
(24461, 1667, 'As Visões da Raven S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113199.mp4', 'http://timg.bdta.pro/images/b42a29ae011cd697de224edb44c3dcef.jpg'),
(24462, 1667, 'As Visões da Raven S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113200.mp4', 'http://timg.bdta.pro/images/a741918a485fc0eedb93666ddb2c02a0.jpg'),
(24463, 1667, 'As Visões da Raven S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113201.mp4', 'http://timg.bdta.pro/images/9cea878ca50ee134fb1d8d7102fdc3b7.jpg'),
(24464, 1667, 'As Visões da Raven S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113202.mp4', 'http://timg.bdta.pro/images/a2f2d2bfdaa506a02f591ef4f49cf8ef.jpg'),
(24465, 1667, 'As Visões da Raven S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113203.mp4', 'http://timg.bdta.pro/images/259227bbfd8b8b521e97048609224652.jpg'),
(24466, 1667, 'As Visões da Raven S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113204.mp4', 'http://timg.bdta.pro/images/62779139522d4eeae21cf92bcf2f1d05.jpg'),
(24467, 1667, 'As Visões da Raven S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/113205.mp4', 'http://timg.bdta.pro/images/f81461f0fde2457d5260b32ec6629601.jpg'),
(24468, 1667, 'As Visões da Raven S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/113206.mp4', 'http://timg.bdta.pro/images/1f36a4f1033a7bc3a2b1f1f7579c7299.jpg'),
(24469, 1668, 'Locke & Key S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195353.mp4', 'http://timg.bdta.pro/images/0971790a548c8ffa67f18efe080a2af4.jpg'),
(24470, 1668, 'Locke & Key S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195354.mp4', 'http://timg.bdta.pro/images/8a24c78b6a8039bf27d2426bd1ded76c.jpg'),
(24471, 1668, 'Locke & Key S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195355.mp4', 'http://timg.bdta.pro/images/0cfa1f6d5e95da95c621e1cde0139b83.jpg'),
(24472, 1668, 'Locke & Key S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195356.mp4', 'http://timg.bdta.pro/images/17b35018dc9c72ab098afec90e33ef34.jpg'),
(24473, 1668, 'Locke & Key S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195357.mp4', 'http://timg.bdta.pro/images/a086f10eaa71cdd7ffbe39dd652ddb60.jpg'),
(24474, 1668, 'Locke & Key S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195358.mp4', 'http://timg.bdta.pro/images/0092c2019bd945296dd6393b291388c6.jpg'),
(24475, 1668, 'Locke & Key S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195359.mp4', 'http://timg.bdta.pro/images/234c9f075de8ce2cb86eff8a11b9987f.jpg'),
(24476, 1668, 'Locke & Key S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195360.mp4', 'http://timg.bdta.pro/images/ad5cb479f168c1b147ddbba75001df78.jpg'),
(24477, 1668, 'Locke & Key S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195361.mp4', 'http://timg.bdta.pro/images/fe17a3ef87209fa7910e041a62eee65e.jpg'),
(24478, 1668, 'Locke & Key S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195362.mp4', 'http://timg.bdta.pro/images/41ef3aab9ce0abe7efb3f98a8efe3cb5.jpg'),
(24479, 1669, 'Locke & Key S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/XQTE5RmMh4foxCO5DQA8o0YmZB.jpg'),
(24480, 1669, 'Locke & Key S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3c2dzU3HeY6SYztCRrLCThsG7fd.jpg'),
(24481, 1669, 'Locke & Key S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eDTOGmryRZYvoYhLV1SPEmlvWIM.jpg'),
(24482, 1669, 'Locke & Key S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2aczVxEAToSRn93vq1ajxvkhEbu.jpg'),
(24483, 1669, 'Locke & Key S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xX2DpWTf2dgYGGmbfpp2uis525G.jpg'),
(24484, 1669, 'Locke & Key S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shI8xP2jILiwNSeSmtcJzdB76UN.jpg'),
(24485, 1669, 'Locke & Key S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uAhZUK0To4mZpOQ8cHe52QY8JiB.jpg'),
(24486, 1669, 'Locke & Key S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nLaNbD6VlqdyhAJCEex8W7qs6UU.jpg'),
(24487, 1669, 'Locke & Key S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tTNJp4wW2dDvY6dYvY72Fs0PX9F.jpg'),
(24488, 1669, 'Locke & Key S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ms6gsaGcCdOApInjixbTlYR5aWJ.jpg'),
(24489, 1670, 'Locke & Key S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195373.mp4', 'http://timg.bdta.pro/images/a21c240f144b597c2b7940e5822ce075.jpg'),
(24490, 1670, 'Locke & Key S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195374.mp4', 'http://timg.bdta.pro/images/82755aa513f5857d65522111190e737d.jpg'),
(24491, 1670, 'Locke & Key S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195375.mp4', 'http://timg.bdta.pro/images/f7f6eec4edf4fe82ed385ec4a3ee8d34.jpg'),
(24492, 1670, 'Locke & Key S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195376.mp4', 'http://timg.bdta.pro/images/cd84cd37ebc800cb0b1130e2f18f217f.jpg'),
(24493, 1670, 'Locke & Key S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195377.mp4', 'http://timg.bdta.pro/images/fb8cdfdce20a95ec0bf6db8fc94459b7.jpg'),
(24494, 1670, 'Locke & Key S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195378.mp4', 'http://timg.bdta.pro/images/162b540404934951a2c3ab61d223671f.jpg'),
(24495, 1670, 'Locke & Key S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195379.mp4', 'http://timg.bdta.pro/images/fc8870dcc11c09cbb6f4ee6e0de6bbf5.jpg'),
(24496, 1670, 'Locke & Key S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195380.mp4', 'http://timg.bdta.pro/images/f034cf74720663228d330d34b035295e.jpg'),
(24497, 1671, 'Lua Negra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108010.mp4', 'http://timg.bdta.pro/images/2489c500c8a730dd48c86ddc75f05a04.jpg'),
(24498, 1671, 'Lua Negra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108011.mp4', 'http://timg.bdta.pro/images/34dcb42372532a34c0bb88315539c70d.jpg'),
(24499, 1671, 'Lua Negra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108012.mp4', 'http://timg.bdta.pro/images/353597bbf4a52aab827c223f9a5a3613.jpg'),
(24500, 1671, 'Lua Negra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108013.mp4', 'http://timg.bdta.pro/images/a6eb5c13aa9e788988f7fa8164a12db0.jpg'),
(24501, 1671, 'Lua Negra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108014.mp4', 'http://timg.bdta.pro/images/fd53082d4efa8832505eac268c221433.jpg'),
(24502, 1671, 'Lua Negra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108015.mp4', 'http://timg.bdta.pro/images/73ff156f01d9246d02d9e4fa281c62e5.jpg'),
(24503, 1672, 'Magnum P.I. S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236956.mp4', 'http://timg.bdta.pro/images/660e701f7519bd5a24817c383aa97c07.jpg'),
(24504, 1672, 'Magnum P.I. S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236957.mp4', 'http://timg.bdta.pro/images/2dc6dc7f9212834b63ce59e45cbe03cd.jpg'),
(24505, 1672, 'Magnum P.I. S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236958.mp4', 'http://timg.bdta.pro/images/3f7350b9670797970bc0153c4dacb848.jpg'),
(24506, 1672, 'Magnum P.I. S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236959.mp4', 'http://timg.bdta.pro/images/ce2dc550b5371b1c73d5b02ffa43f044.jpg'),
(24507, 1672, 'Magnum P.I. S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236960.mp4', 'http://timg.bdta.pro/images/87217b56c46e311f9f3e8a52663cfeea.jpg'),
(24508, 1672, 'Magnum P.I. S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236961.mp4', 'http://timg.bdta.pro/images/511023c183c17b7fa4eb6a8b4a34a46e.jpg'),
(24509, 1672, 'Magnum P.I. S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236962.mp4', 'http://timg.bdta.pro/images/2b0896eac308789f830a63064b90eb05.jpg'),
(24510, 1672, 'Magnum P.I. S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236963.mp4', 'http://timg.bdta.pro/images/6623a0bd1787da0e1bc2637eac5e6a89.jpg'),
(24511, 1672, 'Magnum P.I. S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236964.mp4', 'http://timg.bdta.pro/images/fed695340876c04af93f01dad265e954.jpg'),
(24512, 1672, 'Magnum P.I. S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236965.mp4', 'http://timg.bdta.pro/images/7646ab87a9d2b4b6039bc120858a6028.jpg'),
(24513, 1672, 'Magnum P.I. S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236966.mp4', 'http://timg.bdta.pro/images/1a9909483cadd4e9f6519fa8f509cc34.jpg'),
(24514, 1672, 'Magnum P.I. S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236967.mp4', 'http://timg.bdta.pro/images/f8df50efdbbefe011a927a12fdd9ec1d.jpg'),
(24515, 1672, 'Magnum P.I. S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236968.mp4', 'http://timg.bdta.pro/images/cd45fd629162398b9b8191b24c181e29.jpg'),
(24516, 1672, 'Magnum P.I. S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236969.mp4', 'http://timg.bdta.pro/images/ff12cd7561969a1e40ef1ab7dfc9e9a8.jpg'),
(24517, 1672, 'Magnum P.I. S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236970.mp4', 'http://timg.bdta.pro/images/a86122e655bd63b8b418aaa5a2e6f442.jpg'),
(24518, 1672, 'Magnum P.I. S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236971.mp4', 'http://timg.bdta.pro/images/cd6d2d87b999e6b51eff00f141338821.jpg'),
(24519, 1672, 'Magnum P.I. S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/599416.mp4', 'http://gstaticontent.com/images/dd0083b26fb59bd05034a62458c09a35.jpg'),
(24520, 1672, 'Magnum P.I. S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236974.mp4', 'http://timg.bdta.pro/images/cf6c31b37666963018061a91aa59f8b5.jpg'),
(24521, 1672, 'Magnum P.I. S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/236975.mp4', 'http://timg.bdta.pro/images/aa581bd451a924c9892fa7595f5f10c9.jpg'),
(24522, 1672, 'Magnum P.I. S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/236976.mp4', 'http://timg.bdta.pro/images/94276a56c9f969479a33a407dc1d44cd.jpg'),
(24523, 1673, 'Magnum P.I. S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236977.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24524, 1673, 'Magnum P.I. S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236978.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24525, 1673, 'Magnum P.I. S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236979.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24526, 1673, 'Magnum P.I. S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236980.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24527, 1673, 'Magnum P.I. S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236981.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24528, 1673, 'Magnum P.I. S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236982.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24529, 1673, 'Magnum P.I. S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236983.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24530, 1673, 'Magnum P.I. S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236984.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24531, 1673, 'Magnum P.I. S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236985.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24532, 1673, 'Magnum P.I. S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236986.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24533, 1673, 'Magnum P.I. S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236987.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24534, 1673, 'Magnum P.I. S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236988.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24535, 1673, 'Magnum P.I. S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236989.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24536, 1673, 'Magnum P.I. S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236990.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24537, 1673, 'Magnum P.I. S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236991.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24538, 1673, 'Magnum P.I. S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236992.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24539, 1673, 'Magnum P.I. S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236993.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24540, 1673, 'Magnum P.I. S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236994.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24541, 1673, 'Magnum P.I. S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/236995.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24542, 1673, 'Magnum P.I. S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/236996.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24543, 1674, 'Magnum P.I. S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236997.mp4', 'http://timg.bdta.pro/images/db9d17d2446993878a0b85d363a6bdea.jpg'),
(24544, 1674, 'Magnum P.I. S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236998.mp4', 'http://timg.bdta.pro/images/781576ba801ed433086f5ad20918cd23.jpg'),
(24545, 1674, 'Magnum P.I. S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236999.mp4', 'http://timg.bdta.pro/images/90980b3655e095f21de2bb46a3b8ffa8.jpg'),
(24546, 1674, 'Magnum P.I. S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237000.mp4', 'http://timg.bdta.pro/images/942970faf149aac3e44aa97dbede7aaa.jpg'),
(24547, 1674, 'Magnum P.I. S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237001.mp4', 'http://timg.bdta.pro/images/8f6fb1318eb6bbc2b1a7a9601c8805f2.jpg'),
(24548, 1674, 'Magnum P.I. S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237002.mp4', 'http://image.tmdb.org/t/p/w1280/xJzWJ1el6pSZYC98Af3zXtDRsT1.jpg'),
(24549, 1674, 'Magnum P.I. S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237003.mp4', 'http://image.tmdb.org/t/p/w1280/4iGbEiiNdY8m7kCc46MATCTfcLn.jpg'),
(24550, 1674, 'Magnum P.I. S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237004.mp4', 'http://image.tmdb.org/t/p/w1280/aDCBKKb9BdSzypfrpTuV1f9UFTi.jpg'),
(24551, 1674, 'Magnum P.I. S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237005.mp4', 'http://image.tmdb.org/t/p/w1280/dcGmwoqow8hHH68ES22WVgSoXrn.jpg'),
(24552, 1674, 'Magnum P.I. S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9hO0eJ9tz4OLQymSWUMF28F7wtx.jpg'),
(24553, 1674, 'Magnum P.I. S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2WOa9x9zP0Klu7AxfbUvbSMXEmI.jpg'),
(24554, 1674, 'Magnum P.I. S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237008.mp4', 'http://image.tmdb.org/t/p/w1280/c1bqsbjKDIYtYnmYvZRGJx5L7Y1.jpg'),
(24555, 1674, 'Magnum P.I. S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPOZ1uM8xzcBZCswumibCFJFw8V.jpg'),
(24556, 1674, 'Magnum P.I. S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3DnL9WfL6pdgKetbJjRUDHS7rsK.jpg'),
(24557, 1674, 'Magnum P.I. S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8tpShJ0ZyDLym2IGlRV8xXPtyG8.jpg'),
(24558, 1674, 'Magnum P.I. S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/237012.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24559, 1675, 'Magnum P.I. S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237013.mp4', 'http://timg.bdta.pro/images/28cbdc90a6eea2eecb27ce52934dd7ad.jpg'),
(24560, 1675, 'Magnum P.I. S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237014.mp4', 'http://timg.bdta.pro/images/922697608d1ac0c55342fcce1717b9a0.jpg'),
(24561, 1675, 'Magnum P.I. S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237015.mp4', 'http://timg.bdta.pro/images/ab004a8c31c9e39389c0ca03e9c20c20.jpg'),
(24562, 1675, 'Magnum P.I. S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237016.mp4', 'http://timg.bdta.pro/images/427df7fa60b48cfbd2badae3cec368e7.jpg'),
(24563, 1675, 'Magnum P.I. S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237017.mp4', 'http://timg.bdta.pro/images/a661c70bc86d8a9624c7159d53fb440a.jpg'),
(24564, 1675, 'Magnum P.I. S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237018.mp4', 'http://timg.bdta.pro/images/cdddb7debf2751e4dcf30531c9c31866.jpg'),
(24565, 1675, 'Magnum P.I. S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237019.mp4', 'http://timg.bdta.pro/images/ea986389b050b45fed36ed5a20734ee3.jpg'),
(24566, 1675, 'Magnum P.I. S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237020.mp4', 'http://timg.bdta.pro/images/80937ce13ab706a66788d947fde98822.jpg'),
(24567, 1675, 'Magnum P.I. S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237021.mp4', 'http://timg.bdta.pro/images/cdb4583f3da86887a6bae74d9bcf3c4c.jpg'),
(24568, 1675, 'Magnum P.I. S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237022.mp4', 'http://timg.bdta.pro/images/5e8fefd2a061363a12e6432a56449571.jpg'),
(24569, 1675, 'Magnum P.I. S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237023.mp4', 'http://timg.bdta.pro/images/d3a41e10fc0869787232e358fc31b886.jpg'),
(24570, 1675, 'Magnum P.I. S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237024.mp4', 'http://timg.bdta.pro/images/c1d399488e9e0b424b29844e4e80c7ec.jpg'),
(24571, 1675, 'Magnum P.I. S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237025.mp4', 'http://timg.bdta.pro/images/f26fea92dc052cf62d2315e84b509f3e.jpg'),
(24572, 1675, 'Magnum P.I. S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237026.mp4', 'http://timg.bdta.pro/images/3912e11f2f420fc15b4c2d89e48be1b1.jpg'),
(24573, 1675, 'Magnum P.I. S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237027.mp4', 'http://timg.bdta.pro/images/603e4d4cfb8af4cc41d973f2e469c06d.jpg'),
(24574, 1675, 'Magnum P.I. S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/237028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/swqEMBAjcJKMzGtNiRK02yoq9rk.jpg'),
(24575, 1675, 'Magnum P.I. S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/237029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eSQHjbNZ8RRASMH5Zrvgv8uZ5qz.jpg'),
(24576, 1675, 'Magnum P.I. S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/237030.mp4', 'http://image.tmdb.org/t/p/w1280/y2kKhHeMbIMV7xbodzaVCQiCpSi.jpg'),
(24577, 1675, 'Magnum P.I. S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/237031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sh2TQKt6Op9eQNqiuFUPcVPF9lU.jpg'),
(24578, 1675, 'Magnum P.I. S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/237032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aEug0iOiui5P0AZriW1jDgAws7q.jpg'),
(24579, 1676, 'Magnum P.I. S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237033.mp4', 'http://image.tmdb.org/t/p/w1280/vvNxPuYzJ4C2HS2nYd7RE4PnwBi.jpg'),
(24580, 1676, 'Magnum P.I. S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237034.mp4', 'http://image.tmdb.org/t/p/w1280/wDIHbPDHIAlBYIdrnuE9MbLl6AE.jpg'),
(24581, 1676, 'Magnum P.I. S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237035.mp4', 'http://image.tmdb.org/t/p/w1280/5W0szBfZ6krE91E2mc3iipTeHT5.jpg'),
(24582, 1676, 'Magnum P.I. S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237036.mp4', 'http://image.tmdb.org/t/p/w1280/5FxG7Mjp1PZfhYjet2C9q1FugRJ.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(24583, 1676, 'Magnum P.I. S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237037.mp4', 'http://image.tmdb.org/t/p/w1280/wRK71GBeweY8aiPs0qu9FGgejOD.jpg'),
(24584, 1676, 'Magnum P.I. S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237038.mp4', 'http://image.tmdb.org/t/p/w1280/aeqw4LjaFcneYK4eCUGw0KHXHdF.jpg'),
(24585, 1676, 'Magnum P.I. S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237039.mp4', 'http://image.tmdb.org/t/p/w1280/xyOrbOGZZEYjPkJSYTb2wCDT32H.jpg'),
(24586, 1676, 'Magnum P.I. S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237040.mp4', 'http://image.tmdb.org/t/p/w1280/3gtxQiTMkyTRzltawjVpdBvpFgS.jpg'),
(24587, 1676, 'Magnum P.I. S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237041.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24588, 1676, 'Magnum P.I. S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237042.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24589, 1676, 'Magnum P.I. S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/276500.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24590, 1676, 'Magnum P.I. S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/276501.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24591, 1676, 'Magnum P.I. S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/280858.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24592, 1676, 'Magnum P.I. S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/287150.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24593, 1676, 'Magnum P.I. S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/296334.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24594, 1676, 'Magnum P.I. S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/302676.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24595, 1676, 'Magnum P.I. S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/306104.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24596, 1676, 'Magnum P.I. S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/312433.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24597, 1676, 'Magnum P.I. S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/322617.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24598, 1676, 'Magnum P.I. S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/325674.mp4', 'http://gstaticontent.com/images/son6AuCmsoPWmRgPP6fKQacV9wt_big.jpg'),
(24599, 1677, 'Mao Mao: Heróis de Coração Puro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v7i9ftbOUv3ipMKUDyTEbudCe9J.jpg'),
(24600, 1677, 'Mao Mao: Heróis de Coração Puro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dhXnyoDF51alUJ1toEjvu3EmZtP.jpg'),
(24601, 1677, 'Mao Mao: Heróis de Coração Puro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9vQZJMcmBXy1NMtPiPx6QORSwzq.jpg'),
(24602, 1677, 'Mao Mao: Heróis de Coração Puro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xYB1KUdqHQlI8oB82bjp6KZfKvI.jpg'),
(24603, 1677, 'Mao Mao: Heróis de Coração Puro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pWWcxt4Rl5o297yi1uUMwez3Bal.jpg'),
(24604, 1677, 'Mao Mao: Heróis de Coração Puro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y2ZZMIHPf9bYcrgUBVXr3sp5TBX.jpg'),
(24605, 1677, 'Mao Mao: Heróis de Coração Puro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6CVm9S8A5fYgosB9m4cGoiB4YKQ.jpg'),
(24606, 1677, 'Mao Mao: Heróis de Coração Puro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1SaYfUpOTwacxkkVgZFfGxfFFRj.jpg'),
(24607, 1677, 'Mao Mao: Heróis de Coração Puro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lJRE3WvPNKCDXEkIShD9kP9G2kB.jpg'),
(24608, 1677, 'Mao Mao: Heróis de Coração Puro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2dePVYOyJZxSQ5d5Ac103ZBr0XS.jpg'),
(24609, 1677, 'Mao Mao: Heróis de Coração Puro S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sg9JcomBWpEaA88cdR4Jl6ALBJm.jpg'),
(24610, 1677, 'Mao Mao: Heróis de Coração Puro S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qGYgYLEra0E6uQYYJRdI8S8MUR2.jpg'),
(24611, 1677, 'Mao Mao: Heróis de Coração Puro S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pWJE1fAZWDL47C9OLBfodePoXrC.jpg'),
(24612, 1677, 'Mao Mao: Heróis de Coração Puro S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/159848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Zmpe1UvlFljzP55y5VtZWx4S5z.jpg'),
(24613, 1677, 'Mao Mao: Heróis de Coração Puro S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/159849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nW1u9FtX6xjME17IMI6KpuefE3F.jpg'),
(24614, 1677, 'Mao Mao: Heróis de Coração Puro S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/159850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dLZbI4BJiJakUhAL14oKzzRutCT.jpg'),
(24615, 1677, 'Mao Mao: Heróis de Coração Puro S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/159851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xBhZoEoQUIo3ecY8x7dZxAEUN9f.jpg'),
(24616, 1677, 'Mao Mao: Heróis de Coração Puro S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/159852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hm5GPK9byHnFcETtuYbtC5LqOPM.jpg'),
(24617, 1677, 'Mao Mao: Heróis de Coração Puro S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/159853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fu0KQhQxHB3m8uj01Abe2CWmHu9.jpg'),
(24618, 1677, 'Mao Mao: Heróis de Coração Puro S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/159854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hWZAqy8EPRCTF2RGTsUXfVkfVU2.jpg'),
(24619, 1677, 'Mao Mao: Heróis de Coração Puro S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/159855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nCJVjZnCtqJojX9Rh5aCdyVA5y2.jpg'),
(24620, 1677, 'Mao Mao: Heróis de Coração Puro S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/159856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gDyR9zKi03EbdfEzSrr6xEQCcEn.jpg'),
(24621, 1677, 'Mao Mao: Heróis de Coração Puro S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/159857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFOlxH6fDq4990UMOoMv3WqJMZK.jpg'),
(24622, 1677, 'Mao Mao: Heróis de Coração Puro S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/159858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qizmPcsppgNldiId1ZhZxxT3Gxf.jpg'),
(24623, 1677, 'Mao Mao: Heróis de Coração Puro S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/159859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3RlbC04t5EeLMy0mxJMheS2h1cC.jpg'),
(24624, 1677, 'Mao Mao: Heróis de Coração Puro S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/159860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gSIWaeG7OjU9YgrxNWTBj3EpDzG.jpg'),
(24625, 1677, 'Mao Mao: Heróis de Coração Puro S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/159861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ODzYpluWVOl0Jva8UVvjUsrhTt.jpg'),
(24626, 1677, 'Mao Mao: Heróis de Coração Puro S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/159862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wcO4wfjyxPU2ucMGKOYoDycG5nb.jpg'),
(24627, 1677, 'Mao Mao: Heróis de Coração Puro S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/159863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s29a2qHo3SFwkf7Ax5yN8hox7Lw.jpg'),
(24628, 1677, 'Mao Mao: Heróis de Coração Puro S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/159864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ApbPvU5pz8GDvWGQe4tFbCJLPsz.jpg'),
(24629, 1677, 'Mao Mao: Heróis de Coração Puro S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/159865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1yyYPTSC8p2xgvSHlivBW0uoKWG.jpg'),
(24630, 1677, 'Mao Mao: Heróis de Coração Puro S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/159866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2u1qogw3VTnqrkZ3wqQW7oTlKFE.jpg'),
(24631, 1677, 'Mao Mao: Heróis de Coração Puro S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/159867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/idaNub9VF9yd7zY78HcR8uPT1jA.jpg'),
(24632, 1677, 'Mao Mao: Heróis de Coração Puro S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/159868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMo9ef1G61gsBKCghzDeNvzvTsd.jpg'),
(24633, 1677, 'Mao Mao: Heróis de Coração Puro S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/159869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wCYVpkfi7MMu7hVLIF34ykHgc8T.jpg'),
(24634, 1677, 'Mao Mao: Heróis de Coração Puro S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/159870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cnWg8a63o1zZ2O9Mk7JpwEAZjOD.jpg'),
(24635, 1677, 'Mao Mao: Heróis de Coração Puro S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/159871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oPolrWs6ecdGLg57icfNchoF3Py.jpg'),
(24636, 1677, 'Mao Mao: Heróis de Coração Puro S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/159872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yzNHJUpAD9KsCUBDPPwWhIikWBK.jpg'),
(24637, 1677, 'Mao Mao: Heróis de Coração Puro S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/159873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sxZFFUlkgmNGkjIlhWnoDH3GyOw.jpg'),
(24638, 1677, 'Mao Mao: Heróis de Coração Puro S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/159874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sDoatfk9GsoyjklgnOlzy9kQhFs.jpg'),
(24639, 1678, 'Sra. Wilson S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108007.mp4', 'http://timg.bdta.pro/images/fcc4f665d4c3086f2c120b757e1c97df.jpg'),
(24640, 1678, 'Sra. Wilson S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108008.mp4', 'http://timg.bdta.pro/images/f5d4cbc91e90e358d6a77a82af62f0f6.jpg'),
(24641, 1678, 'Sra. Wilson S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108009.mp4', 'http://timg.bdta.pro/images/2a9ebc5841276258194fe69b65859755.jpg'),
(24642, 1679, 'Mythic Quest: Raven\'s Banquet S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201942.mp4', 'http://timg.bdta.pro/images/0c96f95dc314809b073cb6a6dc71c48d.jpg'),
(24643, 1679, 'Mythic Quest: Raven\'s Banquet S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201943.mp4', 'http://timg.bdta.pro/images/520f89d62c3ca705835a888128407b2f.jpg'),
(24644, 1679, 'Mythic Quest: Raven\'s Banquet S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201944.mp4', 'http://timg.bdta.pro/images/34e9f787cd473794a63dda597e8dd767.jpg'),
(24645, 1679, 'Mythic Quest: Raven\'s Banquet S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201945.mp4', 'http://timg.bdta.pro/images/197694badd84e0d10a36bd9ab186b64b.jpg'),
(24646, 1679, 'Mythic Quest: Raven\'s Banquet S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201946.mp4', 'http://timg.bdta.pro/images/b4c52fdfe873cbaab34a2e3ca196bdea.jpg'),
(24647, 1679, 'Mythic Quest: Raven\'s Banquet S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201947.mp4', 'http://timg.bdta.pro/images/a4dd0461a0635170928d539a72e14432.jpg'),
(24648, 1679, 'Mythic Quest: Raven\'s Banquet S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201948.mp4', 'http://timg.bdta.pro/images/d1e48d85d815d420aecf2e6a118f18e2.jpg'),
(24649, 1679, 'Mythic Quest: Raven\'s Banquet S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201949.mp4', 'http://timg.bdta.pro/images/bbccd1a4a27e5b81358ca536974b96d3.jpg'),
(24650, 1680, 'Mythic Quest: Raven\'s Banquet S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201950.mp4', 'http://timg.bdta.pro/images/135bc5a793abec6edfca49e74312a2ef.jpg'),
(24651, 1680, 'Mythic Quest: Raven\'s Banquet S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201951.mp4', 'http://timg.bdta.pro/images/c9667c4870cb1922dd7b5c296c500f6a.jpg'),
(24652, 1680, 'Mythic Quest: Raven\'s Banquet S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201952.mp4', 'http://timg.bdta.pro/images/5a051e58c525e1d6f9748363ee4ebd83.jpg'),
(24653, 1680, 'Mythic Quest: Raven\'s Banquet S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201953.mp4', 'http://timg.bdta.pro/images/c4bef0c5b638a5b90735ada5f7dfc2dd.jpg'),
(24654, 1680, 'Mythic Quest: Raven\'s Banquet S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201954.mp4', 'http://timg.bdta.pro/images/0dc6c7a6ea2297fc5a6e0576dea1fcd4.jpg'),
(24655, 1680, 'Mythic Quest: Raven\'s Banquet S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201955.mp4', 'http://timg.bdta.pro/images/33a291dd0f67df0ba67dbfe01eda79e3.jpg'),
(24656, 1680, 'Mythic Quest: Raven\'s Banquet S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201956.mp4', 'http://timg.bdta.pro/images/b43eef50e399460268a84deae4382035.jpg'),
(24657, 1680, 'Mythic Quest: Raven\'s Banquet S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201957.mp4', 'http://timg.bdta.pro/images/2ec71dd514e5ad22467220953d1bd4e0.jpg'),
(24658, 1680, 'Mythic Quest: Raven\'s Banquet S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201958.mp4', 'http://timg.bdta.pro/images/aa5726febaa1be7b7041b91f7e91c6f9.jpg'),
(24659, 1681, 'Mythic Quest: Raven\'s Banquet S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xHzxV7XCEafBz4zdiWYOHLdG1sj.jpg'),
(24660, 1681, 'Mythic Quest: Raven\'s Banquet S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sSL8KOXesnuZlDmUtfUNJfcknli.jpg'),
(24661, 1681, 'Mythic Quest: Raven\'s Banquet S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWO8JbDR7zl0GhZP6afPfi8eLkf.jpg'),
(24662, 1681, 'Mythic Quest: Raven\'s Banquet S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/srxjYVudgX9UYU3cIcxJHliZKOL.jpg'),
(24663, 1681, 'Mythic Quest: Raven\'s Banquet S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201963.mp4', 'http://image.tmdb.org/t/p/w1280/x9wHZC3Rxm3tWWm1brnG294Azc7.jpg'),
(24664, 1681, 'Mythic Quest: Raven\'s Banquet S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201964.mp4', 'http://image.tmdb.org/t/p/w1280/pDC5P5wX5K743zlr0pN4R0pxQCz.jpg'),
(24665, 1681, 'Mythic Quest: Raven\'s Banquet S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201965.mp4', 'http://image.tmdb.org/t/p/w1280/wsRkGpwiS9NvqemjuTySVNTZfcX.jpg'),
(24666, 1681, 'Mythic Quest: Raven\'s Banquet S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vuuzriH1BrE3SKYP3yfgwPJbv7X.jpg'),
(24667, 1681, 'Mythic Quest: Raven\'s Banquet S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/usV94nMJvhLVLmz0olU7VofVei1.jpg'),
(24668, 1681, 'Mythic Quest: Raven\'s Banquet S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201968.mp4', 'http://image.tmdb.org/t/p/w1280/xUGhIKYQawpy0Ero8hHh655ftu9.jpg'),
(24669, 1682, 'Mythic Quest: Raven\'s Banquet S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/684344.mp4', 'http://gstaticontent.com/images/lEPXDqTntfWGWoU4E0xtxhFn2Wj_big.jpg'),
(24670, 1682, 'Mythic Quest: Raven\'s Banquet S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/684345.mp4', 'http://gstaticontent.com/images/lEPXDqTntfWGWoU4E0xtxhFn2Wj_big.jpg'),
(24671, 1682, 'Mythic Quest: Raven\'s Banquet S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/684346.mp4', 'http://gstaticontent.com/images/lEPXDqTntfWGWoU4E0xtxhFn2Wj_big.jpg'),
(24672, 1682, 'Mythic Quest: Raven\'s Banquet S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/694949.mp4', 'http://gstaticontent.com/images/lEPXDqTntfWGWoU4E0xtxhFn2Wj_big.jpg'),
(24673, 1682, 'Mythic Quest: Raven\'s Banquet S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/701439.mp4', 'http://gstaticontent.com/images/lEPXDqTntfWGWoU4E0xtxhFn2Wj_big.jpg'),
(24674, 1682, 'Mythic Quest: Raven\'s Banquet S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/708983.mp4', 'http://gstaticontent.com/images/lEPXDqTntfWGWoU4E0xtxhFn2Wj_big.jpg'),
(24675, 1682, 'Mythic Quest: Raven\'s Banquet S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/717952.mp4', 'http://gstaticontent.com/images/lEPXDqTntfWGWoU4E0xtxhFn2Wj_big.jpg'),
(24676, 1682, 'Mythic Quest: Raven\'s Banquet S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/725697.mp4', 'http://gstaticontent.com/images/lEPXDqTntfWGWoU4E0xtxhFn2Wj_big.jpg'),
(24677, 1682, 'Mythic Quest: Raven\'s Banquet S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/732151.mp4', 'http://gstaticontent.com/images/lEPXDqTntfWGWoU4E0xtxhFn2Wj_big.jpg'),
(24678, 1682, 'Mythic Quest: Raven\'s Banquet S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/739886.mp4', 'http://gstaticontent.com/images/lEPXDqTntfWGWoU4E0xtxhFn2Wj_big.jpg'),
(24679, 1683, 'Ragnarok S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233981.mp4', 'http://timg.bdta.pro/images/d1ac778e9dc0cefce91b9bdca7e9d818.jpg'),
(24680, 1683, 'Ragnarok S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233982.mp4', 'http://timg.bdta.pro/images/f3eeea1f34059825ed511ca9b0e5b62e.jpg'),
(24681, 1683, 'Ragnarok S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233983.mp4', 'http://timg.bdta.pro/images/e5df4de53043c5c7cad354f4c48f7cb4.jpg'),
(24682, 1683, 'Ragnarok S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233984.mp4', 'http://timg.bdta.pro/images/0eee884d88074ed6806d6046585e9afe.jpg'),
(24683, 1683, 'Ragnarok S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233985.mp4', 'http://timg.bdta.pro/images/8cff4385bff0f6a03b07fe8430425ed1.jpg'),
(24684, 1683, 'Ragnarok S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233986.mp4', 'http://timg.bdta.pro/images/3c5febf99fb23ae377cd19f9f255016b.jpg'),
(24685, 1684, 'Ragnarok S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233987.mp4', 'http://gstaticontent.com/images/1LRLLWGvs5sZdTzuMqLEahb88Pc_big.jpg'),
(24686, 1684, 'Ragnarok S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233988.mp4', 'http://gstaticontent.com/images/1LRLLWGvs5sZdTzuMqLEahb88Pc_big.jpg'),
(24687, 1684, 'Ragnarok S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233989.mp4', 'http://gstaticontent.com/images/1LRLLWGvs5sZdTzuMqLEahb88Pc_big.jpg'),
(24688, 1684, 'Ragnarok S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233990.mp4', 'http://gstaticontent.com/images/1LRLLWGvs5sZdTzuMqLEahb88Pc_big.jpg'),
(24689, 1684, 'Ragnarok S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233991.mp4', 'http://gstaticontent.com/images/1LRLLWGvs5sZdTzuMqLEahb88Pc_big.jpg'),
(24690, 1684, 'Ragnarok S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233992.mp4', 'http://gstaticontent.com/images/1LRLLWGvs5sZdTzuMqLEahb88Pc_big.jpg'),
(24691, 1685, 'Ragnarok S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqpkwb3KFfYuW1ia2fV27Mekgkh.jpg'),
(24692, 1685, 'Ragnarok S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ut8PuI4FHJfF7f5PUEOwK0EmEEt.jpg'),
(24693, 1685, 'Ragnarok S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tb17Tg1qdMt5J2skHN7VIINiHVI.jpg'),
(24694, 1685, 'Ragnarok S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hvVM6mxDyhfosUR9lwruVBGsLcg.jpg'),
(24695, 1685, 'Ragnarok S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNb0sfe1WqEw9DazHtCqXHEOPDl.jpg'),
(24696, 1685, 'Ragnarok S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lGvc2FXPGS1KuiBpqetRu33gZyE.jpg'),
(24697, 1686, 'O Jovem Papa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107997.mp4', 'http://timg.bdta.pro/images/2cd171e36bca588fc2c3bed2823dc2c5.jpg'),
(24698, 1686, 'O Jovem Papa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107998.mp4', 'http://timg.bdta.pro/images/7b16bf4f01a93642652f339bb037d101.jpg'),
(24699, 1686, 'O Jovem Papa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107999.mp4', 'http://timg.bdta.pro/images/df920ac7cff18eff19b8a696b4182b7c.jpg'),
(24700, 1686, 'O Jovem Papa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108000.mp4', 'http://timg.bdta.pro/images/d01849a6cfb01edc36cdce6bf55baa79.jpg'),
(24701, 1686, 'O Jovem Papa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108001.mp4', 'http://timg.bdta.pro/images/7c3ad870060619669486cdc23c4b90fa.jpg'),
(24702, 1686, 'O Jovem Papa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108002.mp4', 'http://timg.bdta.pro/images/35aaca3cf01c6eaf2cbc4c101ffd0d9e.jpg'),
(24703, 1686, 'O Jovem Papa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108003.mp4', 'http://timg.bdta.pro/images/c3b50237ae40a3637c4568ef07e021a2.jpg'),
(24704, 1686, 'O Jovem Papa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108004.mp4', 'http://timg.bdta.pro/images/5bf33b042611b08583a8b142e15ed9fe.jpg'),
(24705, 1686, 'O Jovem Papa S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108005.mp4', 'http://timg.bdta.pro/images/ecc27a951a9cd230dbd670c208be0c06.jpg'),
(24706, 1686, 'O Jovem Papa S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108006.mp4', 'http://timg.bdta.pro/images/33002ebcc95c9bcf7d98d3ea574eae83.jpg'),
(24707, 1687, 'Tudo ou Nada: Seleção Brasileira S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107992.mp4', 'http://timg.bdta.pro/images/73cc0b4c3b7b6ba3ccec33e689b58413.jpg'),
(24708, 1687, 'Tudo ou Nada: Seleção Brasileira S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107993.mp4', 'http://timg.bdta.pro/images/8c6d06e5f8ec46f1032d5fd8422ad7dc.jpg'),
(24709, 1687, 'Tudo ou Nada: Seleção Brasileira S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107994.mp4', 'http://timg.bdta.pro/images/d2422cd4943ef579c9933b73feb2d4f3.jpg'),
(24710, 1687, 'Tudo ou Nada: Seleção Brasileira S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107995.mp4', 'http://timg.bdta.pro/images/bb7d5fca08e4864ee5fceecb6312a7ab.jpg'),
(24711, 1687, 'Tudo ou Nada: Seleção Brasileira S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107996.mp4', 'http://timg.bdta.pro/images/9053ac4926fa5786a30f84e0aa761df9.jpg'),
(24712, 1688, 'Universo Ashley Garcia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107984.mp4', 'http://gstaticontent.com/images/ekoY0lniQPaeK7ejgcjDnirML6B_big.jpg'),
(24713, 1688, 'Universo Ashley Garcia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107985.mp4', 'http://gstaticontent.com/images/ekoY0lniQPaeK7ejgcjDnirML6B_big.jpg'),
(24714, 1688, 'Universo Ashley Garcia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107986.mp4', 'http://gstaticontent.com/images/ekoY0lniQPaeK7ejgcjDnirML6B_big.jpg'),
(24715, 1688, 'Universo Ashley Garcia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107987.mp4', 'http://gstaticontent.com/images/ekoY0lniQPaeK7ejgcjDnirML6B_big.jpg'),
(24716, 1688, 'Universo Ashley Garcia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107988.mp4', 'http://gstaticontent.com/images/ekoY0lniQPaeK7ejgcjDnirML6B_big.jpg'),
(24717, 1688, 'Universo Ashley Garcia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107989.mp4', 'http://gstaticontent.com/images/ekoY0lniQPaeK7ejgcjDnirML6B_big.jpg'),
(24718, 1688, 'Universo Ashley Garcia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107990.mp4', 'http://gstaticontent.com/images/ekoY0lniQPaeK7ejgcjDnirML6B_big.jpg'),
(24719, 1688, 'Universo Ashley Garcia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107991.mp4', 'http://gstaticontent.com/images/ekoY0lniQPaeK7ejgcjDnirML6B_big.jpg'),
(24720, 1689, 'Gilmore Girls: Um Ano para Recordar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107980.mp4', 'http://timg.bdta.pro/images/4b4b0e762626794d7801c4de43e5b975.jpg'),
(24721, 1689, 'Gilmore Girls: Um Ano para Recordar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107981.mp4', 'http://timg.bdta.pro/images/8e9fb15f4981cd143dccf707406ebad7.jpg'),
(24722, 1689, 'Gilmore Girls: Um Ano para Recordar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107982.mp4', 'http://timg.bdta.pro/images/0dfc08e9af9fc8e8a420246b48c1284f.jpg'),
(24723, 1689, 'Gilmore Girls: Um Ano para Recordar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107983.mp4', 'http://timg.bdta.pro/images/6c94c6c25f979c30d971f2957562ed68.jpg'),
(24724, 1690, 'Deadbeat S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107957.mp4', 'http://timg.bdta.pro/images/881cc1d304cdd0ce7c4ade2a91a627a9.jpg'),
(24725, 1690, 'Deadbeat S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107958.mp4', 'http://timg.bdta.pro/images/c67910d1970f8ef5df00985e8f0ec354.jpg'),
(24726, 1690, 'Deadbeat S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107959.mp4', 'http://timg.bdta.pro/images/b6dcaea9af4869895497266f654b63cf.jpg'),
(24727, 1690, 'Deadbeat S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107960.mp4', 'http://timg.bdta.pro/images/418fad28b12a8d032417fc0a74717684.jpg'),
(24728, 1690, 'Deadbeat S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107961.mp4', 'http://timg.bdta.pro/images/66a8424d096e41fd10de2557c7761247.jpg'),
(24729, 1690, 'Deadbeat S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107962.mp4', 'http://timg.bdta.pro/images/6492d35ff93fcf3a83f737cda07e398b.jpg'),
(24730, 1690, 'Deadbeat S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107963.mp4', 'http://timg.bdta.pro/images/9d86374e78b6cb328c1c71bc443952cc.jpg'),
(24731, 1690, 'Deadbeat S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107964.mp4', 'http://timg.bdta.pro/images/d6792f5395878bddd4ae2a9eb4e6da24.jpg'),
(24732, 1690, 'Deadbeat S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107965.mp4', 'http://timg.bdta.pro/images/d392536ffd0ead0fb58393a181716a75.jpg'),
(24733, 1690, 'Deadbeat S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107966.mp4', 'http://timg.bdta.pro/images/21de0cc702a0452aaebaa02f7449c6a3.jpg'),
(24734, 1691, 'Deadbeat S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107967.mp4', 'http://timg.bdta.pro/images/bd03802b4e8a607cb908703cb0ac067a.jpg'),
(24735, 1691, 'Deadbeat S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107968.mp4', 'http://timg.bdta.pro/images/a2b7feb8c0bc6e4f94adac0d917c701c.jpg'),
(24736, 1691, 'Deadbeat S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107969.mp4', 'http://timg.bdta.pro/images/37496d3a73c81c3c34447df4d58c6905.jpg'),
(24737, 1691, 'Deadbeat S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107970.mp4', 'http://timg.bdta.pro/images/ccdd33fb61607ffed4c79ffbea62474f.jpg'),
(24738, 1691, 'Deadbeat S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107971.mp4', 'http://timg.bdta.pro/images/2ee30509bccde5014d0246710b6e5e15.jpg'),
(24739, 1691, 'Deadbeat S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107972.mp4', 'http://timg.bdta.pro/images/d048578de4094aa0e4e25981f4a3e0f5.jpg'),
(24740, 1691, 'Deadbeat S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107973.mp4', 'http://timg.bdta.pro/images/11f6504e94e0b03aff642e286353989c.jpg'),
(24741, 1691, 'Deadbeat S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107974.mp4', 'http://timg.bdta.pro/images/cc9cddfd39f673402a5c3f2670c4656b.jpg'),
(24742, 1691, 'Deadbeat S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107975.mp4', 'http://timg.bdta.pro/images/ab7d343c35fefeb93e98f17eecada81c.jpg'),
(24743, 1691, 'Deadbeat S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107976.mp4', 'http://timg.bdta.pro/images/51b907492a19703b927173fab18f4d90.jpg'),
(24744, 1691, 'Deadbeat S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107977.mp4', 'http://timg.bdta.pro/images/573d314b3dd6cbaada154434681f5e8e.jpg'),
(24745, 1691, 'Deadbeat S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107978.mp4', 'http://timg.bdta.pro/images/fc6ccda95e7ea74a48b8089fcce57b85.jpg'),
(24746, 1691, 'Deadbeat S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107979.mp4', 'http://timg.bdta.pro/images/3fe17a1e5cf2a85072162f74e0a4dd65.jpg'),
(24747, 1692, 'Barra Bravas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107949.mp4', 'http://timg.bdta.pro/images/3fe17a1e5cf2a85072162f74e0a4dd65.jpg'),
(24748, 1692, 'Barra Bravas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107950.mp4', 'http://timg.bdta.pro/images/3fe17a1e5cf2a85072162f74e0a4dd65.jpg'),
(24749, 1692, 'Barra Bravas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107951.mp4', 'http://timg.bdta.pro/images/3fe17a1e5cf2a85072162f74e0a4dd65.jpg'),
(24750, 1692, 'Barra Bravas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107952.mp4', 'http://timg.bdta.pro/images/3fe17a1e5cf2a85072162f74e0a4dd65.jpg'),
(24751, 1692, 'Barra Bravas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107953.mp4', 'http://timg.bdta.pro/images/3fe17a1e5cf2a85072162f74e0a4dd65.jpg'),
(24752, 1692, 'Barra Bravas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107954.mp4', 'http://timg.bdta.pro/images/3fe17a1e5cf2a85072162f74e0a4dd65.jpg'),
(24753, 1692, 'Barra Bravas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107955.mp4', 'http://timg.bdta.pro/images/3fe17a1e5cf2a85072162f74e0a4dd65.jpg'),
(24754, 1692, 'Barra Bravas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107956.mp4', 'http://timg.bdta.pro/images/3fe17a1e5cf2a85072162f74e0a4dd65.jpg'),
(24755, 1693, 'Seguidores S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107940.mp4', 'http://timg.bdta.pro/images/7c2896e8052e41eda853b718839ce078.jpg'),
(24756, 1693, 'Seguidores S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107941.mp4', 'http://timg.bdta.pro/images/dea3e5496c37c5218db293f35375caf7.jpg'),
(24757, 1693, 'Seguidores S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107942.mp4', 'http://timg.bdta.pro/images/ec77bf2172aafc6c56833f8444bd1dd1.jpg'),
(24758, 1693, 'Seguidores S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107943.mp4', 'http://timg.bdta.pro/images/e9216f38e33525fcfedca06ea20dcf11.jpg'),
(24759, 1693, 'Seguidores S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107944.mp4', 'http://timg.bdta.pro/images/db5327533b011bcaa7cde276bb2c99fd.jpg'),
(24760, 1693, 'Seguidores S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107945.mp4', 'http://timg.bdta.pro/images/a4b423225d94be0e0a3656e286f4ab0c.jpg'),
(24761, 1693, 'Seguidores S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107946.mp4', 'http://timg.bdta.pro/images/be8ddaf9eb7053c73ce377fdb30e685c.jpg'),
(24762, 1693, 'Seguidores S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107947.mp4', 'http://timg.bdta.pro/images/48bc7f72db1cc3afad565b593f34b5f0.jpg'),
(24763, 1693, 'Seguidores S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107948.mp4', 'http://timg.bdta.pro/images/bdb25ceeeb982bf11bb96709fcb64bd6.jpg'),
(24764, 1694, 'Avenue 5 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200680.mp4', 'http://timg.bdta.pro/images/62991a68aa2663cb9335b26dd54fa424.jpg'),
(24765, 1694, 'Avenue 5 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200681.mp4', 'http://timg.bdta.pro/images/e4878ed76729cea4ce49e5b98fbfbfbf.jpg'),
(24766, 1694, 'Avenue 5 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200682.mp4', 'http://timg.bdta.pro/images/a7e3f68e1e25ad6901683974b201d111.jpg'),
(24767, 1694, 'Avenue 5 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200683.mp4', 'http://timg.bdta.pro/images/7d9c8d996e020d824a8154563806f7a8.jpg'),
(24768, 1694, 'Avenue 5 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200684.mp4', 'http://timg.bdta.pro/images/c5a80e4470f79ba35f7c88543d47fdff.jpg'),
(24769, 1694, 'Avenue 5 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200685.mp4', 'http://timg.bdta.pro/images/c3927617f8b362d880e4eb6ec26d7d45.jpg'),
(24770, 1694, 'Avenue 5 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200686.mp4', 'http://timg.bdta.pro/images/1800f51c9ae3a8cc07cb53a96718caa9.jpg'),
(24771, 1694, 'Avenue 5 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200687.mp4', 'http://timg.bdta.pro/images/b7d07fc408d08bb3e1d274d0b8ce314a.jpg'),
(24772, 1694, 'Avenue 5 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200688.mp4', 'http://timg.bdta.pro/images/6362a2ccaa922d176511c06b423ae2d4.jpg'),
(24773, 1695, 'Avenue 5 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200689.mp4', 'http://timg.bdta.pro/images/12a7c697615ac6694157e42cc8372ae4.jpg'),
(24774, 1695, 'Avenue 5 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200690.mp4', 'http://timg.bdta.pro/images/7a777bb88de7d389e812c7ee9812aae9.jpg'),
(24775, 1695, 'Avenue 5 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qpj0cskinQZgqdLghC3tQ4Nq9Q4.jpg'),
(24776, 1695, 'Avenue 5 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/my1MmPak9cr5aKrZcJBgQzjuGNf.jpg'),
(24777, 1695, 'Avenue 5 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200693.mp4', 'http://image.tmdb.org/t/p/w1280/v9oPBpgag185dk7Q8wCrPryuipj.jpg'),
(24778, 1695, 'Avenue 5 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MTFJvlci3hxVKZZwjOZMuyn5GQ.jpg'),
(24779, 1695, 'Avenue 5 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7RdMF02gf4gLrYnoUbgCm9vj6sj.jpg'),
(24780, 1695, 'Avenue 5 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200696.mp4', 'http://image.tmdb.org/t/p/w1280/qaBPYhCixF2huOQBZRJEID7GJWb.jpg'),
(24781, 1696, 'Aceleradas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107930.mp4', 'http://gstaticontent.com/images/1hHQntkBMaV88UUMuQQTSck8f0R_big.jpg'),
(24782, 1696, 'Aceleradas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107931.mp4', 'http://gstaticontent.com/images/1hHQntkBMaV88UUMuQQTSck8f0R_big.jpg'),
(24783, 1696, 'Aceleradas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107932.mp4', 'http://gstaticontent.com/images/1hHQntkBMaV88UUMuQQTSck8f0R_big.jpg'),
(24784, 1696, 'Aceleradas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107933.mp4', 'http://gstaticontent.com/images/1hHQntkBMaV88UUMuQQTSck8f0R_big.jpg'),
(24785, 1696, 'Aceleradas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107934.mp4', 'http://gstaticontent.com/images/1hHQntkBMaV88UUMuQQTSck8f0R_big.jpg'),
(24786, 1696, 'Aceleradas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107935.mp4', 'http://gstaticontent.com/images/1hHQntkBMaV88UUMuQQTSck8f0R_big.jpg'),
(24787, 1696, 'Aceleradas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107936.mp4', 'http://gstaticontent.com/images/1hHQntkBMaV88UUMuQQTSck8f0R_big.jpg'),
(24788, 1696, 'Aceleradas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107937.mp4', 'http://gstaticontent.com/images/1hHQntkBMaV88UUMuQQTSck8f0R_big.jpg'),
(24789, 1696, 'Aceleradas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107938.mp4', 'http://gstaticontent.com/images/1hHQntkBMaV88UUMuQQTSck8f0R_big.jpg'),
(24790, 1696, 'Aceleradas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107939.mp4', 'http://gstaticontent.com/images/1hHQntkBMaV88UUMuQQTSck8f0R_big.jpg'),
(24791, 1697, 'Até o Fim: Flamengo Campeão da Libertadores S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107925.mp4', 'http://gstaticontent.com/images/48bvkEkf8ccabpbEAqw8XbpP8Wz_big.jpg'),
(24792, 1697, 'Até o Fim: Flamengo Campeão da Libertadores S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107926.mp4', 'http://gstaticontent.com/images/48bvkEkf8ccabpbEAqw8XbpP8Wz_big.jpg'),
(24793, 1697, 'Até o Fim: Flamengo Campeão da Libertadores S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107927.mp4', 'http://gstaticontent.com/images/48bvkEkf8ccabpbEAqw8XbpP8Wz_big.jpg'),
(24794, 1697, 'Até o Fim: Flamengo Campeão da Libertadores S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107928.mp4', 'http://gstaticontent.com/images/48bvkEkf8ccabpbEAqw8XbpP8Wz_big.jpg'),
(24795, 1697, 'Até o Fim: Flamengo Campeão da Libertadores S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107929.mp4', 'http://gstaticontent.com/images/48bvkEkf8ccabpbEAqw8XbpP8Wz_big.jpg'),
(24796, 1698, 'I Am Not Okay with This S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107918.mp4', 'http://timg.bdta.pro/images/61c562e7f44e5b5e1665787982cc7779.jpg'),
(24797, 1698, 'I Am Not Okay with This S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107919.mp4', 'http://timg.bdta.pro/images/ee842990121164a9d045b407415b5ee0.jpg'),
(24798, 1698, 'I Am Not Okay with This S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107920.mp4', 'http://timg.bdta.pro/images/8f97a1ba30c2cf2c93a9cca3691e37fc.jpg'),
(24799, 1698, 'I Am Not Okay with This S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107921.mp4', 'http://timg.bdta.pro/images/1f82d6533878b199c5dd44c0dad66ee2.jpg'),
(24800, 1698, 'I Am Not Okay with This S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107922.mp4', 'http://timg.bdta.pro/images/34756f38c37a9c42ee273030b18b0b74.jpg'),
(24801, 1698, 'I Am Not Okay with This S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107923.mp4', 'http://timg.bdta.pro/images/fb05447de0e3ee66738a8a521a0dddfc.jpg'),
(24802, 1698, 'I Am Not Okay with This S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107924.mp4', 'http://timg.bdta.pro/images/98854f8c45ca3117887b6a2a7e27a3f3.jpg'),
(24803, 1699, 'Diablero S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107893.mp4', 'http://timg.bdta.pro/images/9174c21b982ee467b1256163e0f0cb1b.jpg'),
(24804, 1699, 'Diablero S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107894.mp4', 'http://timg.bdta.pro/images/072972b1871b9b79f2494db7a86db602.jpg'),
(24805, 1699, 'Diablero S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107895.mp4', 'http://timg.bdta.pro/images/13b6fb62d56e7753ba83452c56ce06c9.jpg'),
(24806, 1699, 'Diablero S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107896.mp4', 'http://timg.bdta.pro/images/df7bc9c305344cda8c47c50e65278364.jpg'),
(24807, 1699, 'Diablero S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107897.mp4', 'http://timg.bdta.pro/images/6e399a6a46bdacc9995a650709cd1589.jpg'),
(24808, 1699, 'Diablero S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107898.mp4', 'http://timg.bdta.pro/images/62484969ec7e13eac19ad515b5c24a58.jpg'),
(24809, 1699, 'Diablero S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107899.mp4', 'http://timg.bdta.pro/images/fe2f05342da30f4a3decca8a68e904e5.jpg'),
(24810, 1699, 'Diablero S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107900.mp4', 'http://timg.bdta.pro/images/c147c140821f45556a6f1eeeba4efa2e.jpg'),
(24811, 1700, 'Diablero S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107901.mp4', 'http://timg.bdta.pro/images/ba648db968e8aa840828b3add4fe975c.jpg'),
(24812, 1700, 'Diablero S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107902.mp4', 'http://timg.bdta.pro/images/77786ce1ff35e526da21766cafda574d.jpg'),
(24813, 1700, 'Diablero S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107903.mp4', 'http://timg.bdta.pro/images/baa5265afd2e7f30e052e8430189d8df.jpg'),
(24814, 1700, 'Diablero S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107904.mp4', 'http://timg.bdta.pro/images/32a42f08d21662e38fe6109e1d110323.jpg'),
(24815, 1700, 'Diablero S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107905.mp4', 'http://timg.bdta.pro/images/07924f46b2f117fbe5af6c16edd3f36c.jpg'),
(24816, 1700, 'Diablero S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107906.mp4', 'http://timg.bdta.pro/images/3fcfd2196cdbcac3c7bbdf0cebafa489.jpg'),
(24817, 1701, 'Naruto Shippuden [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107393.mp4', 'http://timg.bdta.pro/images/7e2eddb8763e155230e4c578fe2e6332.jpg'),
(24818, 1701, 'Naruto Shippuden [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107394.mp4', 'http://timg.bdta.pro/images/c813140ac73ceac6141fc57a2808a82c.jpg'),
(24819, 1701, 'Naruto Shippuden [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107395.mp4', 'http://timg.bdta.pro/images/3f967cf592f47aff71162bc6550fbd8f.jpg'),
(24820, 1701, 'Naruto Shippuden [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107396.mp4', 'http://timg.bdta.pro/images/2b8c144e22255c828236463409af3b5a.jpg'),
(24821, 1701, 'Naruto Shippuden [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107397.mp4', 'http://timg.bdta.pro/images/1e38c9dd45eb5e125b4ea971e909654c.jpg'),
(24822, 1701, 'Naruto Shippuden [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107398.mp4', 'http://timg.bdta.pro/images/e1dae66bf50e6e56eb66409fe96f6e58.jpg'),
(24823, 1701, 'Naruto Shippuden [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107399.mp4', 'http://timg.bdta.pro/images/3ffbf4c8146390bb9497fcf047c531f3.jpg'),
(24824, 1701, 'Naruto Shippuden [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107400.mp4', 'http://timg.bdta.pro/images/3b01c29f30537425510cf58d6b4e55a1.jpg'),
(24825, 1701, 'Naruto Shippuden [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107401.mp4', 'http://timg.bdta.pro/images/9172b502f1850a8a0a0653bfc9852941.jpg'),
(24826, 1701, 'Naruto Shippuden [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107402.mp4', 'http://timg.bdta.pro/images/7a9a98be6d09804d64e822d776b6e9b9.jpg'),
(24827, 1701, 'Naruto Shippuden [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107403.mp4', 'http://timg.bdta.pro/images/9eab5caa4fcec57f332864807ecfe7ce.jpg'),
(24828, 1701, 'Naruto Shippuden [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107404.mp4', 'http://timg.bdta.pro/images/961d9be5b93ad0bf19cb1f635b9f7539.jpg'),
(24829, 1701, 'Naruto Shippuden [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107405.mp4', 'http://timg.bdta.pro/images/2ef794a38837217aa09e6f3af0c49274.jpg'),
(24830, 1701, 'Naruto Shippuden [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/107406.mp4', 'http://timg.bdta.pro/images/cb75e2a1f6c64d5e698766e9bd8d8a93.jpg'),
(24831, 1701, 'Naruto Shippuden [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/107407.mp4', 'http://timg.bdta.pro/images/2f6f4c5a50729562e39f64f68c2086c8.jpg'),
(24832, 1701, 'Naruto Shippuden [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/107408.mp4', 'http://timg.bdta.pro/images/9624deb3b28c0f6ec6318181bfa555a1.jpg'),
(24833, 1701, 'Naruto Shippuden [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/107409.mp4', 'http://timg.bdta.pro/images/91dedc46c7fa9c1f1611b645495cbd0d.jpg'),
(24834, 1701, 'Naruto Shippuden [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/107410.mp4', 'http://timg.bdta.pro/images/c38b817325a3602e3411f8616cab2fc7.jpg'),
(24835, 1701, 'Naruto Shippuden [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/107411.mp4', 'http://timg.bdta.pro/images/521ecd12dac09ebd54f75995d6e3f20a.jpg'),
(24836, 1701, 'Naruto Shippuden [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/107412.mp4', 'http://timg.bdta.pro/images/7268fa40f81bb808f97ff623182c2e93.jpg'),
(24837, 1701, 'Naruto Shippuden [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/107413.mp4', 'http://timg.bdta.pro/images/6dbd6fdb5c1877c6236fd4c9238aeef5.jpg'),
(24838, 1701, 'Naruto Shippuden [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/107414.mp4', 'http://timg.bdta.pro/images/b58cdd7cb9b8600cb8d9e67f0922e9cb.jpg'),
(24839, 1701, 'Naruto Shippuden [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/107415.mp4', 'http://timg.bdta.pro/images/5b521a368a06727dbf532361b004c10c.jpg'),
(24840, 1701, 'Naruto Shippuden [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/107416.mp4', 'http://timg.bdta.pro/images/da4ded12845a88979d0744dfbc640529.jpg'),
(24841, 1701, 'Naruto Shippuden [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/107417.mp4', 'http://timg.bdta.pro/images/8526cdd95735074e0eac00d77d610175.jpg'),
(24842, 1701, 'Naruto Shippuden [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/107418.mp4', 'http://timg.bdta.pro/images/54fce08c476f551e657b050724972912.jpg'),
(24843, 1701, 'Naruto Shippuden [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/107419.mp4', 'http://timg.bdta.pro/images/980c6f3d22fe8fd07f1c3a5fe015629b.jpg'),
(24844, 1701, 'Naruto Shippuden [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/107420.mp4', 'http://timg.bdta.pro/images/74b9f307c3aed2a5868f903739e5c272.jpg'),
(24845, 1701, 'Naruto Shippuden [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/107421.mp4', 'http://timg.bdta.pro/images/353234cf0f22b2c8bb5cc8f186562345.jpg'),
(24846, 1701, 'Naruto Shippuden [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/107422.mp4', 'http://timg.bdta.pro/images/66007f1377a8afc6b154700ac62bfe90.jpg'),
(24847, 1701, 'Naruto Shippuden [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/107423.mp4', 'http://timg.bdta.pro/images/029b1d9a2ab304d3ef76387d1bca89e9.jpg'),
(24848, 1701, 'Naruto Shippuden [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/107424.mp4', 'http://timg.bdta.pro/images/eda26bcb16f5a22fb1b6520f152911ae.jpg'),
(24849, 1702, 'Naruto Shippuden [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107425.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24850, 1702, 'Naruto Shippuden [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107426.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24851, 1702, 'Naruto Shippuden [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107427.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24852, 1702, 'Naruto Shippuden [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107428.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24853, 1702, 'Naruto Shippuden [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107429.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24854, 1702, 'Naruto Shippuden [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107430.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24855, 1702, 'Naruto Shippuden [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107431.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24856, 1702, 'Naruto Shippuden [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107432.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24857, 1702, 'Naruto Shippuden [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107433.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24858, 1702, 'Naruto Shippuden [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107434.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(24859, 1702, 'Naruto Shippuden [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107435.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24860, 1702, 'Naruto Shippuden [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107436.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24861, 1702, 'Naruto Shippuden [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107437.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24862, 1702, 'Naruto Shippuden [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/107438.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24863, 1702, 'Naruto Shippuden [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/107439.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24864, 1702, 'Naruto Shippuden [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/107440.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24865, 1702, 'Naruto Shippuden [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/107441.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24866, 1702, 'Naruto Shippuden [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/107442.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24867, 1702, 'Naruto Shippuden [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/107443.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24868, 1702, 'Naruto Shippuden [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/107444.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24869, 1702, 'Naruto Shippuden [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/107445.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24870, 1703, 'Naruto Shippuden [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107446.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24871, 1703, 'Naruto Shippuden [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107447.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24872, 1703, 'Naruto Shippuden [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107448.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24873, 1703, 'Naruto Shippuden [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107449.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24874, 1703, 'Naruto Shippuden [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107450.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24875, 1703, 'Naruto Shippuden [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107451.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24876, 1703, 'Naruto Shippuden [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107452.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24877, 1703, 'Naruto Shippuden [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107453.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24878, 1703, 'Naruto Shippuden [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107454.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24879, 1703, 'Naruto Shippuden [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107455.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24880, 1703, 'Naruto Shippuden [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107456.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24881, 1703, 'Naruto Shippuden [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107457.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24882, 1703, 'Naruto Shippuden [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107458.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24883, 1703, 'Naruto Shippuden [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/107459.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24884, 1703, 'Naruto Shippuden [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/107460.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24885, 1703, 'Naruto Shippuden [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/107461.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24886, 1703, 'Naruto Shippuden [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/107462.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24887, 1703, 'Naruto Shippuden [L] S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/107463.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24888, 1704, 'Naruto Shippuden [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107464.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24889, 1704, 'Naruto Shippuden [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107465.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24890, 1704, 'Naruto Shippuden [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107466.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24891, 1704, 'Naruto Shippuden [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107467.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24892, 1704, 'Naruto Shippuden [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107468.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24893, 1704, 'Naruto Shippuden [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107469.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24894, 1704, 'Naruto Shippuden [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107470.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24895, 1704, 'Naruto Shippuden [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107471.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24896, 1704, 'Naruto Shippuden [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107472.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24897, 1704, 'Naruto Shippuden [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107473.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24898, 1704, 'Naruto Shippuden [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107474.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24899, 1704, 'Naruto Shippuden [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107475.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24900, 1704, 'Naruto Shippuden [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107476.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24901, 1704, 'Naruto Shippuden [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/107477.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24902, 1704, 'Naruto Shippuden [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/107478.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24903, 1704, 'Naruto Shippuden [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/107479.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24904, 1704, 'Naruto Shippuden [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/107480.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24905, 1705, 'Naruto Shippuden [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107481.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24906, 1705, 'Naruto Shippuden [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107482.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24907, 1705, 'Naruto Shippuden [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107483.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24908, 1705, 'Naruto Shippuden [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107484.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24909, 1705, 'Naruto Shippuden [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107485.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24910, 1705, 'Naruto Shippuden [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107486.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24911, 1705, 'Naruto Shippuden [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107487.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24912, 1705, 'Naruto Shippuden [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107488.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24913, 1705, 'Naruto Shippuden [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107489.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24914, 1705, 'Naruto Shippuden [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107490.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24915, 1705, 'Naruto Shippuden [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107491.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24916, 1705, 'Naruto Shippuden [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107492.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24917, 1705, 'Naruto Shippuden [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107493.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24918, 1705, 'Naruto Shippuden [L] S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/107494.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24919, 1705, 'Naruto Shippuden [L] S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/107495.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24920, 1705, 'Naruto Shippuden [L] S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/107496.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24921, 1705, 'Naruto Shippuden [L] S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/107497.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24922, 1705, 'Naruto Shippuden [L] S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/107498.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24923, 1705, 'Naruto Shippuden [L] S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/107499.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24924, 1705, 'Naruto Shippuden [L] S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/107500.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24925, 1705, 'Naruto Shippuden [L] S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/107501.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24926, 1705, 'Naruto Shippuden [L] S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/107502.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24927, 1705, 'Naruto Shippuden [L] S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/107503.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24928, 1705, 'Naruto Shippuden [L] S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/107504.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24929, 1706, 'Naruto Shippuden [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107505.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24930, 1706, 'Naruto Shippuden [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107506.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24931, 1706, 'Naruto Shippuden [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107507.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24932, 1706, 'Naruto Shippuden [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107508.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24933, 1706, 'Naruto Shippuden [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107509.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24934, 1706, 'Naruto Shippuden [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107510.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24935, 1706, 'Naruto Shippuden [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107511.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24936, 1706, 'Naruto Shippuden [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107512.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24937, 1706, 'Naruto Shippuden [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107513.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24938, 1706, 'Naruto Shippuden [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107514.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24939, 1706, 'Naruto Shippuden [L] S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107515.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24940, 1706, 'Naruto Shippuden [L] S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107516.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24941, 1706, 'Naruto Shippuden [L] S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107517.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24942, 1706, 'Naruto Shippuden [L] S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/107518.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24943, 1706, 'Naruto Shippuden [L] S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/107519.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24944, 1706, 'Naruto Shippuden [L] S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/107520.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24945, 1706, 'Naruto Shippuden [L] S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/107521.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24946, 1706, 'Naruto Shippuden [L] S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/107522.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24947, 1706, 'Naruto Shippuden [L] S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/107523.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24948, 1706, 'Naruto Shippuden [L] S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/107524.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24949, 1706, 'Naruto Shippuden [L] S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/107525.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24950, 1706, 'Naruto Shippuden [L] S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/107526.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24951, 1706, 'Naruto Shippuden [L] S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/107527.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24952, 1706, 'Naruto Shippuden [L] S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/107528.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24953, 1706, 'Naruto Shippuden [L] S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/107529.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24954, 1706, 'Naruto Shippuden [L] S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/107530.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24955, 1706, 'Naruto Shippuden [L] S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/107531.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24956, 1706, 'Naruto Shippuden [L] S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/107532.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24957, 1706, 'Naruto Shippuden [L] S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/107533.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24958, 1706, 'Naruto Shippuden [L] S06 E30', 'http://sinalprivado.info:80/series/1533784/1533784/107534.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24959, 1706, 'Naruto Shippuden [L] S06 E31', 'http://sinalprivado.info:80/series/1533784/1533784/107535.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24960, 1707, 'Naruto Shippuden [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107536.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24961, 1707, 'Naruto Shippuden [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107537.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24962, 1707, 'Naruto Shippuden [L] S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107538.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24963, 1707, 'Naruto Shippuden [L] S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107539.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24964, 1707, 'Naruto Shippuden [L] S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107540.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24965, 1707, 'Naruto Shippuden [L] S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107541.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24966, 1707, 'Naruto Shippuden [L] S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107542.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24967, 1707, 'Naruto Shippuden [L] S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107543.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24968, 1708, 'Naruto Shippuden [L] S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107544.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24969, 1708, 'Naruto Shippuden [L] S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107545.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24970, 1708, 'Naruto Shippuden [L] S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107546.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24971, 1708, 'Naruto Shippuden [L] S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107547.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24972, 1708, 'Naruto Shippuden [L] S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107548.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24973, 1708, 'Naruto Shippuden [L] S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107549.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24974, 1708, 'Naruto Shippuden [L] S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107550.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24975, 1708, 'Naruto Shippuden [L] S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107551.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24976, 1708, 'Naruto Shippuden [L] S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107552.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24977, 1708, 'Naruto Shippuden [L] S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107553.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24978, 1708, 'Naruto Shippuden [L] S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107554.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24979, 1708, 'Naruto Shippuden [L] S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107555.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24980, 1708, 'Naruto Shippuden [L] S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107556.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24981, 1708, 'Naruto Shippuden [L] S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/107557.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24982, 1708, 'Naruto Shippuden [L] S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/107558.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24983, 1708, 'Naruto Shippuden [L] S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/107559.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24984, 1708, 'Naruto Shippuden [L] S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/107560.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24985, 1708, 'Naruto Shippuden [L] S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/107561.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24986, 1708, 'Naruto Shippuden [L] S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/107562.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24987, 1708, 'Naruto Shippuden [L] S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/107563.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24988, 1708, 'Naruto Shippuden [L] S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/107564.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24989, 1708, 'Naruto Shippuden [L] S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/107565.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24990, 1708, 'Naruto Shippuden [L] S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/107566.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24991, 1708, 'Naruto Shippuden [L] S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/107567.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24992, 1709, 'Naruto Shippuden [L] S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107568.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24993, 1709, 'Naruto Shippuden [L] S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107569.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24994, 1709, 'Naruto Shippuden [L] S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107570.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24995, 1709, 'Naruto Shippuden [L] S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107571.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24996, 1709, 'Naruto Shippuden [L] S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107572.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24997, 1709, 'Naruto Shippuden [L] S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107573.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24998, 1709, 'Naruto Shippuden [L] S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107574.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(24999, 1709, 'Naruto Shippuden [L] S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107575.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25000, 1709, 'Naruto Shippuden [L] S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107576.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25001, 1709, 'Naruto Shippuden [L] S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107577.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25002, 1709, 'Naruto Shippuden [L] S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107578.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25003, 1709, 'Naruto Shippuden [L] S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107579.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25004, 1709, 'Naruto Shippuden [L] S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107580.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25005, 1709, 'Naruto Shippuden [L] S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/107581.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25006, 1709, 'Naruto Shippuden [L] S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/107582.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25007, 1709, 'Naruto Shippuden [L] S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/107583.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25008, 1709, 'Naruto Shippuden [L] S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/107584.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25009, 1709, 'Naruto Shippuden [L] S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/107585.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25010, 1709, 'Naruto Shippuden [L] S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/107586.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25011, 1709, 'Naruto Shippuden [L] S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/107587.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25012, 1709, 'Naruto Shippuden [L] S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/107588.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25013, 1710, 'Naruto Shippuden [L] S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107589.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25014, 1710, 'Naruto Shippuden [L] S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107590.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25015, 1710, 'Naruto Shippuden [L] S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107591.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25016, 1710, 'Naruto Shippuden [L] S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107592.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25017, 1710, 'Naruto Shippuden [L] S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107593.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25018, 1710, 'Naruto Shippuden [L] S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107594.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25019, 1710, 'Naruto Shippuden [L] S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107595.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25020, 1710, 'Naruto Shippuden [L] S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107596.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25021, 1710, 'Naruto Shippuden [L] S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107597.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25022, 1710, 'Naruto Shippuden [L] S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107598.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25023, 1710, 'Naruto Shippuden [L] S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107599.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25024, 1710, 'Naruto Shippuden [L] S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107600.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25025, 1710, 'Naruto Shippuden [L] S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107601.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25026, 1710, 'Naruto Shippuden [L] S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/107602.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25027, 1710, 'Naruto Shippuden [L] S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/107603.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25028, 1710, 'Naruto Shippuden [L] S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/107604.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25029, 1710, 'Naruto Shippuden [L] S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/107605.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25030, 1710, 'Naruto Shippuden [L] S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/107606.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25031, 1710, 'Naruto Shippuden [L] S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/107607.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25032, 1710, 'Naruto Shippuden [L] S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/107608.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25033, 1710, 'Naruto Shippuden [L] S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/107609.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25034, 1710, 'Naruto Shippuden [L] S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/107610.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25035, 1710, 'Naruto Shippuden [L] S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/107611.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25036, 1710, 'Naruto Shippuden [L] S10 E24', 'http://sinalprivado.info:80/series/1533784/1533784/107612.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25037, 1710, 'Naruto Shippuden [L] S10 E25', 'http://sinalprivado.info:80/series/1533784/1533784/107613.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25038, 1711, 'Naruto Shippuden [L] S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107614.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25039, 1711, 'Naruto Shippuden [L] S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107615.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25040, 1711, 'Naruto Shippuden [L] S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107616.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25041, 1711, 'Naruto Shippuden [L] S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107617.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25042, 1711, 'Naruto Shippuden [L] S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107618.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25043, 1711, 'Naruto Shippuden [L] S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107619.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25044, 1711, 'Naruto Shippuden [L] S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107620.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25045, 1711, 'Naruto Shippuden [L] S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107621.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25046, 1711, 'Naruto Shippuden [L] S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107622.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25047, 1711, 'Naruto Shippuden [L] S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107623.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25048, 1711, 'Naruto Shippuden [L] S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107624.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25049, 1711, 'Naruto Shippuden [L] S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107625.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25050, 1711, 'Naruto Shippuden [L] S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107626.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25051, 1711, 'Naruto Shippuden [L] S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/107627.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25052, 1711, 'Naruto Shippuden [L] S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/107628.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25053, 1711, 'Naruto Shippuden [L] S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/107629.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25054, 1711, 'Naruto Shippuden [L] S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/107630.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25055, 1711, 'Naruto Shippuden [L] S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/107631.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25056, 1711, 'Naruto Shippuden [L] S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/107632.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25057, 1711, 'Naruto Shippuden [L] S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/107633.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25058, 1711, 'Naruto Shippuden [L] S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/107634.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25059, 1712, 'Naruto Shippuden [L] S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107635.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25060, 1712, 'Naruto Shippuden [L] S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107636.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25061, 1712, 'Naruto Shippuden [L] S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107637.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25062, 1712, 'Naruto Shippuden [L] S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107638.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25063, 1712, 'Naruto Shippuden [L] S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107639.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25064, 1712, 'Naruto Shippuden [L] S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107640.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25065, 1712, 'Naruto Shippuden [L] S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107641.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25066, 1712, 'Naruto Shippuden [L] S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107642.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25067, 1712, 'Naruto Shippuden [L] S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107643.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25068, 1712, 'Naruto Shippuden [L] S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107644.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25069, 1712, 'Naruto Shippuden [L] S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107645.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25070, 1712, 'Naruto Shippuden [L] S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107646.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25071, 1712, 'Naruto Shippuden [L] S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107647.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25072, 1712, 'Naruto Shippuden [L] S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/107648.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25073, 1712, 'Naruto Shippuden [L] S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/107649.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25074, 1712, 'Naruto Shippuden [L] S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/107650.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25075, 1712, 'Naruto Shippuden [L] S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/107651.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25076, 1712, 'Naruto Shippuden [L] S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/107652.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25077, 1712, 'Naruto Shippuden [L] S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/107653.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25078, 1712, 'Naruto Shippuden [L] S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/107654.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25079, 1712, 'Naruto Shippuden [L] S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/107655.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25080, 1712, 'Naruto Shippuden [L] S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/107656.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25081, 1712, 'Naruto Shippuden [L] S12 E23', 'http://sinalprivado.info:80/series/1533784/1533784/107657.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25082, 1712, 'Naruto Shippuden [L] S12 E24', 'http://sinalprivado.info:80/series/1533784/1533784/107658.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25083, 1712, 'Naruto Shippuden [L] S12 E25', 'http://sinalprivado.info:80/series/1533784/1533784/107659.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25084, 1712, 'Naruto Shippuden [L] S12 E26', 'http://sinalprivado.info:80/series/1533784/1533784/107660.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25085, 1712, 'Naruto Shippuden [L] S12 E27', 'http://sinalprivado.info:80/series/1533784/1533784/107661.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25086, 1712, 'Naruto Shippuden [L] S12 E28', 'http://sinalprivado.info:80/series/1533784/1533784/107662.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25087, 1712, 'Naruto Shippuden [L] S12 E29', 'http://sinalprivado.info:80/series/1533784/1533784/107663.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25088, 1712, 'Naruto Shippuden [L] S12 E30', 'http://sinalprivado.info:80/series/1533784/1533784/107664.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25089, 1712, 'Naruto Shippuden [L] S12 E31', 'http://sinalprivado.info:80/series/1533784/1533784/107665.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25090, 1712, 'Naruto Shippuden [L] S12 E32', 'http://sinalprivado.info:80/series/1533784/1533784/107666.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25091, 1712, 'Naruto Shippuden [L] S12 E33', 'http://sinalprivado.info:80/series/1533784/1533784/107667.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25092, 1713, 'Naruto Shippuden [L] S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107668.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25093, 1713, 'Naruto Shippuden [L] S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107669.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25094, 1713, 'Naruto Shippuden [L] S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107670.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25095, 1713, 'Naruto Shippuden [L] S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107671.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25096, 1713, 'Naruto Shippuden [L] S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107672.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25097, 1713, 'Naruto Shippuden [L] S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107673.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25098, 1713, 'Naruto Shippuden [L] S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107674.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25099, 1713, 'Naruto Shippuden [L] S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107675.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25100, 1713, 'Naruto Shippuden [L] S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107676.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25101, 1713, 'Naruto Shippuden [L] S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107677.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25102, 1713, 'Naruto Shippuden [L] S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107678.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25103, 1713, 'Naruto Shippuden [L] S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107679.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25104, 1713, 'Naruto Shippuden [L] S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107680.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25105, 1713, 'Naruto Shippuden [L] S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/107681.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25106, 1713, 'Naruto Shippuden [L] S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/107682.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25107, 1713, 'Naruto Shippuden [L] S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/107683.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25108, 1713, 'Naruto Shippuden [L] S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/107684.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25109, 1713, 'Naruto Shippuden [L] S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/107685.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25110, 1713, 'Naruto Shippuden [L] S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/107686.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25111, 1713, 'Naruto Shippuden [L] S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/107687.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25112, 1714, 'Naruto Shippuden [L] S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107688.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25113, 1714, 'Naruto Shippuden [L] S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107689.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25114, 1714, 'Naruto Shippuden [L] S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107690.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25115, 1714, 'Naruto Shippuden [L] S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107691.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25116, 1714, 'Naruto Shippuden [L] S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107692.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25117, 1714, 'Naruto Shippuden [L] S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107693.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25118, 1714, 'Naruto Shippuden [L] S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107694.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25119, 1714, 'Naruto Shippuden [L] S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107695.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25120, 1714, 'Naruto Shippuden [L] S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107696.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25121, 1714, 'Naruto Shippuden [L] S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107697.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25122, 1714, 'Naruto Shippuden [L] S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107698.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25123, 1714, 'Naruto Shippuden [L] S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107699.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25124, 1714, 'Naruto Shippuden [L] S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107700.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25125, 1714, 'Naruto Shippuden [L] S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/107701.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25126, 1714, 'Naruto Shippuden [L] S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/107702.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25127, 1714, 'Naruto Shippuden [L] S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/107703.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25128, 1714, 'Naruto Shippuden [L] S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/107704.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25129, 1714, 'Naruto Shippuden [L] S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/107705.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25130, 1714, 'Naruto Shippuden [L] S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/107706.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25131, 1714, 'Naruto Shippuden [L] S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/107707.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25132, 1714, 'Naruto Shippuden [L] S14 E21', 'http://sinalprivado.info:80/series/1533784/1533784/107708.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25133, 1714, 'Naruto Shippuden [L] S14 E22', 'http://sinalprivado.info:80/series/1533784/1533784/107709.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25134, 1714, 'Naruto Shippuden [L] S14 E23', 'http://sinalprivado.info:80/series/1533784/1533784/107710.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25135, 1714, 'Naruto Shippuden [L] S14 E24', 'http://sinalprivado.info:80/series/1533784/1533784/107711.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25136, 1714, 'Naruto Shippuden [L] S14 E25', 'http://sinalprivado.info:80/series/1533784/1533784/107712.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25137, 1715, 'Naruto Shippuden [L] S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107713.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25138, 1715, 'Naruto Shippuden [L] S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107714.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(25139, 1715, 'Naruto Shippuden [L] S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107715.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25140, 1715, 'Naruto Shippuden [L] S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107716.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25141, 1715, 'Naruto Shippuden [L] S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107717.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25142, 1715, 'Naruto Shippuden [L] S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107718.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25143, 1715, 'Naruto Shippuden [L] S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107719.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25144, 1715, 'Naruto Shippuden [L] S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107720.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25145, 1715, 'Naruto Shippuden [L] S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107721.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25146, 1715, 'Naruto Shippuden [L] S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107722.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25147, 1715, 'Naruto Shippuden [L] S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107723.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25148, 1715, 'Naruto Shippuden [L] S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107724.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25149, 1715, 'Naruto Shippuden [L] S15 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107725.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25150, 1715, 'Naruto Shippuden [L] S15 E14', 'http://sinalprivado.info:80/series/1533784/1533784/107726.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25151, 1715, 'Naruto Shippuden [L] S15 E15', 'http://sinalprivado.info:80/series/1533784/1533784/107727.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25152, 1715, 'Naruto Shippuden [L] S15 E16', 'http://sinalprivado.info:80/series/1533784/1533784/107728.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25153, 1715, 'Naruto Shippuden [L] S15 E17', 'http://sinalprivado.info:80/series/1533784/1533784/107729.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25154, 1715, 'Naruto Shippuden [L] S15 E18', 'http://sinalprivado.info:80/series/1533784/1533784/107730.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25155, 1715, 'Naruto Shippuden [L] S15 E19', 'http://sinalprivado.info:80/series/1533784/1533784/107731.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25156, 1715, 'Naruto Shippuden [L] S15 E20', 'http://sinalprivado.info:80/series/1533784/1533784/107732.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25157, 1715, 'Naruto Shippuden [L] S15 E21', 'http://sinalprivado.info:80/series/1533784/1533784/107733.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25158, 1715, 'Naruto Shippuden [L] S15 E22', 'http://sinalprivado.info:80/series/1533784/1533784/107734.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25159, 1715, 'Naruto Shippuden [L] S15 E23', 'http://sinalprivado.info:80/series/1533784/1533784/107735.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25160, 1715, 'Naruto Shippuden [L] S15 E24', 'http://sinalprivado.info:80/series/1533784/1533784/107736.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25161, 1715, 'Naruto Shippuden [L] S15 E25', 'http://sinalprivado.info:80/series/1533784/1533784/107737.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25162, 1715, 'Naruto Shippuden [L] S15 E26', 'http://sinalprivado.info:80/series/1533784/1533784/107738.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25163, 1715, 'Naruto Shippuden [L] S15 E27', 'http://sinalprivado.info:80/series/1533784/1533784/107739.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25164, 1715, 'Naruto Shippuden [L] S15 E28', 'http://sinalprivado.info:80/series/1533784/1533784/107740.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25165, 1716, 'Naruto Shippuden [L] S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107741.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25166, 1716, 'Naruto Shippuden [L] S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107742.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25167, 1716, 'Naruto Shippuden [L] S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107743.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25168, 1716, 'Naruto Shippuden [L] S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107744.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25169, 1716, 'Naruto Shippuden [L] S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107745.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25170, 1716, 'Naruto Shippuden [L] S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107746.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25171, 1716, 'Naruto Shippuden [L] S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107747.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25172, 1716, 'Naruto Shippuden [L] S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107748.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25173, 1716, 'Naruto Shippuden [L] S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107749.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25174, 1716, 'Naruto Shippuden [L] S16 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107750.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25175, 1716, 'Naruto Shippuden [L] S16 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107751.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25176, 1716, 'Naruto Shippuden [L] S16 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107752.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25177, 1716, 'Naruto Shippuden [L] S16 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107753.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25178, 1717, 'Naruto Shippuden [L] S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107754.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25179, 1717, 'Naruto Shippuden [L] S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107755.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25180, 1717, 'Naruto Shippuden [L] S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107756.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25181, 1717, 'Naruto Shippuden [L] S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107757.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25182, 1717, 'Naruto Shippuden [L] S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107758.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25183, 1717, 'Naruto Shippuden [L] S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107759.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25184, 1717, 'Naruto Shippuden [L] S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107760.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25185, 1717, 'Naruto Shippuden [L] S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107761.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25186, 1717, 'Naruto Shippuden [L] S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107762.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25187, 1717, 'Naruto Shippuden [L] S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107763.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25188, 1717, 'Naruto Shippuden [L] S17 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107764.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25189, 1718, 'Naruto Shippuden [L] S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107765.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25190, 1718, 'Naruto Shippuden [L] S18 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107766.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25191, 1718, 'Naruto Shippuden [L] S18 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107767.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25192, 1718, 'Naruto Shippuden [L] S18 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107768.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25193, 1718, 'Naruto Shippuden [L] S18 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107769.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25194, 1718, 'Naruto Shippuden [L] S18 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107770.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25195, 1718, 'Naruto Shippuden [L] S18 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107771.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25196, 1718, 'Naruto Shippuden [L] S18 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107772.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25197, 1718, 'Naruto Shippuden [L] S18 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107773.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25198, 1718, 'Naruto Shippuden [L] S18 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107774.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25199, 1718, 'Naruto Shippuden [L] S18 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107775.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25200, 1718, 'Naruto Shippuden [L] S18 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107776.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25201, 1718, 'Naruto Shippuden [L] S18 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107777.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25202, 1718, 'Naruto Shippuden [L] S18 E14', 'http://sinalprivado.info:80/series/1533784/1533784/107778.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25203, 1718, 'Naruto Shippuden [L] S18 E15', 'http://sinalprivado.info:80/series/1533784/1533784/107779.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25204, 1718, 'Naruto Shippuden [L] S18 E16', 'http://sinalprivado.info:80/series/1533784/1533784/107780.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25205, 1718, 'Naruto Shippuden [L] S18 E17', 'http://sinalprivado.info:80/series/1533784/1533784/107781.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25206, 1718, 'Naruto Shippuden [L] S18 E18', 'http://sinalprivado.info:80/series/1533784/1533784/107782.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25207, 1718, 'Naruto Shippuden [L] S18 E19', 'http://sinalprivado.info:80/series/1533784/1533784/107783.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25208, 1718, 'Naruto Shippuden [L] S18 E20', 'http://sinalprivado.info:80/series/1533784/1533784/107784.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25209, 1718, 'Naruto Shippuden [L] S18 E21', 'http://sinalprivado.info:80/series/1533784/1533784/107785.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25210, 1719, 'Naruto Shippuden [L] S19 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107786.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25211, 1719, 'Naruto Shippuden [L] S19 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107787.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25212, 1719, 'Naruto Shippuden [L] S19 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107788.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25213, 1719, 'Naruto Shippuden [L] S19 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107789.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25214, 1719, 'Naruto Shippuden [L] S19 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107790.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25215, 1719, 'Naruto Shippuden [L] S19 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107791.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25216, 1719, 'Naruto Shippuden [L] S19 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107792.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25217, 1719, 'Naruto Shippuden [L] S19 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107793.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25218, 1719, 'Naruto Shippuden [L] S19 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107794.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25219, 1719, 'Naruto Shippuden [L] S19 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107795.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25220, 1719, 'Naruto Shippuden [L] S19 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107796.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25221, 1719, 'Naruto Shippuden [L] S19 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107797.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25222, 1719, 'Naruto Shippuden [L] S19 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107798.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25223, 1719, 'Naruto Shippuden [L] S19 E14', 'http://sinalprivado.info:80/series/1533784/1533784/107799.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25224, 1719, 'Naruto Shippuden [L] S19 E15', 'http://sinalprivado.info:80/series/1533784/1533784/107800.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25225, 1719, 'Naruto Shippuden [L] S19 E16', 'http://sinalprivado.info:80/series/1533784/1533784/107801.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25226, 1719, 'Naruto Shippuden [L] S19 E17', 'http://sinalprivado.info:80/series/1533784/1533784/107802.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25227, 1719, 'Naruto Shippuden [L] S19 E18', 'http://sinalprivado.info:80/series/1533784/1533784/107803.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25228, 1719, 'Naruto Shippuden [L] S19 E19', 'http://sinalprivado.info:80/series/1533784/1533784/107804.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25229, 1719, 'Naruto Shippuden [L] S19 E20', 'http://sinalprivado.info:80/series/1533784/1533784/107805.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25230, 1720, 'Naruto Shippuden [L] S20 E01', 'http://sinalprivado.info:80/series/1533784/1533784/107806.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25231, 1720, 'Naruto Shippuden [L] S20 E02', 'http://sinalprivado.info:80/series/1533784/1533784/107807.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25232, 1720, 'Naruto Shippuden [L] S20 E03', 'http://sinalprivado.info:80/series/1533784/1533784/107808.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25233, 1720, 'Naruto Shippuden [L] S20 E04', 'http://sinalprivado.info:80/series/1533784/1533784/107809.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25234, 1720, 'Naruto Shippuden [L] S20 E05', 'http://sinalprivado.info:80/series/1533784/1533784/107810.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25235, 1720, 'Naruto Shippuden [L] S20 E06', 'http://sinalprivado.info:80/series/1533784/1533784/107811.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25236, 1720, 'Naruto Shippuden [L] S20 E07', 'http://sinalprivado.info:80/series/1533784/1533784/107812.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25237, 1720, 'Naruto Shippuden [L] S20 E08', 'http://sinalprivado.info:80/series/1533784/1533784/107813.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25238, 1720, 'Naruto Shippuden [L] S20 E09', 'http://sinalprivado.info:80/series/1533784/1533784/107814.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25239, 1720, 'Naruto Shippuden [L] S20 E10', 'http://sinalprivado.info:80/series/1533784/1533784/107815.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25240, 1720, 'Naruto Shippuden [L] S20 E11', 'http://sinalprivado.info:80/series/1533784/1533784/107816.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25241, 1720, 'Naruto Shippuden [L] S20 E12', 'http://sinalprivado.info:80/series/1533784/1533784/107817.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25242, 1720, 'Naruto Shippuden [L] S20 E13', 'http://sinalprivado.info:80/series/1533784/1533784/107818.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25243, 1720, 'Naruto Shippuden [L] S20 E14', 'http://sinalprivado.info:80/series/1533784/1533784/107819.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25244, 1720, 'Naruto Shippuden [L] S20 E15', 'http://sinalprivado.info:80/series/1533784/1533784/107820.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25245, 1720, 'Naruto Shippuden [L] S20 E16', 'http://sinalprivado.info:80/series/1533784/1533784/107821.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25246, 1720, 'Naruto Shippuden [L] S20 E17', 'http://sinalprivado.info:80/series/1533784/1533784/107822.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25247, 1720, 'Naruto Shippuden [L] S20 E18', 'http://sinalprivado.info:80/series/1533784/1533784/107823.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25248, 1720, 'Naruto Shippuden [L] S20 E19', 'http://sinalprivado.info:80/series/1533784/1533784/107824.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25249, 1720, 'Naruto Shippuden [L] S20 E20', 'http://sinalprivado.info:80/series/1533784/1533784/107825.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25250, 1720, 'Naruto Shippuden [L] S20 E21', 'http://sinalprivado.info:80/series/1533784/1533784/107826.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25251, 1720, 'Naruto Shippuden [L] S20 E22', 'http://sinalprivado.info:80/series/1533784/1533784/107827.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25252, 1720, 'Naruto Shippuden [L] S20 E23', 'http://sinalprivado.info:80/series/1533784/1533784/107828.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25253, 1720, 'Naruto Shippuden [L] S20 E24', 'http://sinalprivado.info:80/series/1533784/1533784/107829.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25254, 1720, 'Naruto Shippuden [L] S20 E25', 'http://sinalprivado.info:80/series/1533784/1533784/107830.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25255, 1720, 'Naruto Shippuden [L] S20 E26', 'http://sinalprivado.info:80/series/1533784/1533784/107831.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25256, 1720, 'Naruto Shippuden [L] S20 E27', 'http://sinalprivado.info:80/series/1533784/1533784/107832.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25257, 1720, 'Naruto Shippuden [L] S20 E28', 'http://sinalprivado.info:80/series/1533784/1533784/107833.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25258, 1720, 'Naruto Shippuden [L] S20 E29', 'http://sinalprivado.info:80/series/1533784/1533784/107834.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25259, 1720, 'Naruto Shippuden [L] S20 E30', 'http://sinalprivado.info:80/series/1533784/1533784/107835.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25260, 1720, 'Naruto Shippuden [L] S20 E31', 'http://sinalprivado.info:80/series/1533784/1533784/107836.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25261, 1720, 'Naruto Shippuden [L] S20 E32', 'http://sinalprivado.info:80/series/1533784/1533784/107837.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25262, 1720, 'Naruto Shippuden [L] S20 E33', 'http://sinalprivado.info:80/series/1533784/1533784/107838.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25263, 1720, 'Naruto Shippuden [L] S20 E34', 'http://sinalprivado.info:80/series/1533784/1533784/107839.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25264, 1720, 'Naruto Shippuden [L] S20 E35', 'http://sinalprivado.info:80/series/1533784/1533784/107840.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25265, 1720, 'Naruto Shippuden [L] S20 E36', 'http://sinalprivado.info:80/series/1533784/1533784/107841.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25266, 1720, 'Naruto Shippuden [L] S20 E37', 'http://sinalprivado.info:80/series/1533784/1533784/107842.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25267, 1720, 'Naruto Shippuden [L] S20 E38', 'http://sinalprivado.info:80/series/1533784/1533784/107843.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25268, 1720, 'Naruto Shippuden [L] S20 E39', 'http://sinalprivado.info:80/series/1533784/1533784/107844.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25269, 1720, 'Naruto Shippuden [L] S20 E40', 'http://sinalprivado.info:80/series/1533784/1533784/107845.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25270, 1720, 'Naruto Shippuden [L] S20 E41', 'http://sinalprivado.info:80/series/1533784/1533784/107846.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25271, 1720, 'Naruto Shippuden [L] S20 E42', 'http://sinalprivado.info:80/series/1533784/1533784/107847.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25272, 1720, 'Naruto Shippuden [L] S20 E43', 'http://sinalprivado.info:80/series/1533784/1533784/107848.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25273, 1720, 'Naruto Shippuden [L] S20 E44', 'http://sinalprivado.info:80/series/1533784/1533784/107849.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25274, 1720, 'Naruto Shippuden [L] S20 E45', 'http://sinalprivado.info:80/series/1533784/1533784/107850.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25275, 1720, 'Naruto Shippuden [L] S20 E46', 'http://sinalprivado.info:80/series/1533784/1533784/107851.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25276, 1720, 'Naruto Shippuden [L] S20 E47', 'http://sinalprivado.info:80/series/1533784/1533784/107852.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25277, 1720, 'Naruto Shippuden [L] S20 E48', 'http://sinalprivado.info:80/series/1533784/1533784/107853.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25278, 1720, 'Naruto Shippuden [L] S20 E49', 'http://sinalprivado.info:80/series/1533784/1533784/107854.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25279, 1720, 'Naruto Shippuden [L] S20 E50', 'http://sinalprivado.info:80/series/1533784/1533784/107855.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25280, 1720, 'Naruto Shippuden [L] S20 E51', 'http://sinalprivado.info:80/series/1533784/1533784/107856.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25281, 1720, 'Naruto Shippuden [L] S20 E52', 'http://sinalprivado.info:80/series/1533784/1533784/107857.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25282, 1720, 'Naruto Shippuden [L] S20 E53', 'http://sinalprivado.info:80/series/1533784/1533784/107858.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25283, 1720, 'Naruto Shippuden [L] S20 E54', 'http://sinalprivado.info:80/series/1533784/1533784/107859.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25284, 1720, 'Naruto Shippuden [L] S20 E55', 'http://sinalprivado.info:80/series/1533784/1533784/107860.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25285, 1720, 'Naruto Shippuden [L] S20 E56', 'http://sinalprivado.info:80/series/1533784/1533784/107861.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25286, 1720, 'Naruto Shippuden [L] S20 E57', 'http://sinalprivado.info:80/series/1533784/1533784/107862.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25287, 1720, 'Naruto Shippuden [L] S20 E58', 'http://sinalprivado.info:80/series/1533784/1533784/107863.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25288, 1720, 'Naruto Shippuden [L] S20 E59', 'http://sinalprivado.info:80/series/1533784/1533784/107864.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25289, 1720, 'Naruto Shippuden [L] S20 E60', 'http://sinalprivado.info:80/series/1533784/1533784/107865.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25290, 1720, 'Naruto Shippuden [L] S20 E61', 'http://sinalprivado.info:80/series/1533784/1533784/107866.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25291, 1720, 'Naruto Shippuden [L] S20 E62', 'http://sinalprivado.info:80/series/1533784/1533784/107867.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25292, 1720, 'Naruto Shippuden [L] S20 E63', 'http://sinalprivado.info:80/series/1533784/1533784/107868.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25293, 1720, 'Naruto Shippuden [L] S20 E64', 'http://sinalprivado.info:80/series/1533784/1533784/107869.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25294, 1720, 'Naruto Shippuden [L] S20 E65', 'http://sinalprivado.info:80/series/1533784/1533784/107870.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25295, 1720, 'Naruto Shippuden [L] S20 E66', 'http://sinalprivado.info:80/series/1533784/1533784/107871.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25296, 1720, 'Naruto Shippuden [L] S20 E67', 'http://sinalprivado.info:80/series/1533784/1533784/107872.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25297, 1720, 'Naruto Shippuden [L] S20 E68', 'http://sinalprivado.info:80/series/1533784/1533784/107873.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25298, 1720, 'Naruto Shippuden [L] S20 E69', 'http://sinalprivado.info:80/series/1533784/1533784/107874.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25299, 1720, 'Naruto Shippuden [L] S20 E70', 'http://sinalprivado.info:80/series/1533784/1533784/107875.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25300, 1720, 'Naruto Shippuden [L] S20 E71', 'http://sinalprivado.info:80/series/1533784/1533784/107876.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25301, 1720, 'Naruto Shippuden [L] S20 E72', 'http://sinalprivado.info:80/series/1533784/1533784/107877.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25302, 1720, 'Naruto Shippuden [L] S20 E73', 'http://sinalprivado.info:80/series/1533784/1533784/107878.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25303, 1720, 'Naruto Shippuden [L] S20 E74', 'http://sinalprivado.info:80/series/1533784/1533784/107879.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25304, 1720, 'Naruto Shippuden [L] S20 E75', 'http://sinalprivado.info:80/series/1533784/1533784/107880.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25305, 1720, 'Naruto Shippuden [L] S20 E76', 'http://sinalprivado.info:80/series/1533784/1533784/107881.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25306, 1720, 'Naruto Shippuden [L] S20 E77', 'http://sinalprivado.info:80/series/1533784/1533784/107882.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25307, 1720, 'Naruto Shippuden [L] S20 E78', 'http://sinalprivado.info:80/series/1533784/1533784/107883.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25308, 1720, 'Naruto Shippuden [L] S20 E79', 'http://sinalprivado.info:80/series/1533784/1533784/107884.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25309, 1720, 'Naruto Shippuden [L] S20 E80', 'http://sinalprivado.info:80/series/1533784/1533784/107885.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25310, 1720, 'Naruto Shippuden [L] S20 E81', 'http://sinalprivado.info:80/series/1533784/1533784/107886.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25311, 1720, 'Naruto Shippuden [L] S20 E82', 'http://sinalprivado.info:80/series/1533784/1533784/107887.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25312, 1720, 'Naruto Shippuden [L] S20 E83', 'http://sinalprivado.info:80/series/1533784/1533784/107888.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25313, 1720, 'Naruto Shippuden [L] S20 E84', 'http://sinalprivado.info:80/series/1533784/1533784/107889.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25314, 1720, 'Naruto Shippuden [L] S20 E85', 'http://sinalprivado.info:80/series/1533784/1533784/107890.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25315, 1720, 'Naruto Shippuden [L] S20 E86', 'http://sinalprivado.info:80/series/1533784/1533784/107891.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25316, 1720, 'Naruto Shippuden [L] S20 E87', 'http://sinalprivado.info:80/series/1533784/1533784/107892.mp4', 'http://imagecdn.sh:80/images/qOxedwaJzdms2alAmIEHEnDeDzg_big.jpg'),
(25317, 1721, 'Jornada nas Estrelas: Enterprise S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111685.mp4', 'http://timg.bdta.pro/images/6f8e49581e6e071d5923ed76551174ea.jpg'),
(25318, 1721, 'Jornada nas Estrelas: Enterprise S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111686.mp4', 'http://timg.bdta.pro/images/31927341029a0c7285f4b6cb97c09dca.jpg'),
(25319, 1721, 'Jornada nas Estrelas: Enterprise S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111687.mp4', 'http://timg.bdta.pro/images/870c64548078a8bd1f425c1a36a897ac.jpg'),
(25320, 1721, 'Jornada nas Estrelas: Enterprise S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111688.mp4', 'http://timg.bdta.pro/images/c4101f5785f4fdb03ac7c61fb213b426.jpg'),
(25321, 1721, 'Jornada nas Estrelas: Enterprise S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111689.mp4', 'http://timg.bdta.pro/images/63f7beb39422f7781453621bf8de826a.jpg'),
(25322, 1721, 'Jornada nas Estrelas: Enterprise S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/111690.mp4', 'http://timg.bdta.pro/images/8440a14810cb3bc7ecc970a31133294c.jpg'),
(25323, 1721, 'Jornada nas Estrelas: Enterprise S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/111691.mp4', 'http://timg.bdta.pro/images/642631820d6961f595e510a2867db04c.jpg'),
(25324, 1721, 'Jornada nas Estrelas: Enterprise S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/111692.mp4', 'http://timg.bdta.pro/images/12729bb4f79b9931b9e944a8c7cf82f2.jpg'),
(25325, 1721, 'Jornada nas Estrelas: Enterprise S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/111693.mp4', 'http://timg.bdta.pro/images/d337f3c683b8a63c6e9818e7be77e508.jpg'),
(25326, 1721, 'Jornada nas Estrelas: Enterprise S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/111694.mp4', 'http://timg.bdta.pro/images/0d5c13d4afe72f5e8ed56a1348b8c765.jpg'),
(25327, 1721, 'Jornada nas Estrelas: Enterprise S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/111695.mp4', 'http://timg.bdta.pro/images/0f464d06cd32ce6819102a036ba846d5.jpg'),
(25328, 1721, 'Jornada nas Estrelas: Enterprise S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/111696.mp4', 'http://timg.bdta.pro/images/907c8b96302170f5fdac8e7e234d1469.jpg'),
(25329, 1721, 'Jornada nas Estrelas: Enterprise S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/111697.mp4', 'http://timg.bdta.pro/images/e10973599aa3173aefb1aad69f52cfed.jpg'),
(25330, 1721, 'Jornada nas Estrelas: Enterprise S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/111698.mp4', 'http://timg.bdta.pro/images/56b53ef3599d82a735e6fa0e5373141e.jpg'),
(25331, 1721, 'Jornada nas Estrelas: Enterprise S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/111699.mp4', 'http://timg.bdta.pro/images/6103bbbe70f60d2fbc2c082215dd8ba4.jpg'),
(25332, 1721, 'Jornada nas Estrelas: Enterprise S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/111700.mp4', 'http://timg.bdta.pro/images/e04494d2d5ee81681cd51b2bd2075c3a.jpg'),
(25333, 1721, 'Jornada nas Estrelas: Enterprise S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/111701.mp4', 'http://timg.bdta.pro/images/ff13d9e26a8746cd03d19fcea8504536.jpg'),
(25334, 1721, 'Jornada nas Estrelas: Enterprise S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/111702.mp4', 'http://timg.bdta.pro/images/0a90bbea2f30360f43065b44c0cdb6c3.jpg'),
(25335, 1721, 'Jornada nas Estrelas: Enterprise S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/111703.mp4', 'http://timg.bdta.pro/images/6cf3bda55bab86ec227c8a3422f91197.jpg'),
(25336, 1721, 'Jornada nas Estrelas: Enterprise S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/111704.mp4', 'http://timg.bdta.pro/images/a35f09f05255d2f0cef73c6184f52097.jpg'),
(25337, 1721, 'Jornada nas Estrelas: Enterprise S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/111705.mp4', 'http://timg.bdta.pro/images/2e14fcc6238350701227edc725ebdccf.jpg'),
(25338, 1721, 'Jornada nas Estrelas: Enterprise S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/111706.mp4', 'http://timg.bdta.pro/images/41f03d3b6f41dfce025e194532fba474.jpg'),
(25339, 1721, 'Jornada nas Estrelas: Enterprise S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/111707.mp4', 'http://timg.bdta.pro/images/d6e40c90af6865b32c0a50421834a131.jpg'),
(25340, 1721, 'Jornada nas Estrelas: Enterprise S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/111708.mp4', 'http://timg.bdta.pro/images/de49e23c32021d1b9debd07df0ee6baf.jpg'),
(25341, 1721, 'Jornada nas Estrelas: Enterprise S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/111709.mp4', 'http://timg.bdta.pro/images/dee1df0e3c39e7d47df8b39e10e20770.jpg'),
(25342, 1722, 'Jornada nas Estrelas: Enterprise S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111710.mp4', 'http://timg.bdta.pro/images/f268a634849c100804e4010d3dcbad76.jpg'),
(25343, 1722, 'Jornada nas Estrelas: Enterprise S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111711.mp4', 'http://timg.bdta.pro/images/ac2d109f22085e3af5616ba777c41396.jpg'),
(25344, 1722, 'Jornada nas Estrelas: Enterprise S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111712.mp4', 'http://timg.bdta.pro/images/72cbfece70eda77bd5b0c7502dbfaa8a.jpg'),
(25345, 1722, 'Jornada nas Estrelas: Enterprise S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111713.mp4', 'http://timg.bdta.pro/images/231781af3126d666257babe27a5d1481.jpg'),
(25346, 1722, 'Jornada nas Estrelas: Enterprise S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111714.mp4', 'http://timg.bdta.pro/images/e99bb173f8803d6c20e97d73c0591c6a.jpg'),
(25347, 1722, 'Jornada nas Estrelas: Enterprise S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/111715.mp4', 'http://timg.bdta.pro/images/36840e14c9a5ca20b0521da2e3b01bc3.jpg'),
(25348, 1722, 'Jornada nas Estrelas: Enterprise S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/111716.mp4', 'http://timg.bdta.pro/images/2cb0c843fdcd7b10d9c17978a04f37ed.jpg'),
(25349, 1722, 'Jornada nas Estrelas: Enterprise S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/111717.mp4', 'http://timg.bdta.pro/images/c9e51ab864eec4070737366ba09186f5.jpg'),
(25350, 1722, 'Jornada nas Estrelas: Enterprise S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/111718.mp4', 'http://timg.bdta.pro/images/e82e04a23a43b6c6e4ba80d4762e4f94.jpg'),
(25351, 1722, 'Jornada nas Estrelas: Enterprise S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/111719.mp4', 'http://timg.bdta.pro/images/f8eb58f445e7ff57a7f144d2040bcb00.jpg'),
(25352, 1722, 'Jornada nas Estrelas: Enterprise S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/111720.mp4', 'http://timg.bdta.pro/images/f570c467303c771bdd082c5f46842f62.jpg'),
(25353, 1722, 'Jornada nas Estrelas: Enterprise S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/111721.mp4', 'http://timg.bdta.pro/images/4ce12df9c6c87bc2c1a5097d589b8127.jpg'),
(25354, 1722, 'Jornada nas Estrelas: Enterprise S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/111722.mp4', 'http://timg.bdta.pro/images/b39c25e1aca5a73335ac21f1b80237ab.jpg'),
(25355, 1722, 'Jornada nas Estrelas: Enterprise S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/111723.mp4', 'http://timg.bdta.pro/images/1a670226c74c8e1245eada86e5706c96.jpg'),
(25356, 1722, 'Jornada nas Estrelas: Enterprise S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/111724.mp4', 'http://timg.bdta.pro/images/4c85a96296e8098ba903901957b6e88d.jpg'),
(25357, 1722, 'Jornada nas Estrelas: Enterprise S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/111725.mp4', 'http://timg.bdta.pro/images/46ce04fbb01b851fec32c8466f15573c.jpg'),
(25358, 1722, 'Jornada nas Estrelas: Enterprise S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/111726.mp4', 'http://timg.bdta.pro/images/c34133371398f1d38f78f234a97bf701.jpg'),
(25359, 1722, 'Jornada nas Estrelas: Enterprise S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/111727.mp4', 'http://timg.bdta.pro/images/7067c3cfb36bd527b6d92ce0e4ac46a1.jpg'),
(25360, 1722, 'Jornada nas Estrelas: Enterprise S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/111728.mp4', 'http://timg.bdta.pro/images/165499e7a6ceb0d86ba6fb1793de709a.jpg'),
(25361, 1722, 'Jornada nas Estrelas: Enterprise S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/111729.mp4', 'http://timg.bdta.pro/images/c886c910b8f0bbfcce11350c05485a5a.jpg'),
(25362, 1722, 'Jornada nas Estrelas: Enterprise S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/111730.mp4', 'http://timg.bdta.pro/images/35c6dd26d7600a061480fe5f5b46d28b.jpg'),
(25363, 1722, 'Jornada nas Estrelas: Enterprise S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/111731.mp4', 'http://timg.bdta.pro/images/0c78fe28828801ff576e14ccd6b37dc7.jpg'),
(25364, 1722, 'Jornada nas Estrelas: Enterprise S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/111732.mp4', 'http://timg.bdta.pro/images/fa45bd25238eba8590f205ab42f6af5b.jpg'),
(25365, 1722, 'Jornada nas Estrelas: Enterprise S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/111733.mp4', 'http://timg.bdta.pro/images/f11fef842f4aeca068e566ab7a681e69.jpg'),
(25366, 1722, 'Jornada nas Estrelas: Enterprise S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/111734.mp4', 'http://timg.bdta.pro/images/3093c84ee7232d0c0afcf101a615ce1f.jpg'),
(25367, 1722, 'Jornada nas Estrelas: Enterprise S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/111735.mp4', 'http://timg.bdta.pro/images/5eaedf3e90f4debaf22dcffacc4255fd.jpg'),
(25368, 1723, 'Jornada nas Estrelas: Enterprise S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111736.mp4', 'http://timg.bdta.pro/images/c87fd58f68a934f61641bf8723e32fde.jpg'),
(25369, 1723, 'Jornada nas Estrelas: Enterprise S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111737.mp4', 'http://timg.bdta.pro/images/7788e2622dfdb9845152e3214dbf7642.jpg'),
(25370, 1723, 'Jornada nas Estrelas: Enterprise S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111738.mp4', 'http://timg.bdta.pro/images/664c2266b3b0f074d34788bcd17bab10.jpg'),
(25371, 1723, 'Jornada nas Estrelas: Enterprise S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111739.mp4', 'http://timg.bdta.pro/images/4d299bef44c7eaa5abf69ceba416c4c9.jpg'),
(25372, 1723, 'Jornada nas Estrelas: Enterprise S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111740.mp4', 'http://timg.bdta.pro/images/3af37ab520a8bb10451ce32aa4245079.jpg'),
(25373, 1723, 'Jornada nas Estrelas: Enterprise S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/111741.mp4', 'http://timg.bdta.pro/images/e15639fb5f9d0e20f5f4489fe8030f04.jpg'),
(25374, 1723, 'Jornada nas Estrelas: Enterprise S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/111742.mp4', 'http://timg.bdta.pro/images/f4775d046ab7c1b649cf33bc64a6ac05.jpg'),
(25375, 1723, 'Jornada nas Estrelas: Enterprise S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/111743.mp4', 'http://timg.bdta.pro/images/45b544f6a9dd12b2389caf53ada771ea.jpg'),
(25376, 1723, 'Jornada nas Estrelas: Enterprise S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/111744.mp4', 'http://timg.bdta.pro/images/acd45dee257fcbd40e49b5cef5e322bf.jpg'),
(25377, 1723, 'Jornada nas Estrelas: Enterprise S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/111745.mp4', 'http://timg.bdta.pro/images/7b6aa8b7b225f613e766f7340070e005.jpg'),
(25378, 1723, 'Jornada nas Estrelas: Enterprise S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/111746.mp4', 'http://timg.bdta.pro/images/205d03ae2c13576ddee9d1cdbbdcde91.jpg'),
(25379, 1723, 'Jornada nas Estrelas: Enterprise S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/111747.mp4', 'http://timg.bdta.pro/images/c7606e81b69c648c4629e07b23b87a8c.jpg'),
(25380, 1723, 'Jornada nas Estrelas: Enterprise S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/111748.mp4', 'http://timg.bdta.pro/images/51f7f56a0d2f3edfc48946b4b0979631.jpg'),
(25381, 1723, 'Jornada nas Estrelas: Enterprise S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/111749.mp4', 'http://timg.bdta.pro/images/5ecf3f9804202f8f078f91d5f6391de3.jpg'),
(25382, 1723, 'Jornada nas Estrelas: Enterprise S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/111750.mp4', 'http://timg.bdta.pro/images/8d482d022b67495cc108cb1964f892e2.jpg'),
(25383, 1723, 'Jornada nas Estrelas: Enterprise S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/111751.mp4', 'http://timg.bdta.pro/images/48363188dc2431410fe1c0095bdd862a.jpg'),
(25384, 1723, 'Jornada nas Estrelas: Enterprise S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/111752.mp4', 'http://timg.bdta.pro/images/9d1a4af42a6037920eb40fd6f473e42f.jpg'),
(25385, 1723, 'Jornada nas Estrelas: Enterprise S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/111753.mp4', 'http://timg.bdta.pro/images/1c1515339e2d8b7a9c30e7b1e6178ead.jpg'),
(25386, 1723, 'Jornada nas Estrelas: Enterprise S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/111754.mp4', 'http://timg.bdta.pro/images/e8ca81edea755f6f1cef3adf7046b155.jpg'),
(25387, 1723, 'Jornada nas Estrelas: Enterprise S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/111755.mp4', 'http://timg.bdta.pro/images/83b4314551b060fab2ff7fdc0ae03ecf.jpg'),
(25388, 1723, 'Jornada nas Estrelas: Enterprise S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/111756.mp4', 'http://timg.bdta.pro/images/5616882d85c67fb0d360a1f1298aefa3.jpg'),
(25389, 1723, 'Jornada nas Estrelas: Enterprise S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/111757.mp4', 'http://timg.bdta.pro/images/4a5624e22c13320a921386d4a6fca242.jpg'),
(25390, 1723, 'Jornada nas Estrelas: Enterprise S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/111758.mp4', 'http://timg.bdta.pro/images/c3a3e9b99fee7add4431e093378469a2.jpg'),
(25391, 1723, 'Jornada nas Estrelas: Enterprise S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/111759.mp4', 'http://timg.bdta.pro/images/4a82dff13cd028237759f19a246c8ce1.jpg'),
(25392, 1724, 'Jornada nas Estrelas: Enterprise S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111760.mp4', 'http://timg.bdta.pro/images/a283940f28a30b5dbae25a959eb73c3b.jpg'),
(25393, 1724, 'Jornada nas Estrelas: Enterprise S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111761.mp4', 'http://timg.bdta.pro/images/5102fedb8d67a7461eda6b311fb20dff.jpg'),
(25394, 1724, 'Jornada nas Estrelas: Enterprise S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111762.mp4', 'http://timg.bdta.pro/images/d1314da7e7cab46f4b81183fe54d1b40.jpg'),
(25395, 1724, 'Jornada nas Estrelas: Enterprise S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111763.mp4', 'http://timg.bdta.pro/images/084db67c2e533cb19a124fbee0e4c564.jpg'),
(25396, 1724, 'Jornada nas Estrelas: Enterprise S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111764.mp4', 'http://timg.bdta.pro/images/ab66059e5d83372c4edcef924ef5a571.jpg'),
(25397, 1724, 'Jornada nas Estrelas: Enterprise S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/111765.mp4', 'http://timg.bdta.pro/images/3c1d5a0a8825070d7ff29f55f3db856e.jpg'),
(25398, 1724, 'Jornada nas Estrelas: Enterprise S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/111766.mp4', 'http://timg.bdta.pro/images/6133c694908780e521873baf30b236ba.jpg'),
(25399, 1724, 'Jornada nas Estrelas: Enterprise S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/111767.mp4', 'http://timg.bdta.pro/images/c9ae93b8f39cb1ebdcb3bed5a819468c.jpg'),
(25400, 1724, 'Jornada nas Estrelas: Enterprise S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/111768.mp4', 'http://timg.bdta.pro/images/82fd0a5175db2f6de3ecb10ac975e14b.jpg'),
(25401, 1724, 'Jornada nas Estrelas: Enterprise S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/111769.mp4', 'http://timg.bdta.pro/images/d2f097fefe68d1cbe412e07e09f722f3.jpg'),
(25402, 1724, 'Jornada nas Estrelas: Enterprise S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/111770.mp4', 'http://timg.bdta.pro/images/96dfe0def0eb2ca2d484be1d4a7c9018.jpg'),
(25403, 1724, 'Jornada nas Estrelas: Enterprise S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/111771.mp4', 'http://timg.bdta.pro/images/d3539914c9d3778901bbc2081a2b269b.jpg'),
(25404, 1724, 'Jornada nas Estrelas: Enterprise S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/111772.mp4', 'http://timg.bdta.pro/images/d6b0c643c9e50838f3529d327e590bf5.jpg'),
(25405, 1724, 'Jornada nas Estrelas: Enterprise S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/111773.mp4', 'http://timg.bdta.pro/images/23e435af0b9e17b5e77382ca897ad6e0.jpg'),
(25406, 1724, 'Jornada nas Estrelas: Enterprise S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/111774.mp4', 'http://timg.bdta.pro/images/36389929f7a09fe90c3160fe956f8e25.jpg'),
(25407, 1724, 'Jornada nas Estrelas: Enterprise S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/111775.mp4', 'http://timg.bdta.pro/images/b39be7dc73a325748b6b87d8fb4d0106.jpg'),
(25408, 1724, 'Jornada nas Estrelas: Enterprise S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/111776.mp4', 'http://timg.bdta.pro/images/9834db822a0942b874a17264a0e547bf.jpg'),
(25409, 1724, 'Jornada nas Estrelas: Enterprise S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/111777.mp4', 'http://timg.bdta.pro/images/7c51e64532473a9e21936f5b6acc36c4.jpg'),
(25410, 1724, 'Jornada nas Estrelas: Enterprise S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/111778.mp4', 'http://timg.bdta.pro/images/474b1a4671476b71fc3b0e23d412e8eb.jpg'),
(25411, 1724, 'Jornada nas Estrelas: Enterprise S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/111779.mp4', 'http://timg.bdta.pro/images/b1b67ccec3fc404ea9f0ecf55a696410.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(25412, 1724, 'Jornada nas Estrelas: Enterprise S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/111780.mp4', 'http://timg.bdta.pro/images/841eb95739f8f022f73739d8f0e274f3.jpg'),
(25413, 1724, 'Jornada nas Estrelas: Enterprise S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/111781.mp4', 'http://timg.bdta.pro/images/bde49876b6e06c00e75cc43a860fd3d1.jpg'),
(25414, 1725, 'Bleach [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111326.mp4', 'http://timg.bdta.pro/images/4c62437fa26c8e8a7e9d0bb2f8eb1ac8.jpg'),
(25415, 1725, 'Bleach [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111327.mp4', 'http://timg.bdta.pro/images/bbf13bacdd2f74ac3d129072758dae64.jpg'),
(25416, 1725, 'Bleach [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111328.mp4', 'http://timg.bdta.pro/images/f8b8771a9846e69b011dba4d2bdce47e.jpg'),
(25417, 1725, 'Bleach [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111329.mp4', 'http://timg.bdta.pro/images/22a2d2736d45f46f6723d64c58bb24b1.jpg'),
(25418, 1725, 'Bleach [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111330.mp4', 'http://timg.bdta.pro/images/b544273867c301e674da57f32c85acc2.jpg'),
(25419, 1725, 'Bleach [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/111331.mp4', 'http://timg.bdta.pro/images/498fa2859db1910894a153f778ce1ec0.jpg'),
(25420, 1725, 'Bleach [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/111332.mp4', 'http://timg.bdta.pro/images/c636b6f8f57fa69f822276debcaa0d16.jpg'),
(25421, 1725, 'Bleach [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/111333.mp4', 'http://timg.bdta.pro/images/2a22c26468e54aeec999830494c2f792.jpg'),
(25422, 1725, 'Bleach [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/111334.mp4', 'http://timg.bdta.pro/images/324e26a65594efbf43468e5cbd3416aa.jpg'),
(25423, 1725, 'Bleach [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/111335.mp4', 'http://timg.bdta.pro/images/3e75483b07de667c78a8dad26ede508e.jpg'),
(25424, 1725, 'Bleach [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/111336.mp4', 'http://timg.bdta.pro/images/9320471470fc94faca3873558725b74e.jpg'),
(25425, 1725, 'Bleach [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/111337.mp4', 'http://timg.bdta.pro/images/412e1cc8026e8f6f52c20837cee8f7f8.jpg'),
(25426, 1725, 'Bleach [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/111338.mp4', 'http://timg.bdta.pro/images/968a3d28955105ae9ff19a45e457dc49.jpg'),
(25427, 1725, 'Bleach [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/111339.mp4', 'http://timg.bdta.pro/images/fdbb2c961064da3f221f2b1e39197aaf.jpg'),
(25428, 1725, 'Bleach [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/111340.mp4', 'http://timg.bdta.pro/images/690f0db9a5113d67b682414804301d93.jpg'),
(25429, 1725, 'Bleach [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/111341.mp4', 'http://timg.bdta.pro/images/3cd67d1fe71c285f21852cb93b6ca1a5.jpg'),
(25430, 1725, 'Bleach [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/111342.mp4', 'http://timg.bdta.pro/images/04e4dca2eb758f82d240d699aad633d6.jpg'),
(25431, 1725, 'Bleach [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/111343.mp4', 'http://timg.bdta.pro/images/a271358ba003b0cebde8ebb2ea20f79d.jpg'),
(25432, 1725, 'Bleach [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/111344.mp4', 'http://timg.bdta.pro/images/d28ed4b1fdb9797300cf533bcfab0998.jpg'),
(25433, 1725, 'Bleach [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/111345.mp4', 'http://timg.bdta.pro/images/b7b5cbb310bbedc5874966d77afb5487.jpg'),
(25434, 1725, 'Bleach [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/111346.mp4', 'http://timg.bdta.pro/images/ba3255f917b1da2d47357612c30298c1.jpg'),
(25435, 1725, 'Bleach [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/111347.mp4', 'http://timg.bdta.pro/images/da92d5cb32e8cf6cbb674f648ae61594.jpg'),
(25436, 1725, 'Bleach [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/111348.mp4', 'http://timg.bdta.pro/images/b30a1da476c06bb905e54f30c12c7658.jpg'),
(25437, 1725, 'Bleach [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/111349.mp4', 'http://timg.bdta.pro/images/7c7635cd3844144eac3cf831584a0c6f.jpg'),
(25438, 1725, 'Bleach [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/111350.mp4', 'http://timg.bdta.pro/images/6b57c02407e459634007eeb6159f14af.jpg'),
(25439, 1725, 'Bleach [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/111351.mp4', 'http://timg.bdta.pro/images/3f8dd881670b2f6732311c8e5449ec0d.jpg'),
(25440, 1725, 'Bleach [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/111352.mp4', 'http://timg.bdta.pro/images/a94bfa28d0a83dbde9b38d7a77d8c95f.jpg'),
(25441, 1725, 'Bleach [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/111353.mp4', 'http://timg.bdta.pro/images/254aeff3f1c7de8c8b9dacb281eee688.jpg'),
(25442, 1725, 'Bleach [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/111354.mp4', 'http://timg.bdta.pro/images/24737064ced1eee4c61e24acddf0dcdc.jpg'),
(25443, 1725, 'Bleach [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/111355.mp4', 'http://timg.bdta.pro/images/807c41c21f822a2b1960daa47e08151f.jpg'),
(25444, 1725, 'Bleach [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/111356.mp4', 'http://timg.bdta.pro/images/efb0ad9013778bfe607bf3b9f6f8f819.jpg'),
(25445, 1725, 'Bleach [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/111357.mp4', 'http://timg.bdta.pro/images/393d255aa0f48a862bb3bf1131d482a3.jpg'),
(25446, 1725, 'Bleach [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/111358.mp4', 'http://timg.bdta.pro/images/692dd352501aa5db6b9e497b237b4fe2.jpg'),
(25447, 1725, 'Bleach [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/111359.mp4', 'http://timg.bdta.pro/images/24979f69b7478f9ed0dc0d2107a06167.jpg'),
(25448, 1725, 'Bleach [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/111360.mp4', 'http://timg.bdta.pro/images/aabbcafeae2425aa110df2ef4a751bab.jpg'),
(25449, 1725, 'Bleach [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/111361.mp4', 'http://timg.bdta.pro/images/9ebe6c82699fdb416908431e0009c2f7.jpg'),
(25450, 1725, 'Bleach [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/111362.mp4', 'http://timg.bdta.pro/images/ee019c0c2f9357c35e5d734e8611c8f5.jpg'),
(25451, 1725, 'Bleach [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/111363.mp4', 'http://timg.bdta.pro/images/40c005cf4c872f821874d47a5d54387c.jpg'),
(25452, 1725, 'Bleach [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/111364.mp4', 'http://timg.bdta.pro/images/1d4d1a11a38824334faa05920e4f8697.jpg'),
(25453, 1725, 'Bleach [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/111365.mp4', 'http://timg.bdta.pro/images/0b8872fb40fa3139441acec20d3baa3f.jpg'),
(25454, 1725, 'Bleach [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/111366.mp4', 'http://timg.bdta.pro/images/6b66ab0c043832e9259337fa02c9cd78.jpg'),
(25455, 1725, 'Bleach [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/111367.mp4', 'http://timg.bdta.pro/images/df61ef62d298e68c4409e1f1817f2a18.jpg'),
(25456, 1725, 'Bleach [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/111368.mp4', 'http://timg.bdta.pro/images/f31e0277494abb4f08a98459cf22bd2c.jpg'),
(25457, 1725, 'Bleach [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/111369.mp4', 'http://timg.bdta.pro/images/05be6ef639f30a04030dfbb4a59dd6de.jpg'),
(25458, 1725, 'Bleach [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/111370.mp4', 'http://timg.bdta.pro/images/833a330427b8cf73f101ae267e914716.jpg'),
(25459, 1725, 'Bleach [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/111371.mp4', 'http://timg.bdta.pro/images/6437c1d38dae0d436502056fdf6742da.jpg'),
(25460, 1725, 'Bleach [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/111372.mp4', 'http://timg.bdta.pro/images/b83fbc8f051cfd186fb06b92f8d17fdd.jpg'),
(25461, 1725, 'Bleach [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/111373.mp4', 'http://timg.bdta.pro/images/7efcb88b0dc612ccfa96ce0c78d225e1.jpg'),
(25462, 1725, 'Bleach [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/111374.mp4', 'http://timg.bdta.pro/images/bd1477f66c544070fb20f9ce295ab2d9.jpg'),
(25463, 1725, 'Bleach [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/111375.mp4', 'http://timg.bdta.pro/images/e807933e40c2081c1707e4f65f63e74e.jpg'),
(25464, 1725, 'Bleach [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/111376.mp4', 'http://timg.bdta.pro/images/56f8c01c49db1f1e048c35d54ff5ab6f.jpg'),
(25465, 1725, 'Bleach [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/111377.mp4', 'http://timg.bdta.pro/images/238b5e3a3220b29c0f038a7cd545f644.jpg'),
(25466, 1725, 'Bleach [L] S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/111378.mp4', 'http://timg.bdta.pro/images/bcf2c4bcd0517f5db8019d773efe2f56.jpg'),
(25467, 1725, 'Bleach [L] S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/111379.mp4', 'http://timg.bdta.pro/images/4d161a042016d9a71064f80462a7982c.jpg'),
(25468, 1725, 'Bleach [L] S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/111380.mp4', 'http://timg.bdta.pro/images/9949be616506e1a0007142d82e01dd22.jpg'),
(25469, 1725, 'Bleach [L] S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/111381.mp4', 'http://timg.bdta.pro/images/cb80d3cb0a1d4e811536e537f30824ae.jpg'),
(25470, 1725, 'Bleach [L] S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/111382.mp4', 'http://timg.bdta.pro/images/2c4aa06f9bdbbae0b8eb946b31d365de.jpg'),
(25471, 1725, 'Bleach [L] S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/111383.mp4', 'http://timg.bdta.pro/images/0b2e22275e84ce76c7b64e6c83bf376e.jpg'),
(25472, 1725, 'Bleach [L] S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/111384.mp4', 'http://timg.bdta.pro/images/e85096d8ffb75b731a5d945253d3bf49.jpg'),
(25473, 1725, 'Bleach [L] S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/111385.mp4', 'http://timg.bdta.pro/images/48f1cc65c4ca2c904a329f920bb72e35.jpg'),
(25474, 1725, 'Bleach [L] S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/111386.mp4', 'http://timg.bdta.pro/images/833b047cf868b65b772d14c021f6b2f9.jpg'),
(25475, 1725, 'Bleach [L] S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/111387.mp4', 'http://timg.bdta.pro/images/42f59dcf702ee0b1f58c21e35c42ce71.jpg'),
(25476, 1725, 'Bleach [L] S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/111388.mp4', 'http://timg.bdta.pro/images/28b5b56e907704d90e43797c2f3bc35a.jpg'),
(25477, 1725, 'Bleach [L] S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/111389.mp4', 'http://timg.bdta.pro/images/5e878f186dda96ac7323995f03ba819c.jpg'),
(25478, 1725, 'Bleach [L] S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/111390.mp4', 'http://timg.bdta.pro/images/090da57583f6444caae30727928e0fd0.jpg'),
(25479, 1725, 'Bleach [L] S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/111391.mp4', 'http://timg.bdta.pro/images/b151fd3a48102ce82a81924e512b9bf7.jpg'),
(25480, 1725, 'Bleach [L] S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/111392.mp4', 'http://timg.bdta.pro/images/e080efd3ffb11a565ce043bce043c0c0.jpg'),
(25481, 1725, 'Bleach [L] S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/111393.mp4', 'http://timg.bdta.pro/images/b1b3d9b6b75afd5f81daab713f9ba24f.jpg'),
(25482, 1725, 'Bleach [L] S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/111394.mp4', 'http://timg.bdta.pro/images/aca8977cc445851771c7e574aa9fcc68.jpg'),
(25483, 1725, 'Bleach [L] S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/111395.mp4', 'http://timg.bdta.pro/images/aee8c3a163baa8d7a9c1bcd651d7fdbf.jpg'),
(25484, 1725, 'Bleach [L] S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/111396.mp4', 'http://timg.bdta.pro/images/f86a549c86629189d58ba734edeb71c7.jpg'),
(25485, 1725, 'Bleach [L] S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/111397.mp4', 'http://timg.bdta.pro/images/ec298f7b2aaffdab18084fc6b1e7ae9f.jpg'),
(25486, 1725, 'Bleach [L] S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/111398.mp4', 'http://timg.bdta.pro/images/52ee7f8f4046f0e64aa83174bd8e6581.jpg'),
(25487, 1725, 'Bleach [L] S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/111399.mp4', 'http://timg.bdta.pro/images/bbe303bfc9e7507f2a96376239b70489.jpg'),
(25488, 1725, 'Bleach [L] S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/111400.mp4', 'http://timg.bdta.pro/images/9315bc29941a86da4fa4b733dd252853.jpg'),
(25489, 1725, 'Bleach [L] S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/111401.mp4', 'http://timg.bdta.pro/images/2990a1ad42791c8655d5956e00ba4ec1.jpg'),
(25490, 1725, 'Bleach [L] S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/111402.mp4', 'http://timg.bdta.pro/images/16acfec59fae9c7fde04e729cef93125.jpg'),
(25491, 1725, 'Bleach [L] S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/111403.mp4', 'http://timg.bdta.pro/images/b82d73af96e243cbfb93d1c216f6a0ef.jpg'),
(25492, 1725, 'Bleach [L] S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/111404.mp4', 'http://timg.bdta.pro/images/81d203ee73103684ca72de074c1a246b.jpg'),
(25493, 1725, 'Bleach [L] S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/111405.mp4', 'http://timg.bdta.pro/images/e63e40def1db4533edc97f491f742753.jpg'),
(25494, 1725, 'Bleach [L] S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/111406.mp4', 'http://timg.bdta.pro/images/8b2ab175d38fb89ee1ef82dc1a64c463.jpg'),
(25495, 1725, 'Bleach [L] S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/111407.mp4', 'http://timg.bdta.pro/images/03448d0e5b80e326841deb40a26bbba1.jpg'),
(25496, 1725, 'Bleach [L] S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/111408.mp4', 'http://timg.bdta.pro/images/98b6718d07923608dfba265c1c692c6c.jpg'),
(25497, 1725, 'Bleach [L] S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/111409.mp4', 'http://timg.bdta.pro/images/70b550fded72194fd3d857701f082653.jpg'),
(25498, 1725, 'Bleach [L] S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/111410.mp4', 'http://timg.bdta.pro/images/44867549f7ebf43c6d42670460cdfe2c.jpg'),
(25499, 1725, 'Bleach [L] S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/111411.mp4', 'http://timg.bdta.pro/images/e00ee2137b277603663aa14041a621e1.jpg'),
(25500, 1725, 'Bleach [L] S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/111412.mp4', 'http://timg.bdta.pro/images/afae4a0b2da7538172637848a284d6f3.jpg'),
(25501, 1725, 'Bleach [L] S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/111413.mp4', 'http://timg.bdta.pro/images/9b413fba7c490bdaaec681ace28ee406.jpg'),
(25502, 1725, 'Bleach [L] S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/111414.mp4', 'http://timg.bdta.pro/images/cebbdac47bebebe7e3b87ea765b1a111.jpg'),
(25503, 1725, 'Bleach [L] S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/111415.mp4', 'http://timg.bdta.pro/images/10e51a50604b53a7273a0866e8c3d0c2.jpg'),
(25504, 1725, 'Bleach [L] S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/111416.mp4', 'http://timg.bdta.pro/images/c992830e1dc53b9400b156b012da6ba9.jpg'),
(25505, 1725, 'Bleach [L] S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/111417.mp4', 'http://timg.bdta.pro/images/0b3da795e1ad1a257830568d0bea5a8f.jpg'),
(25506, 1725, 'Bleach [L] S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/111418.mp4', 'http://timg.bdta.pro/images/831ce7bfc950195f32378e81dfafe392.jpg'),
(25507, 1725, 'Bleach [L] S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/111419.mp4', 'http://timg.bdta.pro/images/7b22937d5b27fb1fc5749334dcad00fa.jpg'),
(25508, 1725, 'Bleach [L] S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/111420.mp4', 'http://timg.bdta.pro/images/1c0e746d5acf00dc19d32ea474b22e5b.jpg'),
(25509, 1725, 'Bleach [L] S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/111421.mp4', 'http://timg.bdta.pro/images/7fd6641c879001ad19b8c962ac508436.jpg'),
(25510, 1725, 'Bleach [L] S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/111422.mp4', 'http://timg.bdta.pro/images/e2449e7a9e736c41ee1c0cd6856f1237.jpg'),
(25511, 1725, 'Bleach [L] S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/111423.mp4', 'http://timg.bdta.pro/images/bd741c43cb9e2ffc095bbc387fb3a2da.jpg'),
(25512, 1725, 'Bleach [L] S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/111424.mp4', 'http://timg.bdta.pro/images/5a07cb04a8db736cf01693dae915b116.jpg'),
(25513, 1725, 'Bleach [L] S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/111425.mp4', 'http://timg.bdta.pro/images/76b40f15484ee1c072abf54b47f0eea6.jpg'),
(25514, 1725, 'Bleach [L] S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/111426.mp4', 'http://timg.bdta.pro/images/34f90aa63eb2e7b99440141a21ee2ef9.jpg'),
(25515, 1725, 'Bleach [L] S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/111427.mp4', 'http://timg.bdta.pro/images/2e69922a9e6a3e13ebe7c626e2a2f731.jpg'),
(25516, 1725, 'Bleach [L] S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/111428.mp4', 'http://timg.bdta.pro/images/ac2678db8e52af2c5ae74f432bb23997.jpg'),
(25517, 1725, 'Bleach [L] S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/111429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25518, 1725, 'Bleach [L] S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/111430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25519, 1725, 'Bleach [L] S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/111431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25520, 1725, 'Bleach [L] S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/111432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25521, 1725, 'Bleach [L] S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/111433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25522, 1725, 'Bleach [L] S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/111434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25523, 1725, 'Bleach [L] S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/111435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25524, 1725, 'Bleach [L] S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/111436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25525, 1725, 'Bleach [L] S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/111437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25526, 1725, 'Bleach [L] S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/111438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25527, 1725, 'Bleach [L] S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/111439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25528, 1725, 'Bleach [L] S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/111440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25529, 1725, 'Bleach [L] S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/111441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25530, 1725, 'Bleach [L] S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/111442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25531, 1725, 'Bleach [L] S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/111443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25532, 1725, 'Bleach [L] S01 E119', 'http://sinalprivado.info:80/series/1533784/1533784/111444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25533, 1725, 'Bleach [L] S01 E120', 'http://sinalprivado.info:80/series/1533784/1533784/111445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25534, 1725, 'Bleach [L] S01 E121', 'http://sinalprivado.info:80/series/1533784/1533784/111446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25535, 1725, 'Bleach [L] S01 E122', 'http://sinalprivado.info:80/series/1533784/1533784/111447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25536, 1725, 'Bleach [L] S01 E123', 'http://sinalprivado.info:80/series/1533784/1533784/111448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25537, 1725, 'Bleach [L] S01 E124', 'http://sinalprivado.info:80/series/1533784/1533784/111449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25538, 1725, 'Bleach [L] S01 E125', 'http://sinalprivado.info:80/series/1533784/1533784/111450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25539, 1725, 'Bleach [L] S01 E126', 'http://sinalprivado.info:80/series/1533784/1533784/111451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25540, 1725, 'Bleach [L] S01 E127', 'http://sinalprivado.info:80/series/1533784/1533784/111452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25541, 1725, 'Bleach [L] S01 E128', 'http://sinalprivado.info:80/series/1533784/1533784/111453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25542, 1725, 'Bleach [L] S01 E129', 'http://sinalprivado.info:80/series/1533784/1533784/111454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25543, 1725, 'Bleach [L] S01 E130', 'http://sinalprivado.info:80/series/1533784/1533784/111455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25544, 1725, 'Bleach [L] S01 E131', 'http://sinalprivado.info:80/series/1533784/1533784/111456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25545, 1725, 'Bleach [L] S01 E132', 'http://sinalprivado.info:80/series/1533784/1533784/111457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25546, 1725, 'Bleach [L] S01 E133', 'http://sinalprivado.info:80/series/1533784/1533784/111458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25547, 1725, 'Bleach [L] S01 E134', 'http://sinalprivado.info:80/series/1533784/1533784/111459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25548, 1725, 'Bleach [L] S01 E135', 'http://sinalprivado.info:80/series/1533784/1533784/111460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25549, 1725, 'Bleach [L] S01 E136', 'http://sinalprivado.info:80/series/1533784/1533784/111461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25550, 1725, 'Bleach [L] S01 E137', 'http://sinalprivado.info:80/series/1533784/1533784/111462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25551, 1725, 'Bleach [L] S01 E138', 'http://sinalprivado.info:80/series/1533784/1533784/111463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25552, 1725, 'Bleach [L] S01 E139', 'http://sinalprivado.info:80/series/1533784/1533784/111464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25553, 1725, 'Bleach [L] S01 E140', 'http://sinalprivado.info:80/series/1533784/1533784/111465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25554, 1725, 'Bleach [L] S01 E141', 'http://sinalprivado.info:80/series/1533784/1533784/111466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25555, 1725, 'Bleach [L] S01 E142', 'http://sinalprivado.info:80/series/1533784/1533784/111467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25556, 1725, 'Bleach [L] S01 E143', 'http://sinalprivado.info:80/series/1533784/1533784/111468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25557, 1725, 'Bleach [L] S01 E144', 'http://sinalprivado.info:80/series/1533784/1533784/111469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25558, 1725, 'Bleach [L] S01 E145', 'http://sinalprivado.info:80/series/1533784/1533784/111470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25559, 1725, 'Bleach [L] S01 E146', 'http://sinalprivado.info:80/series/1533784/1533784/111471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25560, 1725, 'Bleach [L] S01 E147', 'http://sinalprivado.info:80/series/1533784/1533784/111472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25561, 1725, 'Bleach [L] S01 E148', 'http://sinalprivado.info:80/series/1533784/1533784/111473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25562, 1725, 'Bleach [L] S01 E149', 'http://sinalprivado.info:80/series/1533784/1533784/111474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25563, 1725, 'Bleach [L] S01 E150', 'http://sinalprivado.info:80/series/1533784/1533784/111475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25564, 1725, 'Bleach [L] S01 E151', 'http://sinalprivado.info:80/series/1533784/1533784/111476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25565, 1725, 'Bleach [L] S01 E152', 'http://sinalprivado.info:80/series/1533784/1533784/111477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25566, 1725, 'Bleach [L] S01 E153', 'http://sinalprivado.info:80/series/1533784/1533784/111478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25567, 1725, 'Bleach [L] S01 E154', 'http://sinalprivado.info:80/series/1533784/1533784/111479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25568, 1725, 'Bleach [L] S01 E155', 'http://sinalprivado.info:80/series/1533784/1533784/111480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25569, 1725, 'Bleach [L] S01 E156', 'http://sinalprivado.info:80/series/1533784/1533784/111481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25570, 1725, 'Bleach [L] S01 E157', 'http://sinalprivado.info:80/series/1533784/1533784/111482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25571, 1725, 'Bleach [L] S01 E158', 'http://sinalprivado.info:80/series/1533784/1533784/111483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25572, 1725, 'Bleach [L] S01 E159', 'http://sinalprivado.info:80/series/1533784/1533784/111484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25573, 1725, 'Bleach [L] S01 E160', 'http://sinalprivado.info:80/series/1533784/1533784/111485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25574, 1725, 'Bleach [L] S01 E161', 'http://sinalprivado.info:80/series/1533784/1533784/111486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25575, 1725, 'Bleach [L] S01 E162', 'http://sinalprivado.info:80/series/1533784/1533784/111487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25576, 1725, 'Bleach [L] S01 E163', 'http://sinalprivado.info:80/series/1533784/1533784/111488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25577, 1725, 'Bleach [L] S01 E164', 'http://sinalprivado.info:80/series/1533784/1533784/111489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25578, 1725, 'Bleach [L] S01 E165', 'http://sinalprivado.info:80/series/1533784/1533784/111490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25579, 1725, 'Bleach [L] S01 E166', 'http://sinalprivado.info:80/series/1533784/1533784/111491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25580, 1725, 'Bleach [L] S01 E167', 'http://sinalprivado.info:80/series/1533784/1533784/111492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25581, 1725, 'Bleach [L] S01 E168', 'http://sinalprivado.info:80/series/1533784/1533784/111493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25582, 1725, 'Bleach [L] S01 E169', 'http://sinalprivado.info:80/series/1533784/1533784/111494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25583, 1725, 'Bleach [L] S01 E170', 'http://sinalprivado.info:80/series/1533784/1533784/111495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25584, 1725, 'Bleach [L] S01 E171', 'http://sinalprivado.info:80/series/1533784/1533784/111496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25585, 1725, 'Bleach [L] S01 E172', 'http://sinalprivado.info:80/series/1533784/1533784/111497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25586, 1725, 'Bleach [L] S01 E173', 'http://sinalprivado.info:80/series/1533784/1533784/111498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25587, 1725, 'Bleach [L] S01 E174', 'http://sinalprivado.info:80/series/1533784/1533784/111499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25588, 1725, 'Bleach [L] S01 E175', 'http://sinalprivado.info:80/series/1533784/1533784/111500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25589, 1725, 'Bleach [L] S01 E176', 'http://sinalprivado.info:80/series/1533784/1533784/111501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25590, 1725, 'Bleach [L] S01 E177', 'http://sinalprivado.info:80/series/1533784/1533784/111502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25591, 1725, 'Bleach [L] S01 E178', 'http://sinalprivado.info:80/series/1533784/1533784/111503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25592, 1725, 'Bleach [L] S01 E179', 'http://sinalprivado.info:80/series/1533784/1533784/111504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25593, 1725, 'Bleach [L] S01 E180', 'http://sinalprivado.info:80/series/1533784/1533784/111505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25594, 1725, 'Bleach [L] S01 E181', 'http://sinalprivado.info:80/series/1533784/1533784/111506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25595, 1725, 'Bleach [L] S01 E182', 'http://sinalprivado.info:80/series/1533784/1533784/111507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25596, 1725, 'Bleach [L] S01 E183', 'http://sinalprivado.info:80/series/1533784/1533784/111508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25597, 1725, 'Bleach [L] S01 E184', 'http://sinalprivado.info:80/series/1533784/1533784/111509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25598, 1725, 'Bleach [L] S01 E185', 'http://sinalprivado.info:80/series/1533784/1533784/111510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25599, 1725, 'Bleach [L] S01 E186', 'http://sinalprivado.info:80/series/1533784/1533784/111511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25600, 1725, 'Bleach [L] S01 E187', 'http://sinalprivado.info:80/series/1533784/1533784/111512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25601, 1725, 'Bleach [L] S01 E188', 'http://sinalprivado.info:80/series/1533784/1533784/111513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25602, 1725, 'Bleach [L] S01 E189', 'http://sinalprivado.info:80/series/1533784/1533784/111514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25603, 1725, 'Bleach [L] S01 E190', 'http://sinalprivado.info:80/series/1533784/1533784/111515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25604, 1725, 'Bleach [L] S01 E191', 'http://sinalprivado.info:80/series/1533784/1533784/111516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25605, 1725, 'Bleach [L] S01 E192', 'http://sinalprivado.info:80/series/1533784/1533784/111517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25606, 1725, 'Bleach [L] S01 E193', 'http://sinalprivado.info:80/series/1533784/1533784/111518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25607, 1725, 'Bleach [L] S01 E194', 'http://sinalprivado.info:80/series/1533784/1533784/111519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25608, 1725, 'Bleach [L] S01 E195', 'http://sinalprivado.info:80/series/1533784/1533784/111520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25609, 1725, 'Bleach [L] S01 E196', 'http://sinalprivado.info:80/series/1533784/1533784/111521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25610, 1725, 'Bleach [L] S01 E197', 'http://sinalprivado.info:80/series/1533784/1533784/111522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25611, 1725, 'Bleach [L] S01 E198', 'http://sinalprivado.info:80/series/1533784/1533784/111523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25612, 1725, 'Bleach [L] S01 E199', 'http://sinalprivado.info:80/series/1533784/1533784/111524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25613, 1725, 'Bleach [L] S01 E200', 'http://sinalprivado.info:80/series/1533784/1533784/111525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25614, 1725, 'Bleach [L] S01 E201', 'http://sinalprivado.info:80/series/1533784/1533784/111526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25615, 1725, 'Bleach [L] S01 E202', 'http://sinalprivado.info:80/series/1533784/1533784/111527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25616, 1725, 'Bleach [L] S01 E203', 'http://sinalprivado.info:80/series/1533784/1533784/111528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25617, 1725, 'Bleach [L] S01 E204', 'http://sinalprivado.info:80/series/1533784/1533784/111529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25618, 1725, 'Bleach [L] S01 E205', 'http://sinalprivado.info:80/series/1533784/1533784/111530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25619, 1725, 'Bleach [L] S01 E206', 'http://sinalprivado.info:80/series/1533784/1533784/111531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25620, 1725, 'Bleach [L] S01 E207', 'http://sinalprivado.info:80/series/1533784/1533784/111532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25621, 1725, 'Bleach [L] S01 E208', 'http://sinalprivado.info:80/series/1533784/1533784/111533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25622, 1725, 'Bleach [L] S01 E209', 'http://sinalprivado.info:80/series/1533784/1533784/111534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25623, 1725, 'Bleach [L] S01 E210', 'http://sinalprivado.info:80/series/1533784/1533784/111535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25624, 1725, 'Bleach [L] S01 E211', 'http://sinalprivado.info:80/series/1533784/1533784/111536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25625, 1725, 'Bleach [L] S01 E212', 'http://sinalprivado.info:80/series/1533784/1533784/111537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25626, 1725, 'Bleach [L] S01 E213', 'http://sinalprivado.info:80/series/1533784/1533784/111538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25627, 1725, 'Bleach [L] S01 E214', 'http://sinalprivado.info:80/series/1533784/1533784/111539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25628, 1725, 'Bleach [L] S01 E215', 'http://sinalprivado.info:80/series/1533784/1533784/111540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25629, 1725, 'Bleach [L] S01 E216', 'http://sinalprivado.info:80/series/1533784/1533784/111541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25630, 1725, 'Bleach [L] S01 E217', 'http://sinalprivado.info:80/series/1533784/1533784/111542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25631, 1725, 'Bleach [L] S01 E218', 'http://sinalprivado.info:80/series/1533784/1533784/111543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25632, 1725, 'Bleach [L] S01 E219', 'http://sinalprivado.info:80/series/1533784/1533784/111544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25633, 1725, 'Bleach [L] S01 E220', 'http://sinalprivado.info:80/series/1533784/1533784/111545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25634, 1725, 'Bleach [L] S01 E221', 'http://sinalprivado.info:80/series/1533784/1533784/111546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25635, 1725, 'Bleach [L] S01 E222', 'http://sinalprivado.info:80/series/1533784/1533784/111547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25636, 1725, 'Bleach [L] S01 E223', 'http://sinalprivado.info:80/series/1533784/1533784/111548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25637, 1725, 'Bleach [L] S01 E224', 'http://sinalprivado.info:80/series/1533784/1533784/111549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25638, 1725, 'Bleach [L] S01 E225', 'http://sinalprivado.info:80/series/1533784/1533784/111550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25639, 1725, 'Bleach [L] S01 E226', 'http://sinalprivado.info:80/series/1533784/1533784/111551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25640, 1725, 'Bleach [L] S01 E227', 'http://sinalprivado.info:80/series/1533784/1533784/111552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25641, 1725, 'Bleach [L] S01 E228', 'http://sinalprivado.info:80/series/1533784/1533784/111553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25642, 1725, 'Bleach [L] S01 E229', 'http://sinalprivado.info:80/series/1533784/1533784/111554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25643, 1725, 'Bleach [L] S01 E230', 'http://sinalprivado.info:80/series/1533784/1533784/111555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25644, 1725, 'Bleach [L] S01 E231', 'http://sinalprivado.info:80/series/1533784/1533784/111556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25645, 1725, 'Bleach [L] S01 E232', 'http://sinalprivado.info:80/series/1533784/1533784/111557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25646, 1725, 'Bleach [L] S01 E233', 'http://sinalprivado.info:80/series/1533784/1533784/111558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25647, 1725, 'Bleach [L] S01 E234', 'http://sinalprivado.info:80/series/1533784/1533784/111559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25648, 1725, 'Bleach [L] S01 E235', 'http://sinalprivado.info:80/series/1533784/1533784/111560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25649, 1725, 'Bleach [L] S01 E236', 'http://sinalprivado.info:80/series/1533784/1533784/111561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25650, 1725, 'Bleach [L] S01 E237', 'http://sinalprivado.info:80/series/1533784/1533784/111562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25651, 1725, 'Bleach [L] S01 E238', 'http://sinalprivado.info:80/series/1533784/1533784/111563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25652, 1725, 'Bleach [L] S01 E239', 'http://sinalprivado.info:80/series/1533784/1533784/111564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25653, 1725, 'Bleach [L] S01 E240', 'http://sinalprivado.info:80/series/1533784/1533784/111565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25654, 1725, 'Bleach [L] S01 E241', 'http://sinalprivado.info:80/series/1533784/1533784/111566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25655, 1725, 'Bleach [L] S01 E242', 'http://sinalprivado.info:80/series/1533784/1533784/111567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25656, 1725, 'Bleach [L] S01 E243', 'http://sinalprivado.info:80/series/1533784/1533784/111568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25657, 1725, 'Bleach [L] S01 E244', 'http://sinalprivado.info:80/series/1533784/1533784/111569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25658, 1725, 'Bleach [L] S01 E245', 'http://sinalprivado.info:80/series/1533784/1533784/111570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25659, 1725, 'Bleach [L] S01 E246', 'http://sinalprivado.info:80/series/1533784/1533784/111571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25660, 1725, 'Bleach [L] S01 E247', 'http://sinalprivado.info:80/series/1533784/1533784/111572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25661, 1725, 'Bleach [L] S01 E248', 'http://sinalprivado.info:80/series/1533784/1533784/111573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25662, 1725, 'Bleach [L] S01 E249', 'http://sinalprivado.info:80/series/1533784/1533784/111574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25663, 1725, 'Bleach [L] S01 E250', 'http://sinalprivado.info:80/series/1533784/1533784/111575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25664, 1725, 'Bleach [L] S01 E251', 'http://sinalprivado.info:80/series/1533784/1533784/111576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25665, 1725, 'Bleach [L] S01 E252', 'http://sinalprivado.info:80/series/1533784/1533784/111577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25666, 1725, 'Bleach [L] S01 E253', 'http://sinalprivado.info:80/series/1533784/1533784/111578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25667, 1725, 'Bleach [L] S01 E254', 'http://sinalprivado.info:80/series/1533784/1533784/111579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25668, 1725, 'Bleach [L] S01 E255', 'http://sinalprivado.info:80/series/1533784/1533784/111580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25669, 1725, 'Bleach [L] S01 E256', 'http://sinalprivado.info:80/series/1533784/1533784/111581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25670, 1725, 'Bleach [L] S01 E257', 'http://sinalprivado.info:80/series/1533784/1533784/111582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25671, 1725, 'Bleach [L] S01 E258', 'http://sinalprivado.info:80/series/1533784/1533784/111583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25672, 1725, 'Bleach [L] S01 E259', 'http://sinalprivado.info:80/series/1533784/1533784/111584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25673, 1725, 'Bleach [L] S01 E260', 'http://sinalprivado.info:80/series/1533784/1533784/111585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25674, 1725, 'Bleach [L] S01 E261', 'http://sinalprivado.info:80/series/1533784/1533784/111586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25675, 1725, 'Bleach [L] S01 E262', 'http://sinalprivado.info:80/series/1533784/1533784/111587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25676, 1725, 'Bleach [L] S01 E263', 'http://sinalprivado.info:80/series/1533784/1533784/111588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25677, 1725, 'Bleach [L] S01 E264', 'http://sinalprivado.info:80/series/1533784/1533784/111589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25678, 1725, 'Bleach [L] S01 E265', 'http://sinalprivado.info:80/series/1533784/1533784/111590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25679, 1725, 'Bleach [L] S01 E266', 'http://sinalprivado.info:80/series/1533784/1533784/111591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25680, 1725, 'Bleach [L] S01 E267', 'http://sinalprivado.info:80/series/1533784/1533784/111592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25681, 1725, 'Bleach [L] S01 E268', 'http://sinalprivado.info:80/series/1533784/1533784/111593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25682, 1725, 'Bleach [L] S01 E269', 'http://sinalprivado.info:80/series/1533784/1533784/111594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25683, 1725, 'Bleach [L] S01 E270', 'http://sinalprivado.info:80/series/1533784/1533784/111595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25684, 1725, 'Bleach [L] S01 E271', 'http://sinalprivado.info:80/series/1533784/1533784/111596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25685, 1725, 'Bleach [L] S01 E272', 'http://sinalprivado.info:80/series/1533784/1533784/111597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25686, 1725, 'Bleach [L] S01 E273', 'http://sinalprivado.info:80/series/1533784/1533784/111598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25687, 1725, 'Bleach [L] S01 E274', 'http://sinalprivado.info:80/series/1533784/1533784/111599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25688, 1725, 'Bleach [L] S01 E275', 'http://sinalprivado.info:80/series/1533784/1533784/111600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25689, 1725, 'Bleach [L] S01 E276', 'http://sinalprivado.info:80/series/1533784/1533784/111601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25690, 1725, 'Bleach [L] S01 E277', 'http://sinalprivado.info:80/series/1533784/1533784/111602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(25691, 1725, 'Bleach [L] S01 E278', 'http://sinalprivado.info:80/series/1533784/1533784/111603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25692, 1725, 'Bleach [L] S01 E279', 'http://sinalprivado.info:80/series/1533784/1533784/111604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25693, 1725, 'Bleach [L] S01 E280', 'http://sinalprivado.info:80/series/1533784/1533784/111605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25694, 1725, 'Bleach [L] S01 E281', 'http://sinalprivado.info:80/series/1533784/1533784/111606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25695, 1725, 'Bleach [L] S01 E282', 'http://sinalprivado.info:80/series/1533784/1533784/111607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25696, 1725, 'Bleach [L] S01 E283', 'http://sinalprivado.info:80/series/1533784/1533784/111608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25697, 1725, 'Bleach [L] S01 E284', 'http://sinalprivado.info:80/series/1533784/1533784/111609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25698, 1725, 'Bleach [L] S01 E285', 'http://sinalprivado.info:80/series/1533784/1533784/111610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25699, 1725, 'Bleach [L] S01 E286', 'http://sinalprivado.info:80/series/1533784/1533784/111611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25700, 1725, 'Bleach [L] S01 E287', 'http://sinalprivado.info:80/series/1533784/1533784/111612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25701, 1725, 'Bleach [L] S01 E288', 'http://sinalprivado.info:80/series/1533784/1533784/111613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25702, 1725, 'Bleach [L] S01 E289', 'http://sinalprivado.info:80/series/1533784/1533784/111614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25703, 1725, 'Bleach [L] S01 E290', 'http://sinalprivado.info:80/series/1533784/1533784/111615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25704, 1725, 'Bleach [L] S01 E291', 'http://sinalprivado.info:80/series/1533784/1533784/111616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25705, 1725, 'Bleach [L] S01 E292', 'http://sinalprivado.info:80/series/1533784/1533784/111617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25706, 1725, 'Bleach [L] S01 E293', 'http://sinalprivado.info:80/series/1533784/1533784/111618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25707, 1725, 'Bleach [L] S01 E294', 'http://sinalprivado.info:80/series/1533784/1533784/111619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25708, 1725, 'Bleach [L] S01 E295', 'http://sinalprivado.info:80/series/1533784/1533784/111620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25709, 1725, 'Bleach [L] S01 E296', 'http://sinalprivado.info:80/series/1533784/1533784/111621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25710, 1725, 'Bleach [L] S01 E297', 'http://sinalprivado.info:80/series/1533784/1533784/111622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25711, 1725, 'Bleach [L] S01 E298', 'http://sinalprivado.info:80/series/1533784/1533784/111623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25712, 1725, 'Bleach [L] S01 E299', 'http://sinalprivado.info:80/series/1533784/1533784/111624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25713, 1725, 'Bleach [L] S01 E300', 'http://sinalprivado.info:80/series/1533784/1533784/111625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25714, 1725, 'Bleach [L] S01 E301', 'http://sinalprivado.info:80/series/1533784/1533784/111626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25715, 1725, 'Bleach [L] S01 E302', 'http://sinalprivado.info:80/series/1533784/1533784/111627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25716, 1725, 'Bleach [L] S01 E303', 'http://sinalprivado.info:80/series/1533784/1533784/111628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25717, 1725, 'Bleach [L] S01 E304', 'http://sinalprivado.info:80/series/1533784/1533784/111629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25718, 1725, 'Bleach [L] S01 E305', 'http://sinalprivado.info:80/series/1533784/1533784/111630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25719, 1725, 'Bleach [L] S01 E306', 'http://sinalprivado.info:80/series/1533784/1533784/111631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25720, 1725, 'Bleach [L] S01 E307', 'http://sinalprivado.info:80/series/1533784/1533784/111632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25721, 1725, 'Bleach [L] S01 E308', 'http://sinalprivado.info:80/series/1533784/1533784/111633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25722, 1725, 'Bleach [L] S01 E309', 'http://sinalprivado.info:80/series/1533784/1533784/111634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25723, 1725, 'Bleach [L] S01 E310', 'http://sinalprivado.info:80/series/1533784/1533784/111635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25724, 1725, 'Bleach [L] S01 E311', 'http://sinalprivado.info:80/series/1533784/1533784/111636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25725, 1725, 'Bleach [L] S01 E312', 'http://sinalprivado.info:80/series/1533784/1533784/111637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25726, 1725, 'Bleach [L] S01 E313', 'http://sinalprivado.info:80/series/1533784/1533784/111638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25727, 1725, 'Bleach [L] S01 E314', 'http://sinalprivado.info:80/series/1533784/1533784/111639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25728, 1725, 'Bleach [L] S01 E315', 'http://sinalprivado.info:80/series/1533784/1533784/111640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25729, 1725, 'Bleach [L] S01 E316', 'http://sinalprivado.info:80/series/1533784/1533784/111641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25730, 1725, 'Bleach [L] S01 E317', 'http://sinalprivado.info:80/series/1533784/1533784/111642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25731, 1725, 'Bleach [L] S01 E318', 'http://sinalprivado.info:80/series/1533784/1533784/111643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25732, 1725, 'Bleach [L] S01 E319', 'http://sinalprivado.info:80/series/1533784/1533784/111644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25733, 1725, 'Bleach [L] S01 E320', 'http://sinalprivado.info:80/series/1533784/1533784/111645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25734, 1725, 'Bleach [L] S01 E321', 'http://sinalprivado.info:80/series/1533784/1533784/111646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25735, 1725, 'Bleach [L] S01 E322', 'http://sinalprivado.info:80/series/1533784/1533784/111647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25736, 1725, 'Bleach [L] S01 E323', 'http://sinalprivado.info:80/series/1533784/1533784/111648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25737, 1725, 'Bleach [L] S01 E324', 'http://sinalprivado.info:80/series/1533784/1533784/111649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25738, 1725, 'Bleach [L] S01 E325', 'http://sinalprivado.info:80/series/1533784/1533784/111650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25739, 1725, 'Bleach [L] S01 E326', 'http://sinalprivado.info:80/series/1533784/1533784/111651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25740, 1725, 'Bleach [L] S01 E327', 'http://sinalprivado.info:80/series/1533784/1533784/111652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25741, 1725, 'Bleach [L] S01 E328', 'http://sinalprivado.info:80/series/1533784/1533784/111653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25742, 1725, 'Bleach [L] S01 E329', 'http://sinalprivado.info:80/series/1533784/1533784/111654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25743, 1725, 'Bleach [L] S01 E330', 'http://sinalprivado.info:80/series/1533784/1533784/111655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25744, 1725, 'Bleach [L] S01 E331', 'http://sinalprivado.info:80/series/1533784/1533784/111656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25745, 1725, 'Bleach [L] S01 E332', 'http://sinalprivado.info:80/series/1533784/1533784/111657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25746, 1725, 'Bleach [L] S01 E333', 'http://sinalprivado.info:80/series/1533784/1533784/111658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25747, 1725, 'Bleach [L] S01 E334', 'http://sinalprivado.info:80/series/1533784/1533784/111659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25748, 1725, 'Bleach [L] S01 E335', 'http://sinalprivado.info:80/series/1533784/1533784/111660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25749, 1725, 'Bleach [L] S01 E336', 'http://sinalprivado.info:80/series/1533784/1533784/111661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25750, 1725, 'Bleach [L] S01 E337', 'http://sinalprivado.info:80/series/1533784/1533784/111662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25751, 1725, 'Bleach [L] S01 E338', 'http://sinalprivado.info:80/series/1533784/1533784/111663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25752, 1725, 'Bleach [L] S01 E339', 'http://sinalprivado.info:80/series/1533784/1533784/111664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25753, 1725, 'Bleach [L] S01 E340', 'http://sinalprivado.info:80/series/1533784/1533784/111665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25754, 1725, 'Bleach [L] S01 E341', 'http://sinalprivado.info:80/series/1533784/1533784/111666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25755, 1725, 'Bleach [L] S01 E342', 'http://sinalprivado.info:80/series/1533784/1533784/111667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25756, 1725, 'Bleach [L] S01 E343', 'http://sinalprivado.info:80/series/1533784/1533784/111668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25757, 1725, 'Bleach [L] S01 E344', 'http://sinalprivado.info:80/series/1533784/1533784/111669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25758, 1725, 'Bleach [L] S01 E345', 'http://sinalprivado.info:80/series/1533784/1533784/111670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25759, 1725, 'Bleach [L] S01 E346', 'http://sinalprivado.info:80/series/1533784/1533784/111671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25760, 1725, 'Bleach [L] S01 E347', 'http://sinalprivado.info:80/series/1533784/1533784/111672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25761, 1725, 'Bleach [L] S01 E348', 'http://sinalprivado.info:80/series/1533784/1533784/111673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25762, 1725, 'Bleach [L] S01 E349', 'http://sinalprivado.info:80/series/1533784/1533784/111674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25763, 1725, 'Bleach [L] S01 E350', 'http://sinalprivado.info:80/series/1533784/1533784/111675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25764, 1725, 'Bleach [L] S01 E351', 'http://sinalprivado.info:80/series/1533784/1533784/111676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25765, 1725, 'Bleach [L] S01 E352', 'http://sinalprivado.info:80/series/1533784/1533784/111677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25766, 1725, 'Bleach [L] S01 E353', 'http://sinalprivado.info:80/series/1533784/1533784/111678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25767, 1725, 'Bleach [L] S01 E354', 'http://sinalprivado.info:80/series/1533784/1533784/111679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25768, 1725, 'Bleach [L] S01 E355', 'http://sinalprivado.info:80/series/1533784/1533784/111680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25769, 1725, 'Bleach [L] S01 E356', 'http://sinalprivado.info:80/series/1533784/1533784/111681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25770, 1725, 'Bleach [L] S01 E357', 'http://sinalprivado.info:80/series/1533784/1533784/111682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25771, 1725, 'Bleach [L] S01 E358', 'http://sinalprivado.info:80/series/1533784/1533784/111683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25772, 1725, 'Bleach [L] S01 E359', 'http://sinalprivado.info:80/series/1533784/1533784/111684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25773, 1726, 'Bleach [L] S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/702945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25774, 1726, 'Bleach [L] S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/702946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25775, 1726, 'Bleach [L] S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/702947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25776, 1726, 'Bleach [L] S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/702948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25777, 1726, 'Bleach [L] S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/702949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25778, 1726, 'Bleach [L] S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/702950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25779, 1726, 'Bleach [L] S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/702951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25780, 1726, 'Bleach [L] S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/702952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25781, 1726, 'Bleach [L] S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/702953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25782, 1726, 'Bleach [L] S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/702954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25783, 1726, 'Bleach [L] S17 E11', 'http://sinalprivado.info:80/series/1533784/1533784/702955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25784, 1726, 'Bleach [L] S17 E12', 'http://sinalprivado.info:80/series/1533784/1533784/702956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25785, 1726, 'Bleach [L] S17 E13', 'http://sinalprivado.info:80/series/1533784/1533784/702957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25786, 1726, 'Bleach [L] S17 E14', 'http://sinalprivado.info:80/series/1533784/1533784/702958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25787, 1726, 'Bleach [L] S17 E15', 'http://sinalprivado.info:80/series/1533784/1533784/702959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25788, 1726, 'Bleach [L] S17 E16', 'http://sinalprivado.info:80/series/1533784/1533784/702960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25789, 1726, 'Bleach [L] S17 E17', 'http://sinalprivado.info:80/series/1533784/1533784/702961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25790, 1726, 'Bleach [L] S17 E18', 'http://sinalprivado.info:80/series/1533784/1533784/702962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25791, 1726, 'Bleach [L] S17 E19', 'http://sinalprivado.info:80/series/1533784/1533784/702963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25792, 1726, 'Bleach [L] S17 E20', 'http://sinalprivado.info:80/series/1533784/1533784/702964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25793, 1726, 'Bleach [L] S17 E21', 'http://sinalprivado.info:80/series/1533784/1533784/702965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25794, 1726, 'Bleach [L] S17 E22', 'http://sinalprivado.info:80/series/1533784/1533784/702966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25795, 1726, 'Bleach [L] S17 E23', 'http://sinalprivado.info:80/series/1533784/1533784/702967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25796, 1726, 'Bleach [L] S17 E24', 'http://sinalprivado.info:80/series/1533784/1533784/702968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25797, 1726, 'Bleach [L] S17 E25', 'http://sinalprivado.info:80/series/1533784/1533784/702969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25798, 1726, 'Bleach [L] S17 E26', 'http://sinalprivado.info:80/series/1533784/1533784/702970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25799, 1726, 'Bleach [L] S17 E27', 'http://sinalprivado.info:80/series/1533784/1533784/702971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25800, 1726, 'Bleach [L] S17 E28', 'http://sinalprivado.info:80/series/1533784/1533784/702972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25801, 1726, 'Bleach [L] S17 E29', 'http://sinalprivado.info:80/series/1533784/1533784/702973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25802, 1726, 'Bleach [L] S17 E30', 'http://sinalprivado.info:80/series/1533784/1533784/702974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25803, 1726, 'Bleach [L] S17 E31', 'http://sinalprivado.info:80/series/1533784/1533784/702975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25804, 1726, 'Bleach [L] S17 E32', 'http://sinalprivado.info:80/series/1533784/1533784/702976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25805, 1726, 'Bleach [L] S17 E33', 'http://sinalprivado.info:80/series/1533784/1533784/702977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25806, 1726, 'Bleach [L] S17 E34', 'http://sinalprivado.info:80/series/1533784/1533784/702978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25807, 1726, 'Bleach [L] S17 E35', 'http://sinalprivado.info:80/series/1533784/1533784/702979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25808, 1726, 'Bleach [L] S17 E36', 'http://sinalprivado.info:80/series/1533784/1533784/702980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25809, 1726, 'Bleach [L] S17 E37', 'http://sinalprivado.info:80/series/1533784/1533784/702981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25810, 1726, 'Bleach [L] S17 E38', 'http://sinalprivado.info:80/series/1533784/1533784/702982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25811, 1726, 'Bleach [L] S17 E39', 'http://sinalprivado.info:80/series/1533784/1533784/702983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25812, 1726, 'Bleach [L] S17 E40', 'http://sinalprivado.info:80/series/1533784/1533784/702984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mB6h4mlZXufkWtt58Bh1DiVvNgv.jpg'),
(25813, 1727, 'Meu País: A Nova Era [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111310.mp4', 'http://timg.bdta.pro/images/1d5e4746ed715d85e2084a6c9c422e66.jpg'),
(25814, 1727, 'Meu País: A Nova Era [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111311.mp4', 'http://timg.bdta.pro/images/48f4249c5570a77bda40cf0fb9491b8b.jpg'),
(25815, 1727, 'Meu País: A Nova Era [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111312.mp4', 'http://gstaticontent.com/images/juSfxfhGm88z38mqO1xar1lmYI2_big.jpg'),
(25816, 1727, 'Meu País: A Nova Era [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111313.mp4', 'http://gstaticontent.com/images/juSfxfhGm88z38mqO1xar1lmYI2_big.jpg'),
(25817, 1727, 'Meu País: A Nova Era [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111314.mp4', 'http://gstaticontent.com/images/juSfxfhGm88z38mqO1xar1lmYI2_big.jpg'),
(25818, 1727, 'Meu País: A Nova Era [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/111315.mp4', 'http://gstaticontent.com/images/juSfxfhGm88z38mqO1xar1lmYI2_big.jpg'),
(25819, 1727, 'Meu País: A Nova Era [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/111316.mp4', 'http://gstaticontent.com/images/juSfxfhGm88z38mqO1xar1lmYI2_big.jpg'),
(25820, 1727, 'Meu País: A Nova Era [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/111317.mp4', 'http://gstaticontent.com/images/juSfxfhGm88z38mqO1xar1lmYI2_big.jpg'),
(25821, 1727, 'Meu País: A Nova Era [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/111318.mp4', 'http://timg.bdta.pro/images/85f40934ff1f7175d09c8a7a23ff461d.jpg'),
(25822, 1727, 'Meu País: A Nova Era [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/111319.mp4', 'http://timg.bdta.pro/images/6035f189776c1a5eba6e289338d57625.jpg'),
(25823, 1727, 'Meu País: A Nova Era [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/111320.mp4', 'http://timg.bdta.pro/images/7d94feae025506152d4adeff7b7d7ab4.jpg'),
(25824, 1727, 'Meu País: A Nova Era [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/111321.mp4', 'http://timg.bdta.pro/images/a0165fd7ea48e93a1f6cb5a4b506dd62.jpg'),
(25825, 1727, 'Meu País: A Nova Era [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/111322.mp4', 'http://timg.bdta.pro/images/e1bdb4c418bab5892d52fbbb79414ba4.jpg'),
(25826, 1727, 'Meu País: A Nova Era [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/111323.mp4', 'http://timg.bdta.pro/images/bc0f4cbb9550540ff501edc374e7677c.jpg'),
(25827, 1727, 'Meu País: A Nova Era [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/111324.mp4', 'http://timg.bdta.pro/images/7948175aedba3164d067c5dae03d5bef.jpg'),
(25828, 1727, 'Meu País: A Nova Era [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/111325.mp4', 'http://timg.bdta.pro/images/51651a9d42333985b13e231e9cf69916.jpg'),
(25829, 1728, 'Toy Boy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172117.mp4', 'http://timg.bdta.pro/images/26f46a8eb21fc295112d8fb09c4a0c1a.jpg'),
(25830, 1728, 'Toy Boy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172118.mp4', 'http://timg.bdta.pro/images/cf943bc34c61e93170250aaad222ee50.jpg'),
(25831, 1728, 'Toy Boy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172119.mp4', 'http://timg.bdta.pro/images/db29761a7d63aeb01b09d6cb802ada38.jpg'),
(25832, 1728, 'Toy Boy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172120.mp4', 'http://timg.bdta.pro/images/6ed4d5348be4b88d933a1143f68d2779.jpg'),
(25833, 1728, 'Toy Boy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172121.mp4', 'http://timg.bdta.pro/images/112e9ee9751dde240b10f7541449f202.jpg'),
(25834, 1728, 'Toy Boy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172122.mp4', 'http://timg.bdta.pro/images/4f8d7ad0c4ae91115d9cbcb0fece4279.jpg'),
(25835, 1728, 'Toy Boy S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172123.mp4', 'http://timg.bdta.pro/images/371e3079e462211491185d3fdea3ce39.jpg'),
(25836, 1728, 'Toy Boy S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172124.mp4', 'http://timg.bdta.pro/images/d2c1c9d78efe717122a037d36a9a072a.jpg'),
(25837, 1728, 'Toy Boy S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172125.mp4', 'http://timg.bdta.pro/images/28d3514ad3a0fd5aad8ac9d8e1864a73.jpg'),
(25838, 1728, 'Toy Boy S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172126.mp4', 'http://timg.bdta.pro/images/c43563e36f97b2b36cf69253c07ed590.jpg'),
(25839, 1728, 'Toy Boy S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172127.mp4', 'http://timg.bdta.pro/images/de10de255d1232c14f88e98f2ae3de7f.jpg'),
(25840, 1728, 'Toy Boy S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172128.mp4', 'http://timg.bdta.pro/images/e09b996f18ef837bb3ba23136c9a8c76.jpg'),
(25841, 1728, 'Toy Boy S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172129.mp4', 'http://timg.bdta.pro/images/65f26975052d387e515d9b69e8bbb642.jpg'),
(25842, 1729, 'Toy Boy S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172130.mp4', 'http://timg.bdta.pro/images/7eb583dc03e17bd0138a8ee7aedc9c43.jpg'),
(25843, 1729, 'Toy Boy S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172131.mp4', 'http://timg.bdta.pro/images/4e6dd84ab58b0258e2e58a6a4f5633d0.jpg'),
(25844, 1729, 'Toy Boy S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172132.mp4', 'http://timg.bdta.pro/images/d67a78a6876bc04b0778f4e5f28444b6.jpg'),
(25845, 1729, 'Toy Boy S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172133.mp4', 'http://timg.bdta.pro/images/18866a973a850a65c0fc469bc544b599.jpg'),
(25846, 1729, 'Toy Boy S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172134.mp4', 'http://timg.bdta.pro/images/4f54d6df0e18450b00cea7702b16d312.jpg'),
(25847, 1729, 'Toy Boy S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172135.mp4', 'http://timg.bdta.pro/images/0123484526f77ae0e357c4b1b0a56ad0.jpg'),
(25848, 1729, 'Toy Boy S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172136.mp4', 'http://timg.bdta.pro/images/77430a08e2b91e28d368d24de4de5348.jpg'),
(25849, 1729, 'Toy Boy S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172137.mp4', 'http://timg.bdta.pro/images/46598c83c09d3247813b6f99b3b0b3b6.jpg'),
(25850, 1730, 'Bebês em Foco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111286.mp4', 'http://gstaticontent.com/images/8PJPBuXuntEpQg1wB4mL5fPTq1k_big.jpg'),
(25851, 1730, 'Bebês em Foco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111287.mp4', 'http://gstaticontent.com/images/8PJPBuXuntEpQg1wB4mL5fPTq1k_big.jpg'),
(25852, 1730, 'Bebês em Foco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111288.mp4', 'http://gstaticontent.com/images/8PJPBuXuntEpQg1wB4mL5fPTq1k_big.jpg'),
(25853, 1730, 'Bebês em Foco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111289.mp4', 'http://gstaticontent.com/images/8PJPBuXuntEpQg1wB4mL5fPTq1k_big.jpg'),
(25854, 1730, 'Bebês em Foco S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111290.mp4', 'http://gstaticontent.com/images/8PJPBuXuntEpQg1wB4mL5fPTq1k_big.jpg'),
(25855, 1730, 'Bebês em Foco S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/111291.mp4', 'http://gstaticontent.com/images/8PJPBuXuntEpQg1wB4mL5fPTq1k_big.jpg'),
(25856, 1731, 'Formula 1: Dirigir para Viver S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207093.mp4', 'http://timg.bdta.pro/images/49365ca8715aec186b16ac5eb38454b0.jpg'),
(25857, 1731, 'Formula 1: Dirigir para Viver S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207094.mp4', 'http://timg.bdta.pro/images/e2b6970faef549f006c0f298a5f90929.jpg'),
(25858, 1731, 'Formula 1: Dirigir para Viver S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207095.mp4', 'http://timg.bdta.pro/images/046966a3a559a56f82fb39e6de2dee67.jpg'),
(25859, 1731, 'Formula 1: Dirigir para Viver S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207096.mp4', 'http://timg.bdta.pro/images/c65f556c042d15580343223b86e4321a.jpg'),
(25860, 1731, 'Formula 1: Dirigir para Viver S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207097.mp4', 'http://timg.bdta.pro/images/461499c14a698438b9ea3002daba9d69.jpg'),
(25861, 1731, 'Formula 1: Dirigir para Viver S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207098.mp4', 'http://timg.bdta.pro/images/348546fcb60b76f052558fa5dacf3b90.jpg'),
(25862, 1731, 'Formula 1: Dirigir para Viver S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207099.mp4', 'http://timg.bdta.pro/images/bb63d7346413969806db2323c3c3fe09.jpg'),
(25863, 1731, 'Formula 1: Dirigir para Viver S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207100.mp4', 'http://timg.bdta.pro/images/c45710b1b49e02039e16ad24df92ba99.jpg'),
(25864, 1731, 'Formula 1: Dirigir para Viver S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207101.mp4', 'http://timg.bdta.pro/images/13bd2fb972e18a01b5ed4f4924cabddd.jpg'),
(25865, 1731, 'Formula 1: Dirigir para Viver S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207102.mp4', 'http://timg.bdta.pro/images/ed334d70a7432810363aade346b9baec.jpg'),
(25866, 1732, 'Formula 1: Dirigir para Viver S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207103.mp4', 'http://timg.bdta.pro/images/f2ebcd3f97a40e4da3bd4a9b256150fa.jpg'),
(25867, 1732, 'Formula 1: Dirigir para Viver S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207104.mp4', 'http://timg.bdta.pro/images/bf45d45fc11bfdc27d41709e1559f03b.jpg'),
(25868, 1732, 'Formula 1: Dirigir para Viver S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207105.mp4', 'http://timg.bdta.pro/images/6e5b37ff203d3e3f888dd24300ce278e.jpg'),
(25869, 1732, 'Formula 1: Dirigir para Viver S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207106.mp4', 'http://timg.bdta.pro/images/b9e98b52a5193939adb498d8cbd3626e.jpg'),
(25870, 1732, 'Formula 1: Dirigir para Viver S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207107.mp4', 'http://timg.bdta.pro/images/d5f150b40dcf319107d00f38405a4d65.jpg'),
(25871, 1732, 'Formula 1: Dirigir para Viver S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207108.mp4', 'http://timg.bdta.pro/images/b2974c4221cde0a830220f7c1e4c42ca.jpg'),
(25872, 1732, 'Formula 1: Dirigir para Viver S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207109.mp4', 'http://timg.bdta.pro/images/24454de026e591c8a8a8113e40e35d21.jpg'),
(25873, 1732, 'Formula 1: Dirigir para Viver S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207110.mp4', 'http://timg.bdta.pro/images/5ea0ef3cba4d90306166f460379f58c6.jpg'),
(25874, 1732, 'Formula 1: Dirigir para Viver S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207111.mp4', 'http://timg.bdta.pro/images/2550aff493b8f3a7aef033ae1bce64ec.jpg'),
(25875, 1732, 'Formula 1: Dirigir para Viver S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207112.mp4', 'http://timg.bdta.pro/images/2aad3bc9c955595376182e9e002e8633.jpg'),
(25876, 1733, 'Formula 1: Dirigir para Viver S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207113.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25877, 1733, 'Formula 1: Dirigir para Viver S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207114.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25878, 1733, 'Formula 1: Dirigir para Viver S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207115.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25879, 1733, 'Formula 1: Dirigir para Viver S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207116.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25880, 1733, 'Formula 1: Dirigir para Viver S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207117.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25881, 1733, 'Formula 1: Dirigir para Viver S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207118.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25882, 1733, 'Formula 1: Dirigir para Viver S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207119.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25883, 1733, 'Formula 1: Dirigir para Viver S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207120.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25884, 1733, 'Formula 1: Dirigir para Viver S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207121.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25885, 1733, 'Formula 1: Dirigir para Viver S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207122.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25886, 1734, 'Formula 1: Dirigir para Viver S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207123.mp4', 'http://timg.bdta.pro/images/176fab0d30149dcee8c35f35e29ee573.jpg'),
(25887, 1734, 'Formula 1: Dirigir para Viver S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207124.mp4', 'http://timg.bdta.pro/images/e7560d3a7c9b4a8bbc63fa3c5d838d6d.jpg'),
(25888, 1734, 'Formula 1: Dirigir para Viver S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207125.mp4', 'http://timg.bdta.pro/images/70967aa75544acb52de0bdc79622373f.jpg'),
(25889, 1734, 'Formula 1: Dirigir para Viver S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207126.mp4', 'http://timg.bdta.pro/images/7314b6eae684d28bf88a8043686d9117.jpg'),
(25890, 1734, 'Formula 1: Dirigir para Viver S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207127.mp4', 'http://timg.bdta.pro/images/ee8427d2c19efcb7ab0c05c3e3b130ef.jpg'),
(25891, 1734, 'Formula 1: Dirigir para Viver S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207128.mp4', 'http://timg.bdta.pro/images/c5e59bd46535f1acac5c53bfe8c1da2f.jpg'),
(25892, 1734, 'Formula 1: Dirigir para Viver S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207129.mp4', 'http://timg.bdta.pro/images/c118b91a7c18f20c698837fa324eb1a0.jpg'),
(25893, 1734, 'Formula 1: Dirigir para Viver S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207130.mp4', 'http://timg.bdta.pro/images/9397f7ec3764190181457b69faba6a1f.jpg'),
(25894, 1734, 'Formula 1: Dirigir para Viver S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207131.mp4', 'http://timg.bdta.pro/images/a71c402b05ffb95c55f4ca7b5d197359.jpg'),
(25895, 1734, 'Formula 1: Dirigir para Viver S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207132.mp4', 'http://timg.bdta.pro/images/8d017f691cbe87fa58ed3f9fd741ea55.jpg'),
(25896, 1735, 'Formula 1: Dirigir para Viver S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/64goSMENABVHVgPKf5x92qkY5UG.jpg'),
(25897, 1735, 'Formula 1: Dirigir para Viver S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r0LtlZGdERaKfLHka4HAHDkK62o.jpg'),
(25898, 1735, 'Formula 1: Dirigir para Viver S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pl9fDqON09SkFvjgnwBakRduk1.jpg'),
(25899, 1735, 'Formula 1: Dirigir para Viver S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cA64ZDiMH5xfUytmM3n20WhyNtc.jpg'),
(25900, 1735, 'Formula 1: Dirigir para Viver S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y3xMP2FqIDEqkxTgTdhBwtsMfdM.jpg'),
(25901, 1735, 'Formula 1: Dirigir para Viver S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhdFHmBQW0mOx6KfpWpDdHymBqj.jpg'),
(25902, 1735, 'Formula 1: Dirigir para Viver S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dAhHXLso3Zc5PCzyRt0aPGS935e.jpg'),
(25903, 1735, 'Formula 1: Dirigir para Viver S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aJUY9cKxgaOzyT8GofcLwMEDbMm.jpg'),
(25904, 1735, 'Formula 1: Dirigir para Viver S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAaUyAoJpoGHm1Ejb3DjZxmad6x.jpg'),
(25905, 1735, 'Formula 1: Dirigir para Viver S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AfIJDDx6qs3IdQGNWXOmJJ3vF9.jpg'),
(25906, 1736, 'Formula 1: Dirigir para Viver S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/593523.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25907, 1736, 'Formula 1: Dirigir para Viver S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282505.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25908, 1736, 'Formula 1: Dirigir para Viver S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/282506.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25909, 1736, 'Formula 1: Dirigir para Viver S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/282507.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25910, 1736, 'Formula 1: Dirigir para Viver S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282508.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25911, 1736, 'Formula 1: Dirigir para Viver S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/282509.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25912, 1736, 'Formula 1: Dirigir para Viver S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282510.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25913, 1736, 'Formula 1: Dirigir para Viver S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/282511.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25914, 1736, 'Formula 1: Dirigir para Viver S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/282512.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25915, 1736, 'Formula 1: Dirigir para Viver S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/282513.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25916, 1737, 'Formula 1: Dirigir para Viver S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/718244.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25917, 1737, 'Formula 1: Dirigir para Viver S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/718245.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25918, 1737, 'Formula 1: Dirigir para Viver S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/718246.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25919, 1737, 'Formula 1: Dirigir para Viver S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/718247.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25920, 1737, 'Formula 1: Dirigir para Viver S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/718248.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25921, 1737, 'Formula 1: Dirigir para Viver S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/718249.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25922, 1737, 'Formula 1: Dirigir para Viver S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/718250.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25923, 1737, 'Formula 1: Dirigir para Viver S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/718251.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25924, 1737, 'Formula 1: Dirigir para Viver S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/718252.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25925, 1737, 'Formula 1: Dirigir para Viver S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/718253.mp4', 'http://gstaticontent.com/images/yzansALXnS7R7e8Qikdz1xAVJfp_big.jpg'),
(25926, 1738, 'Queen Sono S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111280.mp4', 'http://timg.bdta.pro/images/331a9fd1fb60ab37bb2b5b27c5baa5db.jpg'),
(25927, 1738, 'Queen Sono S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111281.mp4', 'http://timg.bdta.pro/images/59e76097752677e6fef52dae76b5df76.jpg'),
(25928, 1738, 'Queen Sono S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111282.mp4', 'http://timg.bdta.pro/images/0814509b505f9d8e405c2cf72df7b058.jpg'),
(25929, 1738, 'Queen Sono S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111283.mp4', 'http://timg.bdta.pro/images/cb04a72bc4ed6c5a9c47d77ee6047b8e.jpg'),
(25930, 1738, 'Queen Sono S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111284.mp4', 'http://timg.bdta.pro/images/ae58fcb8d48035a9c967d2d9ced7bb0d.jpg'),
(25931, 1738, 'Queen Sono S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/111285.mp4', 'http://timg.bdta.pro/images/5cb48eb75864a6d8817fac37f8722e0b.jpg'),
(25932, 1739, 'Restaurantes em Risco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111274.mp4', 'http://timg.bdta.pro/images/4766333eb95ba4d2e0dd1d14abc619d4.jpg'),
(25933, 1739, 'Restaurantes em Risco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111275.mp4', 'http://timg.bdta.pro/images/ad0e3bea6dead24ee1257bbf864c3e88.jpg'),
(25934, 1739, 'Restaurantes em Risco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111276.mp4', 'http://timg.bdta.pro/images/0003c477054a2ab143d57d2a4569a2c7.jpg'),
(25935, 1739, 'Restaurantes em Risco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111277.mp4', 'http://timg.bdta.pro/images/3ba2d2d1666eb375b94776a0670a80fe.jpg'),
(25936, 1739, 'Restaurantes em Risco S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111278.mp4', 'http://timg.bdta.pro/images/4a170bc815236274da8759750f4b017d.jpg'),
(25937, 1739, 'Restaurantes em Risco S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/111279.mp4', 'http://timg.bdta.pro/images/579c7eb1ce066282bf09c60f71b786e5.jpg'),
(25938, 1740, 'Sempre Bruxa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111256.mp4', 'http://timg.bdta.pro/images/5651d82fad48071f64a9b7ec36fc4255.jpg'),
(25939, 1740, 'Sempre Bruxa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111257.mp4', 'http://timg.bdta.pro/images/4940445242c40e927f6ebc93d26210f9.jpg'),
(25940, 1740, 'Sempre Bruxa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111258.mp4', 'http://timg.bdta.pro/images/7b34afbcad3a4e00b74bfb6509cc7c9c.jpg'),
(25941, 1740, 'Sempre Bruxa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111259.mp4', 'http://timg.bdta.pro/images/a97bf526d23df3b701d8bbcbae9d553c.jpg'),
(25942, 1740, 'Sempre Bruxa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111260.mp4', 'http://timg.bdta.pro/images/f1573a1a045aab65c847ee342268bcd8.jpg'),
(25943, 1740, 'Sempre Bruxa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/111261.mp4', 'http://timg.bdta.pro/images/9efd5be0365eff6c02cc235f6100bfd9.jpg'),
(25944, 1740, 'Sempre Bruxa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/111262.mp4', 'http://timg.bdta.pro/images/9d9e599ebcea83e2449480c1246308db.jpg'),
(25945, 1740, 'Sempre Bruxa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/111263.mp4', 'http://timg.bdta.pro/images/5e7f3dd27632857288358e92c8002233.jpg'),
(25946, 1740, 'Sempre Bruxa S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/111264.mp4', 'http://timg.bdta.pro/images/36c49c6df8d5932bb4f30823f11d7a5c.jpg'),
(25947, 1740, 'Sempre Bruxa S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/111265.mp4', 'http://timg.bdta.pro/images/d7bab157bc262e86be61f0ee2d8ac8a8.jpg'),
(25948, 1741, 'Sempre Bruxa S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111266.mp4', 'http://timg.bdta.pro/images/d7bab157bc262e86be61f0ee2d8ac8a8.jpg'),
(25949, 1741, 'Sempre Bruxa S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111267.mp4', 'http://timg.bdta.pro/images/d7bab157bc262e86be61f0ee2d8ac8a8.jpg'),
(25950, 1741, 'Sempre Bruxa S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111268.mp4', 'http://timg.bdta.pro/images/d7bab157bc262e86be61f0ee2d8ac8a8.jpg'),
(25951, 1741, 'Sempre Bruxa S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111269.mp4', 'http://timg.bdta.pro/images/d7bab157bc262e86be61f0ee2d8ac8a8.jpg'),
(25952, 1741, 'Sempre Bruxa S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111270.mp4', 'http://timg.bdta.pro/images/d7bab157bc262e86be61f0ee2d8ac8a8.jpg'),
(25953, 1741, 'Sempre Bruxa S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/111271.mp4', 'http://timg.bdta.pro/images/d7bab157bc262e86be61f0ee2d8ac8a8.jpg'),
(25954, 1741, 'Sempre Bruxa S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/111272.mp4', 'http://timg.bdta.pro/images/d7bab157bc262e86be61f0ee2d8ac8a8.jpg'),
(25955, 1741, 'Sempre Bruxa S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/111273.mp4', 'http://timg.bdta.pro/images/d7bab157bc262e86be61f0ee2d8ac8a8.jpg'),
(25956, 1742, 'Monstro do Pântano S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135126.mp4', 'http://gstaticontent.com/images/sWv8T2WlSrmssqQ4egi9oE4g237_big.jpg'),
(25957, 1742, 'Monstro do Pântano S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135127.mp4', 'http://gstaticontent.com/images/sWv8T2WlSrmssqQ4egi9oE4g237_big.jpg'),
(25958, 1742, 'Monstro do Pântano S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135128.mp4', 'http://gstaticontent.com/images/sWv8T2WlSrmssqQ4egi9oE4g237_big.jpg'),
(25959, 1742, 'Monstro do Pântano S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135129.mp4', 'http://gstaticontent.com/images/sWv8T2WlSrmssqQ4egi9oE4g237_big.jpg'),
(25960, 1742, 'Monstro do Pântano S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135130.mp4', 'http://gstaticontent.com/images/sWv8T2WlSrmssqQ4egi9oE4g237_big.jpg'),
(25961, 1742, 'Monstro do Pântano S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135131.mp4', 'http://gstaticontent.com/images/sWv8T2WlSrmssqQ4egi9oE4g237_big.jpg'),
(25962, 1742, 'Monstro do Pântano S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135132.mp4', 'http://gstaticontent.com/images/sWv8T2WlSrmssqQ4egi9oE4g237_big.jpg'),
(25963, 1742, 'Monstro do Pântano S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135133.mp4', 'http://gstaticontent.com/images/sWv8T2WlSrmssqQ4egi9oE4g237_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(25964, 1742, 'Monstro do Pântano S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135134.mp4', 'http://gstaticontent.com/images/sWv8T2WlSrmssqQ4egi9oE4g237_big.jpg'),
(25965, 1742, 'Monstro do Pântano S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135135.mp4', 'http://gstaticontent.com/images/sWv8T2WlSrmssqQ4egi9oE4g237_big.jpg'),
(25966, 1743, 'Virgin River S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249612.mp4', 'http://timg.bdta.pro/images/211788a534434dcb891e61118c4c84c8.jpg'),
(25967, 1743, 'Virgin River S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249613.mp4', 'http://timg.bdta.pro/images/eb2435411793f7e2b84ff1e4b52cee34.jpg'),
(25968, 1743, 'Virgin River S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249614.mp4', 'http://timg.bdta.pro/images/ae52084866d621f9336050d6b2446677.jpg'),
(25969, 1743, 'Virgin River S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249615.mp4', 'http://timg.bdta.pro/images/b63c04087b6ca323bc2c95aac4968252.jpg'),
(25970, 1743, 'Virgin River S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249616.mp4', 'http://timg.bdta.pro/images/7761176c0a0bd90521eefd2c5ef71086.jpg'),
(25971, 1743, 'Virgin River S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249617.mp4', 'http://timg.bdta.pro/images/3e518581e97fe7e5932d7aba4f98d49a.jpg'),
(25972, 1743, 'Virgin River S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249618.mp4', 'http://timg.bdta.pro/images/651986ac021e8da5e1e5375f721c3177.jpg'),
(25973, 1743, 'Virgin River S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249619.mp4', 'http://timg.bdta.pro/images/11aaff7f5158c0bccee46dc77b05b9b8.jpg'),
(25974, 1743, 'Virgin River S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249620.mp4', 'http://timg.bdta.pro/images/d2768bea0ba0ff5cb0ec30f38df8df4b.jpg'),
(25975, 1743, 'Virgin River S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249621.mp4', 'http://timg.bdta.pro/images/52893945aed8d584216bfc0b7a87b217.jpg'),
(25976, 1744, 'Virgin River S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249622.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(25977, 1744, 'Virgin River S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249623.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(25978, 1744, 'Virgin River S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249624.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(25979, 1744, 'Virgin River S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249625.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(25980, 1744, 'Virgin River S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249626.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(25981, 1744, 'Virgin River S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249627.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(25982, 1744, 'Virgin River S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249628.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(25983, 1744, 'Virgin River S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249629.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(25984, 1744, 'Virgin River S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249630.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(25985, 1744, 'Virgin River S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249631.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(25986, 1745, 'Virgin River S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249632.mp4', 'http://timg.bdta.pro/images/5082f6edacbece0530ee93d3188f7930.jpg'),
(25987, 1745, 'Virgin River S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249633.mp4', 'http://timg.bdta.pro/images/92c1d9338676798d9bb49c87e9a22cb2.jpg'),
(25988, 1745, 'Virgin River S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249634.mp4', 'http://timg.bdta.pro/images/793bf8daabe3ba20f440b00844136ad5.jpg'),
(25989, 1745, 'Virgin River S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249635.mp4', 'http://timg.bdta.pro/images/9eeb1d85eb404a81b0849094ce1d76d3.jpg'),
(25990, 1745, 'Virgin River S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249636.mp4', 'http://timg.bdta.pro/images/cb8b7c474c398a5d60c6574941cdb291.jpg'),
(25991, 1745, 'Virgin River S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249637.mp4', 'http://timg.bdta.pro/images/114730c6a7bf4eb245b23ef078b9b703.jpg'),
(25992, 1745, 'Virgin River S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249638.mp4', 'http://timg.bdta.pro/images/da27a06cf923ef3a5ef69ba62506b4e9.jpg'),
(25993, 1745, 'Virgin River S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249639.mp4', 'http://timg.bdta.pro/images/d4b4e4670f0a092a4cb79bee089f48f2.jpg'),
(25994, 1745, 'Virgin River S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249640.mp4', 'http://timg.bdta.pro/images/bb2e20d9292fcbd7627bfc0e1b299c2b.jpg'),
(25995, 1745, 'Virgin River S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249641.mp4', 'http://timg.bdta.pro/images/60c7965e677d74eda6490e2370fb6340.jpg'),
(25996, 1746, 'Virgin River S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249642.mp4', 'http://timg.bdta.pro/images/dd87f5f9aa5825a96c87d70efa831b7a.jpg'),
(25997, 1746, 'Virgin River S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249643.mp4', 'http://timg.bdta.pro/images/a8412885922e8d56997e9477d9fe42e8.jpg'),
(25998, 1746, 'Virgin River S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249644.mp4', 'http://timg.bdta.pro/images/e1a437f78490ba312c0f69fc3b35c8ae.jpg'),
(25999, 1746, 'Virgin River S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249645.mp4', 'http://timg.bdta.pro/images/fe1563fb6de6b355b997363167594eb0.jpg'),
(26000, 1746, 'Virgin River S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249646.mp4', 'http://timg.bdta.pro/images/f814fc1c8e7dd4f1b3dad4ace48f775c.jpg'),
(26001, 1746, 'Virgin River S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249647.mp4', 'http://timg.bdta.pro/images/56f38c8bc60a54c9c880cffdb2962c07.jpg'),
(26002, 1746, 'Virgin River S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249648.mp4', 'http://timg.bdta.pro/images/afed72dd8d5cc3759ac0bf8972b78498.jpg'),
(26003, 1746, 'Virgin River S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249649.mp4', 'http://timg.bdta.pro/images/44d8afccde649ea7078406b123fa4e7b.jpg'),
(26004, 1746, 'Virgin River S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249650.mp4', 'http://timg.bdta.pro/images/aa0749d5e50af58cdd0347ec9f72c792.jpg'),
(26005, 1746, 'Virgin River S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249651.mp4', 'http://timg.bdta.pro/images/9ad2da616604d9a3e41f6489ede53fa4.jpg'),
(26006, 1746, 'Virgin River S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249652.mp4', 'http://timg.bdta.pro/images/bef9aa0b4a3279da663af40a5db0f021.jpg'),
(26007, 1746, 'Virgin River S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249653.mp4', 'http://timg.bdta.pro/images/8aee79637c8f99421ecb6937c070c271.jpg'),
(26008, 1747, 'Virgin River S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249654.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26009, 1747, 'Virgin River S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249655.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26010, 1747, 'Virgin River S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249656.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26011, 1747, 'Virgin River S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249657.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26012, 1747, 'Virgin River S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249658.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26013, 1747, 'Virgin River S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249659.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26014, 1747, 'Virgin River S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249660.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26015, 1747, 'Virgin River S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249661.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26016, 1747, 'Virgin River S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249662.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26017, 1747, 'Virgin River S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249663.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26018, 1747, 'Virgin River S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249664.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26019, 1747, 'Virgin River S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249665.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26020, 1748, 'Virgin River S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/638854.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26021, 1748, 'Virgin River S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/638855.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26022, 1748, 'Virgin River S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/638856.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26023, 1748, 'Virgin River S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/638857.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26024, 1748, 'Virgin River S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/638858.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26025, 1748, 'Virgin River S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/638859.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26026, 1748, 'Virgin River S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/638860.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26027, 1748, 'Virgin River S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/638861.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26028, 1748, 'Virgin River S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/638862.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26029, 1748, 'Virgin River S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/638863.mp4', 'http://gstaticontent.com/images/jSm9HdxUy9PpsJt0mVAQ0y7gbDJ_big.jpg'),
(26030, 1749, 'The New Pope [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111247.mp4', 'http://timg.bdta.pro/images/db8729d9f5ee9c71cd038812bd6666ba.jpg'),
(26031, 1749, 'The New Pope [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111248.mp4', 'http://timg.bdta.pro/images/6e77d161cfa2b6536002e9c4e887a623.jpg'),
(26032, 1749, 'The New Pope [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111249.mp4', 'http://timg.bdta.pro/images/e765169b4ef6ee4936c49a3469f95d7e.jpg'),
(26033, 1749, 'The New Pope [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111250.mp4', 'http://timg.bdta.pro/images/497d193c5b23b7d5c76856e93d8dedaa.jpg'),
(26034, 1749, 'The New Pope [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111251.mp4', 'http://timg.bdta.pro/images/45aec239c266bf794c6381a6f327913a.jpg'),
(26035, 1749, 'The New Pope [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/111252.mp4', 'http://timg.bdta.pro/images/349b6b06bd2e61ac447124b9096c487e.jpg'),
(26036, 1749, 'The New Pope [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/111253.mp4', 'http://timg.bdta.pro/images/ca5bffd23f3b4387fe75d260a657a222.jpg'),
(26037, 1749, 'The New Pope [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/111254.mp4', 'http://timg.bdta.pro/images/fe5aac3d3436372268ee093e67bbb37b.jpg'),
(26038, 1749, 'The New Pope [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/111255.mp4', 'http://gstaticontent.com/images/s1itw3c0Yu5KcljY6SNCfnq8kfn_big.jpg'),
(26039, 1750, 'Ted Bundy Falling For A Killer [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111242.mp4', 'http://timg.bdta.pro/images/57adb8cf8da64aa2e900d4b34b6cb20c.jpg'),
(26040, 1750, 'Ted Bundy Falling For A Killer [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111243.mp4', 'http://timg.bdta.pro/images/4995200948d7fcfbec1e7585b90a97ec.jpg'),
(26041, 1750, 'Ted Bundy Falling For A Killer [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111244.mp4', 'http://timg.bdta.pro/images/d7d2d3cbc744be6d2121c7bf4b3eb06c.jpg'),
(26042, 1750, 'Ted Bundy Falling For A Killer [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111245.mp4', 'http://timg.bdta.pro/images/98c7aa54f95bc758273d2c1114a7d520.jpg'),
(26043, 1750, 'Ted Bundy Falling For A Killer [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111246.mp4', 'http://timg.bdta.pro/images/76932732783fc9bee51d4d0b955eeb14.jpg'),
(26044, 1751, 'Castlevania S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142050.mp4', 'http://gstaticontent.com/images/uJ7cHITmM83XWAntdi0GZ1bGePI_big.jpg'),
(26045, 1751, 'Castlevania S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142051.mp4', 'http://gstaticontent.com/images/uJ7cHITmM83XWAntdi0GZ1bGePI_big.jpg'),
(26046, 1751, 'Castlevania S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142052.mp4', 'http://gstaticontent.com/images/uJ7cHITmM83XWAntdi0GZ1bGePI_big.jpg'),
(26047, 1751, 'Castlevania S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142053.mp4', 'http://gstaticontent.com/images/uJ7cHITmM83XWAntdi0GZ1bGePI_big.jpg'),
(26048, 1752, 'Castlevania S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142054.mp4', 'http://timg.bdta.pro/images/b3dc4128e39b6402f3d2476ab31ef7eb.jpg'),
(26049, 1752, 'Castlevania S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142055.mp4', 'http://timg.bdta.pro/images/dbee0a389eff835bb3d3dbfe4c652c3a.jpg'),
(26050, 1752, 'Castlevania S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142056.mp4', 'http://timg.bdta.pro/images/b848cbf6cec109e622cf8cf57be09869.jpg'),
(26051, 1752, 'Castlevania S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142057.mp4', 'http://timg.bdta.pro/images/4b86645ef4ac34cb49b2b1bcf93507b5.jpg'),
(26052, 1752, 'Castlevania S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142058.mp4', 'http://timg.bdta.pro/images/ab1d96f4c1226cb5085ee29fa889ec8e.jpg'),
(26053, 1752, 'Castlevania S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142059.mp4', 'http://timg.bdta.pro/images/1f3291628f59720fb09e625eb21e5a4f.jpg'),
(26054, 1752, 'Castlevania S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142060.mp4', 'http://timg.bdta.pro/images/6e0d65ca1c3f4eca4c0da31643af5607.jpg'),
(26055, 1752, 'Castlevania S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142061.mp4', 'http://timg.bdta.pro/images/b4d906e0ecea6afa7d8391f2a0643c10.jpg'),
(26056, 1753, 'Castlevania S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142062.mp4', 'http://timg.bdta.pro/images/e43265ed5fdefc483f8ea0a2527349fa.jpg'),
(26057, 1753, 'Castlevania S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142063.mp4', 'http://timg.bdta.pro/images/693318274e3d7a9e15c9ff6fca7c25bc.jpg'),
(26058, 1753, 'Castlevania S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142064.mp4', 'http://timg.bdta.pro/images/f849a0b6ac242e83e1745826e4fffded.jpg'),
(26059, 1753, 'Castlevania S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142065.mp4', 'http://timg.bdta.pro/images/b4246999e2787e8ee9a4569c2ed5bb40.jpg'),
(26060, 1753, 'Castlevania S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142066.mp4', 'http://timg.bdta.pro/images/83bc6972bbf2594322a7c7da101a3766.jpg'),
(26061, 1753, 'Castlevania S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142067.mp4', 'http://timg.bdta.pro/images/d574be32d22957be06a9dc7598e482aa.jpg'),
(26062, 1753, 'Castlevania S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142068.mp4', 'http://timg.bdta.pro/images/d83bc15cd13d51c7015ef690205233b2.jpg'),
(26063, 1753, 'Castlevania S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142069.mp4', 'http://timg.bdta.pro/images/14c16e0e4a7ae9319a7d89fa40b3592e.jpg'),
(26064, 1753, 'Castlevania S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142070.mp4', 'http://timg.bdta.pro/images/edb150a5a430a664f83701a15c4cda14.jpg'),
(26065, 1753, 'Castlevania S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142071.mp4', 'http://timg.bdta.pro/images/3644b0f060263b1aaf5eaf1fef42d07a.jpg'),
(26066, 1754, 'Castlevania S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142072.mp4', 'http://gstaticontent.com/images/uJ7cHITmM83XWAntdi0GZ1bGePI_big.jpg'),
(26067, 1754, 'Castlevania S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142073.mp4', 'http://gstaticontent.com/images/uJ7cHITmM83XWAntdi0GZ1bGePI_big.jpg'),
(26068, 1754, 'Castlevania S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142074.mp4', 'http://gstaticontent.com/images/uJ7cHITmM83XWAntdi0GZ1bGePI_big.jpg'),
(26069, 1754, 'Castlevania S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142075.mp4', 'http://gstaticontent.com/images/uJ7cHITmM83XWAntdi0GZ1bGePI_big.jpg'),
(26070, 1754, 'Castlevania S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142076.mp4', 'http://gstaticontent.com/images/uJ7cHITmM83XWAntdi0GZ1bGePI_big.jpg'),
(26071, 1754, 'Castlevania S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142077.mp4', 'http://gstaticontent.com/images/uJ7cHITmM83XWAntdi0GZ1bGePI_big.jpg'),
(26072, 1754, 'Castlevania S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142078.mp4', 'http://gstaticontent.com/images/uJ7cHITmM83XWAntdi0GZ1bGePI_big.jpg'),
(26073, 1754, 'Castlevania S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142079.mp4', 'http://gstaticontent.com/images/uJ7cHITmM83XWAntdi0GZ1bGePI_big.jpg'),
(26074, 1754, 'Castlevania S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142080.mp4', 'http://gstaticontent.com/images/uJ7cHITmM83XWAntdi0GZ1bGePI_big.jpg'),
(26075, 1754, 'Castlevania S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142081.mp4', 'http://gstaticontent.com/images/uJ7cHITmM83XWAntdi0GZ1bGePI_big.jpg'),
(26076, 1755, 'ZeroZeroZero S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111054.mp4', 'http://timg.bdta.pro/images/bf0f2c3c494c018155d5673a5669c8e3.jpg'),
(26077, 1755, 'ZeroZeroZero S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111055.mp4', 'http://timg.bdta.pro/images/8acda80df254832ea24445f3d0e47c2a.jpg'),
(26078, 1755, 'ZeroZeroZero S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111056.mp4', 'http://timg.bdta.pro/images/8149036036592622db928211485be762.jpg'),
(26079, 1755, 'ZeroZeroZero S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111057.mp4', 'http://timg.bdta.pro/images/4a537cc9a4441be5452456e59f9eb954.jpg'),
(26080, 1755, 'ZeroZeroZero S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111058.mp4', 'http://timg.bdta.pro/images/0c85266448533175145c65deb50926d1.jpg'),
(26081, 1755, 'ZeroZeroZero S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/111059.mp4', 'http://timg.bdta.pro/images/8e5ff08defbf5da085c15c91c5b62ef7.jpg'),
(26082, 1755, 'ZeroZeroZero S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/111060.mp4', 'http://timg.bdta.pro/images/e39ec234411104ef49b930dbeacf769d.jpg'),
(26083, 1755, 'ZeroZeroZero S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/111061.mp4', 'http://timg.bdta.pro/images/faf028f278f3e8d41385f7e006fbafeb.jpg'),
(26084, 1756, 'FBI: Os Mais Procurados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224286.mp4', 'http://timg.bdta.pro/images/bf209c4cf8dbfa8fea0b85d72af5cbad.jpg'),
(26085, 1756, 'FBI: Os Mais Procurados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224287.mp4', 'http://timg.bdta.pro/images/54b5af2101ee1bc30fb4cc14a5a70e33.jpg'),
(26086, 1756, 'FBI: Os Mais Procurados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224288.mp4', 'http://timg.bdta.pro/images/5dca96fea157bce57e3a964dc7339395.jpg'),
(26087, 1756, 'FBI: Os Mais Procurados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224289.mp4', 'http://timg.bdta.pro/images/a3c650ca996e2a1bd4f537c6a50c5e5c.jpg'),
(26088, 1756, 'FBI: Os Mais Procurados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224290.mp4', 'http://timg.bdta.pro/images/96ba490b4314547596ea9d8d8fd5d51a.jpg'),
(26089, 1756, 'FBI: Os Mais Procurados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224291.mp4', 'http://timg.bdta.pro/images/b6ec217f53a078f4dae90017a35f03f5.jpg'),
(26090, 1756, 'FBI: Os Mais Procurados S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224292.mp4', 'http://timg.bdta.pro/images/61defbeda0aed0066f06640604cf0362.jpg'),
(26091, 1756, 'FBI: Os Mais Procurados S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224293.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26092, 1756, 'FBI: Os Mais Procurados S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224294.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26093, 1756, 'FBI: Os Mais Procurados S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224295.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26094, 1756, 'FBI: Os Mais Procurados S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224296.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26095, 1756, 'FBI: Os Mais Procurados S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224297.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26096, 1756, 'FBI: Os Mais Procurados S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224298.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26097, 1756, 'FBI: Os Mais Procurados S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224299.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26098, 1757, 'FBI: Os Mais Procurados S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224300.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26099, 1757, 'FBI: Os Mais Procurados S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224301.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26100, 1757, 'FBI: Os Mais Procurados S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224302.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26101, 1757, 'FBI: Os Mais Procurados S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224303.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26102, 1757, 'FBI: Os Mais Procurados S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224304.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26103, 1757, 'FBI: Os Mais Procurados S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224305.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26104, 1757, 'FBI: Os Mais Procurados S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224306.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26105, 1757, 'FBI: Os Mais Procurados S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224307.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26106, 1757, 'FBI: Os Mais Procurados S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224308.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26107, 1757, 'FBI: Os Mais Procurados S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224309.mp4', 'http://timg.bdta.pro/images/058209694ff5af25bc04ea2a4132ad4c.jpg'),
(26108, 1757, 'FBI: Os Mais Procurados S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224310.mp4', 'http://timg.bdta.pro/images/f18e4b8a116bd5d934e540cc158caaf0.jpg'),
(26109, 1757, 'FBI: Os Mais Procurados S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224311.mp4', 'http://timg.bdta.pro/images/285e6774223e02dffe2b18171a58fdae.jpg'),
(26110, 1757, 'FBI: Os Mais Procurados S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224312.mp4', 'http://timg.bdta.pro/images/7e42c0d02111adc7ee130b40d7334901.jpg'),
(26111, 1757, 'FBI: Os Mais Procurados S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224313.mp4', 'http://timg.bdta.pro/images/e1175cbf1d630a357c303ecd868cfafe.jpg'),
(26112, 1757, 'FBI: Os Mais Procurados S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224314.mp4', 'http://timg.bdta.pro/images/3a05f8b189653e6c696d9edf66ae79f3.jpg'),
(26113, 1758, 'FBI: Os Mais Procurados S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224315.mp4', 'http://image.tmdb.org/t/p/w1280/lwWj5AGyz5yCzBkXB3sXx1c4AGO.jpg'),
(26114, 1758, 'FBI: Os Mais Procurados S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224316.mp4', 'http://timg.bdta.pro/images/b8b0715edaf15c00893aa070e7c96cf0.jpg'),
(26115, 1758, 'FBI: Os Mais Procurados S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224317.mp4', 'http://timg.bdta.pro/images/55e1c14d240a54961c92b589a1f76974.jpg'),
(26116, 1758, 'FBI: Os Mais Procurados S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224318.mp4', 'http://timg.bdta.pro/images/d556383e56e233ab9a85807e0e4de36c.jpg'),
(26117, 1758, 'FBI: Os Mais Procurados S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224319.mp4', 'http://timg.bdta.pro/images/f8f9ced05948dda046cc0d59f117c3cc.jpg'),
(26118, 1758, 'FBI: Os Mais Procurados S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224320.mp4', 'http://timg.bdta.pro/images/5861f4967231457776e0148bda579692.jpg'),
(26119, 1758, 'FBI: Os Mais Procurados S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224321.mp4', 'http://timg.bdta.pro/images/8a64b8b95fbb79370774d66a2cab4994.jpg'),
(26120, 1758, 'FBI: Os Mais Procurados S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224322.mp4', 'http://timg.bdta.pro/images/467832276f3a104dfc799a1d202e6db6.jpg'),
(26121, 1758, 'FBI: Os Mais Procurados S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224323.mp4', 'http://timg.bdta.pro/images/1888fe55b890b3fd627e4e39fc76bb42.jpg'),
(26122, 1758, 'FBI: Os Mais Procurados S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224324.mp4', 'http://timg.bdta.pro/images/68d3e6aca24d2c10c3179efd7a6c1184.jpg'),
(26123, 1758, 'FBI: Os Mais Procurados S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224325.mp4', 'http://timg.bdta.pro/images/4aa4bf7662aa1e450b0705646b492d94.jpg'),
(26124, 1758, 'FBI: Os Mais Procurados S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224326.mp4', 'http://timg.bdta.pro/images/64a812ad26a2ab8da31ed75c85a64284.jpg'),
(26125, 1758, 'FBI: Os Mais Procurados S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224327.mp4', 'http://timg.bdta.pro/images/338a113be6381a538118f2b9353a28eb.jpg'),
(26126, 1758, 'FBI: Os Mais Procurados S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224328.mp4', 'http://timg.bdta.pro/images/a6e07f14c242a4e3a73a2c0f2b4e2788.jpg'),
(26127, 1758, 'FBI: Os Mais Procurados S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224329.mp4', 'http://timg.bdta.pro/images/05389c144c6b8f777835b58f9799d6c2.jpg'),
(26128, 1758, 'FBI: Os Mais Procurados S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224330.mp4', 'http://timg.bdta.pro/images/88cbbbabe858087a78e9d46a7af7aad9.jpg'),
(26129, 1758, 'FBI: Os Mais Procurados S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224331.mp4', 'http://timg.bdta.pro/images/a77695dcfc63a6b448658d319fefa51e.jpg'),
(26130, 1758, 'FBI: Os Mais Procurados S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224332.mp4', 'http://timg.bdta.pro/images/bdd9358ba3ea059beff4e701d4a9c11d.jpg'),
(26131, 1758, 'FBI: Os Mais Procurados S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224333.mp4', 'http://timg.bdta.pro/images/99f43fe69d52558205ebb00ccdb140c8.jpg'),
(26132, 1758, 'FBI: Os Mais Procurados S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224334.mp4', 'http://timg.bdta.pro/images/288e6004ac353ee625b37aa6e4e223dc.jpg'),
(26133, 1758, 'FBI: Os Mais Procurados S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224335.mp4', 'http://timg.bdta.pro/images/134af5d4644b33b004bdd0c12204059f.jpg'),
(26134, 1758, 'FBI: Os Mais Procurados S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224336.mp4', 'http://timg.bdta.pro/images/b31a7ff3e3a0af5bc62412f9911e8227.jpg'),
(26135, 1759, 'FBI: Os Mais Procurados S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224337.mp4', 'http://image.tmdb.org/t/p/w1280/gY8DpneBHdQqeW9RAbS4tdCotvi.jpg'),
(26136, 1759, 'FBI: Os Mais Procurados S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224338.mp4', 'http://image.tmdb.org/t/p/w1280/7qVmAYE0LRD7nUQsBSnSQbF7L57.jpg'),
(26137, 1759, 'FBI: Os Mais Procurados S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224339.mp4', 'http://image.tmdb.org/t/p/w1280/7Tf2a1zg7xsYX2miowzwhAipBhu.jpg'),
(26138, 1759, 'FBI: Os Mais Procurados S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224340.mp4', 'http://image.tmdb.org/t/p/w1280/haD2jUE52JSHY4kByijfy0kwWl6.jpg'),
(26139, 1759, 'FBI: Os Mais Procurados S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224341.mp4', 'http://image.tmdb.org/t/p/w1280/oqvp3oUCc44DxIZRCwgSl4rEdBm.jpg'),
(26140, 1759, 'FBI: Os Mais Procurados S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224342.mp4', 'http://image.tmdb.org/t/p/w1280/N6VNUMf5NpCpjIxZoKog7hPfJb.jpg'),
(26141, 1759, 'FBI: Os Mais Procurados S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224343.mp4', 'http://image.tmdb.org/t/p/w1280/KmAU3FJ29TKYr8ZpPnE14mOUAM.jpg'),
(26142, 1759, 'FBI: Os Mais Procurados S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224344.mp4', 'http://image.tmdb.org/t/p/w1280/6SJwH3fJxQDan3iraifiv4DDkaj.jpg'),
(26143, 1759, 'FBI: Os Mais Procurados S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224345.mp4', 'http://image.tmdb.org/t/p/w1280/ifM8fScmnrPG7OThaFGJxe3Qya9.jpg'),
(26144, 1759, 'FBI: Os Mais Procurados S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224346.mp4', 'http://image.tmdb.org/t/p/w1280/8m0ROEA9j9wSA5Ekv3uSrMWwx0.jpg'),
(26145, 1759, 'FBI: Os Mais Procurados S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224347.mp4', 'http://image.tmdb.org/t/p/w1280/uTqeGaMctN3Gb4c0BJbGj34rSW4.jpg'),
(26146, 1759, 'FBI: Os Mais Procurados S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224348.mp4', 'http://image.tmdb.org/t/p/w1280/oRFyvWTjcRCGP5FQWXgE3dGNn4S.jpg'),
(26147, 1759, 'FBI: Os Mais Procurados S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224349.mp4', 'http://image.tmdb.org/t/p/w1280/s7qz8y8Tlzd2mhdNnXXKf5NwVxk.jpg'),
(26148, 1759, 'FBI: Os Mais Procurados S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224350.mp4', 'http://image.tmdb.org/t/p/w1280/4un4viKSmNAYjIM3ziyywBOdmn5.jpg'),
(26149, 1759, 'FBI: Os Mais Procurados S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224351.mp4', 'http://image.tmdb.org/t/p/w1280/nDrsVLniEQUgajAjEly7D3UB5bW.jpg'),
(26150, 1759, 'FBI: Os Mais Procurados S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224352.mp4', 'http://image.tmdb.org/t/p/w1280/zGxQa1kP1dOtcS5K9XWBnp1AAXh.jpg'),
(26151, 1759, 'FBI: Os Mais Procurados S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224353.mp4', 'http://image.tmdb.org/t/p/w1280/x1bnC7FiUWhSESpmwcySlPoCDlD.jpg'),
(26152, 1759, 'FBI: Os Mais Procurados S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224354.mp4', 'http://image.tmdb.org/t/p/w1280/wD8NzlQGvR8I8qZbWp0W3gFuV5H.jpg'),
(26153, 1759, 'FBI: Os Mais Procurados S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224355.mp4', 'http://image.tmdb.org/t/p/w1280/bH531IWAOXIoGQuZnnEdBFl0YIP.jpg'),
(26154, 1759, 'FBI: Os Mais Procurados S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224356.mp4', 'http://image.tmdb.org/t/p/w1280/hL5evYkbAE0gad5aiHh1RJxWHmN.jpg'),
(26155, 1759, 'FBI: Os Mais Procurados S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224357.mp4', 'http://image.tmdb.org/t/p/w1280/vcHbgf7GufK8Uc486idd5bzDpej.jpg'),
(26156, 1759, 'FBI: Os Mais Procurados S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224358.mp4', 'http://image.tmdb.org/t/p/w1280/cReVQLHHcuBykWda6ec2Cj3rI0d.jpg'),
(26157, 1760, 'FBI: Os Mais Procurados S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/336829.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26158, 1760, 'FBI: Os Mais Procurados S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/336830.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26159, 1760, 'FBI: Os Mais Procurados S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/345553.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26160, 1760, 'FBI: Os Mais Procurados S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/356607.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26161, 1760, 'FBI: Os Mais Procurados S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/356608.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26162, 1760, 'FBI: Os Mais Procurados S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/363501.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26163, 1760, 'FBI: Os Mais Procurados S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/368927.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26164, 1760, 'FBI: Os Mais Procurados S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/384254.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26165, 1760, 'FBI: Os Mais Procurados S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/384255.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26166, 1760, 'FBI: Os Mais Procurados S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/384256.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26167, 1760, 'FBI: Os Mais Procurados S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/397028.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26168, 1760, 'FBI: Os Mais Procurados S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/403439.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26169, 1760, 'FBI: Os Mais Procurados S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/409179.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26170, 1761, 'FBI: Os Mais Procurados S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/662927.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26171, 1761, 'FBI: Os Mais Procurados S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664970.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26172, 1761, 'FBI: Os Mais Procurados S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/676457.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26173, 1761, 'FBI: Os Mais Procurados S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/679740.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26174, 1761, 'FBI: Os Mais Procurados S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/687599.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26175, 1761, 'FBI: Os Mais Procurados S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/696126.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26176, 1761, 'FBI: Os Mais Procurados S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/701934.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26177, 1761, 'FBI: Os Mais Procurados S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/714915.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26178, 1761, 'FBI: Os Mais Procurados S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/718468.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26179, 1761, 'FBI: Os Mais Procurados S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/724856.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26180, 1761, 'FBI: Os Mais Procurados S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/731483.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26181, 1761, 'FBI: Os Mais Procurados S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/742688.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26182, 1761, 'FBI: Os Mais Procurados S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/767490.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26183, 1761, 'FBI: Os Mais Procurados S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/780717.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26184, 1761, 'FBI: Os Mais Procurados S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/794790.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26185, 1761, 'FBI: Os Mais Procurados S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/795985.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26186, 1761, 'FBI: Os Mais Procurados S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/801198.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26187, 1761, 'FBI: Os Mais Procurados S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/809994.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26188, 1761, 'FBI: Os Mais Procurados S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/822399.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26189, 1761, 'FBI: Os Mais Procurados S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/838068.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26190, 1761, 'FBI: Os Mais Procurados S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/847368.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26191, 1761, 'FBI: Os Mais Procurados S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/854836.mp4', 'http://gstaticontent.com/images/8520f0a71ed2372d7607f82312bccec9.jpg'),
(26192, 1762, 'Histórias Maravilhosas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/528419.mp4', 'http://gstaticontent.com/images/f86ad740efa1935f763026eab88078cd.jpg'),
(26193, 1762, 'Histórias Maravilhosas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109915.mp4', 'http://timg.bdta.pro/images/a2bccd6a7960a6f31fb72efd2f484ddf.jpg'),
(26194, 1762, 'Histórias Maravilhosas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109916.mp4', 'http://timg.bdta.pro/images/01e74eec2c9ec35ff4de73e7b680d640.jpg'),
(26195, 1762, 'Histórias Maravilhosas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109917.mp4', 'http://timg.bdta.pro/images/2ab55e49e66686164f4b33c2091b2b57.jpg'),
(26196, 1762, 'Histórias Maravilhosas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109918.mp4', 'http://timg.bdta.pro/images/a72554569b0775911d46a52f543c90f1.jpg'),
(26197, 1763, 'Power Rangers Beast Morphers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111032.mp4', 'http://timg.bdta.pro/images/c3fd2fbd7b5eb2919db8e6d345ba868e.jpg'),
(26198, 1763, 'Power Rangers Beast Morphers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111033.mp4', 'http://timg.bdta.pro/images/bdbc07653d161eeeaed08c783de5feec.jpg'),
(26199, 1763, 'Power Rangers Beast Morphers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111034.mp4', 'http://timg.bdta.pro/images/272862d60a97b47cac33b21172bbd29d.jpg'),
(26200, 1763, 'Power Rangers Beast Morphers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111035.mp4', 'http://timg.bdta.pro/images/4ea1c61b03cbec6c2cfd84361ed8c7d6.jpg'),
(26201, 1763, 'Power Rangers Beast Morphers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111036.mp4', 'http://timg.bdta.pro/images/263006e209ce895686dc655dd65858e7.jpg'),
(26202, 1763, 'Power Rangers Beast Morphers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/111037.mp4', 'http://timg.bdta.pro/images/263006e209ce895686dc655dd65858e7.jpg'),
(26203, 1763, 'Power Rangers Beast Morphers S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/111038.mp4', 'http://timg.bdta.pro/images/263006e209ce895686dc655dd65858e7.jpg'),
(26204, 1763, 'Power Rangers Beast Morphers S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/111039.mp4', 'http://timg.bdta.pro/images/263006e209ce895686dc655dd65858e7.jpg'),
(26205, 1763, 'Power Rangers Beast Morphers S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/111040.mp4', 'http://timg.bdta.pro/images/263006e209ce895686dc655dd65858e7.jpg'),
(26206, 1763, 'Power Rangers Beast Morphers S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/111041.mp4', 'http://timg.bdta.pro/images/263006e209ce895686dc655dd65858e7.jpg'),
(26207, 1763, 'Power Rangers Beast Morphers S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/111042.mp4', 'http://timg.bdta.pro/images/263006e209ce895686dc655dd65858e7.jpg'),
(26208, 1763, 'Power Rangers Beast Morphers S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/111043.mp4', 'http://timg.bdta.pro/images/263006e209ce895686dc655dd65858e7.jpg'),
(26209, 1763, 'Power Rangers Beast Morphers S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/111044.mp4', 'http://timg.bdta.pro/images/263006e209ce895686dc655dd65858e7.jpg'),
(26210, 1763, 'Power Rangers Beast Morphers S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/111045.mp4', 'http://timg.bdta.pro/images/263006e209ce895686dc655dd65858e7.jpg'),
(26211, 1763, 'Power Rangers Beast Morphers S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/111046.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(26212, 1763, 'Power Rangers Beast Morphers S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/111047.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(26213, 1763, 'Power Rangers Beast Morphers S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/111048.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(26214, 1763, 'Power Rangers Beast Morphers S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/111049.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(26215, 1763, 'Power Rangers Beast Morphers S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/111050.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(26216, 1763, 'Power Rangers Beast Morphers S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/111051.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(26217, 1763, 'Power Rangers Beast Morphers S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/111052.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(26218, 1763, 'Power Rangers Beast Morphers S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/111053.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(26219, 1764, 'Esquadrão Relâmpago Changeman S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110952.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26220, 1764, 'Esquadrão Relâmpago Changeman S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110953.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26221, 1764, 'Esquadrão Relâmpago Changeman S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110954.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26222, 1764, 'Esquadrão Relâmpago Changeman S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110955.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26223, 1764, 'Esquadrão Relâmpago Changeman S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110956.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26224, 1764, 'Esquadrão Relâmpago Changeman S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110957.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26225, 1764, 'Esquadrão Relâmpago Changeman S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110958.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26226, 1764, 'Esquadrão Relâmpago Changeman S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110959.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26227, 1764, 'Esquadrão Relâmpago Changeman S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/110960.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26228, 1764, 'Esquadrão Relâmpago Changeman S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/110961.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26229, 1764, 'Esquadrão Relâmpago Changeman S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/110962.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26230, 1764, 'Esquadrão Relâmpago Changeman S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/110963.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26231, 1764, 'Esquadrão Relâmpago Changeman S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/110964.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26232, 1764, 'Esquadrão Relâmpago Changeman S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/110965.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26233, 1764, 'Esquadrão Relâmpago Changeman S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/110966.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26234, 1764, 'Esquadrão Relâmpago Changeman S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/110967.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26235, 1764, 'Esquadrão Relâmpago Changeman S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/110968.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26236, 1764, 'Esquadrão Relâmpago Changeman S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/110969.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26237, 1764, 'Esquadrão Relâmpago Changeman S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/110970.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26238, 1764, 'Esquadrão Relâmpago Changeman S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/110971.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26239, 1764, 'Esquadrão Relâmpago Changeman S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/110972.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26240, 1764, 'Esquadrão Relâmpago Changeman S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/110973.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26241, 1764, 'Esquadrão Relâmpago Changeman S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/110974.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26242, 1764, 'Esquadrão Relâmpago Changeman S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/110975.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(26243, 1764, 'Esquadrão Relâmpago Changeman S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/110976.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26244, 1764, 'Esquadrão Relâmpago Changeman S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/110977.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26245, 1764, 'Esquadrão Relâmpago Changeman S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/110978.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26246, 1764, 'Esquadrão Relâmpago Changeman S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/110979.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26247, 1764, 'Esquadrão Relâmpago Changeman S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/110980.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26248, 1764, 'Esquadrão Relâmpago Changeman S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/110981.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26249, 1764, 'Esquadrão Relâmpago Changeman S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/110982.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26250, 1764, 'Esquadrão Relâmpago Changeman S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/110983.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26251, 1764, 'Esquadrão Relâmpago Changeman S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/110984.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26252, 1764, 'Esquadrão Relâmpago Changeman S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/110985.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26253, 1764, 'Esquadrão Relâmpago Changeman S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/110986.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26254, 1764, 'Esquadrão Relâmpago Changeman S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/110987.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26255, 1764, 'Esquadrão Relâmpago Changeman S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/110988.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26256, 1764, 'Esquadrão Relâmpago Changeman S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/110989.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26257, 1764, 'Esquadrão Relâmpago Changeman S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/110990.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26258, 1764, 'Esquadrão Relâmpago Changeman S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/110991.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26259, 1764, 'Esquadrão Relâmpago Changeman S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/110992.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26260, 1764, 'Esquadrão Relâmpago Changeman S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/110993.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26261, 1764, 'Esquadrão Relâmpago Changeman S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/110994.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26262, 1764, 'Esquadrão Relâmpago Changeman S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/110995.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26263, 1764, 'Esquadrão Relâmpago Changeman S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/110996.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26264, 1764, 'Esquadrão Relâmpago Changeman S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/110997.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26265, 1764, 'Esquadrão Relâmpago Changeman S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/110998.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26266, 1764, 'Esquadrão Relâmpago Changeman S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/110999.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26267, 1764, 'Esquadrão Relâmpago Changeman S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/111000.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26268, 1764, 'Esquadrão Relâmpago Changeman S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/111001.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26269, 1764, 'Esquadrão Relâmpago Changeman S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/111002.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26270, 1764, 'Esquadrão Relâmpago Changeman S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/111003.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26271, 1764, 'Esquadrão Relâmpago Changeman S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/111004.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26272, 1764, 'Esquadrão Relâmpago Changeman S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/111005.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26273, 1764, 'Esquadrão Relâmpago Changeman S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/111006.mp4', 'http://gstaticontent.com/images/pHC80SHVrlQLHjq88isra3r3GV3_big.jpg'),
(26274, 1765, 'A Garota da Limpeza S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110547.mp4', 'http://gstaticontent.com/images/uhQEEUTUr0hCAs01FcLqT3irTIR_big.jpg'),
(26275, 1765, 'A Garota da Limpeza S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110548.mp4', 'http://gstaticontent.com/images/uhQEEUTUr0hCAs01FcLqT3irTIR_big.jpg'),
(26276, 1765, 'A Garota da Limpeza S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110549.mp4', 'http://gstaticontent.com/images/uhQEEUTUr0hCAs01FcLqT3irTIR_big.jpg'),
(26277, 1765, 'A Garota da Limpeza S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110550.mp4', 'http://gstaticontent.com/images/uhQEEUTUr0hCAs01FcLqT3irTIR_big.jpg'),
(26278, 1765, 'A Garota da Limpeza S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110551.mp4', 'http://gstaticontent.com/images/uhQEEUTUr0hCAs01FcLqT3irTIR_big.jpg'),
(26279, 1765, 'A Garota da Limpeza S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110552.mp4', 'http://gstaticontent.com/images/uhQEEUTUr0hCAs01FcLqT3irTIR_big.jpg'),
(26280, 1765, 'A Garota da Limpeza S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110553.mp4', 'http://gstaticontent.com/images/uhQEEUTUr0hCAs01FcLqT3irTIR_big.jpg'),
(26281, 1765, 'A Garota da Limpeza S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110554.mp4', 'http://gstaticontent.com/images/uhQEEUTUr0hCAs01FcLqT3irTIR_big.jpg'),
(26282, 1765, 'A Garota da Limpeza S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/110555.mp4', 'http://gstaticontent.com/images/uhQEEUTUr0hCAs01FcLqT3irTIR_big.jpg'),
(26283, 1765, 'A Garota da Limpeza S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/110556.mp4', 'http://gstaticontent.com/images/uhQEEUTUr0hCAs01FcLqT3irTIR_big.jpg'),
(26284, 1765, 'A Garota da Limpeza S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/110557.mp4', 'http://gstaticontent.com/images/uhQEEUTUr0hCAs01FcLqT3irTIR_big.jpg'),
(26285, 1765, 'A Garota da Limpeza S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/110558.mp4', 'http://gstaticontent.com/images/uhQEEUTUr0hCAs01FcLqT3irTIR_big.jpg'),
(26286, 1765, 'A Garota da Limpeza S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/110559.mp4', 'http://gstaticontent.com/images/uhQEEUTUr0hCAs01FcLqT3irTIR_big.jpg'),
(26287, 1766, 'Billions S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190094.mp4', 'http://timg.bdta.pro/images/08ff3fd58397e8e2a8cdd404766d91b1.jpg'),
(26288, 1766, 'Billions S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190095.mp4', 'http://timg.bdta.pro/images/74c4c9d5b930674a4943731d0029b9af.jpg'),
(26289, 1766, 'Billions S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190096.mp4', 'http://timg.bdta.pro/images/34abf93f506ff327ba85795f6bf1429a.jpg'),
(26290, 1766, 'Billions S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190097.mp4', 'http://timg.bdta.pro/images/c89b146f189543aa2d92d53beb27d48a.jpg'),
(26291, 1766, 'Billions S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190098.mp4', 'http://timg.bdta.pro/images/a615f95dd5d116144b3b3f612daa3cb6.jpg'),
(26292, 1766, 'Billions S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190099.mp4', 'http://timg.bdta.pro/images/fa5cd5bcac70fe6a0fd294d89501a6d2.jpg'),
(26293, 1766, 'Billions S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190100.mp4', 'http://timg.bdta.pro/images/3c03ac0555efe9de96e6a3a0781d9ae2.jpg'),
(26294, 1766, 'Billions S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190101.mp4', 'http://timg.bdta.pro/images/faf0423eb46141579d5a81a363f2f5d6.jpg'),
(26295, 1766, 'Billions S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190102.mp4', 'http://timg.bdta.pro/images/f42dc6c25d8986045db685f817c0f07a.jpg'),
(26296, 1766, 'Billions S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190103.mp4', 'http://timg.bdta.pro/images/d5b89d6865d267f1a52a1cd6d00787cf.jpg'),
(26297, 1766, 'Billions S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190104.mp4', 'http://timg.bdta.pro/images/cc86414c931a7c12cd4772b255e479fc.jpg'),
(26298, 1766, 'Billions S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190105.mp4', 'http://timg.bdta.pro/images/e95d40e74201419bc0f83a5977944f20.jpg'),
(26299, 1767, 'Billions S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190106.mp4', 'http://timg.bdta.pro/images/94acb24c16efefb9438c0054d26fbee6.jpg'),
(26300, 1767, 'Billions S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190107.mp4', 'http://timg.bdta.pro/images/4c4f24d5ab550ad91d72ea188c3b4eca.jpg'),
(26301, 1767, 'Billions S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190108.mp4', 'http://timg.bdta.pro/images/f8d0b9b9359a2dc66187f5a8d387a02a.jpg'),
(26302, 1767, 'Billions S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190109.mp4', 'http://timg.bdta.pro/images/f73ecbeb625f62aa3dac8e67922dfa3c.jpg'),
(26303, 1767, 'Billions S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190110.mp4', 'http://timg.bdta.pro/images/d1c9f1690b625e85f6f7228c4857b484.jpg'),
(26304, 1767, 'Billions S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190111.mp4', 'http://timg.bdta.pro/images/6f4ecae56a9da20e93123e5f53ef0ea3.jpg'),
(26305, 1767, 'Billions S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190112.mp4', 'http://timg.bdta.pro/images/be88880a6afc48380011ba38b0f3742c.jpg'),
(26306, 1767, 'Billions S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190113.mp4', 'http://timg.bdta.pro/images/c8986c6abff2f11d8ca1b7c378cdb5da.jpg'),
(26307, 1767, 'Billions S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190114.mp4', 'http://timg.bdta.pro/images/d3e725a38adaa3c21a187333577a57e4.jpg'),
(26308, 1767, 'Billions S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190115.mp4', 'http://timg.bdta.pro/images/56ef71408a53926519ed1135be3611ff.jpg'),
(26309, 1767, 'Billions S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190116.mp4', 'http://timg.bdta.pro/images/e38d0e6e067e5db89d812ff716a32dca.jpg'),
(26310, 1767, 'Billions S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190117.mp4', 'http://timg.bdta.pro/images/101d4c6f767d015d87a08982c3504062.jpg'),
(26311, 1768, 'Billions S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190118.mp4', 'http://timg.bdta.pro/images/a7f74d2d0fad20a70f545ea2fdfc145b.jpg'),
(26312, 1768, 'Billions S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190119.mp4', 'http://timg.bdta.pro/images/37ae9b5e59430d8dea328eb8645400b4.jpg'),
(26313, 1768, 'Billions S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190120.mp4', 'http://timg.bdta.pro/images/6e6bcf3f033214c2e8cff3ff365573c0.jpg'),
(26314, 1768, 'Billions S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190121.mp4', 'http://timg.bdta.pro/images/0dfcd7aeda080d385b25e859e96b9964.jpg'),
(26315, 1768, 'Billions S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190122.mp4', 'http://timg.bdta.pro/images/d24ed4c74155ba9c3da8dd284440b187.jpg'),
(26316, 1768, 'Billions S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190123.mp4', 'http://timg.bdta.pro/images/98fdfc274914334f61cf4632f904c08f.jpg'),
(26317, 1768, 'Billions S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190124.mp4', 'http://timg.bdta.pro/images/66c16d50b6d5851ffd7e218cff3e2ae9.jpg'),
(26318, 1768, 'Billions S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190125.mp4', 'http://timg.bdta.pro/images/33be6a0faecc8cb614b99b55d7d78062.jpg'),
(26319, 1768, 'Billions S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190126.mp4', 'http://timg.bdta.pro/images/c0373b081c81d9c84fe418b5ab1faddc.jpg'),
(26320, 1768, 'Billions S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190127.mp4', 'http://timg.bdta.pro/images/40ab5fd86deae3af4cc3be60a0280303.jpg'),
(26321, 1768, 'Billions S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190128.mp4', 'http://timg.bdta.pro/images/75f8c72df2622ce19ef50023660940d5.jpg'),
(26322, 1768, 'Billions S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190129.mp4', 'http://timg.bdta.pro/images/e3981bbc2f5dbd023d3c3f76120735d1.jpg'),
(26323, 1769, 'Billions S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190130.mp4', 'http://timg.bdta.pro/images/baf4d38272b3f232f8240879459a7d01.jpg'),
(26324, 1769, 'Billions S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190131.mp4', 'http://timg.bdta.pro/images/31a86aadb660e2421f8e2c9415e5abbd.jpg'),
(26325, 1769, 'Billions S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190132.mp4', 'http://timg.bdta.pro/images/36bded38edd784336a9a1ec7081ce0a6.jpg'),
(26326, 1769, 'Billions S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190133.mp4', 'http://timg.bdta.pro/images/3934cb12feee902a8ab473f6711faafc.jpg'),
(26327, 1769, 'Billions S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190134.mp4', 'http://timg.bdta.pro/images/42be093368f0c0bc3aa6f13cfe8080ec.jpg'),
(26328, 1769, 'Billions S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190135.mp4', 'http://timg.bdta.pro/images/226f2a8e633a58eb74e165699368a817.jpg'),
(26329, 1769, 'Billions S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190136.mp4', 'http://timg.bdta.pro/images/bb1afc4b0de4360e1dc877994f783305.jpg'),
(26330, 1769, 'Billions S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190137.mp4', 'http://timg.bdta.pro/images/a8f9ce27d78eb7b95ba7510b3225be43.jpg'),
(26331, 1769, 'Billions S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190138.mp4', 'http://timg.bdta.pro/images/61c023d14f0d21bb852254ba98d10368.jpg'),
(26332, 1769, 'Billions S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190139.mp4', 'http://timg.bdta.pro/images/418b53cd4f5ba2604632af0d7ed3a8e8.jpg'),
(26333, 1769, 'Billions S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190140.mp4', 'http://timg.bdta.pro/images/380c97b017a27e87ec22ee81e94f7ad1.jpg'),
(26334, 1769, 'Billions S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190141.mp4', 'http://timg.bdta.pro/images/cc877d6a63ce06e1e7639a93612b8fce.jpg'),
(26335, 1770, 'Billions S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190142.mp4', 'http://timg.bdta.pro/images/7098699ee7ac7e015fa96b8535697533.jpg'),
(26336, 1770, 'Billions S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190143.mp4', 'http://timg.bdta.pro/images/981aeab44f19389b1430eac9e87b2683.jpg'),
(26337, 1770, 'Billions S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190144.mp4', 'http://timg.bdta.pro/images/3f2528506ff607fce17b74f0771ca7ba.jpg'),
(26338, 1770, 'Billions S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190145.mp4', 'http://timg.bdta.pro/images/81b8e0b87d8c736bee5c9eeab35b75ff.jpg'),
(26339, 1770, 'Billions S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190146.mp4', 'http://timg.bdta.pro/images/97bc76f149b0e136ec7b2057733bd57e.jpg'),
(26340, 1770, 'Billions S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190147.mp4', 'http://timg.bdta.pro/images/b0dd85868449e8b42bcf43d18c85e5b4.jpg'),
(26341, 1770, 'Billions S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190148.mp4', 'http://timg.bdta.pro/images/7f95acf24c9a6044479f1c1b1fecad2a.jpg'),
(26342, 1770, 'Billions S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190149.mp4', 'http://timg.bdta.pro/images/b1f3d3abb8675d6281bfde599f46e437.jpg'),
(26343, 1770, 'Billions S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190150.mp4', 'http://timg.bdta.pro/images/f00adb7e247d7c75a6106a092d318152.jpg'),
(26344, 1770, 'Billions S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190151.mp4', 'http://timg.bdta.pro/images/f3e012c974994443659958682aa7a643.jpg'),
(26345, 1770, 'Billions S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190152.mp4', 'http://timg.bdta.pro/images/13ad2bb4e4476c3457314bae4a549329.jpg'),
(26346, 1770, 'Billions S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190153.mp4', 'http://timg.bdta.pro/images/d884a631580d2b887e49bdae9ee5c371.jpg'),
(26347, 1771, 'Billions S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190154.mp4', 'http://timg.bdta.pro/images/0d11e7f5222dec70bfd644fa880ad3ed.jpg'),
(26348, 1771, 'Billions S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190155.mp4', 'http://timg.bdta.pro/images/a27725d9ce9fcd8eb315e6cb3ad77c93.jpg'),
(26349, 1771, 'Billions S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190156.mp4', 'http://timg.bdta.pro/images/1cba2e0ae9d0c02c94fc8b1705645cf3.jpg'),
(26350, 1771, 'Billions S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190157.mp4', 'http://timg.bdta.pro/images/d83f2b355a8e1a9e0d11c918bd922c53.jpg'),
(26351, 1771, 'Billions S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190158.mp4', 'http://timg.bdta.pro/images/d177686a1d163f0739c1ff35350fb8ea.jpg'),
(26352, 1771, 'Billions S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190159.mp4', 'http://timg.bdta.pro/images/27c38317edbe7f081726044970823ba6.jpg'),
(26353, 1771, 'Billions S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190160.mp4', 'http://timg.bdta.pro/images/49e449de6bfa440624bb7afd146f34f9.jpg'),
(26354, 1771, 'Billions S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190161.mp4', 'http://timg.bdta.pro/images/a7faed0a3afbe2e036562da9ddbdee9a.jpg'),
(26355, 1771, 'Billions S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190162.mp4', 'http://timg.bdta.pro/images/d4836edd47caa1f64fae9ed695585e5b.jpg'),
(26356, 1771, 'Billions S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190163.mp4', 'http://timg.bdta.pro/images/1d261dc79a67a25b9afc7dbece3cb5bf.jpg'),
(26357, 1771, 'Billions S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190164.mp4', 'http://timg.bdta.pro/images/39de9b73e1956fe6591679cf4c40ae04.jpg'),
(26358, 1771, 'Billions S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190165.mp4', 'http://timg.bdta.pro/images/b6cc554aa65f188f0e78434e165ee587.jpg'),
(26359, 1772, 'Billions S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/358028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hdaRnpCobvHTSae541f2RuaNkE9.jpg'),
(26360, 1772, 'Billions S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/358029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eoZcnNVO8nteuz0bZMLruwBHmJ5.jpg'),
(26361, 1772, 'Billions S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/358030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2IH7EbTTf8OZRyA8PihT4F2SWc.jpg'),
(26362, 1772, 'Billions S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/358031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/seLAJajZX7Nnwr1GPGhyF2A29JR.jpg'),
(26363, 1772, 'Billions S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/358032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e78NHocpqVXHeqqrKTECdKo8f5t.jpg'),
(26364, 1772, 'Billions S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/358033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6UHzib8rNvYE8lGVZBpOtumKdW1.jpg'),
(26365, 1772, 'Billions S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/358034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kwJR9TTwkwGhCjNPeTspxJyQmgK.jpg'),
(26366, 1772, 'Billions S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/358035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s8cQeCoaUbGD1BoFwgIRnuW3oAw.jpg'),
(26367, 1772, 'Billions S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/358036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ssGynCgHU3GDEszGTjwz4jHrKO2.jpg'),
(26368, 1772, 'Billions S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/358037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pdGiaYFeu1qHUmTXxCRWx4au1qn.jpg'),
(26369, 1772, 'Billions S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/358038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hrjj7vm2TqLTBiOCd1PnSbtpjRz.jpg'),
(26370, 1772, 'Billions S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/358039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hLnzToMfqhOfkiXgWVWKuYfte5.jpg'),
(26371, 1773, 'Riverdale S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232813.mp4', 'http://timg.bdta.pro/images/5faefd6f01f8a1aac199e9eeca09f5a2.jpg'),
(26372, 1773, 'Riverdale S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232814.mp4', 'http://timg.bdta.pro/images/619ac7672d8126cc31e7415f63af8bd7.jpg'),
(26373, 1773, 'Riverdale S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232815.mp4', 'http://timg.bdta.pro/images/f30c67a7bf523e5d5eedd35ba3ece140.jpg'),
(26374, 1773, 'Riverdale S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232816.mp4', 'http://timg.bdta.pro/images/e5d892a3c6304cba4ce04cae6803080d.jpg'),
(26375, 1773, 'Riverdale S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232817.mp4', 'http://timg.bdta.pro/images/a7b2936928f575f481ce3691223c8db8.jpg'),
(26376, 1773, 'Riverdale S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232818.mp4', 'http://timg.bdta.pro/images/b656886680f12bc141eded9b0a01cfa9.jpg'),
(26377, 1773, 'Riverdale S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232819.mp4', 'http://timg.bdta.pro/images/eafa3b7f2b902304ce88b89e0131e743.jpg'),
(26378, 1773, 'Riverdale S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232820.mp4', 'http://timg.bdta.pro/images/8e0b3a7f48c380b2ae8c720ec2dd4b37.jpg'),
(26379, 1773, 'Riverdale S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232821.mp4', 'http://timg.bdta.pro/images/90349fae69e18381d1d6c850bfa5c7c2.jpg'),
(26380, 1773, 'Riverdale S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232822.mp4', 'http://timg.bdta.pro/images/3751e9aae8b0240af7046a6e176568c1.jpg'),
(26381, 1773, 'Riverdale S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232823.mp4', 'http://timg.bdta.pro/images/c4b636d48e2fb0ecd8c6d1ea58349719.jpg'),
(26382, 1773, 'Riverdale S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232824.mp4', 'http://timg.bdta.pro/images/36af2583a3f847570d07f6196f35f859.jpg'),
(26383, 1773, 'Riverdale S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/232825.mp4', 'http://timg.bdta.pro/images/64c41cc50f9008d5b2f1d8b743b08fe6.jpg'),
(26384, 1774, 'Riverdale S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232826.mp4', 'http://timg.bdta.pro/images/2912ed75b0c4e45a5acaa1f822f1156b.jpg'),
(26385, 1774, 'Riverdale S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232827.mp4', 'http://timg.bdta.pro/images/99cf0a5cf67b247a53450fd6d6e8d687.jpg'),
(26386, 1774, 'Riverdale S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232828.mp4', 'http://timg.bdta.pro/images/ae8f109ee8e9bd0e20bed4ec3e1b4328.jpg'),
(26387, 1774, 'Riverdale S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232829.mp4', 'http://timg.bdta.pro/images/3be41eaba407b796484db2d56624ebb7.jpg'),
(26388, 1774, 'Riverdale S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232830.mp4', 'http://timg.bdta.pro/images/795c9ee3bb856d3c2540a83cddc1e909.jpg'),
(26389, 1774, 'Riverdale S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232831.mp4', 'http://timg.bdta.pro/images/f6a0a369bd611d0e459d62d9d032a266.jpg'),
(26390, 1774, 'Riverdale S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232832.mp4', 'http://timg.bdta.pro/images/cf31b73185946fb67c20077480b88abd.jpg'),
(26391, 1774, 'Riverdale S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232833.mp4', 'http://timg.bdta.pro/images/2e0284b44f710c1e1d98bcff569b0448.jpg'),
(26392, 1774, 'Riverdale S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232834.mp4', 'http://timg.bdta.pro/images/6c49b68ca0cea08f44717e7c1a63ebeb.jpg'),
(26393, 1774, 'Riverdale S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232835.mp4', 'http://timg.bdta.pro/images/ad5bf73b26016da95d11c93cdbd421e4.jpg'),
(26394, 1774, 'Riverdale S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232836.mp4', 'http://timg.bdta.pro/images/b405a34809daa3a2d96c0c9b414d3931.jpg'),
(26395, 1774, 'Riverdale S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232837.mp4', 'http://timg.bdta.pro/images/ac9ea6f3e0f3f735b9172e2b1d66e514.jpg'),
(26396, 1774, 'Riverdale S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/232838.mp4', 'http://timg.bdta.pro/images/4bb7dea7c99784a3db34b03272c8ca3b.jpg'),
(26397, 1774, 'Riverdale S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/232839.mp4', 'http://timg.bdta.pro/images/e3f9400cfb2d505b3f23f0e20f89c644.jpg'),
(26398, 1774, 'Riverdale S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/232840.mp4', 'http://timg.bdta.pro/images/b7e14e25f853d0559fb7e8a8d232bdf1.jpg'),
(26399, 1774, 'Riverdale S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/232841.mp4', 'http://timg.bdta.pro/images/b1cda4213eefbd0b847bc9b8c0a8d9a9.jpg'),
(26400, 1774, 'Riverdale S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/232842.mp4', 'http://timg.bdta.pro/images/2ae8b870d72cfff7027d0a7c2a304719.jpg'),
(26401, 1774, 'Riverdale S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/232843.mp4', 'http://timg.bdta.pro/images/0f6dca7fb399aaf7edaa93c41974d6b3.jpg'),
(26402, 1774, 'Riverdale S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/232844.mp4', 'http://timg.bdta.pro/images/8692fd79fe2fa40e85e721d8ec4ca891.jpg'),
(26403, 1774, 'Riverdale S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/232845.mp4', 'http://timg.bdta.pro/images/3e51e63b388e567bbe4050e0b53e7d55.jpg'),
(26404, 1774, 'Riverdale S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/232846.mp4', 'http://timg.bdta.pro/images/214debd12fb849900c08496078c5bbbd.jpg'),
(26405, 1774, 'Riverdale S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/232847.mp4', 'http://timg.bdta.pro/images/7049e85b8667db4c261a8f1a5207bf67.jpg'),
(26406, 1775, 'Riverdale S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232848.mp4', 'http://timg.bdta.pro/images/edfa072187400239c623365a64f5cd3d.jpg'),
(26407, 1775, 'Riverdale S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232849.mp4', 'http://timg.bdta.pro/images/de81245700146832d8ccf50eb09e24f8.jpg'),
(26408, 1775, 'Riverdale S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232850.mp4', 'http://timg.bdta.pro/images/52ffd371baaedb42b7425fc8cc91d2f5.jpg'),
(26409, 1775, 'Riverdale S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232851.mp4', 'http://timg.bdta.pro/images/f930f01abcc492b61ee06022a7b884fb.jpg'),
(26410, 1775, 'Riverdale S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232852.mp4', 'http://timg.bdta.pro/images/27d7975f97acf8304d04f27e61ede15b.jpg'),
(26411, 1775, 'Riverdale S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232853.mp4', 'http://timg.bdta.pro/images/bc40805b1aae6712f9476ceeee5ad5ef.jpg'),
(26412, 1775, 'Riverdale S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232854.mp4', 'http://timg.bdta.pro/images/4317a78dce86c43137e7c3bc748c41ec.jpg'),
(26413, 1775, 'Riverdale S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232855.mp4', 'http://timg.bdta.pro/images/68274a19d9a53d3ca790f4c765a349b3.jpg'),
(26414, 1775, 'Riverdale S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232856.mp4', 'http://timg.bdta.pro/images/96af6340a6c75d59e2879fd2279adb4d.jpg'),
(26415, 1775, 'Riverdale S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232857.mp4', 'http://timg.bdta.pro/images/4f8772f5a8381bf6b1a380b58c1d2c3e.jpg'),
(26416, 1775, 'Riverdale S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232858.mp4', 'http://timg.bdta.pro/images/080f9205b42e8d1e17f8767288c6695a.jpg'),
(26417, 1775, 'Riverdale S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232859.mp4', 'http://timg.bdta.pro/images/043db2a5bb4fceabf9c1f54d4cf0559a.jpg'),
(26418, 1775, 'Riverdale S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/232860.mp4', 'http://timg.bdta.pro/images/9163532c8a543d9e0285feb95cd61c3e.jpg'),
(26419, 1775, 'Riverdale S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/232861.mp4', 'http://timg.bdta.pro/images/8d034c577a1424831420d485358e787c.jpg'),
(26420, 1775, 'Riverdale S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/232862.mp4', 'http://timg.bdta.pro/images/46d01f7868bb837715d461bcbc00d28a.jpg'),
(26421, 1775, 'Riverdale S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/232863.mp4', 'http://timg.bdta.pro/images/11bd8781b41b507901fa1570dabbd74e.jpg'),
(26422, 1775, 'Riverdale S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/232864.mp4', 'http://timg.bdta.pro/images/892d8020523fd60608ffb8d9e7fbe33b.jpg'),
(26423, 1775, 'Riverdale S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/232865.mp4', 'http://timg.bdta.pro/images/362fe3d97237bcea6a1c438bea55bd0f.jpg'),
(26424, 1775, 'Riverdale S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/232866.mp4', 'http://timg.bdta.pro/images/1ecb11a0d54d6af84d0abfd698b29708.jpg'),
(26425, 1775, 'Riverdale S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/232867.mp4', 'http://timg.bdta.pro/images/636669804d9c770605f7d177bb695962.jpg'),
(26426, 1775, 'Riverdale S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/232868.mp4', 'http://timg.bdta.pro/images/1d2b83f18a3aa4ac39335028fff504db.jpg'),
(26427, 1775, 'Riverdale S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/232869.mp4', 'http://timg.bdta.pro/images/d03378c505afcb02256ea55036e6ef61.jpg'),
(26428, 1776, 'Riverdale S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232870.mp4', 'http://timg.bdta.pro/images/61ffbf6afd8a58e096d3b588b182318b.jpg'),
(26429, 1776, 'Riverdale S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232871.mp4', 'http://timg.bdta.pro/images/85e04e3971c68c377a7f5832d76e63d7.jpg'),
(26430, 1776, 'Riverdale S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232872.mp4', 'http://timg.bdta.pro/images/5e2f56542ccb7ad43aec62e6b304cc99.jpg'),
(26431, 1776, 'Riverdale S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232873.mp4', 'http://timg.bdta.pro/images/42e9d6f293984138910d88ab7512dad3.jpg'),
(26432, 1776, 'Riverdale S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232874.mp4', 'http://timg.bdta.pro/images/af4cff04c357dbdf766d5df254865ce9.jpg'),
(26433, 1776, 'Riverdale S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232875.mp4', 'http://timg.bdta.pro/images/21fb1384716ad2f6f322f0de744c7c13.jpg'),
(26434, 1776, 'Riverdale S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232876.mp4', 'http://timg.bdta.pro/images/49bbc64e921ea0af085fd8c0c1af7903.jpg'),
(26435, 1776, 'Riverdale S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232877.mp4', 'http://timg.bdta.pro/images/a67d120c597f42ac38a7c4a0ec12172b.jpg'),
(26436, 1776, 'Riverdale S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232878.mp4', 'http://timg.bdta.pro/images/058b91ddd72e4b9d2222cdb4a9a2ca5f.jpg'),
(26437, 1776, 'Riverdale S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232879.mp4', 'http://timg.bdta.pro/images/4aceb0f4bf5da4ecfdabdff767eab829.jpg'),
(26438, 1776, 'Riverdale S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232880.mp4', 'http://timg.bdta.pro/images/53b721af0798a01e4658be7f32d1898a.jpg'),
(26439, 1776, 'Riverdale S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232881.mp4', 'http://timg.bdta.pro/images/9004f4d6ea86ebd7eb00526b70c6b373.jpg'),
(26440, 1776, 'Riverdale S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/232882.mp4', 'http://timg.bdta.pro/images/d95b812a66d2b40f6e61039b7bca29f5.jpg'),
(26441, 1776, 'Riverdale S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/232883.mp4', 'http://timg.bdta.pro/images/72fa7a9cf01326b909815aa9d7ea49c0.jpg'),
(26442, 1776, 'Riverdale S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/232884.mp4', 'http://timg.bdta.pro/images/be5288f168b2c5e8b25f51d3d9b5aeb5.jpg'),
(26443, 1776, 'Riverdale S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/232885.mp4', 'http://timg.bdta.pro/images/0cc8de8577c75af7bfc926b634b80b0f.jpg'),
(26444, 1777, 'Riverdale S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232886.mp4', 'http://timg.bdta.pro/images/14d970a1025f83a6868ffc2f3d782ca4.jpg'),
(26445, 1777, 'Riverdale S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232887.mp4', 'http://timg.bdta.pro/images/1fced1102dd1ab27e31ffeb0f202812a.jpg'),
(26446, 1777, 'Riverdale S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232888.mp4', 'http://timg.bdta.pro/images/77d730b63229db9563940800cd0284cf.jpg'),
(26447, 1777, 'Riverdale S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232889.mp4', 'http://timg.bdta.pro/images/255f48722375eb5f73b71e1b75481d12.jpg'),
(26448, 1777, 'Riverdale S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232890.mp4', 'http://timg.bdta.pro/images/27f7b28a2f30fccfe32857e6c9a2afe2.jpg'),
(26449, 1777, 'Riverdale S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232891.mp4', 'http://timg.bdta.pro/images/c95559a9e228c664c7e64bf0a95204cc.jpg'),
(26450, 1777, 'Riverdale S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232892.mp4', 'http://timg.bdta.pro/images/125609adae0f9fb0252c02f52ce196db.jpg'),
(26451, 1777, 'Riverdale S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232893.mp4', 'http://timg.bdta.pro/images/093f6a871852ba7513f65f03c9ad4bbd.jpg'),
(26452, 1777, 'Riverdale S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232894.mp4', 'http://timg.bdta.pro/images/240249603b3947f24be4c3a56715234e.jpg'),
(26453, 1777, 'Riverdale S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232895.mp4', 'http://timg.bdta.pro/images/6c79c3f3d5ad7327bcc61d820da961f9.jpg'),
(26454, 1777, 'Riverdale S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232896.mp4', 'http://timg.bdta.pro/images/ea3c7374fa1a7d02c913672f2575211b.jpg'),
(26455, 1777, 'Riverdale S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232897.mp4', 'http://timg.bdta.pro/images/06bb36b9ad4036a8d4cd62dcf7ae192e.jpg'),
(26456, 1777, 'Riverdale S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/232898.mp4', 'http://timg.bdta.pro/images/9f7384f0c1ba5bd6441494bce50c7e1d.jpg'),
(26457, 1777, 'Riverdale S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/232899.mp4', 'http://timg.bdta.pro/images/20ff5a2250bd2a3a414691dc81064bf8.jpg'),
(26458, 1777, 'Riverdale S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/232900.mp4', 'http://image.tmdb.org/t/p/w1280/s3VzYTJ3wZdRLdV1b7Xh5PK0OFz.jpg'),
(26459, 1777, 'Riverdale S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/232901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/an3SLay7v6cRgf7UHn9foTxPwyb.jpg'),
(26460, 1777, 'Riverdale S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/232902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nF61L5d7Rfs4fDtdfpTGFcG2qkz.jpg'),
(26461, 1777, 'Riverdale S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/232903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h46taXNN4eeqRutafurhsswh8nP.jpg'),
(26462, 1777, 'Riverdale S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/232904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/urWm7U1SFhY1vVe5BPnD9HqRZcW.jpg'),
(26463, 1778, 'Riverdale S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232905.mp4', 'http://timg.bdta.pro/images/363ae42646a455789f52db870865e88b.jpg'),
(26464, 1778, 'Riverdale S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232906.mp4', 'http://timg.bdta.pro/images/1088b09f391513b270580b8e3225c540.jpg'),
(26465, 1778, 'Riverdale S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232907.mp4', 'http://timg.bdta.pro/images/3803cdf3e707abd3442db632bfdd6b38.jpg'),
(26466, 1778, 'Riverdale S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232908.mp4', 'http://timg.bdta.pro/images/5dc06565223bd697590e6552e2f6d644.jpg'),
(26467, 1778, 'Riverdale S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232909.mp4', 'http://timg.bdta.pro/images/3888a4d8f5353eecf9d0049056de3419.jpg'),
(26468, 1778, 'Riverdale S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232910.mp4', 'http://timg.bdta.pro/images/e60f613eb5afec2a7c8b6bf0e232c7e1.jpg'),
(26469, 1778, 'Riverdale S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232911.mp4', 'http://timg.bdta.pro/images/c894522801bbc65bcef365efbeff3687.jpg'),
(26470, 1778, 'Riverdale S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232912.mp4', 'http://timg.bdta.pro/images/6ff9e730cf10487ab723fcf787f1276d.jpg'),
(26471, 1778, 'Riverdale S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232913.mp4', 'http://timg.bdta.pro/images/a5878b06faaa0438c0d720fb9f1ee02c.jpg'),
(26472, 1778, 'Riverdale S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232914.mp4', 'http://timg.bdta.pro/images/556fd00bf35449a004f0c358e66c17dd.jpg'),
(26473, 1778, 'Riverdale S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232915.mp4', 'http://timg.bdta.pro/images/478b5048231bc1c415a2ae87917bf239.jpg'),
(26474, 1778, 'Riverdale S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232916.mp4', 'http://timg.bdta.pro/images/755bcc84e36a302700fe08cffa584404.jpg'),
(26475, 1778, 'Riverdale S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/232917.mp4', 'http://timg.bdta.pro/images/814373a63f99b26a01577aa83db68240.jpg'),
(26476, 1778, 'Riverdale S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/232918.mp4', 'http://timg.bdta.pro/images/096ecb2d0c3530ad6d17f65e562c0d21.jpg'),
(26477, 1778, 'Riverdale S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/232919.mp4', 'http://timg.bdta.pro/images/8b0b8d73ded4923fef7bab6b23a7659b.jpg'),
(26478, 1778, 'Riverdale S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/232920.mp4', 'http://timg.bdta.pro/images/0e23f717874b117d30bd7af7e8494df4.jpg'),
(26479, 1778, 'Riverdale S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/232921.mp4', 'http://timg.bdta.pro/images/71956d30077a1ba28eeceee08ddf8f5e.jpg'),
(26480, 1778, 'Riverdale S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/232922.mp4', 'http://timg.bdta.pro/images/e84fe8e9c62ea6fdbd4e1d41c2fa8008.jpg'),
(26481, 1778, 'Riverdale S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/232923.mp4', 'http://timg.bdta.pro/images/b32a76d33db9da5b35a9fcac04a9f78e.jpg'),
(26482, 1778, 'Riverdale S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/232924.mp4', 'http://timg.bdta.pro/images/720d2c966954f5b834069f619d6be9e3.jpg'),
(26483, 1778, 'Riverdale S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/232925.mp4', 'http://timg.bdta.pro/images/67235223fe25b8a9e1403a307b42781d.jpg'),
(26484, 1778, 'Riverdale S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/232926.mp4', 'http://timg.bdta.pro/images/5d2950d96d1ead936f723e4970ffcea1.jpg'),
(26485, 1779, 'Riverdale S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232927.mp4', 'http://image.tmdb.org/t/p/w1280/bwYhzeK1MVfH6SrLSEvTxuyGloT.jpg'),
(26486, 1779, 'Riverdale S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232928.mp4', 'http://image.tmdb.org/t/p/w1280/fKczZ5gDZTTagKijnLB3mkqVqhx.jpg'),
(26487, 1779, 'Riverdale S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232929.mp4', 'http://image.tmdb.org/t/p/w1280/hGw7Q0D25onFkP9hL3RhkA5DTxT.jpg'),
(26488, 1779, 'Riverdale S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232930.mp4', 'http://image.tmdb.org/t/p/w1280/igPlqMQPuKBeRyd7iWeqisEQ3Lv.jpg'),
(26489, 1779, 'Riverdale S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232931.mp4', 'http://image.tmdb.org/t/p/w1280/eFaYKgmQYd7cq5ar5ACxAP3EGFN.jpg'),
(26490, 1779, 'Riverdale S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232932.mp4', 'http://image.tmdb.org/t/p/w1280/wnTNfC1YHoWcrWIjA3bhU40wE7G.jpg'),
(26491, 1779, 'Riverdale S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9naVppZpsBauMvSsdaAGvESDPVO.jpg'),
(26492, 1779, 'Riverdale S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kl3Qg9wzwUR2XrtYcBwErP2Bh2Y.jpg'),
(26493, 1779, 'Riverdale S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ibvkIcFuECEDzQuzMhCbD4Eg9ex.jpg'),
(26494, 1779, 'Riverdale S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/srsh24yiGOoaggLLvKBbyxkuoak.jpg'),
(26495, 1779, 'Riverdale S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qz80IxWODSPVPz1b25LzUPl3uxB.jpg'),
(26496, 1779, 'Riverdale S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8gekLRugqszY64G2Lr5tLOEIjgA.jpg'),
(26497, 1779, 'Riverdale S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/232939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1jmeKf3C038oOHE57RSifMIg5z5.jpg'),
(26498, 1779, 'Riverdale S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/232940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bGDfy4AjIZkBTV3JpRMSeUaMpjt.jpg'),
(26499, 1779, 'Riverdale S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/232941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5HKltbDLElW4dTceLlpp2Bwutao.jpg'),
(26500, 1779, 'Riverdale S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/232942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iBjTQgEK87UOUmHoHfzZNbnjbkg.jpg'),
(26501, 1779, 'Riverdale S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/232943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ikWQSYmd1fTWDjvbGBKjJLsH4Yt.jpg'),
(26502, 1779, 'Riverdale S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/232944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uY3MHHltuKBFuAw8wn1aFLf2DW1.jpg'),
(26503, 1779, 'Riverdale S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/232945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cPsWccszLHF9r336NNZL5Qxibbn.jpg'),
(26504, 1779, 'Riverdale S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/232946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/OrtjXZmvx03MKjxRe3goJGKN3h.jpg'),
(26505, 1780, 'The Circle Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110279.mp4', 'http://timg.bdta.pro/images/2de4a4268764cf6764c1fe31e95ab7f7.jpg'),
(26506, 1780, 'The Circle Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110280.mp4', 'http://timg.bdta.pro/images/c83f9aa1bca59fb0faa6e729e149bf2f.jpg'),
(26507, 1780, 'The Circle Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110281.mp4', 'http://timg.bdta.pro/images/4326a9a56b9f517d556356dba7d6e108.jpg'),
(26508, 1780, 'The Circle Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110282.mp4', 'http://timg.bdta.pro/images/e40ece36a8ea1b2242a616372d5e9227.jpg'),
(26509, 1780, 'The Circle Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110283.mp4', 'http://timg.bdta.pro/images/0efffb4548e8341c5996f74afbf0c026.jpg'),
(26510, 1780, 'The Circle Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110284.mp4', 'http://timg.bdta.pro/images/0efffb4548e8341c5996f74afbf0c026.jpg'),
(26511, 1780, 'The Circle Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110285.mp4', 'http://timg.bdta.pro/images/0efffb4548e8341c5996f74afbf0c026.jpg'),
(26512, 1780, 'The Circle Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110286.mp4', 'http://timg.bdta.pro/images/0efffb4548e8341c5996f74afbf0c026.jpg'),
(26513, 1780, 'The Circle Brasil S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/110287.mp4', 'http://gstaticontent.com/images/w0SInlIR3VS7MNVBVdh8J17S3od_big.jpg'),
(26514, 1780, 'The Circle Brasil S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/110288.mp4', 'http://gstaticontent.com/images/w0SInlIR3VS7MNVBVdh8J17S3od_big.jpg'),
(26515, 1780, 'The Circle Brasil S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/110289.mp4', 'http://gstaticontent.com/images/w0SInlIR3VS7MNVBVdh8J17S3od_big.jpg'),
(26516, 1780, 'The Circle Brasil S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/110290.mp4', 'http://gstaticontent.com/images/w0SInlIR3VS7MNVBVdh8J17S3od_big.jpg'),
(26517, 1781, 'A História do Imagineering S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110496.mp4', 'http://timg.bdta.pro/images/0eed7980ec90d2f105533d2347827e69.jpg'),
(26518, 1781, 'A História do Imagineering S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110497.mp4', 'http://timg.bdta.pro/images/c81aa335dc20192c53482632ebff4efc.jpg'),
(26519, 1781, 'A História do Imagineering S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110498.mp4', 'http://timg.bdta.pro/images/db5e191a591a73775ff535efad7aef63.jpg'),
(26520, 1781, 'A História do Imagineering S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110499.mp4', 'http://timg.bdta.pro/images/24387a297f11ffd141147eec01b01a92.jpg'),
(26521, 1781, 'A História do Imagineering S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110500.mp4', 'http://timg.bdta.pro/images/cbc3eac25b7ff21787d2be89d7e7d931.jpg'),
(26522, 1781, 'A História do Imagineering S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110501.mp4', 'http://timg.bdta.pro/images/639bcedf44128f9e466283987d399d9b.jpg'),
(26523, 1782, 'Marielle O Documentario S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110490.mp4', 'http://gstaticontent.com/images/Znd1Vvku9q5veBaHYQM5A04E8E_big.jpg'),
(26524, 1782, 'Marielle O Documentario S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110491.mp4', 'http://gstaticontent.com/images/Znd1Vvku9q5veBaHYQM5A04E8E_big.jpg'),
(26525, 1782, 'Marielle O Documentario S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110492.mp4', 'http://gstaticontent.com/images/Znd1Vvku9q5veBaHYQM5A04E8E_big.jpg'),
(26526, 1782, 'Marielle O Documentario S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110493.mp4', 'http://gstaticontent.com/images/Znd1Vvku9q5veBaHYQM5A04E8E_big.jpg'),
(26527, 1782, 'Marielle O Documentario S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110494.mp4', 'http://gstaticontent.com/images/Znd1Vvku9q5veBaHYQM5A04E8E_big.jpg'),
(26528, 1782, 'Marielle O Documentario S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110495.mp4', 'http://gstaticontent.com/images/Znd1Vvku9q5veBaHYQM5A04E8E_big.jpg'),
(26529, 1783, 'Meu Nome é S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110487.mp4', 'http://gstaticontent.com/images/oogunE22HDTcTxFakKQbwqfw1qo_big.jpg'),
(26530, 1783, 'Meu Nome é S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110488.mp4', 'http://gstaticontent.com/images/oogunE22HDTcTxFakKQbwqfw1qo_big.jpg'),
(26531, 1783, 'Meu Nome é S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110489.mp4', 'http://gstaticontent.com/images/oogunE22HDTcTxFakKQbwqfw1qo_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(26532, 1784, '100 Humanos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110479.mp4', 'http://gstaticontent.com/images/ykN9uhnGdtjvx9Lk8bYvdprNQsC_big.jpg'),
(26533, 1784, '100 Humanos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110480.mp4', 'http://gstaticontent.com/images/ykN9uhnGdtjvx9Lk8bYvdprNQsC_big.jpg'),
(26534, 1784, '100 Humanos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110481.mp4', 'http://gstaticontent.com/images/ykN9uhnGdtjvx9Lk8bYvdprNQsC_big.jpg'),
(26535, 1784, '100 Humanos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110482.mp4', 'http://gstaticontent.com/images/ykN9uhnGdtjvx9Lk8bYvdprNQsC_big.jpg'),
(26536, 1784, '100 Humanos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110483.mp4', 'http://gstaticontent.com/images/ykN9uhnGdtjvx9Lk8bYvdprNQsC_big.jpg'),
(26537, 1784, '100 Humanos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110484.mp4', 'http://gstaticontent.com/images/ykN9uhnGdtjvx9Lk8bYvdprNQsC_big.jpg'),
(26538, 1784, '100 Humanos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110485.mp4', 'http://gstaticontent.com/images/ykN9uhnGdtjvx9Lk8bYvdprNQsC_big.jpg'),
(26539, 1784, '100 Humanos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110486.mp4', 'http://gstaticontent.com/images/ykN9uhnGdtjvx9Lk8bYvdprNQsC_big.jpg'),
(26540, 1785, 'Between S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110467.mp4', 'http://timg.bdta.pro/images/fa01485ef2a36d262308345847144fa7.jpg'),
(26541, 1785, 'Between S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110468.mp4', 'http://timg.bdta.pro/images/db16509285057b46d337c1f1792e57fe.jpg'),
(26542, 1785, 'Between S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110469.mp4', 'http://timg.bdta.pro/images/f3ee6c5038538fc21816dc57d6b1466b.jpg'),
(26543, 1785, 'Between S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110470.mp4', 'http://timg.bdta.pro/images/5c2677f5f488fe3a2d081aa279781d2d.jpg'),
(26544, 1785, 'Between S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110471.mp4', 'http://timg.bdta.pro/images/44f6efa847f36922ba8c4f4bf034b984.jpg'),
(26545, 1785, 'Between S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110472.mp4', 'http://timg.bdta.pro/images/d9edc325f219c4756de661e52b777020.jpg'),
(26546, 1786, 'Between S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110473.mp4', 'http://timg.bdta.pro/images/2ae950237c1c2f246a94f4165fcd646c.jpg'),
(26547, 1786, 'Between S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110474.mp4', 'http://timg.bdta.pro/images/5738fd534124771e1295d0906a4c7fc4.jpg'),
(26548, 1786, 'Between S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110475.mp4', 'http://timg.bdta.pro/images/8f3203b696445095dd8aacdeb2c73940.jpg'),
(26549, 1786, 'Between S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110476.mp4', 'http://timg.bdta.pro/images/8c82e2b950a6596981bf1c237bde1115.jpg'),
(26550, 1786, 'Between S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110477.mp4', 'http://timg.bdta.pro/images/54fcaa2e253207a310b2ea2e0dc6250e.jpg'),
(26551, 1786, 'Between S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110478.mp4', 'http://timg.bdta.pro/images/e7b996d788c1dbfef1f795257aadba0e.jpg'),
(26552, 1787, 'Califado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110459.mp4', 'http://timg.bdta.pro/images/e7b996d788c1dbfef1f795257aadba0e.jpg'),
(26553, 1787, 'Califado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110460.mp4', 'http://timg.bdta.pro/images/e7b996d788c1dbfef1f795257aadba0e.jpg'),
(26554, 1787, 'Califado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110461.mp4', 'http://timg.bdta.pro/images/e7b996d788c1dbfef1f795257aadba0e.jpg'),
(26555, 1787, 'Califado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110462.mp4', 'http://timg.bdta.pro/images/e7b996d788c1dbfef1f795257aadba0e.jpg'),
(26556, 1787, 'Califado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110463.mp4', 'http://timg.bdta.pro/images/e7b996d788c1dbfef1f795257aadba0e.jpg'),
(26557, 1787, 'Califado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110464.mp4', 'http://timg.bdta.pro/images/e7b996d788c1dbfef1f795257aadba0e.jpg'),
(26558, 1787, 'Califado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110465.mp4', 'http://timg.bdta.pro/images/e7b996d788c1dbfef1f795257aadba0e.jpg'),
(26559, 1787, 'Califado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110466.mp4', 'http://timg.bdta.pro/images/e7b996d788c1dbfef1f795257aadba0e.jpg'),
(26560, 1788, 'Coletivo Terror S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110453.mp4', 'http://timg.bdta.pro/images/07dbed6a4ab798abaa9e48ee63d6ba6b.jpg'),
(26561, 1788, 'Coletivo Terror S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110454.mp4', 'http://timg.bdta.pro/images/8cdb38d1ff82de55a59c2ed25cbc74b5.jpg'),
(26562, 1788, 'Coletivo Terror S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110455.mp4', 'http://timg.bdta.pro/images/bfde42dec90c4b9ac6f8c984a54a71a7.jpg'),
(26563, 1788, 'Coletivo Terror S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110456.mp4', 'http://timg.bdta.pro/images/921981e4d164865d8c6e7b9a641f174a.jpg'),
(26564, 1788, 'Coletivo Terror S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110457.mp4', 'http://timg.bdta.pro/images/a1dbb7b1082224f81700b29c6bd6e9ef.jpg'),
(26565, 1788, 'Coletivo Terror S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110458.mp4', 'http://timg.bdta.pro/images/b7ef8d290a340fa2644e35fc106bf9f7.jpg'),
(26566, 1789, 'a Vó e a Boi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110447.mp4', 'http://timg.bdta.pro/images/8d426619c84c5e3952b77ebad395fb0a.jpg'),
(26567, 1789, 'a Vó e a Boi S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110448.mp4', 'http://timg.bdta.pro/images/f2d0a680526e7193c04e119f929daaff.jpg'),
(26568, 1789, 'a Vó e a Boi S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110449.mp4', 'http://timg.bdta.pro/images/d3bbcf46db2276214dcd4588e0a46d83.jpg'),
(26569, 1789, 'a Vó e a Boi S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110450.mp4', 'http://timg.bdta.pro/images/0ad30209ddf72ea90446d8f26beccc85.jpg'),
(26570, 1789, 'a Vó e a Boi S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110451.mp4', 'http://timg.bdta.pro/images/745d9197b46b46574cb9f0ce1776c98d.jpg'),
(26571, 1789, 'a Vó e a Boi S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110452.mp4', 'http://timg.bdta.pro/images/7971edea949b411b30cb7eeac46e0a0a.jpg'),
(26572, 1790, 'Jo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/528899.mp4', 'http://gstaticontent.com/images/l0UHTjvEwpsbJlLyQbVTupcR9lU_big.jpg'),
(26573, 1790, 'Jo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110445.mp4', 'http://gstaticontent.com/images/l0UHTjvEwpsbJlLyQbVTupcR9lU_big.jpg'),
(26574, 1790, 'Jo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110446.mp4', 'http://gstaticontent.com/images/l0UHTjvEwpsbJlLyQbVTupcR9lU_big.jpg'),
(26575, 1791, 'Manhunt Unabomber S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124505.mp4', 'http://timg.bdta.pro/images/48e612f43bf0372412408e0d284a0734.jpg'),
(26576, 1791, 'Manhunt Unabomber S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124506.mp4', 'http://timg.bdta.pro/images/c2bce4b0b2b971da9b26fafff774bd17.jpg'),
(26577, 1791, 'Manhunt Unabomber S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124507.mp4', 'http://timg.bdta.pro/images/44f75376a986d21b39c1e8b78726be3f.jpg'),
(26578, 1791, 'Manhunt Unabomber S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124508.mp4', 'http://timg.bdta.pro/images/6414bae614524cba098caa510cd65ac3.jpg'),
(26579, 1791, 'Manhunt Unabomber S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124509.mp4', 'http://timg.bdta.pro/images/9328daafa3b8a8fd73fbe7d4326cc4c9.jpg'),
(26580, 1791, 'Manhunt Unabomber S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124510.mp4', 'http://timg.bdta.pro/images/3bde9fcc4d809d9679ab38c67513af8b.jpg'),
(26581, 1791, 'Manhunt Unabomber S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124511.mp4', 'http://timg.bdta.pro/images/ab37c042a64bd58d9fd62a2b5b8e86e1.jpg'),
(26582, 1791, 'Manhunt Unabomber S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124512.mp4', 'http://timg.bdta.pro/images/6cc6dcb3a3abf1d40bd7b30bd5c8b846.jpg'),
(26583, 1792, 'Manhunt Unabomber S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124513.mp4', 'http://timg.bdta.pro/images/a3df47163bc78d9fc28c0e46439ebfa8.jpg'),
(26584, 1792, 'Manhunt Unabomber S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124514.mp4', 'http://timg.bdta.pro/images/881aca4ee541781e51239e7b92d5b1a0.jpg'),
(26585, 1792, 'Manhunt Unabomber S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124515.mp4', 'http://timg.bdta.pro/images/3af9cd0cdd5d11010783d962d787e9e4.jpg'),
(26586, 1792, 'Manhunt Unabomber S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124516.mp4', 'http://timg.bdta.pro/images/b7720bea5004abb838bcb8f75ca72d4e.jpg'),
(26587, 1792, 'Manhunt Unabomber S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124517.mp4', 'http://timg.bdta.pro/images/155364c96a32a39a39d556cb0f855e6b.jpg'),
(26588, 1792, 'Manhunt Unabomber S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124518.mp4', 'http://timg.bdta.pro/images/39ddae5ac3efdf73c50183e34e0f3f12.jpg'),
(26589, 1792, 'Manhunt Unabomber S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124519.mp4', 'http://timg.bdta.pro/images/2219f40d9c2e9f8af6ddd9ebec0a35ca.jpg'),
(26590, 1792, 'Manhunt Unabomber S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124520.mp4', 'http://timg.bdta.pro/images/659646c1352038e880ea79488197134f.jpg'),
(26591, 1792, 'Manhunt Unabomber S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124521.mp4', 'http://timg.bdta.pro/images/3b565885ee0e4270930b3b124a30f755.jpg'),
(26592, 1792, 'Manhunt Unabomber S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124522.mp4', 'http://timg.bdta.pro/images/9a14ac8476ef882040e14f734edccd22.jpg'),
(26593, 1793, 'Morte e Rouxinóis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110424.mp4', 'http://timg.bdta.pro/images/cfbfb215bfae48b8610a295ab1c7ace4.jpg'),
(26594, 1793, 'Morte e Rouxinóis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110425.mp4', 'http://timg.bdta.pro/images/630529bf103193bdec6a6ecfe19e9e6c.jpg'),
(26595, 1793, 'Morte e Rouxinóis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110426.mp4', 'http://timg.bdta.pro/images/6532475141467c14418b15d7af623a44.jpg'),
(26596, 1794, 'Mulheres da Noite S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110414.mp4', 'http://timg.bdta.pro/images/6532475141467c14418b15d7af623a44.jpg'),
(26597, 1794, 'Mulheres da Noite S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110415.mp4', 'http://timg.bdta.pro/images/6532475141467c14418b15d7af623a44.jpg'),
(26598, 1794, 'Mulheres da Noite S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110416.mp4', 'http://timg.bdta.pro/images/6532475141467c14418b15d7af623a44.jpg'),
(26599, 1794, 'Mulheres da Noite S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110417.mp4', 'http://timg.bdta.pro/images/6532475141467c14418b15d7af623a44.jpg'),
(26600, 1794, 'Mulheres da Noite S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110418.mp4', 'http://timg.bdta.pro/images/6532475141467c14418b15d7af623a44.jpg'),
(26601, 1794, 'Mulheres da Noite S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110419.mp4', 'http://timg.bdta.pro/images/6532475141467c14418b15d7af623a44.jpg'),
(26602, 1794, 'Mulheres da Noite S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110420.mp4', 'http://timg.bdta.pro/images/6532475141467c14418b15d7af623a44.jpg'),
(26603, 1794, 'Mulheres da Noite S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110421.mp4', 'http://timg.bdta.pro/images/6532475141467c14418b15d7af623a44.jpg'),
(26604, 1794, 'Mulheres da Noite S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/110422.mp4', 'http://timg.bdta.pro/images/6532475141467c14418b15d7af623a44.jpg'),
(26605, 1794, 'Mulheres da Noite S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/110423.mp4', 'http://timg.bdta.pro/images/6532475141467c14418b15d7af623a44.jpg'),
(26606, 1795, 'O Assassino de Valhalla S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110406.mp4', 'http://timg.bdta.pro/images/fff13e79b6b76c6a434d5d859b1830c9.jpg'),
(26607, 1795, 'O Assassino de Valhalla S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110407.mp4', 'http://timg.bdta.pro/images/e3b3b1dcdc01654017fb65bb6ffd9078.jpg'),
(26608, 1795, 'O Assassino de Valhalla S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110408.mp4', 'http://timg.bdta.pro/images/9394774c4b92ca4a22b35ea5a8ee911c.jpg'),
(26609, 1795, 'O Assassino de Valhalla S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110409.mp4', 'http://timg.bdta.pro/images/7c4ce10ddcff5386857c965e014ae5cc.jpg'),
(26610, 1795, 'O Assassino de Valhalla S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110410.mp4', 'http://timg.bdta.pro/images/4a860c5170013028f7b174736a5ddc48.jpg'),
(26611, 1795, 'O Assassino de Valhalla S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110411.mp4', 'http://timg.bdta.pro/images/cb89f2449923580124249f73170e28ea.jpg'),
(26612, 1795, 'O Assassino de Valhalla S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110412.mp4', 'http://timg.bdta.pro/images/9c39ed462f4f83a80b26b342afd7af7e.jpg'),
(26613, 1795, 'O Assassino de Valhalla S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110413.mp4', 'http://timg.bdta.pro/images/7c40aa658edb3cbd49bfeba3aee021c3.jpg'),
(26614, 1796, 'Schitt\'s Creek S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131463.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26615, 1796, 'Schitt\'s Creek S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131464.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26616, 1796, 'Schitt\'s Creek S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131465.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26617, 1796, 'Schitt\'s Creek S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131466.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26618, 1796, 'Schitt\'s Creek S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131467.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26619, 1796, 'Schitt\'s Creek S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131468.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26620, 1796, 'Schitt\'s Creek S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131469.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26621, 1796, 'Schitt\'s Creek S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131470.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26622, 1796, 'Schitt\'s Creek S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131471.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26623, 1796, 'Schitt\'s Creek S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131472.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26624, 1796, 'Schitt\'s Creek S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131473.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26625, 1796, 'Schitt\'s Creek S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131474.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26626, 1796, 'Schitt\'s Creek S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131475.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26627, 1797, 'Schitt\'s Creek S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131476.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26628, 1797, 'Schitt\'s Creek S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131477.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26629, 1797, 'Schitt\'s Creek S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131478.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26630, 1797, 'Schitt\'s Creek S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131479.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26631, 1797, 'Schitt\'s Creek S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131480.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26632, 1797, 'Schitt\'s Creek S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131481.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26633, 1797, 'Schitt\'s Creek S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131482.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26634, 1797, 'Schitt\'s Creek S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131483.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26635, 1797, 'Schitt\'s Creek S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131484.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26636, 1797, 'Schitt\'s Creek S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131485.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26637, 1797, 'Schitt\'s Creek S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131486.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26638, 1797, 'Schitt\'s Creek S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131487.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26639, 1797, 'Schitt\'s Creek S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131488.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26640, 1798, 'Schitt\'s Creek S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131489.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26641, 1798, 'Schitt\'s Creek S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131490.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26642, 1798, 'Schitt\'s Creek S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131491.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26643, 1798, 'Schitt\'s Creek S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131492.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26644, 1798, 'Schitt\'s Creek S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131493.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26645, 1798, 'Schitt\'s Creek S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131494.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26646, 1798, 'Schitt\'s Creek S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131495.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26647, 1798, 'Schitt\'s Creek S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131496.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26648, 1798, 'Schitt\'s Creek S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131497.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26649, 1798, 'Schitt\'s Creek S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131498.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26650, 1798, 'Schitt\'s Creek S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131499.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26651, 1798, 'Schitt\'s Creek S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131500.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26652, 1798, 'Schitt\'s Creek S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131501.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26653, 1799, 'Schitt\'s Creek S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131502.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26654, 1799, 'Schitt\'s Creek S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131503.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26655, 1799, 'Schitt\'s Creek S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131504.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26656, 1799, 'Schitt\'s Creek S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131505.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26657, 1799, 'Schitt\'s Creek S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131506.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26658, 1799, 'Schitt\'s Creek S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131507.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26659, 1799, 'Schitt\'s Creek S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131508.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26660, 1799, 'Schitt\'s Creek S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131509.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26661, 1799, 'Schitt\'s Creek S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131510.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26662, 1799, 'Schitt\'s Creek S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131511.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26663, 1799, 'Schitt\'s Creek S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131512.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26664, 1799, 'Schitt\'s Creek S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131513.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26665, 1799, 'Schitt\'s Creek S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131514.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26666, 1800, 'Schitt\'s Creek S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131515.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26667, 1800, 'Schitt\'s Creek S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131516.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26668, 1800, 'Schitt\'s Creek S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131517.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26669, 1800, 'Schitt\'s Creek S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131518.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26670, 1800, 'Schitt\'s Creek S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131519.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26671, 1800, 'Schitt\'s Creek S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131520.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26672, 1800, 'Schitt\'s Creek S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131521.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26673, 1800, 'Schitt\'s Creek S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131522.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26674, 1800, 'Schitt\'s Creek S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131523.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26675, 1800, 'Schitt\'s Creek S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131524.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26676, 1800, 'Schitt\'s Creek S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131525.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26677, 1800, 'Schitt\'s Creek S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131526.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26678, 1800, 'Schitt\'s Creek S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131527.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26679, 1800, 'Schitt\'s Creek S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131528.mp4', 'http://gstaticontent.com/images/iRfSzrPS5VYWQv7KVSEg2BZZL6C_big.jpg'),
(26680, 1801, 'Submersos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109960.mp4', 'http://timg.bdta.pro/images/0efffb4548e8341c5996f74afbf0c026.jpg'),
(26681, 1801, 'Submersos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109961.mp4', 'http://gstaticontent.com/images/9fkm1Ak7e6ytvx60XKEt3pfQdtr_big.jpg'),
(26682, 1801, 'Submersos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109962.mp4', 'http://gstaticontent.com/images/9fkm1Ak7e6ytvx60XKEt3pfQdtr_big.jpg'),
(26683, 1801, 'Submersos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109963.mp4', 'http://gstaticontent.com/images/9fkm1Ak7e6ytvx60XKEt3pfQdtr_big.jpg'),
(26684, 1802, 'The Plot Against America S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109957.mp4', 'http://timg.bdta.pro/images/434b982c63cea848bf0db5220c475961.jpg'),
(26685, 1802, 'The Plot Against America S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109958.mp4', 'http://timg.bdta.pro/images/3d8a5efc1aee2eba761b823c771d8c08.jpg'),
(26686, 1802, 'The Plot Against America S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109959.mp4', 'http://timg.bdta.pro/images/1faac0bc667d066262a2557fa02d3a0e.jpg'),
(26687, 1803, 'Um Milhão de Coisas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231762.mp4', 'http://timg.bdta.pro/images/6e27b3a56d5a1050a2ea711bf0f5f484.jpg'),
(26688, 1803, 'Um Milhão de Coisas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231763.mp4', 'http://timg.bdta.pro/images/7db7592ee621a924abb74d86cc8f47ba.jpg'),
(26689, 1803, 'Um Milhão de Coisas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231764.mp4', 'http://timg.bdta.pro/images/c3c9570fef9582ba925b7fca45a61ec8.jpg'),
(26690, 1803, 'Um Milhão de Coisas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231765.mp4', 'http://timg.bdta.pro/images/dec42acbb01b3e0fcc3fa5057dbe2d8f.jpg'),
(26691, 1803, 'Um Milhão de Coisas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231766.mp4', 'http://timg.bdta.pro/images/2e4b8f68e8bc07dab03b278477d487ee.jpg'),
(26692, 1803, 'Um Milhão de Coisas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231767.mp4', 'http://timg.bdta.pro/images/8c4031cd10f15250e1b88358c8bdfa3e.jpg'),
(26693, 1803, 'Um Milhão de Coisas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231768.mp4', 'http://timg.bdta.pro/images/6b458ea6f73c7468ea980f68518671fa.jpg'),
(26694, 1803, 'Um Milhão de Coisas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231769.mp4', 'http://timg.bdta.pro/images/b43f782af0876e94405f37fcdeaf5e92.jpg'),
(26695, 1803, 'Um Milhão de Coisas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231770.mp4', 'http://timg.bdta.pro/images/6352f0ddf7d74081a5ff3720585f61f4.jpg'),
(26696, 1803, 'Um Milhão de Coisas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231771.mp4', 'http://timg.bdta.pro/images/3fc6f2569f8c73fa5096a755e3c14dc2.jpg'),
(26697, 1803, 'Um Milhão de Coisas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/231772.mp4', 'http://timg.bdta.pro/images/4a5ba342d873e8d805d0f5d9feb1e5cf.jpg'),
(26698, 1803, 'Um Milhão de Coisas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/231773.mp4', 'http://timg.bdta.pro/images/7dd37336100d2b73f09691bda157fa2e.jpg'),
(26699, 1803, 'Um Milhão de Coisas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/231774.mp4', 'http://timg.bdta.pro/images/a9c51236222b8f8c79f7e4895f685087.jpg'),
(26700, 1803, 'Um Milhão de Coisas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/231775.mp4', 'http://timg.bdta.pro/images/c5f20a729aa25daf02cf622e6355e0c7.jpg'),
(26701, 1803, 'Um Milhão de Coisas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/231776.mp4', 'http://timg.bdta.pro/images/47a377a315b64d084c6de4753a389155.jpg'),
(26702, 1803, 'Um Milhão de Coisas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/231777.mp4', 'http://timg.bdta.pro/images/43d7f0c410c42bfa0989ee145b48749b.jpg'),
(26703, 1803, 'Um Milhão de Coisas S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/231778.mp4', 'http://timg.bdta.pro/images/cd15a29e64bfb9361c5c6cfc4da75ad7.jpg'),
(26704, 1804, 'Um Milhão de Coisas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231779.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26705, 1804, 'Um Milhão de Coisas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231780.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26706, 1804, 'Um Milhão de Coisas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231781.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26707, 1804, 'Um Milhão de Coisas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231782.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26708, 1804, 'Um Milhão de Coisas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231783.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26709, 1804, 'Um Milhão de Coisas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231784.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26710, 1804, 'Um Milhão de Coisas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231785.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26711, 1804, 'Um Milhão de Coisas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231786.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26712, 1804, 'Um Milhão de Coisas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231787.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26713, 1804, 'Um Milhão de Coisas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231788.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26714, 1804, 'Um Milhão de Coisas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/231789.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26715, 1804, 'Um Milhão de Coisas S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/231790.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26716, 1804, 'Um Milhão de Coisas S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/231791.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26717, 1804, 'Um Milhão de Coisas S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/231792.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26718, 1804, 'Um Milhão de Coisas S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/231793.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26719, 1804, 'Um Milhão de Coisas S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/231794.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26720, 1804, 'Um Milhão de Coisas S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/231795.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26721, 1804, 'Um Milhão de Coisas S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/231796.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26722, 1804, 'Um Milhão de Coisas S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/231797.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26723, 1805, 'Um Milhão de Coisas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231798.mp4', 'http://timg.bdta.pro/images/8c20344b3e98eac3be298ae5f2d1840e.jpg'),
(26724, 1805, 'Um Milhão de Coisas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231799.mp4', 'http://timg.bdta.pro/images/9e4f222dfc476a82ca52a1276cc7c9e4.jpg'),
(26725, 1805, 'Um Milhão de Coisas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231800.mp4', 'http://timg.bdta.pro/images/5bc894861ccb734bab363afd60cb98dd.jpg'),
(26726, 1805, 'Um Milhão de Coisas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231801.mp4', 'http://timg.bdta.pro/images/5ddbfdafcb5794c8c12bcbeae93ad9e5.jpg'),
(26727, 1805, 'Um Milhão de Coisas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231802.mp4', 'http://timg.bdta.pro/images/a6109bc683ba785c428e65d6a2989829.jpg'),
(26728, 1805, 'Um Milhão de Coisas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231803.mp4', 'http://timg.bdta.pro/images/0b402d9bfb1b5c685e2163ea9f76efa1.jpg'),
(26729, 1805, 'Um Milhão de Coisas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231804.mp4', 'http://timg.bdta.pro/images/15849421ae794cf7af09c99be22c70c1.jpg'),
(26730, 1805, 'Um Milhão de Coisas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231805.mp4', 'http://timg.bdta.pro/images/60bc1972ffb94f7632dbb4b66e662382.jpg'),
(26731, 1805, 'Um Milhão de Coisas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231806.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26732, 1805, 'Um Milhão de Coisas S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231807.mp4', 'http://timg.bdta.pro/images/581e0cd3f06dea7ca53145389fc1af5c.jpg'),
(26733, 1805, 'Um Milhão de Coisas S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/231808.mp4', 'http://timg.bdta.pro/images/b581267508decd81dd70a5b7bb9b0b2c.jpg'),
(26734, 1805, 'Um Milhão de Coisas S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/231809.mp4', 'http://timg.bdta.pro/images/adf0bd53090d797de89b07b3ef729f62.jpg'),
(26735, 1805, 'Um Milhão de Coisas S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/231810.mp4', 'http://timg.bdta.pro/images/f1d7bf7b91a43f92752de4edf5441ee1.jpg'),
(26736, 1805, 'Um Milhão de Coisas S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/231811.mp4', 'http://timg.bdta.pro/images/848016d5c84d4e7c727e2896606c1ded.jpg'),
(26737, 1805, 'Um Milhão de Coisas S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/231812.mp4', 'http://timg.bdta.pro/images/5c219dc4f210c581b36947e397167ff6.jpg'),
(26738, 1805, 'Um Milhão de Coisas S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/231813.mp4', 'http://timg.bdta.pro/images/2528578e46c4f799504450e943cba694.jpg'),
(26739, 1805, 'Um Milhão de Coisas S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/231814.mp4', 'http://timg.bdta.pro/images/2b1012c91680dee36e4230af6ed605c4.jpg'),
(26740, 1805, 'Um Milhão de Coisas S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/231815.mp4', 'http://timg.bdta.pro/images/729029130180a00461827459462d7c42.jpg'),
(26741, 1806, 'Um Milhão de Coisas S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5H8H49CcWbNEHcRc4eg25qk0TcA.jpg'),
(26742, 1806, 'Um Milhão de Coisas S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ig4AV7SdUz1bb2Nz2qtxVAjNNSs.jpg'),
(26743, 1806, 'Um Milhão de Coisas S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kTPbiwHjXRHvtwHlCupJjVn4N1.jpg'),
(26744, 1806, 'Um Milhão de Coisas S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o4VR0zuQEQ06WGrt7vqqiJIqdfd.jpg'),
(26745, 1806, 'Um Milhão de Coisas S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h7dmqqorcl49K5Hc5JJNC7ZDhgE.jpg'),
(26746, 1806, 'Um Milhão de Coisas S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231821.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26747, 1806, 'Um Milhão de Coisas S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231822.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26748, 1806, 'Um Milhão de Coisas S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231823.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26749, 1806, 'Um Milhão de Coisas S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231824.mp4', 'http://timg.bdta.pro/images/b09b10edf2be1ff775b30887f1f9704e.jpg'),
(26750, 1806, 'Um Milhão de Coisas S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231825.mp4', 'http://timg.bdta.pro/images/b1b4aca9344f93db9f11aade275b5c4c.jpg'),
(26751, 1806, 'Um Milhão de Coisas S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/231826.mp4', 'http://timg.bdta.pro/images/8bde2ce8a36078b6e21b13694babd839.jpg'),
(26752, 1806, 'Um Milhão de Coisas S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/231827.mp4', 'http://timg.bdta.pro/images/f1412b3203093710e3dcf25646bba1d4.jpg'),
(26753, 1806, 'Um Milhão de Coisas S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/231828.mp4', 'http://timg.bdta.pro/images/a3c1ddb1fbbd41df6eb5b7060ec0af4b.jpg'),
(26754, 1806, 'Um Milhão de Coisas S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/231829.mp4', 'http://timg.bdta.pro/images/3fb2217ba8b89907506087b9f61c81ca.jpg'),
(26755, 1806, 'Um Milhão de Coisas S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/231830.mp4', 'http://timg.bdta.pro/images/2e2fa42f4258a95cfb2d36e77f99154a.jpg'),
(26756, 1806, 'Um Milhão de Coisas S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/231831.mp4', 'http://timg.bdta.pro/images/8800015ab84cfec6657bdf3391e43903.jpg'),
(26757, 1806, 'Um Milhão de Coisas S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/231832.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26758, 1806, 'Um Milhão de Coisas S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/231833.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26759, 1806, 'Um Milhão de Coisas S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/231834.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26760, 1806, 'Um Milhão de Coisas S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/231835.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26761, 1807, 'Um Milhão de Coisas S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231836.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26762, 1807, 'Um Milhão de Coisas S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231837.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26763, 1807, 'Um Milhão de Coisas S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231838.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26764, 1807, 'Um Milhão de Coisas S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231839.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26765, 1807, 'Um Milhão de Coisas S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231840.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26766, 1807, 'Um Milhão de Coisas S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231841.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26767, 1807, 'Um Milhão de Coisas S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231842.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26768, 1807, 'Um Milhão de Coisas S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231843.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26769, 1807, 'Um Milhão de Coisas S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231844.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26770, 1807, 'Um Milhão de Coisas S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231845.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26771, 1807, 'Um Milhão de Coisas S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/231846.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26772, 1807, 'Um Milhão de Coisas S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/231847.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26773, 1807, 'Um Milhão de Coisas S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/231848.mp4', 'http://gstaticontent.com/images/dihgdUlrIHJO6umt0zb00deHTFa_big.jpg'),
(26774, 1808, 'A Máfia dos Tigres S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166349.mp4', 'http://gstaticontent.com/images/pmjYMCnSwndlEpiFZhhOWSWmUsu_big.jpg'),
(26775, 1808, 'A Máfia dos Tigres S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166350.mp4', 'http://gstaticontent.com/images/pmjYMCnSwndlEpiFZhhOWSWmUsu_big.jpg'),
(26776, 1808, 'A Máfia dos Tigres S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166351.mp4', 'http://gstaticontent.com/images/pmjYMCnSwndlEpiFZhhOWSWmUsu_big.jpg'),
(26777, 1808, 'A Máfia dos Tigres S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166352.mp4', 'http://gstaticontent.com/images/pmjYMCnSwndlEpiFZhhOWSWmUsu_big.jpg'),
(26778, 1808, 'A Máfia dos Tigres S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166353.mp4', 'http://gstaticontent.com/images/pmjYMCnSwndlEpiFZhhOWSWmUsu_big.jpg'),
(26779, 1808, 'A Máfia dos Tigres S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166354.mp4', 'http://gstaticontent.com/images/pmjYMCnSwndlEpiFZhhOWSWmUsu_big.jpg'),
(26780, 1808, 'A Máfia dos Tigres S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166355.mp4', 'http://gstaticontent.com/images/pmjYMCnSwndlEpiFZhhOWSWmUsu_big.jpg'),
(26781, 1809, 'A Máfia dos Tigres S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9UMxxYDSouSxG6KXyES3eLzh6G.jpg'),
(26782, 1809, 'A Máfia dos Tigres S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AbkyGu4zupNbIOC7pmHXKgNKCMv.jpg'),
(26783, 1809, 'A Máfia dos Tigres S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fimvKwQv0cWysdjQb2gkhFe96ej.jpg'),
(26784, 1809, 'A Máfia dos Tigres S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ymrgSovfz2Sxgc9AFJMpl9otZzr.jpg'),
(26785, 1809, 'A Máfia dos Tigres S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eRMfnmYrAk36U5DNpWyjHW3Ad4T.jpg'),
(26786, 1810, 'A Vida e a História de Madam C.J. Walker S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110365.mp4', 'http://timg.bdta.pro/images/8a59ae6e6597da330e6ffae1d24eda9b.jpg'),
(26787, 1810, 'A Vida e a História de Madam C.J. Walker S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110366.mp4', 'http://timg.bdta.pro/images/f28e62cd2fd63b89ab5a7801be0b8a1b.jpg'),
(26788, 1810, 'A Vida e a História de Madam C.J. Walker S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110367.mp4', 'http://timg.bdta.pro/images/7d4e42c88f29bccabea3a15b3112da27.jpg'),
(26789, 1810, 'A Vida e a História de Madam C.J. Walker S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110368.mp4', 'http://timg.bdta.pro/images/3eddd1f9203d6167bcae6c7e714fccb4.jpg'),
(26790, 1811, 'Alemão: Os Dois Lados do Complexo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110361.mp4', 'http://gstaticontent.com/images/rOU8esr3ocvlc7EsqoWRLhempQJ_big.jpg'),
(26791, 1811, 'Alemão: Os Dois Lados do Complexo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110362.mp4', 'http://gstaticontent.com/images/rOU8esr3ocvlc7EsqoWRLhempQJ_big.jpg'),
(26792, 1811, 'Alemão: Os Dois Lados do Complexo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110363.mp4', 'http://gstaticontent.com/images/rOU8esr3ocvlc7EsqoWRLhempQJ_big.jpg'),
(26793, 1811, 'Alemão: Os Dois Lados do Complexo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110364.mp4', 'http://gstaticontent.com/images/rOU8esr3ocvlc7EsqoWRLhempQJ_big.jpg'),
(26794, 1812, 'Carta ao Rei S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110355.mp4', 'http://timg.bdta.pro/images/c573c6a9d2c12229b1c9e15ed8a8c23e.jpg'),
(26795, 1812, 'Carta ao Rei S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110356.mp4', 'http://timg.bdta.pro/images/d376914496d5f95feabad7d52a1f3b23.jpg'),
(26796, 1812, 'Carta ao Rei S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110357.mp4', 'http://timg.bdta.pro/images/8e3b4a5a34de711fb2f281f80fe3899c.jpg'),
(26797, 1812, 'Carta ao Rei S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110358.mp4', 'http://timg.bdta.pro/images/816ad2aaa36d7b484d2e3113b1fff4fe.jpg'),
(26798, 1812, 'Carta ao Rei S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110359.mp4', 'http://timg.bdta.pro/images/6587858a2f5618e9c1c97589875b0117.jpg'),
(26799, 1812, 'Carta ao Rei S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110360.mp4', 'http://timg.bdta.pro/images/0f41ae7787f9dff6d77919823f3ddce8.jpg'),
(26800, 1813, 'Feel Good S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147559.mp4', 'http://timg.bdta.pro/images/3409679aaf8cc7adfb052701aca4ec39.jpg'),
(26801, 1813, 'Feel Good S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147560.mp4', 'http://timg.bdta.pro/images/2cbbaaf370b173c94e0842617a7b062b.jpg'),
(26802, 1813, 'Feel Good S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147561.mp4', 'http://timg.bdta.pro/images/2bc64b92c217fd670729c07029685fa9.jpg'),
(26803, 1813, 'Feel Good S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147562.mp4', 'http://timg.bdta.pro/images/ad95fe693d8a894c43eab59cf05dae6f.jpg'),
(26804, 1813, 'Feel Good S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147563.mp4', 'http://timg.bdta.pro/images/95a85abdc6f887686c2f97e525939515.jpg'),
(26805, 1813, 'Feel Good S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147564.mp4', 'http://timg.bdta.pro/images/38cb6c32163ea85c71fe60d80b588c28.jpg'),
(26806, 1814, 'Feel Good S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147565.mp4', 'http://gstaticontent.com/images/pt2Cw0uVRzaQDsoLqMDECnexXbQ_big.jpg'),
(26807, 1814, 'Feel Good S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147566.mp4', 'http://gstaticontent.com/images/pt2Cw0uVRzaQDsoLqMDECnexXbQ_big.jpg'),
(26808, 1814, 'Feel Good S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147567.mp4', 'http://gstaticontent.com/images/pt2Cw0uVRzaQDsoLqMDECnexXbQ_big.jpg'),
(26809, 1814, 'Feel Good S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147568.mp4', 'http://gstaticontent.com/images/pt2Cw0uVRzaQDsoLqMDECnexXbQ_big.jpg'),
(26810, 1814, 'Feel Good S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147569.mp4', 'http://gstaticontent.com/images/pt2Cw0uVRzaQDsoLqMDECnexXbQ_big.jpg'),
(26811, 1814, 'Feel Good S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147570.mp4', 'http://gstaticontent.com/images/pt2Cw0uVRzaQDsoLqMDECnexXbQ_big.jpg'),
(26812, 1815, 'Freud S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110347.mp4', 'http://timg.bdta.pro/images/732384eac6558414ac7499e8bfc7b1bb.jpg'),
(26813, 1815, 'Freud S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110348.mp4', 'http://timg.bdta.pro/images/d6fca6cd7a7e7fda0cb12fdb0c209938.jpg'),
(26814, 1815, 'Freud S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110349.mp4', 'http://timg.bdta.pro/images/90047a3ee111655bb4959834da479979.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(26815, 1815, 'Freud S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110350.mp4', 'http://timg.bdta.pro/images/82676e4082277ac9a2a314c9d6a35490.jpg'),
(26816, 1815, 'Freud S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110351.mp4', 'http://timg.bdta.pro/images/b7d98a8bd7c0ad28ce6472dd327736c6.jpg'),
(26817, 1815, 'Freud S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110352.mp4', 'http://timg.bdta.pro/images/b43c690dc994bc21a27717d88e4b0c4d.jpg'),
(26818, 1815, 'Freud S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110353.mp4', 'http://timg.bdta.pro/images/c0888a47dd26c8a84c7c8c622de735bb.jpg'),
(26819, 1815, 'Freud S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110354.mp4', 'http://timg.bdta.pro/images/80f74bb56e1012520a870701c053a73f.jpg'),
(26820, 1816, 'Não Provoque S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uVFAstBmfqNMMrVBV432vaiVbYa.jpg'),
(26821, 1816, 'Não Provoque S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110338.mp4', 'http://timg.bdta.pro/images/f2a0147c528993d1cc468472fc3f2cb9.jpg'),
(26822, 1816, 'Não Provoque S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110339.mp4', 'http://timg.bdta.pro/images/59fc4e4bfd74fcd9ac8434acbea1d175.jpg'),
(26823, 1816, 'Não Provoque S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110340.mp4', 'http://timg.bdta.pro/images/3353d36d3a7bdb35a9a16d37febc0bec.jpg'),
(26824, 1816, 'Não Provoque S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110341.mp4', 'http://timg.bdta.pro/images/b5c122e3f1414b64db4b1a19cdb2f94f.jpg'),
(26825, 1816, 'Não Provoque S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hdmqCrYnZIZsFHT7FkWgLEpQGG1.jpg'),
(26826, 1816, 'Não Provoque S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110343.mp4', 'http://timg.bdta.pro/images/1da67e0d6b2b9e43d8aa8d772b2b26e3.jpg'),
(26827, 1816, 'Não Provoque S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l7wRrUjeMfP05J4xn4vHWJEpDxu.jpg'),
(26828, 1816, 'Não Provoque S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/110345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/omAy8VyGb0U9I4f3lwasVJOhSZA.jpg'),
(26829, 1816, 'Não Provoque S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/110346.mp4', 'http://timg.bdta.pro/images/cce9e682203794aab121ed4aea8349e5.jpg'),
(26830, 1817, 'Soltos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26831, 1817, 'Soltos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26832, 1817, 'Soltos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26833, 1817, 'Soltos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26834, 1817, 'Soltos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26835, 1817, 'Soltos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26836, 1817, 'Soltos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26837, 1817, 'Soltos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26838, 1818, 'Soltos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26839, 1818, 'Soltos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26840, 1818, 'Soltos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26841, 1818, 'Soltos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26842, 1818, 'Soltos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26843, 1818, 'Soltos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26844, 1818, 'Soltos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26845, 1818, 'Soltos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26846, 1819, 'Soltos S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybmFypX33wpND3CBQAJ8ZzAdgME.jpg'),
(26847, 1819, 'Soltos S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4QPPfUOeUeX9y0qPvS0h6V4fKCh.jpg'),
(26848, 1819, 'Soltos S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26849, 1819, 'Soltos S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26850, 1819, 'Soltos S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26851, 1819, 'Soltos S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26852, 1819, 'Soltos S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26853, 1819, 'Soltos S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26854, 1819, 'Soltos S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26855, 1820, 'Soltos S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/279452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26856, 1820, 'Soltos S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/279453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26857, 1820, 'Soltos S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/279454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26858, 1820, 'Soltos S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/279455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26859, 1820, 'Soltos S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/279456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26860, 1820, 'Soltos S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/279457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26861, 1820, 'Soltos S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/279458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26862, 1820, 'Soltos S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/279459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26863, 1821, 'Soltos S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/697377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26864, 1821, 'Soltos S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/697378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26865, 1821, 'Soltos S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/697379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26866, 1821, 'Soltos S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/697380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26867, 1821, 'Soltos S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/697381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26868, 1821, 'Soltos S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/697382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26869, 1821, 'Soltos S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/697383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26870, 1821, 'Soltos S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/697384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMhE8RUXTonuALOWpJYvpScJscc.jpg'),
(26871, 1822, 'O Jogo Inglês S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110331.mp4', 'http://timg.bdta.pro/images/6b2fb10199a34061e6509d9868e002c8.jpg'),
(26872, 1822, 'O Jogo Inglês S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110332.mp4', 'http://timg.bdta.pro/images/7389e7c7ffba0194eeb36b9a64e95ecd.jpg'),
(26873, 1822, 'O Jogo Inglês S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110333.mp4', 'http://timg.bdta.pro/images/34322f2bf5e0f2953e191303a30bfa69.jpg'),
(26874, 1822, 'O Jogo Inglês S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110334.mp4', 'http://timg.bdta.pro/images/a022bdd8328e9368ce6cf7f43c4cc572.jpg'),
(26875, 1822, 'O Jogo Inglês S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110335.mp4', 'http://timg.bdta.pro/images/0008081f2c655e23e7daab83de98bf0b.jpg'),
(26876, 1822, 'O Jogo Inglês S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110336.mp4', 'http://timg.bdta.pro/images/c5c23ce534f896b1b1167912af525a7e.jpg'),
(26877, 1823, 'O Mundo Segundo Jeff Goldblum S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110319.mp4', 'http://timg.bdta.pro/images/9a4c49bd124123d53bbf36481c53fd28.jpg'),
(26878, 1823, 'O Mundo Segundo Jeff Goldblum S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110320.mp4', 'http://timg.bdta.pro/images/9bd013ebfcfca7d9944fffd1180a35c4.jpg'),
(26879, 1823, 'O Mundo Segundo Jeff Goldblum S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110321.mp4', 'http://timg.bdta.pro/images/c08010c36908d48bae541a1c0a1b9484.jpg'),
(26880, 1823, 'O Mundo Segundo Jeff Goldblum S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110322.mp4', 'http://timg.bdta.pro/images/f14c78f4fcb03c478a7c05eb52af6280.jpg'),
(26881, 1823, 'O Mundo Segundo Jeff Goldblum S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110323.mp4', 'http://timg.bdta.pro/images/b12b1dab83092e9f87b6a3f60e777ed9.jpg'),
(26882, 1823, 'O Mundo Segundo Jeff Goldblum S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110324.mp4', 'http://timg.bdta.pro/images/578c6007d0c2095e6ac40b7ccd52d882.jpg'),
(26883, 1823, 'O Mundo Segundo Jeff Goldblum S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110325.mp4', 'http://timg.bdta.pro/images/e4ac760fb080cb3a42b4f8cc44ab51ca.jpg'),
(26884, 1823, 'O Mundo Segundo Jeff Goldblum S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110326.mp4', 'http://timg.bdta.pro/images/20faa2b4f254509a375fd09e51629de8.jpg'),
(26885, 1823, 'O Mundo Segundo Jeff Goldblum S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/110327.mp4', 'http://timg.bdta.pro/images/b4cdcbc9f3d0512ad0ad2862e343bba4.jpg'),
(26886, 1823, 'O Mundo Segundo Jeff Goldblum S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/110328.mp4', 'http://timg.bdta.pro/images/93273098a671b72332aa865fc5291a8c.jpg'),
(26887, 1823, 'O Mundo Segundo Jeff Goldblum S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/110329.mp4', 'http://timg.bdta.pro/images/1c62aa45d60c19e6401a373d095be582.jpg'),
(26888, 1823, 'O Mundo Segundo Jeff Goldblum S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/110330.mp4', 'http://timg.bdta.pro/images/45744bea1da806ca052e1d3923d52e98.jpg'),
(26889, 1824, 'Todxs Nos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114949.mp4', 'http://gstaticontent.com/images/cSnH3z11orsFkngkVt59vi4DnZJ_big.jpg'),
(26890, 1824, 'Todxs Nos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114950.mp4', 'http://gstaticontent.com/images/cSnH3z11orsFkngkVt59vi4DnZJ_big.jpg'),
(26891, 1824, 'Todxs Nos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114951.mp4', 'http://gstaticontent.com/images/cSnH3z11orsFkngkVt59vi4DnZJ_big.jpg'),
(26892, 1824, 'Todxs Nos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114952.mp4', 'http://gstaticontent.com/images/cSnH3z11orsFkngkVt59vi4DnZJ_big.jpg'),
(26893, 1824, 'Todxs Nos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114953.mp4', 'http://gstaticontent.com/images/cSnH3z11orsFkngkVt59vi4DnZJ_big.jpg'),
(26894, 1824, 'Todxs Nos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114954.mp4', 'http://gstaticontent.com/images/cSnH3z11orsFkngkVt59vi4DnZJ_big.jpg'),
(26895, 1824, 'Todxs Nos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114955.mp4', 'http://gstaticontent.com/images/cSnH3z11orsFkngkVt59vi4DnZJ_big.jpg'),
(26896, 1825, 'Vampiros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110313.mp4', 'http://timg.bdta.pro/images/a518d78a11024b77495819fb9772a696.jpg'),
(26897, 1825, 'Vampiros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110314.mp4', 'http://timg.bdta.pro/images/53f7aa62398836703fb1b868061fd3ef.jpg'),
(26898, 1825, 'Vampiros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110315.mp4', 'http://timg.bdta.pro/images/ee2ed8aaa3d2bb0b64f07799be746f44.jpg'),
(26899, 1825, 'Vampiros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110316.mp4', 'http://timg.bdta.pro/images/caf3c8144943bb90cf2a91726b5fc166.jpg'),
(26900, 1825, 'Vampiros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110317.mp4', 'http://timg.bdta.pro/images/81cb675556849c6c349c3e4d8f430252.jpg'),
(26901, 1825, 'Vampiros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110318.mp4', 'http://timg.bdta.pro/images/c78d6397be3b6f6ed2e5f2e0f1bd9b19.jpg'),
(26902, 1826, 'Greenhouse Academy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126984.mp4', 'http://timg.bdta.pro/images/1f70ca88ab2247724ae4082931a06814.jpg'),
(26903, 1826, 'Greenhouse Academy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126985.mp4', 'http://timg.bdta.pro/images/03ac2faac2937ebfd932d5e10f858e7c.jpg'),
(26904, 1826, 'Greenhouse Academy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126986.mp4', 'http://timg.bdta.pro/images/b9800fe427778911d49a2235d43dc085.jpg'),
(26905, 1826, 'Greenhouse Academy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126987.mp4', 'http://timg.bdta.pro/images/9fa67b358a005df131b3413ff67612b3.jpg'),
(26906, 1826, 'Greenhouse Academy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126988.mp4', 'http://timg.bdta.pro/images/d138b4a64243ac7c1388c8f9f9844b80.jpg'),
(26907, 1826, 'Greenhouse Academy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126989.mp4', 'http://timg.bdta.pro/images/95dc31e88d39423592b5b25c9e850c9e.jpg'),
(26908, 1826, 'Greenhouse Academy S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126990.mp4', 'http://timg.bdta.pro/images/1aa8f1a820ac88f170c6dba7c067b9e2.jpg'),
(26909, 1826, 'Greenhouse Academy S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126991.mp4', 'http://timg.bdta.pro/images/ce83615a89db3e1df53a4500dd747995.jpg'),
(26910, 1826, 'Greenhouse Academy S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126992.mp4', 'http://timg.bdta.pro/images/0431a793669e99b351bf0c6426534274.jpg'),
(26911, 1826, 'Greenhouse Academy S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126993.mp4', 'http://timg.bdta.pro/images/b5068555c46a2f6d1578f76044efd1fd.jpg'),
(26912, 1826, 'Greenhouse Academy S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/126994.mp4', 'http://timg.bdta.pro/images/cb1866f00ff5b036b1f236292f6255dc.jpg'),
(26913, 1826, 'Greenhouse Academy S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/126995.mp4', 'http://timg.bdta.pro/images/f2c848932eac91c83706ae9ef6842a97.jpg'),
(26914, 1827, 'Greenhouse Academy S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126996.mp4', 'http://timg.bdta.pro/images/8f94ca551b54bf8b2cc7503e92196c9b.jpg'),
(26915, 1827, 'Greenhouse Academy S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126997.mp4', 'http://timg.bdta.pro/images/465d6f0ea3b86cf9d07f91401b557590.jpg'),
(26916, 1827, 'Greenhouse Academy S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126998.mp4', 'http://timg.bdta.pro/images/1284e64f4efeedb7bac9c1a4c23dda24.jpg'),
(26917, 1827, 'Greenhouse Academy S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126999.mp4', 'http://timg.bdta.pro/images/877a33a40f8886e8b84bcad6d2aad1fb.jpg'),
(26918, 1827, 'Greenhouse Academy S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127000.mp4', 'http://timg.bdta.pro/images/23268668d4eb6483b2f9a2a0c4d11143.jpg'),
(26919, 1827, 'Greenhouse Academy S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127001.mp4', 'http://timg.bdta.pro/images/12cc663699c5a47d5ba153bafffc5473.jpg'),
(26920, 1827, 'Greenhouse Academy S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127002.mp4', 'http://timg.bdta.pro/images/1f6177a09008641b09256591456afc64.jpg'),
(26921, 1827, 'Greenhouse Academy S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127003.mp4', 'http://timg.bdta.pro/images/c604362b94cbf967d0c8597e84729324.jpg'),
(26922, 1827, 'Greenhouse Academy S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127004.mp4', 'http://timg.bdta.pro/images/3550e639c030ab44785a463175b10775.jpg'),
(26923, 1827, 'Greenhouse Academy S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127005.mp4', 'http://timg.bdta.pro/images/ba7c5e23d95415d899be729007bf43c8.jpg'),
(26924, 1827, 'Greenhouse Academy S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127006.mp4', 'http://timg.bdta.pro/images/90ab5b5440c388dbaedad78614a16772.jpg'),
(26925, 1827, 'Greenhouse Academy S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127007.mp4', 'http://timg.bdta.pro/images/1bcc52f3bc1e74afd56f8f8a356a165d.jpg'),
(26926, 1828, 'Greenhouse Academy S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127008.mp4', 'http://timg.bdta.pro/images/160022108490b8044bfaeaf22b4d34a9.jpg'),
(26927, 1828, 'Greenhouse Academy S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127009.mp4', 'http://timg.bdta.pro/images/746853232acfb6de5c9c297aaf054394.jpg'),
(26928, 1828, 'Greenhouse Academy S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127010.mp4', 'http://timg.bdta.pro/images/746853232acfb6de5c9c297aaf054394.jpg'),
(26929, 1828, 'Greenhouse Academy S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127011.mp4', 'http://timg.bdta.pro/images/746853232acfb6de5c9c297aaf054394.jpg'),
(26930, 1828, 'Greenhouse Academy S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127012.mp4', 'http://timg.bdta.pro/images/746853232acfb6de5c9c297aaf054394.jpg'),
(26931, 1828, 'Greenhouse Academy S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127013.mp4', 'http://timg.bdta.pro/images/746853232acfb6de5c9c297aaf054394.jpg'),
(26932, 1828, 'Greenhouse Academy S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127014.mp4', 'http://timg.bdta.pro/images/746853232acfb6de5c9c297aaf054394.jpg'),
(26933, 1828, 'Greenhouse Academy S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127015.mp4', 'http://timg.bdta.pro/images/746853232acfb6de5c9c297aaf054394.jpg'),
(26934, 1829, 'Greenhouse Academy S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127016.mp4', 'http://timg.bdta.pro/images/dc3b875e11c2915aad43cefed3cf2c12.jpg'),
(26935, 1829, 'Greenhouse Academy S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127017.mp4', 'http://timg.bdta.pro/images/4c5b4e09efd0baa19dda709b422f9b41.jpg'),
(26936, 1829, 'Greenhouse Academy S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127018.mp4', 'http://timg.bdta.pro/images/769289826eb6cdddd1278c51034f8d67.jpg'),
(26937, 1829, 'Greenhouse Academy S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127019.mp4', 'http://timg.bdta.pro/images/c9ac56b704b9e8a99d6a9a40866c4bec.jpg'),
(26938, 1829, 'Greenhouse Academy S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127020.mp4', 'http://timg.bdta.pro/images/1491e760200572dc392c0a83df5ca2bc.jpg'),
(26939, 1829, 'Greenhouse Academy S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127021.mp4', 'http://timg.bdta.pro/images/a4e3ed94a9c6217c1ce163a3db2de9f5.jpg'),
(26940, 1829, 'Greenhouse Academy S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127022.mp4', 'http://timg.bdta.pro/images/f544924db9a145f5d088bcc590762b76.jpg'),
(26941, 1829, 'Greenhouse Academy S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127023.mp4', 'http://timg.bdta.pro/images/3bba58924c1162e792e29fe151f57ea9.jpg'),
(26942, 1830, 'False Flag S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110295.mp4', 'http://timg.bdta.pro/images/04c6e30e7cbfc0089aa035f15e811501.jpg'),
(26943, 1830, 'False Flag S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110296.mp4', 'http://timg.bdta.pro/images/00f015f171de76f40e54658aacdb7148.jpg'),
(26944, 1830, 'False Flag S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110297.mp4', 'http://timg.bdta.pro/images/b59dabf23f72f28f49893a3c2463502d.jpg'),
(26945, 1830, 'False Flag S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110298.mp4', 'http://timg.bdta.pro/images/f56fa7bcfdf20ecaa961fb3b1137046a.jpg'),
(26946, 1830, 'False Flag S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110299.mp4', 'http://timg.bdta.pro/images/2fe35f6ee13c1e547a35025b945f0400.jpg'),
(26947, 1830, 'False Flag S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110300.mp4', 'http://timg.bdta.pro/images/2fe35f6ee13c1e547a35025b945f0400.jpg'),
(26948, 1830, 'False Flag S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110301.mp4', 'http://timg.bdta.pro/images/2fe35f6ee13c1e547a35025b945f0400.jpg'),
(26949, 1830, 'False Flag S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110302.mp4', 'http://timg.bdta.pro/images/2fe35f6ee13c1e547a35025b945f0400.jpg'),
(26950, 1831, 'False Flag S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110303.mp4', 'http://timg.bdta.pro/images/2fe35f6ee13c1e547a35025b945f0400.jpg'),
(26951, 1831, 'False Flag S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110304.mp4', 'http://timg.bdta.pro/images/2fe35f6ee13c1e547a35025b945f0400.jpg'),
(26952, 1831, 'False Flag S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110305.mp4', 'http://timg.bdta.pro/images/2fe35f6ee13c1e547a35025b945f0400.jpg'),
(26953, 1831, 'False Flag S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110306.mp4', 'http://timg.bdta.pro/images/2fe35f6ee13c1e547a35025b945f0400.jpg'),
(26954, 1831, 'False Flag S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110307.mp4', 'http://timg.bdta.pro/images/2fe35f6ee13c1e547a35025b945f0400.jpg'),
(26955, 1831, 'False Flag S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110308.mp4', 'http://timg.bdta.pro/images/2fe35f6ee13c1e547a35025b945f0400.jpg'),
(26956, 1831, 'False Flag S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110309.mp4', 'http://timg.bdta.pro/images/2fe35f6ee13c1e547a35025b945f0400.jpg'),
(26957, 1831, 'False Flag S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110310.mp4', 'http://timg.bdta.pro/images/2fe35f6ee13c1e547a35025b945f0400.jpg'),
(26958, 1831, 'False Flag S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/110311.mp4', 'http://timg.bdta.pro/images/2fe35f6ee13c1e547a35025b945f0400.jpg'),
(26959, 1831, 'False Flag S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/110312.mp4', 'http://gstaticontent.com/images/vUk7g97tVULbtSm4QgPCpqtn6vl_big.jpg'),
(26960, 1832, 'Nada Ortodoxa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110291.mp4', 'http://timg.bdta.pro/images/4413eb35b8cda1ed250e9b5e87543070.jpg'),
(26961, 1832, 'Nada Ortodoxa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110292.mp4', 'http://timg.bdta.pro/images/92b25049136600de9f9469c2709c1f2a.jpg'),
(26962, 1832, 'Nada Ortodoxa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110293.mp4', 'http://timg.bdta.pro/images/da0b1edbc315cdb5bf71948f06f629d3.jpg'),
(26963, 1832, 'Nada Ortodoxa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110294.mp4', 'http://timg.bdta.pro/images/ff28ab53ccb2bdd307d49a06289dd77b.jpg'),
(26964, 1833, 'Patrulha do Destino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238802.mp4', 'http://timg.bdta.pro/images/c6af200abaf6b766e3f427991717bf1f.jpg'),
(26965, 1833, 'Patrulha do Destino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238803.mp4', 'http://timg.bdta.pro/images/662de83db62ad514b27d411044c6bba0.jpg'),
(26966, 1833, 'Patrulha do Destino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238804.mp4', 'http://timg.bdta.pro/images/ed3e70420b9d573abe85884a4fca5ea3.jpg'),
(26967, 1833, 'Patrulha do Destino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238805.mp4', 'http://timg.bdta.pro/images/db22e26815b2bd2b7e6506a15b9e766d.jpg'),
(26968, 1833, 'Patrulha do Destino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238806.mp4', 'http://timg.bdta.pro/images/458b20426c443bb45e237251f77acf87.jpg'),
(26969, 1833, 'Patrulha do Destino S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238807.mp4', 'http://timg.bdta.pro/images/af5ad10a7a2348dcbf5196698f9ae444.jpg'),
(26970, 1833, 'Patrulha do Destino S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238808.mp4', 'http://timg.bdta.pro/images/a212e79c9386f6c5b10a3cebf15ca629.jpg'),
(26971, 1833, 'Patrulha do Destino S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238809.mp4', 'http://timg.bdta.pro/images/21590545c006ba1676c5c0c02edae4fe.jpg'),
(26972, 1833, 'Patrulha do Destino S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238810.mp4', 'http://timg.bdta.pro/images/a2455aa5488d6c8db2a125fe8de8ef5c.jpg'),
(26973, 1833, 'Patrulha do Destino S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238811.mp4', 'http://gstaticontent.com/images/6kUWtKaYWmrdY0cWhtTU6p5d4gc_big.jpg'),
(26974, 1833, 'Patrulha do Destino S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/238812.mp4', 'http://timg.bdta.pro/images/7cc5de63f3527adfbce643b38e1ad202.jpg'),
(26975, 1833, 'Patrulha do Destino S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/238813.mp4', 'http://timg.bdta.pro/images/9c1788944d468940d510b11b8f64462f.jpg'),
(26976, 1833, 'Patrulha do Destino S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/238814.mp4', 'http://gstaticontent.com/images/6kUWtKaYWmrdY0cWhtTU6p5d4gc_big.jpg'),
(26977, 1833, 'Patrulha do Destino S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/238815.mp4', 'http://gstaticontent.com/images/6kUWtKaYWmrdY0cWhtTU6p5d4gc_big.jpg'),
(26978, 1833, 'Patrulha do Destino S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/238816.mp4', 'http://timg.bdta.pro/images/7953a094eeb1c95489698c50b19e1285.jpg'),
(26979, 1834, 'Patrulha do Destino S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238817.mp4', 'http://gstaticontent.com/images/6kUWtKaYWmrdY0cWhtTU6p5d4gc_big.jpg'),
(26980, 1834, 'Patrulha do Destino S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238818.mp4', 'http://gstaticontent.com/images/6kUWtKaYWmrdY0cWhtTU6p5d4gc_big.jpg'),
(26981, 1834, 'Patrulha do Destino S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238819.mp4', 'http://timg.bdta.pro/images/9bd81d989605b25f34610959e77bfab8.jpg'),
(26982, 1834, 'Patrulha do Destino S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238820.mp4', 'http://timg.bdta.pro/images/2f59f565b83c8f8916e3973feda44e4b.jpg'),
(26983, 1834, 'Patrulha do Destino S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238821.mp4', 'http://timg.bdta.pro/images/c1b957d94e8342c5447c3865b7e556db.jpg'),
(26984, 1834, 'Patrulha do Destino S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238822.mp4', 'http://timg.bdta.pro/images/04da30284af45e3d2ab292dc1eb12d25.jpg'),
(26985, 1834, 'Patrulha do Destino S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238823.mp4', 'http://timg.bdta.pro/images/635b58373b1e1c698828126f506dbc84.jpg'),
(26986, 1834, 'Patrulha do Destino S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238824.mp4', 'http://timg.bdta.pro/images/b26f0e1fb931cfb00f3585d319138e5b.jpg'),
(26987, 1834, 'Patrulha do Destino S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nlI6o5l04ovzy7W3YNWTokwMuwN.jpg'),
(26988, 1835, 'Patrulha do Destino S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/585001.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ihB8cVlPSisXaS2UdKcDk3W4L19.jpg'),
(26989, 1835, 'Patrulha do Destino S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/585003.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8uDaGC1ac2UtqSSMNh29jiXk6Du.jpg'),
(26990, 1835, 'Patrulha do Destino S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/585005.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rSYEMIK5IeG7HtbQieomwqoK4nf.jpg'),
(26991, 1835, 'Patrulha do Destino S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/90QngYHTeSwTuVtHdnPVCCsuvVM.jpg'),
(26992, 1835, 'Patrulha do Destino S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238833.mp4', 'http://image.tmdb.org/t/p/w1280/xB3BgZxCgZwW6RyDihTP6bBXyO7.jpg'),
(26993, 1835, 'Patrulha do Destino S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238834.mp4', 'http://image.tmdb.org/t/p/w1280/eDNHcsiIxEW0OuUkftFaDKyE1h8.jpg'),
(26994, 1835, 'Patrulha do Destino S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238835.mp4', 'http://image.tmdb.org/t/p/w1280/bIzgC49qUVU42OYbtjYmgYJsrRf.jpg'),
(26995, 1835, 'Patrulha do Destino S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238836.mp4', 'http://image.tmdb.org/t/p/w1280/9LndjNWOx1MD4p4Et0YxQEZ7myG.jpg'),
(26996, 1835, 'Patrulha do Destino S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238837.mp4', 'http://image.tmdb.org/t/p/w1280/wBED9KwEeZRvJAwevB3wFzLG5Es.jpg'),
(26997, 1835, 'Patrulha do Destino S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238838.mp4', 'http://image.tmdb.org/t/p/w1280/6rdORYPiiGoF1L6QvqryT9wvLsq.jpg'),
(26998, 1836, 'Patrulha do Destino S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ug9qoVi27PwcocUVlvnHCTwyoZ.jpg'),
(26999, 1836, 'Patrulha do Destino S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tVaF758eS5g6kUbr8KNhl2S7QLB.jpg'),
(27000, 1836, 'Patrulha do Destino S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238841.mp4', 'http://image.tmdb.org/t/p/w1280/6uqcwxEGf9GVygeBtsx0qGYs9od.jpg'),
(27001, 1836, 'Patrulha do Destino S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/flxA6PjuGeYBXKrl7AP8Z7VyiH6.jpg'),
(27002, 1836, 'Patrulha do Destino S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ax0oOVM0TeGg0d0OCip7xIGA7R.jpg'),
(27003, 1836, 'Patrulha do Destino S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238844.mp4', 'http://image.tmdb.org/t/p/w1280/dtW9XqfkBhvusi1i21lVvgYrG7d.jpg'),
(27004, 1836, 'Patrulha do Destino S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238845.mp4', 'http://gstaticontent.com/images/6kUWtKaYWmrdY0cWhtTU6p5d4gc_big.jpg'),
(27005, 1836, 'Patrulha do Destino S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238846.mp4', 'http://gstaticontent.com/images/6kUWtKaYWmrdY0cWhtTU6p5d4gc_big.jpg'),
(27006, 1836, 'Patrulha do Destino S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238847.mp4', 'http://gstaticontent.com/images/6kUWtKaYWmrdY0cWhtTU6p5d4gc_big.jpg'),
(27007, 1836, 'Patrulha do Destino S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238848.mp4', 'http://gstaticontent.com/images/6kUWtKaYWmrdY0cWhtTU6p5d4gc_big.jpg'),
(27008, 1836, 'Patrulha do Destino S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/238849.mp4', 'http://gstaticontent.com/images/6kUWtKaYWmrdY0cWhtTU6p5d4gc_big.jpg'),
(27009, 1836, 'Patrulha do Destino S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/238850.mp4', 'http://gstaticontent.com/images/6kUWtKaYWmrdY0cWhtTU6p5d4gc_big.jpg'),
(27010, 1837, 'Fina Estampa Especial S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127199.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27011, 1837, 'Fina Estampa Especial S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127200.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27012, 1837, 'Fina Estampa Especial S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127201.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27013, 1837, 'Fina Estampa Especial S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127202.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27014, 1837, 'Fina Estampa Especial S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127203.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27015, 1837, 'Fina Estampa Especial S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127204.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27016, 1837, 'Fina Estampa Especial S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127205.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27017, 1837, 'Fina Estampa Especial S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127206.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27018, 1837, 'Fina Estampa Especial S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127207.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27019, 1837, 'Fina Estampa Especial S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127208.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27020, 1837, 'Fina Estampa Especial S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127209.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27021, 1837, 'Fina Estampa Especial S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127210.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27022, 1837, 'Fina Estampa Especial S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127211.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27023, 1837, 'Fina Estampa Especial S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127212.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27024, 1837, 'Fina Estampa Especial S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127213.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27025, 1837, 'Fina Estampa Especial S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127214.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27026, 1837, 'Fina Estampa Especial S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127215.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27027, 1837, 'Fina Estampa Especial S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127216.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27028, 1837, 'Fina Estampa Especial S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127217.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27029, 1837, 'Fina Estampa Especial S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127218.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27030, 1837, 'Fina Estampa Especial S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127219.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27031, 1837, 'Fina Estampa Especial S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/127220.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27032, 1837, 'Fina Estampa Especial S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/127221.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27033, 1837, 'Fina Estampa Especial S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/127222.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27034, 1837, 'Fina Estampa Especial S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/127223.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27035, 1837, 'Fina Estampa Especial S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/127224.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27036, 1837, 'Fina Estampa Especial S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/127225.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27037, 1837, 'Fina Estampa Especial S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/127226.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27038, 1837, 'Fina Estampa Especial S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/127227.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27039, 1837, 'Fina Estampa Especial S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/127228.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27040, 1837, 'Fina Estampa Especial S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/127229.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27041, 1837, 'Fina Estampa Especial S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/127230.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27042, 1837, 'Fina Estampa Especial S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/127231.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27043, 1837, 'Fina Estampa Especial S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/127232.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27044, 1837, 'Fina Estampa Especial S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/127233.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27045, 1837, 'Fina Estampa Especial S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/127234.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27046, 1837, 'Fina Estampa Especial S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/127235.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27047, 1837, 'Fina Estampa Especial S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/127236.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27048, 1837, 'Fina Estampa Especial S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/127237.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27049, 1837, 'Fina Estampa Especial S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/127238.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27050, 1837, 'Fina Estampa Especial S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/127239.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27051, 1837, 'Fina Estampa Especial S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/127240.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27052, 1837, 'Fina Estampa Especial S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/127241.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27053, 1837, 'Fina Estampa Especial S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/127242.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27054, 1837, 'Fina Estampa Especial S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/127243.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27055, 1837, 'Fina Estampa Especial S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/127244.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27056, 1837, 'Fina Estampa Especial S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/127245.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27057, 1837, 'Fina Estampa Especial S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/127246.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27058, 1837, 'Fina Estampa Especial S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/127247.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27059, 1837, 'Fina Estampa Especial S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/127248.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27060, 1837, 'Fina Estampa Especial S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/127249.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27061, 1837, 'Fina Estampa Especial S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/127250.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27062, 1837, 'Fina Estampa Especial S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/127251.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27063, 1837, 'Fina Estampa Especial S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/127252.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27064, 1837, 'Fina Estampa Especial S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/127253.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27065, 1837, 'Fina Estampa Especial S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/127254.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27066, 1837, 'Fina Estampa Especial S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/127255.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27067, 1837, 'Fina Estampa Especial S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/127256.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27068, 1837, 'Fina Estampa Especial S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/127257.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27069, 1837, 'Fina Estampa Especial S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/127258.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27070, 1837, 'Fina Estampa Especial S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/127259.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27071, 1837, 'Fina Estampa Especial S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/127260.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27072, 1837, 'Fina Estampa Especial S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/127261.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27073, 1837, 'Fina Estampa Especial S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/127262.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27074, 1837, 'Fina Estampa Especial S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/127263.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27075, 1837, 'Fina Estampa Especial S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/127264.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27076, 1837, 'Fina Estampa Especial S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/127265.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27077, 1837, 'Fina Estampa Especial S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/127266.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27078, 1837, 'Fina Estampa Especial S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/127267.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27079, 1837, 'Fina Estampa Especial S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/127268.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27080, 1837, 'Fina Estampa Especial S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/127269.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27081, 1837, 'Fina Estampa Especial S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/127270.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27082, 1837, 'Fina Estampa Especial S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/127271.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27083, 1837, 'Fina Estampa Especial S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/127272.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27084, 1837, 'Fina Estampa Especial S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/127273.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27085, 1837, 'Fina Estampa Especial S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/127274.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27086, 1837, 'Fina Estampa Especial S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/127275.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27087, 1837, 'Fina Estampa Especial S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/127276.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27088, 1837, 'Fina Estampa Especial S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/127277.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27089, 1837, 'Fina Estampa Especial S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/127278.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27090, 1837, 'Fina Estampa Especial S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/127279.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27091, 1837, 'Fina Estampa Especial S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/127280.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27092, 1837, 'Fina Estampa Especial S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/127281.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27093, 1837, 'Fina Estampa Especial S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/127282.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(27094, 1837, 'Fina Estampa Especial S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/127283.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27095, 1837, 'Fina Estampa Especial S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/127284.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27096, 1837, 'Fina Estampa Especial S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/127285.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27097, 1837, 'Fina Estampa Especial S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/127286.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27098, 1837, 'Fina Estampa Especial S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/127287.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27099, 1837, 'Fina Estampa Especial S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/127288.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27100, 1837, 'Fina Estampa Especial S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/127289.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27101, 1837, 'Fina Estampa Especial S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/127290.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27102, 1837, 'Fina Estampa Especial S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/127291.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27103, 1837, 'Fina Estampa Especial S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/127292.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27104, 1837, 'Fina Estampa Especial S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/127293.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27105, 1837, 'Fina Estampa Especial S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/127294.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27106, 1837, 'Fina Estampa Especial S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/127295.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27107, 1837, 'Fina Estampa Especial S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/127296.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27108, 1837, 'Fina Estampa Especial S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/127297.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27109, 1837, 'Fina Estampa Especial S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/127298.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27110, 1837, 'Fina Estampa Especial S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/127299.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27111, 1837, 'Fina Estampa Especial S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/127300.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27112, 1837, 'Fina Estampa Especial S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/127301.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27113, 1837, 'Fina Estampa Especial S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/127302.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27114, 1837, 'Fina Estampa Especial S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/127303.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27115, 1837, 'Fina Estampa Especial S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/127304.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27116, 1837, 'Fina Estampa Especial S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/127305.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27117, 1837, 'Fina Estampa Especial S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/127306.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27118, 1837, 'Fina Estampa Especial S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/127307.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27119, 1837, 'Fina Estampa Especial S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/127308.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27120, 1837, 'Fina Estampa Especial S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/127309.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27121, 1837, 'Fina Estampa Especial S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/127310.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27122, 1837, 'Fina Estampa Especial S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/127311.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27123, 1837, 'Fina Estampa Especial S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/127312.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27124, 1837, 'Fina Estampa Especial S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/127313.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27125, 1837, 'Fina Estampa Especial S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/127314.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27126, 1837, 'Fina Estampa Especial S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/127315.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27127, 1837, 'Fina Estampa Especial S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/127316.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27128, 1837, 'Fina Estampa Especial S01 E119', 'http://sinalprivado.info:80/series/1533784/1533784/127317.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27129, 1837, 'Fina Estampa Especial S01 E120', 'http://sinalprivado.info:80/series/1533784/1533784/127318.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27130, 1837, 'Fina Estampa Especial S01 E121', 'http://sinalprivado.info:80/series/1533784/1533784/127319.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27131, 1837, 'Fina Estampa Especial S01 E122', 'http://sinalprivado.info:80/series/1533784/1533784/127320.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27132, 1837, 'Fina Estampa Especial S01 E123', 'http://sinalprivado.info:80/series/1533784/1533784/127321.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27133, 1837, 'Fina Estampa Especial S01 E124', 'http://sinalprivado.info:80/series/1533784/1533784/127322.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27134, 1837, 'Fina Estampa Especial S01 E125', 'http://sinalprivado.info:80/series/1533784/1533784/127323.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27135, 1837, 'Fina Estampa Especial S01 E126', 'http://sinalprivado.info:80/series/1533784/1533784/127324.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27136, 1837, 'Fina Estampa Especial S01 E127', 'http://sinalprivado.info:80/series/1533784/1533784/127325.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27137, 1837, 'Fina Estampa Especial S01 E128', 'http://sinalprivado.info:80/series/1533784/1533784/127326.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27138, 1837, 'Fina Estampa Especial S01 E129', 'http://sinalprivado.info:80/series/1533784/1533784/127327.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27139, 1837, 'Fina Estampa Especial S01 E130', 'http://sinalprivado.info:80/series/1533784/1533784/127328.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27140, 1837, 'Fina Estampa Especial S01 E131', 'http://sinalprivado.info:80/series/1533784/1533784/127329.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27141, 1837, 'Fina Estampa Especial S01 E132', 'http://sinalprivado.info:80/series/1533784/1533784/127330.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27142, 1837, 'Fina Estampa Especial S01 E133', 'http://sinalprivado.info:80/series/1533784/1533784/127331.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27143, 1837, 'Fina Estampa Especial S01 E134', 'http://sinalprivado.info:80/series/1533784/1533784/127332.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27144, 1837, 'Fina Estampa Especial S01 E135', 'http://sinalprivado.info:80/series/1533784/1533784/127333.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27145, 1837, 'Fina Estampa Especial S01 E136', 'http://sinalprivado.info:80/series/1533784/1533784/127334.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27146, 1837, 'Fina Estampa Especial S01 E137', 'http://sinalprivado.info:80/series/1533784/1533784/127335.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27147, 1837, 'Fina Estampa Especial S01 E138', 'http://sinalprivado.info:80/series/1533784/1533784/127336.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27148, 1837, 'Fina Estampa Especial S01 E139', 'http://sinalprivado.info:80/series/1533784/1533784/127337.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27149, 1837, 'Fina Estampa Especial S01 E140', 'http://sinalprivado.info:80/series/1533784/1533784/127338.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27150, 1837, 'Fina Estampa Especial S01 E141', 'http://sinalprivado.info:80/series/1533784/1533784/127339.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27151, 1837, 'Fina Estampa Especial S01 E142', 'http://sinalprivado.info:80/series/1533784/1533784/127340.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27152, 1837, 'Fina Estampa Especial S01 E143', 'http://sinalprivado.info:80/series/1533784/1533784/127341.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27153, 1837, 'Fina Estampa Especial S01 E144', 'http://sinalprivado.info:80/series/1533784/1533784/127342.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27154, 1837, 'Fina Estampa Especial S01 E145', 'http://sinalprivado.info:80/series/1533784/1533784/127343.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27155, 1837, 'Fina Estampa Especial S01 E146', 'http://sinalprivado.info:80/series/1533784/1533784/127344.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27156, 1837, 'Fina Estampa Especial S01 E147', 'http://sinalprivado.info:80/series/1533784/1533784/127345.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27157, 1837, 'Fina Estampa Especial S01 E148', 'http://sinalprivado.info:80/series/1533784/1533784/127346.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27158, 1837, 'Fina Estampa Especial S01 E149', 'http://sinalprivado.info:80/series/1533784/1533784/127347.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27159, 1837, 'Fina Estampa Especial S01 E150', 'http://sinalprivado.info:80/series/1533784/1533784/127348.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27160, 1837, 'Fina Estampa Especial S01 E151', 'http://sinalprivado.info:80/series/1533784/1533784/127349.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27161, 1837, 'Fina Estampa Especial S01 E152', 'http://sinalprivado.info:80/series/1533784/1533784/127350.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27162, 1837, 'Fina Estampa Especial S01 E153', 'http://sinalprivado.info:80/series/1533784/1533784/127351.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27163, 1837, 'Fina Estampa Especial S01 E154', 'http://sinalprivado.info:80/series/1533784/1533784/127352.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27164, 1837, 'Fina Estampa Especial S01 E155', 'http://sinalprivado.info:80/series/1533784/1533784/127353.mp4', 'http://gstaticontent.com/images/f8031f3732ed5caf04cd03105ccd69ee.jpg'),
(27165, 1838, 'Jovens Construtores S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109104.mp4', 'http://timg.bdta.pro/images/f7f101674e32fc95a44d89c5deb70974.jpg'),
(27166, 1838, 'Jovens Construtores S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109105.mp4', 'http://timg.bdta.pro/images/c85b568326e67d3c3327be0b0e335340.jpg'),
(27167, 1838, 'Jovens Construtores S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109106.mp4', 'http://timg.bdta.pro/images/6001d1507ca4e03e898e9bb86d7fd153.jpg'),
(27168, 1838, 'Jovens Construtores S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109107.mp4', 'http://gstaticontent.com/images/7qfiIGVDMD11AHirJmex54nOIuh_big.jpg'),
(27169, 1838, 'Jovens Construtores S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109108.mp4', 'http://gstaticontent.com/images/7qfiIGVDMD11AHirJmex54nOIuh_big.jpg'),
(27170, 1838, 'Jovens Construtores S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109109.mp4', 'http://gstaticontent.com/images/7qfiIGVDMD11AHirJmex54nOIuh_big.jpg'),
(27171, 1838, 'Jovens Construtores S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109110.mp4', 'http://gstaticontent.com/images/7qfiIGVDMD11AHirJmex54nOIuh_big.jpg'),
(27172, 1838, 'Jovens Construtores S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109111.mp4', 'http://gstaticontent.com/images/7qfiIGVDMD11AHirJmex54nOIuh_big.jpg'),
(27173, 1839, 'Quatro Casamentos e um Funeral S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110048.mp4', 'http://timg.bdta.pro/images/fb7cfd31ca9b50073e39ff19baed11c4.jpg'),
(27174, 1839, 'Quatro Casamentos e um Funeral S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110049.mp4', 'http://timg.bdta.pro/images/04742abfbf0f3db4aa1ddda9fc8ab50e.jpg'),
(27175, 1839, 'Quatro Casamentos e um Funeral S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110050.mp4', 'http://timg.bdta.pro/images/568a8dca028c89285f6112c3e5f83317.jpg'),
(27176, 1839, 'Quatro Casamentos e um Funeral S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110051.mp4', 'http://timg.bdta.pro/images/57a57a55118eb1443f11e929ca6a2ca6.jpg'),
(27177, 1839, 'Quatro Casamentos e um Funeral S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110052.mp4', 'http://timg.bdta.pro/images/764b9f515883ef71f8416ba9f70b5599.jpg'),
(27178, 1839, 'Quatro Casamentos e um Funeral S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110053.mp4', 'http://timg.bdta.pro/images/b9cba1499e6202629476d939c1b95da0.jpg'),
(27179, 1839, 'Quatro Casamentos e um Funeral S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110054.mp4', 'http://timg.bdta.pro/images/ddfc0445074ebec719a55515d4c1b5c3.jpg'),
(27180, 1839, 'Quatro Casamentos e um Funeral S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110055.mp4', 'http://timg.bdta.pro/images/6fa7acfa5ae271b9f5a6dc37a3e2ee27.jpg'),
(27181, 1839, 'Quatro Casamentos e um Funeral S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/110056.mp4', 'http://timg.bdta.pro/images/9b109fed895051b011c634a2666f4688.jpg'),
(27182, 1839, 'Quatro Casamentos e um Funeral S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/110057.mp4', 'http://timg.bdta.pro/images/62b2b43cabc8318826d4f57e5e797712.jpg'),
(27183, 1840, 'Under The Dome S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136182.mp4', 'http://timg.bdta.pro/images/484b44ee698a4e1b07d5500de8f9d382.jpg'),
(27184, 1840, 'Under The Dome S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136183.mp4', 'http://timg.bdta.pro/images/325e52ad1d62809ce8b9af7abbb553d9.jpg'),
(27185, 1840, 'Under The Dome S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136184.mp4', 'http://timg.bdta.pro/images/c4180914396e1963c51e6f5eda3f1595.jpg'),
(27186, 1840, 'Under The Dome S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136185.mp4', 'http://timg.bdta.pro/images/5366e4edd2e42666c827a38471c86149.jpg'),
(27187, 1840, 'Under The Dome S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136186.mp4', 'http://timg.bdta.pro/images/1c3084d266a488b07e34491266f99478.jpg'),
(27188, 1840, 'Under The Dome S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136187.mp4', 'http://timg.bdta.pro/images/6ed1fbf7cdb49854ad16fdfabf235bc7.jpg'),
(27189, 1840, 'Under The Dome S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136188.mp4', 'http://timg.bdta.pro/images/52ab4eb705b44f9fa0bc2d49484bc393.jpg'),
(27190, 1840, 'Under The Dome S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136189.mp4', 'http://timg.bdta.pro/images/13c54265110632d4a7c98e47299d1406.jpg'),
(27191, 1840, 'Under The Dome S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136190.mp4', 'http://timg.bdta.pro/images/481aff478d033bc573f546e2009cabef.jpg'),
(27192, 1840, 'Under The Dome S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136191.mp4', 'http://timg.bdta.pro/images/ad0a79312685e5a6e9bf27abaccb4a7a.jpg'),
(27193, 1840, 'Under The Dome S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136192.mp4', 'http://timg.bdta.pro/images/bb87016d033b10a4c5c56c558aed6594.jpg'),
(27194, 1840, 'Under The Dome S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136193.mp4', 'http://timg.bdta.pro/images/19c9b2dedb49731f084b1a747da1737e.jpg'),
(27195, 1840, 'Under The Dome S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136194.mp4', 'http://timg.bdta.pro/images/d80e32fff72748921e65272ac22c4829.jpg'),
(27196, 1841, 'Under The Dome S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136195.mp4', 'http://timg.bdta.pro/images/bcd1f305f767042dc192815c2ed83f6c.jpg'),
(27197, 1841, 'Under The Dome S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136196.mp4', 'http://timg.bdta.pro/images/584458ad6b89c8a5ae02021c97ddf2b4.jpg'),
(27198, 1841, 'Under The Dome S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136197.mp4', 'http://timg.bdta.pro/images/5b80eb2f0718b0ffca73d115bd2cd703.jpg'),
(27199, 1841, 'Under The Dome S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136198.mp4', 'http://timg.bdta.pro/images/97c73a32cc9e739b1662b364d233d157.jpg'),
(27200, 1841, 'Under The Dome S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136199.mp4', 'http://timg.bdta.pro/images/1fb9896ac84510a07832d41238b4b51d.jpg'),
(27201, 1841, 'Under The Dome S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136200.mp4', 'http://timg.bdta.pro/images/bb59725f6b6454f55e9d96469b7975a9.jpg'),
(27202, 1841, 'Under The Dome S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136201.mp4', 'http://timg.bdta.pro/images/f5f138774e36a2902c945cab8fd43e34.jpg'),
(27203, 1841, 'Under The Dome S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136202.mp4', 'http://timg.bdta.pro/images/acf15841cb6aece3c0bfda0ef6ff2e9c.jpg'),
(27204, 1841, 'Under The Dome S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136203.mp4', 'http://timg.bdta.pro/images/f1752fd77de938f29ba2ef2d9908fe67.jpg'),
(27205, 1841, 'Under The Dome S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136204.mp4', 'http://timg.bdta.pro/images/f5c0609aeb63b35e5a218d8cd126af0d.jpg'),
(27206, 1841, 'Under The Dome S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136205.mp4', 'http://timg.bdta.pro/images/4f9f2b7ac949f6e64ea3fe9b9f33cdbf.jpg'),
(27207, 1841, 'Under The Dome S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136206.mp4', 'http://timg.bdta.pro/images/21c3e67b460f59a2bfa591a1ba528b21.jpg'),
(27208, 1841, 'Under The Dome S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136207.mp4', 'http://timg.bdta.pro/images/0922a365f45a0c4bc6116e503e11f161.jpg'),
(27209, 1842, 'Under The Dome S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136208.mp4', 'http://gstaticontent.com/images/iz6JZkXMNs12ZeveNLvuXx4nOhH_big.jpg'),
(27210, 1842, 'Under The Dome S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136209.mp4', 'http://gstaticontent.com/images/iz6JZkXMNs12ZeveNLvuXx4nOhH_big.jpg'),
(27211, 1842, 'Under The Dome S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136210.mp4', 'http://gstaticontent.com/images/iz6JZkXMNs12ZeveNLvuXx4nOhH_big.jpg'),
(27212, 1842, 'Under The Dome S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136211.mp4', 'http://gstaticontent.com/images/iz6JZkXMNs12ZeveNLvuXx4nOhH_big.jpg'),
(27213, 1842, 'Under The Dome S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136212.mp4', 'http://gstaticontent.com/images/iz6JZkXMNs12ZeveNLvuXx4nOhH_big.jpg'),
(27214, 1842, 'Under The Dome S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136213.mp4', 'http://gstaticontent.com/images/iz6JZkXMNs12ZeveNLvuXx4nOhH_big.jpg'),
(27215, 1842, 'Under The Dome S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136214.mp4', 'http://gstaticontent.com/images/iz6JZkXMNs12ZeveNLvuXx4nOhH_big.jpg'),
(27216, 1842, 'Under The Dome S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136215.mp4', 'http://gstaticontent.com/images/iz6JZkXMNs12ZeveNLvuXx4nOhH_big.jpg'),
(27217, 1842, 'Under The Dome S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136216.mp4', 'http://gstaticontent.com/images/iz6JZkXMNs12ZeveNLvuXx4nOhH_big.jpg'),
(27218, 1842, 'Under The Dome S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136217.mp4', 'http://gstaticontent.com/images/iz6JZkXMNs12ZeveNLvuXx4nOhH_big.jpg'),
(27219, 1842, 'Under The Dome S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136218.mp4', 'http://gstaticontent.com/images/iz6JZkXMNs12ZeveNLvuXx4nOhH_big.jpg'),
(27220, 1842, 'Under The Dome S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136219.mp4', 'http://gstaticontent.com/images/iz6JZkXMNs12ZeveNLvuXx4nOhH_big.jpg'),
(27221, 1843, 'Banshee S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110010.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27222, 1843, 'Banshee S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110011.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27223, 1843, 'Banshee S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110012.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27224, 1843, 'Banshee S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110013.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27225, 1843, 'Banshee S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110014.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27226, 1843, 'Banshee S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110015.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27227, 1843, 'Banshee S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110016.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27228, 1843, 'Banshee S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110017.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27229, 1843, 'Banshee S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/110018.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27230, 1843, 'Banshee S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/110019.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27231, 1844, 'Banshee S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110020.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27232, 1844, 'Banshee S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110021.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27233, 1844, 'Banshee S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110022.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27234, 1844, 'Banshee S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110023.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27235, 1844, 'Banshee S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110024.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27236, 1844, 'Banshee S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110025.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27237, 1844, 'Banshee S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110026.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27238, 1844, 'Banshee S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110027.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27239, 1844, 'Banshee S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/110028.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27240, 1844, 'Banshee S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/110029.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27241, 1845, 'Banshee S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110030.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27242, 1845, 'Banshee S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110031.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27243, 1845, 'Banshee S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110032.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27244, 1845, 'Banshee S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110033.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27245, 1845, 'Banshee S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110034.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27246, 1845, 'Banshee S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110035.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27247, 1845, 'Banshee S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110036.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27248, 1845, 'Banshee S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110037.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27249, 1845, 'Banshee S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/110038.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27250, 1845, 'Banshee S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/110039.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27251, 1846, 'Banshee S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/110040.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27252, 1846, 'Banshee S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/110041.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27253, 1846, 'Banshee S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/110042.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27254, 1846, 'Banshee S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/110043.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27255, 1846, 'Banshee S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/110044.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27256, 1846, 'Banshee S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/110045.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27257, 1846, 'Banshee S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/110046.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27258, 1846, 'Banshee S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/110047.mp4', 'http://gstaticontent.com/images/rBhjKiOrVB1vd5NrPPzIGvmRvW5_big.jpg'),
(27259, 1847, 'Diário de uma Futura Presidente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159025.mp4', 'http://gstaticontent.com/images/fPXuAuowiKWNa8fFZe9Zo4cYp3J_big.jpg'),
(27260, 1847, 'Diário de uma Futura Presidente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159026.mp4', 'http://gstaticontent.com/images/fPXuAuowiKWNa8fFZe9Zo4cYp3J_big.jpg'),
(27261, 1847, 'Diário de uma Futura Presidente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159027.mp4', 'http://gstaticontent.com/images/fPXuAuowiKWNa8fFZe9Zo4cYp3J_big.jpg'),
(27262, 1847, 'Diário de uma Futura Presidente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159028.mp4', 'http://gstaticontent.com/images/fPXuAuowiKWNa8fFZe9Zo4cYp3J_big.jpg'),
(27263, 1847, 'Diário de uma Futura Presidente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159029.mp4', 'http://gstaticontent.com/images/fPXuAuowiKWNa8fFZe9Zo4cYp3J_big.jpg'),
(27264, 1847, 'Diário de uma Futura Presidente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159030.mp4', 'http://gstaticontent.com/images/fPXuAuowiKWNa8fFZe9Zo4cYp3J_big.jpg'),
(27265, 1847, 'Diário de uma Futura Presidente S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159031.mp4', 'http://gstaticontent.com/images/fPXuAuowiKWNa8fFZe9Zo4cYp3J_big.jpg'),
(27266, 1847, 'Diário de uma Futura Presidente S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159032.mp4', 'http://gstaticontent.com/images/fPXuAuowiKWNa8fFZe9Zo4cYp3J_big.jpg'),
(27267, 1847, 'Diário de uma Futura Presidente S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159033.mp4', 'http://gstaticontent.com/images/fPXuAuowiKWNa8fFZe9Zo4cYp3J_big.jpg'),
(27268, 1847, 'Diário de uma Futura Presidente S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159034.mp4', 'http://gstaticontent.com/images/fPXuAuowiKWNa8fFZe9Zo4cYp3J_big.jpg'),
(27269, 1848, 'Diário de uma Futura Presidente S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159035.mp4', 'http://timg.bdta.pro/images/fedb3b18fdf61b2bac2d3567289b6f07.jpg'),
(27270, 1848, 'Diário de uma Futura Presidente S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159036.mp4', 'http://timg.bdta.pro/images/5fff2a551804e9a858439f2b71a13a65.jpg'),
(27271, 1848, 'Diário de uma Futura Presidente S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159037.mp4', 'http://timg.bdta.pro/images/8f79b26fdcc7b0c2234e00dec207f23c.jpg'),
(27272, 1848, 'Diário de uma Futura Presidente S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159038.mp4', 'http://timg.bdta.pro/images/62cdccdc1045d06df43065ad2501998a.jpg'),
(27273, 1848, 'Diário de uma Futura Presidente S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159039.mp4', 'http://timg.bdta.pro/images/f8467175dfe5b66566ca66a5025c1607.jpg'),
(27274, 1848, 'Diário de uma Futura Presidente S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159040.mp4', 'http://timg.bdta.pro/images/c1bab0916073a3d8d65cf01b0e95fa3d.jpg'),
(27275, 1848, 'Diário de uma Futura Presidente S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159041.mp4', 'http://timg.bdta.pro/images/ef3138c0967c938045508200fd5107b5.jpg'),
(27276, 1848, 'Diário de uma Futura Presidente S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159042.mp4', 'http://timg.bdta.pro/images/cc0dd2e02f09e1c2ec8021c8e05dad99.jpg'),
(27277, 1848, 'Diário de uma Futura Presidente S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159043.mp4', 'http://timg.bdta.pro/images/935340d0e0f0617d2e5ccef4d060e09d.jpg'),
(27278, 1848, 'Diário de uma Futura Presidente S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159044.mp4', 'http://timg.bdta.pro/images/6f349670b31328117c0197e710439c49.jpg'),
(27279, 1849, 'Cosmos: Possible Worlds [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108600.mp4', 'http://gstaticontent.com/images/lMvrEICzMPZcz0ec1sbM6juIUHw_big.jpg'),
(27280, 1849, 'Cosmos: Possible Worlds [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108601.mp4', 'http://gstaticontent.com/images/lMvrEICzMPZcz0ec1sbM6juIUHw_big.jpg'),
(27281, 1849, 'Cosmos: Possible Worlds [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108602.mp4', 'http://gstaticontent.com/images/lMvrEICzMPZcz0ec1sbM6juIUHw_big.jpg'),
(27282, 1849, 'Cosmos: Possible Worlds [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108603.mp4', 'http://gstaticontent.com/images/lMvrEICzMPZcz0ec1sbM6juIUHw_big.jpg'),
(27283, 1849, 'Cosmos: Possible Worlds [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108604.mp4', 'http://gstaticontent.com/images/lMvrEICzMPZcz0ec1sbM6juIUHw_big.jpg'),
(27284, 1849, 'Cosmos: Possible Worlds [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108605.mp4', 'http://gstaticontent.com/images/lMvrEICzMPZcz0ec1sbM6juIUHw_big.jpg'),
(27285, 1849, 'Cosmos: Possible Worlds [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108606.mp4', 'http://gstaticontent.com/images/lMvrEICzMPZcz0ec1sbM6juIUHw_big.jpg'),
(27286, 1849, 'Cosmos: Possible Worlds [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108607.mp4', 'http://gstaticontent.com/images/lMvrEICzMPZcz0ec1sbM6juIUHw_big.jpg'),
(27287, 1849, 'Cosmos: Possible Worlds [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108608.mp4', 'http://gstaticontent.com/images/lMvrEICzMPZcz0ec1sbM6juIUHw_big.jpg'),
(27288, 1849, 'Cosmos: Possible Worlds [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108609.mp4', 'http://gstaticontent.com/images/lMvrEICzMPZcz0ec1sbM6juIUHw_big.jpg'),
(27289, 1849, 'Cosmos: Possible Worlds [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108610.mp4', 'http://gstaticontent.com/images/lMvrEICzMPZcz0ec1sbM6juIUHw_big.jpg'),
(27290, 1849, 'Cosmos: Possible Worlds [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108611.mp4', 'http://gstaticontent.com/images/lMvrEICzMPZcz0ec1sbM6juIUHw_big.jpg'),
(27291, 1850, 'Home Before Dark S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159005.mp4', 'http://timg.bdta.pro/images/ce4b997f9b863a25dfca7c769dc895e6.jpg'),
(27292, 1850, 'Home Before Dark S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159006.mp4', 'http://timg.bdta.pro/images/ae0efce6f320129f7973a693b05f2a05.jpg'),
(27293, 1850, 'Home Before Dark S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159007.mp4', 'http://timg.bdta.pro/images/b5d6bdd69a1f3c32042b246407f23bb7.jpg'),
(27294, 1850, 'Home Before Dark S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159008.mp4', 'http://timg.bdta.pro/images/0925af58a0a9b5de4f22178135553e06.jpg'),
(27295, 1850, 'Home Before Dark S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159009.mp4', 'http://timg.bdta.pro/images/b61e8b57887f8ab9a9a9483f4509aef4.jpg'),
(27296, 1850, 'Home Before Dark S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159010.mp4', 'http://timg.bdta.pro/images/349e90a67bd8d070185f5f2a165e270c.jpg'),
(27297, 1850, 'Home Before Dark S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159011.mp4', 'http://timg.bdta.pro/images/e80c7851d7e3c1d2339483d16c08facc.jpg'),
(27298, 1850, 'Home Before Dark S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159012.mp4', 'http://timg.bdta.pro/images/2a0f100ea301bf869a264702b5f46478.jpg'),
(27299, 1850, 'Home Before Dark S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159013.mp4', 'http://timg.bdta.pro/images/7b698f5c8ca41a1fdecb88bef12e54ac.jpg'),
(27300, 1850, 'Home Before Dark S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159014.mp4', 'http://timg.bdta.pro/images/c97bd337ae298282a4921a3af607f9d4.jpg'),
(27301, 1851, 'Home Before Dark S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159015.mp4', 'http://timg.bdta.pro/images/7b09e7d1aa303fe3ce3cff4d20b5996a.jpg'),
(27302, 1851, 'Home Before Dark S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159016.mp4', 'http://timg.bdta.pro/images/c9d833cf1ddb117320d7bda587e2fa6b.jpg'),
(27303, 1851, 'Home Before Dark S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159017.mp4', 'http://timg.bdta.pro/images/f7f81f5866d08530105fedee3ab9bd1e.jpg'),
(27304, 1851, 'Home Before Dark S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159018.mp4', 'http://timg.bdta.pro/images/176cd888a8020e7ffaebd6c350cabbdd.jpg'),
(27305, 1851, 'Home Before Dark S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159019.mp4', 'http://timg.bdta.pro/images/953b0b0a013217b823809fb405ae9754.jpg'),
(27306, 1851, 'Home Before Dark S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159020.mp4', 'http://timg.bdta.pro/images/7cbaa9fc94ad283047cb6c4a6b8e28f1.jpg'),
(27307, 1851, 'Home Before Dark S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159021.mp4', 'http://timg.bdta.pro/images/3897faefabe94f1d8929329627af894c.jpg'),
(27308, 1851, 'Home Before Dark S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159022.mp4', 'http://timg.bdta.pro/images/2cc29f750045b25bae3befc35ce20169.jpg'),
(27309, 1851, 'Home Before Dark S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159023.mp4', 'http://timg.bdta.pro/images/521978e3fea7688c7f881a695ad57635.jpg'),
(27310, 1851, 'Home Before Dark S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159024.mp4', 'http://timg.bdta.pro/images/f2443b99527430765af2c265621d08d5.jpg'),
(27311, 1852, 'Contos do Loop S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109949.mp4', 'http://timg.bdta.pro/images/59b43e196815bbdfe8415a0200f8a83d.jpg'),
(27312, 1852, 'Contos do Loop S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109950.mp4', 'http://timg.bdta.pro/images/6e4f39ebcf30904314e159646d1835d0.jpg'),
(27313, 1852, 'Contos do Loop S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109951.mp4', 'http://timg.bdta.pro/images/f4a3c4bd9189b329b3117f65d8e80e87.jpg'),
(27314, 1852, 'Contos do Loop S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109952.mp4', 'http://timg.bdta.pro/images/7496c6be71ed7bb509573116cc8fa8de.jpg'),
(27315, 1852, 'Contos do Loop S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109953.mp4', 'http://timg.bdta.pro/images/0a2380b4ab192e4c24f400418f60c7a3.jpg'),
(27316, 1852, 'Contos do Loop S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109954.mp4', 'http://timg.bdta.pro/images/493e543faa7afecbe51f2151b1901824.jpg'),
(27317, 1852, 'Contos do Loop S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109955.mp4', 'http://timg.bdta.pro/images/3a7bb8be9a16267621346274160c3ef5.jpg'),
(27318, 1852, 'Contos do Loop S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109956.mp4', 'http://timg.bdta.pro/images/ce201e29e07700fb5b992391557d3c31.jpg'),
(27319, 1853, 'Narcos: Mexico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176621.mp4', 'http://timg.bdta.pro/images/f02106ddd6d4fd13486a5c0cc3a1f826.jpg'),
(27320, 1853, 'Narcos: Mexico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176622.mp4', 'http://timg.bdta.pro/images/a3272e476f12a9e1c91097302afbd700.jpg'),
(27321, 1853, 'Narcos: Mexico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176623.mp4', 'http://timg.bdta.pro/images/314e215e7ea4d7d699f7461389cc0893.jpg'),
(27322, 1853, 'Narcos: Mexico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176624.mp4', 'http://timg.bdta.pro/images/41509819fd79ea3efa3b56e3018f98dc.jpg'),
(27323, 1853, 'Narcos: Mexico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176625.mp4', 'http://timg.bdta.pro/images/b3afb746774fb61d04ce69f5ddcbee5f.jpg'),
(27324, 1853, 'Narcos: Mexico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176626.mp4', 'http://timg.bdta.pro/images/aa0158bb50e648ef2e7b117c68a85b9e.jpg'),
(27325, 1853, 'Narcos: Mexico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176627.mp4', 'http://timg.bdta.pro/images/1fabfb26cd4951aff7dd2704594f2ca2.jpg'),
(27326, 1853, 'Narcos: Mexico S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176628.mp4', 'http://timg.bdta.pro/images/51745653cfc3d9f4b9c5528488c2bd11.jpg'),
(27327, 1853, 'Narcos: Mexico S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176629.mp4', 'http://timg.bdta.pro/images/6783e08967b053c570f49c9c374091fa.jpg'),
(27328, 1853, 'Narcos: Mexico S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176630.mp4', 'http://timg.bdta.pro/images/435f0be40c96c8cd6364ee03cfb5f1d1.jpg'),
(27329, 1854, 'Narcos: Mexico S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176631.mp4', 'http://timg.bdta.pro/images/392858dc17f6702973c68cc2581a1468.jpg'),
(27330, 1854, 'Narcos: Mexico S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176632.mp4', 'http://timg.bdta.pro/images/0640f601700321de9a1dbf82e1565af8.jpg'),
(27331, 1854, 'Narcos: Mexico S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176633.mp4', 'http://timg.bdta.pro/images/4e8fe8415976b01be2a4e46e702d203d.jpg'),
(27332, 1854, 'Narcos: Mexico S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176634.mp4', 'http://timg.bdta.pro/images/1351168634bea639275de87a645cd2fb.jpg'),
(27333, 1854, 'Narcos: Mexico S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176635.mp4', 'http://timg.bdta.pro/images/0ac5cf073394265c7b07c4dd6aee609b.jpg'),
(27334, 1854, 'Narcos: Mexico S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176636.mp4', 'http://timg.bdta.pro/images/c58cafd9a8b3cb81306350a946ed54b6.jpg'),
(27335, 1854, 'Narcos: Mexico S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176637.mp4', 'http://timg.bdta.pro/images/614d940cb7f7934e09de49762f78d318.jpg'),
(27336, 1854, 'Narcos: Mexico S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176638.mp4', 'http://timg.bdta.pro/images/977712205fd334b2edd2bd0ef3b1044c.jpg'),
(27337, 1854, 'Narcos: Mexico S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176639.mp4', 'http://timg.bdta.pro/images/68801b3262413389af5c95c89519f59d.jpg'),
(27338, 1854, 'Narcos: Mexico S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176640.mp4', 'http://timg.bdta.pro/images/a5bff66221923c8a4a07124f9c0f5f13.jpg'),
(27339, 1855, 'Narcos: Mexico S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176641.mp4', 'http://timg.bdta.pro/images/fb33c74d4d571a6a0fb232e4775795a1.jpg'),
(27340, 1855, 'Narcos: Mexico S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176642.mp4', 'http://timg.bdta.pro/images/b1543c15e5e8541736253df398cd7794.jpg'),
(27341, 1855, 'Narcos: Mexico S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176643.mp4', 'http://timg.bdta.pro/images/66f40773a889874db70e4050e3a4e20f.jpg'),
(27342, 1855, 'Narcos: Mexico S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176644.mp4', 'http://timg.bdta.pro/images/27e99f5409d8d51e848e266dd21baed9.jpg'),
(27343, 1855, 'Narcos: Mexico S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176645.mp4', 'http://timg.bdta.pro/images/8332a7e0776ab985286562a613a42e4c.jpg'),
(27344, 1855, 'Narcos: Mexico S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176646.mp4', 'http://timg.bdta.pro/images/1a999df03d250676da4a0859ee24656a.jpg'),
(27345, 1855, 'Narcos: Mexico S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176647.mp4', 'http://timg.bdta.pro/images/c7b1910406fc2cd6f64b0a0ce4602ce6.jpg'),
(27346, 1855, 'Narcos: Mexico S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176648.mp4', 'http://timg.bdta.pro/images/ac745b0b7a3c25082ea01029d9eacc6d.jpg'),
(27347, 1855, 'Narcos: Mexico S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176649.mp4', 'http://timg.bdta.pro/images/8ecea658b8ac6e487093d4e7e7d10b7a.jpg'),
(27348, 1855, 'Narcos: Mexico S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176650.mp4', 'http://timg.bdta.pro/images/5c30d034c0ab5abbfc9b7f8d475cbf84.jpg'),
(27349, 1856, 'The Office S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109478.mp4', 'http://timg.bdta.pro/images/a81281c24b9d992f9cf3bd1619533e64.jpg'),
(27350, 1856, 'The Office S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109479.mp4', 'http://timg.bdta.pro/images/12bcef642e8ff07060ab6d3cd8a97696.jpg'),
(27351, 1856, 'The Office S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109480.mp4', 'http://timg.bdta.pro/images/8abb75a536739355c42c9b322471cf7a.jpg'),
(27352, 1856, 'The Office S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109481.mp4', 'http://timg.bdta.pro/images/cbd973fb3ee5ddeececd4b2b594d02c8.jpg'),
(27353, 1856, 'The Office S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109482.mp4', 'http://timg.bdta.pro/images/2048da9e2397186463d371efc46d27da.jpg'),
(27354, 1856, 'The Office S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109483.mp4', 'http://timg.bdta.pro/images/fa4bddbeb406eac442f76dfc64c06cd1.jpg'),
(27355, 1857, 'The Office S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109484.mp4', 'http://timg.bdta.pro/images/e23451ba627daf77b7b06d95e04b222b.jpg'),
(27356, 1857, 'The Office S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109485.mp4', 'http://timg.bdta.pro/images/a6ee0c8b78d3b161bf1ca1d52635aac6.jpg'),
(27357, 1857, 'The Office S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109486.mp4', 'http://timg.bdta.pro/images/1bed70fc1b05bbf9d579b30194a59c68.jpg'),
(27358, 1857, 'The Office S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109487.mp4', 'http://timg.bdta.pro/images/a38ce0529eb2a5ec4f845a60061fa251.jpg'),
(27359, 1857, 'The Office S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109488.mp4', 'http://timg.bdta.pro/images/b98751b83f466ca6a6ae69b4049e97bc.jpg'),
(27360, 1857, 'The Office S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109489.mp4', 'http://timg.bdta.pro/images/5d583535f68ecd1e0d97451a5f00ef0e.jpg'),
(27361, 1857, 'The Office S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109490.mp4', 'http://timg.bdta.pro/images/9878700919bd28817e1d4b1bda0093ef.jpg'),
(27362, 1857, 'The Office S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109491.mp4', 'http://timg.bdta.pro/images/42cfb472cc3bafe4c66c03cc723d4581.jpg'),
(27363, 1857, 'The Office S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109492.mp4', 'http://timg.bdta.pro/images/fd72de6937f7bb88c74993e1ffdda3c1.jpg'),
(27364, 1857, 'The Office S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109493.mp4', 'http://timg.bdta.pro/images/37a02022c7a6f6c63887973bd01d535a.jpg'),
(27365, 1857, 'The Office S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109494.mp4', 'http://timg.bdta.pro/images/0e575e44123eb7f01719b339ab2ae6c1.jpg'),
(27366, 1857, 'The Office S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109495.mp4', 'http://timg.bdta.pro/images/cce2e2396ba43b993990cc153269bbf3.jpg'),
(27367, 1857, 'The Office S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109496.mp4', 'http://timg.bdta.pro/images/d79b7a13f39fc2a363d2b4d421aa92b0.jpg'),
(27368, 1857, 'The Office S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109497.mp4', 'http://timg.bdta.pro/images/0904238a61a18a42c46d2afb0714df83.jpg'),
(27369, 1857, 'The Office S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109498.mp4', 'http://timg.bdta.pro/images/f1ef601ad01b58cc0b909cee38835e65.jpg'),
(27370, 1857, 'The Office S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109499.mp4', 'http://timg.bdta.pro/images/da60166eaf12c22fa94968b96598bb9b.jpg'),
(27371, 1857, 'The Office S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/109500.mp4', 'http://timg.bdta.pro/images/700deeaa591b7afec1280247768a5def.jpg'),
(27372, 1857, 'The Office S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/109501.mp4', 'http://timg.bdta.pro/images/47a7b4506faa3b00809840e1444cb4d0.jpg'),
(27373, 1857, 'The Office S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/109502.mp4', 'http://timg.bdta.pro/images/819e7fb8bfecd68ad177f34e053dc78f.jpg'),
(27374, 1857, 'The Office S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/109503.mp4', 'http://timg.bdta.pro/images/f24ab0547b555f6b39b75b1ab0d6f907.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(27375, 1857, 'The Office S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/109504.mp4', 'http://timg.bdta.pro/images/c944ebb3bf928b69542ddd3f9fafeba6.jpg'),
(27376, 1857, 'The Office S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/109505.mp4', 'http://timg.bdta.pro/images/605dce8124788a4ad45322dbaf184a0b.jpg'),
(27377, 1858, 'The Office S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109506.mp4', 'http://timg.bdta.pro/images/20da6e7ab5b4bc1494e82c818430a84b.jpg'),
(27378, 1858, 'The Office S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109507.mp4', 'http://timg.bdta.pro/images/9718410416f18e9b355efaecba926b13.jpg'),
(27379, 1858, 'The Office S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109508.mp4', 'http://timg.bdta.pro/images/7c8f0cef7bf6366d20a399d58a91f3fb.jpg'),
(27380, 1858, 'The Office S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109509.mp4', 'http://timg.bdta.pro/images/3ee1e1aca53b97d927a6756213bd5678.jpg'),
(27381, 1858, 'The Office S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109510.mp4', 'http://timg.bdta.pro/images/51757dddf83dd9a44b332bb79cb436ef.jpg'),
(27382, 1858, 'The Office S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109511.mp4', 'http://timg.bdta.pro/images/0b298cfd82d8fea3eea0072070d049ae.jpg'),
(27383, 1858, 'The Office S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109512.mp4', 'http://timg.bdta.pro/images/44a75f6bdbe2edc7121e68fd22ffb610.jpg'),
(27384, 1858, 'The Office S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109513.mp4', 'http://timg.bdta.pro/images/853f996c4d4f42a38b7a9dbefd33a55b.jpg'),
(27385, 1858, 'The Office S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109514.mp4', 'http://timg.bdta.pro/images/7c8b28b38472d9111bfebd6d462f2829.jpg'),
(27386, 1858, 'The Office S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109515.mp4', 'http://timg.bdta.pro/images/35f2e72781430ff93e482ef2450f0e4d.jpg'),
(27387, 1858, 'The Office S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109516.mp4', 'http://timg.bdta.pro/images/981b7f6f177d724f09c388c35840b812.jpg'),
(27388, 1858, 'The Office S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109517.mp4', 'http://timg.bdta.pro/images/16316717f34cda14f471412fbd3523ca.jpg'),
(27389, 1858, 'The Office S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109518.mp4', 'http://timg.bdta.pro/images/c15874bea748c194568916101407962b.jpg'),
(27390, 1858, 'The Office S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109519.mp4', 'http://timg.bdta.pro/images/74ce709e822f8c3592f1d27cdbe0178d.jpg'),
(27391, 1858, 'The Office S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109520.mp4', 'http://timg.bdta.pro/images/4904ed00cc7393bac741e047101663aa.jpg'),
(27392, 1858, 'The Office S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109521.mp4', 'http://timg.bdta.pro/images/4243a6d16184dc627b92f33ae4ca3d66.jpg'),
(27393, 1858, 'The Office S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/109522.mp4', 'http://timg.bdta.pro/images/2a852e698051e7efbe60bde655e4b51f.jpg'),
(27394, 1858, 'The Office S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/109523.mp4', 'http://timg.bdta.pro/images/659dba728696760b385355d17d1279b3.jpg'),
(27395, 1858, 'The Office S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/109524.mp4', 'http://timg.bdta.pro/images/8144863b5c28b68337e415a8ca0044f9.jpg'),
(27396, 1858, 'The Office S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/109525.mp4', 'http://timg.bdta.pro/images/ac1c9869cd85445c60e8e468a22ae884.jpg'),
(27397, 1858, 'The Office S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/109526.mp4', 'http://timg.bdta.pro/images/46d7415e3ccbc962f23f11cd27943357.jpg'),
(27398, 1858, 'The Office S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/109527.mp4', 'http://timg.bdta.pro/images/f1fc792393f2add6707fa2a639bfa780.jpg'),
(27399, 1858, 'The Office S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/109528.mp4', 'http://timg.bdta.pro/images/043dabfb8e5a2b4c46591db26edd7b92.jpg'),
(27400, 1858, 'The Office S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/109529.mp4', 'http://gstaticontent.com/images/oNZAJgcGVDxjv4PtJ2xU6MPZlHh_big.jpg'),
(27401, 1858, 'The Office S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/109530.mp4', 'http://gstaticontent.com/images/oNZAJgcGVDxjv4PtJ2xU6MPZlHh_big.jpg'),
(27402, 1859, 'The Office S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109531.mp4', 'http://timg.bdta.pro/images/9897040d97e488a42607634ac6a2da23.jpg'),
(27403, 1859, 'The Office S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109532.mp4', 'http://timg.bdta.pro/images/ccd90828be5366703fa32c2141b0724e.jpg'),
(27404, 1859, 'The Office S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109533.mp4', 'http://timg.bdta.pro/images/0b3935139bb2a404c6c573ec53e55076.jpg'),
(27405, 1859, 'The Office S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109534.mp4', 'http://timg.bdta.pro/images/0b3935139bb2a404c6c573ec53e55076.jpg'),
(27406, 1859, 'The Office S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109535.mp4', 'http://timg.bdta.pro/images/2634271971a027c887fbaa59f7e84967.jpg'),
(27407, 1859, 'The Office S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109536.mp4', 'http://timg.bdta.pro/images/2634271971a027c887fbaa59f7e84967.jpg'),
(27408, 1859, 'The Office S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109537.mp4', 'http://timg.bdta.pro/images/25b4a94a6d942a44ab89f53920074bad.jpg'),
(27409, 1859, 'The Office S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109538.mp4', 'http://timg.bdta.pro/images/25b4a94a6d942a44ab89f53920074bad.jpg'),
(27410, 1859, 'The Office S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109539.mp4', 'http://timg.bdta.pro/images/853f3232886efccf1ad266b7404b374d.jpg'),
(27411, 1859, 'The Office S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109540.mp4', 'http://timg.bdta.pro/images/2b390a9d193d560bcf6ef68a47d8fc60.jpg'),
(27412, 1859, 'The Office S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109541.mp4', 'http://timg.bdta.pro/images/342611f3aa453bea087742609b647eab.jpg'),
(27413, 1859, 'The Office S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109542.mp4', 'http://timg.bdta.pro/images/a32c5fb83f2fea7274b5ca9267b10f34.jpg'),
(27414, 1859, 'The Office S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109543.mp4', 'http://timg.bdta.pro/images/4378039f23a20fc4cd158f11a9eb5b2e.jpg'),
(27415, 1859, 'The Office S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109544.mp4', 'http://timg.bdta.pro/images/8118d69798b370b76d8b764cdc39220e.jpg'),
(27416, 1859, 'The Office S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109545.mp4', 'http://timg.bdta.pro/images/6c7735a5d9db568e022731712c3a9dcf.jpg'),
(27417, 1859, 'The Office S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109546.mp4', 'http://timg.bdta.pro/images/9019fbf6b4717335cba2413dd59f862e.jpg'),
(27418, 1859, 'The Office S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/109547.mp4', 'http://timg.bdta.pro/images/b66bd1d806a52a12927834668709a7e2.jpg'),
(27419, 1859, 'The Office S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/109548.mp4', 'http://timg.bdta.pro/images/5cee3bce0c3b9ba293df3d33b6edd7e4.jpg'),
(27420, 1859, 'The Office S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/109549.mp4', 'http://timg.bdta.pro/images/5cee3bce0c3b9ba293df3d33b6edd7e4.jpg'),
(27421, 1860, 'The Office S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109550.mp4', 'http://timg.bdta.pro/images/ff6f4ab72fa777138a561715e4120f9e.jpg'),
(27422, 1860, 'The Office S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109551.mp4', 'http://timg.bdta.pro/images/2ce6bebd4ed1c61111b03ed28e9077cd.jpg'),
(27423, 1860, 'The Office S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109552.mp4', 'http://timg.bdta.pro/images/2055d0cd8cb4b314d3c71a8e116bc9fb.jpg'),
(27424, 1860, 'The Office S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109553.mp4', 'http://timg.bdta.pro/images/32a5d4fcc971005ff48a765d344c1573.jpg'),
(27425, 1860, 'The Office S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109554.mp4', 'http://timg.bdta.pro/images/c57a2795c3f77a701b6a8667bd022c7e.jpg'),
(27426, 1860, 'The Office S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109555.mp4', 'http://timg.bdta.pro/images/877ae31bdf6b547f0a0a07d9670f7d81.jpg'),
(27427, 1860, 'The Office S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109556.mp4', 'http://timg.bdta.pro/images/6b852842cf21f6bd82dee6accfbdb2c4.jpg'),
(27428, 1860, 'The Office S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109557.mp4', 'http://timg.bdta.pro/images/ca98bfd999bfe8d0e7c2448df1780ccd.jpg'),
(27429, 1860, 'The Office S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109558.mp4', 'http://timg.bdta.pro/images/b9e3beb745a7e6fbddecee1b4882e0dc.jpg'),
(27430, 1860, 'The Office S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109559.mp4', 'http://timg.bdta.pro/images/46e1cb6e8b6fbba69a7db6eef5986326.jpg'),
(27431, 1860, 'The Office S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109560.mp4', 'http://timg.bdta.pro/images/b4456057ac84b36b2caaff9866e3134d.jpg'),
(27432, 1860, 'The Office S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109561.mp4', 'http://timg.bdta.pro/images/65ae2b15f0b5e180f386d3403481f623.jpg'),
(27433, 1860, 'The Office S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109562.mp4', 'http://timg.bdta.pro/images/2d3033a1e407b1425248cf4fdd7ab257.jpg'),
(27434, 1860, 'The Office S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109563.mp4', 'http://timg.bdta.pro/images/12a945504254fdd972ad4fa027a55919.jpg'),
(27435, 1860, 'The Office S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109564.mp4', 'http://timg.bdta.pro/images/59892ce14da2d30c7d9d276e0e131041.jpg'),
(27436, 1860, 'The Office S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109565.mp4', 'http://timg.bdta.pro/images/7301253a6d21d75a7084d210c6a2e2eb.jpg'),
(27437, 1860, 'The Office S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/109566.mp4', 'http://timg.bdta.pro/images/1945c07bfd3a390e13bbedeca057621c.jpg'),
(27438, 1860, 'The Office S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/109567.mp4', 'http://timg.bdta.pro/images/7681568226f14cdb7f883f0e20c3a480.jpg'),
(27439, 1860, 'The Office S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/109568.mp4', 'http://timg.bdta.pro/images/4d6f18d64d5d97758c310aeffd738f26.jpg'),
(27440, 1860, 'The Office S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/109569.mp4', 'http://timg.bdta.pro/images/46c15f5df306f81f7c7f09d357d27499.jpg'),
(27441, 1860, 'The Office S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/109570.mp4', 'http://timg.bdta.pro/images/c8cfa3e8d17ae89fd33f3e5301ece75e.jpg'),
(27442, 1860, 'The Office S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/109571.mp4', 'http://timg.bdta.pro/images/fb4d409c890b84e41ab3d22073de5393.jpg'),
(27443, 1860, 'The Office S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/109572.mp4', 'http://timg.bdta.pro/images/0fbd661b24b968a11503bf0a5016b682.jpg'),
(27444, 1860, 'The Office S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/109573.mp4', 'http://timg.bdta.pro/images/dd64920610be6e85e8340752958d8a10.jpg'),
(27445, 1860, 'The Office S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/109574.mp4', 'http://timg.bdta.pro/images/3c97656fa3a5b5b7b79a5e09f1cac228.jpg'),
(27446, 1860, 'The Office S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/109575.mp4', 'http://timg.bdta.pro/images/ca0567aaeaf7e21d0393d4d77028eb18.jpg'),
(27447, 1860, 'The Office S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/109576.mp4', 'http://gstaticontent.com/images/oNZAJgcGVDxjv4PtJ2xU6MPZlHh_big.jpg'),
(27448, 1860, 'The Office S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/109577.mp4', 'http://gstaticontent.com/images/oNZAJgcGVDxjv4PtJ2xU6MPZlHh_big.jpg'),
(27449, 1861, 'The Office S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109578.mp4', 'http://timg.bdta.pro/images/9942d066ce9c51b24edbe6a0511ad0f8.jpg'),
(27450, 1861, 'The Office S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109579.mp4', 'http://timg.bdta.pro/images/e308b35f8d33bdaa18acd941779e8406.jpg'),
(27451, 1861, 'The Office S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109580.mp4', 'http://timg.bdta.pro/images/55883cfda3321d92669b1928eba5ad51.jpg'),
(27452, 1861, 'The Office S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109581.mp4', 'http://timg.bdta.pro/images/79206c395c66578dfdef7304ec4f571e.jpg'),
(27453, 1861, 'The Office S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109582.mp4', 'http://timg.bdta.pro/images/b2db046c3f2ab3c18572a3f71451244c.jpg'),
(27454, 1861, 'The Office S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109583.mp4', 'http://timg.bdta.pro/images/8754bb37622f06f0c6cee59e5da32642.jpg'),
(27455, 1861, 'The Office S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109584.mp4', 'http://timg.bdta.pro/images/742bb8d07f8b1c6d93a6f9cb827e19ac.jpg'),
(27456, 1861, 'The Office S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109585.mp4', 'http://timg.bdta.pro/images/2272aacab0122dbf855e7372ad651959.jpg'),
(27457, 1861, 'The Office S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109586.mp4', 'http://timg.bdta.pro/images/2a72485d7b09d88d5ee2dded46fd4bdd.jpg'),
(27458, 1861, 'The Office S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109587.mp4', 'http://timg.bdta.pro/images/b476e3ff7e301e943f867fd9f01f8a70.jpg'),
(27459, 1861, 'The Office S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109588.mp4', 'http://timg.bdta.pro/images/78c4424fdb2b3b50a5d3eace4cfc2707.jpg'),
(27460, 1861, 'The Office S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109589.mp4', 'http://timg.bdta.pro/images/cfa54b875c02d2c05e7606f0a5f0aec5.jpg'),
(27461, 1861, 'The Office S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109590.mp4', 'http://timg.bdta.pro/images/96f1c28955051d953e81321551e7bbd0.jpg'),
(27462, 1861, 'The Office S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109591.mp4', 'http://timg.bdta.pro/images/a76435a8fd86582559968bbd79e0ed35.jpg'),
(27463, 1861, 'The Office S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109592.mp4', 'http://timg.bdta.pro/images/f468af53699f18c8a75bf2f7edcfb4d0.jpg'),
(27464, 1861, 'The Office S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109593.mp4', 'http://timg.bdta.pro/images/048eb32d88cdb8de823ea1de6ba3bb92.jpg'),
(27465, 1861, 'The Office S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/109594.mp4', 'http://timg.bdta.pro/images/4dd025f0a3d7a9ef1d4db8d26b210030.jpg'),
(27466, 1861, 'The Office S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/109595.mp4', 'http://timg.bdta.pro/images/66480ce5d772aef9e462fbd268339829.jpg'),
(27467, 1861, 'The Office S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/109596.mp4', 'http://timg.bdta.pro/images/911791e66b6f986fef48b298a71f262e.jpg'),
(27468, 1861, 'The Office S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/109597.mp4', 'http://timg.bdta.pro/images/21548ee5f3dad7dac7ddc858c3d4ee37.jpg'),
(27469, 1861, 'The Office S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/109598.mp4', 'http://timg.bdta.pro/images/9fb71fc07ec40ab5a02d17a46ce13f7f.jpg'),
(27470, 1861, 'The Office S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/109599.mp4', 'http://timg.bdta.pro/images/f05f4dc819415fbc74621f8dcd73662a.jpg'),
(27471, 1861, 'The Office S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/109600.mp4', 'http://timg.bdta.pro/images/8c24e5fe3c1397b8ed414293c68433ce.jpg'),
(27472, 1861, 'The Office S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/109601.mp4', 'http://timg.bdta.pro/images/f01d1b46655b33c0c9ef7630338199d1.jpg'),
(27473, 1861, 'The Office S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/109602.mp4', 'http://timg.bdta.pro/images/3226e2be31ef87e11c99bd6e1a806a9d.jpg'),
(27474, 1861, 'The Office S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/109603.mp4', 'http://timg.bdta.pro/images/e04a05ee1b2b0ae650ed6130085b13ed.jpg'),
(27475, 1862, 'The Office S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109604.mp4', 'http://timg.bdta.pro/images/accc2a009bec7a6db3eb6184d51fd115.jpg'),
(27476, 1862, 'The Office S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109605.mp4', 'http://timg.bdta.pro/images/b30c3337786c7ec04934e08c91930ae7.jpg'),
(27477, 1862, 'The Office S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109606.mp4', 'http://timg.bdta.pro/images/dba8f125475c2add374abca5e46dbfd2.jpg'),
(27478, 1862, 'The Office S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109607.mp4', 'http://timg.bdta.pro/images/a44a5a3f01d38d4397858ba4c921623c.jpg'),
(27479, 1862, 'The Office S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109608.mp4', 'http://timg.bdta.pro/images/407e80c21496622983da3dcd0e7f86fa.jpg'),
(27480, 1862, 'The Office S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109609.mp4', 'http://timg.bdta.pro/images/91dda29ba3e234cabd6a3a159308a0a8.jpg'),
(27481, 1862, 'The Office S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109610.mp4', 'http://timg.bdta.pro/images/826897fb9cf25b199828b30313287261.jpg'),
(27482, 1862, 'The Office S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109611.mp4', 'http://timg.bdta.pro/images/312dc1d3c2acc4da1a9b343cc260b184.jpg'),
(27483, 1862, 'The Office S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109612.mp4', 'http://timg.bdta.pro/images/b5d623345330aac0ebb200205f6a11a2.jpg'),
(27484, 1862, 'The Office S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109613.mp4', 'http://timg.bdta.pro/images/a2addd32c905516924b6e5c503a28f54.jpg'),
(27485, 1862, 'The Office S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109614.mp4', 'http://timg.bdta.pro/images/72c9a24873fad069c67eeb898e8e0fdb.jpg'),
(27486, 1862, 'The Office S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109615.mp4', 'http://timg.bdta.pro/images/a5cfa643e20eaa5e86dfda9ab5dede4b.jpg'),
(27487, 1862, 'The Office S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109616.mp4', 'http://timg.bdta.pro/images/37d87e149c333f2fb3509a5df66f3a77.jpg'),
(27488, 1862, 'The Office S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109617.mp4', 'http://timg.bdta.pro/images/bfddda727a78d258f7fd2a94b4b1242c.jpg'),
(27489, 1862, 'The Office S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109618.mp4', 'http://timg.bdta.pro/images/4138c09180c72f0777dcc3d3562193e9.jpg'),
(27490, 1862, 'The Office S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109619.mp4', 'http://timg.bdta.pro/images/41651104261293e1b5644af6e5a37060.jpg'),
(27491, 1862, 'The Office S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/109620.mp4', 'http://timg.bdta.pro/images/2d0459e82961f1ea03de8b6da536cc6f.jpg'),
(27492, 1862, 'The Office S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/109621.mp4', 'http://timg.bdta.pro/images/4398a128283e6a8469dfa67e41db6f0f.jpg'),
(27493, 1862, 'The Office S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/109622.mp4', 'http://timg.bdta.pro/images/e5d871269edc2487ca142fdec6da10ae.jpg'),
(27494, 1862, 'The Office S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/109623.mp4', 'http://timg.bdta.pro/images/6fcd865f2f6c9a4c9450e9ea8ebe426b.jpg'),
(27495, 1862, 'The Office S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/109624.mp4', 'http://timg.bdta.pro/images/99e35ea7d52b2abfe4fda9745ba46a40.jpg'),
(27496, 1862, 'The Office S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/109625.mp4', 'http://timg.bdta.pro/images/73c9f440d76911af27e3afdd4e897dde.jpg'),
(27497, 1862, 'The Office S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/109626.mp4', 'http://timg.bdta.pro/images/3c047d1538c93569556f1b16e901c31e.jpg'),
(27498, 1862, 'The Office S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/109627.mp4', 'http://timg.bdta.pro/images/d813a9eb33cb91b2f744929af48a056c.jpg'),
(27499, 1862, 'The Office S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/109628.mp4', 'http://timg.bdta.pro/images/37234bac5e282f4bf776e9553db14033.jpg'),
(27500, 1862, 'The Office S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/109629.mp4', 'http://timg.bdta.pro/images/617ed072bf0cf50a1d8fa6585c384149.jpg'),
(27501, 1862, 'The Office S07 E27', 'http://sinalprivado.info:80/series/1533784/1533784/109630.mp4', 'http://gstaticontent.com/images/oNZAJgcGVDxjv4PtJ2xU6MPZlHh_big.jpg'),
(27502, 1863, 'The Office S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109631.mp4', 'http://timg.bdta.pro/images/f88d8e2149ae7764212b929866651d68.jpg'),
(27503, 1863, 'The Office S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109632.mp4', 'http://timg.bdta.pro/images/7dce58b4d1f6d2d621454070c45ef70a.jpg'),
(27504, 1863, 'The Office S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109633.mp4', 'http://timg.bdta.pro/images/5acbe33546edb35aa1bb728d963400f3.jpg'),
(27505, 1863, 'The Office S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109634.mp4', 'http://timg.bdta.pro/images/0a66aa0743d2ca3e190f2eb4586b6a80.jpg'),
(27506, 1863, 'The Office S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109635.mp4', 'http://timg.bdta.pro/images/2f3bb3de87c0914013515e4deed2bb1c.jpg'),
(27507, 1863, 'The Office S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109636.mp4', 'http://timg.bdta.pro/images/2a925a6b602822aba30abf61abb5d22e.jpg'),
(27508, 1863, 'The Office S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109637.mp4', 'http://timg.bdta.pro/images/0bf558f0bd1b7fd1a18f334de77909cd.jpg'),
(27509, 1863, 'The Office S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109638.mp4', 'http://timg.bdta.pro/images/4b56c486fb9bb235ac578e099d50fa5d.jpg'),
(27510, 1863, 'The Office S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109639.mp4', 'http://timg.bdta.pro/images/3c509797d739c41ee50474d46f9def76.jpg'),
(27511, 1863, 'The Office S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109640.mp4', 'http://timg.bdta.pro/images/1dce24b9b73f8d21c856a5f54d25420c.jpg'),
(27512, 1863, 'The Office S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109641.mp4', 'http://timg.bdta.pro/images/e203800ea912957c153c4bb1ae5fe187.jpg'),
(27513, 1863, 'The Office S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109642.mp4', 'http://timg.bdta.pro/images/ff345863c93867718039b19dd9ad1316.jpg'),
(27514, 1863, 'The Office S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109643.mp4', 'http://timg.bdta.pro/images/dc80ed431df0028054e70fe704817082.jpg'),
(27515, 1863, 'The Office S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109644.mp4', 'http://timg.bdta.pro/images/309eee6f611b81fea8b1d5c4b8e425db.jpg'),
(27516, 1863, 'The Office S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109645.mp4', 'http://timg.bdta.pro/images/f22438f61e915680a2458d7b96fd55d1.jpg'),
(27517, 1863, 'The Office S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109646.mp4', 'http://timg.bdta.pro/images/e4cb144f1053ad805205038147fbd826.jpg'),
(27518, 1863, 'The Office S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/109647.mp4', 'http://timg.bdta.pro/images/942d92e72a6983184a26bfad95714d0c.jpg'),
(27519, 1863, 'The Office S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/109648.mp4', 'http://timg.bdta.pro/images/c658a9c404c2ef580bac8280f9ae8ef6.jpg'),
(27520, 1863, 'The Office S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/109649.mp4', 'http://timg.bdta.pro/images/13cec7ad569d6e816ee11df30265519e.jpg'),
(27521, 1863, 'The Office S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/109650.mp4', 'http://timg.bdta.pro/images/5aea2c938cc9011ba838a2908afbc30a.jpg'),
(27522, 1863, 'The Office S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/109651.mp4', 'http://timg.bdta.pro/images/cabb20a69ce9a212a66f1a8f17c40544.jpg'),
(27523, 1863, 'The Office S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/109652.mp4', 'http://timg.bdta.pro/images/4877c0e59d04a799e111865e6de179de.jpg'),
(27524, 1863, 'The Office S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/109653.mp4', 'http://timg.bdta.pro/images/63a0f2c678011a16f3175f40b697d671.jpg'),
(27525, 1863, 'The Office S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/109654.mp4', 'http://timg.bdta.pro/images/074edceeb73cdb5f9ca75569dacc51f6.jpg'),
(27526, 1864, 'The Office S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109655.mp4', 'http://timg.bdta.pro/images/c31f88cd63ca8dae15a47c1c525b9598.jpg'),
(27527, 1864, 'The Office S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109656.mp4', 'http://timg.bdta.pro/images/7c6cb104da6e9bb58b36ea1e566315cc.jpg'),
(27528, 1864, 'The Office S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109657.mp4', 'http://timg.bdta.pro/images/645e8960ac9ed6696738b0aa6285b97a.jpg'),
(27529, 1864, 'The Office S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109658.mp4', 'http://timg.bdta.pro/images/bd00f545e350d10435a537df5a57d5e7.jpg'),
(27530, 1864, 'The Office S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109659.mp4', 'http://timg.bdta.pro/images/e1c8a3a8da32e61aa47fff93fa5b4446.jpg'),
(27531, 1864, 'The Office S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109660.mp4', 'http://timg.bdta.pro/images/9893e95398c8cfa85b10a0d126e4e156.jpg'),
(27532, 1864, 'The Office S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109661.mp4', 'http://timg.bdta.pro/images/be91ee08507a8802372390f9064c9732.jpg'),
(27533, 1864, 'The Office S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109662.mp4', 'http://timg.bdta.pro/images/d7fe0d6873d67719833fa924c13727ff.jpg'),
(27534, 1864, 'The Office S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109663.mp4', 'http://timg.bdta.pro/images/3d10676d1a07bee811fb393fce8adc6c.jpg'),
(27535, 1864, 'The Office S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109664.mp4', 'http://timg.bdta.pro/images/f2c6edd67fbd919132c152baebb621f0.jpg'),
(27536, 1864, 'The Office S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109665.mp4', 'http://timg.bdta.pro/images/885dc98cccdf6024fcdb7cea7578ca88.jpg'),
(27537, 1864, 'The Office S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109666.mp4', 'http://timg.bdta.pro/images/9fe455f5cff16e8e543683949f52b9d1.jpg'),
(27538, 1864, 'The Office S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109667.mp4', 'http://timg.bdta.pro/images/0a8d452c007e3312a42eff201f58481c.jpg'),
(27539, 1864, 'The Office S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109668.mp4', 'http://timg.bdta.pro/images/702236c631d9761273ee9bcc5f5aee5d.jpg'),
(27540, 1864, 'The Office S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109669.mp4', 'http://timg.bdta.pro/images/97a1b98162986e781ab673f14735a897.jpg'),
(27541, 1864, 'The Office S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109670.mp4', 'http://timg.bdta.pro/images/38f833c64a5176c48caeeb50818055cf.jpg'),
(27542, 1864, 'The Office S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/109671.mp4', 'http://timg.bdta.pro/images/787203b099c04abb21dcccb8c5ff1db1.jpg'),
(27543, 1864, 'The Office S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/109672.mp4', 'http://timg.bdta.pro/images/e1027df71fb11c795c1fc29f6c996fc1.jpg'),
(27544, 1864, 'The Office S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/109673.mp4', 'http://timg.bdta.pro/images/c9e25dbe69030bd77e8dea54e65e06fe.jpg'),
(27545, 1864, 'The Office S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/109674.mp4', 'http://timg.bdta.pro/images/4ea03c7e06f16d393ed7abc665490afb.jpg'),
(27546, 1864, 'The Office S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/109675.mp4', 'http://timg.bdta.pro/images/56b0cc63e1bd89482fd2296fd3b47fa3.jpg'),
(27547, 1864, 'The Office S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/109676.mp4', 'http://timg.bdta.pro/images/47067b507b2a35940e04dab7dabf0c7c.jpg'),
(27548, 1864, 'The Office S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/109677.mp4', 'http://timg.bdta.pro/images/a6af3d379685ad2bbb74dca0e7c0569a.jpg'),
(27549, 1864, 'The Office S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/109678.mp4', 'http://timg.bdta.pro/images/d712b71f84f46b7edcc36da7e3e8ab97.jpg'),
(27550, 1864, 'The Office S09 E25', 'http://sinalprivado.info:80/series/1533784/1533784/109679.mp4', 'http://timg.bdta.pro/images/8cdb83f7a02e99b3db2670440b3af9cd.jpg'),
(27551, 1864, 'The Office S09 E26', 'http://sinalprivado.info:80/series/1533784/1533784/109680.mp4', 'http://timg.bdta.pro/images/0d047b9d2ba54e23af0c6f6635599fc8.jpg'),
(27552, 1864, 'The Office S09 E27', 'http://sinalprivado.info:80/series/1533784/1533784/109681.mp4', 'http://timg.bdta.pro/images/8f5ec1386126fb6168e61113e226b8be.jpg'),
(27553, 1865, 'A Casa Coruja S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228899.mp4', 'http://timg.bdta.pro/images/538564df6714dcbe41d89b171b8a4848.jpg'),
(27554, 1865, 'A Casa Coruja S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228900.mp4', 'http://timg.bdta.pro/images/ff19907bf321f68d6109007a227b182e.jpg'),
(27555, 1865, 'A Casa Coruja S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228901.mp4', 'http://timg.bdta.pro/images/2b04c17e8e44af52a3381b940e0fe639.jpg'),
(27556, 1865, 'A Casa Coruja S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228902.mp4', 'http://timg.bdta.pro/images/a417b22745f5c392922f4e397c9703fb.jpg'),
(27557, 1865, 'A Casa Coruja S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228903.mp4', 'http://timg.bdta.pro/images/ce95ab2d2044df143428fb0f999bdfdb.jpg'),
(27558, 1865, 'A Casa Coruja S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228904.mp4', 'http://timg.bdta.pro/images/094018fbdc25f355cbcf79864a030312.jpg'),
(27559, 1865, 'A Casa Coruja S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228905.mp4', 'http://timg.bdta.pro/images/d2b7947c749a34c7125beb1bd3c1bbc0.jpg'),
(27560, 1865, 'A Casa Coruja S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228906.mp4', 'http://timg.bdta.pro/images/918ec66929b8ce7da2d2d746a16df4d1.jpg'),
(27561, 1865, 'A Casa Coruja S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228907.mp4', 'http://timg.bdta.pro/images/4f4fb7bc10dc0664ee9de06e591de102.jpg'),
(27562, 1865, 'A Casa Coruja S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228908.mp4', 'http://timg.bdta.pro/images/fb97bc402f5265deca7a8d49cc178c78.jpg'),
(27563, 1865, 'A Casa Coruja S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228909.mp4', 'http://timg.bdta.pro/images/2bcf5d5b189f3eb48203d03be4e1b448.jpg'),
(27564, 1865, 'A Casa Coruja S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228910.mp4', 'http://timg.bdta.pro/images/00486b1a50ce6547bb079c835a5f7872.jpg'),
(27565, 1865, 'A Casa Coruja S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228911.mp4', 'http://timg.bdta.pro/images/a808a2e07e369d42eb02043f724956ac.jpg'),
(27566, 1865, 'A Casa Coruja S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228912.mp4', 'http://timg.bdta.pro/images/e66b49aea92660cf68dc3a93932cd32f.jpg'),
(27567, 1865, 'A Casa Coruja S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228913.mp4', 'http://timg.bdta.pro/images/b10c6fe13d8b2a0a9fb5eee2a9ca84c0.jpg'),
(27568, 1865, 'A Casa Coruja S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/228914.mp4', 'http://timg.bdta.pro/images/766a447c8b6efab14a64a968fa76ea06.jpg'),
(27569, 1865, 'A Casa Coruja S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/228915.mp4', 'http://timg.bdta.pro/images/7f914d053d645946a7d7964a741d6957.jpg'),
(27570, 1865, 'A Casa Coruja S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/228916.mp4', 'http://timg.bdta.pro/images/4ddca0fe0df27a4f3e166f8cdbc7c970.jpg'),
(27571, 1865, 'A Casa Coruja S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/228917.mp4', 'http://timg.bdta.pro/images/5da30f70342b4c388868e91823d458bd.jpg'),
(27572, 1866, 'A Casa Coruja S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228918.mp4', 'http://timg.bdta.pro/images/e51837e8ee88e1f090ca43c1996e4d5e.jpg'),
(27573, 1866, 'A Casa Coruja S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228919.mp4', 'http://timg.bdta.pro/images/6f737091006f2ec41f7be9243a8c2a33.jpg'),
(27574, 1866, 'A Casa Coruja S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228920.mp4', 'http://timg.bdta.pro/images/dbbec6ac91580acc37ec5b29301e4c6e.jpg'),
(27575, 1866, 'A Casa Coruja S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228921.mp4', 'http://timg.bdta.pro/images/dd55ac55de0bcbc3cf0b834f20dba7f7.jpg'),
(27576, 1866, 'A Casa Coruja S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228922.mp4', 'http://timg.bdta.pro/images/0b9c6075bd79ae9ca7a2230293032684.jpg'),
(27577, 1866, 'A Casa Coruja S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228923.mp4', 'http://timg.bdta.pro/images/f39caab9591d58fa461068d361c99af1.jpg'),
(27578, 1866, 'A Casa Coruja S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228924.mp4', 'http://timg.bdta.pro/images/15e8df6f9e8292c34bac3165ca412f7e.jpg'),
(27579, 1866, 'A Casa Coruja S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228925.mp4', 'http://timg.bdta.pro/images/40789386a9e7fb79be1c54a220c94825.jpg'),
(27580, 1866, 'A Casa Coruja S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228926.mp4', 'http://timg.bdta.pro/images/d623533fbf245d5c872d26558e95ddb8.jpg'),
(27581, 1866, 'A Casa Coruja S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228927.mp4', 'http://timg.bdta.pro/images/63ccb2d93774d578eea8ae2b9698fb17.jpg'),
(27582, 1866, 'A Casa Coruja S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228928.mp4', 'http://timg.bdta.pro/images/3bb3a3d848d37c305885c2509f3462de.jpg'),
(27583, 1866, 'A Casa Coruja S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228929.mp4', 'http://timg.bdta.pro/images/7ba09779e12fa55573da89161f6d32d1.jpg'),
(27584, 1866, 'A Casa Coruja S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228930.mp4', 'http://timg.bdta.pro/images/675758564a64a9cec6617034cf9171de.jpg'),
(27585, 1866, 'A Casa Coruja S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228931.mp4', 'http://timg.bdta.pro/images/07680923fca90f260381e21c2c151df8.jpg'),
(27586, 1866, 'A Casa Coruja S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228932.mp4', 'http://timg.bdta.pro/images/7e3a42850a8d06a92cb33b0a8d7bc116.jpg'),
(27587, 1866, 'A Casa Coruja S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/228933.mp4', 'http://timg.bdta.pro/images/90851690539a047b4a728c63340183c4.jpg'),
(27588, 1866, 'A Casa Coruja S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/228934.mp4', 'http://timg.bdta.pro/images/a9dbcaafb7a50ba6d77ec87c2cd17366.jpg'),
(27589, 1866, 'A Casa Coruja S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/228935.mp4', 'http://timg.bdta.pro/images/7ab4f424a6e4dd6f78f91bb26b0442fe.jpg'),
(27590, 1866, 'A Casa Coruja S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/228936.mp4', 'http://timg.bdta.pro/images/05ae7df21cadaa12680236039e0c283f.jpg'),
(27591, 1866, 'A Casa Coruja S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/228937.mp4', 'http://timg.bdta.pro/images/b6581c36ed861bbfb9a64d3f9e879f8b.jpg'),
(27592, 1866, 'A Casa Coruja S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/228938.mp4', 'http://timg.bdta.pro/images/8d33b5b1dbe35ef74d6a224b7d8f2820.jpg'),
(27593, 1867, 'A Casa Coruja S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJDR4hosdiyyCsZrsyl0nWRXrp0.jpg'),
(27594, 1867, 'A Casa Coruja S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2mpB9RMSFL1bPlm4snkKiFei9nQ.jpg'),
(27595, 1867, 'A Casa Coruja S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/djgqkbPt6SVlmIwMLd1tUP9joip.jpg'),
(27596, 1868, 'Mega Man: Fully Charged S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114962.mp4', 'http://gstaticontent.com/images/ue354a9MYmEDIurUKCXIJFk0nJX_big.jpg'),
(27597, 1868, 'Mega Man: Fully Charged S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114963.mp4', 'http://gstaticontent.com/images/ue354a9MYmEDIurUKCXIJFk0nJX_big.jpg'),
(27598, 1868, 'Mega Man: Fully Charged S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114964.mp4', 'http://gstaticontent.com/images/ue354a9MYmEDIurUKCXIJFk0nJX_big.jpg'),
(27599, 1868, 'Mega Man: Fully Charged S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114965.mp4', 'http://gstaticontent.com/images/ue354a9MYmEDIurUKCXIJFk0nJX_big.jpg'),
(27600, 1868, 'Mega Man: Fully Charged S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114966.mp4', 'http://gstaticontent.com/images/ue354a9MYmEDIurUKCXIJFk0nJX_big.jpg'),
(27601, 1868, 'Mega Man: Fully Charged S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114967.mp4', 'http://gstaticontent.com/images/ue354a9MYmEDIurUKCXIJFk0nJX_big.jpg'),
(27602, 1868, 'Mega Man: Fully Charged S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114968.mp4', 'http://gstaticontent.com/images/ue354a9MYmEDIurUKCXIJFk0nJX_big.jpg'),
(27603, 1868, 'Mega Man: Fully Charged S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114969.mp4', 'http://gstaticontent.com/images/ue354a9MYmEDIurUKCXIJFk0nJX_big.jpg'),
(27604, 1868, 'Mega Man: Fully Charged S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114970.mp4', 'http://gstaticontent.com/images/ue354a9MYmEDIurUKCXIJFk0nJX_big.jpg'),
(27605, 1868, 'Mega Man: Fully Charged S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114971.mp4', 'http://gstaticontent.com/images/ue354a9MYmEDIurUKCXIJFk0nJX_big.jpg'),
(27606, 1869, 'One Punch Man S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171571.mp4', 'http://timg.bdta.pro/images/7767796a94fbfc00f6437d4643f9628e.jpg'),
(27607, 1869, 'One Punch Man S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171572.mp4', 'http://timg.bdta.pro/images/82436cf16c059296a121cd20c020e7fd.jpg'),
(27608, 1869, 'One Punch Man S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171573.mp4', 'http://timg.bdta.pro/images/27375290f8a697facba0a40dc6f3431a.jpg'),
(27609, 1869, 'One Punch Man S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171574.mp4', 'http://timg.bdta.pro/images/c3fbe0981d8c4ec7444e2f6a403acfa7.jpg'),
(27610, 1869, 'One Punch Man S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171575.mp4', 'http://timg.bdta.pro/images/a528ee1783fa06b9bd341bb68dc20928.jpg'),
(27611, 1869, 'One Punch Man S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171576.mp4', 'http://timg.bdta.pro/images/bbcecb1a265c34743e1dbc554e194c57.jpg'),
(27612, 1869, 'One Punch Man S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171577.mp4', 'http://timg.bdta.pro/images/1052704ee62a181fda42bb4dd4d6affe.jpg'),
(27613, 1869, 'One Punch Man S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171578.mp4', 'http://timg.bdta.pro/images/448360a632421d0dda17d7d249992111.jpg'),
(27614, 1869, 'One Punch Man S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171579.mp4', 'http://timg.bdta.pro/images/cf424560aeda1a6661fe11b162ca2f9f.jpg'),
(27615, 1869, 'One Punch Man S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171580.mp4', 'http://timg.bdta.pro/images/6fdaf2422c761a91768740f0bf98126f.jpg'),
(27616, 1869, 'One Punch Man S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171581.mp4', 'http://timg.bdta.pro/images/dff47737d8563bff19d369c9716eeafa.jpg'),
(27617, 1869, 'One Punch Man S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171582.mp4', 'http://timg.bdta.pro/images/e3333ac887befcc2384c09f31cc37ec6.jpg'),
(27618, 1870, 'One Punch Man S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wNeKfTka6lIDQCGpZuOMATv0UJD.jpg'),
(27619, 1870, 'One Punch Man S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hh6JMbDji6wuz5RFRqDrYzqihaE.jpg'),
(27620, 1870, 'One Punch Man S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gedbotRXMOCUC7P9RblaHgw0LuL.jpg'),
(27621, 1870, 'One Punch Man S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1I29xRhdTy6A1ybdPHc6Ke4fRV2.jpg'),
(27622, 1870, 'One Punch Man S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/us7myp7Us2h87nZ1f8ACZ6Fcaoz.jpg'),
(27623, 1870, 'One Punch Man S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sN0T4orzh3HgMBFoKqI7xcYNjBI.jpg'),
(27624, 1870, 'One Punch Man S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c9QhXBPVwOaayJ04FBt3OXjmafV.jpg'),
(27625, 1870, 'One Punch Man S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tGKbogDzxuL8KlHOkYm6yKlUzFU.jpg'),
(27626, 1870, 'One Punch Man S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/on2YtDbgc6KdbKpRy2DFHShRZP3.jpg'),
(27627, 1870, 'One Punch Man S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zD7LqTECY0MKFVCjsNbdOrBWFQs.jpg'),
(27628, 1870, 'One Punch Man S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gkpapTjLwcjejU1WrLdAhH8O2aG.jpg'),
(27629, 1870, 'One Punch Man S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eveMaMNy7umvSlJDapm2LJERs5n.jpg'),
(27630, 1871, 'One Punch Man S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/896765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vcyxcIh8GeQBFaFlyDxhbEMB2Ta.jpg'),
(27631, 1871, 'One Punch Man S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/896766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eCY9QrCeDElIPruX90uROhbhSRi.jpg'),
(27632, 1871, 'One Punch Man S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/896767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fibP3gymhfGFGpQSl4ShKKiwjy6.jpg'),
(27633, 1872, 'Prisao de Mulheres S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109692.mp4', 'http://timg.bdta.pro/images/feb43ac495873972f794142612ebbfa1.jpg'),
(27634, 1872, 'Prisao de Mulheres S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109693.mp4', 'http://timg.bdta.pro/images/435a0f1b980d33d70ae6a7efb5dbf0c7.jpg'),
(27635, 1872, 'Prisao de Mulheres S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109694.mp4', 'http://timg.bdta.pro/images/a91341602aeee91092ca44429337f9a1.jpg'),
(27636, 1872, 'Prisao de Mulheres S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109695.mp4', 'http://timg.bdta.pro/images/89b0ecdcfd9e0787d34c994db018e1e5.jpg'),
(27637, 1872, 'Prisao de Mulheres S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109696.mp4', 'http://timg.bdta.pro/images/5e08816d85115584305ba162e7594c9b.jpg'),
(27638, 1872, 'Prisao de Mulheres S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109697.mp4', 'http://timg.bdta.pro/images/5c418a926cac154d6a72ee7e2d1863ce.jpg'),
(27639, 1872, 'Prisao de Mulheres S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109698.mp4', 'http://timg.bdta.pro/images/7e423b18de76f1e1090082a13d510fe6.jpg'),
(27640, 1872, 'Prisao de Mulheres S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109699.mp4', 'http://timg.bdta.pro/images/a2f86e8e9a3870261b265bf4b99c2383.jpg'),
(27641, 1872, 'Prisao de Mulheres S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109700.mp4', 'http://timg.bdta.pro/images/4e419686aff2220be6c68c5a11bef805.jpg'),
(27642, 1872, 'Prisao de Mulheres S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109701.mp4', 'http://timg.bdta.pro/images/ff8f5443cddfda83ef3a846c6abc105a.jpg'),
(27643, 1872, 'Prisao de Mulheres S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109702.mp4', 'http://timg.bdta.pro/images/2377e84f782061e1eb5b38c30001d2a7.jpg'),
(27644, 1872, 'Prisao de Mulheres S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109703.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27645, 1872, 'Prisao de Mulheres S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109704.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27646, 1872, 'Prisao de Mulheres S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109705.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27647, 1872, 'Prisao de Mulheres S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109706.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27648, 1872, 'Prisao de Mulheres S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109707.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27649, 1872, 'Prisao de Mulheres S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/109708.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27650, 1872, 'Prisao de Mulheres S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/109709.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27651, 1872, 'Prisao de Mulheres S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/109710.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27652, 1872, 'Prisao de Mulheres S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/109711.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27653, 1872, 'Prisao de Mulheres S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/109712.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27654, 1872, 'Prisao de Mulheres S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/109713.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27655, 1872, 'Prisao de Mulheres S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/109714.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27656, 1872, 'Prisao de Mulheres S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/109715.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27657, 1872, 'Prisao de Mulheres S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/109716.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27658, 1872, 'Prisao de Mulheres S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/109717.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27659, 1872, 'Prisao de Mulheres S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/109718.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27660, 1872, 'Prisao de Mulheres S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/109719.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27661, 1872, 'Prisao de Mulheres S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/109720.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27662, 1872, 'Prisao de Mulheres S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/109721.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27663, 1872, 'Prisao de Mulheres S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/109722.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27664, 1872, 'Prisao de Mulheres S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/109723.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27665, 1872, 'Prisao de Mulheres S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/109724.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(27666, 1872, 'Prisao de Mulheres S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/109725.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27667, 1872, 'Prisao de Mulheres S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/109726.mp4', 'http://gstaticontent.com/images/be7455f6fee3c48ba17b4a3b3c4b4b8a.jpg'),
(27668, 1873, 'Prisao de Mulheres S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bryEvlpFugyFUCu7ceIhQAcbluT.jpg'),
(27669, 1873, 'Prisao de Mulheres S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kNduBdXwG8eQuwXc47gV5HIeCJ.jpg'),
(27670, 1873, 'Prisao de Mulheres S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pH5qxIo6JdkueEaOkEGbZV342z8.jpg'),
(27671, 1873, 'Prisao de Mulheres S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/399391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AeztD6BS2QfDEMYVH5Fvq7l5WZm.jpg'),
(27672, 1873, 'Prisao de Mulheres S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/65LmpbRhZ9cYSlbRcSJt73v7RQY.jpg'),
(27673, 1873, 'Prisao de Mulheres S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/399393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b7VsfaGK6RNbqgkXDBLAd7ocwQn.jpg'),
(27674, 1873, 'Prisao de Mulheres S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/399394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cNOI48bdExypaP0tGu233LNtRsT.jpg'),
(27675, 1873, 'Prisao de Mulheres S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/399395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5nD8VYZPzELi8hfH3Z2FHex7XX.jpg'),
(27676, 1873, 'Prisao de Mulheres S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/399396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1m5a5Xir6uN2KrQrqiprd4lOlG0.jpg'),
(27677, 1873, 'Prisao de Mulheres S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/399397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gIia9jTWbDMHzZvvnmZm7xFe7ZE.jpg'),
(27678, 1873, 'Prisao de Mulheres S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/399398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ouJGvx9fq0xASaC0ahnlSdUhYPp.jpg'),
(27679, 1873, 'Prisao de Mulheres S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/399399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ssgcdCxdEQ9k31fYBtYqkk2Dpzw.jpg'),
(27680, 1873, 'Prisao de Mulheres S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/399400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qHm25PURTebENc0EwNiaqobX4dZ.jpg'),
(27681, 1873, 'Prisao de Mulheres S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/399401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pUjeESkY6IgXm1wSdPi32kojwCN.jpg'),
(27682, 1873, 'Prisao de Mulheres S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/399402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDw5LwHXo86cMub7LBFMgWUVFPp.jpg'),
(27683, 1873, 'Prisao de Mulheres S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/399403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gesvEIScfDs1XBNhIW3kC3jmg8i.jpg'),
(27684, 1873, 'Prisao de Mulheres S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/399404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/paTWLyoaUe3PccXTED9Hti01EYS.jpg'),
(27685, 1873, 'Prisao de Mulheres S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/399405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xkzu2Cw1tvdgA8FJyGt6yIlqwJV.jpg'),
(27686, 1873, 'Prisao de Mulheres S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/399406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yp4Qd35uRBR3fcW8qPq6B5h87Gg.jpg'),
(27687, 1873, 'Prisao de Mulheres S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/399407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nc1TBRPy6tIT7AzF3gQDGFr4Jz3.jpg'),
(27688, 1873, 'Prisao de Mulheres S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/399408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ywroMbr3GF2ob6blgJFtoPZHfl.jpg'),
(27689, 1873, 'Prisao de Mulheres S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/399409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k29QJqIcjdFMCXXSGVIA7KG7EhH.jpg'),
(27690, 1873, 'Prisao de Mulheres S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/399410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rZ2T8u2EL5Iv7eb8lqZuWRRyTlW.jpg'),
(27691, 1874, 'The Oath S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109682.mp4', 'http://timg.bdta.pro/images/345d4c202cacf75e2dbf3a28d481f005.jpg'),
(27692, 1874, 'The Oath S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109683.mp4', 'http://timg.bdta.pro/images/3d7834cb720e143c1f97005ead809a7e.jpg'),
(27693, 1874, 'The Oath S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109684.mp4', 'http://timg.bdta.pro/images/9d44170e8d93faeb4d456368dceb71bb.jpg'),
(27694, 1874, 'The Oath S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109685.mp4', 'http://timg.bdta.pro/images/863017a629515b170e75bafd8e2b16d2.jpg'),
(27695, 1874, 'The Oath S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109686.mp4', 'http://timg.bdta.pro/images/36946ec0141252b8b1212fcce4139b0b.jpg'),
(27696, 1874, 'The Oath S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109687.mp4', 'http://timg.bdta.pro/images/9c6ffe7e579aa986fdfc633b9cf85608.jpg'),
(27697, 1874, 'The Oath S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109688.mp4', 'http://timg.bdta.pro/images/143cbaa79612f9d57b3a5db9016bf825.jpg'),
(27698, 1874, 'The Oath S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109689.mp4', 'http://timg.bdta.pro/images/08b351b7161416d6e1f3c828968653b9.jpg'),
(27699, 1874, 'The Oath S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109690.mp4', 'http://timg.bdta.pro/images/bc09c9bcee584ceaf9db734fb4dc59e6.jpg'),
(27700, 1874, 'The Oath S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109691.mp4', 'http://timg.bdta.pro/images/22b607594fcaf1d2e1c320fc4ed679d3.jpg'),
(27701, 1875, 'Carter S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109929.mp4', 'http://timg.bdta.pro/images/99dc18e8651526be1aa8fbb8b67f35fe.jpg'),
(27702, 1875, 'Carter S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109930.mp4', 'http://timg.bdta.pro/images/8073004364ea0afca5b3c4bb3ab948a5.jpg'),
(27703, 1875, 'Carter S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109931.mp4', 'http://timg.bdta.pro/images/39da3ad9f2f33f02e1d7b269b5d83c42.jpg'),
(27704, 1875, 'Carter S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109932.mp4', 'http://timg.bdta.pro/images/dc4b413a692e1c50b0b7111f79a76e66.jpg'),
(27705, 1875, 'Carter S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109933.mp4', 'http://timg.bdta.pro/images/78f34c5a9529be15d21e54b0a2570276.jpg'),
(27706, 1875, 'Carter S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109934.mp4', 'http://timg.bdta.pro/images/ecb68ddd605e89c30cf18553898dd843.jpg'),
(27707, 1875, 'Carter S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109935.mp4', 'http://timg.bdta.pro/images/ff0313362b2b6ffde2cb9b131e5c6ead.jpg'),
(27708, 1875, 'Carter S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109936.mp4', 'http://timg.bdta.pro/images/118d2031428f6174faf47b47a9aa1ebe.jpg'),
(27709, 1875, 'Carter S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109937.mp4', 'http://timg.bdta.pro/images/8aeb272bc322f0bee1c822992b9faa18.jpg'),
(27710, 1875, 'Carter S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109938.mp4', 'http://timg.bdta.pro/images/c8d1a3f770c070bad16f0ff7f8f6709a.jpg'),
(27711, 1876, 'Carter S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109939.mp4', 'http://timg.bdta.pro/images/6441a0e187057491b4a9a1cd355cf0dc.jpg'),
(27712, 1876, 'Carter S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109940.mp4', 'http://timg.bdta.pro/images/edec8cafc73f09814dccc5e3160cc342.jpg'),
(27713, 1876, 'Carter S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109941.mp4', 'http://timg.bdta.pro/images/ef6c62ff0586c7d6366e5f45e8b3fdea.jpg'),
(27714, 1876, 'Carter S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109942.mp4', 'http://timg.bdta.pro/images/2ac4081318ee4714871fd27b772bce18.jpg'),
(27715, 1876, 'Carter S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109943.mp4', 'http://timg.bdta.pro/images/c8f607c2eee89a3c9cd03acf66d33b6e.jpg'),
(27716, 1876, 'Carter S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109944.mp4', 'http://timg.bdta.pro/images/3dd23a17fc5989dae34e3aa5b83c7ce1.jpg'),
(27717, 1876, 'Carter S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109945.mp4', 'http://timg.bdta.pro/images/ca68522508ccd27199e902a8d5e84885.jpg'),
(27718, 1876, 'Carter S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109946.mp4', 'http://timg.bdta.pro/images/ed4fb53ca608e7b6372e012d2d8b6e6c.jpg'),
(27719, 1876, 'Carter S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109947.mp4', 'http://timg.bdta.pro/images/ed4fb53ca608e7b6372e012d2d8b6e6c.jpg'),
(27720, 1876, 'Carter S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109948.mp4', 'http://timg.bdta.pro/images/ed4fb53ca608e7b6372e012d2d8b6e6c.jpg'),
(27721, 1877, 'Plantao Noturno S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109727.mp4', 'http://timg.bdta.pro/images/bfd41610514bbcc6d773650a0368b868.jpg'),
(27722, 1877, 'Plantao Noturno S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109728.mp4', 'http://timg.bdta.pro/images/ce4d7ee2c8d1c8cd55c6cf0061e782fd.jpg'),
(27723, 1877, 'Plantao Noturno S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109729.mp4', 'http://timg.bdta.pro/images/ab3c6b8c32c6da095152020b10b96a5d.jpg'),
(27724, 1877, 'Plantao Noturno S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109730.mp4', 'http://timg.bdta.pro/images/744d5c8e24b5d470d11ed5bdc0d1147c.jpg'),
(27725, 1877, 'Plantao Noturno S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109731.mp4', 'http://timg.bdta.pro/images/dc6151e91ac7ce4140bcfd149df3a981.jpg'),
(27726, 1877, 'Plantao Noturno S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109732.mp4', 'http://timg.bdta.pro/images/9ce0b89edd6a5cbb28914869e3005fe5.jpg'),
(27727, 1877, 'Plantao Noturno S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109733.mp4', 'http://timg.bdta.pro/images/e4299cacd731c9034b14afd0dc971230.jpg'),
(27728, 1877, 'Plantao Noturno S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109734.mp4', 'http://timg.bdta.pro/images/ebfa0cb9e2d13bd3bc19175cda133895.jpg'),
(27729, 1878, 'Plantao Noturno S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109735.mp4', 'http://timg.bdta.pro/images/2075b2e88b5a9da2787fc7d6b9fead83.jpg'),
(27730, 1878, 'Plantao Noturno S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109736.mp4', 'http://timg.bdta.pro/images/060d6a3183ba141b363f758ff01216d1.jpg'),
(27731, 1878, 'Plantao Noturno S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109737.mp4', 'http://timg.bdta.pro/images/bc2c1554251bcbed9d1bae78065abcc1.jpg'),
(27732, 1878, 'Plantao Noturno S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109738.mp4', 'http://timg.bdta.pro/images/1c2b82f2c78d74a947d15ed8d65b9431.jpg'),
(27733, 1878, 'Plantao Noturno S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109739.mp4', 'http://timg.bdta.pro/images/a790cc50a5535674b0eb6e0f82f0347e.jpg'),
(27734, 1878, 'Plantao Noturno S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109740.mp4', 'http://timg.bdta.pro/images/c82525e1621d665edbda067755903188.jpg'),
(27735, 1878, 'Plantao Noturno S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109741.mp4', 'http://timg.bdta.pro/images/fb59534d9d385f036b0bb4a21342d118.jpg'),
(27736, 1878, 'Plantao Noturno S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109742.mp4', 'http://timg.bdta.pro/images/4e548191dd2987b1ad8d0075ae6ebb9d.jpg'),
(27737, 1878, 'Plantao Noturno S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109743.mp4', 'http://timg.bdta.pro/images/c90d0b8b7dbdfd4b59923e4dca7daab9.jpg'),
(27738, 1878, 'Plantao Noturno S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109744.mp4', 'http://timg.bdta.pro/images/258754baf1e51ad7a8814b3e8dec389a.jpg'),
(27739, 1878, 'Plantao Noturno S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109745.mp4', 'http://timg.bdta.pro/images/9ab89b30f3548d716f5a902e5a7892ee.jpg'),
(27740, 1878, 'Plantao Noturno S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109746.mp4', 'http://timg.bdta.pro/images/e396646936cf35f290fe1d8d6fbe52b6.jpg'),
(27741, 1878, 'Plantao Noturno S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109747.mp4', 'http://timg.bdta.pro/images/91bfb11654e1c5cba85f118d871dd4cb.jpg'),
(27742, 1878, 'Plantao Noturno S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109748.mp4', 'http://timg.bdta.pro/images/d2d8567d3a29bac6a91f5576415edc5e.jpg'),
(27743, 1879, 'Plantao Noturno S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109749.mp4', 'http://timg.bdta.pro/images/465a4a889f9226373148f8b9a59d8ba8.jpg'),
(27744, 1879, 'Plantao Noturno S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109750.mp4', 'http://timg.bdta.pro/images/1fe2fc2619e21e7e1000f725bbe03c15.jpg'),
(27745, 1879, 'Plantao Noturno S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109751.mp4', 'http://timg.bdta.pro/images/fc51910f79191b4e57dffcb56cfa6efa.jpg'),
(27746, 1879, 'Plantao Noturno S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109752.mp4', 'http://timg.bdta.pro/images/bbd2ac40c830de366d41183cdb8cc22c.jpg'),
(27747, 1879, 'Plantao Noturno S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109753.mp4', 'http://timg.bdta.pro/images/95faaa191a0e77dfadc8febde6fc68ca.jpg'),
(27748, 1879, 'Plantao Noturno S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109754.mp4', 'http://timg.bdta.pro/images/082d798f459d863f91c52f9103fcbeea.jpg'),
(27749, 1879, 'Plantao Noturno S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109755.mp4', 'http://timg.bdta.pro/images/c029dbe979f68df69a3c1ff650eca6bb.jpg'),
(27750, 1879, 'Plantao Noturno S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109756.mp4', 'http://timg.bdta.pro/images/d5761e5a97b6caa6396d35b662c61799.jpg'),
(27751, 1879, 'Plantao Noturno S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109757.mp4', 'http://timg.bdta.pro/images/5ef261a75512021f87b9aa1144c91c50.jpg'),
(27752, 1879, 'Plantao Noturno S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109758.mp4', 'http://timg.bdta.pro/images/7a6e549a741d27c05927871070d8d387.jpg'),
(27753, 1879, 'Plantao Noturno S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109759.mp4', 'http://timg.bdta.pro/images/d3099d62efc50c67ddf2c6cbd7ae3f42.jpg'),
(27754, 1879, 'Plantao Noturno S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109760.mp4', 'http://timg.bdta.pro/images/e276d895d888758e5b93c7663e1df89c.jpg'),
(27755, 1879, 'Plantao Noturno S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109761.mp4', 'http://timg.bdta.pro/images/bffcd7655c59e099a3dee1758d0ab065.jpg'),
(27756, 1880, 'Plantao Noturno S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109762.mp4', 'http://timg.bdta.pro/images/3e05d40619131c611e91173d2d44ffc9.jpg'),
(27757, 1880, 'Plantao Noturno S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109763.mp4', 'http://timg.bdta.pro/images/d14cd1d7c098ac39cff6f2cb16e71f4a.jpg'),
(27758, 1880, 'Plantao Noturno S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109764.mp4', 'http://timg.bdta.pro/images/f2459c9a6f6a06a43f6edde9b17cdbb8.jpg'),
(27759, 1880, 'Plantao Noturno S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109765.mp4', 'http://timg.bdta.pro/images/dd35d827cfedaea8695fad6046d7bd4c.jpg'),
(27760, 1880, 'Plantao Noturno S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109766.mp4', 'http://timg.bdta.pro/images/0e86518750608da768eef15779a138bb.jpg'),
(27761, 1880, 'Plantao Noturno S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109767.mp4', 'http://timg.bdta.pro/images/559722e6b0b7b5963463c21fcd5d902f.jpg'),
(27762, 1880, 'Plantao Noturno S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109768.mp4', 'http://timg.bdta.pro/images/ac19b3e5b50a0f0498c1758275cb81b8.jpg'),
(27763, 1880, 'Plantao Noturno S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109769.mp4', 'http://timg.bdta.pro/images/1c2e2b2f097c9900c8453c40db083c31.jpg'),
(27764, 1880, 'Plantao Noturno S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109770.mp4', 'http://timg.bdta.pro/images/327f7d014c4c6b4497706c8efccf8d81.jpg'),
(27765, 1880, 'Plantao Noturno S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109771.mp4', 'http://timg.bdta.pro/images/eecfa1a2b538bfc0fa67910809cf6735.jpg'),
(27766, 1881, 'Deadwood S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108564.mp4', 'http://timg.bdta.pro/images/750975e0f03eb2b601810fc1186ca378.jpg'),
(27767, 1881, 'Deadwood S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108565.mp4', 'http://timg.bdta.pro/images/7fa34f56cc6d7487233c49f3ef00d93f.jpg'),
(27768, 1881, 'Deadwood S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108566.mp4', 'http://timg.bdta.pro/images/40cb70c1231b9dd2252f4dc8e23ea74e.jpg'),
(27769, 1881, 'Deadwood S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108567.mp4', 'http://timg.bdta.pro/images/8880af1508e08a4af8f223984b25632b.jpg'),
(27770, 1881, 'Deadwood S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108568.mp4', 'http://timg.bdta.pro/images/377dda58dcb9335a90254fcae97ce921.jpg'),
(27771, 1881, 'Deadwood S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108569.mp4', 'http://timg.bdta.pro/images/290d03c7f6fb62d1a1cedbf20944916b.jpg'),
(27772, 1881, 'Deadwood S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108570.mp4', 'http://timg.bdta.pro/images/0c4e641bcef1b2c100d32329192802a4.jpg'),
(27773, 1881, 'Deadwood S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108571.mp4', 'http://timg.bdta.pro/images/acbccb4f1ea82769d3022b08d70551b5.jpg'),
(27774, 1881, 'Deadwood S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108572.mp4', 'http://timg.bdta.pro/images/f5d1f5b41b1599a8f424911106ee150b.jpg'),
(27775, 1881, 'Deadwood S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108573.mp4', 'http://timg.bdta.pro/images/6ded5e2a75aab22e053a5a04ce428f95.jpg'),
(27776, 1881, 'Deadwood S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108574.mp4', 'http://timg.bdta.pro/images/926d621ad4b568fc41a4155cdefef9ce.jpg'),
(27777, 1881, 'Deadwood S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108575.mp4', 'http://timg.bdta.pro/images/02bb963f1102ff2c377e03b038a8c8aa.jpg'),
(27778, 1882, 'Deadwood S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108576.mp4', 'http://timg.bdta.pro/images/4bb1ea64a7d53147073e370313fb12da.jpg'),
(27779, 1882, 'Deadwood S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108577.mp4', 'http://timg.bdta.pro/images/74fd4960ec691d4d48a6d5c58ae583f0.jpg'),
(27780, 1882, 'Deadwood S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108578.mp4', 'http://timg.bdta.pro/images/47f6111dccef023f91aecc07d799ae2a.jpg'),
(27781, 1882, 'Deadwood S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108579.mp4', 'http://timg.bdta.pro/images/faa5670629c90e4aab939f261fc7f100.jpg'),
(27782, 1882, 'Deadwood S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108580.mp4', 'http://timg.bdta.pro/images/b0735d2bb885955f6c6424df3bd973b0.jpg'),
(27783, 1882, 'Deadwood S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108581.mp4', 'http://timg.bdta.pro/images/34a346a7857109fdb27bec4a999da8d2.jpg'),
(27784, 1882, 'Deadwood S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108582.mp4', 'http://timg.bdta.pro/images/c5d07009f9cd825001c6a24ff55e76cd.jpg'),
(27785, 1882, 'Deadwood S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108583.mp4', 'http://timg.bdta.pro/images/42afb1c193f4ef96bba6ca6da6473d72.jpg'),
(27786, 1882, 'Deadwood S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108584.mp4', 'http://timg.bdta.pro/images/c753eb6c072bb02ff007e7496602c4cf.jpg'),
(27787, 1882, 'Deadwood S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108585.mp4', 'http://timg.bdta.pro/images/13d7002e0f1777ba83cee5497033a584.jpg'),
(27788, 1882, 'Deadwood S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108586.mp4', 'http://timg.bdta.pro/images/00de17f4f9b8b0e38179a3871ce2d51e.jpg'),
(27789, 1882, 'Deadwood S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108587.mp4', 'http://timg.bdta.pro/images/44a2e9212b0c6fccf2139b7b78afb9d6.jpg'),
(27790, 1883, 'Deadwood S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108588.mp4', 'http://timg.bdta.pro/images/6f0d8165b9bf7f9e9423f7baa8de3d4f.jpg'),
(27791, 1883, 'Deadwood S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108589.mp4', 'http://timg.bdta.pro/images/c30a6332a3657fdeb73e9a0096247066.jpg'),
(27792, 1883, 'Deadwood S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108590.mp4', 'http://timg.bdta.pro/images/823b9eb6b38fd47502f9e7f96ffe9870.jpg'),
(27793, 1883, 'Deadwood S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108591.mp4', 'http://timg.bdta.pro/images/a75fba316e9b26b3d84fcd46dccd4962.jpg'),
(27794, 1883, 'Deadwood S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108592.mp4', 'http://timg.bdta.pro/images/b2b8db74fb21d1e8d461752ed7132dc8.jpg'),
(27795, 1883, 'Deadwood S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108593.mp4', 'http://timg.bdta.pro/images/6c85b78efe02916e56ef6d7d85312744.jpg'),
(27796, 1883, 'Deadwood S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108594.mp4', 'http://timg.bdta.pro/images/f8f0ab2e42fbabdd7f7f1570d5ff142a.jpg'),
(27797, 1883, 'Deadwood S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108595.mp4', 'http://timg.bdta.pro/images/d62cbf1c9793c4efbbacff05cbf66a6b.jpg'),
(27798, 1883, 'Deadwood S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108596.mp4', 'http://timg.bdta.pro/images/9db1ba54637750b1c667c6fc8faaadfe.jpg'),
(27799, 1883, 'Deadwood S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108597.mp4', 'http://timg.bdta.pro/images/cada148c3ced7f6859d0c2aae8dc5166.jpg'),
(27800, 1883, 'Deadwood S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108598.mp4', 'http://timg.bdta.pro/images/f287973556bf80812a73bcb4041ef6e9.jpg'),
(27801, 1883, 'Deadwood S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108599.mp4', 'http://timg.bdta.pro/images/5db208239a0ab1340e16186ffe83f555.jpg'),
(27802, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109772.mp4', 'http://timg.bdta.pro/images/e43e751ed845ba1d8dd9e2c2da5062e0.jpg'),
(27803, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109773.mp4', 'http://timg.bdta.pro/images/60b11c11c8d9f4e2b4d281edd4c17bd0.jpg'),
(27804, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109774.mp4', 'http://timg.bdta.pro/images/33f98f2a52928c7c7c1023be7f01b22b.jpg'),
(27805, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109775.mp4', 'http://timg.bdta.pro/images/6900a120892829175feb73d9941dd5f5.jpg'),
(27806, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109776.mp4', 'http://timg.bdta.pro/images/90b1228f1540e3097da8668d4774feb2.jpg'),
(27807, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109777.mp4', 'http://timg.bdta.pro/images/df25b98470f0a31b8802c5ad7a779262.jpg'),
(27808, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109778.mp4', 'http://timg.bdta.pro/images/61894a95192569e5845116228e72eef2.jpg'),
(27809, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109779.mp4', 'http://timg.bdta.pro/images/f6f15b2018975c97740e03c0f40628c2.jpg'),
(27810, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109780.mp4', 'http://timg.bdta.pro/images/86ba64e4f2f73cdebd24a81d4578d199.jpg'),
(27811, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109781.mp4', 'http://timg.bdta.pro/images/48066e604c0fbcd614e3e93c298df0f1.jpg'),
(27812, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109782.mp4', 'http://timg.bdta.pro/images/bff3a0230fc69303eebce8a796394c5f.jpg'),
(27813, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109783.mp4', 'http://timg.bdta.pro/images/4a71b973d2b8d40ac5d8406843dbcfa5.jpg'),
(27814, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109784.mp4', 'http://timg.bdta.pro/images/842245ec56913753f268396ea4d93909.jpg'),
(27815, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109785.mp4', 'http://timg.bdta.pro/images/bccd0a35220aee658158ce256bd16c8f.jpg'),
(27816, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109786.mp4', 'http://timg.bdta.pro/images/43e14dcdd691c1c3cd2032e60edaf543.jpg'),
(27817, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109787.mp4', 'http://timg.bdta.pro/images/f266efcf28badba30a83b752913bddbd.jpg'),
(27818, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/109788.mp4', 'http://timg.bdta.pro/images/335a61738a5a1b42816f389eeae2d8bb.jpg'),
(27819, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/109789.mp4', 'http://timg.bdta.pro/images/b60ca7e744d59e8820190ebf123d7490.jpg'),
(27820, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/109790.mp4', 'http://timg.bdta.pro/images/d58d9e602beb536e09b7d17cdebf1e32.jpg'),
(27821, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/109791.mp4', 'http://timg.bdta.pro/images/40a06de9b26a3e339b042c6f137f78dc.jpg'),
(27822, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/109792.mp4', 'http://timg.bdta.pro/images/8d90c7789ddf3894dbf1814b73bbf993.jpg'),
(27823, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/109793.mp4', 'http://timg.bdta.pro/images/21f09bcf47eff7345c7032da5d97122d.jpg'),
(27824, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/109794.mp4', 'http://timg.bdta.pro/images/4c67cb55ca14c6b31330dc4fcf976814.jpg'),
(27825, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/109795.mp4', 'http://timg.bdta.pro/images/8f404853a961baf256b297650d50c6e0.jpg'),
(27826, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/109796.mp4', 'http://timg.bdta.pro/images/4ced19aa5fe35610ed03726378174fad.jpg'),
(27827, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/109797.mp4', 'http://timg.bdta.pro/images/241157b0f8e9ed77789937b3c174efaa.jpg'),
(27828, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/109798.mp4', 'http://timg.bdta.pro/images/e2310790f98b37ef1d3d95b0f586acf4.jpg'),
(27829, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/109799.mp4', 'http://timg.bdta.pro/images/17157f80b649d367dbbd6d12e688dc5a.jpg'),
(27830, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/109800.mp4', 'http://timg.bdta.pro/images/ae27f95f29dd3a1c649f7aec2716d75d.jpg'),
(27831, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/109801.mp4', 'http://timg.bdta.pro/images/fc860838717834ac43ab90ebb8ff3afd.jpg'),
(27832, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/109802.mp4', 'http://timg.bdta.pro/images/6f70bbcd6fcaf56438840df3f48af27a.jpg'),
(27833, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/109803.mp4', 'http://timg.bdta.pro/images/a2c6f7be998eb653675ab6660dde2790.jpg'),
(27834, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/109804.mp4', 'http://timg.bdta.pro/images/6f633904084a2ba5a88721b11d6136bf.jpg'),
(27835, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/109805.mp4', 'http://timg.bdta.pro/images/2fd0671496acca690bbd0e02f063caba.jpg'),
(27836, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/109806.mp4', 'http://timg.bdta.pro/images/4e84bf41a34e61154be99e1f7296ff0e.jpg'),
(27837, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/109807.mp4', 'http://timg.bdta.pro/images/28eee7ce7f2359a96aec9a29259b8c9c.jpg'),
(27838, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/109808.mp4', 'http://timg.bdta.pro/images/f83fa30facbf462e0b33033a436d555e.jpg'),
(27839, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/109809.mp4', 'http://timg.bdta.pro/images/92442519ef4ddc15918b8bd29d18bcc3.jpg'),
(27840, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/109810.mp4', 'http://timg.bdta.pro/images/cb1ed1edad69819e4eb30e91374c4831.jpg'),
(27841, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/109811.mp4', 'http://timg.bdta.pro/images/dd16c61deb1be5a90eb9e9181e63e5a2.jpg'),
(27842, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/109812.mp4', 'http://timg.bdta.pro/images/f8d3e88bde4bfa0cbb24444d2f1973c7.jpg'),
(27843, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/109813.mp4', 'http://timg.bdta.pro/images/c270ee2dbc8135490e9ec782831516c9.jpg'),
(27844, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/109814.mp4', 'http://timg.bdta.pro/images/17315e63d0c0cc309291def401e5dd5d.jpg'),
(27845, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/109815.mp4', 'http://timg.bdta.pro/images/1dd787781a011596d7f79e89e2afc523.jpg'),
(27846, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/109816.mp4', 'http://timg.bdta.pro/images/e7b26c3884aea62efecc3e10e4cfc911.jpg'),
(27847, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/109817.mp4', 'http://timg.bdta.pro/images/e34992c8dcacecff4bcb1754822a1b54.jpg'),
(27848, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/109818.mp4', 'http://timg.bdta.pro/images/d9ff4a55b776e35a29f3671946e18b3a.jpg'),
(27849, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/109819.mp4', 'http://timg.bdta.pro/images/e2f06baca110472655b70a05f52c0974.jpg'),
(27850, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/109820.mp4', 'http://timg.bdta.pro/images/6049b45fa474a06bd07a97b42f28fcdf.jpg'),
(27851, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/109821.mp4', 'http://timg.bdta.pro/images/d4fc306e745fbc33586a96914314fb4b.jpg'),
(27852, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/109822.mp4', 'http://timg.bdta.pro/images/3d28c8c02012af55b7cb446d6d113470.jpg'),
(27853, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/109823.mp4', 'http://timg.bdta.pro/images/2cc9865bdb4a64a9fd596cd0a56060a5.jpg'),
(27854, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/109824.mp4', 'http://timg.bdta.pro/images/5cb60bfb31291fe578f60964321be02c.jpg'),
(27855, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/109825.mp4', 'http://timg.bdta.pro/images/625e4bf9b2419df2d7ee42c2aba901bf.jpg'),
(27856, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/109826.mp4', 'http://timg.bdta.pro/images/8d488e833bb327f55afc9057368bd0b6.jpg'),
(27857, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/109827.mp4', 'http://timg.bdta.pro/images/fadd63f0506056c372f5f02e3bf58e6c.jpg'),
(27858, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/109828.mp4', 'http://timg.bdta.pro/images/08ca81364c40319e53d8c8e291d57c53.jpg'),
(27859, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/109829.mp4', 'http://timg.bdta.pro/images/8dd98727dfd2de202eabd0858600ca89.jpg'),
(27860, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/109830.mp4', 'http://timg.bdta.pro/images/3998c694fce24ee842371fc75731439d.jpg'),
(27861, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/109831.mp4', 'http://timg.bdta.pro/images/41f358f18ed536db88e665fb23ec0994.jpg'),
(27862, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/109832.mp4', 'http://timg.bdta.pro/images/d9507e49a45526fc2038e1bcc33aeebc.jpg'),
(27863, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/109833.mp4', 'http://timg.bdta.pro/images/42266e2a8275597fd8ccafc02a5bc60c.jpg'),
(27864, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/109834.mp4', 'http://timg.bdta.pro/images/d8c8aba388eaf57bdd03c92987dcff5c.jpg'),
(27865, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/109835.mp4', 'http://timg.bdta.pro/images/64a779323e96db6be19351b1f5f5aa6e.jpg'),
(27866, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/109836.mp4', 'http://timg.bdta.pro/images/bece4747893123065182367569d61b13.jpg'),
(27867, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/109837.mp4', 'http://timg.bdta.pro/images/11f0f110d620bb6efcde1c3b5aa72717.jpg'),
(27868, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/109838.mp4', 'http://timg.bdta.pro/images/363a5a7240bceea741dd74754b849002.jpg'),
(27869, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/109839.mp4', 'http://timg.bdta.pro/images/dcd73bb6d5fbfbaa4320bb742ade10ef.jpg'),
(27870, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/109840.mp4', 'http://timg.bdta.pro/images/dd65714daccfaeba14594c2ddcfcff00.jpg'),
(27871, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/109841.mp4', 'http://timg.bdta.pro/images/898870c625ebfe06159bd51538c5750c.jpg'),
(27872, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/109842.mp4', 'http://timg.bdta.pro/images/9c3e6bd3840ffefb9d96a9a789e34966.jpg'),
(27873, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/109843.mp4', 'http://timg.bdta.pro/images/9e4469ef1bd0bc22d29cc67ef4e84b01.jpg'),
(27874, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/109844.mp4', 'http://timg.bdta.pro/images/b33ed1b7d11a4c73952b4771feb25d72.jpg'),
(27875, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/109845.mp4', 'http://timg.bdta.pro/images/d4cfc363e0f7855c02676460a9ffdea6.jpg'),
(27876, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/109846.mp4', 'http://timg.bdta.pro/images/fc070d141f81371d5d636d67262c4493.jpg'),
(27877, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/109847.mp4', 'http://timg.bdta.pro/images/49fb259fdcc4de2bdb2fc08bb8464926.jpg'),
(27878, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/109848.mp4', 'http://timg.bdta.pro/images/b235db8700325b00289ff1d1cd264d33.jpg'),
(27879, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/109849.mp4', 'http://timg.bdta.pro/images/265a3f6dcbfb609ec5e289adc16a426a.jpg'),
(27880, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/109850.mp4', 'http://timg.bdta.pro/images/26096a3939c51faf09ed484bfc217141.jpg'),
(27881, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/109851.mp4', 'http://timg.bdta.pro/images/051bd3525560bef1f574bb6627cb26f6.jpg'),
(27882, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/109852.mp4', 'http://timg.bdta.pro/images/db705fb84fa24dfa649783e9116f651d.jpg'),
(27883, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/109853.mp4', 'http://timg.bdta.pro/images/ecfc806f853b8e0396672078e8c95e22.jpg'),
(27884, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/109854.mp4', 'http://timg.bdta.pro/images/60687ee65b9505a58575cdeac204fbd0.jpg'),
(27885, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/109855.mp4', 'http://timg.bdta.pro/images/1637361c5253804a58a115f8cd0eec43.jpg'),
(27886, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/109856.mp4', 'http://timg.bdta.pro/images/6e01f2af481092d320e7c92d1859ab75.jpg'),
(27887, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/109857.mp4', 'http://timg.bdta.pro/images/e27b227fea7c3caf0fcfdec6281e7d8d.jpg'),
(27888, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/109858.mp4', 'http://timg.bdta.pro/images/e2eaad655d6102f04d8ce10d55d4cac5.jpg'),
(27889, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/109859.mp4', 'http://timg.bdta.pro/images/0fee19eefd34b5b54fa8898c86414d51.jpg'),
(27890, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/109860.mp4', 'http://timg.bdta.pro/images/c19cca0eef442bcfc00624e96f12168b.jpg'),
(27891, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/109861.mp4', 'http://timg.bdta.pro/images/cc599dcc2f5892da198d0ee7cd34993b.jpg'),
(27892, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/109862.mp4', 'http://timg.bdta.pro/images/770d6b468248bbc554bab1a4262db623.jpg'),
(27893, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/109863.mp4', 'http://timg.bdta.pro/images/16bab7c3f467e043a7c471c623f4f724.jpg'),
(27894, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/109864.mp4', 'http://timg.bdta.pro/images/f3891655fcfef765ea326b1e1b5dcd20.jpg'),
(27895, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/109865.mp4', 'http://timg.bdta.pro/images/c5e1d936ac762b7b8e0532b01c64fa69.jpg'),
(27896, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/109866.mp4', 'http://timg.bdta.pro/images/1c68d445cc1eb019645e0115b0201a9b.jpg'),
(27897, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/109867.mp4', 'http://timg.bdta.pro/images/4fef09ac1e2c1cc458eb05c5d07c3fc0.jpg'),
(27898, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/109868.mp4', 'http://timg.bdta.pro/images/66264d26db28e3198e3c458e9ad96881.jpg'),
(27899, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/109869.mp4', 'http://timg.bdta.pro/images/dfff3929298f80e9f55d04952780f6f4.jpg'),
(27900, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/109870.mp4', 'http://timg.bdta.pro/images/cc9508b810fbd15af70dc2c51a273137.jpg'),
(27901, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/109871.mp4', 'http://timg.bdta.pro/images/1c82f8d591754e698035acbecb8f45c1.jpg'),
(27902, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/109872.mp4', 'http://timg.bdta.pro/images/8bec08175d598cd8ba253ee0ea513746.jpg'),
(27903, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/109873.mp4', 'http://timg.bdta.pro/images/95c40cc2ba20fe2d3b68b0953fb04528.jpg'),
(27904, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/109874.mp4', 'http://timg.bdta.pro/images/3a3a89b11fea92fac45a534f276f63ba.jpg'),
(27905, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/109875.mp4', 'http://timg.bdta.pro/images/5ccd3a1809f56a882ed2cb2ade12e4f0.jpg'),
(27906, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/109876.mp4', 'http://timg.bdta.pro/images/5361384ac0fc640cb892319a0a3a89b3.jpg'),
(27907, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/109877.mp4', 'http://timg.bdta.pro/images/5be690aa38e37e826d265cd287162a19.jpg'),
(27908, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/109878.mp4', 'http://timg.bdta.pro/images/e7a6a6ab959c2fa6f9b7b876599287fd.jpg'),
(27909, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/109879.mp4', 'http://timg.bdta.pro/images/5f1d541fbf8f26363a6324b3710d5318.jpg'),
(27910, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/109880.mp4', 'http://timg.bdta.pro/images/67cf91401bd470d21a1a80ce517ad9eb.jpg'),
(27911, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/109881.mp4', 'http://timg.bdta.pro/images/2b6a5179ea0882a33473b86151b06cc5.jpg'),
(27912, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/109882.mp4', 'http://timg.bdta.pro/images/3fb5db56f6fcaecb84b98a82cadee65f.jpg'),
(27913, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/109883.mp4', 'http://timg.bdta.pro/images/c29c7a7b1e3e4af21325d4cc03c09d76.jpg'),
(27914, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/109884.mp4', 'http://timg.bdta.pro/images/070120a33da2c905b6f471cee257ec20.jpg'),
(27915, 1884, 'Os Cavaleiros do Zodíaco - Saga do Santuário S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/109885.mp4', 'http://timg.bdta.pro/images/276ceda380a55e1808584a3620faf2d7.jpg'),
(27916, 1885, 'Luther S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109894.mp4', 'http://timg.bdta.pro/images/0bc005e82cf98bf5715c835df4cabe1b.jpg'),
(27917, 1885, 'Luther S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109895.mp4', 'http://timg.bdta.pro/images/e9cf500d9ad1972d594ceb1c80326d1e.jpg'),
(27918, 1885, 'Luther S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109896.mp4', 'http://timg.bdta.pro/images/d5bd6424b325f88f9382c05c0e7039eb.jpg'),
(27919, 1885, 'Luther S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109897.mp4', 'http://timg.bdta.pro/images/0b1f4f0241d10430d11c1e544b68c5dd.jpg'),
(27920, 1885, 'Luther S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109898.mp4', 'http://timg.bdta.pro/images/c4a09713ce74c01c333d18024e77afea.jpg'),
(27921, 1885, 'Luther S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109899.mp4', 'http://timg.bdta.pro/images/085ebcd4fee3b6be7fc114a74df460f1.jpg'),
(27922, 1886, 'Luther S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109900.mp4', 'http://timg.bdta.pro/images/e6afa771a8e5b65b8a32756f8f553219.jpg'),
(27923, 1886, 'Luther S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109901.mp4', 'http://timg.bdta.pro/images/501d7aedde230ac9e4a9967cd72f2a44.jpg'),
(27924, 1886, 'Luther S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109902.mp4', 'http://timg.bdta.pro/images/16dda445ee880bbf94549f8012cb2c61.jpg'),
(27925, 1886, 'Luther S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109903.mp4', 'http://timg.bdta.pro/images/9544079e77be03beb625774f7a58ed2f.jpg'),
(27926, 1887, 'Luther S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109904.mp4', 'http://timg.bdta.pro/images/caf58b90668f8887e3c3bf2c8218f484.jpg'),
(27927, 1887, 'Luther S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109905.mp4', 'http://timg.bdta.pro/images/287161bdce4dc54732f38ea8ae4f7841.jpg'),
(27928, 1887, 'Luther S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109906.mp4', 'http://timg.bdta.pro/images/b4dbcf384face0cb49889bac595807f1.jpg'),
(27929, 1887, 'Luther S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109907.mp4', 'http://timg.bdta.pro/images/3b604fc1fb769d4c334ebfe17d1a9e66.jpg'),
(27930, 1888, 'Luther S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109908.mp4', 'http://timg.bdta.pro/images/948323cfffc1df453fd38087a3ca9b30.jpg'),
(27931, 1888, 'Luther S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109909.mp4', 'http://timg.bdta.pro/images/c21ef895f579fc05832f9b5b7c0fded7.jpg'),
(27932, 1889, 'Luther S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109910.mp4', 'http://timg.bdta.pro/images/f43b435ee2700b673ebddc8638bf5f02.jpg'),
(27933, 1889, 'Luther S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109911.mp4', 'http://timg.bdta.pro/images/ed499a0af51d3dc3c37afbb8f0c594b9.jpg'),
(27934, 1889, 'Luther S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109912.mp4', 'http://timg.bdta.pro/images/edb35002024cd99790a3c3ee3783cbe8.jpg'),
(27935, 1889, 'Luther S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109913.mp4', 'http://timg.bdta.pro/images/a6612e3291e6c58324ff0ba72328c328.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(27936, 1890, 'BoJack Horseman S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108698.mp4', 'http://timg.bdta.pro/images/f730029c8346a13b552c0d6bec6a8eb8.jpg'),
(27937, 1890, 'BoJack Horseman S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108699.mp4', 'http://timg.bdta.pro/images/35d66423b8a8d5cded419cf4248c650f.jpg'),
(27938, 1890, 'BoJack Horseman S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108700.mp4', 'http://timg.bdta.pro/images/49c6cf80c93268d25b5ec8226fe3ffd1.jpg'),
(27939, 1890, 'BoJack Horseman S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108701.mp4', 'http://timg.bdta.pro/images/717830cacb156e22dfc035cc51e6ac97.jpg'),
(27940, 1890, 'BoJack Horseman S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108702.mp4', 'http://timg.bdta.pro/images/e2c9aaea781dc1d386ceeda753fc1a97.jpg'),
(27941, 1890, 'BoJack Horseman S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108703.mp4', 'http://timg.bdta.pro/images/4cb01821990707f1c6c7bade0c1d882e.jpg'),
(27942, 1890, 'BoJack Horseman S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108704.mp4', 'http://timg.bdta.pro/images/6c02cbf398dfd0061ab7c91fbb2b9018.jpg'),
(27943, 1890, 'BoJack Horseman S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108705.mp4', 'http://timg.bdta.pro/images/1b7076d2187001628c6a8cf4c2a1f2ee.jpg'),
(27944, 1890, 'BoJack Horseman S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108706.mp4', 'http://timg.bdta.pro/images/1b81fed682b7d5cd0727a37281d775a8.jpg'),
(27945, 1890, 'BoJack Horseman S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108707.mp4', 'http://timg.bdta.pro/images/b4803c5c9d41a5b332c4f947c479a0e1.jpg'),
(27946, 1890, 'BoJack Horseman S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108708.mp4', 'http://timg.bdta.pro/images/02fe4a4f1bde5b0a50580450e59e965f.jpg'),
(27947, 1890, 'BoJack Horseman S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108709.mp4', 'http://timg.bdta.pro/images/0cfc948a24d8033d24666f3b012d1f15.jpg'),
(27948, 1891, 'BoJack Horseman S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108710.mp4', 'http://timg.bdta.pro/images/6f7804856267a093d37e61aace1e82fc.jpg'),
(27949, 1891, 'BoJack Horseman S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108711.mp4', 'http://timg.bdta.pro/images/3841e91a84e8255a5ba1322750794386.jpg'),
(27950, 1891, 'BoJack Horseman S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108712.mp4', 'http://timg.bdta.pro/images/8b23b49da620697b22bc725629f71273.jpg'),
(27951, 1891, 'BoJack Horseman S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108713.mp4', 'http://timg.bdta.pro/images/11cb39643a8ef321562ef0ea470b82d9.jpg'),
(27952, 1891, 'BoJack Horseman S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108714.mp4', 'http://timg.bdta.pro/images/050ccc2ca0b2a86c4631f2fae419263d.jpg'),
(27953, 1891, 'BoJack Horseman S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108715.mp4', 'http://timg.bdta.pro/images/ed038ffe0457b234f66ff95adc46e8f0.jpg'),
(27954, 1891, 'BoJack Horseman S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108716.mp4', 'http://timg.bdta.pro/images/69297ffb8e066543e35e3fa2c7c36e16.jpg'),
(27955, 1891, 'BoJack Horseman S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108717.mp4', 'http://timg.bdta.pro/images/c897d82f87ca4c6b9bb01e3091f56eb5.jpg'),
(27956, 1891, 'BoJack Horseman S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108718.mp4', 'http://timg.bdta.pro/images/432a892809352bbcf50181c738ce74a8.jpg'),
(27957, 1891, 'BoJack Horseman S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108719.mp4', 'http://timg.bdta.pro/images/e2637ed00fe894337fc736eeca64a9fc.jpg'),
(27958, 1891, 'BoJack Horseman S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108720.mp4', 'http://timg.bdta.pro/images/fd660bd47da0e1a13ef7b2216a7282b1.jpg'),
(27959, 1891, 'BoJack Horseman S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108721.mp4', 'http://timg.bdta.pro/images/fd643e59390e3770b112f2b00f6dcd70.jpg'),
(27960, 1892, 'BoJack Horseman S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108722.mp4', 'http://timg.bdta.pro/images/4909d50a5f18a23b4d6f8ceb95757db5.jpg'),
(27961, 1892, 'BoJack Horseman S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108723.mp4', 'http://timg.bdta.pro/images/c02ecd7dbd6f69be878b500d86257f94.jpg'),
(27962, 1892, 'BoJack Horseman S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108724.mp4', 'http://timg.bdta.pro/images/926f9810e0cb74e885ee032a70b1eb08.jpg'),
(27963, 1892, 'BoJack Horseman S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108725.mp4', 'http://timg.bdta.pro/images/f670677a06fdda80aae1107fd7af2a90.jpg'),
(27964, 1892, 'BoJack Horseman S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108726.mp4', 'http://timg.bdta.pro/images/12872808955d4d4f3a6783403906af78.jpg'),
(27965, 1892, 'BoJack Horseman S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108727.mp4', 'http://timg.bdta.pro/images/184b5ed079e9814bffa2d03b864dd868.jpg'),
(27966, 1892, 'BoJack Horseman S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108728.mp4', 'http://timg.bdta.pro/images/941626a5a1185b60a2c8226956896e66.jpg'),
(27967, 1892, 'BoJack Horseman S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108729.mp4', 'http://timg.bdta.pro/images/3ae1a5dad9b555230a6bd31d43d32288.jpg'),
(27968, 1892, 'BoJack Horseman S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108730.mp4', 'http://timg.bdta.pro/images/94c80be2e1a8211bf710561187e07381.jpg'),
(27969, 1892, 'BoJack Horseman S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108731.mp4', 'http://timg.bdta.pro/images/94497ee555cf1eeefc0df2aa64b14971.jpg'),
(27970, 1892, 'BoJack Horseman S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108732.mp4', 'http://timg.bdta.pro/images/ee426a4365d50ddec6f208b50f38af3b.jpg'),
(27971, 1892, 'BoJack Horseman S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108733.mp4', 'http://timg.bdta.pro/images/7421645743db6d3e8526a8694b7a7738.jpg'),
(27972, 1893, 'BoJack Horseman S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108734.mp4', 'http://timg.bdta.pro/images/133064db2910af2beb20e3e1254bbc53.jpg'),
(27973, 1893, 'BoJack Horseman S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108735.mp4', 'http://timg.bdta.pro/images/a038d3c0bfebbf599e7f6d899972aa48.jpg'),
(27974, 1893, 'BoJack Horseman S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108736.mp4', 'http://timg.bdta.pro/images/fa16d36e46a5763e56fc65daccad4ad9.jpg'),
(27975, 1893, 'BoJack Horseman S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108737.mp4', 'http://timg.bdta.pro/images/a4f45ccac047eb760ce8b8db53707b57.jpg'),
(27976, 1893, 'BoJack Horseman S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108738.mp4', 'http://timg.bdta.pro/images/20506c5d844a6c27c3eb9ccbe5f303bd.jpg'),
(27977, 1893, 'BoJack Horseman S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108739.mp4', 'http://timg.bdta.pro/images/842839abd6b398100de69947ba944621.jpg'),
(27978, 1893, 'BoJack Horseman S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108740.mp4', 'http://timg.bdta.pro/images/d2f4d767e0720ec587cbdd6ccbd26316.jpg'),
(27979, 1893, 'BoJack Horseman S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108741.mp4', 'http://timg.bdta.pro/images/e16d6a42d37e9c16a8fc122c05997b10.jpg'),
(27980, 1893, 'BoJack Horseman S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108742.mp4', 'http://timg.bdta.pro/images/1edfb6298d5f43c15bbefdf90184452a.jpg'),
(27981, 1893, 'BoJack Horseman S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108743.mp4', 'http://timg.bdta.pro/images/b077f3cbeaf32df2a006b2b1d230ce9a.jpg'),
(27982, 1893, 'BoJack Horseman S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108744.mp4', 'http://timg.bdta.pro/images/15d9c27d465087d8b6a4c378507d4da3.jpg'),
(27983, 1893, 'BoJack Horseman S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108745.mp4', 'http://timg.bdta.pro/images/bc366e873ce229a3902c0f819d5441e0.jpg'),
(27984, 1894, 'BoJack Horseman S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108746.mp4', 'http://timg.bdta.pro/images/a9fd6fd7f8ca3b5c903c4fe405ed8130.jpg'),
(27985, 1894, 'BoJack Horseman S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108747.mp4', 'http://timg.bdta.pro/images/dfada76ea49a182b8f0819b3a5b22bae.jpg'),
(27986, 1894, 'BoJack Horseman S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108748.mp4', 'http://timg.bdta.pro/images/324d0e1d15c95ff6b8f3c6b36cc19ff0.jpg'),
(27987, 1894, 'BoJack Horseman S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108749.mp4', 'http://timg.bdta.pro/images/4910985523fdf9aed3feba9faa3bc7f6.jpg'),
(27988, 1894, 'BoJack Horseman S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108750.mp4', 'http://timg.bdta.pro/images/c0296814937e2419ead96c266e7dcd49.jpg'),
(27989, 1894, 'BoJack Horseman S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108751.mp4', 'http://timg.bdta.pro/images/3c46d7f57f535e071dac931f69ccdb79.jpg'),
(27990, 1894, 'BoJack Horseman S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108752.mp4', 'http://timg.bdta.pro/images/9bf9c8a916233f36fcbd3e82fa57e013.jpg'),
(27991, 1894, 'BoJack Horseman S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108753.mp4', 'http://timg.bdta.pro/images/c8f27c39e195694cac1b60485fc63dbb.jpg'),
(27992, 1894, 'BoJack Horseman S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108754.mp4', 'http://timg.bdta.pro/images/0e73af47fd271b407e5a54685cb99b1d.jpg'),
(27993, 1894, 'BoJack Horseman S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108755.mp4', 'http://timg.bdta.pro/images/10d250c12c127025f2c2c34dce77e137.jpg'),
(27994, 1894, 'BoJack Horseman S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108756.mp4', 'http://timg.bdta.pro/images/c13ebb4249e61cf57185166ca9926a89.jpg'),
(27995, 1894, 'BoJack Horseman S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108757.mp4', 'http://timg.bdta.pro/images/e5ea53af391886aee9992a6cc7ff48ea.jpg'),
(27996, 1895, 'BoJack Horseman S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108758.mp4', 'http://timg.bdta.pro/images/383f4e081847bd580a72e3124a391009.jpg'),
(27997, 1895, 'BoJack Horseman S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108759.mp4', 'http://timg.bdta.pro/images/fb660efdea7209dc77610af7b789fc78.jpg'),
(27998, 1895, 'BoJack Horseman S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108760.mp4', 'http://timg.bdta.pro/images/94c7c13a16f7f6fbd98c5281cd9c4c4c.jpg'),
(27999, 1895, 'BoJack Horseman S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108761.mp4', 'http://timg.bdta.pro/images/a4fca1e4b3cf57af48cb3bfbc5c5a79c.jpg'),
(28000, 1895, 'BoJack Horseman S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108762.mp4', 'http://timg.bdta.pro/images/a3f037d3d4b06df2ba6d7fa1f0e7b665.jpg'),
(28001, 1895, 'BoJack Horseman S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108763.mp4', 'http://timg.bdta.pro/images/64f1d4a94d9cee611e2ce5ab42c650b8.jpg'),
(28002, 1895, 'BoJack Horseman S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108764.mp4', 'http://timg.bdta.pro/images/fc7fe3648fe3fc2f6df3c09c188bc8fa.jpg'),
(28003, 1895, 'BoJack Horseman S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108765.mp4', 'http://timg.bdta.pro/images/d6d4bb41d00ce76624f36e84252d665a.jpg'),
(28004, 1895, 'BoJack Horseman S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108766.mp4', 'http://timg.bdta.pro/images/8419648ff85ddd4cff06c69cd7751a9f.jpg'),
(28005, 1895, 'BoJack Horseman S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108767.mp4', 'http://timg.bdta.pro/images/871d58050055b5dda244f745fd7594b4.jpg'),
(28006, 1895, 'BoJack Horseman S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108768.mp4', 'http://timg.bdta.pro/images/5c4c8dd2747b029dbd9f9af10ea7f355.jpg'),
(28007, 1895, 'BoJack Horseman S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108769.mp4', 'http://timg.bdta.pro/images/e4d817cc8bf939367fdb017694bec1ca.jpg'),
(28008, 1895, 'BoJack Horseman S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108770.mp4', 'http://timg.bdta.pro/images/9a7b744b00c5c7163b81c4da839703a7.jpg'),
(28009, 1895, 'BoJack Horseman S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108771.mp4', 'http://timg.bdta.pro/images/6d0461ebbb3300ee36044d65a7106250.jpg'),
(28010, 1895, 'BoJack Horseman S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108772.mp4', 'http://timg.bdta.pro/images/fe284940225ff6eaeecc99adbf06aafa.jpg'),
(28011, 1895, 'BoJack Horseman S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108773.mp4', 'http://timg.bdta.pro/images/21456b7e32b63480d36560a2d38eeda5.jpg'),
(28012, 1896, 'Classe Mortal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109919.mp4', 'http://timg.bdta.pro/images/a12d12ff74dad40a47685e8efde0a4b6.jpg'),
(28013, 1896, 'Classe Mortal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109920.mp4', 'http://timg.bdta.pro/images/716e27b4f7f5eaaf0ac321caa5ce3436.jpg'),
(28014, 1896, 'Classe Mortal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109921.mp4', 'http://timg.bdta.pro/images/c3c48762846582ba747824fe077c478f.jpg'),
(28015, 1896, 'Classe Mortal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109922.mp4', 'http://timg.bdta.pro/images/6f39c8c4960dfd68b5b036678b3cc8ef.jpg'),
(28016, 1896, 'Classe Mortal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109923.mp4', 'http://timg.bdta.pro/images/326dc1c067a1ab455d49b6dab53d6537.jpg'),
(28017, 1896, 'Classe Mortal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109924.mp4', 'http://timg.bdta.pro/images/870bca375ac2308fe52f0ee6859058d9.jpg'),
(28018, 1896, 'Classe Mortal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109925.mp4', 'http://timg.bdta.pro/images/7fe865fda6d2f8fe3b3a6ab3e4081348.jpg'),
(28019, 1896, 'Classe Mortal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109926.mp4', 'http://timg.bdta.pro/images/820be6f8edaf6050a10461362c9e071d.jpg'),
(28020, 1896, 'Classe Mortal S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109927.mp4', 'http://timg.bdta.pro/images/1918052347bf77348e85a1fe04b54629.jpg'),
(28021, 1896, 'Classe Mortal S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109928.mp4', 'http://timg.bdta.pro/images/bdef63dbcc8e4f503b4a6a01a4db59f8.jpg'),
(28022, 1897, 'Não Fale com Estranhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109886.mp4', 'http://timg.bdta.pro/images/c10da6d0fc98f291d6bae5b675644a03.jpg'),
(28023, 1897, 'Não Fale com Estranhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109887.mp4', 'http://timg.bdta.pro/images/733fe60f69abaef3f85faff41684159e.jpg'),
(28024, 1897, 'Não Fale com Estranhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109888.mp4', 'http://timg.bdta.pro/images/b82ba0a1af411446308045bee5261fe2.jpg'),
(28025, 1897, 'Não Fale com Estranhos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109889.mp4', 'http://timg.bdta.pro/images/8bf8e3e8b51a1c6f6bf52ff0e39d1c38.jpg'),
(28026, 1897, 'Não Fale com Estranhos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109890.mp4', 'http://timg.bdta.pro/images/b255234daaa962e3e87877398887d0c5.jpg'),
(28027, 1897, 'Não Fale com Estranhos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109891.mp4', 'http://timg.bdta.pro/images/dd907c9a0877703f25bb9e22ae1755cf.jpg'),
(28028, 1897, 'Não Fale com Estranhos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109892.mp4', 'http://timg.bdta.pro/images/4bb2529ff3f0662dff56da09b1a9238b.jpg'),
(28029, 1897, 'Não Fale com Estranhos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109893.mp4', 'http://timg.bdta.pro/images/ebaa213f7b01387e593797972f21967c.jpg'),
(28030, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191257.mp4', 'http://timg.bdta.pro/images/dd0abaefe8a5ebe876963dc9e6093736.jpg'),
(28031, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191258.mp4', 'http://timg.bdta.pro/images/76814945fba9165197a33c0a10df8d48.jpg'),
(28032, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191259.mp4', 'http://timg.bdta.pro/images/e4424f0679073f4506466b6db0e40ad0.jpg'),
(28033, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191260.mp4', 'http://timg.bdta.pro/images/c2f4d2b053e52f58208cc6bd2d7448f7.jpg'),
(28034, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191261.mp4', 'http://timg.bdta.pro/images/813c20e9d7ecc6c406d508351135c72b.jpg'),
(28035, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191262.mp4', 'http://timg.bdta.pro/images/d5b056181993c8edd6ed502efd5afcef.jpg'),
(28036, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191263.mp4', 'http://timg.bdta.pro/images/1ae5f285ad678df3132fa842da2434b2.jpg'),
(28037, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191264.mp4', 'http://timg.bdta.pro/images/04fb2bfdf1b058bb9236d8902438e6a4.jpg'),
(28038, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191265.mp4', 'http://timg.bdta.pro/images/9a111d8095fe8e31f1eecbdad6edacf4.jpg'),
(28039, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191266.mp4', 'http://timg.bdta.pro/images/8aa9dd2aa2fd6d65188a3f6311a1bb6c.jpg'),
(28040, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191267.mp4', 'http://timg.bdta.pro/images/a2bf89ca16251b100281e507d97e8d78.jpg'),
(28041, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/191268.mp4', 'http://timg.bdta.pro/images/07273fe8c75af2003933130c1f059dc3.jpg'),
(28042, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/191269.mp4', 'http://timg.bdta.pro/images/67abef221d09d31636a3e5762795bb3d.jpg'),
(28043, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/191270.mp4', 'http://timg.bdta.pro/images/ccf86f07c3e50c1e1c0772cc3ee95def.jpg'),
(28044, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/191271.mp4', 'http://timg.bdta.pro/images/675662e845900113943ec23a767dd463.jpg'),
(28045, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/191272.mp4', 'http://timg.bdta.pro/images/73421f394401a8419eed35b4d7b970f1.jpg'),
(28046, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/191273.mp4', 'http://timg.bdta.pro/images/d61f76b106127895fade60333f0d20c5.jpg'),
(28047, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/191274.mp4', 'http://timg.bdta.pro/images/2136f70c7861163417a396e9ebdc1a79.jpg'),
(28048, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/191275.mp4', 'http://timg.bdta.pro/images/0fd7a3d11c8df6490bab9c911b14498d.jpg'),
(28049, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/191276.mp4', 'http://timg.bdta.pro/images/1d55b2839f54ee1eba824c7ace9bd0fc.jpg'),
(28050, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/191277.mp4', 'http://timg.bdta.pro/images/3ca436be58f8e7d392b62a3295670a4e.jpg'),
(28051, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/191278.mp4', 'http://timg.bdta.pro/images/0cf42d1e427995d5ad80d6bfbe3cf800.jpg'),
(28052, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/191279.mp4', 'http://timg.bdta.pro/images/8599063b1637680a47fcb3ed4862cc3f.jpg'),
(28053, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/191280.mp4', 'http://timg.bdta.pro/images/8791078620244a8b1aefc77170003102.jpg'),
(28054, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/191281.mp4', 'http://timg.bdta.pro/images/b23374a93d696ad893eea3a95bf605b5.jpg'),
(28055, 1898, 'Demon Slayer Kimetsu No Yaiba [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/191282.mp4', 'http://timg.bdta.pro/images/53c3f75c1f7f21cf6b4650b8c788c748.jpg'),
(28056, 1899, 'Demon Slayer Kimetsu No Yaiba [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191283.mp4', 'http://timg.bdta.pro/images/c8b52cce6980fa40d2953b8190085a35.jpg'),
(28057, 1899, 'Demon Slayer Kimetsu No Yaiba [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191284.mp4', 'http://timg.bdta.pro/images/fb4d2ac0913a6fbf96324f6363ea561d.jpg'),
(28058, 1899, 'Demon Slayer Kimetsu No Yaiba [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191285.mp4', 'http://timg.bdta.pro/images/aa34a1fd953e9a51075e600e58226eeb.jpg'),
(28059, 1899, 'Demon Slayer Kimetsu No Yaiba [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191286.mp4', 'http://timg.bdta.pro/images/567d6233c8f97e5f1f513b3bf55f54a1.jpg'),
(28060, 1899, 'Demon Slayer Kimetsu No Yaiba [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191287.mp4', 'http://timg.bdta.pro/images/a61793d84912ab15656ae041590d556a.jpg'),
(28061, 1899, 'Demon Slayer Kimetsu No Yaiba [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191288.mp4', 'http://timg.bdta.pro/images/87e077e787d616488b9a19c669f5aeff.jpg'),
(28062, 1899, 'Demon Slayer Kimetsu No Yaiba [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191289.mp4', 'http://timg.bdta.pro/images/a923b612aa10174d80ff9212556865db.jpg'),
(28063, 1900, 'Demon Slayer Kimetsu No Yaiba [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191290.mp4', 'http://timg.bdta.pro/images/914f03cee23da1571b0f7f6e5b792273.jpg'),
(28064, 1900, 'Demon Slayer Kimetsu No Yaiba [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191291.mp4', 'http://timg.bdta.pro/images/31ad45687643e4b660353d4330058f04.jpg'),
(28065, 1900, 'Demon Slayer Kimetsu No Yaiba [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191292.mp4', 'http://timg.bdta.pro/images/31dd65875158ea8197609db1ee639e45.jpg'),
(28066, 1900, 'Demon Slayer Kimetsu No Yaiba [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191293.mp4', 'http://timg.bdta.pro/images/c1c8bd8ed62d665edb350031a2fe7f67.jpg'),
(28067, 1900, 'Demon Slayer Kimetsu No Yaiba [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191294.mp4', 'http://timg.bdta.pro/images/6a0d5ca9b685f97945603235f27d9109.jpg'),
(28068, 1900, 'Demon Slayer Kimetsu No Yaiba [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191295.mp4', 'http://timg.bdta.pro/images/f102725831556fbc0762a8897d32aa55.jpg'),
(28069, 1900, 'Demon Slayer Kimetsu No Yaiba [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191296.mp4', 'http://timg.bdta.pro/images/f92ce9022c5f22dd302ff2441802b5a3.jpg'),
(28070, 1900, 'Demon Slayer Kimetsu No Yaiba [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191297.mp4', 'http://timg.bdta.pro/images/75d5b5183d50fac4c6ebd6bebead6e1f.jpg'),
(28071, 1900, 'Demon Slayer Kimetsu No Yaiba [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191298.mp4', 'http://timg.bdta.pro/images/188525a27bfe6c82576dcca79d85d280.jpg'),
(28072, 1900, 'Demon Slayer Kimetsu No Yaiba [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191299.mp4', 'http://timg.bdta.pro/images/34c22399140af1e66876c15aecb1e9e3.jpg'),
(28073, 1900, 'Demon Slayer Kimetsu No Yaiba [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191300.mp4', 'http://timg.bdta.pro/images/f97740eea1a0c8d92f2cba8b477a28a2.jpg'),
(28074, 1901, 'Demon Slayer Kimetsu No Yaiba [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/360802.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(28075, 1901, 'Demon Slayer Kimetsu No Yaiba [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/360803.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(28076, 1901, 'Demon Slayer Kimetsu No Yaiba [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/360804.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(28077, 1901, 'Demon Slayer Kimetsu No Yaiba [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/360805.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(28078, 1901, 'Demon Slayer Kimetsu No Yaiba [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/360806.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(28079, 1901, 'Demon Slayer Kimetsu No Yaiba [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/360807.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(28080, 1901, 'Demon Slayer Kimetsu No Yaiba [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/360808.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(28081, 1901, 'Demon Slayer Kimetsu No Yaiba [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/360809.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(28082, 1901, 'Demon Slayer Kimetsu No Yaiba [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/360810.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(28083, 1901, 'Demon Slayer Kimetsu No Yaiba [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/360811.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(28084, 1901, 'Demon Slayer Kimetsu No Yaiba [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/360812.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(28085, 1902, 'Demon Slayer Kimetsu No Yaiba [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/360813.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(28086, 1902, 'Demon Slayer Kimetsu No Yaiba [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/360814.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(28087, 1902, 'Demon Slayer Kimetsu No Yaiba [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/360815.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(28088, 1902, 'Demon Slayer Kimetsu No Yaiba [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/368288.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(28089, 1902, 'Demon Slayer Kimetsu No Yaiba [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/379856.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(28090, 1902, 'Demon Slayer Kimetsu No Yaiba [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/389582.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(28091, 1902, 'Demon Slayer Kimetsu No Yaiba [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/392667.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(28092, 1902, 'Demon Slayer Kimetsu No Yaiba [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/398588.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(28093, 1903, 'A Bela e a Fera S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109351.mp4', 'http://timg.bdta.pro/images/78ee586ec8d78e30a28a518ebc0aed60.jpg'),
(28094, 1903, 'A Bela e a Fera S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109352.mp4', 'http://timg.bdta.pro/images/672df9ec29c7629a15230f7d615cc092.jpg'),
(28095, 1903, 'A Bela e a Fera S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109353.mp4', 'http://timg.bdta.pro/images/5c8f55541d3ababd824af024fb5ec7cd.jpg'),
(28096, 1903, 'A Bela e a Fera S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109354.mp4', 'http://timg.bdta.pro/images/ed1535295459feb80972ab39716f4914.jpg'),
(28097, 1903, 'A Bela e a Fera S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109355.mp4', 'http://timg.bdta.pro/images/57d52ecfe8389d80f18eb81b28730ce0.jpg'),
(28098, 1903, 'A Bela e a Fera S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109356.mp4', 'http://timg.bdta.pro/images/b14eb23b140936323a4d557c55e73a1d.jpg'),
(28099, 1903, 'A Bela e a Fera S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109357.mp4', 'http://timg.bdta.pro/images/6d02923bb05d61e04663dc697b7280be.jpg'),
(28100, 1903, 'A Bela e a Fera S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109358.mp4', 'http://timg.bdta.pro/images/93fda33e2a85ece15e99ef03bee00ae1.jpg'),
(28101, 1903, 'A Bela e a Fera S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109359.mp4', 'http://timg.bdta.pro/images/5f5764f5c47d93c04080300c5cc54f91.jpg'),
(28102, 1903, 'A Bela e a Fera S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109360.mp4', 'http://timg.bdta.pro/images/a298cce2c69272b6d388c14d93a55a3b.jpg'),
(28103, 1903, 'A Bela e a Fera S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109361.mp4', 'http://timg.bdta.pro/images/2073fdd8731ce06ae7dd96352e414787.jpg'),
(28104, 1903, 'A Bela e a Fera S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109362.mp4', 'http://timg.bdta.pro/images/7f871bd83fa51dce6fa87bac1f44e4da.jpg'),
(28105, 1903, 'A Bela e a Fera S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109363.mp4', 'http://timg.bdta.pro/images/b2123218ad03a77e0b63701ccda34444.jpg'),
(28106, 1903, 'A Bela e a Fera S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109364.mp4', 'http://timg.bdta.pro/images/2a39746013f4fac0eef3e2ed8b89bb05.jpg'),
(28107, 1903, 'A Bela e a Fera S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109365.mp4', 'http://timg.bdta.pro/images/e031cae0ed0550872416c8b9b70844d4.jpg'),
(28108, 1903, 'A Bela e a Fera S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109366.mp4', 'http://timg.bdta.pro/images/b0338406e0e28bdba681490923921d70.jpg'),
(28109, 1903, 'A Bela e a Fera S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/109367.mp4', 'http://timg.bdta.pro/images/17dc55e39655bf183da51a4fafe7b5dd.jpg'),
(28110, 1903, 'A Bela e a Fera S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/109368.mp4', 'http://timg.bdta.pro/images/5e10ae4f0002c19673c25c9acdcc0602.jpg'),
(28111, 1903, 'A Bela e a Fera S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/109369.mp4', 'http://timg.bdta.pro/images/c33cd828ae000c7ab2db31e4d346e5be.jpg'),
(28112, 1903, 'A Bela e a Fera S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/109370.mp4', 'http://timg.bdta.pro/images/7b57a028c50cc07d990015cf441ea499.jpg'),
(28113, 1903, 'A Bela e a Fera S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/109371.mp4', 'http://timg.bdta.pro/images/c9689efa640a60abb6fa6cb5877ddddc.jpg'),
(28114, 1903, 'A Bela e a Fera S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/109372.mp4', 'http://timg.bdta.pro/images/10a6a2188b63e2724ee15a4fa720f255.jpg'),
(28115, 1904, 'A Bela e a Fera S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109373.mp4', 'http://timg.bdta.pro/images/adf666563f456f2604f53da1643a921e.jpg'),
(28116, 1904, 'A Bela e a Fera S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109374.mp4', 'http://timg.bdta.pro/images/0ca27dd67ed492c44cade0dee25a34ce.jpg'),
(28117, 1904, 'A Bela e a Fera S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109375.mp4', 'http://timg.bdta.pro/images/ddedcf39e200d244386ab14e091bf63b.jpg'),
(28118, 1904, 'A Bela e a Fera S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109376.mp4', 'http://timg.bdta.pro/images/1c4dce788936a0068f5d4c68dbed6a9d.jpg'),
(28119, 1904, 'A Bela e a Fera S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109377.mp4', 'http://timg.bdta.pro/images/9c1e5597f57b8839724be6bfff13c424.jpg'),
(28120, 1904, 'A Bela e a Fera S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109378.mp4', 'http://timg.bdta.pro/images/2abe64a38c879cd8c17d3101effb0923.jpg'),
(28121, 1904, 'A Bela e a Fera S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109379.mp4', 'http://timg.bdta.pro/images/94a8855211e8a8e7da3ac039f6ced0c0.jpg'),
(28122, 1904, 'A Bela e a Fera S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109380.mp4', 'http://timg.bdta.pro/images/b0d3aae1a297b5bd17bf05005cf745c2.jpg'),
(28123, 1904, 'A Bela e a Fera S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109381.mp4', 'http://timg.bdta.pro/images/c24a3d50b2d842675ed1432e8540765f.jpg'),
(28124, 1904, 'A Bela e a Fera S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109382.mp4', 'http://timg.bdta.pro/images/fa87c9420b60746e5cd0d06e62b67243.jpg'),
(28125, 1904, 'A Bela e a Fera S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109383.mp4', 'http://timg.bdta.pro/images/207f2633ca87d43978e65431173f88e1.jpg'),
(28126, 1904, 'A Bela e a Fera S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109384.mp4', 'http://timg.bdta.pro/images/f63923033b7362c24f76a6b1d3ee80e9.jpg'),
(28127, 1904, 'A Bela e a Fera S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109385.mp4', 'http://timg.bdta.pro/images/ccaab4c588dcb32e9df1328c4955ca43.jpg'),
(28128, 1904, 'A Bela e a Fera S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109386.mp4', 'http://timg.bdta.pro/images/b8393295db5f13ce6f73ea52cb7ed013.jpg'),
(28129, 1904, 'A Bela e a Fera S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109387.mp4', 'http://timg.bdta.pro/images/141c9594b5d22ce8b31e7cbdda739535.jpg'),
(28130, 1904, 'A Bela e a Fera S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109388.mp4', 'http://timg.bdta.pro/images/81d828095fb2dc80e368d3cd2344884c.jpg'),
(28131, 1904, 'A Bela e a Fera S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/109389.mp4', 'http://timg.bdta.pro/images/4c7c4e8d7d8cacad35131f50e6e1c5e9.jpg'),
(28132, 1904, 'A Bela e a Fera S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/109390.mp4', 'http://timg.bdta.pro/images/cdba2cb3eb44ff660c2b16a8b5813cd0.jpg'),
(28133, 1904, 'A Bela e a Fera S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/109391.mp4', 'http://timg.bdta.pro/images/337c1295dd5f221e53e561c7225a8a33.jpg'),
(28134, 1904, 'A Bela e a Fera S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/109392.mp4', 'http://timg.bdta.pro/images/1632bbbffd4877f21712f21548900686.jpg'),
(28135, 1904, 'A Bela e a Fera S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/109393.mp4', 'http://timg.bdta.pro/images/4dd3348baf927ccc225791554587c249.jpg'),
(28136, 1904, 'A Bela e a Fera S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/109394.mp4', 'http://timg.bdta.pro/images/8a90ca70dc2727bbe7112ea864c41fe4.jpg'),
(28137, 1905, 'A Bela e a Fera S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109395.mp4', 'http://timg.bdta.pro/images/b75a35da486b2f7f0db3b7d41f375501.jpg'),
(28138, 1905, 'A Bela e a Fera S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109396.mp4', 'http://timg.bdta.pro/images/4c5f26f0d7a341df7aad8e77917e3027.jpg'),
(28139, 1905, 'A Bela e a Fera S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109397.mp4', 'http://timg.bdta.pro/images/fc0e46498b97b19fd2534524bc4dd8ae.jpg'),
(28140, 1905, 'A Bela e a Fera S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109398.mp4', 'http://timg.bdta.pro/images/223b5172b5991dbb25821de2dc63e353.jpg'),
(28141, 1905, 'A Bela e a Fera S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109399.mp4', 'http://timg.bdta.pro/images/1d7ec3a8e2e2a6fd794f39c25f68f0e4.jpg'),
(28142, 1905, 'A Bela e a Fera S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109400.mp4', 'http://timg.bdta.pro/images/b568666c90ee587bbd53b0ca86aa86d3.jpg'),
(28143, 1905, 'A Bela e a Fera S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109401.mp4', 'http://timg.bdta.pro/images/7bb231ebf80656e0761d1b8a76ae2f26.jpg'),
(28144, 1905, 'A Bela e a Fera S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109402.mp4', 'http://timg.bdta.pro/images/21e7f8dddc824b96f8ca69bb886057a4.jpg'),
(28145, 1905, 'A Bela e a Fera S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109403.mp4', 'http://timg.bdta.pro/images/60c72281f9dd57ad8c1b15221a5b658d.jpg'),
(28146, 1905, 'A Bela e a Fera S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109404.mp4', 'http://timg.bdta.pro/images/540dd5b552b0946808b07168e6601d22.jpg'),
(28147, 1905, 'A Bela e a Fera S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109405.mp4', 'http://timg.bdta.pro/images/65bc0142a282b83d716d4bb9b10532e8.jpg'),
(28148, 1905, 'A Bela e a Fera S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109406.mp4', 'http://timg.bdta.pro/images/f78915724b3e9999bfa32bd7c3a220d3.jpg'),
(28149, 1905, 'A Bela e a Fera S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109407.mp4', 'http://timg.bdta.pro/images/fee0b7c75e966e227ed3984703fcf5b0.jpg'),
(28150, 1906, 'A Bela e a Fera S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109408.mp4', 'http://timg.bdta.pro/images/ecf4b14b3d086afa80cd93834c63eec7.jpg'),
(28151, 1906, 'A Bela e a Fera S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109409.mp4', 'http://timg.bdta.pro/images/6874a92975a63902bf658990282b9868.jpg'),
(28152, 1906, 'A Bela e a Fera S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109410.mp4', 'http://timg.bdta.pro/images/126d9e505998db566a98ca453cc3569b.jpg'),
(28153, 1906, 'A Bela e a Fera S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109411.mp4', 'http://timg.bdta.pro/images/226b7adacd0596186a94ac39f9600143.jpg'),
(28154, 1906, 'A Bela e a Fera S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109412.mp4', 'http://timg.bdta.pro/images/2d6237f889a80fa9720de93fd5bf2a80.jpg'),
(28155, 1906, 'A Bela e a Fera S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109413.mp4', 'http://timg.bdta.pro/images/f5252f78a6671f885c4bbe4839f63ede.jpg'),
(28156, 1906, 'A Bela e a Fera S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109414.mp4', 'http://timg.bdta.pro/images/6d9844c768da7304105fa2a949534f8b.jpg'),
(28157, 1906, 'A Bela e a Fera S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109415.mp4', 'http://timg.bdta.pro/images/7907e0936d8bf695bcc7c1df3ea8b925.jpg'),
(28158, 1906, 'A Bela e a Fera S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109416.mp4', 'http://timg.bdta.pro/images/3efc77f5df0f2c92ef39fc8c48da7836.jpg'),
(28159, 1906, 'A Bela e a Fera S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109417.mp4', 'http://timg.bdta.pro/images/03cd4cf1d1c9ce23711313df6fdf6f5f.jpg'),
(28160, 1906, 'A Bela e a Fera S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109418.mp4', 'http://timg.bdta.pro/images/4673fe73ff186361f7bd2eb39db22b2e.jpg'),
(28161, 1906, 'A Bela e a Fera S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109419.mp4', 'http://timg.bdta.pro/images/5f3d9f3c6fda20a93dddc9f034eea633.jpg'),
(28162, 1906, 'A Bela e a Fera S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109420.mp4', 'http://timg.bdta.pro/images/c80f2c326099069c01651347095dca8e.jpg'),
(28163, 1907, 'Rocketeer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114956.mp4', 'http://timg.bdta.pro/images/e315af606450b233b223b9bde9e4e631.jpg'),
(28164, 1907, 'Rocketeer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114957.mp4', 'http://gstaticontent.com/images/zkQYWMZTh45X9N6FDaPPPmqZopQ_big.jpg'),
(28165, 1907, 'Rocketeer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114958.mp4', 'http://gstaticontent.com/images/zkQYWMZTh45X9N6FDaPPPmqZopQ_big.jpg'),
(28166, 1907, 'Rocketeer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114959.mp4', 'http://timg.bdta.pro/images/1282980f7dad6cf1696254af4f24dc6e.jpg'),
(28167, 1907, 'Rocketeer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114960.mp4', 'http://timg.bdta.pro/images/7cb16a2eb4c345449c75563acd1e51ca.jpg'),
(28168, 1907, 'Rocketeer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114961.mp4', 'http://gstaticontent.com/images/zkQYWMZTh45X9N6FDaPPPmqZopQ_big.jpg'),
(28169, 1908, 'Insecure S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168794.mp4', 'http://timg.bdta.pro/images/9c004fa4609aff78a7f4b5929c48d037.jpg'),
(28170, 1908, 'Insecure S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168795.mp4', 'http://timg.bdta.pro/images/938242c835fa095a1a5c0f880bed52ec.jpg'),
(28171, 1908, 'Insecure S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168796.mp4', 'http://timg.bdta.pro/images/51f29c8828a1c8e7e5828bd49a1c81d1.jpg'),
(28172, 1908, 'Insecure S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168797.mp4', 'http://timg.bdta.pro/images/93f10a86d03b657e0d97c5017872ec12.jpg'),
(28173, 1908, 'Insecure S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168798.mp4', 'http://timg.bdta.pro/images/79bc1218f5ecec6ed36b83347f5b2791.jpg'),
(28174, 1908, 'Insecure S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168799.mp4', 'http://timg.bdta.pro/images/c05a20f3ff82770e98093e5678caf2ea.jpg'),
(28175, 1908, 'Insecure S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168800.mp4', 'http://timg.bdta.pro/images/1b02a1c099afdb94af8f94a65f3f47d1.jpg'),
(28176, 1908, 'Insecure S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168801.mp4', 'http://timg.bdta.pro/images/636f1947f822d2148a888ce776831aa1.jpg'),
(28177, 1909, 'Insecure S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168802.mp4', 'http://timg.bdta.pro/images/f747801066029f8e6f6b082fdf0cf243.jpg'),
(28178, 1909, 'Insecure S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168803.mp4', 'http://timg.bdta.pro/images/c69de3d251a8207c9e3be45ceb496046.jpg'),
(28179, 1909, 'Insecure S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168804.mp4', 'http://timg.bdta.pro/images/4b0c2d234a7270e34305fd003573dad3.jpg'),
(28180, 1909, 'Insecure S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168805.mp4', 'http://timg.bdta.pro/images/6e53757c5585f79efd46ecd7b6b80dd8.jpg'),
(28181, 1909, 'Insecure S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168806.mp4', 'http://timg.bdta.pro/images/348522a551d06a824c0d087d494ad241.jpg'),
(28182, 1909, 'Insecure S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168807.mp4', 'http://timg.bdta.pro/images/c28f4acb513d6feca713f17a81560499.jpg'),
(28183, 1909, 'Insecure S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168808.mp4', 'http://timg.bdta.pro/images/50d009a2c082917f24960903a7c0bc2e.jpg'),
(28184, 1909, 'Insecure S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168809.mp4', 'http://timg.bdta.pro/images/0406740cca577a4aa63c8b139ac1df3d.jpg'),
(28185, 1910, 'Insecure S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168810.mp4', 'http://timg.bdta.pro/images/b0e8a891d4e5f2048c0358a950d721a9.jpg'),
(28186, 1910, 'Insecure S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168811.mp4', 'http://timg.bdta.pro/images/813416da6033b68cbf4a5e4d8e2d8364.jpg'),
(28187, 1910, 'Insecure S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168812.mp4', 'http://timg.bdta.pro/images/235b2db014fae103f939ca3b40ce3070.jpg'),
(28188, 1910, 'Insecure S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168813.mp4', 'http://timg.bdta.pro/images/1a5eaae90181db05e89e67b63fed3407.jpg'),
(28189, 1910, 'Insecure S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168814.mp4', 'http://timg.bdta.pro/images/5936a2117364ad3644307bd8446dbdf9.jpg'),
(28190, 1910, 'Insecure S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168815.mp4', 'http://timg.bdta.pro/images/ec9fdcf2398e40b3bf65235e6b8ae841.jpg'),
(28191, 1910, 'Insecure S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168816.mp4', 'http://timg.bdta.pro/images/3d80a8180f1f683076b27cba46cfed2e.jpg'),
(28192, 1910, 'Insecure S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168817.mp4', 'http://timg.bdta.pro/images/67668245a09214ba2d2fc6337bbc409d.jpg'),
(28193, 1911, 'Insecure S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5GpIhhHf9gqUC85Np6xA5GQFOht.jpg'),
(28194, 1911, 'Insecure S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ghV9kDh0O2Yv5ur6ZUhdUwg2k2z.jpg'),
(28195, 1911, 'Insecure S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iyzQvoPUVffTCvccWtWWHnlyH6L.jpg'),
(28196, 1911, 'Insecure S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOCtAqiZovNYGWPbszEEDANp9BM.jpg'),
(28197, 1911, 'Insecure S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tQcJhNlmT962kk0fjK5IQHTJsIG.jpg'),
(28198, 1911, 'Insecure S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d2OBAMVuvOQi2464MDH7DtFJrpI.jpg'),
(28199, 1911, 'Insecure S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jatGWtJ1CQR5sk5ZGIjJ5OFcqt4.jpg'),
(28200, 1911, 'Insecure S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lN4Z943lNZ92Lx8XtppbEbzfrEe.jpg'),
(28201, 1911, 'Insecure S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/168826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e0AkMCQ0XqqXTZ8hzL0RXtVzn4V.jpg'),
(28202, 1911, 'Insecure S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/168827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1PF6yFYBW1JHMIMQFJQ9GMWSVdq.jpg'),
(28203, 1912, 'Insecure S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/86C8Zkj8RppTUYWKOE58PByGojX.jpg'),
(28204, 1912, 'Insecure S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/22q1df2A80kbvz0LgCq7ddhNt6c.jpg'),
(28205, 1912, 'Insecure S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kHnaIKMR21CxiJo5dRMuTAyMewL.jpg'),
(28206, 1912, 'Insecure S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gI7b15DSruX6HyRkIQWUoO3A1Zj.jpg'),
(28207, 1912, 'Insecure S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eZBLnOp7ot3ODTS2CctHjpjiUy2.jpg'),
(28208, 1912, 'Insecure S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lN1QNvXswRT0mqzRQZbtPkdoKOC.jpg'),
(28209, 1912, 'Insecure S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/arqOqG6HCoEw01dwD6j5MWz9Os3.jpg'),
(28210, 1912, 'Insecure S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/psDd6FlwsAgvBTbjbSzdLOK0V9T.jpg'),
(28211, 1912, 'Insecure S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/168836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t8z3pWzJeggMQzQnYQNL9otOxbm.jpg'),
(28212, 1912, 'Insecure S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/168837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w466UW7l6KdAtuomZpTBjcmr44f.jpg'),
(28213, 1913, 'Trigger - Gatilho Mental S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109274.mp4', 'http://gstaticontent.com/images/3fn6Jearv8UcJkaguHJ22MOaZUy_big.jpg'),
(28214, 1913, 'Trigger - Gatilho Mental S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109275.mp4', 'http://gstaticontent.com/images/3fn6Jearv8UcJkaguHJ22MOaZUy_big.jpg'),
(28215, 1913, 'Trigger - Gatilho Mental S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109276.mp4', 'http://gstaticontent.com/images/3fn6Jearv8UcJkaguHJ22MOaZUy_big.jpg'),
(28216, 1913, 'Trigger - Gatilho Mental S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109277.mp4', 'http://gstaticontent.com/images/3fn6Jearv8UcJkaguHJ22MOaZUy_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(28217, 1913, 'Trigger - Gatilho Mental S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109278.mp4', 'http://gstaticontent.com/images/3fn6Jearv8UcJkaguHJ22MOaZUy_big.jpg'),
(28218, 1913, 'Trigger - Gatilho Mental S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109279.mp4', 'http://gstaticontent.com/images/3fn6Jearv8UcJkaguHJ22MOaZUy_big.jpg'),
(28219, 1913, 'Trigger - Gatilho Mental S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109280.mp4', 'http://gstaticontent.com/images/3fn6Jearv8UcJkaguHJ22MOaZUy_big.jpg'),
(28220, 1913, 'Trigger - Gatilho Mental S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109281.mp4', 'http://gstaticontent.com/images/3fn6Jearv8UcJkaguHJ22MOaZUy_big.jpg'),
(28221, 1913, 'Trigger - Gatilho Mental S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109282.mp4', 'http://gstaticontent.com/images/3fn6Jearv8UcJkaguHJ22MOaZUy_big.jpg'),
(28222, 1913, 'Trigger - Gatilho Mental S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109283.mp4', 'http://gstaticontent.com/images/3fn6Jearv8UcJkaguHJ22MOaZUy_big.jpg'),
(28223, 1913, 'Trigger - Gatilho Mental S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109284.mp4', 'http://gstaticontent.com/images/3fn6Jearv8UcJkaguHJ22MOaZUy_big.jpg'),
(28224, 1913, 'Trigger - Gatilho Mental S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109285.mp4', 'http://gstaticontent.com/images/3fn6Jearv8UcJkaguHJ22MOaZUy_big.jpg'),
(28225, 1913, 'Trigger - Gatilho Mental S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109286.mp4', 'http://gstaticontent.com/images/3fn6Jearv8UcJkaguHJ22MOaZUy_big.jpg'),
(28226, 1913, 'Trigger - Gatilho Mental S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109287.mp4', 'http://gstaticontent.com/images/3fn6Jearv8UcJkaguHJ22MOaZUy_big.jpg'),
(28227, 1913, 'Trigger - Gatilho Mental S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109288.mp4', 'http://gstaticontent.com/images/3fn6Jearv8UcJkaguHJ22MOaZUy_big.jpg'),
(28228, 1914, 'Sunderland Até Morrer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109334.mp4', 'http://timg.bdta.pro/images/72ad52f386d14bdc5361d4ddb0c2e15e.jpg'),
(28229, 1914, 'Sunderland Até Morrer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109335.mp4', 'http://timg.bdta.pro/images/4fffd72bc7517a80b779f43514e87560.jpg'),
(28230, 1914, 'Sunderland Até Morrer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109336.mp4', 'http://timg.bdta.pro/images/e0eed7e23df7578476ad0f2deadaa91a.jpg'),
(28231, 1914, 'Sunderland Até Morrer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109337.mp4', 'http://timg.bdta.pro/images/d186a0433ff0e4d2ddac229afa555a6c.jpg'),
(28232, 1914, 'Sunderland Até Morrer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109338.mp4', 'http://timg.bdta.pro/images/92fecb9959fb99f2a9a2f4d036925a6f.jpg'),
(28233, 1914, 'Sunderland Até Morrer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109339.mp4', 'http://timg.bdta.pro/images/dea37547442e7a6304dd9494fa1f97ac.jpg'),
(28234, 1914, 'Sunderland Até Morrer S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109340.mp4', 'http://timg.bdta.pro/images/49abe96f91dbcd4a0e0e1e3515f1a610.jpg'),
(28235, 1914, 'Sunderland Até Morrer S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109341.mp4', 'http://timg.bdta.pro/images/9baf57243660db1e1bfef877b7da83ad.jpg'),
(28236, 1915, 'Sunderland Até Morrer S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364054.mp4', 'http://gstaticontent.com/images/xBb1OvJxOTXtjdZDPfkzi5nXkAd_big.jpg'),
(28237, 1915, 'Sunderland Até Morrer S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364055.mp4', 'http://gstaticontent.com/images/xBb1OvJxOTXtjdZDPfkzi5nXkAd_big.jpg'),
(28238, 1915, 'Sunderland Até Morrer S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364056.mp4', 'http://gstaticontent.com/images/xBb1OvJxOTXtjdZDPfkzi5nXkAd_big.jpg'),
(28239, 1915, 'Sunderland Até Morrer S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364057.mp4', 'http://gstaticontent.com/images/xBb1OvJxOTXtjdZDPfkzi5nXkAd_big.jpg'),
(28240, 1915, 'Sunderland Até Morrer S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364058.mp4', 'http://gstaticontent.com/images/xBb1OvJxOTXtjdZDPfkzi5nXkAd_big.jpg'),
(28241, 1915, 'Sunderland Até Morrer S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364059.mp4', 'http://gstaticontent.com/images/xBb1OvJxOTXtjdZDPfkzi5nXkAd_big.jpg'),
(28242, 1916, 'The Following S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109289.mp4', 'http://timg.bdta.pro/images/c1e7139323034c1c7b36223ef33476e2.jpg'),
(28243, 1916, 'The Following S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109290.mp4', 'http://timg.bdta.pro/images/86f10f59ed654a7d962c87cbee0d41ad.jpg'),
(28244, 1916, 'The Following S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109291.mp4', 'http://timg.bdta.pro/images/81f6ed37ab0b71bdc975c5e52a399a84.jpg'),
(28245, 1916, 'The Following S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109292.mp4', 'http://timg.bdta.pro/images/7ab1b315eca10da98af6f0da3290ceff.jpg'),
(28246, 1916, 'The Following S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109293.mp4', 'http://timg.bdta.pro/images/cc650967a2b2246b5769772e945ba696.jpg'),
(28247, 1916, 'The Following S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109294.mp4', 'http://timg.bdta.pro/images/12859a21cec3f985c43e9520e2bbfc86.jpg'),
(28248, 1916, 'The Following S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109295.mp4', 'http://timg.bdta.pro/images/6e4ace3c5c778b8736d4ea7ff49ec5b0.jpg'),
(28249, 1916, 'The Following S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109296.mp4', 'http://timg.bdta.pro/images/ea1bedfabce3ed351e18cee31644162e.jpg'),
(28250, 1916, 'The Following S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109297.mp4', 'http://timg.bdta.pro/images/9e7cc8739ba2de5a0a96ee3019b8fd4c.jpg'),
(28251, 1916, 'The Following S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109298.mp4', 'http://timg.bdta.pro/images/56c9cdcaf622fbaf6382980df1db6e0e.jpg'),
(28252, 1916, 'The Following S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109299.mp4', 'http://timg.bdta.pro/images/7b70a3c17d37b8310d870ff93d44e090.jpg'),
(28253, 1916, 'The Following S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109300.mp4', 'http://timg.bdta.pro/images/da0ef5432c4a416734b5ee7847b1cc1b.jpg'),
(28254, 1916, 'The Following S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109301.mp4', 'http://timg.bdta.pro/images/b9c9879f04a7d369cb73af80574c341c.jpg'),
(28255, 1916, 'The Following S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109302.mp4', 'http://timg.bdta.pro/images/5bf1216d72e0a013f992f92615f455b0.jpg'),
(28256, 1916, 'The Following S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109303.mp4', 'http://timg.bdta.pro/images/b539d6fa317a0b8522ff3dd2fdb02cde.jpg'),
(28257, 1917, 'The Following S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109304.mp4', 'http://timg.bdta.pro/images/7f243aa85eac0ac70d58a593ed2139df.jpg'),
(28258, 1917, 'The Following S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109305.mp4', 'http://timg.bdta.pro/images/6d17ba4b33924779c67139e70f440195.jpg'),
(28259, 1917, 'The Following S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109306.mp4', 'http://timg.bdta.pro/images/4ee288849599c3ffc3e0f1a53244e585.jpg'),
(28260, 1917, 'The Following S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109307.mp4', 'http://timg.bdta.pro/images/2cf21e5aa592b85c1e577c28b7ca3bb6.jpg'),
(28261, 1917, 'The Following S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109309.mp4', 'http://timg.bdta.pro/images/4e9408daa3057e26f69dbb981bc5ee9c.jpg'),
(28262, 1917, 'The Following S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109310.mp4', 'http://timg.bdta.pro/images/3c3cd2d0e8b48706e3c542940f3aa0b1.jpg'),
(28263, 1917, 'The Following S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109311.mp4', 'http://timg.bdta.pro/images/1ee1c9e42812bdf5b376abfca4164b33.jpg'),
(28264, 1917, 'The Following S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109312.mp4', 'http://timg.bdta.pro/images/764d8e1a74c117c865102ada11e47379.jpg'),
(28265, 1917, 'The Following S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109313.mp4', 'http://timg.bdta.pro/images/5b45f9379fd953bbadd1984e6e2ba39c.jpg'),
(28266, 1917, 'The Following S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109314.mp4', 'http://timg.bdta.pro/images/5dcc545df492adc1e2d5eb61ad7c910c.jpg'),
(28267, 1917, 'The Following S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109315.mp4', 'http://timg.bdta.pro/images/37d76f9b63e9e708f87aed2488c2f850.jpg'),
(28268, 1917, 'The Following S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109316.mp4', 'http://timg.bdta.pro/images/739c6ff27eb478a63d8e4471163fcb85.jpg'),
(28269, 1917, 'The Following S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109317.mp4', 'http://timg.bdta.pro/images/88e47232e2425669e2907e0673e0d8da.jpg'),
(28270, 1917, 'The Following S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109318.mp4', 'http://timg.bdta.pro/images/15d1240b2bb36e4e23c36c1311d8b0e8.jpg'),
(28271, 1918, 'The Following S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109319.mp4', 'http://timg.bdta.pro/images/4ef339c19972b6b20a4955f8fb4eac2c.jpg'),
(28272, 1918, 'The Following S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109320.mp4', 'http://timg.bdta.pro/images/62ccb3013535e5e8179b0d4a09910b3d.jpg'),
(28273, 1918, 'The Following S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109321.mp4', 'http://timg.bdta.pro/images/304d6cced9fee8c65be3be43723d654e.jpg'),
(28274, 1918, 'The Following S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109322.mp4', 'http://timg.bdta.pro/images/997ed1c7b0e952dd6fa6a2fde7b39401.jpg'),
(28275, 1918, 'The Following S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109323.mp4', 'http://timg.bdta.pro/images/111f259887ee79ac39d9d0581ab9181a.jpg'),
(28276, 1918, 'The Following S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109324.mp4', 'http://timg.bdta.pro/images/51e2b9982d33d6696e65fa19f412d657.jpg'),
(28277, 1918, 'The Following S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109325.mp4', 'http://timg.bdta.pro/images/30939c9eea10ccac6b82ff3200c4f9a6.jpg'),
(28278, 1918, 'The Following S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109326.mp4', 'http://timg.bdta.pro/images/9612b07a3c4113b2be069d739fee5fbe.jpg'),
(28279, 1918, 'The Following S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109327.mp4', 'http://timg.bdta.pro/images/e5988e1e16dc9ef408de2b48e34b6e95.jpg'),
(28280, 1918, 'The Following S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109328.mp4', 'http://timg.bdta.pro/images/bb4dc19bd0592207375a6d98ff83b934.jpg'),
(28281, 1918, 'The Following S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109329.mp4', 'http://timg.bdta.pro/images/92a86946ca2d53430f9c3f94c7d2b510.jpg'),
(28282, 1918, 'The Following S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109330.mp4', 'http://timg.bdta.pro/images/bdcdfdddf3b19f43bb77b703d4c5966f.jpg'),
(28283, 1918, 'The Following S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109331.mp4', 'http://timg.bdta.pro/images/d7513264a50acc084959ba305e54ef08.jpg'),
(28284, 1918, 'The Following S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109332.mp4', 'http://timg.bdta.pro/images/e19c787580be44a80eec91bfc3f2f126.jpg'),
(28285, 1918, 'The Following S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109333.mp4', 'http://timg.bdta.pro/images/a0714cd1f3c1448fb4b4a81f8f3eda10.jpg'),
(28286, 1919, 'Greenleaf S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130240.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28287, 1919, 'Greenleaf S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130241.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28288, 1919, 'Greenleaf S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130242.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28289, 1919, 'Greenleaf S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130243.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28290, 1919, 'Greenleaf S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130244.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28291, 1919, 'Greenleaf S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130245.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28292, 1919, 'Greenleaf S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130246.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28293, 1919, 'Greenleaf S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130247.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28294, 1919, 'Greenleaf S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130248.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28295, 1919, 'Greenleaf S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130249.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28296, 1919, 'Greenleaf S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/130250.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28297, 1919, 'Greenleaf S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/130251.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28298, 1919, 'Greenleaf S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/130252.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28299, 1920, 'Greenleaf S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130253.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28300, 1920, 'Greenleaf S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130254.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28301, 1920, 'Greenleaf S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130255.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28302, 1920, 'Greenleaf S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130256.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28303, 1920, 'Greenleaf S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130257.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28304, 1920, 'Greenleaf S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130258.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28305, 1920, 'Greenleaf S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130259.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28306, 1920, 'Greenleaf S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130260.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28307, 1920, 'Greenleaf S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130261.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28308, 1920, 'Greenleaf S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130262.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28309, 1920, 'Greenleaf S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/130263.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28310, 1920, 'Greenleaf S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/130264.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28311, 1920, 'Greenleaf S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/130265.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28312, 1920, 'Greenleaf S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/130266.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28313, 1920, 'Greenleaf S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/130267.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28314, 1920, 'Greenleaf S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/130268.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28315, 1921, 'Greenleaf S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130269.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28316, 1921, 'Greenleaf S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130270.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28317, 1921, 'Greenleaf S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130271.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28318, 1921, 'Greenleaf S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130272.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28319, 1921, 'Greenleaf S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130273.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28320, 1921, 'Greenleaf S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130274.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28321, 1921, 'Greenleaf S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130275.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28322, 1921, 'Greenleaf S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130276.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28323, 1921, 'Greenleaf S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130277.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28324, 1921, 'Greenleaf S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130278.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28325, 1921, 'Greenleaf S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/130279.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28326, 1921, 'Greenleaf S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/130280.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28327, 1921, 'Greenleaf S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/130281.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28328, 1922, 'Greenleaf S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130282.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28329, 1922, 'Greenleaf S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130283.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28330, 1922, 'Greenleaf S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130284.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28331, 1922, 'Greenleaf S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130285.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28332, 1922, 'Greenleaf S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130286.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28333, 1922, 'Greenleaf S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130287.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28334, 1922, 'Greenleaf S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130288.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28335, 1922, 'Greenleaf S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130289.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28336, 1922, 'Greenleaf S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130290.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28337, 1922, 'Greenleaf S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130291.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28338, 1923, 'Greenleaf S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130292.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28339, 1923, 'Greenleaf S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130293.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28340, 1923, 'Greenleaf S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130294.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28341, 1923, 'Greenleaf S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130295.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28342, 1923, 'Greenleaf S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130296.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28343, 1923, 'Greenleaf S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130297.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28344, 1923, 'Greenleaf S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130298.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28345, 1923, 'Greenleaf S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130299.mp4', 'http://gstaticontent.com/images/4ObrV4ctUCWUw29DUadpIsLR4Iz_big.jpg'),
(28346, 1924, 'Fast Layne S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109343.mp4', 'http://timg.bdta.pro/images/dc057280805de38f5f449348c0a2293e.jpg'),
(28347, 1924, 'Fast Layne S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109344.mp4', 'http://timg.bdta.pro/images/1b6c650870fb84f4fe58ce14af2416b6.jpg'),
(28348, 1924, 'Fast Layne S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109345.mp4', 'http://timg.bdta.pro/images/b38e93c18924019faf9201104d6c62da.jpg'),
(28349, 1924, 'Fast Layne S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109346.mp4', 'http://timg.bdta.pro/images/a5cdf10f250d943c10844d96e1a3be03.jpg'),
(28350, 1924, 'Fast Layne S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109347.mp4', 'http://timg.bdta.pro/images/3b41fb6595ec424bba8f924c68a65503.jpg'),
(28351, 1924, 'Fast Layne S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109348.mp4', 'http://timg.bdta.pro/images/cae3182ac7d4dd5a4ad7c84a7ee6e0ee.jpg'),
(28352, 1924, 'Fast Layne S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109349.mp4', 'http://timg.bdta.pro/images/277a0ff14e42736c48523956c0710937.jpg'),
(28353, 1924, 'Fast Layne S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109350.mp4', 'http://timg.bdta.pro/images/a2b9400c47da87b99bbe1f40f48e3cfd.jpg'),
(28354, 1925, 'Power Players S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109342.mp4', 'http://gstaticontent.com/images/nM24X1sYoi1uXKFAhgiSJWhpCzi_big.jpg'),
(28355, 1926, 'Vis a Vis: El Oasis [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/112817.mp4', 'http://timg.bdta.pro/images/b2b071980d5b870ca93a877cb8cd9662.jpg'),
(28356, 1926, 'Vis a Vis: El Oasis [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/112818.mp4', 'http://timg.bdta.pro/images/6981fc2b5ab82bd1a40e20221e7585da.jpg'),
(28357, 1926, 'Vis a Vis: El Oasis [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/112819.mp4', 'http://timg.bdta.pro/images/ece6019a6bbaa35a283bf9d74e2f4415.jpg'),
(28358, 1926, 'Vis a Vis: El Oasis [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/112820.mp4', 'http://gstaticontent.com/images/7EOWkNGxXq2MBZxfV3ZxjRM4vlH_big.jpg'),
(28359, 1926, 'Vis a Vis: El Oasis [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/112821.mp4', 'http://timg.bdta.pro/images/f6532d13e99098246ccab5cc423ae85b.jpg'),
(28360, 1926, 'Vis a Vis: El Oasis [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/112822.mp4', 'http://timg.bdta.pro/images/e6fa15893dde92aecc78e56cdfcebd13.jpg'),
(28361, 1926, 'Vis a Vis: El Oasis [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/112823.mp4', 'http://timg.bdta.pro/images/31490b5dfd576e50ec432d06371b096b.jpg'),
(28362, 1926, 'Vis a Vis: El Oasis [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/112824.mp4', 'http://timg.bdta.pro/images/ba485ef66d240e740b8d5db915894d7a.jpg'),
(28363, 1927, 'Batwoman S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174826.mp4', 'http://timg.bdta.pro/images/17ed67b8091693dfe92e26b80e8d0ea5.jpg'),
(28364, 1927, 'Batwoman S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174827.mp4', 'http://timg.bdta.pro/images/5d61b5ddd3b00b93fcbc13c58c2b665b.jpg'),
(28365, 1927, 'Batwoman S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174828.mp4', 'http://timg.bdta.pro/images/9c9b9f487a77c5af048bc5587544cb50.jpg'),
(28366, 1927, 'Batwoman S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174829.mp4', 'http://timg.bdta.pro/images/3b926e4c7675306728c8fbf1480adbc0.jpg'),
(28367, 1927, 'Batwoman S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174830.mp4', 'http://timg.bdta.pro/images/c40e35de713d06beaa9d9ed40b938a8c.jpg'),
(28368, 1927, 'Batwoman S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174831.mp4', 'http://timg.bdta.pro/images/26e7c3a3829e2653e2d9fe9077a52468.jpg'),
(28369, 1927, 'Batwoman S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174832.mp4', 'http://timg.bdta.pro/images/a533e5f929170724b864c3802ef083ad.jpg'),
(28370, 1927, 'Batwoman S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174833.mp4', 'http://timg.bdta.pro/images/a2187bad92577a98f636661b19881331.jpg'),
(28371, 1927, 'Batwoman S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174834.mp4', 'http://timg.bdta.pro/images/2595ae9f71cb32798a6e0f94e4617dac.jpg'),
(28372, 1927, 'Batwoman S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174835.mp4', 'http://timg.bdta.pro/images/f0ad3f7aebc2a7b54903cd81fc2a9d61.jpg'),
(28373, 1927, 'Batwoman S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/174836.mp4', 'http://timg.bdta.pro/images/377deddb5b6a8b6411fa70bb8127f9e2.jpg'),
(28374, 1927, 'Batwoman S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/174837.mp4', 'http://timg.bdta.pro/images/aef1233bc802506779e5280fbff374e7.jpg'),
(28375, 1927, 'Batwoman S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/174838.mp4', 'http://timg.bdta.pro/images/26a898a9ae698cf4a8e8e54d49ec2c37.jpg'),
(28376, 1927, 'Batwoman S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/174839.mp4', 'http://timg.bdta.pro/images/347cc400d548c340e1de0366331df586.jpg'),
(28377, 1927, 'Batwoman S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/174840.mp4', 'http://timg.bdta.pro/images/5d607fbdcba45c985f741cfb2525df35.jpg'),
(28378, 1927, 'Batwoman S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/174841.mp4', 'http://timg.bdta.pro/images/b3cb57d18c739019a62549d634aa9f9c.jpg'),
(28379, 1927, 'Batwoman S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/174842.mp4', 'http://timg.bdta.pro/images/692688d9c345a6cb6b4f5242b3643e08.jpg'),
(28380, 1927, 'Batwoman S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/174843.mp4', 'http://timg.bdta.pro/images/36da162e0d314e8e48c4c24af07d6342.jpg'),
(28381, 1927, 'Batwoman S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/174844.mp4', 'http://timg.bdta.pro/images/81639cbda419bdb9ab8af94b92b61cd2.jpg'),
(28382, 1927, 'Batwoman S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/174845.mp4', 'http://timg.bdta.pro/images/a1b7d90d4ef61db493ea3382da9f2430.jpg'),
(28383, 1928, 'Batwoman S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174846.mp4', 'http://timg.bdta.pro/images/80e98f05caf15776a700dfef8b4ab98d.jpg'),
(28384, 1928, 'Batwoman S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174847.mp4', 'http://timg.bdta.pro/images/02233c55eb196f605d028338b050aec8.jpg'),
(28385, 1928, 'Batwoman S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174848.mp4', 'http://timg.bdta.pro/images/17b108058b89f626d895b8d66e53507b.jpg'),
(28386, 1928, 'Batwoman S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174849.mp4', 'http://timg.bdta.pro/images/1431ce039e244633af1d9f0fc23f699f.jpg'),
(28387, 1928, 'Batwoman S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174850.mp4', 'http://timg.bdta.pro/images/ed3f3eb6be250097ad8d3ea8dc78aecd.jpg'),
(28388, 1928, 'Batwoman S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174851.mp4', 'http://timg.bdta.pro/images/4115fb3d22c4d5b7e1ccb7c84df00ad9.jpg'),
(28389, 1928, 'Batwoman S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174852.mp4', 'http://timg.bdta.pro/images/657d28515a8dd7d38b028f6edb3008ff.jpg'),
(28390, 1928, 'Batwoman S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174853.mp4', 'http://timg.bdta.pro/images/979e210991508a0a42f55cb98be2cd06.jpg'),
(28391, 1928, 'Batwoman S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174854.mp4', 'http://timg.bdta.pro/images/06afb8a65aabeae2e81f327a2836a013.jpg'),
(28392, 1928, 'Batwoman S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174855.mp4', 'http://timg.bdta.pro/images/aa2926ad9e104775ef43d0095f2deae1.jpg'),
(28393, 1928, 'Batwoman S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/174856.mp4', 'http://timg.bdta.pro/images/11d7de2960f11390635509de75ef2c98.jpg'),
(28394, 1928, 'Batwoman S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/174857.mp4', 'http://timg.bdta.pro/images/bddb01f14e6bf0d9b3a34e921fbfcf12.jpg'),
(28395, 1928, 'Batwoman S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/174858.mp4', 'http://timg.bdta.pro/images/da1dce54897ff52d65605712003c4f05.jpg'),
(28396, 1928, 'Batwoman S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/174859.mp4', 'http://timg.bdta.pro/images/53c9c14c89f49b2db8ac02922e118e64.jpg'),
(28397, 1928, 'Batwoman S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/174860.mp4', 'http://timg.bdta.pro/images/ea76c68841d115aa0dbd1ec0afc59eb6.jpg'),
(28398, 1928, 'Batwoman S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/174861.mp4', 'http://timg.bdta.pro/images/a28bc57f0f1df150e5aecd17449fdcbf.jpg'),
(28399, 1928, 'Batwoman S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/174862.mp4', 'http://timg.bdta.pro/images/9fd01eae010d1fbe374fcfb3299a0ee8.jpg'),
(28400, 1928, 'Batwoman S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/174863.mp4', 'http://timg.bdta.pro/images/8a8c6b5f847f4623ed514bb7aaeae9dd.jpg'),
(28401, 1929, 'Batwoman S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2bnaVaFm3eJppPNSkibEb7nm8dJ.jpg'),
(28402, 1929, 'Batwoman S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLTMcm1rAqFZiJI3s0h49kJOtcH.jpg'),
(28403, 1929, 'Batwoman S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nO4XzfmMmp2sQXc0fo1H32ANoLf.jpg'),
(28404, 1929, 'Batwoman S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3KPpPKDsChjuss6GfwjNmZI0Hra.jpg'),
(28405, 1929, 'Batwoman S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174868.mp4', 'http://image.tmdb.org/t/p/w1280/jiuMxorzudQS0VYNVojPCYoQRbK.jpg'),
(28406, 1929, 'Batwoman S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174869.mp4', 'http://image.tmdb.org/t/p/w1280/rgDqoFsWNZZgBCkOrfxm55UFuqA.jpg'),
(28407, 1929, 'Batwoman S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174870.mp4', 'http://image.tmdb.org/t/p/w1280/lalwxiOrCCbSGI6v4HjdUO20zqx.jpg'),
(28408, 1929, 'Batwoman S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174871.mp4', 'http://timg.bdta.pro/images/9f1046baf2c6e4f017b82b22c3fd2e57.jpg'),
(28409, 1929, 'Batwoman S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174872.mp4', 'http://timg.bdta.pro/images/ff79cca1fcd22e443bdd3555e9410a27.jpg'),
(28410, 1929, 'Batwoman S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174873.mp4', 'http://timg.bdta.pro/images/a959370cea77b4a778d4bacf4551c021.jpg'),
(28411, 1929, 'Batwoman S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/174874.mp4', 'http://timg.bdta.pro/images/513c67398d1af6ae5f23098e1b4ddcef.jpg'),
(28412, 1929, 'Batwoman S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/174875.mp4', 'http://timg.bdta.pro/images/2dd3ccabc6c741de0cc77c8f9fe525e4.jpg'),
(28413, 1930, 'Em Defesa de Jacob S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123772.mp4', 'http://timg.bdta.pro/images/7dca5a5eac8492d2900dff5e1a874524.jpg'),
(28414, 1930, 'Em Defesa de Jacob S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123773.mp4', 'http://timg.bdta.pro/images/9418d43b6f4b5e9dee960b0d7f1bf55f.jpg'),
(28415, 1930, 'Em Defesa de Jacob S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123774.mp4', 'http://timg.bdta.pro/images/4d7f6df656e78a8b38817caf7a829555.jpg'),
(28416, 1930, 'Em Defesa de Jacob S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123775.mp4', 'http://timg.bdta.pro/images/266f4812a7670fc6a1b53811703fd80b.jpg'),
(28417, 1930, 'Em Defesa de Jacob S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123776.mp4', 'http://timg.bdta.pro/images/9d55dc7305fde7aaffa4cddff979d719.jpg'),
(28418, 1930, 'Em Defesa de Jacob S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123777.mp4', 'http://timg.bdta.pro/images/f2fa9196ccc9e7f59a37e878027f2e0b.jpg'),
(28419, 1930, 'Em Defesa de Jacob S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123778.mp4', 'http://timg.bdta.pro/images/3ba9905bfe00f1dfe40792cd54d644f6.jpg'),
(28420, 1930, 'Em Defesa de Jacob S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123779.mp4', 'http://timg.bdta.pro/images/61d97c6e359a90552b8e3f4cd3be86db.jpg'),
(28421, 1931, 'Oi Ninja S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109084.mp4', 'http://timg.bdta.pro/images/f921ee5527baf9a4e1ee4fb7f4a9eebf.jpg'),
(28422, 1931, 'Oi Ninja S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109085.mp4', 'http://timg.bdta.pro/images/80a483d6d75febfb2ea37b794e420974.jpg'),
(28423, 1931, 'Oi Ninja S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109086.mp4', 'http://timg.bdta.pro/images/45a422ccbf5bacd4b3d0cf506e0c33f6.jpg'),
(28424, 1931, 'Oi Ninja S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109087.mp4', 'http://timg.bdta.pro/images/f77c55972a64593809a65dcbd7d9171e.jpg'),
(28425, 1931, 'Oi Ninja S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109088.mp4', 'http://timg.bdta.pro/images/cc43e05cbd9ad0dbe14bb9a2b625d783.jpg'),
(28426, 1931, 'Oi Ninja S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109089.mp4', 'http://timg.bdta.pro/images/81058941fb9d4019966871fa5c25bac2.jpg'),
(28427, 1931, 'Oi Ninja S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109090.mp4', 'http://timg.bdta.pro/images/0c3615b1c67ea6763f6db14e246e6090.jpg'),
(28428, 1931, 'Oi Ninja S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109091.mp4', 'http://timg.bdta.pro/images/d9d6975ae5003e14ac01f76143dd0a5c.jpg'),
(28429, 1931, 'Oi Ninja S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109092.mp4', 'http://timg.bdta.pro/images/c570778e3be5042d893fa1ccb2fd333e.jpg'),
(28430, 1931, 'Oi Ninja S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109093.mp4', 'http://timg.bdta.pro/images/97989b4ddb1bc9355530f8c58c4a2f17.jpg'),
(28431, 1932, 'Oi Ninja S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109094.mp4', 'http://gstaticontent.com/images/cHJT7OPB71EnMry8FM92iyNwpHE_big.jpg'),
(28432, 1932, 'Oi Ninja S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109095.mp4', 'http://gstaticontent.com/images/cHJT7OPB71EnMry8FM92iyNwpHE_big.jpg'),
(28433, 1932, 'Oi Ninja S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109096.mp4', 'http://gstaticontent.com/images/cHJT7OPB71EnMry8FM92iyNwpHE_big.jpg'),
(28434, 1932, 'Oi Ninja S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109097.mp4', 'http://gstaticontent.com/images/cHJT7OPB71EnMry8FM92iyNwpHE_big.jpg'),
(28435, 1932, 'Oi Ninja S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109098.mp4', 'http://gstaticontent.com/images/cHJT7OPB71EnMry8FM92iyNwpHE_big.jpg'),
(28436, 1932, 'Oi Ninja S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109099.mp4', 'http://gstaticontent.com/images/cHJT7OPB71EnMry8FM92iyNwpHE_big.jpg'),
(28437, 1932, 'Oi Ninja S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109100.mp4', 'http://gstaticontent.com/images/cHJT7OPB71EnMry8FM92iyNwpHE_big.jpg'),
(28438, 1932, 'Oi Ninja S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109101.mp4', 'http://gstaticontent.com/images/cHJT7OPB71EnMry8FM92iyNwpHE_big.jpg'),
(28439, 1932, 'Oi Ninja S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109102.mp4', 'http://gstaticontent.com/images/cHJT7OPB71EnMry8FM92iyNwpHE_big.jpg'),
(28440, 1932, 'Oi Ninja S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109103.mp4', 'http://gstaticontent.com/images/cHJT7OPB71EnMry8FM92iyNwpHE_big.jpg'),
(28441, 1933, 'Chef\'s Table S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183759.mp4', 'http://timg.bdta.pro/images/b955749abac4db6a549156a160ee4c3e.jpg'),
(28442, 1933, 'Chef\'s Table S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183760.mp4', 'http://timg.bdta.pro/images/43fc64f85cc68bde2f408c866352a3c8.jpg'),
(28443, 1933, 'Chef\'s Table S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183761.mp4', 'http://timg.bdta.pro/images/6e552c531e27d32a6b3f095a175bd6fd.jpg'),
(28444, 1933, 'Chef\'s Table S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183762.mp4', 'http://timg.bdta.pro/images/41bf58044b42c4e43c21dabffe617977.jpg'),
(28445, 1933, 'Chef\'s Table S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183763.mp4', 'http://timg.bdta.pro/images/879027789c3ab7bfc3c69202d524eda8.jpg'),
(28446, 1933, 'Chef\'s Table S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183764.mp4', 'http://timg.bdta.pro/images/7d831570898b7804db1f0546e9ad90bc.jpg'),
(28447, 1934, 'Chef\'s Table S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183765.mp4', 'http://timg.bdta.pro/images/181b2f3bf08ca4a948827c05b48e7896.jpg'),
(28448, 1934, 'Chef\'s Table S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183766.mp4', 'http://timg.bdta.pro/images/eb28298a4a00d3e0ebc13ee7902c170b.jpg'),
(28449, 1934, 'Chef\'s Table S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183767.mp4', 'http://timg.bdta.pro/images/2ff5a6f8ea3df22d9121553ee02a0dae.jpg'),
(28450, 1934, 'Chef\'s Table S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183768.mp4', 'http://timg.bdta.pro/images/2ff5a6f8ea3df22d9121553ee02a0dae.jpg'),
(28451, 1934, 'Chef\'s Table S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183769.mp4', 'http://timg.bdta.pro/images/9124766581427e862de091c701a345a5.jpg'),
(28452, 1934, 'Chef\'s Table S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183770.mp4', 'http://timg.bdta.pro/images/9124766581427e862de091c701a345a5.jpg'),
(28453, 1935, 'Chef\'s Table S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183771.mp4', 'http://timg.bdta.pro/images/6234f1c74191c45b1d597e2841aad5e9.jpg'),
(28454, 1935, 'Chef\'s Table S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183772.mp4', 'http://timg.bdta.pro/images/4d4ade0c1358a9d0c85aedb0a8fb9bbf.jpg'),
(28455, 1935, 'Chef\'s Table S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183773.mp4', 'http://timg.bdta.pro/images/f556d44118579f00830256dedc5ce1e1.jpg'),
(28456, 1935, 'Chef\'s Table S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183774.mp4', 'http://timg.bdta.pro/images/b4493863671f0dd80f5778280c12e3fc.jpg'),
(28457, 1935, 'Chef\'s Table S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183775.mp4', 'http://timg.bdta.pro/images/82b6e668d4d0ca946857e12bc4a8ebbc.jpg'),
(28458, 1935, 'Chef\'s Table S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183776.mp4', 'http://timg.bdta.pro/images/47ec9a0feb7afe9cb53309004d382e22.jpg'),
(28459, 1936, 'Chef\'s Table S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183777.mp4', 'http://timg.bdta.pro/images/6dd437ce1cfa2d9f5df47d9f2d5dc912.jpg'),
(28460, 1936, 'Chef\'s Table S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183778.mp4', 'http://timg.bdta.pro/images/f74827f8b2ee5823623d3c584a61bfcc.jpg'),
(28461, 1936, 'Chef\'s Table S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183779.mp4', 'http://timg.bdta.pro/images/0a2478d239f9146e2b350f81ec8b0d9a.jpg'),
(28462, 1936, 'Chef\'s Table S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183780.mp4', 'http://timg.bdta.pro/images/f032f237f8571cbfa2e50a26d4c10cf0.jpg'),
(28463, 1937, 'Chef\'s Table S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183781.mp4', 'http://timg.bdta.pro/images/a9fe20b3b53ddbcf0964f58d8e5fff34.jpg'),
(28464, 1937, 'Chef\'s Table S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183782.mp4', 'http://timg.bdta.pro/images/ea3ff6ee5d3a2082046a001a116b2e2e.jpg'),
(28465, 1937, 'Chef\'s Table S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183783.mp4', 'http://timg.bdta.pro/images/1d30e887cc9065afc63b80a2e460e346.jpg'),
(28466, 1937, 'Chef\'s Table S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183784.mp4', 'http://timg.bdta.pro/images/011fe99943fde4f0b7ab03a2270c056d.jpg'),
(28467, 1938, 'Chef\'s Table S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183785.mp4', 'http://timg.bdta.pro/images/250049a64dc1578b5dff65c06a53d1aa.jpg'),
(28468, 1938, 'Chef\'s Table S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183786.mp4', 'http://timg.bdta.pro/images/b721bab5c9015e1665120949e7cd82aa.jpg'),
(28469, 1938, 'Chef\'s Table S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183787.mp4', 'http://timg.bdta.pro/images/049789c3e862eebc8c7cf23303d7bd2e.jpg'),
(28470, 1938, 'Chef\'s Table S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183788.mp4', 'http://timg.bdta.pro/images/1440e0ddfde4e5a7e7879049caba6f8c.jpg'),
(28471, 1939, 'Chef\'s Table S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/523572.mp4', 'http://gstaticontent.com/images/2aTdai1vsWr2NjdYEBDxA2hffXb_big.jpg'),
(28472, 1939, 'Chef\'s Table S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/523573.mp4', 'http://gstaticontent.com/images/2aTdai1vsWr2NjdYEBDxA2hffXb_big.jpg'),
(28473, 1939, 'Chef\'s Table S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/523574.mp4', 'http://gstaticontent.com/images/2aTdai1vsWr2NjdYEBDxA2hffXb_big.jpg'),
(28474, 1939, 'Chef\'s Table S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/523575.mp4', 'http://gstaticontent.com/images/2aTdai1vsWr2NjdYEBDxA2hffXb_big.jpg'),
(28475, 1940, 'Constantine S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109245.mp4', 'http://timg.bdta.pro/images/22cae32bfc274bec03932367c7eba6ae.jpg'),
(28476, 1940, 'Constantine S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109246.mp4', 'http://timg.bdta.pro/images/81d27d80eae9ef06a1a0ca1daa0c661c.jpg'),
(28477, 1940, 'Constantine S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109247.mp4', 'http://timg.bdta.pro/images/6d80417856d193059602ea9b1faeba52.jpg'),
(28478, 1940, 'Constantine S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109248.mp4', 'http://timg.bdta.pro/images/fb61e0f92fcefd38a2671dc2674d85e8.jpg'),
(28479, 1940, 'Constantine S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109249.mp4', 'http://timg.bdta.pro/images/4e479993a4fcd3148aaed9d7ccff6439.jpg'),
(28480, 1940, 'Constantine S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109250.mp4', 'http://timg.bdta.pro/images/aeb85e4b30fda2f96d223698491257a2.jpg'),
(28481, 1940, 'Constantine S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109251.mp4', 'http://timg.bdta.pro/images/fe3329bfbf69b0c4887e46a6629d730e.jpg'),
(28482, 1940, 'Constantine S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109252.mp4', 'http://timg.bdta.pro/images/2152a4e388e4fecd6253021652af5f35.jpg'),
(28483, 1940, 'Constantine S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109253.mp4', 'http://timg.bdta.pro/images/f87736d673334bb9c414028d45b71587.jpg'),
(28484, 1940, 'Constantine S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109254.mp4', 'http://timg.bdta.pro/images/c3794d39fb9da30883b0c351ccd4ac73.jpg'),
(28485, 1940, 'Constantine S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109255.mp4', 'http://timg.bdta.pro/images/0b625c00c4cbabb3b8241b43bcbb356f.jpg'),
(28486, 1940, 'Constantine S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109256.mp4', 'http://timg.bdta.pro/images/e132d909819f064b20b15f402e3a012a.jpg'),
(28487, 1940, 'Constantine S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109257.mp4', 'http://timg.bdta.pro/images/3236e63ab69b3b1e7ff2743d70bfde35.jpg'),
(28488, 1941, 'The Midnight Gospel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109237.mp4', 'http://gstaticontent.com/images/me3kxfiFRkdto6SmDQv0nczjfmP_big.jpg'),
(28489, 1941, 'The Midnight Gospel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109238.mp4', 'http://gstaticontent.com/images/me3kxfiFRkdto6SmDQv0nczjfmP_big.jpg'),
(28490, 1941, 'The Midnight Gospel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109239.mp4', 'http://gstaticontent.com/images/me3kxfiFRkdto6SmDQv0nczjfmP_big.jpg'),
(28491, 1941, 'The Midnight Gospel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109240.mp4', 'http://gstaticontent.com/images/me3kxfiFRkdto6SmDQv0nczjfmP_big.jpg'),
(28492, 1941, 'The Midnight Gospel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109241.mp4', 'http://gstaticontent.com/images/me3kxfiFRkdto6SmDQv0nczjfmP_big.jpg'),
(28493, 1941, 'The Midnight Gospel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109242.mp4', 'http://gstaticontent.com/images/me3kxfiFRkdto6SmDQv0nczjfmP_big.jpg'),
(28494, 1941, 'The Midnight Gospel S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109243.mp4', 'http://gstaticontent.com/images/me3kxfiFRkdto6SmDQv0nczjfmP_big.jpg'),
(28495, 1941, 'The Midnight Gospel S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109244.mp4', 'http://gstaticontent.com/images/me3kxfiFRkdto6SmDQv0nczjfmP_big.jpg'),
(28496, 1942, 'Monk: Um Detetive Diferente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109112.mp4', 'http://timg.bdta.pro/images/859f79ee87d510f1943263b3884bae15.jpg'),
(28497, 1942, 'Monk: Um Detetive Diferente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109113.mp4', 'http://timg.bdta.pro/images/daaddef04b64c14ab5c4da97872f52c8.jpg'),
(28498, 1942, 'Monk: Um Detetive Diferente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109114.mp4', 'http://timg.bdta.pro/images/6cc7804a6ec7ba4575351b4edcb43cb1.jpg'),
(28499, 1942, 'Monk: Um Detetive Diferente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109115.mp4', 'http://timg.bdta.pro/images/fa39b09db1c8321eed71c1bb4309ab34.jpg'),
(28500, 1942, 'Monk: Um Detetive Diferente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109116.mp4', 'http://timg.bdta.pro/images/f6a57c072366771bea41a061d7ac26f3.jpg'),
(28501, 1942, 'Monk: Um Detetive Diferente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109117.mp4', 'http://timg.bdta.pro/images/058a8d37222696fe749695862d7efe7c.jpg'),
(28502, 1942, 'Monk: Um Detetive Diferente S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109118.mp4', 'http://timg.bdta.pro/images/a6d8571034da186b6fb270da728e784c.jpg'),
(28503, 1942, 'Monk: Um Detetive Diferente S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109119.mp4', 'http://timg.bdta.pro/images/d9a35b4a7ef4f7b167aef2e6d5eaa4a4.jpg'),
(28504, 1942, 'Monk: Um Detetive Diferente S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109120.mp4', 'http://timg.bdta.pro/images/cc1879cf1bc9aa298da2a8a5b957b719.jpg'),
(28505, 1942, 'Monk: Um Detetive Diferente S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109121.mp4', 'http://timg.bdta.pro/images/a8171fbceba99de42e4210f6dd9111b8.jpg'),
(28506, 1942, 'Monk: Um Detetive Diferente S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109122.mp4', 'http://timg.bdta.pro/images/7db3502e4a62fc31946e66fcb9b545b3.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(28507, 1942, 'Monk: Um Detetive Diferente S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109123.mp4', 'http://timg.bdta.pro/images/1222d330809d225758bdbc070eb373ed.jpg'),
(28508, 1942, 'Monk: Um Detetive Diferente S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109124.mp4', 'http://timg.bdta.pro/images/246e5985c6358530bd2fac98efee5938.jpg'),
(28509, 1943, 'Monk: Um Detetive Diferente S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109125.mp4', 'http://timg.bdta.pro/images/88bdadd165719744dd3e0a195ed46618.jpg'),
(28510, 1943, 'Monk: Um Detetive Diferente S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109126.mp4', 'http://timg.bdta.pro/images/9b6f315439be3d3b71d919cf3887699c.jpg'),
(28511, 1943, 'Monk: Um Detetive Diferente S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109127.mp4', 'http://timg.bdta.pro/images/c43141d59f765fe3438c4d03ed53f2eb.jpg'),
(28512, 1943, 'Monk: Um Detetive Diferente S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109128.mp4', 'http://timg.bdta.pro/images/4729fea3bf9055c916e905d500ba08df.jpg'),
(28513, 1943, 'Monk: Um Detetive Diferente S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109129.mp4', 'http://timg.bdta.pro/images/36d71e99e8a770c714fda1d677de974c.jpg'),
(28514, 1943, 'Monk: Um Detetive Diferente S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109130.mp4', 'http://timg.bdta.pro/images/30ac5586bb6049439d1302ff3d76a9dc.jpg'),
(28515, 1943, 'Monk: Um Detetive Diferente S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109131.mp4', 'http://timg.bdta.pro/images/4120f89c02b65395d14847aa1452f781.jpg'),
(28516, 1943, 'Monk: Um Detetive Diferente S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109132.mp4', 'http://timg.bdta.pro/images/323bca7ca3034d1757c237fc881c6cb3.jpg'),
(28517, 1943, 'Monk: Um Detetive Diferente S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109133.mp4', 'http://timg.bdta.pro/images/5a2f2f10cc039f4be88f7ac496982eaa.jpg'),
(28518, 1943, 'Monk: Um Detetive Diferente S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109134.mp4', 'http://timg.bdta.pro/images/9dfd7da0feb8c3bb8028f27343f0e1e9.jpg'),
(28519, 1943, 'Monk: Um Detetive Diferente S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109135.mp4', 'http://timg.bdta.pro/images/4f21ecd69d2c1e5d6311f86b5a59feb6.jpg'),
(28520, 1943, 'Monk: Um Detetive Diferente S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109136.mp4', 'http://timg.bdta.pro/images/d656d805684758cf8cf6138f69517459.jpg'),
(28521, 1943, 'Monk: Um Detetive Diferente S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109137.mp4', 'http://timg.bdta.pro/images/4dbc07620ba520174af0bcb927ab626e.jpg'),
(28522, 1943, 'Monk: Um Detetive Diferente S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109138.mp4', 'http://timg.bdta.pro/images/1daf996654ab3cac6b637ba6848b1cc9.jpg'),
(28523, 1943, 'Monk: Um Detetive Diferente S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109139.mp4', 'http://timg.bdta.pro/images/bc5f74c8b1d76caccc2a226befbeaa48.jpg'),
(28524, 1943, 'Monk: Um Detetive Diferente S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109140.mp4', 'http://timg.bdta.pro/images/f54e4dd89f19f13ed3e4da5dd156d7a2.jpg'),
(28525, 1944, 'Monk: Um Detetive Diferente S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109141.mp4', 'http://timg.bdta.pro/images/ab5452eeceae6ada42b84b6c016a5843.jpg'),
(28526, 1944, 'Monk: Um Detetive Diferente S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109142.mp4', 'http://timg.bdta.pro/images/8e885dd3e218ba827425326c03a14c2c.jpg'),
(28527, 1944, 'Monk: Um Detetive Diferente S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109143.mp4', 'http://timg.bdta.pro/images/58ca00ca03b413036d3586d6113ee28c.jpg'),
(28528, 1944, 'Monk: Um Detetive Diferente S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109144.mp4', 'http://timg.bdta.pro/images/47351719b9ae394836912cc2fdb67f76.jpg'),
(28529, 1944, 'Monk: Um Detetive Diferente S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109145.mp4', 'http://timg.bdta.pro/images/44df6a330440474f22d714c8fce9b3ce.jpg'),
(28530, 1944, 'Monk: Um Detetive Diferente S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109146.mp4', 'http://timg.bdta.pro/images/2dcf179513200977c06f17f81c363883.jpg'),
(28531, 1944, 'Monk: Um Detetive Diferente S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109147.mp4', 'http://timg.bdta.pro/images/a24615d8667faadb3d0295c5522c2986.jpg'),
(28532, 1944, 'Monk: Um Detetive Diferente S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109148.mp4', 'http://timg.bdta.pro/images/032a79bdf6eaf6e45a45502e9da3d4cc.jpg'),
(28533, 1944, 'Monk: Um Detetive Diferente S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109149.mp4', 'http://timg.bdta.pro/images/fd136eac7e4472b976168089608c1104.jpg'),
(28534, 1944, 'Monk: Um Detetive Diferente S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109150.mp4', 'http://timg.bdta.pro/images/85b0558be25b40fe1d8846db95b5df8f.jpg'),
(28535, 1944, 'Monk: Um Detetive Diferente S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109151.mp4', 'http://timg.bdta.pro/images/d95bde99451e539aeb64bdb4855c7112.jpg'),
(28536, 1944, 'Monk: Um Detetive Diferente S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109152.mp4', 'http://timg.bdta.pro/images/99437f5a715011a753bc2482f73af5ae.jpg'),
(28537, 1944, 'Monk: Um Detetive Diferente S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109153.mp4', 'http://timg.bdta.pro/images/0ad3812383d6fc8927e42b9465d2755b.jpg'),
(28538, 1944, 'Monk: Um Detetive Diferente S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109154.mp4', 'http://timg.bdta.pro/images/f5729e7defb5bd0d701a516bf673047b.jpg'),
(28539, 1944, 'Monk: Um Detetive Diferente S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109155.mp4', 'http://timg.bdta.pro/images/b96c004b4d8fcfda36ec1800b4520fe2.jpg'),
(28540, 1944, 'Monk: Um Detetive Diferente S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109156.mp4', 'http://timg.bdta.pro/images/79c95c9833f77991c2c074ca8a23a6b6.jpg'),
(28541, 1945, 'Monk: Um Detetive Diferente S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109157.mp4', 'http://timg.bdta.pro/images/6f371a10300bd3f950c15342a8643b87.jpg'),
(28542, 1945, 'Monk: Um Detetive Diferente S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109158.mp4', 'http://timg.bdta.pro/images/c5cd76bd9ed5fd68354729520e143320.jpg'),
(28543, 1945, 'Monk: Um Detetive Diferente S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109159.mp4', 'http://timg.bdta.pro/images/56c65d1c6bbbd3c494c25516527d502c.jpg'),
(28544, 1945, 'Monk: Um Detetive Diferente S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109160.mp4', 'http://timg.bdta.pro/images/2bcc9e287ee4f0fa8b2d11a7c43f67ba.jpg'),
(28545, 1945, 'Monk: Um Detetive Diferente S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109161.mp4', 'http://timg.bdta.pro/images/b6a9c04d531b4aae5e8499a4e6d729c0.jpg'),
(28546, 1945, 'Monk: Um Detetive Diferente S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109162.mp4', 'http://timg.bdta.pro/images/f1165c439b3692db3641209c99e8623c.jpg'),
(28547, 1945, 'Monk: Um Detetive Diferente S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109163.mp4', 'http://timg.bdta.pro/images/e7142e3b6679c91564a7624dd553c664.jpg'),
(28548, 1945, 'Monk: Um Detetive Diferente S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109164.mp4', 'http://timg.bdta.pro/images/8daa90913242d834581d4ac9832baf41.jpg'),
(28549, 1945, 'Monk: Um Detetive Diferente S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109165.mp4', 'http://timg.bdta.pro/images/d5b34983ff8cc3853a172899d53dec9b.jpg'),
(28550, 1945, 'Monk: Um Detetive Diferente S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109166.mp4', 'http://timg.bdta.pro/images/e62cb291c7bf4101547241609532e0da.jpg'),
(28551, 1945, 'Monk: Um Detetive Diferente S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109167.mp4', 'http://timg.bdta.pro/images/423993da93f8048b3fb273edc2f8cec6.jpg'),
(28552, 1945, 'Monk: Um Detetive Diferente S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109168.mp4', 'http://timg.bdta.pro/images/9268a6d66fc1a97cf806c229ec67155a.jpg'),
(28553, 1945, 'Monk: Um Detetive Diferente S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109169.mp4', 'http://timg.bdta.pro/images/7d3c20837347e37195b5aad44cd43147.jpg'),
(28554, 1945, 'Monk: Um Detetive Diferente S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109170.mp4', 'http://timg.bdta.pro/images/2f5f3a1d9bd89b67482bb8fa4340348d.jpg'),
(28555, 1945, 'Monk: Um Detetive Diferente S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109171.mp4', 'http://timg.bdta.pro/images/fbf133a5b396dee805a3d46d55a9ca66.jpg'),
(28556, 1945, 'Monk: Um Detetive Diferente S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109172.mp4', 'http://timg.bdta.pro/images/250d6e4ac16b1005e98c7190ab851bd8.jpg'),
(28557, 1946, 'Monk: Um Detetive Diferente S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109173.mp4', 'http://timg.bdta.pro/images/f8e1878b41f44ef2f04986c509fbeafe.jpg'),
(28558, 1946, 'Monk: Um Detetive Diferente S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109174.mp4', 'http://timg.bdta.pro/images/3f41ece3de6a1825f1339f7c325de149.jpg'),
(28559, 1946, 'Monk: Um Detetive Diferente S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109175.mp4', 'http://timg.bdta.pro/images/b35c0ab9242709365f97d715bce31406.jpg'),
(28560, 1946, 'Monk: Um Detetive Diferente S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109176.mp4', 'http://timg.bdta.pro/images/e885d4d9e4a6eaf1f6e0194b561d31d9.jpg'),
(28561, 1946, 'Monk: Um Detetive Diferente S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109177.mp4', 'http://timg.bdta.pro/images/fee41f2280a6258b2b1c244f1213ddf6.jpg'),
(28562, 1946, 'Monk: Um Detetive Diferente S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109178.mp4', 'http://timg.bdta.pro/images/c2747093705289ac0da0ec672eb92dde.jpg'),
(28563, 1946, 'Monk: Um Detetive Diferente S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109179.mp4', 'http://timg.bdta.pro/images/b4993a48023eccaf8228871bbaf20df5.jpg'),
(28564, 1946, 'Monk: Um Detetive Diferente S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109180.mp4', 'http://timg.bdta.pro/images/774a20fa1e02f666b7e0d00721ee0a9b.jpg'),
(28565, 1946, 'Monk: Um Detetive Diferente S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109181.mp4', 'http://timg.bdta.pro/images/8e53060a8ad1a0affd9cce4c7938e2a3.jpg'),
(28566, 1946, 'Monk: Um Detetive Diferente S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109182.mp4', 'http://timg.bdta.pro/images/3f9f4ee38841898482a00490175a8618.jpg'),
(28567, 1946, 'Monk: Um Detetive Diferente S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109183.mp4', 'http://timg.bdta.pro/images/7784b99c486fdc66ebe764e6f56e9c75.jpg'),
(28568, 1946, 'Monk: Um Detetive Diferente S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109184.mp4', 'http://timg.bdta.pro/images/63abdfeebcf4aa4dda1fbf8c3cf2eb18.jpg'),
(28569, 1946, 'Monk: Um Detetive Diferente S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109185.mp4', 'http://timg.bdta.pro/images/42b4b6d8bbd4b833ac778624117b6486.jpg'),
(28570, 1946, 'Monk: Um Detetive Diferente S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109186.mp4', 'http://timg.bdta.pro/images/dd2542fd6cf64260d12e156c0939d544.jpg'),
(28571, 1946, 'Monk: Um Detetive Diferente S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109187.mp4', 'http://timg.bdta.pro/images/dae1179db3492e4051762375d4f8aea0.jpg'),
(28572, 1946, 'Monk: Um Detetive Diferente S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109188.mp4', 'http://timg.bdta.pro/images/af1f44b3b6fa14c5fff7cc7000bdd0d8.jpg'),
(28573, 1947, 'Monk: Um Detetive Diferente S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109189.mp4', 'http://timg.bdta.pro/images/b0a2a35b497efdd59da466a0301289ae.jpg'),
(28574, 1947, 'Monk: Um Detetive Diferente S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109190.mp4', 'http://timg.bdta.pro/images/654a5a41845125205b7b8bec6e058491.jpg'),
(28575, 1947, 'Monk: Um Detetive Diferente S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109191.mp4', 'http://timg.bdta.pro/images/e1181bff3918c4fb50ac40f5dbdec55f.jpg'),
(28576, 1947, 'Monk: Um Detetive Diferente S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109192.mp4', 'http://timg.bdta.pro/images/a388132563f7a6eb4eaeaabbc8cba6a0.jpg'),
(28577, 1947, 'Monk: Um Detetive Diferente S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109193.mp4', 'http://timg.bdta.pro/images/f7d726baa54fe552d8ffa3b591964e0e.jpg'),
(28578, 1947, 'Monk: Um Detetive Diferente S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109194.mp4', 'http://timg.bdta.pro/images/d4a84d9eb0bbdb3b010e92fbd02039d2.jpg'),
(28579, 1947, 'Monk: Um Detetive Diferente S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109195.mp4', 'http://timg.bdta.pro/images/dbc6976b8e75865098a19be46fdd6e57.jpg'),
(28580, 1947, 'Monk: Um Detetive Diferente S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109196.mp4', 'http://timg.bdta.pro/images/e5eb2deeb2cee03813f36a291b769d73.jpg'),
(28581, 1947, 'Monk: Um Detetive Diferente S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109197.mp4', 'http://timg.bdta.pro/images/57f4c1b7d48b39391ce3398031092843.jpg'),
(28582, 1947, 'Monk: Um Detetive Diferente S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109198.mp4', 'http://timg.bdta.pro/images/eb3cd7fe960c938b040084d725f15796.jpg'),
(28583, 1947, 'Monk: Um Detetive Diferente S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109199.mp4', 'http://timg.bdta.pro/images/0052ae83809e53324f1581333e832ea9.jpg'),
(28584, 1947, 'Monk: Um Detetive Diferente S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109200.mp4', 'http://timg.bdta.pro/images/53a8e3566931e792d0001a6f757d9e4f.jpg'),
(28585, 1947, 'Monk: Um Detetive Diferente S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109201.mp4', 'http://timg.bdta.pro/images/84882971d90487790b3d49db4306b707.jpg'),
(28586, 1947, 'Monk: Um Detetive Diferente S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109202.mp4', 'http://timg.bdta.pro/images/ad5bfde0cb9646dc7f10fdbd5db2a2ef.jpg'),
(28587, 1947, 'Monk: Um Detetive Diferente S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109203.mp4', 'http://timg.bdta.pro/images/e9b2ae7908652f69003a919badb79c79.jpg'),
(28588, 1947, 'Monk: Um Detetive Diferente S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109204.mp4', 'http://timg.bdta.pro/images/e326dd1977ee2e6963a524478e43f7e6.jpg'),
(28589, 1948, 'Monk: Um Detetive Diferente S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109205.mp4', 'http://timg.bdta.pro/images/0aec8941b0130e7b79142cd8cbeface5.jpg'),
(28590, 1948, 'Monk: Um Detetive Diferente S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109206.mp4', 'http://timg.bdta.pro/images/6ff72c8944d5053182922e783e1497f2.jpg'),
(28591, 1948, 'Monk: Um Detetive Diferente S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109207.mp4', 'http://timg.bdta.pro/images/37acac18d5cfb7c5cb814eb997a46ed9.jpg'),
(28592, 1948, 'Monk: Um Detetive Diferente S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109208.mp4', 'http://timg.bdta.pro/images/e2d874a579b526751d09c9ddde7027b5.jpg'),
(28593, 1948, 'Monk: Um Detetive Diferente S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109209.mp4', 'http://timg.bdta.pro/images/dd0b4c0302c493e6042fd8dcac52605d.jpg'),
(28594, 1948, 'Monk: Um Detetive Diferente S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109210.mp4', 'http://timg.bdta.pro/images/eec297dfcd84cd9a1a44537cf4ad8d66.jpg'),
(28595, 1948, 'Monk: Um Detetive Diferente S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109211.mp4', 'http://timg.bdta.pro/images/33eac379d8ec7d534d3bffe39e6c026c.jpg'),
(28596, 1948, 'Monk: Um Detetive Diferente S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109212.mp4', 'http://timg.bdta.pro/images/806c0153d1c6c847cfaff325b5250861.jpg'),
(28597, 1948, 'Monk: Um Detetive Diferente S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109213.mp4', 'http://timg.bdta.pro/images/15f81a5ce4f393904f41de9149d1aa0f.jpg'),
(28598, 1948, 'Monk: Um Detetive Diferente S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109214.mp4', 'http://timg.bdta.pro/images/4e47cc4d84e784060fca97956504496e.jpg'),
(28599, 1948, 'Monk: Um Detetive Diferente S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109215.mp4', 'http://timg.bdta.pro/images/6cfdb2ab1245174b30ac6b4ff851c54c.jpg'),
(28600, 1948, 'Monk: Um Detetive Diferente S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109216.mp4', 'http://timg.bdta.pro/images/b382cd9b7bb54ccae473b8289a22fc07.jpg'),
(28601, 1948, 'Monk: Um Detetive Diferente S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109217.mp4', 'http://timg.bdta.pro/images/544a3bc94a65c313f502cb7c3291b636.jpg'),
(28602, 1948, 'Monk: Um Detetive Diferente S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109218.mp4', 'http://timg.bdta.pro/images/6533a183acead36490a97bb05735a961.jpg'),
(28603, 1948, 'Monk: Um Detetive Diferente S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109219.mp4', 'http://timg.bdta.pro/images/f5c42535e9136a0500c074e45004d19c.jpg'),
(28604, 1948, 'Monk: Um Detetive Diferente S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109220.mp4', 'http://timg.bdta.pro/images/3de6586d309f7ff853289ffadcbf313d.jpg'),
(28605, 1949, 'Monk: Um Detetive Diferente S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109221.mp4', 'http://timg.bdta.pro/images/195a83cae1dba54385fddef1b40e224d.jpg'),
(28606, 1949, 'Monk: Um Detetive Diferente S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109222.mp4', 'http://timg.bdta.pro/images/8388b4d8088980fc2955072fc917b594.jpg'),
(28607, 1949, 'Monk: Um Detetive Diferente S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109223.mp4', 'http://timg.bdta.pro/images/fc7f729852587cbaf306e520d7d1c6aa.jpg'),
(28608, 1949, 'Monk: Um Detetive Diferente S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109224.mp4', 'http://timg.bdta.pro/images/3786df5d54b3c7c6e11c723b1d46f982.jpg'),
(28609, 1949, 'Monk: Um Detetive Diferente S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109225.mp4', 'http://timg.bdta.pro/images/9eae8a17f1a5d454e35b5e79c8f41b1d.jpg'),
(28610, 1949, 'Monk: Um Detetive Diferente S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109226.mp4', 'http://timg.bdta.pro/images/e5e2157fb0bf4b76b38c9a0e4de8fcdc.jpg'),
(28611, 1949, 'Monk: Um Detetive Diferente S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109227.mp4', 'http://timg.bdta.pro/images/98f9618934a5a9e5aa655830e4149605.jpg'),
(28612, 1949, 'Monk: Um Detetive Diferente S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109228.mp4', 'http://timg.bdta.pro/images/f607ed418ec2865153405daef1e7774e.jpg'),
(28613, 1949, 'Monk: Um Detetive Diferente S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109229.mp4', 'http://timg.bdta.pro/images/5d0c338327704445708ba6f0f15af503.jpg'),
(28614, 1949, 'Monk: Um Detetive Diferente S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109230.mp4', 'http://timg.bdta.pro/images/ede390ead3a9aa22de09f93c8f97c702.jpg'),
(28615, 1949, 'Monk: Um Detetive Diferente S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109231.mp4', 'http://timg.bdta.pro/images/6d6fd3bc2aec0b3317d10ee8a10bf849.jpg'),
(28616, 1949, 'Monk: Um Detetive Diferente S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109232.mp4', 'http://timg.bdta.pro/images/1e70caeed634b1aac3fc285e04efee96.jpg'),
(28617, 1949, 'Monk: Um Detetive Diferente S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109233.mp4', 'http://timg.bdta.pro/images/98887c9b8410dd6cab51b0d94259f12f.jpg'),
(28618, 1949, 'Monk: Um Detetive Diferente S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/109234.mp4', 'http://timg.bdta.pro/images/ff3063abeda9345476a6a483ecb4c46e.jpg'),
(28619, 1949, 'Monk: Um Detetive Diferente S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/109235.mp4', 'http://timg.bdta.pro/images/cf7dafdbc53b1bde1bca12d43483fe90.jpg'),
(28620, 1949, 'Monk: Um Detetive Diferente S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/109236.mp4', 'http://timg.bdta.pro/images/ed1355e6e0b5facee16be18bdb0fa698.jpg'),
(28621, 1950, 'Il processo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109076.mp4', 'http://timg.bdta.pro/images/0318d666b0e343a71f0a342bf164017a.jpg'),
(28622, 1950, 'Il processo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109077.mp4', 'http://timg.bdta.pro/images/cbb2ceeabb60bb0d17913071151c43e9.jpg'),
(28623, 1950, 'Il processo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109078.mp4', 'http://timg.bdta.pro/images/1aee2eda590844c78a9d64443334129e.jpg'),
(28624, 1950, 'Il processo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109079.mp4', 'http://timg.bdta.pro/images/13e3378620b903cef13dfb589ffc7c39.jpg'),
(28625, 1950, 'Il processo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109080.mp4', 'http://timg.bdta.pro/images/a37e3211013bb324847fe47359357442.jpg'),
(28626, 1950, 'Il processo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109081.mp4', 'http://timg.bdta.pro/images/2133768b858ab6649674d57503dd80df.jpg'),
(28627, 1950, 'Il processo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109082.mp4', 'http://timg.bdta.pro/images/6306c21c530eefbcad27dbedd85c5fc3.jpg'),
(28628, 1950, 'Il processo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109083.mp4', 'http://timg.bdta.pro/images/578da64460cef0303f933f6bd0e0560d.jpg'),
(28629, 1951, 'Planeta Bizarro [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109064.mp4', 'http://timg.bdta.pro/images/4b050b871a12c24ad4aac0f1b450350c.jpg'),
(28630, 1951, 'Planeta Bizarro [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109065.mp4', 'http://timg.bdta.pro/images/13eda166fe208436cadbe278c556a70f.jpg'),
(28631, 1951, 'Planeta Bizarro [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109066.mp4', 'http://timg.bdta.pro/images/fbce1ca009244d742b9b1362c4f6448a.jpg'),
(28632, 1951, 'Planeta Bizarro [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109067.mp4', 'http://timg.bdta.pro/images/6df36cb64c52b7420903a6df65f5bff5.jpg'),
(28633, 1951, 'Planeta Bizarro [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109068.mp4', 'http://timg.bdta.pro/images/22ae213753115fc9a785738c76b6a1ce.jpg'),
(28634, 1951, 'Planeta Bizarro [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109069.mp4', 'http://timg.bdta.pro/images/0354dce0e2b6fa3004386f06fff649ec.jpg'),
(28635, 1951, 'Planeta Bizarro [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109070.mp4', 'http://timg.bdta.pro/images/7f5d02abc6168106cc6999a8ddbe0c4a.jpg'),
(28636, 1951, 'Planeta Bizarro [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109071.mp4', 'http://timg.bdta.pro/images/78893542f7bf873f258cbdb26d363e2c.jpg'),
(28637, 1951, 'Planeta Bizarro [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109072.mp4', 'http://timg.bdta.pro/images/233e0566658d16dd0fd9cc849337e752.jpg'),
(28638, 1951, 'Planeta Bizarro [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109073.mp4', 'http://timg.bdta.pro/images/92fbeadbe6c411974448d0a216c8fa1a.jpg'),
(28639, 1951, 'Planeta Bizarro [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109074.mp4', 'http://timg.bdta.pro/images/12ebb4dc342e7db88893abe779c30627.jpg'),
(28640, 1951, 'Planeta Bizarro [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109075.mp4', 'http://timg.bdta.pro/images/ddb67c0359a18930f93d8f88eb0a6508.jpg'),
(28641, 1952, 'Harlots S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109040.mp4', 'http://timg.bdta.pro/images/6b5d582bb00cf59ba391ec7422d05555.jpg'),
(28642, 1952, 'Harlots S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109041.mp4', 'http://timg.bdta.pro/images/86f2e9778b620f0ff8308220ede3fa02.jpg'),
(28643, 1952, 'Harlots S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109042.mp4', 'http://timg.bdta.pro/images/87c3166eae757c5dd3812bfd8d61ddea.jpg'),
(28644, 1952, 'Harlots S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109043.mp4', 'http://timg.bdta.pro/images/6a53a1b41bf301327d72f2b71f989513.jpg'),
(28645, 1952, 'Harlots S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109044.mp4', 'http://timg.bdta.pro/images/3740c01f659d91b34768cda12cf413de.jpg'),
(28646, 1952, 'Harlots S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109045.mp4', 'http://timg.bdta.pro/images/7da814b952d45cda91729f9b24ffc2dd.jpg'),
(28647, 1952, 'Harlots S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109046.mp4', 'http://timg.bdta.pro/images/804fa38ca89a9a7fb7e64b2bc2ae04b5.jpg'),
(28648, 1952, 'Harlots S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109047.mp4', 'http://timg.bdta.pro/images/25b5aa235adba94342049122424a276b.jpg'),
(28649, 1953, 'Harlots S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109048.mp4', 'http://timg.bdta.pro/images/7ea4b2f7f904f7a977b21efacdf42656.jpg'),
(28650, 1953, 'Harlots S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109049.mp4', 'http://timg.bdta.pro/images/bbc8d7c93180ca7a4fb7cb972e5f9983.jpg'),
(28651, 1953, 'Harlots S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109050.mp4', 'http://timg.bdta.pro/images/bbc8d7c93180ca7a4fb7cb972e5f9983.jpg'),
(28652, 1953, 'Harlots S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109051.mp4', 'http://timg.bdta.pro/images/bbc8d7c93180ca7a4fb7cb972e5f9983.jpg'),
(28653, 1953, 'Harlots S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109052.mp4', 'http://timg.bdta.pro/images/bbc8d7c93180ca7a4fb7cb972e5f9983.jpg'),
(28654, 1953, 'Harlots S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109053.mp4', 'http://timg.bdta.pro/images/bbc8d7c93180ca7a4fb7cb972e5f9983.jpg'),
(28655, 1953, 'Harlots S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109054.mp4', 'http://timg.bdta.pro/images/bbc8d7c93180ca7a4fb7cb972e5f9983.jpg'),
(28656, 1953, 'Harlots S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109055.mp4', 'http://timg.bdta.pro/images/bbc8d7c93180ca7a4fb7cb972e5f9983.jpg'),
(28657, 1954, 'Harlots S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109056.mp4', 'http://timg.bdta.pro/images/5ac50f12a1acbbf13db7c6fa8712a4ea.jpg'),
(28658, 1954, 'Harlots S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109057.mp4', 'http://timg.bdta.pro/images/75849133d0a6266f439d87d48cb8db77.jpg'),
(28659, 1954, 'Harlots S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109058.mp4', 'http://timg.bdta.pro/images/4b91e7576b68ecd67b82d5beaea70ebd.jpg'),
(28660, 1954, 'Harlots S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109059.mp4', 'http://timg.bdta.pro/images/efda8aed580d6e6c1ae78a7d7afa63b4.jpg'),
(28661, 1954, 'Harlots S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109060.mp4', 'http://timg.bdta.pro/images/19d9b3f0db51923f88c2c4f97904b94f.jpg'),
(28662, 1954, 'Harlots S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109061.mp4', 'http://timg.bdta.pro/images/c32bb86b03f185fa72f8d55b1e6fc986.jpg'),
(28663, 1954, 'Harlots S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109062.mp4', 'http://timg.bdta.pro/images/c32bb86b03f185fa72f8d55b1e6fc986.jpg'),
(28664, 1954, 'Harlots S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109063.mp4', 'http://timg.bdta.pro/images/c32bb86b03f185fa72f8d55b1e6fc986.jpg'),
(28665, 1955, 'Love 101 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161451.mp4', 'http://timg.bdta.pro/images/55461aa5f7ffa9630df14de85bb93063.jpg'),
(28666, 1955, 'Love 101 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161452.mp4', 'http://timg.bdta.pro/images/438b6ee8b9935aadc28961ea4e2c5076.jpg'),
(28667, 1955, 'Love 101 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161453.mp4', 'http://timg.bdta.pro/images/de62bfb9b5e1f4ad447cccd66bb43d95.jpg'),
(28668, 1955, 'Love 101 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161454.mp4', 'http://timg.bdta.pro/images/e88974e2cd6710b74920d8c85f5d101c.jpg'),
(28669, 1955, 'Love 101 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161455.mp4', 'http://timg.bdta.pro/images/1b5a33a7f161358f947ca60729ed71b2.jpg'),
(28670, 1955, 'Love 101 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161456.mp4', 'http://timg.bdta.pro/images/043a4fdcf5ce092c0359b94b164c93d5.jpg'),
(28671, 1955, 'Love 101 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161457.mp4', 'http://timg.bdta.pro/images/60753f768baf8810ffcd2957355ec0e5.jpg'),
(28672, 1955, 'Love 101 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161458.mp4', 'http://timg.bdta.pro/images/342a729b775fffa8fcfd450938a133ea.jpg'),
(28673, 1956, 'Love 101 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mLEljGuWsx4AX8hkrY3GcNvPFdv.jpg'),
(28674, 1956, 'Love 101 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Rm1hjeBvSTxlbU8arOzQzbOLq4.jpg'),
(28675, 1956, 'Love 101 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/onvOnCZlKgX0DBZ21isx96sI1U.jpg'),
(28676, 1956, 'Love 101 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dIVtTxhEgDLvw3BaavRcsMhZ6Lf.jpg'),
(28677, 1956, 'Love 101 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u3Yg4O3IMEGfCDjJvE0hZhf05Mx.jpg'),
(28678, 1956, 'Love 101 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tDXSncEYVZ4fnUM3ojJ08tDRMSL.jpg'),
(28679, 1956, 'Love 101 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/UNr4so8ljt7KftldERVotCFEEj.jpg'),
(28680, 1956, 'Love 101 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gBepzKsrYvvKWYzR6RbUrz9Ep0T.jpg'),
(28681, 1957, 'After Life S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109028.mp4', 'http://timg.bdta.pro/images/73b7f0c8ecbbbc1d930bde7224c90a63.jpg'),
(28682, 1957, 'After Life S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109029.mp4', 'http://timg.bdta.pro/images/369d254e9ab6d1f52cdd2babe3d00b04.jpg'),
(28683, 1957, 'After Life S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109030.mp4', 'http://timg.bdta.pro/images/3583a7d49f42018d9b2ad342f89ed53b.jpg'),
(28684, 1957, 'After Life S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109031.mp4', 'http://timg.bdta.pro/images/bc9b814d5e4035982a6e0965bd7653ca.jpg'),
(28685, 1957, 'After Life S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109032.mp4', 'http://timg.bdta.pro/images/8e191cece08fea83ab81b440baf40725.jpg'),
(28686, 1957, 'After Life S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109033.mp4', 'http://timg.bdta.pro/images/7e0d092100979dd618b5344a3c15f4fc.jpg'),
(28687, 1958, 'After Life S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109034.mp4', 'http://timg.bdta.pro/images/a962c30d6693c95305094a6c0e1c7414.jpg'),
(28688, 1958, 'After Life S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109035.mp4', 'http://timg.bdta.pro/images/77d297d3f02e919473636e23dc66dd8a.jpg'),
(28689, 1958, 'After Life S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109036.mp4', 'http://timg.bdta.pro/images/709360a136f698c9ad0aaa7a42ff0be5.jpg'),
(28690, 1958, 'After Life S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109037.mp4', 'http://timg.bdta.pro/images/709360a136f698c9ad0aaa7a42ff0be5.jpg'),
(28691, 1958, 'After Life S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109038.mp4', 'http://timg.bdta.pro/images/709360a136f698c9ad0aaa7a42ff0be5.jpg'),
(28692, 1958, 'After Life S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109039.mp4', 'http://timg.bdta.pro/images/709360a136f698c9ad0aaa7a42ff0be5.jpg'),
(28693, 1959, 'Upload S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238765.mp4', 'http://timg.bdta.pro/images/1a28f58b841dcf821e0d7cc9a6cae3cb.jpg'),
(28694, 1959, 'Upload S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238766.mp4', 'http://timg.bdta.pro/images/5e509a9db69d9d9b1c59ae29b6cc2b99.jpg'),
(28695, 1959, 'Upload S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238767.mp4', 'http://timg.bdta.pro/images/a7646c08abec10128881355a9b5f921a.jpg'),
(28696, 1959, 'Upload S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238768.mp4', 'http://timg.bdta.pro/images/3d2ac20fa7f535e2b2cf1ade62ee5799.jpg'),
(28697, 1959, 'Upload S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238769.mp4', 'http://timg.bdta.pro/images/5303aee82ffd8e182188821e89166f6a.jpg'),
(28698, 1959, 'Upload S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238770.mp4', 'http://timg.bdta.pro/images/91fadc8a54b712f51acb2270abb0ef35.jpg'),
(28699, 1959, 'Upload S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238771.mp4', 'http://timg.bdta.pro/images/2924051101937be99294e2ebbf852d26.jpg'),
(28700, 1959, 'Upload S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238772.mp4', 'http://timg.bdta.pro/images/3aaf806dd90a7180c84022ac22d5fc99.jpg'),
(28701, 1959, 'Upload S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238773.mp4', 'http://timg.bdta.pro/images/86f4fcf13dc22e0e435c9fe7742addff.jpg'),
(28702, 1959, 'Upload S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238774.mp4', 'http://timg.bdta.pro/images/2a075cf26da0dda15b02804d92fc44c8.jpg'),
(28703, 1960, 'Upload S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238775.mp4', 'http://timg.bdta.pro/images/ff93a7f0cd74c96a175a6afbc4fa35e9.jpg'),
(28704, 1960, 'Upload S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238776.mp4', 'http://timg.bdta.pro/images/5e252f95fe54780f4bdee7b25670e657.jpg'),
(28705, 1960, 'Upload S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238777.mp4', 'http://timg.bdta.pro/images/de2e951462bbf946e9fdd424689400db.jpg'),
(28706, 1960, 'Upload S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238778.mp4', 'http://timg.bdta.pro/images/0f155986e9b8892b72c7bda63b27ce77.jpg'),
(28707, 1960, 'Upload S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238779.mp4', 'http://timg.bdta.pro/images/c1d4b9db625cbdfed2712d3a172e9359.jpg'),
(28708, 1960, 'Upload S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238780.mp4', 'http://timg.bdta.pro/images/368ba73b7a7432b1861ca7849806a253.jpg'),
(28709, 1960, 'Upload S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238781.mp4', 'http://timg.bdta.pro/images/2b5b543150515cad8baf74bac72c7778.jpg'),
(28710, 1961, 'Upload S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238782.mp4', 'http://gstaticontent.com/images/6SIDIB59JYsQ8EfUgM0IaFfwXtS_big.jpg'),
(28711, 1961, 'Upload S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238783.mp4', 'http://gstaticontent.com/images/6SIDIB59JYsQ8EfUgM0IaFfwXtS_big.jpg'),
(28712, 1961, 'Upload S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238784.mp4', 'http://gstaticontent.com/images/6SIDIB59JYsQ8EfUgM0IaFfwXtS_big.jpg'),
(28713, 1961, 'Upload S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238785.mp4', 'http://gstaticontent.com/images/6SIDIB59JYsQ8EfUgM0IaFfwXtS_big.jpg'),
(28714, 1961, 'Upload S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238786.mp4', 'http://gstaticontent.com/images/6SIDIB59JYsQ8EfUgM0IaFfwXtS_big.jpg'),
(28715, 1961, 'Upload S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238787.mp4', 'http://gstaticontent.com/images/6SIDIB59JYsQ8EfUgM0IaFfwXtS_big.jpg'),
(28716, 1961, 'Upload S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238788.mp4', 'http://gstaticontent.com/images/6SIDIB59JYsQ8EfUgM0IaFfwXtS_big.jpg'),
(28717, 1961, 'Upload S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238789.mp4', 'http://gstaticontent.com/images/6SIDIB59JYsQ8EfUgM0IaFfwXtS_big.jpg'),
(28718, 1962, 'Upload S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/881450.mp4', 'http://gstaticontent.com/images/6SIDIB59JYsQ8EfUgM0IaFfwXtS_big.jpg'),
(28719, 1962, 'Upload S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/881451.mp4', 'http://gstaticontent.com/images/6SIDIB59JYsQ8EfUgM0IaFfwXtS_big.jpg'),
(28720, 1962, 'Upload S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/881452.mp4', 'http://gstaticontent.com/images/6SIDIB59JYsQ8EfUgM0IaFfwXtS_big.jpg'),
(28721, 1962, 'Upload S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/881453.mp4', 'http://gstaticontent.com/images/6SIDIB59JYsQ8EfUgM0IaFfwXtS_big.jpg'),
(28722, 1963, 'Hollywood [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109021.mp4', 'http://timg.bdta.pro/images/9beb3a285e0240a8ce25a599dcf5577c.jpg'),
(28723, 1963, 'Hollywood [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109022.mp4', 'http://timg.bdta.pro/images/5934973671e2740cdf7dd9e8adba589e.jpg'),
(28724, 1963, 'Hollywood [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109023.mp4', 'http://timg.bdta.pro/images/c472040c9f9f43e97871cc6091e66ee2.jpg'),
(28725, 1963, 'Hollywood [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109024.mp4', 'http://timg.bdta.pro/images/df0165ddd661bdee9c5275ffea58531b.jpg'),
(28726, 1963, 'Hollywood [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109025.mp4', 'http://timg.bdta.pro/images/72bea2d58648656219e427b8956620c7.jpg'),
(28727, 1963, 'Hollywood [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109026.mp4', 'http://timg.bdta.pro/images/04ccfb07d7c07c6da8b8056a72cc2d45.jpg'),
(28728, 1963, 'Hollywood [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109027.mp4', 'http://timg.bdta.pro/images/45110b17f77d888942daf97d53f5f11f.jpg'),
(28729, 1964, 'Eu Nunca... S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220501.mp4', 'http://timg.bdta.pro/images/1dbdee4d2e22293b493016a817bcaf88.jpg'),
(28730, 1964, 'Eu Nunca... S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220502.mp4', 'http://timg.bdta.pro/images/d6b02ae3f7a981bea4bec23f4390b873.jpg'),
(28731, 1964, 'Eu Nunca... S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220503.mp4', 'http://timg.bdta.pro/images/541de0fca207a08af6714a5973e84eef.jpg'),
(28732, 1964, 'Eu Nunca... S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220504.mp4', 'http://timg.bdta.pro/images/c09decb1851b257682f8b3a320d41d4a.jpg'),
(28733, 1964, 'Eu Nunca... S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220505.mp4', 'http://timg.bdta.pro/images/1fa248bf9dbc39c6f844492cc7f3999f.jpg'),
(28734, 1964, 'Eu Nunca... S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220506.mp4', 'http://timg.bdta.pro/images/45430e71445a09116724ec1fdd3e6f25.jpg'),
(28735, 1964, 'Eu Nunca... S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220507.mp4', 'http://timg.bdta.pro/images/4325da5f10582fbe1842c94c45239443.jpg'),
(28736, 1964, 'Eu Nunca... S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220508.mp4', 'http://timg.bdta.pro/images/9476cda7e3ae5a682e2481e3f0d795fe.jpg'),
(28737, 1964, 'Eu Nunca... S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220509.mp4', 'http://timg.bdta.pro/images/f57403bf9f2165ad08019004675dbea3.jpg'),
(28738, 1964, 'Eu Nunca... S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220510.mp4', 'http://timg.bdta.pro/images/1004c4fe9850aa9e5d71aef04c1dbe5e.jpg'),
(28739, 1965, 'Eu Nunca... S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220511.mp4', 'http://timg.bdta.pro/images/ce03afecd149a7a247ea046e5faaf72f.jpg'),
(28740, 1965, 'Eu Nunca... S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220512.mp4', 'http://timg.bdta.pro/images/dede0aa23c6576eb702ca0805eed155f.jpg'),
(28741, 1965, 'Eu Nunca... S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220513.mp4', 'http://timg.bdta.pro/images/a39dd624f36520dac7c2d7c79845bd35.jpg'),
(28742, 1965, 'Eu Nunca... S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220514.mp4', 'http://timg.bdta.pro/images/d3d2f6bbd911b9f45a3c7c1d18aeaa20.jpg'),
(28743, 1965, 'Eu Nunca... S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220515.mp4', 'http://timg.bdta.pro/images/37c695b88686c8b334313e3bf6eb586c.jpg'),
(28744, 1965, 'Eu Nunca... S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220516.mp4', 'http://timg.bdta.pro/images/a7df31794be38755264550575fcf2753.jpg'),
(28745, 1965, 'Eu Nunca... S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220517.mp4', 'http://timg.bdta.pro/images/fc5170d62f40ddfe5cdd3398d02d0d78.jpg'),
(28746, 1965, 'Eu Nunca... S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220518.mp4', 'http://timg.bdta.pro/images/2dd3277ef81ed6263caf353098ace9d6.jpg'),
(28747, 1965, 'Eu Nunca... S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220519.mp4', 'http://timg.bdta.pro/images/f9fae7ddebea794824f4adf90adac956.jpg'),
(28748, 1965, 'Eu Nunca... S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220520.mp4', 'http://timg.bdta.pro/images/67527a9c9edc3bd1bfe788d808b0252a.jpg'),
(28749, 1966, 'Eu Nunca... S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220521.mp4', 'http://timg.bdta.pro/images/8c6f0364fbc3ac923fa62dd262dd9326.jpg'),
(28750, 1966, 'Eu Nunca... S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220522.mp4', 'http://timg.bdta.pro/images/eaf8ace982a12a9ff9df3ad4a476d1ef.jpg'),
(28751, 1966, 'Eu Nunca... S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220523.mp4', 'http://timg.bdta.pro/images/e6a930f7cbdce1baa43cf3c50c1831d2.jpg'),
(28752, 1966, 'Eu Nunca... S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220524.mp4', 'http://timg.bdta.pro/images/b3825eead424ccc03023398221e6c81b.jpg'),
(28753, 1966, 'Eu Nunca... S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220525.mp4', 'http://timg.bdta.pro/images/516e86f9bb7de16fc72d73cc4484334a.jpg'),
(28754, 1966, 'Eu Nunca... S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220526.mp4', 'http://timg.bdta.pro/images/395b9bb2ce59721c484d8aa40110d82d.jpg'),
(28755, 1966, 'Eu Nunca... S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220527.mp4', 'http://timg.bdta.pro/images/f1dba8a6bbd9ae67cfed20a0839768f3.jpg'),
(28756, 1966, 'Eu Nunca... S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220528.mp4', 'http://timg.bdta.pro/images/b85cab872c5667be5f01f731b6cb2f34.jpg'),
(28757, 1966, 'Eu Nunca... S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220529.mp4', 'http://timg.bdta.pro/images/a04226e705e884f48ce943ca9e908d65.jpg'),
(28758, 1966, 'Eu Nunca... S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220530.mp4', 'http://timg.bdta.pro/images/6e0657fe086171d87f1a20654e5ca2eb.jpg'),
(28759, 1967, 'Eu Nunca... S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220531.mp4', 'http://gstaticontent.com/images/l3uS5KSvEL91nJfTprx9oyl2Y2r_big.jpg'),
(28760, 1967, 'Eu Nunca... S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220532.mp4', 'http://gstaticontent.com/images/l3uS5KSvEL91nJfTprx9oyl2Y2r_big.jpg'),
(28761, 1967, 'Eu Nunca... S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220533.mp4', 'http://gstaticontent.com/images/l3uS5KSvEL91nJfTprx9oyl2Y2r_big.jpg'),
(28762, 1967, 'Eu Nunca... S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220534.mp4', 'http://gstaticontent.com/images/l3uS5KSvEL91nJfTprx9oyl2Y2r_big.jpg'),
(28763, 1967, 'Eu Nunca... S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220535.mp4', 'http://gstaticontent.com/images/l3uS5KSvEL91nJfTprx9oyl2Y2r_big.jpg'),
(28764, 1967, 'Eu Nunca... S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220536.mp4', 'http://gstaticontent.com/images/l3uS5KSvEL91nJfTprx9oyl2Y2r_big.jpg'),
(28765, 1967, 'Eu Nunca... S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220537.mp4', 'http://gstaticontent.com/images/l3uS5KSvEL91nJfTprx9oyl2Y2r_big.jpg'),
(28766, 1967, 'Eu Nunca... S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220538.mp4', 'http://gstaticontent.com/images/l3uS5KSvEL91nJfTprx9oyl2Y2r_big.jpg'),
(28767, 1967, 'Eu Nunca... S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220539.mp4', 'http://gstaticontent.com/images/l3uS5KSvEL91nJfTprx9oyl2Y2r_big.jpg'),
(28768, 1967, 'Eu Nunca... S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220540.mp4', 'http://gstaticontent.com/images/l3uS5KSvEL91nJfTprx9oyl2Y2r_big.jpg'),
(28769, 1968, 'Ladrões da Floresta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109011.mp4', 'http://timg.bdta.pro/images/cd54dcc4e58a5c390bd30cf6bc1441f6.jpg'),
(28770, 1968, 'Ladrões da Floresta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109012.mp4', 'http://timg.bdta.pro/images/5c00008dfecf8e3434a187b28e7ff56f.jpg'),
(28771, 1968, 'Ladrões da Floresta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109013.mp4', 'http://timg.bdta.pro/images/b45a19d54ee1e2583da9140600db1263.jpg'),
(28772, 1968, 'Ladrões da Floresta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109014.mp4', 'http://timg.bdta.pro/images/09a74f86cabb99123d2039c9e296fb13.jpg'),
(28773, 1968, 'Ladrões da Floresta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109015.mp4', 'http://timg.bdta.pro/images/800a4d9cdd17f63aad8bd3e4b15666f3.jpg'),
(28774, 1968, 'Ladrões da Floresta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/109016.mp4', 'http://timg.bdta.pro/images/1d71fd194500709c99e57e85d9c12d35.jpg'),
(28775, 1968, 'Ladrões da Floresta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/109017.mp4', 'http://timg.bdta.pro/images/ea14f02850a4f2279e4f45e860c5d4de.jpg'),
(28776, 1968, 'Ladrões da Floresta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109018.mp4', 'http://timg.bdta.pro/images/8631841af1f20890a2b6dbf6d6d5a0c0.jpg'),
(28777, 1968, 'Ladrões da Floresta S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109019.mp4', 'http://timg.bdta.pro/images/7fd141535ad0c776878516d4d673a331.jpg'),
(28778, 1968, 'Ladrões da Floresta S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109020.mp4', 'http://timg.bdta.pro/images/4c6186bcbe9d967ef3e25bf2bc3b1bcf.jpg'),
(28779, 1969, 'Cursed Films [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/109006.mp4', 'http://timg.bdta.pro/images/8bde0545c234681cb9a7bdd9dbc0be9e.jpg'),
(28780, 1969, 'Cursed Films [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/109007.mp4', 'http://timg.bdta.pro/images/c984e13c68953ca2f273f9484967d268.jpg'),
(28781, 1969, 'Cursed Films [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/109008.mp4', 'http://timg.bdta.pro/images/2b1a4857105e13e5d6c838c044f30d15.jpg'),
(28782, 1969, 'Cursed Films [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/109009.mp4', 'http://timg.bdta.pro/images/56d97c2c2a723ee9ed5fdf72b26bfdeb.jpg'),
(28783, 1969, 'Cursed Films [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/109010.mp4', 'http://timg.bdta.pro/images/2cf8ab7b4549725bc11d03edf5a42199.jpg'),
(28784, 1970, 'Os 4400 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108962.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28785, 1970, 'Os 4400 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108963.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28786, 1970, 'Os 4400 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108964.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28787, 1970, 'Os 4400 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108965.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28788, 1970, 'Os 4400 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108966.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28789, 1971, 'Os 4400 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108967.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28790, 1971, 'Os 4400 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108968.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(28791, 1971, 'Os 4400 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108969.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28792, 1971, 'Os 4400 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108970.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28793, 1971, 'Os 4400 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108971.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28794, 1971, 'Os 4400 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108972.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28795, 1971, 'Os 4400 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108973.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28796, 1971, 'Os 4400 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108974.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28797, 1971, 'Os 4400 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108975.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28798, 1971, 'Os 4400 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108976.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28799, 1971, 'Os 4400 S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108977.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28800, 1971, 'Os 4400 S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108978.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28801, 1971, 'Os 4400 S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108979.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28802, 1972, 'Os 4400 S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108980.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28803, 1972, 'Os 4400 S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108981.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28804, 1972, 'Os 4400 S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108982.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28805, 1972, 'Os 4400 S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108983.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28806, 1972, 'Os 4400 S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108984.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28807, 1972, 'Os 4400 S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108985.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28808, 1972, 'Os 4400 S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108986.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28809, 1972, 'Os 4400 S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108987.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28810, 1972, 'Os 4400 S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108988.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28811, 1972, 'Os 4400 S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108989.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28812, 1972, 'Os 4400 S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108990.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28813, 1972, 'Os 4400 S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108991.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28814, 1972, 'Os 4400 S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108992.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28815, 1973, 'Os 4400 S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108993.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28816, 1973, 'Os 4400 S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108994.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28817, 1973, 'Os 4400 S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108995.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28818, 1973, 'Os 4400 S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108996.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28819, 1973, 'Os 4400 S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108997.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28820, 1973, 'Os 4400 S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108998.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28821, 1973, 'Os 4400 S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108999.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28822, 1973, 'Os 4400 S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/109000.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28823, 1973, 'Os 4400 S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/109001.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28824, 1973, 'Os 4400 S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/109002.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28825, 1973, 'Os 4400 S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/109003.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28826, 1973, 'Os 4400 S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/109004.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28827, 1973, 'Os 4400 S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/109005.mp4', 'http://gstaticontent.com/images/nWpatnVtPVxjsn7mMiRZNAalEMf_big.jpg'),
(28828, 1974, 'Todas as Mulheres do Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108950.mp4', 'http://gstaticontent.com/images/cOcB0dgIHkWpHdM8BCEEtijB1nL_big.jpg'),
(28829, 1974, 'Todas as Mulheres do Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108951.mp4', 'http://gstaticontent.com/images/cOcB0dgIHkWpHdM8BCEEtijB1nL_big.jpg'),
(28830, 1974, 'Todas as Mulheres do Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108952.mp4', 'http://gstaticontent.com/images/cOcB0dgIHkWpHdM8BCEEtijB1nL_big.jpg'),
(28831, 1974, 'Todas as Mulheres do Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108953.mp4', 'http://gstaticontent.com/images/cOcB0dgIHkWpHdM8BCEEtijB1nL_big.jpg'),
(28832, 1974, 'Todas as Mulheres do Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108954.mp4', 'http://gstaticontent.com/images/cOcB0dgIHkWpHdM8BCEEtijB1nL_big.jpg'),
(28833, 1974, 'Todas as Mulheres do Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108955.mp4', 'http://gstaticontent.com/images/cOcB0dgIHkWpHdM8BCEEtijB1nL_big.jpg'),
(28834, 1974, 'Todas as Mulheres do Mundo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108956.mp4', 'http://gstaticontent.com/images/cOcB0dgIHkWpHdM8BCEEtijB1nL_big.jpg'),
(28835, 1974, 'Todas as Mulheres do Mundo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108957.mp4', 'http://gstaticontent.com/images/cOcB0dgIHkWpHdM8BCEEtijB1nL_big.jpg'),
(28836, 1974, 'Todas as Mulheres do Mundo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108958.mp4', 'http://gstaticontent.com/images/cOcB0dgIHkWpHdM8BCEEtijB1nL_big.jpg'),
(28837, 1974, 'Todas as Mulheres do Mundo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108959.mp4', 'http://gstaticontent.com/images/cOcB0dgIHkWpHdM8BCEEtijB1nL_big.jpg'),
(28838, 1974, 'Todas as Mulheres do Mundo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108960.mp4', 'http://gstaticontent.com/images/cOcB0dgIHkWpHdM8BCEEtijB1nL_big.jpg'),
(28839, 1974, 'Todas as Mulheres do Mundo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108961.mp4', 'http://gstaticontent.com/images/cOcB0dgIHkWpHdM8BCEEtijB1nL_big.jpg'),
(28840, 1975, 'Dá Cá S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108859.mp4', 'http://timg.bdta.pro/images/ff13be4743cec7de971936b928184a29.jpg'),
(28841, 1975, 'Dá Cá S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108860.mp4', 'http://timg.bdta.pro/images/bee6153474e6a421be067c0b638a912b.jpg'),
(28842, 1975, 'Dá Cá S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108861.mp4', 'http://timg.bdta.pro/images/a6de36b45696793badcd1f0ceb4fe00f.jpg'),
(28843, 1975, 'Dá Cá S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108862.mp4', 'http://timg.bdta.pro/images/f38527f0ba59ff516bb9efa1946bf6e1.jpg'),
(28844, 1975, 'Dá Cá S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108863.mp4', 'http://timg.bdta.pro/images/45100a20c63f13ce28e786b4c6e987a0.jpg'),
(28845, 1975, 'Dá Cá S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108864.mp4', 'http://timg.bdta.pro/images/0bc561f046cb62163b35d9f375cb54e1.jpg'),
(28846, 1975, 'Dá Cá S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108865.mp4', 'http://timg.bdta.pro/images/9cf1f8628bbc33197eb978b3db837332.jpg'),
(28847, 1975, 'Dá Cá S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108866.mp4', 'http://timg.bdta.pro/images/6cc359ce42a9a8c281524931b7079938.jpg'),
(28848, 1975, 'Dá Cá S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108867.mp4', 'http://timg.bdta.pro/images/73a910157a9ae19eace0b25f01ee48b8.jpg'),
(28849, 1975, 'Dá Cá S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108868.mp4', 'http://timg.bdta.pro/images/0685613920f951f547f3213c28251bb6.jpg'),
(28850, 1975, 'Dá Cá S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108869.mp4', 'http://timg.bdta.pro/images/1f1ab4c7a89143e8fcd134ad4bee5b05.jpg'),
(28851, 1975, 'Dá Cá S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108870.mp4', 'http://timg.bdta.pro/images/6a6fb1a4f642a1701ef29278b92ce3c8.jpg'),
(28852, 1975, 'Dá Cá S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108871.mp4', 'http://timg.bdta.pro/images/447d5d8bf442f0864477c7974df1e25e.jpg'),
(28853, 1975, 'Dá Cá S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108872.mp4', 'http://timg.bdta.pro/images/7cf9de8c20bc7c25fe4ca030441fa267.jpg'),
(28854, 1975, 'Dá Cá S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108873.mp4', 'http://timg.bdta.pro/images/8da348d3054401c938bc6272296b61cd.jpg'),
(28855, 1975, 'Dá Cá S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108874.mp4', 'http://timg.bdta.pro/images/8fae8d9fbcc839b81ff11300e2927fe2.jpg'),
(28856, 1975, 'Dá Cá S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108875.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28857, 1975, 'Dá Cá S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108876.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28858, 1975, 'Dá Cá S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108877.mp4', 'http://timg.bdta.pro/images/c6bc165167b36a99756f4b4eed828550.jpg'),
(28859, 1975, 'Dá Cá S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108878.mp4', 'http://timg.bdta.pro/images/44a9414616484accc41040a0f1c26d54.jpg'),
(28860, 1976, 'Dá Cá S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108879.mp4', 'http://timg.bdta.pro/images/ab9090256866953ba4ce32d61d25e5cf.jpg'),
(28861, 1976, 'Dá Cá S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108880.mp4', 'http://timg.bdta.pro/images/62e402f17d0c97946856ae0104aade21.jpg'),
(28862, 1976, 'Dá Cá S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108881.mp4', 'http://timg.bdta.pro/images/a85db4e32ee244b37af32a1ac8065269.jpg'),
(28863, 1976, 'Dá Cá S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108882.mp4', 'http://timg.bdta.pro/images/12938a9f822eb3723d8f26bbfcb8ddec.jpg'),
(28864, 1976, 'Dá Cá S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108883.mp4', 'http://timg.bdta.pro/images/c9d050706266176477661b2f37a4f0dc.jpg'),
(28865, 1976, 'Dá Cá S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108884.mp4', 'http://timg.bdta.pro/images/ced52de8c011924abc1e9a737445563b.jpg'),
(28866, 1976, 'Dá Cá S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108885.mp4', 'http://timg.bdta.pro/images/19aecba6a9504b3273c2dd6f81e29663.jpg'),
(28867, 1976, 'Dá Cá S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108886.mp4', 'http://timg.bdta.pro/images/37aaf9af71f409f6625a596a27a16e6e.jpg'),
(28868, 1976, 'Dá Cá S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108887.mp4', 'http://timg.bdta.pro/images/c173dd78158b744348604f1c9359e43f.jpg'),
(28869, 1976, 'Dá Cá S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108888.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28870, 1976, 'Dá Cá S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108889.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28871, 1976, 'Dá Cá S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108890.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28872, 1976, 'Dá Cá S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108891.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28873, 1976, 'Dá Cá S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108892.mp4', 'http://timg.bdta.pro/images/897b349847a0e6dfe92c09b3c476134f.jpg'),
(28874, 1976, 'Dá Cá S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108893.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28875, 1976, 'Dá Cá S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108894.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28876, 1976, 'Dá Cá S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108895.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28877, 1976, 'Dá Cá S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108896.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28878, 1976, 'Dá Cá S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108897.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28879, 1976, 'Dá Cá S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108898.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28880, 1976, 'Dá Cá S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/108899.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28881, 1976, 'Dá Cá S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/108900.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28882, 1976, 'Dá Cá S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/108901.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28883, 1976, 'Dá Cá S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/108902.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28884, 1976, 'Dá Cá S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/108903.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28885, 1976, 'Dá Cá S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/108904.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28886, 1976, 'Dá Cá S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/108905.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28887, 1976, 'Dá Cá S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/108906.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28888, 1976, 'Dá Cá S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/108907.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28889, 1976, 'Dá Cá S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/108908.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28890, 1976, 'Dá Cá S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/108909.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28891, 1976, 'Dá Cá S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/108910.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28892, 1976, 'Dá Cá S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/108911.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28893, 1976, 'Dá Cá S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/108912.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28894, 1976, 'Dá Cá S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/108913.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28895, 1976, 'Dá Cá S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/108914.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28896, 1976, 'Dá Cá S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/108915.mp4', 'http://gstaticontent.com/images/d00Hpwh70yAapKSmaIhBhTFn3HN_big.jpg'),
(28897, 1977, 'Dá Cá S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/108916.mp4', 'http://timg.bdta.pro/images/996082ce272ab0a0e53c6105fa30a4d1.jpg'),
(28898, 1977, 'Dá Cá S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/108917.mp4', 'http://timg.bdta.pro/images/a323a4388477260cfc88b25941ebe0da.jpg'),
(28899, 1977, 'Dá Cá S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/108918.mp4', 'http://timg.bdta.pro/images/d38d443b232297fd51902401826834fd.jpg'),
(28900, 1977, 'Dá Cá S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/108919.mp4', 'http://timg.bdta.pro/images/c20f1c45f3f1d40b4f06b9ab00f368bd.jpg'),
(28901, 1977, 'Dá Cá S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/108920.mp4', 'http://timg.bdta.pro/images/1cf058124ea771d0e4c1fc35ffaa640c.jpg'),
(28902, 1977, 'Dá Cá S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/108921.mp4', 'http://timg.bdta.pro/images/2e0b9166911067678a36ba5cb622bd87.jpg'),
(28903, 1977, 'Dá Cá S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/108922.mp4', 'http://timg.bdta.pro/images/197dbfc69b3932d8ba8b4aaefc671a31.jpg'),
(28904, 1977, 'Dá Cá S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/108923.mp4', 'http://timg.bdta.pro/images/139a267440b8329a25f206e80e9e778d.jpg'),
(28905, 1977, 'Dá Cá S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/108924.mp4', 'http://timg.bdta.pro/images/bbc78424faaea5a1ba9259da93f97371.jpg'),
(28906, 1977, 'Dá Cá S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/108925.mp4', 'http://timg.bdta.pro/images/89b77f2be1f1190ed735062da33d3055.jpg'),
(28907, 1977, 'Dá Cá S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/108926.mp4', 'http://timg.bdta.pro/images/c90778bd63ca7c7297ab5e803b5b4951.jpg'),
(28908, 1977, 'Dá Cá S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/108927.mp4', 'http://timg.bdta.pro/images/994bc74658d5fe15d70387a97c52c770.jpg'),
(28909, 1977, 'Dá Cá S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/108928.mp4', 'http://timg.bdta.pro/images/fca05caf336f74effa672180ae00d8e1.jpg'),
(28910, 1977, 'Dá Cá S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/108929.mp4', 'http://timg.bdta.pro/images/f9a591948a1bbca94ee347fbd6bbfe6d.jpg'),
(28911, 1977, 'Dá Cá S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/108930.mp4', 'http://timg.bdta.pro/images/5017162b500e5a4b8f3cdc4ba075556b.jpg'),
(28912, 1977, 'Dá Cá S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/108931.mp4', 'http://timg.bdta.pro/images/71db51c58a6716f95f9dea420958d6c4.jpg'),
(28913, 1977, 'Dá Cá S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/108932.mp4', 'http://timg.bdta.pro/images/047a76697df83c9f6a85d59787762d57.jpg'),
(28914, 1977, 'Dá Cá S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/108933.mp4', 'http://timg.bdta.pro/images/d6116b35128146dbcc8676651d8e6abb.jpg'),
(28915, 1977, 'Dá Cá S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/108934.mp4', 'http://timg.bdta.pro/images/fb061928d68b4caaeca4305f36fa709d.jpg'),
(28916, 1977, 'Dá Cá S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/108935.mp4', 'http://timg.bdta.pro/images/86b8f70da43cbf80f94845c955200bbc.jpg'),
(28917, 1977, 'Dá Cá S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/108936.mp4', 'http://timg.bdta.pro/images/012cfe6c9eddc3bffe93a5265a4d007c.jpg'),
(28918, 1977, 'Dá Cá S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/108937.mp4', 'http://timg.bdta.pro/images/5a46b4fd01c8f4efe5a87a8839ddc4e8.jpg'),
(28919, 1977, 'Dá Cá S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/108938.mp4', 'http://timg.bdta.pro/images/bc3f3fe2446f94eeb42ad149802146ef.jpg'),
(28920, 1977, 'Dá Cá S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/108939.mp4', 'http://timg.bdta.pro/images/25cb89da9f529fb95e92e70d8b1bf407.jpg'),
(28921, 1977, 'Dá Cá S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/108940.mp4', 'http://timg.bdta.pro/images/1a29220b3856c8e0e96bd8f56416b6ef.jpg'),
(28922, 1977, 'Dá Cá S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/108941.mp4', 'http://timg.bdta.pro/images/713118e249bd6cbfa8d851383f50a468.jpg'),
(28923, 1977, 'Dá Cá S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/108942.mp4', 'http://timg.bdta.pro/images/5a01d4e00a2588b58ba85a8c88ebb18b.jpg'),
(28924, 1977, 'Dá Cá S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/108943.mp4', 'http://timg.bdta.pro/images/ac09db5f17d045f8d74fd6483d673cf7.jpg'),
(28925, 1977, 'Dá Cá S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/108944.mp4', 'http://timg.bdta.pro/images/0d5a8dc18b336e2d6162ed400e6fa7e0.jpg'),
(28926, 1977, 'Dá Cá S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/108945.mp4', 'http://timg.bdta.pro/images/c6493f2de62358ef6db5e62197656c34.jpg'),
(28927, 1977, 'Dá Cá S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/108946.mp4', 'http://timg.bdta.pro/images/d73b8227206a8b554b979bab6d5e88d9.jpg'),
(28928, 1977, 'Dá Cá S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/108947.mp4', 'http://timg.bdta.pro/images/465b7d9daa7930e9c1e8338fbab5b72f.jpg'),
(28929, 1977, 'Dá Cá S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/108948.mp4', 'http://timg.bdta.pro/images/7c7f64dce9b1629fcbec396cd915e2d0.jpg'),
(28930, 1977, 'Dá Cá S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/108949.mp4', 'http://timg.bdta.pro/images/039983fb866c8c8fe336449e875bfd06.jpg'),
(28931, 1978, '220 Volts S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114837.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28932, 1978, '220 Volts S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114838.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28933, 1978, '220 Volts S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114839.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28934, 1978, '220 Volts S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114840.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28935, 1978, '220 Volts S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114841.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28936, 1978, '220 Volts S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114842.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28937, 1978, '220 Volts S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114843.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28938, 1978, '220 Volts S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114844.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28939, 1978, '220 Volts S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114845.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28940, 1978, '220 Volts S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114846.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28941, 1978, '220 Volts S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114847.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28942, 1978, '220 Volts S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114848.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28943, 1978, '220 Volts S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114849.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28944, 1979, '220 Volts S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114850.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28945, 1979, '220 Volts S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114851.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28946, 1979, '220 Volts S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114852.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28947, 1979, '220 Volts S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114853.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28948, 1979, '220 Volts S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114854.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28949, 1979, '220 Volts S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114855.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28950, 1979, '220 Volts S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114856.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28951, 1979, '220 Volts S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114857.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28952, 1979, '220 Volts S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114858.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28953, 1979, '220 Volts S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114859.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28954, 1979, '220 Volts S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114860.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28955, 1979, '220 Volts S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114861.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28956, 1979, '220 Volts S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114862.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28957, 1980, '220 Volts S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114863.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28958, 1980, '220 Volts S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114864.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28959, 1980, '220 Volts S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114865.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28960, 1980, '220 Volts S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114866.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28961, 1980, '220 Volts S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114867.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28962, 1980, '220 Volts S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114868.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28963, 1980, '220 Volts S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114869.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28964, 1980, '220 Volts S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114870.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28965, 1980, '220 Volts S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114871.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28966, 1980, '220 Volts S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114872.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28967, 1980, '220 Volts S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114873.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28968, 1980, '220 Volts S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114874.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28969, 1980, '220 Volts S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114875.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28970, 1981, '220 Volts S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114876.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28971, 1981, '220 Volts S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114877.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28972, 1981, '220 Volts S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114878.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28973, 1981, '220 Volts S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114879.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28974, 1981, '220 Volts S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114880.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28975, 1981, '220 Volts S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114881.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28976, 1981, '220 Volts S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114882.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28977, 1981, '220 Volts S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114883.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28978, 1981, '220 Volts S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114884.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28979, 1981, '220 Volts S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114885.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28980, 1981, '220 Volts S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114886.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28981, 1981, '220 Volts S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114887.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28982, 1981, '220 Volts S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114888.mp4', 'http://gstaticontent.com/images/d20b6efc560dd42aa1725656dde3500d.jpg'),
(28983, 1982, 'Black Sails S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114889.mp4', 'http://timg.bdta.pro/images/372d94084b58f18f7cdb3f924a024b41.jpg'),
(28984, 1982, 'Black Sails S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114890.mp4', 'http://timg.bdta.pro/images/b75ab71a216da695f9eec2e2b1a968b5.jpg'),
(28985, 1982, 'Black Sails S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114891.mp4', 'http://timg.bdta.pro/images/51ad18d6c31c1fc7b3f2ac1c41249e1a.jpg'),
(28986, 1982, 'Black Sails S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114892.mp4', 'http://timg.bdta.pro/images/18e250910321771b42a1633d34b98ac6.jpg'),
(28987, 1982, 'Black Sails S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114893.mp4', 'http://timg.bdta.pro/images/f032554aaad05910a6b205e4a4980310.jpg'),
(28988, 1982, 'Black Sails S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114894.mp4', 'http://timg.bdta.pro/images/0cb99857403822f21be6750ba0058bd2.jpg'),
(28989, 1982, 'Black Sails S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114895.mp4', 'http://timg.bdta.pro/images/303a952f1a341e7856fc4ef574003c56.jpg'),
(28990, 1982, 'Black Sails S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114896.mp4', 'http://timg.bdta.pro/images/fc3855dfb3637a7203cddcb3ab486ac1.jpg'),
(28991, 1983, 'Black Sails S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114897.mp4', 'http://timg.bdta.pro/images/da59a194e058425ccaf5614a0ea9b7d8.jpg'),
(28992, 1983, 'Black Sails S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114898.mp4', 'http://timg.bdta.pro/images/ec3d69209f76d6d42f22c2244ffae556.jpg'),
(28993, 1983, 'Black Sails S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114899.mp4', 'http://timg.bdta.pro/images/326e74d68b34b4ecbdbd918212476301.jpg'),
(28994, 1983, 'Black Sails S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114900.mp4', 'http://timg.bdta.pro/images/12d2df143e1fb8d6ef03befda5f3d256.jpg'),
(28995, 1983, 'Black Sails S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114901.mp4', 'http://timg.bdta.pro/images/b8d2698e733be75cb5bff30d442ee760.jpg'),
(28996, 1983, 'Black Sails S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114902.mp4', 'http://timg.bdta.pro/images/37fe9c6b0340f7d938e124d5fea13191.jpg'),
(28997, 1983, 'Black Sails S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114903.mp4', 'http://timg.bdta.pro/images/e13292e2588a70c21d14322f64aa22d3.jpg'),
(28998, 1983, 'Black Sails S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114904.mp4', 'http://timg.bdta.pro/images/d2c12cd7758c0cf8f21a69807274b3d8.jpg'),
(28999, 1983, 'Black Sails S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114905.mp4', 'http://timg.bdta.pro/images/b3405c25ef3443a3b5909db77cbd88a8.jpg'),
(29000, 1983, 'Black Sails S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114906.mp4', 'http://timg.bdta.pro/images/5e3ae13c1bdd25b8d72c783f1c309aac.jpg'),
(29001, 1984, 'Black Sails S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114907.mp4', 'http://timg.bdta.pro/images/82137b3f56b014f0afc60de2a7618f35.jpg'),
(29002, 1984, 'Black Sails S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114908.mp4', 'http://timg.bdta.pro/images/7c67f921afe3d38cab9809f94b70a3a1.jpg'),
(29003, 1984, 'Black Sails S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114909.mp4', 'http://timg.bdta.pro/images/c942c41f2b21e25103f2b1e9172a6be4.jpg'),
(29004, 1984, 'Black Sails S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114910.mp4', 'http://timg.bdta.pro/images/73327e962a51293840e1617a17f091b2.jpg'),
(29005, 1984, 'Black Sails S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114911.mp4', 'http://timg.bdta.pro/images/278df8a1c9822eea411c856f077a1adf.jpg'),
(29006, 1984, 'Black Sails S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114912.mp4', 'http://timg.bdta.pro/images/28505af5c31044b57b50a03b1cf9b577.jpg'),
(29007, 1984, 'Black Sails S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114913.mp4', 'http://timg.bdta.pro/images/b12034f6a6fbdb33d110538ae54048b0.jpg'),
(29008, 1984, 'Black Sails S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114914.mp4', 'http://timg.bdta.pro/images/e7e58fa4472eb33859413c4ee7c7d48b.jpg'),
(29009, 1984, 'Black Sails S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114915.mp4', 'http://timg.bdta.pro/images/15a72d4a91304a0d6a5a31057453f0a5.jpg'),
(29010, 1984, 'Black Sails S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114916.mp4', 'http://timg.bdta.pro/images/7201418db66c61afb826de062e991d7a.jpg'),
(29011, 1985, 'Black Sails S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114917.mp4', 'http://timg.bdta.pro/images/6eff9e899096fb3b3120cb038f481ae4.jpg'),
(29012, 1985, 'Black Sails S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114918.mp4', 'http://timg.bdta.pro/images/cef861ad316324ce13714cbb55459545.jpg'),
(29013, 1985, 'Black Sails S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114919.mp4', 'http://timg.bdta.pro/images/cb07b205a0f7927cac006c0b48c608f3.jpg'),
(29014, 1985, 'Black Sails S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114920.mp4', 'http://timg.bdta.pro/images/642c97ac7c3dc5c3a2ab570a57d80296.jpg'),
(29015, 1985, 'Black Sails S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114921.mp4', 'http://timg.bdta.pro/images/5fffa574f72fbd25b42a461d6cde1396.jpg'),
(29016, 1985, 'Black Sails S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114922.mp4', 'http://timg.bdta.pro/images/e973cd05e4d077e5250b45ee66c69a68.jpg'),
(29017, 1985, 'Black Sails S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114923.mp4', 'http://timg.bdta.pro/images/9f8f98b17120c1a8a7afaf3bda713c2a.jpg'),
(29018, 1985, 'Black Sails S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114924.mp4', 'http://timg.bdta.pro/images/266ccf42b2de0c54e6620407a31cdf48.jpg'),
(29019, 1985, 'Black Sails S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114925.mp4', 'http://timg.bdta.pro/images/12176a10bc55334cb23722b4f637da1c.jpg'),
(29020, 1985, 'Black Sails S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114926.mp4', 'http://timg.bdta.pro/images/cf4bb69a82150afa01d062baa71f1440.jpg'),
(29021, 1986, 'Hernan S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114927.mp4', 'http://timg.bdta.pro/images/eb59bea30744f5068544f322cecf9500.jpg'),
(29022, 1986, 'Hernan S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114928.mp4', 'http://timg.bdta.pro/images/e6d45150f4a02f8f3828291abd267a6b.jpg'),
(29023, 1986, 'Hernan S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114929.mp4', 'http://timg.bdta.pro/images/8f37862c2bce3ddb66fb31ddaa7555b8.jpg'),
(29024, 1986, 'Hernan S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114930.mp4', 'http://timg.bdta.pro/images/45fb1e308fbd1ba1ba145650926d27fb.jpg'),
(29025, 1986, 'Hernan S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114931.mp4', 'http://timg.bdta.pro/images/e8c9ce1f9167e8659d3d1851224cf49a.jpg'),
(29026, 1986, 'Hernan S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114932.mp4', 'http://timg.bdta.pro/images/776a5affd8868feb19656c43072a2b25.jpg'),
(29027, 1986, 'Hernan S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114933.mp4', 'http://timg.bdta.pro/images/4f9c70d16c0d549ddcdfb70c919103d7.jpg'),
(29028, 1986, 'Hernan S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114934.mp4', 'http://timg.bdta.pro/images/b398a01357ec359e7fe614b17b678ed7.jpg'),
(29029, 1987, 'The Last Dance [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114935.mp4', 'http://timg.bdta.pro/images/3c1534d8edba510d66206ba5b06f54f7.jpg'),
(29030, 1987, 'The Last Dance [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114936.mp4', 'http://timg.bdta.pro/images/25e2ed5b364e59bf5257aa9301cf7608.jpg'),
(29031, 1987, 'The Last Dance [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114937.mp4', 'http://timg.bdta.pro/images/cd34b2325f51cfdb89ab3a75fc1aa0ba.jpg'),
(29032, 1987, 'The Last Dance [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114938.mp4', 'http://timg.bdta.pro/images/377b166dd6aeb59d8decd374faa081cc.jpg'),
(29033, 1987, 'The Last Dance [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114939.mp4', 'http://timg.bdta.pro/images/03fbc1c7bc79e1ad239d94c59c0c52f2.jpg'),
(29034, 1987, 'The Last Dance [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114940.mp4', 'http://timg.bdta.pro/images/5e35f920637af02c40fc9ead3c75a36a.jpg'),
(29035, 1987, 'The Last Dance [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114941.mp4', 'http://timg.bdta.pro/images/fd570c70f86fc8f2eff9bc97bf0bfb6e.jpg'),
(29036, 1987, 'The Last Dance [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114942.mp4', 'http://timg.bdta.pro/images/0775be9a9f4c504e08e095a7bf9957c6.jpg'),
(29037, 1988, 'Trial By Media [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114943.mp4', 'http://timg.bdta.pro/images/44d333b74bc3d3c832349809b9d7b603.jpg'),
(29038, 1988, 'Trial By Media [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114944.mp4', 'http://timg.bdta.pro/images/11d163459da0f251c6154d270bf07d73.jpg'),
(29039, 1988, 'Trial By Media [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114945.mp4', 'http://timg.bdta.pro/images/5aed0a8dddb3439e3f04098c7af98d1d.jpg'),
(29040, 1988, 'Trial By Media [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114946.mp4', 'http://timg.bdta.pro/images/e6ea5599d942dea14302d969475287b5.jpg'),
(29041, 1988, 'Trial By Media [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114947.mp4', 'http://timg.bdta.pro/images/b46e14801c54855d368bf7a4b37236eb.jpg'),
(29042, 1988, 'Trial By Media [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114948.mp4', 'http://timg.bdta.pro/images/5dbf3859381569857cc51dd9c87b3111.jpg'),
(29043, 1989, 'Warrior S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229169.mp4', 'http://timg.bdta.pro/images/42bb224bfc11ae1710c77f3ddeadc012.jpg'),
(29044, 1989, 'Warrior S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229170.mp4', 'http://timg.bdta.pro/images/e7fc33036cac5d62bc06d865a1303518.jpg'),
(29045, 1989, 'Warrior S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229171.mp4', 'http://timg.bdta.pro/images/61739895cf44ed9ddbb2eec7b668468c.jpg'),
(29046, 1989, 'Warrior S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229172.mp4', 'http://timg.bdta.pro/images/fd615842becc702aa0d5a77ce94fcdb2.jpg'),
(29047, 1989, 'Warrior S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229173.mp4', 'http://timg.bdta.pro/images/0535af113e8fc17859a295de0db6ed71.jpg'),
(29048, 1989, 'Warrior S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229174.mp4', 'http://timg.bdta.pro/images/9bf8cd041a1e8baab1000cead36f63b5.jpg'),
(29049, 1989, 'Warrior S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229175.mp4', 'http://timg.bdta.pro/images/fdbf6d454933658c8882195c08093820.jpg'),
(29050, 1989, 'Warrior S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229176.mp4', 'http://timg.bdta.pro/images/ec329258cdda211e98bf859b1aa2a238.jpg'),
(29051, 1989, 'Warrior S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229177.mp4', 'http://timg.bdta.pro/images/4f26ceffee96d1a6839f3b8701d142a3.jpg'),
(29052, 1989, 'Warrior S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229178.mp4', 'http://timg.bdta.pro/images/10e404a9409ea6047c042280a9fba2a9.jpg'),
(29053, 1990, 'Warrior S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6d9BPZDLon7wnTz8TjBf8tps6I.jpg'),
(29054, 1990, 'Warrior S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vOSY8AijddVnL4keKMLq1TtxnQF.jpg'),
(29055, 1990, 'Warrior S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/igyqhIasYURdR0Vf0Ou9DOCBSmR.jpg'),
(29056, 1990, 'Warrior S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3bHrCLxVfOofliqapTgoY18l3bc.jpg'),
(29057, 1990, 'Warrior S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eQz0jXzcS1eFRnE8XDHSxUvpzZb.jpg'),
(29058, 1990, 'Warrior S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZEstDf1P87LktDgHsBxjKoo546.jpg'),
(29059, 1990, 'Warrior S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qIJjZU8jzTZjwFD11Of83zroBFJ.jpg'),
(29060, 1990, 'Warrior S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qMp7zankichW83ZrKujgDhCIo3X.jpg'),
(29061, 1990, 'Warrior S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xGcy0IAVjlgN70zunxgcHs60qva.jpg'),
(29062, 1990, 'Warrior S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1NGfogRQBbHvsK9sTon97Za54OJ.jpg'),
(29063, 1991, 'Warrior S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o75jkGHOxmttRMfGxLa6X4Yw7h5.jpg'),
(29064, 1991, 'Warrior S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qPjMeYgnKh4M3HVZfoCRRbF3byV.jpg'),
(29065, 1991, 'Warrior S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3RQUR5uZS4qJwz1rgIgBpKmo07U.jpg'),
(29066, 1991, 'Warrior S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ML4vEpW0unBCyzIDPLIG9K0UkN.jpg'),
(29067, 1991, 'Warrior S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQqBGHpoYnQLQpCqmfp3Plx6rB6.jpg'),
(29068, 1991, 'Warrior S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229194.mp4', 'http://image.tmdb.org/t/p/w1280/3fqEKm5v8W7jO3AV0pcuBL4zYVa.jpg'),
(29069, 1991, 'Warrior S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229195.mp4', 'http://image.tmdb.org/t/p/w1280/5a3F5k4Hq0jqmAemFtW2906dzQ5.jpg'),
(29070, 1991, 'Warrior S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229196.mp4', 'http://image.tmdb.org/t/p/w1280/3BFqlAKDHOXESItUYpRioJxFcn2.jpg'),
(29071, 1991, 'Warrior S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229197.mp4', 'http://image.tmdb.org/t/p/w1280/lq9KB3JTPEWQsqcWcWT3zqjBxzt.jpg'),
(29072, 1991, 'Warrior S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229198.mp4', 'http://image.tmdb.org/t/p/w1280/ruEYBn1FI3vEaOCZMlRrZeJBskg.jpg'),
(29073, 1992, 'Os Feiticeiros de Waverly Place S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114731.mp4', 'http://timg.bdta.pro/images/7b0a215a99540794f7dead994cea4611.jpg'),
(29074, 1992, 'Os Feiticeiros de Waverly Place S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114732.mp4', 'http://timg.bdta.pro/images/55795327a1d3a3f62cab56bdb24dfad8.jpg'),
(29075, 1992, 'Os Feiticeiros de Waverly Place S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114733.mp4', 'http://timg.bdta.pro/images/d3980f1bd490aa39ec42b7df391b4774.jpg'),
(29076, 1992, 'Os Feiticeiros de Waverly Place S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114734.mp4', 'http://timg.bdta.pro/images/96d6ebc0bd2b29a42f4f42cf95e6dd2d.jpg'),
(29077, 1992, 'Os Feiticeiros de Waverly Place S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114735.mp4', 'http://timg.bdta.pro/images/77ea64f4290b73bd3d5ace8f8626533b.jpg'),
(29078, 1992, 'Os Feiticeiros de Waverly Place S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114736.mp4', 'http://timg.bdta.pro/images/5d242330c0f51687224d865940e6490c.jpg'),
(29079, 1992, 'Os Feiticeiros de Waverly Place S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114737.mp4', 'http://timg.bdta.pro/images/e707f9ed69a10ad0408872930095cdfe.jpg'),
(29080, 1992, 'Os Feiticeiros de Waverly Place S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114738.mp4', 'http://timg.bdta.pro/images/590353b58ba8fbc3f3988546f1996d01.jpg'),
(29081, 1992, 'Os Feiticeiros de Waverly Place S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114739.mp4', 'http://timg.bdta.pro/images/9117436f5d1a1e10816e6a58e5c93971.jpg'),
(29082, 1992, 'Os Feiticeiros de Waverly Place S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114740.mp4', 'http://timg.bdta.pro/images/9422b3cf9f30ae1b4021bc2f2965116c.jpg'),
(29083, 1992, 'Os Feiticeiros de Waverly Place S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114741.mp4', 'http://timg.bdta.pro/images/35575641bc4ab11ae1e1571e41fbb555.jpg'),
(29084, 1992, 'Os Feiticeiros de Waverly Place S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114742.mp4', 'http://timg.bdta.pro/images/3d7e53b95fbfd5ab43f844c94bbe997d.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(29085, 1992, 'Os Feiticeiros de Waverly Place S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114743.mp4', 'http://timg.bdta.pro/images/bc7e8b5238e1d8cd64bd6467f7239b37.jpg'),
(29086, 1992, 'Os Feiticeiros de Waverly Place S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/114744.mp4', 'http://timg.bdta.pro/images/eb8afa66125da86ebd242fe63e8203d8.jpg'),
(29087, 1992, 'Os Feiticeiros de Waverly Place S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/114745.mp4', 'http://timg.bdta.pro/images/d3d2e535559aef99d1772d2b78c83810.jpg'),
(29088, 1992, 'Os Feiticeiros de Waverly Place S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/114746.mp4', 'http://timg.bdta.pro/images/85524dcbd9d8ff1d5ce92741d7d50deb.jpg'),
(29089, 1992, 'Os Feiticeiros de Waverly Place S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/114747.mp4', 'http://timg.bdta.pro/images/9d929442421aade0a54d2da5c193cdff.jpg'),
(29090, 1992, 'Os Feiticeiros de Waverly Place S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/114748.mp4', 'http://timg.bdta.pro/images/f1e7c8056cb89d44788e60d2a9f137f1.jpg'),
(29091, 1992, 'Os Feiticeiros de Waverly Place S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/114749.mp4', 'http://timg.bdta.pro/images/01d25b5dc566cdbccf1e809ace8e4e2f.jpg'),
(29092, 1992, 'Os Feiticeiros de Waverly Place S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/114750.mp4', 'http://timg.bdta.pro/images/142863578c29bb6a27e3dc90a55a1a26.jpg'),
(29093, 1992, 'Os Feiticeiros de Waverly Place S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/114751.mp4', 'http://timg.bdta.pro/images/89848c93728bab0255847a81ab48944c.jpg'),
(29094, 1993, 'Os Feiticeiros de Waverly Place S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114752.mp4', 'http://timg.bdta.pro/images/747f11ead39c85907e95be2334fd8c66.jpg'),
(29095, 1993, 'Os Feiticeiros de Waverly Place S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114753.mp4', 'http://timg.bdta.pro/images/431e607ed63a4e510923c3ed40557d2e.jpg'),
(29096, 1993, 'Os Feiticeiros de Waverly Place S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114754.mp4', 'http://timg.bdta.pro/images/10f2a9c4e481d14a2c865538a1abf4eb.jpg'),
(29097, 1993, 'Os Feiticeiros de Waverly Place S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114755.mp4', 'http://timg.bdta.pro/images/23482e07a9aafe6f43651a321250257f.jpg'),
(29098, 1993, 'Os Feiticeiros de Waverly Place S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114756.mp4', 'http://timg.bdta.pro/images/de4412cb76f7c8b9d859a9d042c681c0.jpg'),
(29099, 1993, 'Os Feiticeiros de Waverly Place S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114757.mp4', 'http://timg.bdta.pro/images/f03f34e679826e332b1fa18a4d015187.jpg'),
(29100, 1993, 'Os Feiticeiros de Waverly Place S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114758.mp4', 'http://timg.bdta.pro/images/a509e294e94689b13d1537f2823c4f12.jpg'),
(29101, 1993, 'Os Feiticeiros de Waverly Place S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114759.mp4', 'http://timg.bdta.pro/images/d4fd0c7563c939353f3357caf714fbd2.jpg'),
(29102, 1993, 'Os Feiticeiros de Waverly Place S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114760.mp4', 'http://timg.bdta.pro/images/a3e10e787ea8c5ba5f3016a4a6f8ac99.jpg'),
(29103, 1993, 'Os Feiticeiros de Waverly Place S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114761.mp4', 'http://timg.bdta.pro/images/844c25ddba3a8e1bb3ceb675c70da443.jpg'),
(29104, 1993, 'Os Feiticeiros de Waverly Place S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114762.mp4', 'http://timg.bdta.pro/images/7cbd749320a1982fbe459171be9342c7.jpg'),
(29105, 1993, 'Os Feiticeiros de Waverly Place S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114763.mp4', 'http://timg.bdta.pro/images/83bad709940263bedd87e0943584f3cc.jpg'),
(29106, 1993, 'Os Feiticeiros de Waverly Place S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114764.mp4', 'http://timg.bdta.pro/images/2a83dff71a21e8aa85dfc8b8e8b55671.jpg'),
(29107, 1993, 'Os Feiticeiros de Waverly Place S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/114765.mp4', 'http://timg.bdta.pro/images/27d433eb3d077660c3122ee3bcf1b8ad.jpg'),
(29108, 1993, 'Os Feiticeiros de Waverly Place S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/114766.mp4', 'http://timg.bdta.pro/images/dc6638cf8d0596b1e10cceb74b303174.jpg'),
(29109, 1993, 'Os Feiticeiros de Waverly Place S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/114767.mp4', 'http://timg.bdta.pro/images/25ad4590e3b1e9f3254497af9e12e744.jpg'),
(29110, 1993, 'Os Feiticeiros de Waverly Place S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/114768.mp4', 'http://timg.bdta.pro/images/b163646bd39b131356ce1a6e1601ce62.jpg'),
(29111, 1993, 'Os Feiticeiros de Waverly Place S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/114769.mp4', 'http://timg.bdta.pro/images/5932faba64f08553e68624e92aaf5c5f.jpg'),
(29112, 1993, 'Os Feiticeiros de Waverly Place S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/114770.mp4', 'http://timg.bdta.pro/images/0681a90d4652d78b1c7da94ac5e22124.jpg'),
(29113, 1993, 'Os Feiticeiros de Waverly Place S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/114771.mp4', 'http://timg.bdta.pro/images/541873f7755b19992fc10db421df496d.jpg'),
(29114, 1993, 'Os Feiticeiros de Waverly Place S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/114772.mp4', 'http://timg.bdta.pro/images/6dfdd5e300690677109d23e62a976318.jpg'),
(29115, 1993, 'Os Feiticeiros de Waverly Place S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/114773.mp4', 'http://timg.bdta.pro/images/414a6091d962b7c473329b1318146086.jpg'),
(29116, 1993, 'Os Feiticeiros de Waverly Place S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/114774.mp4', 'http://timg.bdta.pro/images/22166ce257e17066497687398919c81e.jpg'),
(29117, 1993, 'Os Feiticeiros de Waverly Place S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/114775.mp4', 'http://timg.bdta.pro/images/99fccd9bd0711c1e307e0d5b6d3a47ef.jpg'),
(29118, 1993, 'Os Feiticeiros de Waverly Place S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/114776.mp4', 'http://timg.bdta.pro/images/5c272ae46c86092bbf06f0ffb962195e.jpg'),
(29119, 1993, 'Os Feiticeiros de Waverly Place S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/114777.mp4', 'http://timg.bdta.pro/images/b7bd69770d0d99a0f69d56410dddad34.jpg'),
(29120, 1993, 'Os Feiticeiros de Waverly Place S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/114778.mp4', 'http://timg.bdta.pro/images/b6e6b944829bd4ddb2bb2f334bfc1bd2.jpg'),
(29121, 1993, 'Os Feiticeiros de Waverly Place S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/114779.mp4', 'http://timg.bdta.pro/images/52f38da7822ee0a0ca40424896eb241b.jpg'),
(29122, 1993, 'Os Feiticeiros de Waverly Place S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/114780.mp4', 'http://timg.bdta.pro/images/c8a443d6e59ea15f56ea479f56fd0dad.jpg'),
(29123, 1993, 'Os Feiticeiros de Waverly Place S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/114781.mp4', 'http://timg.bdta.pro/images/e7c3163e6e04c5de2261505f4f6194ed.jpg'),
(29124, 1994, 'Os Feiticeiros de Waverly Place S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114782.mp4', 'http://timg.bdta.pro/images/b21a53b390b7a86a7c9b715eee8c58a4.jpg'),
(29125, 1994, 'Os Feiticeiros de Waverly Place S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114783.mp4', 'http://timg.bdta.pro/images/637412e63d0d18ef6d30ce9d864bbbf7.jpg'),
(29126, 1994, 'Os Feiticeiros de Waverly Place S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114784.mp4', 'http://timg.bdta.pro/images/4b25ab3bcff0a3cb39225a8062c48870.jpg'),
(29127, 1994, 'Os Feiticeiros de Waverly Place S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114785.mp4', 'http://timg.bdta.pro/images/55c6fafa2df7ebb2b253dc085f67c1c8.jpg'),
(29128, 1994, 'Os Feiticeiros de Waverly Place S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114786.mp4', 'http://timg.bdta.pro/images/f167ff19a8147d653a70446d83696e10.jpg'),
(29129, 1994, 'Os Feiticeiros de Waverly Place S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114787.mp4', 'http://timg.bdta.pro/images/132169718b85132a90b8f6860fb6c2b3.jpg'),
(29130, 1994, 'Os Feiticeiros de Waverly Place S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114788.mp4', 'http://timg.bdta.pro/images/942658e9a1988fcce067204fd4ce5848.jpg'),
(29131, 1994, 'Os Feiticeiros de Waverly Place S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114789.mp4', 'http://timg.bdta.pro/images/41d4ee95511e6b9ef3788129ca1aec09.jpg'),
(29132, 1994, 'Os Feiticeiros de Waverly Place S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114790.mp4', 'http://timg.bdta.pro/images/a7cdc19609157a77309b636f4bd993c3.jpg'),
(29133, 1994, 'Os Feiticeiros de Waverly Place S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114791.mp4', 'http://timg.bdta.pro/images/1d318945296b30913cb39ee58d7cda13.jpg'),
(29134, 1994, 'Os Feiticeiros de Waverly Place S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114792.mp4', 'http://timg.bdta.pro/images/c4cbe4db1882fd6f799bdd8b3f19f9ad.jpg'),
(29135, 1994, 'Os Feiticeiros de Waverly Place S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114793.mp4', 'http://timg.bdta.pro/images/6d03bf6ebf20d94e3a00dd478f713e3d.jpg'),
(29136, 1994, 'Os Feiticeiros de Waverly Place S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114794.mp4', 'http://timg.bdta.pro/images/041698b6a376a18ab190ec081c78c1c0.jpg'),
(29137, 1994, 'Os Feiticeiros de Waverly Place S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/114795.mp4', 'http://timg.bdta.pro/images/2c00622aee03a2e796ddff8424f43712.jpg'),
(29138, 1994, 'Os Feiticeiros de Waverly Place S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/114796.mp4', 'http://timg.bdta.pro/images/640a5e6067f41e4791563634b96dd50b.jpg'),
(29139, 1994, 'Os Feiticeiros de Waverly Place S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/114797.mp4', 'http://timg.bdta.pro/images/c695e04200982353721cc80ee12c7782.jpg'),
(29140, 1994, 'Os Feiticeiros de Waverly Place S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/114798.mp4', 'http://timg.bdta.pro/images/c5acc1d353aae032e88f8f5ae22be914.jpg'),
(29141, 1994, 'Os Feiticeiros de Waverly Place S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/114799.mp4', 'http://timg.bdta.pro/images/d19f6d57eefe5a1820cb0fe9ddb3dd40.jpg'),
(29142, 1994, 'Os Feiticeiros de Waverly Place S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/114800.mp4', 'http://timg.bdta.pro/images/2d879f59f302e0a6506486a43f347ac3.jpg'),
(29143, 1994, 'Os Feiticeiros de Waverly Place S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/114801.mp4', 'http://timg.bdta.pro/images/b671919da62acf9e150c9809d4bd73c1.jpg'),
(29144, 1994, 'Os Feiticeiros de Waverly Place S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/114802.mp4', 'http://timg.bdta.pro/images/f8c296716fa9c7671179761aad73a970.jpg'),
(29145, 1994, 'Os Feiticeiros de Waverly Place S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/114803.mp4', 'http://timg.bdta.pro/images/477d5b0d085ffb69bb3abed739a2b765.jpg'),
(29146, 1994, 'Os Feiticeiros de Waverly Place S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/114804.mp4', 'http://timg.bdta.pro/images/7cf9f872bc7fbcf7ad18ad6946228e1e.jpg'),
(29147, 1994, 'Os Feiticeiros de Waverly Place S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/114805.mp4', 'http://timg.bdta.pro/images/c8468076870f226aa4607c74fbe49210.jpg'),
(29148, 1994, 'Os Feiticeiros de Waverly Place S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/114806.mp4', 'http://timg.bdta.pro/images/02ee4aeb85cb629896640a06bde39739.jpg'),
(29149, 1994, 'Os Feiticeiros de Waverly Place S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/114807.mp4', 'http://timg.bdta.pro/images/1cb4da52641891cc7f606f739c573310.jpg'),
(29150, 1994, 'Os Feiticeiros de Waverly Place S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/114808.mp4', 'http://timg.bdta.pro/images/4fba0b81a3eeafae83401181f02eb909.jpg'),
(29151, 1994, 'Os Feiticeiros de Waverly Place S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/114809.mp4', 'http://timg.bdta.pro/images/2552c92c1e4f6daa36001f47987365d8.jpg'),
(29152, 1995, 'Os Feiticeiros de Waverly Place S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114810.mp4', 'http://timg.bdta.pro/images/ac7d12d003b618d9b24df6764a00e7c3.jpg'),
(29153, 1995, 'Os Feiticeiros de Waverly Place S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114811.mp4', 'http://timg.bdta.pro/images/3fd2f6c284d343739e0f8fb9af4984c0.jpg'),
(29154, 1995, 'Os Feiticeiros de Waverly Place S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114812.mp4', 'http://timg.bdta.pro/images/969bf91fbb2530659c74504d5fe60102.jpg'),
(29155, 1995, 'Os Feiticeiros de Waverly Place S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114813.mp4', 'http://timg.bdta.pro/images/6e7a4d92c72322e4cbd8ea265860f50d.jpg'),
(29156, 1995, 'Os Feiticeiros de Waverly Place S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114814.mp4', 'http://timg.bdta.pro/images/96e895cbee647a140c646d747c90866f.jpg'),
(29157, 1995, 'Os Feiticeiros de Waverly Place S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114815.mp4', 'http://timg.bdta.pro/images/3754070cb460bc75a1a4fb1ac4c1649f.jpg'),
(29158, 1995, 'Os Feiticeiros de Waverly Place S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114816.mp4', 'http://timg.bdta.pro/images/e47609fec5fcbfd46d9e74fca0d158fa.jpg'),
(29159, 1995, 'Os Feiticeiros de Waverly Place S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114817.mp4', 'http://timg.bdta.pro/images/b5f9d87560e439c0d6024ae4a1dd3790.jpg'),
(29160, 1995, 'Os Feiticeiros de Waverly Place S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114818.mp4', 'http://timg.bdta.pro/images/27d71f2d823fadbac8fbf99b0c2b85ef.jpg'),
(29161, 1995, 'Os Feiticeiros de Waverly Place S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114819.mp4', 'http://timg.bdta.pro/images/f3bc14537c205ee553095af86e9aec3a.jpg'),
(29162, 1995, 'Os Feiticeiros de Waverly Place S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114820.mp4', 'http://timg.bdta.pro/images/08aa24bbe91654e8623ee2784bb69d1a.jpg'),
(29163, 1995, 'Os Feiticeiros de Waverly Place S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114821.mp4', 'http://timg.bdta.pro/images/a4293381c0af35ac669c544e41f3fc2b.jpg'),
(29164, 1995, 'Os Feiticeiros de Waverly Place S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114822.mp4', 'http://timg.bdta.pro/images/9e86312eab685b1ba863f087eb8249ce.jpg'),
(29165, 1995, 'Os Feiticeiros de Waverly Place S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/114823.mp4', 'http://timg.bdta.pro/images/70990e85493b195ca79585a71031273e.jpg'),
(29166, 1995, 'Os Feiticeiros de Waverly Place S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/114824.mp4', 'http://timg.bdta.pro/images/49fe5ff877fab705cfccd902655eb53c.jpg'),
(29167, 1995, 'Os Feiticeiros de Waverly Place S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/114825.mp4', 'http://timg.bdta.pro/images/9ed387145903c1760806f11fa81a27d6.jpg'),
(29168, 1995, 'Os Feiticeiros de Waverly Place S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/114826.mp4', 'http://timg.bdta.pro/images/bce0513528cbce81a4a5920d4c25f2b0.jpg'),
(29169, 1995, 'Os Feiticeiros de Waverly Place S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/114827.mp4', 'http://timg.bdta.pro/images/dd87463280f427342ac06191f6294a54.jpg'),
(29170, 1995, 'Os Feiticeiros de Waverly Place S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/114828.mp4', 'http://timg.bdta.pro/images/38ad27a357ae887306e92675ad4c9928.jpg'),
(29171, 1995, 'Os Feiticeiros de Waverly Place S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/114829.mp4', 'http://timg.bdta.pro/images/a30a9cbaef55c24566bf04238e3ea07a.jpg'),
(29172, 1995, 'Os Feiticeiros de Waverly Place S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/114830.mp4', 'http://timg.bdta.pro/images/b117e19a4e5195724c078c9a41ac10e5.jpg'),
(29173, 1995, 'Os Feiticeiros de Waverly Place S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/114831.mp4', 'http://timg.bdta.pro/images/a5fd8b03b54c5b48e2046220a7a8d469.jpg'),
(29174, 1995, 'Os Feiticeiros de Waverly Place S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/114832.mp4', 'http://timg.bdta.pro/images/e34772d5edff83b42fc139badf3e7446.jpg'),
(29175, 1995, 'Os Feiticeiros de Waverly Place S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/114833.mp4', 'http://timg.bdta.pro/images/19da778525cbb15a2aae10268d2909cd.jpg'),
(29176, 1995, 'Os Feiticeiros de Waverly Place S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/114834.mp4', 'http://timg.bdta.pro/images/d96b22afcdb26351f1e7ed827f0b438d.jpg'),
(29177, 1995, 'Os Feiticeiros de Waverly Place S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/114835.mp4', 'http://timg.bdta.pro/images/6b85a4c93228fec49a046784a39c3147.jpg'),
(29178, 1995, 'Os Feiticeiros de Waverly Place S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/114836.mp4', 'http://timg.bdta.pro/images/eb596b1e2b95ab3ecc94cae6e5446cb7.jpg'),
(29179, 1996, 'As Brasileiras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114709.mp4', 'http://gstaticontent.com/images/kLAVM6qAMQJEWpebEuvqYpbmKJk_big.jpg'),
(29180, 1996, 'As Brasileiras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114710.mp4', 'http://gstaticontent.com/images/kLAVM6qAMQJEWpebEuvqYpbmKJk_big.jpg'),
(29181, 1996, 'As Brasileiras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114711.mp4', 'http://gstaticontent.com/images/kLAVM6qAMQJEWpebEuvqYpbmKJk_big.jpg'),
(29182, 1996, 'As Brasileiras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114712.mp4', 'http://gstaticontent.com/images/kLAVM6qAMQJEWpebEuvqYpbmKJk_big.jpg'),
(29183, 1996, 'As Brasileiras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114713.mp4', 'http://gstaticontent.com/images/kLAVM6qAMQJEWpebEuvqYpbmKJk_big.jpg'),
(29184, 1996, 'As Brasileiras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114715.mp4', 'http://gstaticontent.com/images/kLAVM6qAMQJEWpebEuvqYpbmKJk_big.jpg'),
(29185, 1996, 'As Brasileiras S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114716.mp4', 'http://gstaticontent.com/images/kLAVM6qAMQJEWpebEuvqYpbmKJk_big.jpg'),
(29186, 1996, 'As Brasileiras S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114717.mp4', 'http://gstaticontent.com/images/kLAVM6qAMQJEWpebEuvqYpbmKJk_big.jpg'),
(29187, 1996, 'As Brasileiras S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114718.mp4', 'http://gstaticontent.com/images/kLAVM6qAMQJEWpebEuvqYpbmKJk_big.jpg'),
(29188, 1996, 'As Brasileiras S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114719.mp4', 'http://gstaticontent.com/images/kLAVM6qAMQJEWpebEuvqYpbmKJk_big.jpg'),
(29189, 1996, 'As Brasileiras S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114720.mp4', 'http://gstaticontent.com/images/kLAVM6qAMQJEWpebEuvqYpbmKJk_big.jpg'),
(29190, 1996, 'As Brasileiras S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114721.mp4', 'http://gstaticontent.com/images/kLAVM6qAMQJEWpebEuvqYpbmKJk_big.jpg'),
(29191, 1996, 'As Brasileiras S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114722.mp4', 'http://gstaticontent.com/images/kLAVM6qAMQJEWpebEuvqYpbmKJk_big.jpg'),
(29192, 1996, 'As Brasileiras S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/114723.mp4', 'http://gstaticontent.com/images/kLAVM6qAMQJEWpebEuvqYpbmKJk_big.jpg'),
(29193, 1996, 'As Brasileiras S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/114724.mp4', 'http://gstaticontent.com/images/kLAVM6qAMQJEWpebEuvqYpbmKJk_big.jpg'),
(29194, 1996, 'As Brasileiras S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/114725.mp4', 'http://gstaticontent.com/images/kLAVM6qAMQJEWpebEuvqYpbmKJk_big.jpg'),
(29195, 1996, 'As Brasileiras S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/114726.mp4', 'http://gstaticontent.com/images/kLAVM6qAMQJEWpebEuvqYpbmKJk_big.jpg'),
(29196, 1996, 'As Brasileiras S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/114727.mp4', 'http://gstaticontent.com/images/kLAVM6qAMQJEWpebEuvqYpbmKJk_big.jpg'),
(29197, 1996, 'As Brasileiras S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/114728.mp4', 'http://gstaticontent.com/images/kLAVM6qAMQJEWpebEuvqYpbmKJk_big.jpg'),
(29198, 1996, 'As Brasileiras S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/114729.mp4', 'http://gstaticontent.com/images/kLAVM6qAMQJEWpebEuvqYpbmKJk_big.jpg'),
(29199, 1996, 'As Brasileiras S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/114730.mp4', 'http://gstaticontent.com/images/kLAVM6qAMQJEWpebEuvqYpbmKJk_big.jpg'),
(29200, 1997, 'Bulletproof [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114703.mp4', 'http://gstaticontent.com/images/pMfMsFNwpk5kY5ACU93BZQJ2ay6_big.jpg'),
(29201, 1997, 'Bulletproof [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114704.mp4', 'http://gstaticontent.com/images/pMfMsFNwpk5kY5ACU93BZQJ2ay6_big.jpg'),
(29202, 1997, 'Bulletproof [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114705.mp4', 'http://gstaticontent.com/images/pMfMsFNwpk5kY5ACU93BZQJ2ay6_big.jpg'),
(29203, 1997, 'Bulletproof [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114706.mp4', 'http://gstaticontent.com/images/pMfMsFNwpk5kY5ACU93BZQJ2ay6_big.jpg'),
(29204, 1997, 'Bulletproof [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114707.mp4', 'http://gstaticontent.com/images/pMfMsFNwpk5kY5ACU93BZQJ2ay6_big.jpg'),
(29205, 1997, 'Bulletproof [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114708.mp4', 'http://gstaticontent.com/images/pMfMsFNwpk5kY5ACU93BZQJ2ay6_big.jpg'),
(29206, 1998, 'Duncanville [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114692.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(29207, 1998, 'Duncanville [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114693.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(29208, 1998, 'Duncanville [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114694.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(29209, 1998, 'Duncanville [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114695.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(29210, 1998, 'Duncanville [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114696.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(29211, 1998, 'Duncanville [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114697.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(29212, 1998, 'Duncanville [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114698.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(29213, 1998, 'Duncanville [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114699.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(29214, 1998, 'Duncanville [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114700.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(29215, 1998, 'Duncanville [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114701.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(29216, 1998, 'Duncanville [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114702.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(29217, 1999, 'For Life [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114679.mp4', 'http://timg.bdta.pro/images/99885f29d9b1e63f1705235d38cf89bc.jpg'),
(29218, 1999, 'For Life [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114680.mp4', 'http://timg.bdta.pro/images/3083e4f10e1cb9ca667f575a18a1f0a9.jpg'),
(29219, 1999, 'For Life [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114681.mp4', 'http://timg.bdta.pro/images/6b41cf52d20a6f5f4e73c9a8b6127e9a.jpg'),
(29220, 1999, 'For Life [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114682.mp4', 'http://timg.bdta.pro/images/d6e14136711d224c2f4cfa0ee7bda4e7.jpg'),
(29221, 1999, 'For Life [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114683.mp4', 'http://timg.bdta.pro/images/e879e72a6a9cd43bdcf69d7ab3ae1973.jpg'),
(29222, 1999, 'For Life [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114684.mp4', 'http://timg.bdta.pro/images/ff86a8c92dccc1cadc3879fbf2c264ff.jpg'),
(29223, 1999, 'For Life [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114685.mp4', 'http://timg.bdta.pro/images/e7876c22389716acd2b6ef7c063f80de.jpg'),
(29224, 1999, 'For Life [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114686.mp4', 'http://timg.bdta.pro/images/65908d25b11faa10b785398afeb646db.jpg'),
(29225, 1999, 'For Life [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114687.mp4', 'http://timg.bdta.pro/images/0748584d443b97415dab6cd3b2a02ce7.jpg'),
(29226, 1999, 'For Life [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114688.mp4', 'http://timg.bdta.pro/images/6cfd4b16e89e59ed98371e40200fade2.jpg'),
(29227, 1999, 'For Life [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114689.mp4', 'http://timg.bdta.pro/images/42605f28d8dc7829bcaa0e06f6e4d07d.jpg'),
(29228, 1999, 'For Life [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114690.mp4', 'http://timg.bdta.pro/images/06d0cec1d05cb4da01b37fcb5c2c8aea.jpg'),
(29229, 1999, 'For Life [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114691.mp4', 'http://timg.bdta.pro/images/7ff970c18bad73067949d6f08d70d68a.jpg'),
(29230, 2000, 'Gone S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114678.mp4', 'http://timg.bdta.pro/images/9cd14f7534646c94e3074d94fbe5abb4.jpg'),
(29231, 2001, 'Hard S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161724.mp4', 'http://gstaticontent.com/images/j1cGmHM12wAJcDLYclrOFWFmRPx_big.jpg'),
(29232, 2001, 'Hard S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161725.mp4', 'http://timg.bdta.pro/images/486fb56449dd7e8f74a0166214261ca5.jpg'),
(29233, 2001, 'Hard S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161726.mp4', 'http://timg.bdta.pro/images/cddbc5ff3bfc6af58a6da062d809e4de.jpg'),
(29234, 2001, 'Hard S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161727.mp4', 'http://timg.bdta.pro/images/1cd65e0862feccfef8058946d5f5f50a.jpg'),
(29235, 2001, 'Hard S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161728.mp4', 'http://timg.bdta.pro/images/dd3d696ce4833686498c3ff4dd3e59b2.jpg'),
(29236, 2001, 'Hard S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161729.mp4', 'http://timg.bdta.pro/images/c4e215ad2c87f87741e48d09fb66dd39.jpg'),
(29237, 2001, 'Hard S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161730.mp4', 'http://gstaticontent.com/images/j1cGmHM12wAJcDLYclrOFWFmRPx_big.jpg'),
(29238, 2001, 'Hard S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161731.mp4', 'http://gstaticontent.com/images/j1cGmHM12wAJcDLYclrOFWFmRPx_big.jpg'),
(29239, 2001, 'Hard S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161732.mp4', 'http://gstaticontent.com/images/j1cGmHM12wAJcDLYclrOFWFmRPx_big.jpg'),
(29240, 2001, 'Hard S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161733.mp4', 'http://gstaticontent.com/images/j1cGmHM12wAJcDLYclrOFWFmRPx_big.jpg'),
(29241, 2001, 'Hard S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161734.mp4', 'http://gstaticontent.com/images/j1cGmHM12wAJcDLYclrOFWFmRPx_big.jpg'),
(29242, 2001, 'Hard S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161735.mp4', 'http://gstaticontent.com/images/j1cGmHM12wAJcDLYclrOFWFmRPx_big.jpg'),
(29243, 2002, 'Hard S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161736.mp4', 'http://gstaticontent.com/images/j1cGmHM12wAJcDLYclrOFWFmRPx_big.jpg'),
(29244, 2002, 'Hard S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161737.mp4', 'http://gstaticontent.com/images/j1cGmHM12wAJcDLYclrOFWFmRPx_big.jpg'),
(29245, 2002, 'Hard S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161738.mp4', 'http://gstaticontent.com/images/j1cGmHM12wAJcDLYclrOFWFmRPx_big.jpg'),
(29246, 2002, 'Hard S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161739.mp4', 'http://gstaticontent.com/images/j1cGmHM12wAJcDLYclrOFWFmRPx_big.jpg'),
(29247, 2002, 'Hard S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161740.mp4', 'http://gstaticontent.com/images/j1cGmHM12wAJcDLYclrOFWFmRPx_big.jpg'),
(29248, 2002, 'Hard S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161741.mp4', 'http://gstaticontent.com/images/j1cGmHM12wAJcDLYclrOFWFmRPx_big.jpg'),
(29249, 2003, 'Hard S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161742.mp4', 'http://gstaticontent.com/images/j1cGmHM12wAJcDLYclrOFWFmRPx_big.jpg'),
(29250, 2003, 'Hard S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161743.mp4', 'http://gstaticontent.com/images/j1cGmHM12wAJcDLYclrOFWFmRPx_big.jpg'),
(29251, 2003, 'Hard S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161744.mp4', 'http://gstaticontent.com/images/j1cGmHM12wAJcDLYclrOFWFmRPx_big.jpg'),
(29252, 2003, 'Hard S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161745.mp4', 'http://gstaticontent.com/images/j1cGmHM12wAJcDLYclrOFWFmRPx_big.jpg'),
(29253, 2003, 'Hard S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161746.mp4', 'http://gstaticontent.com/images/j1cGmHM12wAJcDLYclrOFWFmRPx_big.jpg'),
(29254, 2003, 'Hard S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161747.mp4', 'http://gstaticontent.com/images/j1cGmHM12wAJcDLYclrOFWFmRPx_big.jpg'),
(29255, 2004, 'Historia Secreta do Pop Brasileiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114670.mp4', 'http://gstaticontent.com/images/h5zl4U5YrTe7qvYW8vHcoiZSBAW_big.jpg'),
(29256, 2004, 'Historia Secreta do Pop Brasileiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114671.mp4', 'http://gstaticontent.com/images/h5zl4U5YrTe7qvYW8vHcoiZSBAW_big.jpg'),
(29257, 2004, 'Historia Secreta do Pop Brasileiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114672.mp4', 'http://gstaticontent.com/images/h5zl4U5YrTe7qvYW8vHcoiZSBAW_big.jpg'),
(29258, 2004, 'Historia Secreta do Pop Brasileiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114673.mp4', 'http://gstaticontent.com/images/h5zl4U5YrTe7qvYW8vHcoiZSBAW_big.jpg'),
(29259, 2004, 'Historia Secreta do Pop Brasileiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114674.mp4', 'http://gstaticontent.com/images/h5zl4U5YrTe7qvYW8vHcoiZSBAW_big.jpg'),
(29260, 2004, 'Historia Secreta do Pop Brasileiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114675.mp4', 'http://gstaticontent.com/images/h5zl4U5YrTe7qvYW8vHcoiZSBAW_big.jpg'),
(29261, 2004, 'Historia Secreta do Pop Brasileiro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114676.mp4', 'http://gstaticontent.com/images/h5zl4U5YrTe7qvYW8vHcoiZSBAW_big.jpg'),
(29262, 2004, 'Historia Secreta do Pop Brasileiro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114677.mp4', 'http://gstaticontent.com/images/h5zl4U5YrTe7qvYW8vHcoiZSBAW_big.jpg'),
(29263, 2005, 'Lei & Ordem: Crimes Premeditados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/112875.mp4', 'http://timg.bdta.pro/images/af611ecfba1e5d87d72a26fb844a355e.jpg'),
(29264, 2005, 'Lei & Ordem: Crimes Premeditados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/112876.mp4', 'http://timg.bdta.pro/images/1f04b3a9abe89b468246f1cc515bd988.jpg'),
(29265, 2005, 'Lei & Ordem: Crimes Premeditados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/112877.mp4', 'http://timg.bdta.pro/images/359cc624ffd9b106f91e00e5236d619f.jpg'),
(29266, 2005, 'Lei & Ordem: Crimes Premeditados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/112878.mp4', 'http://timg.bdta.pro/images/a97880b213082029990a63c98307f288.jpg'),
(29267, 2005, 'Lei & Ordem: Crimes Premeditados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/112879.mp4', 'http://timg.bdta.pro/images/9efaad63d67ad279a6ab84d5f1b728cc.jpg'),
(29268, 2005, 'Lei & Ordem: Crimes Premeditados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/112880.mp4', 'http://timg.bdta.pro/images/6995bdb70d26a2dbef712c252075feea.jpg'),
(29269, 2005, 'Lei & Ordem: Crimes Premeditados S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/112881.mp4', 'http://timg.bdta.pro/images/d2a3d6fb86ba1763bce39d7f8dce23ad.jpg'),
(29270, 2005, 'Lei & Ordem: Crimes Premeditados S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/112882.mp4', 'http://timg.bdta.pro/images/5cab076fa3f672cea241c3c7ba774bb8.jpg'),
(29271, 2005, 'Lei & Ordem: Crimes Premeditados S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/112883.mp4', 'http://timg.bdta.pro/images/637cccb4e80f337f5a6da9f49eee2412.jpg'),
(29272, 2005, 'Lei & Ordem: Crimes Premeditados S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/112884.mp4', 'http://timg.bdta.pro/images/9a8445e092e7cdea7aec69f93dc38095.jpg'),
(29273, 2005, 'Lei & Ordem: Crimes Premeditados S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/112885.mp4', 'http://timg.bdta.pro/images/ad2e83b7076ddb75a6ad6b4da94006e4.jpg'),
(29274, 2005, 'Lei & Ordem: Crimes Premeditados S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/112886.mp4', 'http://timg.bdta.pro/images/61029b9943095b6152b2637cdbbc9369.jpg'),
(29275, 2005, 'Lei & Ordem: Crimes Premeditados S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/112887.mp4', 'http://timg.bdta.pro/images/b7d806b838898245a6421d9ba4cb4440.jpg'),
(29276, 2005, 'Lei & Ordem: Crimes Premeditados S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/112888.mp4', 'http://timg.bdta.pro/images/2649d1ce8931975124ee3ca77dbefc76.jpg'),
(29277, 2005, 'Lei & Ordem: Crimes Premeditados S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/112889.mp4', 'http://timg.bdta.pro/images/1056650603f19f568b0f5e342aff30b3.jpg'),
(29278, 2005, 'Lei & Ordem: Crimes Premeditados S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/112890.mp4', 'http://timg.bdta.pro/images/d41b1a87a329e49f6b28c3597aad375c.jpg'),
(29279, 2005, 'Lei & Ordem: Crimes Premeditados S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/112891.mp4', 'http://timg.bdta.pro/images/31844bb09fe0c67fe520982bbc2aa95e.jpg'),
(29280, 2005, 'Lei & Ordem: Crimes Premeditados S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/112892.mp4', 'http://timg.bdta.pro/images/d5133734be6345a1acf46178524a51f4.jpg'),
(29281, 2005, 'Lei & Ordem: Crimes Premeditados S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/112893.mp4', 'http://timg.bdta.pro/images/b5daf6d48083fe0e3c87dabffb3075a6.jpg'),
(29282, 2005, 'Lei & Ordem: Crimes Premeditados S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/112894.mp4', 'http://timg.bdta.pro/images/9337032858be90955942b1b94f0934ad.jpg'),
(29283, 2005, 'Lei & Ordem: Crimes Premeditados S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/112895.mp4', 'http://timg.bdta.pro/images/45dc390c658442358e5e4cb7b1f1dec3.jpg'),
(29284, 2005, 'Lei & Ordem: Crimes Premeditados S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/112896.mp4', 'http://timg.bdta.pro/images/bbb864d55093a65d9ac8da69a214cc2b.jpg'),
(29285, 2006, 'Lei & Ordem: Crimes Premeditados S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/112897.mp4', 'http://timg.bdta.pro/images/a2fa3dd1f7e66e7287ac9b23c91e05b2.jpg'),
(29286, 2006, 'Lei & Ordem: Crimes Premeditados S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/112898.mp4', 'http://timg.bdta.pro/images/5b2090e20aed6e8c66095ba267c75798.jpg'),
(29287, 2006, 'Lei & Ordem: Crimes Premeditados S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/112899.mp4', 'http://timg.bdta.pro/images/72951fccaff493b74ffc6257a9699029.jpg'),
(29288, 2006, 'Lei & Ordem: Crimes Premeditados S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/112900.mp4', 'http://timg.bdta.pro/images/20ba1160c59a1c00328fd7ab937184a0.jpg'),
(29289, 2006, 'Lei & Ordem: Crimes Premeditados S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/112901.mp4', 'http://timg.bdta.pro/images/ca2ad07085c68f67fc9e0999473e26ec.jpg'),
(29290, 2006, 'Lei & Ordem: Crimes Premeditados S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/112902.mp4', 'http://timg.bdta.pro/images/0a6314f771fc3b58095a09f218d5ab42.jpg'),
(29291, 2006, 'Lei & Ordem: Crimes Premeditados S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/112903.mp4', 'http://timg.bdta.pro/images/ed287f1987ab7ca018fd00e9700aee8b.jpg'),
(29292, 2006, 'Lei & Ordem: Crimes Premeditados S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/112904.mp4', 'http://timg.bdta.pro/images/586a8e18eace946540f81420f96a0139.jpg'),
(29293, 2006, 'Lei & Ordem: Crimes Premeditados S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/112905.mp4', 'http://timg.bdta.pro/images/356faa80c1688f0a9235f0e2309e5d19.jpg'),
(29294, 2006, 'Lei & Ordem: Crimes Premeditados S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/112906.mp4', 'http://timg.bdta.pro/images/b21946c492224be4e0919a5e1d3be3b1.jpg'),
(29295, 2006, 'Lei & Ordem: Crimes Premeditados S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/112907.mp4', 'http://timg.bdta.pro/images/bbe22b5b5c136aaa3c8422acbb046d7a.jpg'),
(29296, 2006, 'Lei & Ordem: Crimes Premeditados S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/112908.mp4', 'http://timg.bdta.pro/images/bb3e270110f2166e47862c710a3058a3.jpg'),
(29297, 2006, 'Lei & Ordem: Crimes Premeditados S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/112909.mp4', 'http://timg.bdta.pro/images/6ffed3b54e60928cee2ea6ca1a87f26b.jpg'),
(29298, 2006, 'Lei & Ordem: Crimes Premeditados S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/112910.mp4', 'http://timg.bdta.pro/images/7207852c0441da2fa57a37bda608e2f4.jpg'),
(29299, 2006, 'Lei & Ordem: Crimes Premeditados S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/112911.mp4', 'http://timg.bdta.pro/images/d4d9224238abd2374f7861d184cf2eda.jpg'),
(29300, 2006, 'Lei & Ordem: Crimes Premeditados S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/112912.mp4', 'http://timg.bdta.pro/images/6a67bc7e3cf5a0ee19b3e41dae6bfa4d.jpg'),
(29301, 2006, 'Lei & Ordem: Crimes Premeditados S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/112913.mp4', 'http://timg.bdta.pro/images/9694e7765d82798ac6ae3024f72b31ed.jpg'),
(29302, 2006, 'Lei & Ordem: Crimes Premeditados S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/112914.mp4', 'http://timg.bdta.pro/images/bd20a5db4782c638c5dc44de63364e94.jpg'),
(29303, 2006, 'Lei & Ordem: Crimes Premeditados S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/112915.mp4', 'http://timg.bdta.pro/images/a7338db8f25c87c16aecc8b32c3bbd91.jpg'),
(29304, 2006, 'Lei & Ordem: Crimes Premeditados S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/112916.mp4', 'http://timg.bdta.pro/images/3d10c0728a0c562f272667c13bb17d69.jpg'),
(29305, 2006, 'Lei & Ordem: Crimes Premeditados S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/112917.mp4', 'http://timg.bdta.pro/images/041d76f670e73f36fc78354ba7a1a39d.jpg'),
(29306, 2006, 'Lei & Ordem: Crimes Premeditados S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/112918.mp4', 'http://timg.bdta.pro/images/57208fef550cdc19dbad37471b4b4e70.jpg'),
(29307, 2007, 'Lei & Ordem: Crimes Premeditados S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/112919.mp4', 'http://timg.bdta.pro/images/45be33d54171177bcd8b44f90a8a1e28.jpg'),
(29308, 2007, 'Lei & Ordem: Crimes Premeditados S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/112920.mp4', 'http://timg.bdta.pro/images/0c06cc11e9937ead173f36670e29a7e1.jpg'),
(29309, 2007, 'Lei & Ordem: Crimes Premeditados S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/112921.mp4', 'http://timg.bdta.pro/images/7f41ed7494257eed7f5883dcadbb123e.jpg'),
(29310, 2007, 'Lei & Ordem: Crimes Premeditados S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/112922.mp4', 'http://timg.bdta.pro/images/d5e42cbbd4a2b1f06c23f4f0c8a6e442.jpg'),
(29311, 2007, 'Lei & Ordem: Crimes Premeditados S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/112923.mp4', 'http://timg.bdta.pro/images/97e7dfd89af73192a869f57a6e1edefa.jpg'),
(29312, 2007, 'Lei & Ordem: Crimes Premeditados S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/112924.mp4', 'http://timg.bdta.pro/images/f3506cf743683f3e8dc0fcb3dfa2c54e.jpg'),
(29313, 2007, 'Lei & Ordem: Crimes Premeditados S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/112925.mp4', 'http://timg.bdta.pro/images/810f95fb6dd8141cc883cad6a753a211.jpg'),
(29314, 2007, 'Lei & Ordem: Crimes Premeditados S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/112926.mp4', 'http://timg.bdta.pro/images/430536cbf5bf8a4804ff716c3d246553.jpg'),
(29315, 2007, 'Lei & Ordem: Crimes Premeditados S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/112927.mp4', 'http://timg.bdta.pro/images/03107f6a13760de40e5f9ce8ea959b5f.jpg'),
(29316, 2007, 'Lei & Ordem: Crimes Premeditados S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/112928.mp4', 'http://timg.bdta.pro/images/52fafaf92bfb4bb572a7b15186a49bca.jpg'),
(29317, 2007, 'Lei & Ordem: Crimes Premeditados S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/112929.mp4', 'http://timg.bdta.pro/images/4bd3ebeb96c1cdf1116a9247af68445e.jpg'),
(29318, 2007, 'Lei & Ordem: Crimes Premeditados S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/112930.mp4', 'http://timg.bdta.pro/images/cd8850e79ed27090d04716d472d03193.jpg'),
(29319, 2007, 'Lei & Ordem: Crimes Premeditados S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/112931.mp4', 'http://timg.bdta.pro/images/20761e6b30e88b43a4c23e93efec2b0b.jpg'),
(29320, 2007, 'Lei & Ordem: Crimes Premeditados S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/112932.mp4', 'http://timg.bdta.pro/images/6458d4d5cbce2005fb6a1564f493a91f.jpg'),
(29321, 2007, 'Lei & Ordem: Crimes Premeditados S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/112933.mp4', 'http://timg.bdta.pro/images/11a678945f656c76d6801e8e99db3ee1.jpg'),
(29322, 2007, 'Lei & Ordem: Crimes Premeditados S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/112934.mp4', 'http://timg.bdta.pro/images/9e40aa7fd95ede90031691ecc0c17c04.jpg'),
(29323, 2007, 'Lei & Ordem: Crimes Premeditados S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/112935.mp4', 'http://timg.bdta.pro/images/2ded3a0c97a18c393d1979b34d890d68.jpg'),
(29324, 2007, 'Lei & Ordem: Crimes Premeditados S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/112936.mp4', 'http://timg.bdta.pro/images/f50ec485e1d587f6a57414f97ffcb526.jpg'),
(29325, 2007, 'Lei & Ordem: Crimes Premeditados S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/112937.mp4', 'http://timg.bdta.pro/images/11959eb27c8f04a0d51d2a21cbc0f6ca.jpg'),
(29326, 2007, 'Lei & Ordem: Crimes Premeditados S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/112938.mp4', 'http://timg.bdta.pro/images/8b75581371b517fc0933f22273da61d4.jpg'),
(29327, 2007, 'Lei & Ordem: Crimes Premeditados S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/112939.mp4', 'http://timg.bdta.pro/images/130487afebd35331697022e1cb411fec.jpg'),
(29328, 2008, 'Lei & Ordem: Crimes Premeditados S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/112940.mp4', 'http://timg.bdta.pro/images/bb791b58bddb3ada35a42a851eeaa2ea.jpg'),
(29329, 2008, 'Lei & Ordem: Crimes Premeditados S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/112941.mp4', 'http://timg.bdta.pro/images/89eb1bec11f4aae1376d8e1cb1aa5712.jpg'),
(29330, 2008, 'Lei & Ordem: Crimes Premeditados S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/112942.mp4', 'http://timg.bdta.pro/images/7ed120b92c1ccb91b648f64c77003456.jpg'),
(29331, 2008, 'Lei & Ordem: Crimes Premeditados S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/112943.mp4', 'http://timg.bdta.pro/images/927bec587773e53efea170cb2107ede4.jpg'),
(29332, 2008, 'Lei & Ordem: Crimes Premeditados S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/112944.mp4', 'http://timg.bdta.pro/images/fe4afb7c1892a879f65e49b1cbda7810.jpg'),
(29333, 2008, 'Lei & Ordem: Crimes Premeditados S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/112945.mp4', 'http://timg.bdta.pro/images/578130e7a3d16eef4bfca24bbca6f62f.jpg'),
(29334, 2008, 'Lei & Ordem: Crimes Premeditados S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/112946.mp4', 'http://timg.bdta.pro/images/9a0ef8a50ce38a390e2d452f69b332aa.jpg'),
(29335, 2008, 'Lei & Ordem: Crimes Premeditados S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/112947.mp4', 'http://timg.bdta.pro/images/849461a967a6d09f16c237240b0034db.jpg'),
(29336, 2008, 'Lei & Ordem: Crimes Premeditados S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/112948.mp4', 'http://timg.bdta.pro/images/9c94d314d9aa625b3872429e09ee1a40.jpg'),
(29337, 2008, 'Lei & Ordem: Crimes Premeditados S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/112949.mp4', 'http://timg.bdta.pro/images/84066d1f1c7e54cc8e5c9155e1d984db.jpg'),
(29338, 2008, 'Lei & Ordem: Crimes Premeditados S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/112950.mp4', 'http://timg.bdta.pro/images/f40ba86087cec968c68e4140a4ab12f5.jpg'),
(29339, 2008, 'Lei & Ordem: Crimes Premeditados S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/112951.mp4', 'http://timg.bdta.pro/images/5ec87cf7af1cca56fdc3d913300f3bf3.jpg'),
(29340, 2008, 'Lei & Ordem: Crimes Premeditados S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/112952.mp4', 'http://timg.bdta.pro/images/6564bb06c2ec78a0276a0e179d95c787.jpg'),
(29341, 2008, 'Lei & Ordem: Crimes Premeditados S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/112953.mp4', 'http://timg.bdta.pro/images/8e9768476801fd8cbfc31d0de5130d8f.jpg'),
(29342, 2008, 'Lei & Ordem: Crimes Premeditados S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/112954.mp4', 'http://timg.bdta.pro/images/24432f90701f200a08d37e097a7b3698.jpg'),
(29343, 2008, 'Lei & Ordem: Crimes Premeditados S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/112955.mp4', 'http://timg.bdta.pro/images/fbb9582fb3dca49738e43ab7212c4556.jpg'),
(29344, 2008, 'Lei & Ordem: Crimes Premeditados S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/112956.mp4', 'http://timg.bdta.pro/images/34464b6ff9983305d8a9e6f259799c1e.jpg'),
(29345, 2008, 'Lei & Ordem: Crimes Premeditados S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/112957.mp4', 'http://timg.bdta.pro/images/5f9935b418aefc19a622fecb9f5fb25f.jpg'),
(29346, 2008, 'Lei & Ordem: Crimes Premeditados S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/112958.mp4', 'http://timg.bdta.pro/images/74e2b507910f2a56848d5a4fd5a00d5c.jpg'),
(29347, 2008, 'Lei & Ordem: Crimes Premeditados S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/112959.mp4', 'http://timg.bdta.pro/images/9e5dfa79667f422318dc6df9c38c67d1.jpg'),
(29348, 2008, 'Lei & Ordem: Crimes Premeditados S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/112960.mp4', 'http://timg.bdta.pro/images/f6559507e7ca6f8917dea9d2e4afa1c0.jpg'),
(29349, 2008, 'Lei & Ordem: Crimes Premeditados S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/112961.mp4', 'http://timg.bdta.pro/images/318de50c6d65df252cc650d514165532.jpg'),
(29350, 2008, 'Lei & Ordem: Crimes Premeditados S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/112962.mp4', 'http://timg.bdta.pro/images/90c86bf99471d6fe116cde116113c097.jpg'),
(29351, 2009, 'Lei & Ordem: Crimes Premeditados S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/112963.mp4', 'http://timg.bdta.pro/images/8924d756980ccdcc0acb2e560ac8e6b0.jpg'),
(29352, 2009, 'Lei & Ordem: Crimes Premeditados S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/112964.mp4', 'http://timg.bdta.pro/images/0b91dd6f8ed784c6a90f6ad7d2f5d6cd.jpg'),
(29353, 2009, 'Lei & Ordem: Crimes Premeditados S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/112965.mp4', 'http://timg.bdta.pro/images/88c170c30d4be266e1ca5c309a6e6474.jpg'),
(29354, 2009, 'Lei & Ordem: Crimes Premeditados S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/112966.mp4', 'http://timg.bdta.pro/images/31f743db825eec7e495de43779f5c507.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(29355, 2009, 'Lei & Ordem: Crimes Premeditados S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/112967.mp4', 'http://timg.bdta.pro/images/ce9fad0225032b7db2a1d33edc7771cf.jpg'),
(29356, 2009, 'Lei & Ordem: Crimes Premeditados S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/112968.mp4', 'http://timg.bdta.pro/images/4ad2fd1b0e3520be56b12a0667a413b2.jpg'),
(29357, 2009, 'Lei & Ordem: Crimes Premeditados S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/112969.mp4', 'http://timg.bdta.pro/images/d41c83318ce0ed8c4e9e4818a1ab829a.jpg'),
(29358, 2009, 'Lei & Ordem: Crimes Premeditados S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/112970.mp4', 'http://timg.bdta.pro/images/b42cc00dcf1690dd9a82cad21ac91565.jpg'),
(29359, 2009, 'Lei & Ordem: Crimes Premeditados S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/112971.mp4', 'http://timg.bdta.pro/images/cac3192bb26c8f6f0c72eb4c684cee69.jpg'),
(29360, 2009, 'Lei & Ordem: Crimes Premeditados S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/112972.mp4', 'http://timg.bdta.pro/images/72216f23a0d63837344e7fe5d3b15a09.jpg'),
(29361, 2009, 'Lei & Ordem: Crimes Premeditados S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/112973.mp4', 'http://timg.bdta.pro/images/dbe8ce4c72440c2aa3fe6a7e95c3e688.jpg'),
(29362, 2009, 'Lei & Ordem: Crimes Premeditados S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/112974.mp4', 'http://timg.bdta.pro/images/510f8344ca627eb3048570b0b5f2e1af.jpg'),
(29363, 2009, 'Lei & Ordem: Crimes Premeditados S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/112975.mp4', 'http://timg.bdta.pro/images/70d21022f6c051a77ac31a313be31795.jpg'),
(29364, 2009, 'Lei & Ordem: Crimes Premeditados S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/112976.mp4', 'http://timg.bdta.pro/images/cf2f70d0a4d35830b6f965947ba2cc1f.jpg'),
(29365, 2009, 'Lei & Ordem: Crimes Premeditados S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/112977.mp4', 'http://timg.bdta.pro/images/69f6fecc1657c6c5c95be7846b9543c7.jpg'),
(29366, 2009, 'Lei & Ordem: Crimes Premeditados S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/112978.mp4', 'http://timg.bdta.pro/images/63df34c38ba408f7d2de2663edcc91f4.jpg'),
(29367, 2009, 'Lei & Ordem: Crimes Premeditados S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/541930.mp4', 'http://gstaticontent.com/images/3b9787df61249a64386b820b86034099.jpg'),
(29368, 2009, 'Lei & Ordem: Crimes Premeditados S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/541932.mp4', 'http://gstaticontent.com/images/c8e57decb67c7e17455c41f01a3b4476.jpg'),
(29369, 2009, 'Lei & Ordem: Crimes Premeditados S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/541934.mp4', 'http://gstaticontent.com/images/ec462ca36e1dab2f32975c58a5635876.jpg'),
(29370, 2009, 'Lei & Ordem: Crimes Premeditados S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/541936.mp4', 'http://gstaticontent.com/images/ea1830cc30b01116e05fcf97a70096cc.jpg'),
(29371, 2009, 'Lei & Ordem: Crimes Premeditados S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/541938.mp4', 'http://gstaticontent.com/images/c493d3faa538e2b578a1efbfa81e31aa.jpg'),
(29372, 2010, 'Lei & Ordem: Crimes Premeditados S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/112989.mp4', 'http://timg.bdta.pro/images/c400c36763c72ef1cbb12ce10fdcf4ca.jpg'),
(29373, 2010, 'Lei & Ordem: Crimes Premeditados S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/112990.mp4', 'http://timg.bdta.pro/images/61c206af2f8af5bd7d1d92d43f44fb60.jpg'),
(29374, 2010, 'Lei & Ordem: Crimes Premeditados S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/112991.mp4', 'http://timg.bdta.pro/images/0d187356231c6fc0207035d394b85ad5.jpg'),
(29375, 2010, 'Lei & Ordem: Crimes Premeditados S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/112992.mp4', 'http://timg.bdta.pro/images/4a4df3493f0ce9ef62472f9c14a190ad.jpg'),
(29376, 2010, 'Lei & Ordem: Crimes Premeditados S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/112993.mp4', 'http://timg.bdta.pro/images/78777d820dbaa9e10aae2a07e3dc910f.jpg'),
(29377, 2010, 'Lei & Ordem: Crimes Premeditados S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/112994.mp4', 'http://timg.bdta.pro/images/382d3a8497900fd7c62b5b63ab110397.jpg'),
(29378, 2010, 'Lei & Ordem: Crimes Premeditados S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/112995.mp4', 'http://timg.bdta.pro/images/3fd4151bdee7199abb2ad407ea6ea53d.jpg'),
(29379, 2010, 'Lei & Ordem: Crimes Premeditados S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/112996.mp4', 'http://timg.bdta.pro/images/d010057ae28599a0d5af0c57396be0a0.jpg'),
(29380, 2010, 'Lei & Ordem: Crimes Premeditados S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/112997.mp4', 'http://timg.bdta.pro/images/6543465b0a0c8c974f4cd84d7b9ff238.jpg'),
(29381, 2010, 'Lei & Ordem: Crimes Premeditados S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/112998.mp4', 'http://timg.bdta.pro/images/6c6f93ccb9d06655330e11aef32bf542.jpg'),
(29382, 2010, 'Lei & Ordem: Crimes Premeditados S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/112999.mp4', 'http://timg.bdta.pro/images/fab5fe6af52e9fa56381187511185d3d.jpg'),
(29383, 2010, 'Lei & Ordem: Crimes Premeditados S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113000.mp4', 'http://timg.bdta.pro/images/5a35e3113d1d78e3b5393c36941f345f.jpg'),
(29384, 2010, 'Lei & Ordem: Crimes Premeditados S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113001.mp4', 'http://timg.bdta.pro/images/8450d858347b51a3fdaf4e2331fa7de9.jpg'),
(29385, 2010, 'Lei & Ordem: Crimes Premeditados S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113002.mp4', 'http://timg.bdta.pro/images/2a558ed49a2e31745a9003b160e4aa1e.jpg'),
(29386, 2010, 'Lei & Ordem: Crimes Premeditados S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113003.mp4', 'http://timg.bdta.pro/images/b278d17d922b8b5c95cc41385dc13a1c.jpg'),
(29387, 2010, 'Lei & Ordem: Crimes Premeditados S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113004.mp4', 'http://timg.bdta.pro/images/79c48ee4df076136f1cb7fb7353ce7eb.jpg'),
(29388, 2010, 'Lei & Ordem: Crimes Premeditados S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113005.mp4', 'http://timg.bdta.pro/images/2337567e7bab47ae44aca67508d32d89.jpg'),
(29389, 2010, 'Lei & Ordem: Crimes Premeditados S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113006.mp4', 'http://timg.bdta.pro/images/57bf3c860b1660da3017fe44532b248e.jpg'),
(29390, 2010, 'Lei & Ordem: Crimes Premeditados S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113007.mp4', 'http://timg.bdta.pro/images/d1ed2f92549642fe2bdde70d46a1944f.jpg'),
(29391, 2010, 'Lei & Ordem: Crimes Premeditados S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/113008.mp4', 'http://timg.bdta.pro/images/ba228444b5ff72579572314eab8e3eb9.jpg'),
(29392, 2010, 'Lei & Ordem: Crimes Premeditados S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/113009.mp4', 'http://timg.bdta.pro/images/f1d802b89d8153124ad27ee9571de388.jpg'),
(29393, 2010, 'Lei & Ordem: Crimes Premeditados S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/113010.mp4', 'http://timg.bdta.pro/images/5c8fd48e88162825141850e309d54b81.jpg'),
(29394, 2011, 'Lei & Ordem: Crimes Premeditados S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113011.mp4', 'http://timg.bdta.pro/images/af3261746bc8f14903c2f5bf05357c71.jpg'),
(29395, 2011, 'Lei & Ordem: Crimes Premeditados S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113012.mp4', 'http://timg.bdta.pro/images/ab3abf6c253cb42fc46095e6f82c6a98.jpg'),
(29396, 2011, 'Lei & Ordem: Crimes Premeditados S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113013.mp4', 'http://timg.bdta.pro/images/409ca0005ad5356d1176f281f89a0e76.jpg'),
(29397, 2011, 'Lei & Ordem: Crimes Premeditados S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113014.mp4', 'http://timg.bdta.pro/images/4be54138c9aa28c8482ddd66c007d141.jpg'),
(29398, 2011, 'Lei & Ordem: Crimes Premeditados S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113015.mp4', 'http://timg.bdta.pro/images/de751d4d7ddf14f03adf892db2ddf9b8.jpg'),
(29399, 2011, 'Lei & Ordem: Crimes Premeditados S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113016.mp4', 'http://timg.bdta.pro/images/ab82bba4b4c0679e48645607f7387084.jpg'),
(29400, 2011, 'Lei & Ordem: Crimes Premeditados S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113017.mp4', 'http://timg.bdta.pro/images/a1f1145a06de35f637f26910d2f9c46a.jpg'),
(29401, 2011, 'Lei & Ordem: Crimes Premeditados S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113018.mp4', 'http://timg.bdta.pro/images/12ecc0db1fc91dc52d12a41028fe1bd0.jpg'),
(29402, 2011, 'Lei & Ordem: Crimes Premeditados S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113019.mp4', 'http://timg.bdta.pro/images/8155260acb47f1fbbcea32b9e84d71bb.jpg'),
(29403, 2011, 'Lei & Ordem: Crimes Premeditados S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113020.mp4', 'http://timg.bdta.pro/images/6891deaf16fd98e9d7ec14bd656a8d2d.jpg'),
(29404, 2011, 'Lei & Ordem: Crimes Premeditados S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113021.mp4', 'http://timg.bdta.pro/images/6569609e15680dceafb6423e58982844.jpg'),
(29405, 2011, 'Lei & Ordem: Crimes Premeditados S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113022.mp4', 'http://timg.bdta.pro/images/eb2083d5bf4969ab6142564b8e206c58.jpg'),
(29406, 2011, 'Lei & Ordem: Crimes Premeditados S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113023.mp4', 'http://timg.bdta.pro/images/2a967d89c2863d3d5bde10ad9084b9e1.jpg'),
(29407, 2011, 'Lei & Ordem: Crimes Premeditados S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113024.mp4', 'http://timg.bdta.pro/images/bfbba25df4e9982ce848ed1293c0a700.jpg'),
(29408, 2011, 'Lei & Ordem: Crimes Premeditados S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113025.mp4', 'http://timg.bdta.pro/images/37c18b598d68df279892ccbf43669c74.jpg'),
(29409, 2011, 'Lei & Ordem: Crimes Premeditados S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113026.mp4', 'http://timg.bdta.pro/images/b94b1fc50899abe662d0f1ce3d1db98e.jpg'),
(29410, 2011, 'Lei & Ordem: Crimes Premeditados S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113027.mp4', 'http://timg.bdta.pro/images/79bd6e11680553d7eeb7d2c8e6d87180.jpg'),
(29411, 2011, 'Lei & Ordem: Crimes Premeditados S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113028.mp4', 'http://timg.bdta.pro/images/272fadba3c0d586e3ab413b67177352b.jpg'),
(29412, 2011, 'Lei & Ordem: Crimes Premeditados S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113029.mp4', 'http://timg.bdta.pro/images/afef86f53c0b7f372fc097cd4d742039.jpg'),
(29413, 2011, 'Lei & Ordem: Crimes Premeditados S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/113030.mp4', 'http://timg.bdta.pro/images/3c54fa36585c43ce163a2a3a7d814ffd.jpg'),
(29414, 2012, 'Lei & Ordem: Crimes Premeditados S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113031.mp4', 'http://timg.bdta.pro/images/88838e76f975b268c1d052f5dce87eaf.jpg'),
(29415, 2012, 'Lei & Ordem: Crimes Premeditados S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113032.mp4', 'http://timg.bdta.pro/images/a63790ad5563adb045e630b8d3f0a485.jpg'),
(29416, 2012, 'Lei & Ordem: Crimes Premeditados S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113033.mp4', 'http://timg.bdta.pro/images/bf06ca9af1ffe327b33515e081e5ed00.jpg'),
(29417, 2012, 'Lei & Ordem: Crimes Premeditados S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113034.mp4', 'http://timg.bdta.pro/images/f3aaeee8da36718998ced5375f232d67.jpg'),
(29418, 2012, 'Lei & Ordem: Crimes Premeditados S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113035.mp4', 'http://timg.bdta.pro/images/c6b51d90fd77d5029e27702ff5c29687.jpg'),
(29419, 2012, 'Lei & Ordem: Crimes Premeditados S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113036.mp4', 'http://timg.bdta.pro/images/599cdd2010fa488e620ee1773ce09b6e.jpg'),
(29420, 2012, 'Lei & Ordem: Crimes Premeditados S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113037.mp4', 'http://timg.bdta.pro/images/69dac4a1f6559f7eb5401b9954102dcb.jpg'),
(29421, 2012, 'Lei & Ordem: Crimes Premeditados S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113038.mp4', 'http://timg.bdta.pro/images/f8101f43c56a731a63240b2db1c1c798.jpg'),
(29422, 2012, 'Lei & Ordem: Crimes Premeditados S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113039.mp4', 'http://timg.bdta.pro/images/871302de91caaf0c1bdff6b4fb6c3444.jpg'),
(29423, 2012, 'Lei & Ordem: Crimes Premeditados S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113040.mp4', 'http://timg.bdta.pro/images/5cedd066bea1161642754401cfe26bb4.jpg'),
(29424, 2012, 'Lei & Ordem: Crimes Premeditados S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113041.mp4', 'http://timg.bdta.pro/images/0165c3832560cc2fcc22fbaa0fa5e476.jpg'),
(29425, 2012, 'Lei & Ordem: Crimes Premeditados S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113042.mp4', 'http://timg.bdta.pro/images/7cc844618ff73edb2bba52605dd89193.jpg'),
(29426, 2012, 'Lei & Ordem: Crimes Premeditados S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113043.mp4', 'http://timg.bdta.pro/images/6f2ba5a419e90e6732a27b65a5289e42.jpg'),
(29427, 2012, 'Lei & Ordem: Crimes Premeditados S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113044.mp4', 'http://timg.bdta.pro/images/64b2b2f9296ec2466c61b26eb1f6cc22.jpg'),
(29428, 2012, 'Lei & Ordem: Crimes Premeditados S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113045.mp4', 'http://timg.bdta.pro/images/b338acda191a625244dc6be5b1c7bd3b.jpg'),
(29429, 2013, 'Lei & Ordem: Crimes Premeditados S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113046.mp4', 'http://timg.bdta.pro/images/c377bf0fccb2473a1a67707b39eb7e2a.jpg'),
(29430, 2013, 'Lei & Ordem: Crimes Premeditados S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113047.mp4', 'http://gstaticontent.com/images/xMxeq0IMQsuyJ4itzUS0WAh9Ukh_big.jpg'),
(29431, 2013, 'Lei & Ordem: Crimes Premeditados S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113048.mp4', 'http://timg.bdta.pro/images/0ac0f71300911126a9374115853b0f9d.jpg'),
(29432, 2013, 'Lei & Ordem: Crimes Premeditados S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113049.mp4', 'http://timg.bdta.pro/images/483c55f586f3f68efbb25c851432ce2c.jpg'),
(29433, 2013, 'Lei & Ordem: Crimes Premeditados S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113050.mp4', 'http://timg.bdta.pro/images/7434dd0b27abc6d4d6106fb3e3449b65.jpg'),
(29434, 2013, 'Lei & Ordem: Crimes Premeditados S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113051.mp4', 'http://gstaticontent.com/images/xMxeq0IMQsuyJ4itzUS0WAh9Ukh_big.jpg'),
(29435, 2013, 'Lei & Ordem: Crimes Premeditados S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113052.mp4', 'http://gstaticontent.com/images/xMxeq0IMQsuyJ4itzUS0WAh9Ukh_big.jpg'),
(29436, 2013, 'Lei & Ordem: Crimes Premeditados S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113053.mp4', 'http://timg.bdta.pro/images/bee30f71d2f0da62fe81899a8d7b1474.jpg'),
(29437, 2013, 'Lei & Ordem: Crimes Premeditados S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113054.mp4', 'http://gstaticontent.com/images/xMxeq0IMQsuyJ4itzUS0WAh9Ukh_big.jpg'),
(29438, 2013, 'Lei & Ordem: Crimes Premeditados S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113055.mp4', 'http://timg.bdta.pro/images/ed18dd2a256336a4db83dfc5a134f776.jpg'),
(29439, 2013, 'Lei & Ordem: Crimes Premeditados S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113056.mp4', 'http://timg.bdta.pro/images/732c5e34e5bb0a9b3cca6791f6dcef6c.jpg'),
(29440, 2013, 'Lei & Ordem: Crimes Premeditados S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113057.mp4', 'http://timg.bdta.pro/images/5f49f86c30d030620a0af80a80b1bdbf.jpg'),
(29441, 2013, 'Lei & Ordem: Crimes Premeditados S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113058.mp4', 'http://timg.bdta.pro/images/cb8da5433a6805cb2ef2fe4cd4a62c0a.jpg'),
(29442, 2013, 'Lei & Ordem: Crimes Premeditados S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113059.mp4', 'http://gstaticontent.com/images/xMxeq0IMQsuyJ4itzUS0WAh9Ukh_big.jpg'),
(29443, 2013, 'Lei & Ordem: Crimes Premeditados S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113060.mp4', 'http://timg.bdta.pro/images/e9ca6f53622217ea4bfe810ee74d5b1b.jpg'),
(29444, 2013, 'Lei & Ordem: Crimes Premeditados S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113061.mp4', 'http://gstaticontent.com/images/xMxeq0IMQsuyJ4itzUS0WAh9Ukh_big.jpg'),
(29445, 2014, 'Lei & Ordem: Crimes Premeditados S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113062.mp4', 'http://gstaticontent.com/images/xMxeq0IMQsuyJ4itzUS0WAh9Ukh_big.jpg'),
(29446, 2014, 'Lei & Ordem: Crimes Premeditados S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113063.mp4', 'http://timg.bdta.pro/images/01d2eab0a66c828a60d710f6ed59a9d4.jpg'),
(29447, 2014, 'Lei & Ordem: Crimes Premeditados S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113064.mp4', 'http://timg.bdta.pro/images/4247fde911ef7536724f74d2c1201a67.jpg'),
(29448, 2014, 'Lei & Ordem: Crimes Premeditados S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113065.mp4', 'http://gstaticontent.com/images/xMxeq0IMQsuyJ4itzUS0WAh9Ukh_big.jpg'),
(29449, 2014, 'Lei & Ordem: Crimes Premeditados S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113066.mp4', 'http://timg.bdta.pro/images/e7ba923440f0aa25b71cd80d09253098.jpg'),
(29450, 2014, 'Lei & Ordem: Crimes Premeditados S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113067.mp4', 'http://gstaticontent.com/images/xMxeq0IMQsuyJ4itzUS0WAh9Ukh_big.jpg'),
(29451, 2014, 'Lei & Ordem: Crimes Premeditados S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113068.mp4', 'http://gstaticontent.com/images/xMxeq0IMQsuyJ4itzUS0WAh9Ukh_big.jpg'),
(29452, 2014, 'Lei & Ordem: Crimes Premeditados S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113069.mp4', 'http://gstaticontent.com/images/xMxeq0IMQsuyJ4itzUS0WAh9Ukh_big.jpg'),
(29453, 2015, 'Lincoln Rhyme: A Caçada pelo Colecionador de Ossos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124523.mp4', 'http://timg.bdta.pro/images/767dbf0596cbaa7eba614646f868a60d.jpg'),
(29454, 2015, 'Lincoln Rhyme: A Caçada pelo Colecionador de Ossos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124524.mp4', 'http://timg.bdta.pro/images/d251d848cd85412e67e99cb221bc32d8.jpg'),
(29455, 2015, 'Lincoln Rhyme: A Caçada pelo Colecionador de Ossos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124525.mp4', 'http://timg.bdta.pro/images/bc99b11725ab9e6b03d188e9d40e648d.jpg'),
(29456, 2015, 'Lincoln Rhyme: A Caçada pelo Colecionador de Ossos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124526.mp4', 'http://timg.bdta.pro/images/b7871bb334507e2ea8f55b5315062350.jpg'),
(29457, 2015, 'Lincoln Rhyme: A Caçada pelo Colecionador de Ossos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124527.mp4', 'http://timg.bdta.pro/images/7a6a1e76ad99b8c5c0f8973deae19cdf.jpg'),
(29458, 2015, 'Lincoln Rhyme: A Caçada pelo Colecionador de Ossos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124528.mp4', 'http://timg.bdta.pro/images/3f5e0993346e016a2ce102d49eeba868.jpg'),
(29459, 2015, 'Lincoln Rhyme: A Caçada pelo Colecionador de Ossos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124529.mp4', 'http://timg.bdta.pro/images/fdf9fd7ab83923bb7bc78153567e6b7c.jpg'),
(29460, 2015, 'Lincoln Rhyme: A Caçada pelo Colecionador de Ossos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124530.mp4', 'http://timg.bdta.pro/images/7d2d6070e265efb3b6d6d89b6ac25780.jpg'),
(29461, 2015, 'Lincoln Rhyme: A Caçada pelo Colecionador de Ossos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124531.mp4', 'http://timg.bdta.pro/images/78380d3615888b4e6c1bac3462f8b00d.jpg'),
(29462, 2015, 'Lincoln Rhyme: A Caçada pelo Colecionador de Ossos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124532.mp4', 'http://timg.bdta.pro/images/f87ba530603e281716a57d0962b66651.jpg'),
(29463, 2016, 'Texas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114651.mp4', 'http://timg.bdta.pro/images/9ddc3169c7d3212b25c94aa0792968af.jpg'),
(29464, 2016, 'Texas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114652.mp4', 'http://timg.bdta.pro/images/8523123780cf25fbf06bfe9fd8fa1baf.jpg'),
(29465, 2016, 'Texas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114653.mp4', 'http://timg.bdta.pro/images/e6a51403ff09029be53d5b19c59089da.jpg'),
(29466, 2016, 'Texas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114654.mp4', 'http://timg.bdta.pro/images/906c3486c2f55da8d29bbe1d6a722993.jpg'),
(29467, 2016, 'Texas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114655.mp4', 'http://timg.bdta.pro/images/8e873875a4398ad8bed90f151e4162dd.jpg'),
(29468, 2016, 'Texas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114656.mp4', 'http://timg.bdta.pro/images/de65be05ca495e99a87bfc1e23422ae2.jpg'),
(29469, 2016, 'Texas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114657.mp4', 'http://timg.bdta.pro/images/5ad01bbeee98a88bc9f5da9b10124a71.jpg'),
(29470, 2016, 'Texas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114658.mp4', 'http://timg.bdta.pro/images/157c56ea41bd5180960b220c551309aa.jpg'),
(29471, 2016, 'Texas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114659.mp4', 'http://timg.bdta.pro/images/65f7983b981f559169e1d1711150920c.jpg'),
(29472, 2016, 'Texas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114660.mp4', 'http://timg.bdta.pro/images/eb291ade32d0b8079e75e0bd458bf010.jpg'),
(29473, 2017, 'Texas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114661.mp4', 'http://timg.bdta.pro/images/a8daf83ebea5e891a396e880c7d18eb0.jpg'),
(29474, 2017, 'Texas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114662.mp4', 'http://timg.bdta.pro/images/be3d55e518da64e32074d773f5335006.jpg'),
(29475, 2017, 'Texas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114663.mp4', 'http://timg.bdta.pro/images/71d846d94d912065bf1f4fcac0a7bdf8.jpg'),
(29476, 2017, 'Texas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114664.mp4', 'http://timg.bdta.pro/images/dd0e09e2a5577996d2292e72eaa6dcd7.jpg'),
(29477, 2017, 'Texas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114665.mp4', 'http://timg.bdta.pro/images/862331d22582da81ec64cda2ee7c56d7.jpg'),
(29478, 2017, 'Texas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114666.mp4', 'http://timg.bdta.pro/images/cba3f43bce16cfdc4a8a7bfc723f8fed.jpg'),
(29479, 2017, 'Texas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114667.mp4', 'http://timg.bdta.pro/images/7bf778104adbf7c6d45ca171a98266b8.jpg'),
(29480, 2017, 'Texas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114668.mp4', 'http://timg.bdta.pro/images/47215d9db42751234103c1bf7d68cad0.jpg'),
(29481, 2017, 'Texas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114669.mp4', 'http://timg.bdta.pro/images/e5467f81d64d333c96c91401852a8d6b.jpg'),
(29482, 2018, 'Pacto de Sangue S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114643.mp4', 'http://gstaticontent.com/images/rei0mmhl2wIFi18UjsQMagQIoqO_big.jpg'),
(29483, 2018, 'Pacto de Sangue S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114644.mp4', 'http://gstaticontent.com/images/rei0mmhl2wIFi18UjsQMagQIoqO_big.jpg'),
(29484, 2018, 'Pacto de Sangue S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114645.mp4', 'http://gstaticontent.com/images/rei0mmhl2wIFi18UjsQMagQIoqO_big.jpg'),
(29485, 2018, 'Pacto de Sangue S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114646.mp4', 'http://gstaticontent.com/images/rei0mmhl2wIFi18UjsQMagQIoqO_big.jpg'),
(29486, 2018, 'Pacto de Sangue S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114647.mp4', 'http://gstaticontent.com/images/rei0mmhl2wIFi18UjsQMagQIoqO_big.jpg'),
(29487, 2018, 'Pacto de Sangue S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114648.mp4', 'http://gstaticontent.com/images/rei0mmhl2wIFi18UjsQMagQIoqO_big.jpg'),
(29488, 2018, 'Pacto de Sangue S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114649.mp4', 'http://gstaticontent.com/images/rei0mmhl2wIFi18UjsQMagQIoqO_big.jpg'),
(29489, 2018, 'Pacto de Sangue S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114650.mp4', 'http://gstaticontent.com/images/rei0mmhl2wIFi18UjsQMagQIoqO_big.jpg'),
(29490, 2019, 'Sangue e Água S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200857.mp4', 'http://gstaticontent.com/images/jzhVUKDIX0fikdDOyRYjdTDyUcu_big.jpg'),
(29491, 2019, 'Sangue e Água S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200858.mp4', 'http://gstaticontent.com/images/jzhVUKDIX0fikdDOyRYjdTDyUcu_big.jpg'),
(29492, 2019, 'Sangue e Água S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200859.mp4', 'http://gstaticontent.com/images/jzhVUKDIX0fikdDOyRYjdTDyUcu_big.jpg'),
(29493, 2019, 'Sangue e Água S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200860.mp4', 'http://gstaticontent.com/images/jzhVUKDIX0fikdDOyRYjdTDyUcu_big.jpg'),
(29494, 2019, 'Sangue e Água S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200861.mp4', 'http://gstaticontent.com/images/jzhVUKDIX0fikdDOyRYjdTDyUcu_big.jpg'),
(29495, 2019, 'Sangue e Água S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200862.mp4', 'http://gstaticontent.com/images/jzhVUKDIX0fikdDOyRYjdTDyUcu_big.jpg'),
(29496, 2020, 'Sangue e Água S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7qqvyfjE3VOAuKqsavcro0iARx3.jpg'),
(29497, 2020, 'Sangue e Água S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hjr1yJG0XToDK7q3KXmv3jCCtas.jpg'),
(29498, 2020, 'Sangue e Água S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2SeezYhYZ0kF5aTob5BNr2d3VQe.jpg'),
(29499, 2020, 'Sangue e Água S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nECzA8uhpN5VVvynzUnmc0mmEvq.jpg'),
(29500, 2020, 'Sangue e Água S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2goEXP36vR9TICV9sfEjbgpSGPc.jpg'),
(29501, 2020, 'Sangue e Água S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fP0SxjPHZBT7SAUNXpZOzuV4uF.jpg'),
(29502, 2020, 'Sangue e Água S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHS9sSZWgKQeirJW2KGJMor61xp.jpg'),
(29503, 2021, 'Sangue e Água S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/819yqJm8yErCOtJvG3LHsSbkWSo.jpg'),
(29504, 2021, 'Sangue e Água S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uPcLNrxWgfZY6KkemRIqP77CuqU.jpg'),
(29505, 2021, 'Sangue e Água S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k8ZmsHyCvAzhitScoIg31Armx0x.jpg'),
(29506, 2021, 'Sangue e Água S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8piIGtseU4p6dZ07NGuq1L9OSXk.jpg'),
(29507, 2021, 'Sangue e Água S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/geBST3FylQRoRUyk5SvEYwxs08t.jpg'),
(29508, 2021, 'Sangue e Água S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ykiJpnfxlo3ogsTCjcGKqcwXIUS.jpg'),
(29509, 2022, 'Sangue e Água S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/316489.mp4', 'http://gstaticontent.com/images/jzhVUKDIX0fikdDOyRYjdTDyUcu_big.jpg'),
(29510, 2022, 'Sangue e Água S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/316490.mp4', 'http://gstaticontent.com/images/jzhVUKDIX0fikdDOyRYjdTDyUcu_big.jpg'),
(29511, 2022, 'Sangue e Água S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/316491.mp4', 'http://gstaticontent.com/images/jzhVUKDIX0fikdDOyRYjdTDyUcu_big.jpg'),
(29512, 2022, 'Sangue e Água S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/316492.mp4', 'http://gstaticontent.com/images/jzhVUKDIX0fikdDOyRYjdTDyUcu_big.jpg'),
(29513, 2022, 'Sangue e Água S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/316493.mp4', 'http://gstaticontent.com/images/jzhVUKDIX0fikdDOyRYjdTDyUcu_big.jpg'),
(29514, 2022, 'Sangue e Água S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/316494.mp4', 'http://gstaticontent.com/images/jzhVUKDIX0fikdDOyRYjdTDyUcu_big.jpg'),
(29515, 2023, 'Solar Opposites [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114635.mp4', 'http://timg.bdta.pro/images/f85fb0548adc6f7134f8a86e18a8bf3b.jpg'),
(29516, 2023, 'Solar Opposites [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114636.mp4', 'http://timg.bdta.pro/images/613eb1e6f454a35e1744d8c3059298f7.jpg'),
(29517, 2023, 'Solar Opposites [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114637.mp4', 'http://timg.bdta.pro/images/7e9b9495fc06ce2773b122cfaeafc2c7.jpg'),
(29518, 2023, 'Solar Opposites [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114638.mp4', 'http://timg.bdta.pro/images/fc48afe494aed5ab0c8de91699fde3f3.jpg'),
(29519, 2023, 'Solar Opposites [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114639.mp4', 'http://timg.bdta.pro/images/4d02311631cdbd83af445d6460691b02.jpg'),
(29520, 2023, 'Solar Opposites [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114640.mp4', 'http://timg.bdta.pro/images/5558eb430ead686438a7a9aa7590d89b.jpg'),
(29521, 2023, 'Solar Opposites [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114641.mp4', 'http://timg.bdta.pro/images/0d0dc5897d6d9c95acb4a26a46fa4983.jpg'),
(29522, 2023, 'Solar Opposites [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114642.mp4', 'http://timg.bdta.pro/images/8de26338c06a30841562190b98509520.jpg'),
(29523, 2024, 'DC Super Hero Girls S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173433.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29524, 2024, 'DC Super Hero Girls S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173434.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29525, 2024, 'DC Super Hero Girls S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173435.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29526, 2024, 'DC Super Hero Girls S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173436.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29527, 2024, 'DC Super Hero Girls S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173437.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29528, 2024, 'DC Super Hero Girls S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173438.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29529, 2024, 'DC Super Hero Girls S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173439.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29530, 2024, 'DC Super Hero Girls S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173440.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29531, 2024, 'DC Super Hero Girls S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173441.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29532, 2024, 'DC Super Hero Girls S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173442.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29533, 2024, 'DC Super Hero Girls S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173443.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29534, 2024, 'DC Super Hero Girls S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173444.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29535, 2024, 'DC Super Hero Girls S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173445.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29536, 2024, 'DC Super Hero Girls S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/173446.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29537, 2024, 'DC Super Hero Girls S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/173447.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29538, 2024, 'DC Super Hero Girls S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/173448.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29539, 2024, 'DC Super Hero Girls S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/173449.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29540, 2024, 'DC Super Hero Girls S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/173450.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29541, 2024, 'DC Super Hero Girls S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/173451.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29542, 2024, 'DC Super Hero Girls S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/173452.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29543, 2024, 'DC Super Hero Girls S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/173453.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29544, 2024, 'DC Super Hero Girls S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/173454.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29545, 2024, 'DC Super Hero Girls S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/173455.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29546, 2024, 'DC Super Hero Girls S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/173456.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29547, 2024, 'DC Super Hero Girls S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/173457.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29548, 2024, 'DC Super Hero Girls S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/173458.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29549, 2024, 'DC Super Hero Girls S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/173459.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29550, 2024, 'DC Super Hero Girls S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/173460.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29551, 2024, 'DC Super Hero Girls S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/173461.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29552, 2024, 'DC Super Hero Girls S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/173462.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29553, 2024, 'DC Super Hero Girls S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/173463.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29554, 2024, 'DC Super Hero Girls S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/173464.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29555, 2024, 'DC Super Hero Girls S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/173465.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29556, 2024, 'DC Super Hero Girls S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/173466.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29557, 2024, 'DC Super Hero Girls S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/173467.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29558, 2024, 'DC Super Hero Girls S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/173468.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29559, 2024, 'DC Super Hero Girls S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/173469.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29560, 2024, 'DC Super Hero Girls S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/173470.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29561, 2024, 'DC Super Hero Girls S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/173471.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29562, 2024, 'DC Super Hero Girls S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/173472.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29563, 2024, 'DC Super Hero Girls S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/173473.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29564, 2024, 'DC Super Hero Girls S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/173474.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29565, 2024, 'DC Super Hero Girls S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/173475.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29566, 2024, 'DC Super Hero Girls S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/173476.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29567, 2024, 'DC Super Hero Girls S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/173477.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29568, 2024, 'DC Super Hero Girls S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/173478.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29569, 2024, 'DC Super Hero Girls S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/173479.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29570, 2024, 'DC Super Hero Girls S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/173480.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29571, 2024, 'DC Super Hero Girls S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/173481.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29572, 2024, 'DC Super Hero Girls S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/173482.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29573, 2024, 'DC Super Hero Girls S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/173483.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29574, 2024, 'DC Super Hero Girls S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/173484.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29575, 2025, 'DC Super Hero Girls S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173485.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29576, 2025, 'DC Super Hero Girls S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173486.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29577, 2025, 'DC Super Hero Girls S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173487.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29578, 2025, 'DC Super Hero Girls S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173488.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29579, 2025, 'DC Super Hero Girls S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173489.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29580, 2025, 'DC Super Hero Girls S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173490.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29581, 2025, 'DC Super Hero Girls S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173491.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29582, 2025, 'DC Super Hero Girls S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173492.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29583, 2025, 'DC Super Hero Girls S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173493.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29584, 2025, 'DC Super Hero Girls S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173494.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29585, 2025, 'DC Super Hero Girls S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173495.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29586, 2025, 'DC Super Hero Girls S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173496.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29587, 2025, 'DC Super Hero Girls S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173497.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29588, 2025, 'DC Super Hero Girls S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/173498.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29589, 2025, 'DC Super Hero Girls S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/173499.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29590, 2025, 'DC Super Hero Girls S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/173500.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29591, 2025, 'DC Super Hero Girls S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/173501.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29592, 2025, 'DC Super Hero Girls S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/173502.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29593, 2025, 'DC Super Hero Girls S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/173503.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29594, 2025, 'DC Super Hero Girls S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/173504.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29595, 2025, 'DC Super Hero Girls S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/173505.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29596, 2025, 'DC Super Hero Girls S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/173506.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29597, 2025, 'DC Super Hero Girls S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/173507.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29598, 2025, 'DC Super Hero Girls S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/173508.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29599, 2025, 'DC Super Hero Girls S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/173509.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29600, 2025, 'DC Super Hero Girls S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/173510.mp4', 'http://gstaticontent.com/images/xpOW4hlnkqlIXrjkUHUWPF3Hws2_big.jpg'),
(29601, 2026, 'The Good Fight S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114602.mp4', 'http://timg.bdta.pro/images/f1ac96f17bc23fb44f983d5930a23b59.jpg'),
(29602, 2026, 'The Good Fight S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114603.mp4', 'http://timg.bdta.pro/images/c61c2b29b07701027b66c00b52542bdb.jpg'),
(29603, 2026, 'The Good Fight S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114604.mp4', 'http://timg.bdta.pro/images/23953a61ded9d3a55abde6e7b53197cd.jpg'),
(29604, 2026, 'The Good Fight S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114605.mp4', 'http://timg.bdta.pro/images/9bd7831012f4b3d695f8d10e897bbb39.jpg'),
(29605, 2026, 'The Good Fight S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114606.mp4', 'http://timg.bdta.pro/images/448116879c05402a41b510ab37e0b971.jpg'),
(29606, 2026, 'The Good Fight S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114607.mp4', 'http://timg.bdta.pro/images/c3d55f7158e02a6b56c3ba999d872c34.jpg'),
(29607, 2026, 'The Good Fight S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114608.mp4', 'http://timg.bdta.pro/images/908b156240285ff5d6f64c362a7cda70.jpg'),
(29608, 2026, 'The Good Fight S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114609.mp4', 'http://timg.bdta.pro/images/74377d00b8f04b70da6ef99f6ed3ad23.jpg'),
(29609, 2026, 'The Good Fight S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114610.mp4', 'http://timg.bdta.pro/images/7b9801e1b082b4aa319e42cd6670772e.jpg'),
(29610, 2026, 'The Good Fight S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114611.mp4', 'http://timg.bdta.pro/images/0f2b3382202983810cd7d0ba969567df.jpg'),
(29611, 2027, 'The Good Fight S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114612.mp4', 'http://timg.bdta.pro/images/573d1ae82672f872b8f25f883ac0dd78.jpg'),
(29612, 2027, 'The Good Fight S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114613.mp4', 'http://timg.bdta.pro/images/41d737e7c89fe5e1e3a51fece5f89a1d.jpg'),
(29613, 2027, 'The Good Fight S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114614.mp4', 'http://timg.bdta.pro/images/1121b44a80e867b7f871f3a867744a09.jpg'),
(29614, 2027, 'The Good Fight S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114615.mp4', 'http://timg.bdta.pro/images/034b302467771a008f5bac8c33eaf650.jpg'),
(29615, 2027, 'The Good Fight S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114616.mp4', 'http://timg.bdta.pro/images/7f77517d4528ee48dce752527fb24095.jpg'),
(29616, 2027, 'The Good Fight S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114617.mp4', 'http://timg.bdta.pro/images/550cd659996f437d5fae35dfdf21d4f8.jpg'),
(29617, 2027, 'The Good Fight S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114618.mp4', 'http://timg.bdta.pro/images/1997dd7cc849c974931dbbf3ebcc0e58.jpg'),
(29618, 2027, 'The Good Fight S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114619.mp4', 'http://timg.bdta.pro/images/619109110560c9f98bd80b02ec8e0f24.jpg'),
(29619, 2027, 'The Good Fight S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114620.mp4', 'http://timg.bdta.pro/images/65d37b66747e5f9a93d67841b6be1dbb.jpg'),
(29620, 2027, 'The Good Fight S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114621.mp4', 'http://timg.bdta.pro/images/fb666e13dcf8e50353e85393f65350c7.jpg'),
(29621, 2027, 'The Good Fight S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114622.mp4', 'http://timg.bdta.pro/images/3b9c2de3fe87f7709c96be434eb1ca02.jpg'),
(29622, 2027, 'The Good Fight S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114623.mp4', 'http://timg.bdta.pro/images/5496de519f0ef9e8ff225ac4c9d49a25.jpg'),
(29623, 2027, 'The Good Fight S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114624.mp4', 'http://timg.bdta.pro/images/d5e4223c6522d395d4f98ae1f0410c5e.jpg'),
(29624, 2028, 'The Good Fight S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114625.mp4', 'http://timg.bdta.pro/images/e4ce190ce1a711e362ea24a15f1c5bbe.jpg'),
(29625, 2028, 'The Good Fight S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114626.mp4', 'http://timg.bdta.pro/images/aa87f73ce411a1472d925d1c0f138a1e.jpg'),
(29626, 2028, 'The Good Fight S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114627.mp4', 'http://timg.bdta.pro/images/e4eb04c18e267bb9400fc36687de00ee.jpg'),
(29627, 2028, 'The Good Fight S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114628.mp4', 'http://timg.bdta.pro/images/52fb8d562a0b15c8eda402d924b15a36.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(29628, 2028, 'The Good Fight S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114629.mp4', 'http://timg.bdta.pro/images/b44d3283ee2e7223e5f48de36b13753a.jpg'),
(29629, 2028, 'The Good Fight S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114630.mp4', 'http://timg.bdta.pro/images/f032a2c1b6eb98167d257b63d5fdc65e.jpg'),
(29630, 2028, 'The Good Fight S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114631.mp4', 'http://timg.bdta.pro/images/8a57319f499495a807f02c2065143cac.jpg'),
(29631, 2028, 'The Good Fight S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114632.mp4', 'http://timg.bdta.pro/images/ebfe0f5fd929821b0f97d667f704709a.jpg'),
(29632, 2028, 'The Good Fight S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114633.mp4', 'http://timg.bdta.pro/images/05bcab1b872acce5b01d93da652ed7ef.jpg'),
(29633, 2028, 'The Good Fight S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114634.mp4', 'http://timg.bdta.pro/images/8b19f05787ef8c2797b4a403074367ef.jpg'),
(29634, 2029, 'White Lines S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114592.mp4', 'http://timg.bdta.pro/images/8289a413755843dd397732bb54193684.jpg'),
(29635, 2029, 'White Lines S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114593.mp4', 'http://timg.bdta.pro/images/4ecbc159b1cf7749ff234f7af6015da0.jpg'),
(29636, 2029, 'White Lines S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114594.mp4', 'http://timg.bdta.pro/images/f7f986ce95550f7f24de5069c61854f6.jpg'),
(29637, 2029, 'White Lines S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114595.mp4', 'http://timg.bdta.pro/images/3cd3765e3bc1dad01c40a288f6fc3b55.jpg'),
(29638, 2029, 'White Lines S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114596.mp4', 'http://timg.bdta.pro/images/0fdc7c6e34d5bb6a3393dbb379c61517.jpg'),
(29639, 2029, 'White Lines S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114597.mp4', 'http://timg.bdta.pro/images/bfdba63857a7f702b3c74240ea879c6a.jpg'),
(29640, 2029, 'White Lines S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114598.mp4', 'http://timg.bdta.pro/images/d69df62f3b4e626fcb14986b8e1dfe98.jpg'),
(29641, 2029, 'White Lines S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114599.mp4', 'http://timg.bdta.pro/images/cf21d4c941e00292d5d196f15867d105.jpg'),
(29642, 2029, 'White Lines S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114600.mp4', 'http://gstaticontent.com/images/qjcfAOBI9KrySLAsGszEn81xEzn_big.jpg'),
(29643, 2029, 'White Lines S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114601.mp4', 'http://gstaticontent.com/images/qjcfAOBI9KrySLAsGszEn81xEzn_big.jpg'),
(29644, 2030, 'Wolf Creek S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114586.mp4', 'http://timg.bdta.pro/images/96f927a1c5e9f3b097d7b80b1bd08cee.jpg'),
(29645, 2030, 'Wolf Creek S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114587.mp4', 'http://timg.bdta.pro/images/482375f68ee9f2b7260d4b95ce917beb.jpg'),
(29646, 2030, 'Wolf Creek S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114588.mp4', 'http://timg.bdta.pro/images/bdc9a775531d8d657c694315c9d0ac5a.jpg'),
(29647, 2030, 'Wolf Creek S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114589.mp4', 'http://timg.bdta.pro/images/6a480130d0c95dde549be7a1649d37f9.jpg'),
(29648, 2030, 'Wolf Creek S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114590.mp4', 'http://timg.bdta.pro/images/ab8b10c803444577ee83f112ec9b8bd7.jpg'),
(29649, 2030, 'Wolf Creek S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114591.mp4', 'http://timg.bdta.pro/images/1baac973d4414d00ed865f16b6876b50.jpg'),
(29650, 2031, 'Três Metros Acima do Céu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181468.mp4', 'http://timg.bdta.pro/images/8289a413755843dd397732bb54193684.jpg'),
(29651, 2031, 'Três Metros Acima do Céu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181469.mp4', 'http://timg.bdta.pro/images/4ecbc159b1cf7749ff234f7af6015da0.jpg'),
(29652, 2031, 'Três Metros Acima do Céu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181470.mp4', 'http://timg.bdta.pro/images/f7f986ce95550f7f24de5069c61854f6.jpg'),
(29653, 2031, 'Três Metros Acima do Céu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181471.mp4', 'http://timg.bdta.pro/images/3cd3765e3bc1dad01c40a288f6fc3b55.jpg'),
(29654, 2031, 'Três Metros Acima do Céu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181472.mp4', 'http://timg.bdta.pro/images/0fdc7c6e34d5bb6a3393dbb379c61517.jpg'),
(29655, 2031, 'Três Metros Acima do Céu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181473.mp4', 'http://timg.bdta.pro/images/bfdba63857a7f702b3c74240ea879c6a.jpg'),
(29656, 2031, 'Três Metros Acima do Céu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181474.mp4', 'http://timg.bdta.pro/images/d69df62f3b4e626fcb14986b8e1dfe98.jpg'),
(29657, 2031, 'Três Metros Acima do Céu S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181475.mp4', 'http://timg.bdta.pro/images/cf21d4c941e00292d5d196f15867d105.jpg'),
(29658, 2032, 'Três Metros Acima do Céu S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181476.mp4', 'http://gstaticontent.com/images/qjcfAOBI9KrySLAsGszEn81xEzn_big.jpg'),
(29659, 2032, 'Três Metros Acima do Céu S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181477.mp4', 'http://gstaticontent.com/images/qjcfAOBI9KrySLAsGszEn81xEzn_big.jpg'),
(29660, 2032, 'Três Metros Acima do Céu S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181478.mp4', 'http://gstaticontent.com/images/qjcfAOBI9KrySLAsGszEn81xEzn_big.jpg'),
(29661, 2032, 'Três Metros Acima do Céu S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181479.mp4', 'http://gstaticontent.com/images/qjcfAOBI9KrySLAsGszEn81xEzn_big.jpg'),
(29662, 2032, 'Três Metros Acima do Céu S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181480.mp4', 'http://gstaticontent.com/images/qjcfAOBI9KrySLAsGszEn81xEzn_big.jpg'),
(29663, 2032, 'Três Metros Acima do Céu S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181481.mp4', 'http://gstaticontent.com/images/qjcfAOBI9KrySLAsGszEn81xEzn_big.jpg'),
(29664, 2032, 'Três Metros Acima do Céu S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181482.mp4', 'http://gstaticontent.com/images/qjcfAOBI9KrySLAsGszEn81xEzn_big.jpg'),
(29665, 2032, 'Três Metros Acima do Céu S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181483.mp4', 'http://gstaticontent.com/images/qjcfAOBI9KrySLAsGszEn81xEzn_big.jpg'),
(29666, 2033, 'Três Metros Acima do Céu S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181484.mp4', 'http://gstaticontent.com/images/qjcfAOBI9KrySLAsGszEn81xEzn_big.jpg'),
(29667, 2033, 'Três Metros Acima do Céu S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181485.mp4', 'http://gstaticontent.com/images/qjcfAOBI9KrySLAsGszEn81xEzn_big.jpg'),
(29668, 2033, 'Três Metros Acima do Céu S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181486.mp4', 'http://gstaticontent.com/images/qjcfAOBI9KrySLAsGszEn81xEzn_big.jpg'),
(29669, 2033, 'Três Metros Acima do Céu S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181487.mp4', 'http://gstaticontent.com/images/qjcfAOBI9KrySLAsGszEn81xEzn_big.jpg'),
(29670, 2033, 'Três Metros Acima do Céu S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181488.mp4', 'http://gstaticontent.com/images/qjcfAOBI9KrySLAsGszEn81xEzn_big.jpg'),
(29671, 2033, 'Três Metros Acima do Céu S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181489.mp4', 'http://gstaticontent.com/images/qjcfAOBI9KrySLAsGszEn81xEzn_big.jpg'),
(29672, 2033, 'Três Metros Acima do Céu S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181490.mp4', 'http://gstaticontent.com/images/qjcfAOBI9KrySLAsGszEn81xEzn_big.jpg'),
(29673, 2033, 'Três Metros Acima do Céu S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181491.mp4', 'http://gstaticontent.com/images/qjcfAOBI9KrySLAsGszEn81xEzn_big.jpg'),
(29674, 2034, 'Damien [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114576.mp4', 'http://timg.bdta.pro/images/f7a83465afccac8d7a361e8ac06a64b0.jpg'),
(29675, 2034, 'Damien [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114577.mp4', 'http://timg.bdta.pro/images/190162570fe3f91d98d29db1400fdc1e.jpg'),
(29676, 2034, 'Damien [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114578.mp4', 'http://timg.bdta.pro/images/f2cb436319763c4cc1b64dd39bc476eb.jpg'),
(29677, 2034, 'Damien [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114579.mp4', 'http://timg.bdta.pro/images/e7b77c5dccbde8e6fb37c7a2d80e2c48.jpg'),
(29678, 2034, 'Damien [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114580.mp4', 'http://timg.bdta.pro/images/0a4686994f4f89cad2bdb216d60afef9.jpg'),
(29679, 2034, 'Damien [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114581.mp4', 'http://timg.bdta.pro/images/802d5bbef3f27dbb82b694090855ac6b.jpg'),
(29680, 2034, 'Damien [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114582.mp4', 'http://timg.bdta.pro/images/c629362c407029988722875f9b3dd622.jpg'),
(29681, 2034, 'Damien [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114583.mp4', 'http://timg.bdta.pro/images/6346fae7e2bed73d3282f16119381b02.jpg'),
(29682, 2034, 'Damien [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114584.mp4', 'http://timg.bdta.pro/images/964f86a1f91a21e3bfc055cae9334a95.jpg'),
(29683, 2034, 'Damien [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114585.mp4', 'http://timg.bdta.pro/images/e87439f2951dc2719b51d6097f8fef42.jpg'),
(29684, 2035, 'O Ultimo Dragão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114494.mp4', 'http://timg.bdta.pro/images/59df9eba90d62752d3547677b341a2cf.jpg'),
(29685, 2035, 'O Ultimo Dragão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114495.mp4', 'http://timg.bdta.pro/images/cef5a99638be8039f913477cd95a1be6.jpg'),
(29686, 2035, 'O Ultimo Dragão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114496.mp4', 'http://timg.bdta.pro/images/cef5a99638be8039f913477cd95a1be6.jpg'),
(29687, 2035, 'O Ultimo Dragão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114497.mp4', 'http://timg.bdta.pro/images/cef5a99638be8039f913477cd95a1be6.jpg'),
(29688, 2035, 'O Ultimo Dragão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114498.mp4', 'http://timg.bdta.pro/images/38d82324fd4b0acfd719614fd979b7a1.jpg'),
(29689, 2035, 'O Ultimo Dragão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114499.mp4', 'http://timg.bdta.pro/images/38d82324fd4b0acfd719614fd979b7a1.jpg'),
(29690, 2035, 'O Ultimo Dragão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114500.mp4', 'http://timg.bdta.pro/images/af0fc2999cb756e77587a00d8f38ba37.jpg'),
(29691, 2035, 'O Ultimo Dragão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114501.mp4', 'http://timg.bdta.pro/images/98a1a02cc46921f295b476dbcef7bfdd.jpg'),
(29692, 2035, 'O Ultimo Dragão S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114502.mp4', 'http://timg.bdta.pro/images/549db84929207f26a5b267967e84d0c4.jpg'),
(29693, 2035, 'O Ultimo Dragão S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114503.mp4', 'http://timg.bdta.pro/images/dc4e940d89fefe74afae052c922b8312.jpg'),
(29694, 2035, 'O Ultimo Dragão S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114504.mp4', 'http://timg.bdta.pro/images/dc4e940d89fefe74afae052c922b8312.jpg'),
(29695, 2035, 'O Ultimo Dragão S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114505.mp4', 'http://timg.bdta.pro/images/dc4e940d89fefe74afae052c922b8312.jpg'),
(29696, 2035, 'O Ultimo Dragão S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114506.mp4', 'http://timg.bdta.pro/images/dc4e940d89fefe74afae052c922b8312.jpg'),
(29697, 2035, 'O Ultimo Dragão S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/114507.mp4', 'http://timg.bdta.pro/images/dc4e940d89fefe74afae052c922b8312.jpg'),
(29698, 2035, 'O Ultimo Dragão S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/114508.mp4', 'http://timg.bdta.pro/images/5500672183d696c57bdce90dba04c9e3.jpg'),
(29699, 2035, 'O Ultimo Dragão S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/114509.mp4', 'http://timg.bdta.pro/images/bcc45e89cc213e70d5b35786855b6304.jpg'),
(29700, 2035, 'O Ultimo Dragão S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/114510.mp4', 'http://timg.bdta.pro/images/bcc45e89cc213e70d5b35786855b6304.jpg'),
(29701, 2035, 'O Ultimo Dragão S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/114511.mp4', 'http://timg.bdta.pro/images/bcc45e89cc213e70d5b35786855b6304.jpg'),
(29702, 2035, 'O Ultimo Dragão S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/114512.mp4', 'http://timg.bdta.pro/images/0a5b3b0c4262715dda4d4b258e67c08a.jpg'),
(29703, 2035, 'O Ultimo Dragão S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/114513.mp4', 'http://timg.bdta.pro/images/0a5b3b0c4262715dda4d4b258e67c08a.jpg'),
(29704, 2035, 'O Ultimo Dragão S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/114514.mp4', 'http://timg.bdta.pro/images/d25862a58f4148881b1d722ed3ef358e.jpg'),
(29705, 2035, 'O Ultimo Dragão S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/114515.mp4', 'http://timg.bdta.pro/images/d25862a58f4148881b1d722ed3ef358e.jpg'),
(29706, 2035, 'O Ultimo Dragão S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/114516.mp4', 'http://timg.bdta.pro/images/d25862a58f4148881b1d722ed3ef358e.jpg'),
(29707, 2035, 'O Ultimo Dragão S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/114517.mp4', 'http://timg.bdta.pro/images/fe84bab036ee872f2b3407c584aa64fb.jpg'),
(29708, 2035, 'O Ultimo Dragão S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/114518.mp4', 'http://timg.bdta.pro/images/a364498ce7b35c61ede07eb7e73373a5.jpg'),
(29709, 2035, 'O Ultimo Dragão S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/114519.mp4', 'http://timg.bdta.pro/images/31fbc07b4ed9cbe848926fb8ac012a3e.jpg'),
(29710, 2035, 'O Ultimo Dragão S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/114520.mp4', 'http://timg.bdta.pro/images/56dc5821dab0592d56ca616bccf55198.jpg'),
(29711, 2035, 'O Ultimo Dragão S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/114521.mp4', 'http://timg.bdta.pro/images/7696b5b7d41853508752baae5374f05e.jpg'),
(29712, 2035, 'O Ultimo Dragão S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/114522.mp4', 'http://timg.bdta.pro/images/7696b5b7d41853508752baae5374f05e.jpg'),
(29713, 2035, 'O Ultimo Dragão S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/114523.mp4', 'http://timg.bdta.pro/images/7696b5b7d41853508752baae5374f05e.jpg'),
(29714, 2035, 'O Ultimo Dragão S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/114524.mp4', 'http://timg.bdta.pro/images/13c750de21593a89dd2dff6839ae5f63.jpg'),
(29715, 2035, 'O Ultimo Dragão S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/114525.mp4', 'http://timg.bdta.pro/images/8c0aacae1d8276d4dc9f1cf826bb52ad.jpg'),
(29716, 2035, 'O Ultimo Dragão S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/114526.mp4', 'http://timg.bdta.pro/images/ecba21eeb47e6c3cfb9fab6af3616f33.jpg'),
(29717, 2035, 'O Ultimo Dragão S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/114527.mp4', 'http://timg.bdta.pro/images/ecba21eeb47e6c3cfb9fab6af3616f33.jpg'),
(29718, 2035, 'O Ultimo Dragão S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/114528.mp4', 'http://timg.bdta.pro/images/49545716cff3f31bface9cd8b6628798.jpg'),
(29719, 2035, 'O Ultimo Dragão S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/114529.mp4', 'http://timg.bdta.pro/images/7ab7735b6e4694313d0276b93688bb3a.jpg'),
(29720, 2035, 'O Ultimo Dragão S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/114530.mp4', 'http://timg.bdta.pro/images/0b5e06087bc8b9c9ccb7543cdd5956dd.jpg'),
(29721, 2035, 'O Ultimo Dragão S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/114531.mp4', 'http://timg.bdta.pro/images/3a314f6cbc4ddd375f3b8c7175efad48.jpg'),
(29722, 2036, 'O Ultimo Dragão S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114532.mp4', 'http://timg.bdta.pro/images/3a314f6cbc4ddd375f3b8c7175efad48.jpg'),
(29723, 2036, 'O Ultimo Dragão S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114533.mp4', 'http://timg.bdta.pro/images/4b22a23c47760d693624620f0937b433.jpg'),
(29724, 2036, 'O Ultimo Dragão S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114534.mp4', 'http://timg.bdta.pro/images/4b22a23c47760d693624620f0937b433.jpg'),
(29725, 2036, 'O Ultimo Dragão S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114535.mp4', 'http://timg.bdta.pro/images/4b22a23c47760d693624620f0937b433.jpg'),
(29726, 2036, 'O Ultimo Dragão S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114536.mp4', 'http://timg.bdta.pro/images/4b22a23c47760d693624620f0937b433.jpg'),
(29727, 2036, 'O Ultimo Dragão S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114537.mp4', 'http://timg.bdta.pro/images/4b22a23c47760d693624620f0937b433.jpg'),
(29728, 2036, 'O Ultimo Dragão S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114538.mp4', 'http://timg.bdta.pro/images/4b22a23c47760d693624620f0937b433.jpg'),
(29729, 2036, 'O Ultimo Dragão S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114539.mp4', 'http://timg.bdta.pro/images/4b22a23c47760d693624620f0937b433.jpg'),
(29730, 2036, 'O Ultimo Dragão S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114540.mp4', 'http://timg.bdta.pro/images/4b22a23c47760d693624620f0937b433.jpg'),
(29731, 2036, 'O Ultimo Dragão S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114541.mp4', 'http://timg.bdta.pro/images/4b22a23c47760d693624620f0937b433.jpg'),
(29732, 2036, 'O Ultimo Dragão S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114542.mp4', 'http://timg.bdta.pro/images/4b22a23c47760d693624620f0937b433.jpg'),
(29733, 2036, 'O Ultimo Dragão S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114543.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29734, 2036, 'O Ultimo Dragão S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114544.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29735, 2036, 'O Ultimo Dragão S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/114545.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29736, 2036, 'O Ultimo Dragão S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/114546.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29737, 2036, 'O Ultimo Dragão S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/114547.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29738, 2036, 'O Ultimo Dragão S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/114548.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29739, 2036, 'O Ultimo Dragão S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/114549.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29740, 2036, 'O Ultimo Dragão S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/114550.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29741, 2036, 'O Ultimo Dragão S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/114551.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29742, 2036, 'O Ultimo Dragão S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/114552.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29743, 2036, 'O Ultimo Dragão S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/114553.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29744, 2036, 'O Ultimo Dragão S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/114554.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29745, 2036, 'O Ultimo Dragão S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/114555.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29746, 2036, 'O Ultimo Dragão S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/114556.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29747, 2036, 'O Ultimo Dragão S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/114557.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29748, 2036, 'O Ultimo Dragão S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/114558.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29749, 2036, 'O Ultimo Dragão S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/114559.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29750, 2036, 'O Ultimo Dragão S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/114560.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29751, 2036, 'O Ultimo Dragão S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/114561.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29752, 2036, 'O Ultimo Dragão S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/114562.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29753, 2036, 'O Ultimo Dragão S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/114563.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29754, 2036, 'O Ultimo Dragão S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/114564.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29755, 2036, 'O Ultimo Dragão S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/114565.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29756, 2036, 'O Ultimo Dragão S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/114566.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29757, 2036, 'O Ultimo Dragão S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/114567.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29758, 2036, 'O Ultimo Dragão S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/114568.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29759, 2036, 'O Ultimo Dragão S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/114569.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29760, 2036, 'O Ultimo Dragão S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/114570.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29761, 2036, 'O Ultimo Dragão S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/114571.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29762, 2036, 'O Ultimo Dragão S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/114572.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29763, 2036, 'O Ultimo Dragão S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/114573.mp4', 'http://gstaticontent.com/images/5gJLpSjh4vgkF0YosBxbAAuIjKc_big.jpg'),
(29764, 2036, 'O Ultimo Dragão S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/114574.mp4', 'http://timg.bdta.pro/images/2a27a047680e834097809000d3f8839a.jpg'),
(29765, 2036, 'O Ultimo Dragão S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/114575.mp4', 'http://timg.bdta.pro/images/d8eb7a0410649f9cd011b69ba85413c1.jpg'),
(29766, 2037, 'A Ordem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114474.mp4', 'http://timg.bdta.pro/images/47add36f7741352421aea1aa467d3bff.jpg'),
(29767, 2037, 'A Ordem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114475.mp4', 'http://timg.bdta.pro/images/9dddb87b17ebf39ce40a872bae8c97e0.jpg'),
(29768, 2037, 'A Ordem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114476.mp4', 'http://timg.bdta.pro/images/6b3dce063595817cdc8e30ec68e4af61.jpg'),
(29769, 2037, 'A Ordem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114477.mp4', 'http://timg.bdta.pro/images/89cd112e1ff2ce8d304a2e4458bb0282.jpg'),
(29770, 2037, 'A Ordem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114478.mp4', 'http://timg.bdta.pro/images/13543316545e4d48387fbe6c4ce9b1ef.jpg'),
(29771, 2037, 'A Ordem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114479.mp4', 'http://timg.bdta.pro/images/12a7def2358c64cfee55bdf5699f2d38.jpg'),
(29772, 2037, 'A Ordem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114480.mp4', 'http://timg.bdta.pro/images/42e0aded8d81f254251a87b915382ccb.jpg'),
(29773, 2037, 'A Ordem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114481.mp4', 'http://timg.bdta.pro/images/08c62afc04bbb2bf0a8be95818f188ea.jpg'),
(29774, 2037, 'A Ordem S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114482.mp4', 'http://timg.bdta.pro/images/e18dd800f4903b7d3ced1367ea8c3ac2.jpg'),
(29775, 2037, 'A Ordem S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114483.mp4', 'http://timg.bdta.pro/images/63798fbaa3cde140c0a79df4705e656a.jpg'),
(29776, 2038, 'A Ordem S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114484.mp4', 'http://timg.bdta.pro/images/a62b32f24060963568bea9178ca80880.jpg'),
(29777, 2038, 'A Ordem S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114485.mp4', 'http://timg.bdta.pro/images/fae085bc10416a9c2b30f439ce30ba5e.jpg'),
(29778, 2038, 'A Ordem S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114486.mp4', 'http://timg.bdta.pro/images/5d0d6f33c455988dea419a15ecfd646e.jpg'),
(29779, 2038, 'A Ordem S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114487.mp4', 'http://timg.bdta.pro/images/1269494831c610197c0ba8c69bf850e5.jpg'),
(29780, 2038, 'A Ordem S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114488.mp4', 'http://timg.bdta.pro/images/589bb2303aacb56339ac51e21215c388.jpg'),
(29781, 2038, 'A Ordem S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114489.mp4', 'http://timg.bdta.pro/images/5a0d8e5813482afb8ca4097ed6f9c626.jpg'),
(29782, 2038, 'A Ordem S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114490.mp4', 'http://timg.bdta.pro/images/f412243ce0996a440eb561246a405bf8.jpg'),
(29783, 2038, 'A Ordem S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114491.mp4', 'http://timg.bdta.pro/images/42b5918d15a9be17715ba057e2625dd9.jpg'),
(29784, 2038, 'A Ordem S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114492.mp4', 'http://timg.bdta.pro/images/daddb08d54c7945f633e60a141310145.jpg'),
(29785, 2038, 'A Ordem S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114493.mp4', 'http://timg.bdta.pro/images/3735ac0de1ca1e5aba1d534f7e86e318.jpg'),
(29786, 2039, 'A Verdade Por Tras do Homem Na Lua S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114468.mp4', 'http://timg.bdta.pro/images/96fce9d2aaba4e102b818ce36b14a344.jpg'),
(29787, 2039, 'A Verdade Por Tras do Homem Na Lua S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114469.mp4', 'http://timg.bdta.pro/images/ef2a03480a574d34373490ee256db4b3.jpg'),
(29788, 2039, 'A Verdade Por Tras do Homem Na Lua S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114470.mp4', 'http://timg.bdta.pro/images/09ffe96b479931c157070ce81d07cbe3.jpg'),
(29789, 2039, 'A Verdade Por Tras do Homem Na Lua S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114471.mp4', 'http://timg.bdta.pro/images/4f0e90d3bccd14196c11de3c00260e08.jpg'),
(29790, 2039, 'A Verdade Por Tras do Homem Na Lua S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114472.mp4', 'http://gstaticontent.com/images/wRLTislvtEFXD6vx4TOvfHeqjJ0_big.jpg'),
(29791, 2039, 'A Verdade Por Tras do Homem Na Lua S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114473.mp4', 'http://gstaticontent.com/images/wRLTislvtEFXD6vx4TOvfHeqjJ0_big.jpg'),
(29792, 2040, 'Alex Rider [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114460.mp4', 'http://timg.bdta.pro/images/ffb9089c39bea1472c3363bb9ad44eb5.jpg'),
(29793, 2040, 'Alex Rider [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114461.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(29794, 2040, 'Alex Rider [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114462.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(29795, 2040, 'Alex Rider [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114463.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(29796, 2040, 'Alex Rider [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114464.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(29797, 2040, 'Alex Rider [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114465.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(29798, 2040, 'Alex Rider [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114466.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(29799, 2040, 'Alex Rider [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114467.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(29800, 2041, 'Babylon Berlin S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201621.mp4', 'http://timg.bdta.pro/images/8f5f075189821a42530251b5249351f7.jpg'),
(29801, 2041, 'Babylon Berlin S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201622.mp4', 'http://timg.bdta.pro/images/fc15cca8649e274a7cd7b5c14bc2003f.jpg'),
(29802, 2041, 'Babylon Berlin S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201623.mp4', 'http://timg.bdta.pro/images/079c45d8744aed6e1b7c524748be6205.jpg'),
(29803, 2041, 'Babylon Berlin S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201624.mp4', 'http://timg.bdta.pro/images/f5016bd7d96a96170d456497eafba804.jpg'),
(29804, 2041, 'Babylon Berlin S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201625.mp4', 'http://timg.bdta.pro/images/3c67349ff9938cf6c480beff76768422.jpg'),
(29805, 2041, 'Babylon Berlin S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201626.mp4', 'http://timg.bdta.pro/images/d1415f3ac4b44028928813e4fb48d4fa.jpg'),
(29806, 2041, 'Babylon Berlin S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201627.mp4', 'http://timg.bdta.pro/images/3ffd1a9a4c2b9847febcc18c2b508b0a.jpg'),
(29807, 2041, 'Babylon Berlin S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201628.mp4', 'http://timg.bdta.pro/images/1af15cdb7d24273a2d80822b26a775d6.jpg'),
(29808, 2042, 'Babylon Berlin S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201629.mp4', 'http://timg.bdta.pro/images/db7f70cf131c2df80b4e92ab9da29bff.jpg'),
(29809, 2042, 'Babylon Berlin S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201630.mp4', 'http://timg.bdta.pro/images/2cab9818e35367eeee0d073b956d6ab9.jpg'),
(29810, 2042, 'Babylon Berlin S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201631.mp4', 'http://timg.bdta.pro/images/59bcf45e8214687122c2e5237e64f5ff.jpg'),
(29811, 2042, 'Babylon Berlin S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201632.mp4', 'http://timg.bdta.pro/images/e793c27d5297e9ad902000576d3c23aa.jpg'),
(29812, 2042, 'Babylon Berlin S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201633.mp4', 'http://timg.bdta.pro/images/eef81ea2cd6284d9b40d5739f84948a7.jpg'),
(29813, 2042, 'Babylon Berlin S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201634.mp4', 'http://timg.bdta.pro/images/a22227ace067afb540a51bd9a0337592.jpg'),
(29814, 2042, 'Babylon Berlin S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201635.mp4', 'http://timg.bdta.pro/images/c211e96662b81096248d1f86dc2dd289.jpg'),
(29815, 2042, 'Babylon Berlin S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201636.mp4', 'http://timg.bdta.pro/images/777bfe11760fc9e98b1366e7db420cfd.jpg'),
(29816, 2043, 'Babylon Berlin S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24dhuGaJoxsq2tKl1JYRMAlphcs.jpg'),
(29817, 2043, 'Babylon Berlin S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hm9mFxRCN0C67wJMstPvD3bnidw.jpg'),
(29818, 2043, 'Babylon Berlin S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pioWTxE5ags6fBgbxPWuXjOzY9O.jpg'),
(29819, 2043, 'Babylon Berlin S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4YoFlCswrgBlfXhL34IwWqDuMG0.jpg'),
(29820, 2043, 'Babylon Berlin S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lo54XwLvF3c03nEyYVNRoJS1DKg.jpg'),
(29821, 2043, 'Babylon Berlin S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lkmrSgax93y2bMqwSpcDWlbKGq7.jpg'),
(29822, 2043, 'Babylon Berlin S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oPIbpSeh2GM5XKEerHAaL6aQ1pY.jpg'),
(29823, 2043, 'Babylon Berlin S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vTxdU3gxzqbKX0PFsFQ9iwcOEko.jpg'),
(29824, 2043, 'Babylon Berlin S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gGCxu2ghm14BFvsGDOy6sYArV4D.jpg'),
(29825, 2043, 'Babylon Berlin S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6YKY2qfwPvNUCDluh9NEucPCqkp.jpg'),
(29826, 2043, 'Babylon Berlin S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zq22U5IUrHUqIFBqym1NAmQPgvh.jpg'),
(29827, 2043, 'Babylon Berlin S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zQmODOdboXCRM8cAq38WF8mu3J2.jpg'),
(29828, 2044, 'Betaal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114412.mp4', 'http://timg.bdta.pro/images/c2520a64f9e900e616a20b6b64c8d921.jpg'),
(29829, 2044, 'Betaal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114413.mp4', 'http://timg.bdta.pro/images/b6795eccd2b55c92e412fbd64de788bd.jpg'),
(29830, 2044, 'Betaal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114414.mp4', 'http://timg.bdta.pro/images/bc944defde10774e2bb5758cd2682af5.jpg'),
(29831, 2044, 'Betaal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114415.mp4', 'http://timg.bdta.pro/images/d36aeb569af1d6d1e9dd27f9d6a3fb87.jpg'),
(29832, 2045, 'Blood Machines [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114409.mp4', 'http://gstaticontent.com/images/63YJqpUJZ1d6JmeRawLMy4yYKsN_big.jpg'),
(29833, 2045, 'Blood Machines [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114410.mp4', 'http://gstaticontent.com/images/63YJqpUJZ1d6JmeRawLMy4yYKsN_big.jpg'),
(29834, 2045, 'Blood Machines [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114411.mp4', 'http://gstaticontent.com/images/63YJqpUJZ1d6JmeRawLMy4yYKsN_big.jpg'),
(29835, 2046, 'Bull S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195441.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29836, 2046, 'Bull S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195442.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29837, 2046, 'Bull S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195443.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29838, 2046, 'Bull S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195444.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29839, 2046, 'Bull S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195445.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29840, 2046, 'Bull S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195446.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29841, 2046, 'Bull S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195447.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29842, 2046, 'Bull S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195448.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29843, 2046, 'Bull S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195449.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29844, 2046, 'Bull S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195450.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29845, 2046, 'Bull S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/195451.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29846, 2046, 'Bull S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/195452.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29847, 2046, 'Bull S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/195453.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29848, 2046, 'Bull S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/195454.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29849, 2046, 'Bull S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/195455.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29850, 2046, 'Bull S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/195456.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29851, 2046, 'Bull S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/195457.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29852, 2046, 'Bull S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/195458.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29853, 2046, 'Bull S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/195459.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29854, 2046, 'Bull S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/195460.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29855, 2046, 'Bull S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/195461.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29856, 2046, 'Bull S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/195462.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29857, 2046, 'Bull S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/195463.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29858, 2047, 'Bull S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195464.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29859, 2047, 'Bull S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195465.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29860, 2047, 'Bull S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195466.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29861, 2047, 'Bull S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195467.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29862, 2047, 'Bull S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195468.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29863, 2047, 'Bull S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195469.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29864, 2047, 'Bull S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195470.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29865, 2047, 'Bull S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195471.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29866, 2047, 'Bull S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195472.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29867, 2047, 'Bull S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195473.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29868, 2047, 'Bull S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/195474.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29869, 2047, 'Bull S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/195475.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29870, 2047, 'Bull S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/195476.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29871, 2047, 'Bull S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/195477.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29872, 2047, 'Bull S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/195478.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29873, 2047, 'Bull S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/195479.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29874, 2047, 'Bull S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/195480.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29875, 2047, 'Bull S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/195481.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29876, 2047, 'Bull S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/195482.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29877, 2047, 'Bull S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/195483.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29878, 2047, 'Bull S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/195484.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29879, 2047, 'Bull S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/195485.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29880, 2048, 'Bull S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195486.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29881, 2048, 'Bull S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195487.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29882, 2048, 'Bull S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195488.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29883, 2048, 'Bull S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195489.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29884, 2048, 'Bull S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195490.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29885, 2048, 'Bull S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195491.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29886, 2048, 'Bull S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195492.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29887, 2048, 'Bull S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195493.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29888, 2048, 'Bull S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195494.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29889, 2048, 'Bull S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195495.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29890, 2048, 'Bull S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/195496.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29891, 2048, 'Bull S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/195497.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29892, 2048, 'Bull S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/195498.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29893, 2048, 'Bull S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/195499.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29894, 2048, 'Bull S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/195500.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29895, 2048, 'Bull S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/195501.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29896, 2048, 'Bull S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/195502.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29897, 2048, 'Bull S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/195503.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29898, 2048, 'Bull S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/195504.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29899, 2048, 'Bull S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/195505.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29900, 2048, 'Bull S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/195506.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29901, 2048, 'Bull S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/195507.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29902, 2049, 'Bull S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195508.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29903, 2049, 'Bull S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195509.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29904, 2049, 'Bull S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195510.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29905, 2049, 'Bull S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195511.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29906, 2049, 'Bull S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195512.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29907, 2049, 'Bull S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195513.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29908, 2049, 'Bull S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195514.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29909, 2049, 'Bull S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195515.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29910, 2049, 'Bull S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195516.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29911, 2049, 'Bull S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195517.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29912, 2049, 'Bull S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/195518.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29913, 2049, 'Bull S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/195519.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29914, 2049, 'Bull S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/195520.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29915, 2049, 'Bull S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/195521.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29916, 2049, 'Bull S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/195522.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29917, 2049, 'Bull S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/195523.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(29918, 2049, 'Bull S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/195524.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29919, 2049, 'Bull S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/195525.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29920, 2049, 'Bull S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/195526.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29921, 2049, 'Bull S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/195527.mp4', 'http://gstaticontent.com/images/ou5ObrRmt7nAV8vMrUYKtMXmBgY_big.jpg'),
(29922, 2050, 'Bull S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kNtexVLPsqM01PBbQJ9mRxivR59.jpg'),
(29923, 2050, 'Bull S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fbOysVSSTTedbHp4efC537O8DLW.jpg'),
(29924, 2050, 'Bull S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8TBHKk2Nv1vmYDgoFEtZh31jWMS.jpg'),
(29925, 2050, 'Bull S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4pIyVcotdLbFtBAKuw0hBeMGa84.jpg'),
(29926, 2050, 'Bull S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eWDMlQGfW8veRNPpNvTcku45OQ2.jpg'),
(29927, 2050, 'Bull S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lAtjBUEjtGyUkMeSZtTQyi6qwez.jpg'),
(29928, 2050, 'Bull S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z0OirG4XUEPM30YbT46QPeWWPoX.jpg'),
(29929, 2050, 'Bull S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mItjRAgRATLfzbsAEPFkokapsy5.jpg'),
(29930, 2050, 'Bull S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aIarL2BZg5w0VpiaBoQLcQXbTxq.jpg'),
(29931, 2050, 'Bull S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzc2NSuN8sHQTUXnEcjxSVWbkMU.jpg'),
(29932, 2050, 'Bull S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/195538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kMimWjPpO45sb8kTjR3gT84eUhd.jpg'),
(29933, 2050, 'Bull S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/195539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8iSHWRA2JF0g6yUeiTTynrjON6S.jpg'),
(29934, 2050, 'Bull S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/195540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nlsWa8ToAaf7EMu35bpB7dlJmx8.jpg'),
(29935, 2050, 'Bull S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/195541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/52sjDEv8hM3H8lK3c43WCouRxTi.jpg'),
(29936, 2050, 'Bull S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/195542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0aLCZhQgKMaF056KUOhdeM5kN4.jpg'),
(29937, 2050, 'Bull S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/195543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eJiajSlEdvM9aWlakF9U0cQFygh.jpg'),
(29938, 2051, 'Bull S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195544.mp4', 'http://timg.bdta.pro/images/e5f960d02243db159386387fb52c31f0.jpg'),
(29939, 2051, 'Bull S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195545.mp4', 'http://timg.bdta.pro/images/55bae8050ffb379d387a7ab033fee218.jpg'),
(29940, 2051, 'Bull S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195546.mp4', 'http://timg.bdta.pro/images/aaf879d3e7079697bc030417e14a4db7.jpg'),
(29941, 2051, 'Bull S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195547.mp4', 'http://timg.bdta.pro/images/8dc12eb73e995b9f03e81d65376306c4.jpg'),
(29942, 2051, 'Bull S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195548.mp4', 'http://timg.bdta.pro/images/157b95e8e2e00c5cf8a6e1f230b2593b.jpg'),
(29943, 2051, 'Bull S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195549.mp4', 'http://timg.bdta.pro/images/90a947ead2b2249bfa2e3f89bd7a493e.jpg'),
(29944, 2051, 'Bull S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195550.mp4', 'http://timg.bdta.pro/images/57e6c58d68c0e946f434b4b733c639c6.jpg'),
(29945, 2051, 'Bull S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195551.mp4', 'http://timg.bdta.pro/images/fd072b96fbb9b4d1950258e26c580bcd.jpg'),
(29946, 2051, 'Bull S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195552.mp4', 'http://timg.bdta.pro/images/1445fde080b1ba5b424f9ce273f01927.jpg'),
(29947, 2051, 'Bull S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195553.mp4', 'http://timg.bdta.pro/images/b038fd81ebdea0bd296a2143b1e420c3.jpg'),
(29948, 2051, 'Bull S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/195554.mp4', 'http://timg.bdta.pro/images/cb24c34a85b43496eedc1ac0824f7d3e.jpg'),
(29949, 2051, 'Bull S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/195555.mp4', 'http://timg.bdta.pro/images/02bb8307e776d4e377872bb3cb1b9970.jpg'),
(29950, 2051, 'Bull S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/195556.mp4', 'http://timg.bdta.pro/images/56d4e5ba4b2e30ba7f1eea41756123ab.jpg'),
(29951, 2051, 'Bull S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/195557.mp4', 'http://timg.bdta.pro/images/468890d559a617b7cac07c4a789aedf7.jpg'),
(29952, 2051, 'Bull S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/195558.mp4', 'http://timg.bdta.pro/images/daf2b6be8320fe4f058af6b8ae184de8.jpg'),
(29953, 2051, 'Bull S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/195559.mp4', 'http://timg.bdta.pro/images/92e24abbf2e6fb918ef323753732486b.jpg'),
(29954, 2051, 'Bull S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/195560.mp4', 'http://timg.bdta.pro/images/244fdc73e5bba2b0f53ec485433bcb51.jpg'),
(29955, 2051, 'Bull S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/195561.mp4', 'http://timg.bdta.pro/images/eaaad76cc791b0a82e8e41af7dd9e825.jpg'),
(29956, 2051, 'Bull S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/195562.mp4', 'http://timg.bdta.pro/images/9f4bea1dc97bfb613774cea835d64b4a.jpg'),
(29957, 2051, 'Bull S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/195563.mp4', 'http://timg.bdta.pro/images/edf0d75c72aa8de264afb7ff3459a435.jpg'),
(29958, 2051, 'Bull S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/195564.mp4', 'http://timg.bdta.pro/images/263c8ca9208b99c53f6f95e4ce0ce5e5.jpg'),
(29959, 2051, 'Bull S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/195565.mp4', 'http://timg.bdta.pro/images/e78c67194113ae42167c51337f1627e4.jpg'),
(29960, 2052, 'Central Park S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201092.mp4', 'http://timg.bdta.pro/images/e2acac04588e6cdbc014ba1bb6f49c7e.jpg'),
(29961, 2052, 'Central Park S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201093.mp4', 'http://timg.bdta.pro/images/7904546f57735e2344d4d8d8b3ad9e24.jpg'),
(29962, 2052, 'Central Park S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201094.mp4', 'http://timg.bdta.pro/images/fde04106441f81e1e9b47d85c870cf08.jpg'),
(29963, 2052, 'Central Park S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201095.mp4', 'http://timg.bdta.pro/images/aa0b0da79a9c38fec078e77a7dfa8dfd.jpg'),
(29964, 2052, 'Central Park S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201096.mp4', 'http://timg.bdta.pro/images/a03628907ecb31d25c6bf0e44fff110e.jpg'),
(29965, 2052, 'Central Park S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201097.mp4', 'http://timg.bdta.pro/images/47d2868723af480c77fb34ec72aa17a3.jpg'),
(29966, 2052, 'Central Park S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201098.mp4', 'http://timg.bdta.pro/images/590b70ad4de7d3891b4cc2ce14f16e0e.jpg'),
(29967, 2052, 'Central Park S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201099.mp4', 'http://timg.bdta.pro/images/2a78c949f3057d6e9ef020d970ba97bf.jpg'),
(29968, 2052, 'Central Park S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201100.mp4', 'http://timg.bdta.pro/images/b3fc601487d015620a9960bc3bb7b349.jpg'),
(29969, 2052, 'Central Park S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201101.mp4', 'http://timg.bdta.pro/images/ec15f9f4381340c1f62a6eb1a3fb84c9.jpg'),
(29970, 2053, 'Central Park S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8kXZnbS6b2gmgiYGaCBnhA9w5s8.jpg'),
(29971, 2053, 'Central Park S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wAsXZpj8qbISbtzfq2Tsby2u1D6.jpg'),
(29972, 2053, 'Central Park S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7xmTihRBmMbCX08yGrMO9UWMZP2.jpg'),
(29973, 2053, 'Central Park S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pUBNrfS9UvlsL5PfbGelcZ0vZhI.jpg'),
(29974, 2053, 'Central Park S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1K2nV0jsgS6C5jLeEozQoiRrEZl.jpg'),
(29975, 2053, 'Central Park S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rzG25LkcA8PIZWLn4HUvkPSdSdU.jpg'),
(29976, 2053, 'Central Park S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lAJ3SaR1LQlF5VZQb9ssErJCWKd.jpg'),
(29977, 2053, 'Central Park S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkH3VLerOWd4sB5Skz9HcrOP4X6.jpg'),
(29978, 2053, 'Central Park S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201110.mp4', 'http://timg.bdta.pro/images/13e2ff3debf77d69b736cce75a90f37c.jpg'),
(29979, 2053, 'Central Park S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201111.mp4', 'http://timg.bdta.pro/images/ce394663ce403d9e6511e08f396e38ec.jpg'),
(29980, 2053, 'Central Park S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201112.mp4', 'http://timg.bdta.pro/images/9847d4697a12af54e233fa05e63a6e8e.jpg'),
(29981, 2053, 'Central Park S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201113.mp4', 'http://timg.bdta.pro/images/b34dd3610135f17dd50d62ae6d5d79ab.jpg'),
(29982, 2053, 'Central Park S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201114.mp4', 'http://timg.bdta.pro/images/58bf6c5516fafdabcfa2e0768dfea435.jpg'),
(29983, 2053, 'Central Park S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/201115.mp4', 'http://timg.bdta.pro/images/f8540833a5b37d4b166c4442847546f3.jpg'),
(29984, 2053, 'Central Park S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/201116.mp4', 'http://timg.bdta.pro/images/ecddf18f59ebe2ca0fe368f564b8161f.jpg'),
(29985, 2053, 'Central Park S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/201117.mp4', 'http://timg.bdta.pro/images/410222ec41d459bd7ad9ab7a8bf66ef2.jpg'),
(29986, 2054, 'Central Park S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201118.mp4', 'http://timg.bdta.pro/images/191a72be85518fde10e053e9c3df1356.jpg'),
(29987, 2054, 'Central Park S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201119.mp4', 'http://timg.bdta.pro/images/32f780377367cb1a7e3c10283c340b56.jpg'),
(29988, 2054, 'Central Park S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201120.mp4', 'http://timg.bdta.pro/images/cfb6cdc3444bd1fb780fc259b4f60087.jpg'),
(29989, 2054, 'Central Park S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201121.mp4', 'http://timg.bdta.pro/images/3d6305b5e9cb0f3e609cf0e74f146c27.jpg'),
(29990, 2054, 'Central Park S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201122.mp4', 'http://timg.bdta.pro/images/3ce05ba200f85b56ac37f157eaa3cfbb.jpg'),
(29991, 2054, 'Central Park S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201123.mp4', 'http://timg.bdta.pro/images/359d9b61496c3fdcacd58c9ab58c0557.jpg'),
(29992, 2054, 'Central Park S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201124.mp4', 'http://timg.bdta.pro/images/7c75da95b6db5848e9e16054b92e01cb.jpg'),
(29993, 2054, 'Central Park S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201125.mp4', 'http://timg.bdta.pro/images/10a946de30a197557e07b1d065238a7d.jpg'),
(29994, 2054, 'Central Park S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201126.mp4', 'http://timg.bdta.pro/images/31451159e5dbcedacc856e6aa5f6a193.jpg'),
(29995, 2054, 'Central Park S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dpTblZ45eQSEUhfdxoaU0Xqucj.jpg'),
(29996, 2054, 'Central Park S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eFnsPzSpFcHwW5Ay4Hi3I4n6mpf.jpg'),
(29997, 2054, 'Central Park S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201129.mp4', 'http://image.tmdb.org/t/p/w1280/sgo2ssTi4t4XbzDRYCSS8rDDhqI.jpg'),
(29998, 2054, 'Central Park S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201130.mp4', 'http://image.tmdb.org/t/p/w1280/kB120VQduIO6Bm4cgdYElsvsTBw.jpg'),
(29999, 2055, 'Conhecendo as Esculturas e Modelagens dos Filmes Disney S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114401.mp4', 'http://gstaticontent.com/images/xUOdaD2gABkzq7LOIjHGdGB7KUI_big.jpg'),
(30000, 2055, 'Conhecendo as Esculturas e Modelagens dos Filmes Disney S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114402.mp4', 'http://gstaticontent.com/images/xUOdaD2gABkzq7LOIjHGdGB7KUI_big.jpg'),
(30001, 2055, 'Conhecendo as Esculturas e Modelagens dos Filmes Disney S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114403.mp4', 'http://gstaticontent.com/images/xUOdaD2gABkzq7LOIjHGdGB7KUI_big.jpg'),
(30002, 2055, 'Conhecendo as Esculturas e Modelagens dos Filmes Disney S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114404.mp4', 'http://gstaticontent.com/images/xUOdaD2gABkzq7LOIjHGdGB7KUI_big.jpg'),
(30003, 2055, 'Conhecendo as Esculturas e Modelagens dos Filmes Disney S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114405.mp4', 'http://gstaticontent.com/images/xUOdaD2gABkzq7LOIjHGdGB7KUI_big.jpg'),
(30004, 2055, 'Conhecendo as Esculturas e Modelagens dos Filmes Disney S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114406.mp4', 'http://gstaticontent.com/images/xUOdaD2gABkzq7LOIjHGdGB7KUI_big.jpg'),
(30005, 2055, 'Conhecendo as Esculturas e Modelagens dos Filmes Disney S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114407.mp4', 'http://gstaticontent.com/images/xUOdaD2gABkzq7LOIjHGdGB7KUI_big.jpg'),
(30006, 2055, 'Conhecendo as Esculturas e Modelagens dos Filmes Disney S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114408.mp4', 'http://gstaticontent.com/images/xUOdaD2gABkzq7LOIjHGdGB7KUI_big.jpg'),
(30007, 2056, 'Coronavirus Explained [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114398.mp4', 'http://timg.bdta.pro/images/94dc7ec7c11347532d44b1977a3a56fa.jpg'),
(30008, 2056, 'Coronavirus Explained [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114399.mp4', 'http://timg.bdta.pro/images/087a305322eb72ed7616651243a0b362.jpg'),
(30009, 2056, 'Coronavirus Explained [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114400.mp4', 'http://timg.bdta.pro/images/7c1e1c1207dc9c7c4410beb619cf0895.jpg'),
(30010, 2057, 'Cosmos Mundos Possiveis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129219.mp4', 'http://timg.bdta.pro/images/9bacd475563d8aef958be8c467415154.jpg'),
(30011, 2057, 'Cosmos Mundos Possiveis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129220.mp4', 'http://timg.bdta.pro/images/cf466e826431a6a340f393f9259338fa.jpg'),
(30012, 2057, 'Cosmos Mundos Possiveis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129221.mp4', 'http://timg.bdta.pro/images/573cb40a7c3211debcf966e6beec00e2.jpg'),
(30013, 2057, 'Cosmos Mundos Possiveis S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129222.mp4', 'http://timg.bdta.pro/images/f66a57dd9dd7dee6cb95e1b13caf059e.jpg'),
(30014, 2057, 'Cosmos Mundos Possiveis S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129223.mp4', 'http://timg.bdta.pro/images/8d260d27c90f4bc560bc0c8e6849e050.jpg'),
(30015, 2057, 'Cosmos Mundos Possiveis S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129224.mp4', 'http://timg.bdta.pro/images/decc038e5c1b9cbfef302ecfc7f389db.jpg'),
(30016, 2057, 'Cosmos Mundos Possiveis S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129225.mp4', 'http://timg.bdta.pro/images/41259fca1b71571ffcf8bb9a7450f967.jpg'),
(30017, 2057, 'Cosmos Mundos Possiveis S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129226.mp4', 'http://timg.bdta.pro/images/7147256977305ace07f12d37325a2eee.jpg'),
(30018, 2057, 'Cosmos Mundos Possiveis S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129227.mp4', 'http://timg.bdta.pro/images/bc88a8bdf032463227016ac92cc6abe4.jpg'),
(30019, 2057, 'Cosmos Mundos Possiveis S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129228.mp4', 'http://timg.bdta.pro/images/7001acb9eb52e305fc15408efcc4c417.jpg'),
(30020, 2057, 'Cosmos Mundos Possiveis S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129229.mp4', 'http://timg.bdta.pro/images/fef0771af5cebadf2f076ea44ba6bb8a.jpg'),
(30021, 2057, 'Cosmos Mundos Possiveis S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129230.mp4', 'http://timg.bdta.pro/images/1fbaab0652fe84a421f0cf89ac2749f1.jpg'),
(30022, 2057, 'Cosmos Mundos Possiveis S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129231.mp4', 'http://timg.bdta.pro/images/f3951c9b686c2fbaa2f7d6c0dba0a5fc.jpg'),
(30023, 2058, 'Counterpart: Mundo Paralelo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114378.mp4', 'http://timg.bdta.pro/images/7535c59d7495fcf2db1785d427c648c2.jpg'),
(30024, 2058, 'Counterpart: Mundo Paralelo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114379.mp4', 'http://timg.bdta.pro/images/76a4e19ab20d5424415dc071b163785c.jpg'),
(30025, 2058, 'Counterpart: Mundo Paralelo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114380.mp4', 'http://timg.bdta.pro/images/d43acba9b4519e2d9fc0aee1f9b0c159.jpg'),
(30026, 2058, 'Counterpart: Mundo Paralelo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114381.mp4', 'http://timg.bdta.pro/images/ab4c699701cbd867c10579871b39e152.jpg'),
(30027, 2058, 'Counterpart: Mundo Paralelo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114382.mp4', 'http://timg.bdta.pro/images/30f1f12adfc1bd1a5a8a86510d73f5e8.jpg'),
(30028, 2058, 'Counterpart: Mundo Paralelo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114383.mp4', 'http://timg.bdta.pro/images/a362dca3423228e3663135806a50046e.jpg'),
(30029, 2058, 'Counterpart: Mundo Paralelo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114384.mp4', 'http://timg.bdta.pro/images/723b4aee0aefc30ed9cd6e8c679a98e5.jpg'),
(30030, 2058, 'Counterpart: Mundo Paralelo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114385.mp4', 'http://timg.bdta.pro/images/1bca19e1eeda394ca2eeca6a5cd8a14e.jpg'),
(30031, 2058, 'Counterpart: Mundo Paralelo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114386.mp4', 'http://timg.bdta.pro/images/438f3aee7cfd3c3a2fc5d146bc6c47a1.jpg'),
(30032, 2058, 'Counterpart: Mundo Paralelo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114387.mp4', 'http://timg.bdta.pro/images/46670f48bb9e3eff83da399cb7696585.jpg'),
(30033, 2059, 'Counterpart: Mundo Paralelo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114388.mp4', 'http://timg.bdta.pro/images/c4b95a9289e7efe692a4e4d6c0581e0c.jpg'),
(30034, 2059, 'Counterpart: Mundo Paralelo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114389.mp4', 'http://timg.bdta.pro/images/21f5962eaadce5b81b549416b50c1971.jpg'),
(30035, 2059, 'Counterpart: Mundo Paralelo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114390.mp4', 'http://timg.bdta.pro/images/113b5f3baa12aec165bdb6423d8b1b36.jpg'),
(30036, 2059, 'Counterpart: Mundo Paralelo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114391.mp4', 'http://timg.bdta.pro/images/a28a6a4102dc75608156c15f0251453d.jpg'),
(30037, 2059, 'Counterpart: Mundo Paralelo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114392.mp4', 'http://timg.bdta.pro/images/dd31654b92a14e82941eadf443528fb7.jpg'),
(30038, 2059, 'Counterpart: Mundo Paralelo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114393.mp4', 'http://timg.bdta.pro/images/285db192b1f372b01f71d1ddd787128a.jpg'),
(30039, 2059, 'Counterpart: Mundo Paralelo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114394.mp4', 'http://timg.bdta.pro/images/594ae18b792fe8c42b2f058ea6c0ca4f.jpg'),
(30040, 2059, 'Counterpart: Mundo Paralelo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114395.mp4', 'http://timg.bdta.pro/images/3880841318e8fe11917f7c7d5cc0c33b.jpg'),
(30041, 2059, 'Counterpart: Mundo Paralelo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114396.mp4', 'http://timg.bdta.pro/images/c2651b0820400d9cba67dbfdd1e9c942.jpg'),
(30042, 2059, 'Counterpart: Mundo Paralelo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114397.mp4', 'http://timg.bdta.pro/images/0937305830cce82a861464bb333652ca.jpg'),
(30043, 2060, 'Crimes do Colarinho Branco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114297.mp4', 'http://timg.bdta.pro/images/0bc18fdb5a1bc2740167343e70e87d05.jpg'),
(30044, 2060, 'Crimes do Colarinho Branco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114298.mp4', 'http://timg.bdta.pro/images/95afbbc82016e9bf6e208dd80f084a73.jpg'),
(30045, 2060, 'Crimes do Colarinho Branco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114299.mp4', 'http://timg.bdta.pro/images/c6fcf2036e5414776b56e23df7e55bf8.jpg'),
(30046, 2060, 'Crimes do Colarinho Branco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114300.mp4', 'http://timg.bdta.pro/images/cc22fb98bf0a690f5d5caa971f3369d6.jpg'),
(30047, 2060, 'Crimes do Colarinho Branco S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114301.mp4', 'http://timg.bdta.pro/images/600a9fabce455a766623a618d0899e33.jpg'),
(30048, 2060, 'Crimes do Colarinho Branco S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114302.mp4', 'http://timg.bdta.pro/images/38d2fad855fc182d0012cba9d37b78ff.jpg'),
(30049, 2060, 'Crimes do Colarinho Branco S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114303.mp4', 'http://timg.bdta.pro/images/11e906c2c301c51ef1b03cf6473aa8bf.jpg'),
(30050, 2060, 'Crimes do Colarinho Branco S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114304.mp4', 'http://timg.bdta.pro/images/b24a82dfce008431c67628c715e4a81a.jpg'),
(30051, 2060, 'Crimes do Colarinho Branco S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114305.mp4', 'http://timg.bdta.pro/images/69b1f8971ab155abf481063449e2408b.jpg'),
(30052, 2060, 'Crimes do Colarinho Branco S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114306.mp4', 'http://timg.bdta.pro/images/241a103f951f6cd36a35c9a16000f440.jpg'),
(30053, 2060, 'Crimes do Colarinho Branco S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114307.mp4', 'http://timg.bdta.pro/images/15eafba9c49bd1869e7d676db413cf53.jpg'),
(30054, 2060, 'Crimes do Colarinho Branco S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114308.mp4', 'http://timg.bdta.pro/images/aea9682c5586f0443e9f5ea4abcde1d3.jpg'),
(30055, 2060, 'Crimes do Colarinho Branco S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114309.mp4', 'http://timg.bdta.pro/images/ee733c37e65bcb18a979b6917645c99d.jpg'),
(30056, 2060, 'Crimes do Colarinho Branco S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/114310.mp4', 'http://timg.bdta.pro/images/b5259af2ae536454b3e9a950c994b8cf.jpg'),
(30057, 2061, 'Crimes do Colarinho Branco S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114311.mp4', 'http://timg.bdta.pro/images/bd133eb3a010b1a189f572525152bdf8.jpg'),
(30058, 2061, 'Crimes do Colarinho Branco S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114312.mp4', 'http://timg.bdta.pro/images/b1004486f7c65ee0a8d5d104463b7aff.jpg'),
(30059, 2061, 'Crimes do Colarinho Branco S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114313.mp4', 'http://timg.bdta.pro/images/7ac9300ad68b462d10a101c06cb96cf7.jpg'),
(30060, 2061, 'Crimes do Colarinho Branco S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114314.mp4', 'http://timg.bdta.pro/images/fa74027fcd1d4c482b475f99ea0883d9.jpg'),
(30061, 2061, 'Crimes do Colarinho Branco S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114315.mp4', 'http://timg.bdta.pro/images/0fe4ab3c5c6568da351eac5f6e423138.jpg'),
(30062, 2061, 'Crimes do Colarinho Branco S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114316.mp4', 'http://timg.bdta.pro/images/cf7b569d5a409ac0c658539c093eace5.jpg'),
(30063, 2061, 'Crimes do Colarinho Branco S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114317.mp4', 'http://timg.bdta.pro/images/6bee23ba1760a7e3277bf3e569116b2e.jpg'),
(30064, 2061, 'Crimes do Colarinho Branco S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114318.mp4', 'http://timg.bdta.pro/images/e77c71d6b971d3935aa51d16fbcc2d04.jpg'),
(30065, 2061, 'Crimes do Colarinho Branco S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114319.mp4', 'http://timg.bdta.pro/images/619a0f9205cc11110ef8f3320bf81bd4.jpg'),
(30066, 2061, 'Crimes do Colarinho Branco S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114320.mp4', 'http://timg.bdta.pro/images/6ff44109ad243c6081bf492d7ca67a7f.jpg'),
(30067, 2061, 'Crimes do Colarinho Branco S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114321.mp4', 'http://timg.bdta.pro/images/3858f433a7042f5059663148132de26f.jpg'),
(30068, 2061, 'Crimes do Colarinho Branco S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114322.mp4', 'http://timg.bdta.pro/images/04631d68efa0965dcfef46101ccf0467.jpg'),
(30069, 2061, 'Crimes do Colarinho Branco S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114323.mp4', 'http://timg.bdta.pro/images/e8842f6e2d59451eada1a56096a13bbf.jpg'),
(30070, 2061, 'Crimes do Colarinho Branco S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/114324.mp4', 'http://timg.bdta.pro/images/303f15b893321e23212f2c0064976499.jpg'),
(30071, 2061, 'Crimes do Colarinho Branco S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/114325.mp4', 'http://timg.bdta.pro/images/a8977cd7a5446e9ce6d130aeb9449aed.jpg'),
(30072, 2061, 'Crimes do Colarinho Branco S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/114326.mp4', 'http://timg.bdta.pro/images/4adcaf9ba7804c23e7f4d97496fe304b.jpg'),
(30073, 2062, 'Crimes do Colarinho Branco S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114327.mp4', 'http://timg.bdta.pro/images/ec6eed5191b22523181b93e66ff9ad2f.jpg'),
(30074, 2062, 'Crimes do Colarinho Branco S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114328.mp4', 'http://timg.bdta.pro/images/fdaa1abe7645ce46cf4ef2de53c2b2d7.jpg'),
(30075, 2062, 'Crimes do Colarinho Branco S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114329.mp4', 'http://timg.bdta.pro/images/715e3289aa120b1c495611752318c6d2.jpg'),
(30076, 2062, 'Crimes do Colarinho Branco S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114330.mp4', 'http://timg.bdta.pro/images/b999e56926f7c339d60ad15fc86c4127.jpg'),
(30077, 2062, 'Crimes do Colarinho Branco S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114331.mp4', 'http://timg.bdta.pro/images/bd5a9c2d41fd7990310dbae8b1a1380c.jpg'),
(30078, 2062, 'Crimes do Colarinho Branco S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114332.mp4', 'http://timg.bdta.pro/images/ee7a88d82fa30dc248d4ad404408ea98.jpg'),
(30079, 2062, 'Crimes do Colarinho Branco S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114333.mp4', 'http://timg.bdta.pro/images/24a9d7b88cae1691c996d4dee9cb7770.jpg'),
(30080, 2062, 'Crimes do Colarinho Branco S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114334.mp4', 'http://timg.bdta.pro/images/b98485f70a94e124ce70be1a82766671.jpg'),
(30081, 2062, 'Crimes do Colarinho Branco S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114335.mp4', 'http://timg.bdta.pro/images/6cf0f8e11164c3c5d63e58d2ec93e112.jpg'),
(30082, 2062, 'Crimes do Colarinho Branco S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114336.mp4', 'http://timg.bdta.pro/images/a0011092168c40c09fbfac82c749f68c.jpg'),
(30083, 2062, 'Crimes do Colarinho Branco S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114337.mp4', 'http://timg.bdta.pro/images/d98a401f397196a863be1a00376e3e8d.jpg'),
(30084, 2062, 'Crimes do Colarinho Branco S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114338.mp4', 'http://timg.bdta.pro/images/bf14cbec7da60affb1c961c826d8dbc6.jpg'),
(30085, 2062, 'Crimes do Colarinho Branco S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114339.mp4', 'http://timg.bdta.pro/images/8467ff8408abbca7a6e6e269555e5172.jpg'),
(30086, 2062, 'Crimes do Colarinho Branco S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/114340.mp4', 'http://timg.bdta.pro/images/9632392ec5287fad79ec63991af3cc5c.jpg'),
(30087, 2062, 'Crimes do Colarinho Branco S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/114341.mp4', 'http://timg.bdta.pro/images/4cf28e1321e8aad5155bb2a5f4dc5d64.jpg'),
(30088, 2062, 'Crimes do Colarinho Branco S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/114342.mp4', 'http://timg.bdta.pro/images/cc12101ab78d2b2860cb0a82234aa523.jpg'),
(30089, 2063, 'Crimes do Colarinho Branco S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114343.mp4', 'http://timg.bdta.pro/images/4ba889ff4c3e6618b7a373238d8058c7.jpg'),
(30090, 2063, 'Crimes do Colarinho Branco S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114344.mp4', 'http://timg.bdta.pro/images/e949f49b8c54cc274a4b42384e29efc7.jpg'),
(30091, 2063, 'Crimes do Colarinho Branco S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114345.mp4', 'http://timg.bdta.pro/images/0bf754c6a8f13388f329010bf217a690.jpg'),
(30092, 2063, 'Crimes do Colarinho Branco S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114346.mp4', 'http://timg.bdta.pro/images/a56659e027a0fab8afdf669d3dd9b6ec.jpg'),
(30093, 2063, 'Crimes do Colarinho Branco S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114347.mp4', 'http://timg.bdta.pro/images/5cb09fd18f0eec4b5464696e0b9d3959.jpg'),
(30094, 2063, 'Crimes do Colarinho Branco S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114348.mp4', 'http://timg.bdta.pro/images/4691229b935cf87808b5e88e5ef1c171.jpg'),
(30095, 2063, 'Crimes do Colarinho Branco S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114349.mp4', 'http://timg.bdta.pro/images/3fbeaab788bcff13479712242ad306d9.jpg'),
(30096, 2063, 'Crimes do Colarinho Branco S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114350.mp4', 'http://timg.bdta.pro/images/42c23154ec795e10dff53ecb6266e6ca.jpg'),
(30097, 2063, 'Crimes do Colarinho Branco S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114351.mp4', 'http://timg.bdta.pro/images/a04ab29b94b569f3d0ab553ceec73749.jpg'),
(30098, 2063, 'Crimes do Colarinho Branco S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114352.mp4', 'http://timg.bdta.pro/images/0b17dc3d19177c79954809254d0ef5d1.jpg'),
(30099, 2063, 'Crimes do Colarinho Branco S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114353.mp4', 'http://timg.bdta.pro/images/ad399107c1ae83fbda2b8c63519fab37.jpg'),
(30100, 2063, 'Crimes do Colarinho Branco S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114354.mp4', 'http://timg.bdta.pro/images/4b60a46489c296eb8ebe38ccc73230a6.jpg'),
(30101, 2063, 'Crimes do Colarinho Branco S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114355.mp4', 'http://timg.bdta.pro/images/93784f5676bb19f440109ec7b4046a79.jpg'),
(30102, 2063, 'Crimes do Colarinho Branco S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/114356.mp4', 'http://timg.bdta.pro/images/cbc772c9a8bd5812a5c78245e1256619.jpg'),
(30103, 2063, 'Crimes do Colarinho Branco S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/114357.mp4', 'http://timg.bdta.pro/images/5fe9c910e57a83bcb291db000ad5b9ed.jpg'),
(30104, 2063, 'Crimes do Colarinho Branco S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/114358.mp4', 'http://timg.bdta.pro/images/53fea095a53d54fbbb8d87211dcd3c43.jpg'),
(30105, 2064, 'Crimes do Colarinho Branco S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114359.mp4', 'http://timg.bdta.pro/images/c3849f6d5fa5a1b344071da96907ae52.jpg'),
(30106, 2064, 'Crimes do Colarinho Branco S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114360.mp4', 'http://timg.bdta.pro/images/bb8f92a68305fe73043b242b8bcbea90.jpg'),
(30107, 2064, 'Crimes do Colarinho Branco S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114361.mp4', 'http://timg.bdta.pro/images/921041d9cbc7eb80d15a568337fef356.jpg'),
(30108, 2064, 'Crimes do Colarinho Branco S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114362.mp4', 'http://timg.bdta.pro/images/271cf1b30aa3b634e1f26f82b3dec096.jpg'),
(30109, 2064, 'Crimes do Colarinho Branco S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114363.mp4', 'http://timg.bdta.pro/images/8f2bfdb7d451bd1710247b453257244c.jpg'),
(30110, 2064, 'Crimes do Colarinho Branco S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114364.mp4', 'http://timg.bdta.pro/images/428a955629e3b0324a64d325c11e8927.jpg'),
(30111, 2064, 'Crimes do Colarinho Branco S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114365.mp4', 'http://timg.bdta.pro/images/8e3812d3bdf2b830a8163764d447588e.jpg'),
(30112, 2064, 'Crimes do Colarinho Branco S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114366.mp4', 'http://timg.bdta.pro/images/1d20f4ba287662e5f6418d643212af24.jpg'),
(30113, 2064, 'Crimes do Colarinho Branco S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114367.mp4', 'http://timg.bdta.pro/images/39d05e90b9e495bdb2e85fd77b1fde48.jpg'),
(30114, 2064, 'Crimes do Colarinho Branco S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114368.mp4', 'http://timg.bdta.pro/images/e252a1ca324b36526b4788df1729f97b.jpg'),
(30115, 2064, 'Crimes do Colarinho Branco S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114369.mp4', 'http://timg.bdta.pro/images/ab875776620c4ae5937816cb68094088.jpg'),
(30116, 2064, 'Crimes do Colarinho Branco S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114370.mp4', 'http://timg.bdta.pro/images/e4f8f0ec581f22909d884e13d16cc336.jpg'),
(30117, 2064, 'Crimes do Colarinho Branco S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114371.mp4', 'http://timg.bdta.pro/images/24de07f45ce0782e118ee5ce28fca339.jpg'),
(30118, 2065, 'Crimes do Colarinho Branco S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114372.mp4', 'http://timg.bdta.pro/images/92811a529401ded12817c7eef80dfa54.jpg'),
(30119, 2065, 'Crimes do Colarinho Branco S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114373.mp4', 'http://timg.bdta.pro/images/34e047ec5f05a47ce64cc3ae2f1ef082.jpg'),
(30120, 2065, 'Crimes do Colarinho Branco S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114374.mp4', 'http://timg.bdta.pro/images/cbb9a60c730f73b88e2e190bb534c8c6.jpg'),
(30121, 2065, 'Crimes do Colarinho Branco S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114375.mp4', 'http://timg.bdta.pro/images/118100e2f5a61f83b22557f944366173.jpg'),
(30122, 2065, 'Crimes do Colarinho Branco S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114376.mp4', 'http://timg.bdta.pro/images/ea6ec64c70f3bf8ce5d049a93c138d53.jpg'),
(30123, 2065, 'Crimes do Colarinho Branco S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114377.mp4', 'http://timg.bdta.pro/images/246de21c899b01545c4f62767f4267df.jpg'),
(30124, 2066, 'Das Boot - O Barco Inferno No Mar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195685.mp4', 'http://timg.bdta.pro/images/e34a335ad48a07a8372f8813a632145d.jpg'),
(30125, 2066, 'Das Boot - O Barco Inferno No Mar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195686.mp4', 'http://timg.bdta.pro/images/222206cf8108f998bccba604dfab1939.jpg'),
(30126, 2066, 'Das Boot - O Barco Inferno No Mar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195687.mp4', 'http://timg.bdta.pro/images/9369bad1a4ac04dd618f7bc009c3208c.jpg'),
(30127, 2066, 'Das Boot - O Barco Inferno No Mar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195688.mp4', 'http://timg.bdta.pro/images/fca85deff25d85daa9e755d682faa876.jpg'),
(30128, 2066, 'Das Boot - O Barco Inferno No Mar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195689.mp4', 'http://timg.bdta.pro/images/58ce635aed4f0a7d7dc768b86ab8f29b.jpg'),
(30129, 2066, 'Das Boot - O Barco Inferno No Mar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195690.mp4', 'http://timg.bdta.pro/images/abfa0ef27bcb42cd09225547e3ca9d91.jpg'),
(30130, 2066, 'Das Boot - O Barco Inferno No Mar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195691.mp4', 'http://timg.bdta.pro/images/1d996bd215e1c548b3c4f894fa931fdd.jpg'),
(30131, 2066, 'Das Boot - O Barco Inferno No Mar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195692.mp4', 'http://timg.bdta.pro/images/a5481a1aa065efae1038c160a63e1c42.jpg'),
(30132, 2067, 'Das Boot - O Barco Inferno No Mar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195693.mp4', 'http://timg.bdta.pro/images/42507ab1a143c2704baac2512d198c4b.jpg'),
(30133, 2067, 'Das Boot - O Barco Inferno No Mar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195694.mp4', 'http://timg.bdta.pro/images/4388c9d15d0139fb8a7562df84598aa5.jpg'),
(30134, 2067, 'Das Boot - O Barco Inferno No Mar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195695.mp4', 'http://timg.bdta.pro/images/2d910d1098ebe06b0d98e23ab86818ee.jpg'),
(30135, 2067, 'Das Boot - O Barco Inferno No Mar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195696.mp4', 'http://timg.bdta.pro/images/53064467ea04ab5adc8d46b8b48c673c.jpg'),
(30136, 2067, 'Das Boot - O Barco Inferno No Mar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195697.mp4', 'http://timg.bdta.pro/images/8f68b173b336ea6982064a2a3acedc7a.jpg'),
(30137, 2067, 'Das Boot - O Barco Inferno No Mar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195698.mp4', 'http://timg.bdta.pro/images/af24ed53ebf6bc0753de6c3b10b74be0.jpg'),
(30138, 2067, 'Das Boot - O Barco Inferno No Mar S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195699.mp4', 'http://timg.bdta.pro/images/606f6d2d9827eb65afaaf354e686caa3.jpg'),
(30139, 2067, 'Das Boot - O Barco Inferno No Mar S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195700.mp4', 'http://timg.bdta.pro/images/760724f0ba9fce0aea58abeec0cdd101.jpg'),
(30140, 2068, 'Das Boot - O Barco Inferno No Mar S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195701.mp4', 'http://timg.bdta.pro/images/84bd75c30fc2fa18f517d57c7cc330ac.jpg'),
(30141, 2068, 'Das Boot - O Barco Inferno No Mar S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195702.mp4', 'http://timg.bdta.pro/images/d40a9cc96d84a010874fdef591c3f17b.jpg'),
(30142, 2068, 'Das Boot - O Barco Inferno No Mar S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195703.mp4', 'http://timg.bdta.pro/images/d80a1e762e79d3c853d4e60897e10f6e.jpg'),
(30143, 2068, 'Das Boot - O Barco Inferno No Mar S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195704.mp4', 'http://timg.bdta.pro/images/07b03d1ea93712d35b4d4f6451e7248c.jpg'),
(30144, 2068, 'Das Boot - O Barco Inferno No Mar S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195705.mp4', 'http://timg.bdta.pro/images/bc3cec6ad16771afba8a8a4307ada741.jpg'),
(30145, 2068, 'Das Boot - O Barco Inferno No Mar S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195706.mp4', 'http://timg.bdta.pro/images/fd04528ede4684f6ddb415baaeced114.jpg'),
(30146, 2068, 'Das Boot - O Barco Inferno No Mar S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195707.mp4', 'http://timg.bdta.pro/images/5f54e6f7b6b3f5a561d57ae930834d98.jpg'),
(30147, 2068, 'Das Boot - O Barco Inferno No Mar S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195708.mp4', 'http://timg.bdta.pro/images/7f840b9a43809ae5ac7a8f1759dd176e.jpg'),
(30148, 2068, 'Das Boot - O Barco Inferno No Mar S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195709.mp4', 'http://timg.bdta.pro/images/ac9852548c47d60f31d20b9f682d7f75.jpg'),
(30149, 2068, 'Das Boot - O Barco Inferno No Mar S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195710.mp4', 'http://timg.bdta.pro/images/c864c1cfe99f38a174bc748e9696be5b.jpg'),
(30150, 2069, 'Death Note S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114260.mp4', 'http://timg.bdta.pro/images/f52c2309ec0fcab116d703d684c70d95.jpg'),
(30151, 2069, 'Death Note S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114261.mp4', 'http://timg.bdta.pro/images/1639b88f293cddae46501214a6c04aed.jpg'),
(30152, 2069, 'Death Note S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114262.mp4', 'http://timg.bdta.pro/images/099dd3c9848226e9b7b19e0b7f58ae57.jpg'),
(30153, 2069, 'Death Note S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114263.mp4', 'http://timg.bdta.pro/images/d32005c9b1754888e1d85acc388e2427.jpg'),
(30154, 2069, 'Death Note S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114264.mp4', 'http://timg.bdta.pro/images/9cbc4a3d6873aa99c009e5e075b8cba8.jpg'),
(30155, 2069, 'Death Note S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114265.mp4', 'http://timg.bdta.pro/images/61fe8efabd6d2e7271c7a7d5fa1d1ed0.jpg'),
(30156, 2069, 'Death Note S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114266.mp4', 'http://timg.bdta.pro/images/1aecbc2f8e10d08aad80ee3341390fa8.jpg'),
(30157, 2069, 'Death Note S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114267.mp4', 'http://timg.bdta.pro/images/185071f4ad8b8b86efff10bea89426fb.jpg'),
(30158, 2069, 'Death Note S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114268.mp4', 'http://timg.bdta.pro/images/b26dbd15fc0a8b1ffaaa69f62f681c82.jpg'),
(30159, 2069, 'Death Note S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114269.mp4', 'http://timg.bdta.pro/images/569f67a5399fc734ad1e2209b56450ff.jpg'),
(30160, 2069, 'Death Note S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114270.mp4', 'http://timg.bdta.pro/images/0c477a6620d2c50a1023f2fcca288edd.jpg'),
(30161, 2069, 'Death Note S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114271.mp4', 'http://timg.bdta.pro/images/dff815fcacec5b79e35a9307838d0da5.jpg'),
(30162, 2069, 'Death Note S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114272.mp4', 'http://timg.bdta.pro/images/fa0401098e666dfc336a898d4d644d49.jpg'),
(30163, 2069, 'Death Note S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/114273.mp4', 'http://timg.bdta.pro/images/81be43e083b74a5b75e82b4f9a6f27a8.jpg'),
(30164, 2069, 'Death Note S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/114274.mp4', 'http://timg.bdta.pro/images/cb61d973b3758ad865328e16479f5ba5.jpg'),
(30165, 2069, 'Death Note S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/114275.mp4', 'http://timg.bdta.pro/images/a663bd2b239bee9e6fce5a5205f7f93f.jpg'),
(30166, 2069, 'Death Note S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/114276.mp4', 'http://timg.bdta.pro/images/b4d5697a798944155856bde9923f6662.jpg'),
(30167, 2069, 'Death Note S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/114277.mp4', 'http://timg.bdta.pro/images/0b079e2c43654b574c8d81c35e05595f.jpg'),
(30168, 2069, 'Death Note S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/114278.mp4', 'http://timg.bdta.pro/images/08cf3339873ae3b09a3118fa63efcd73.jpg'),
(30169, 2069, 'Death Note S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/114279.mp4', 'http://timg.bdta.pro/images/a6a53a133e83444086ca33c30f50ff11.jpg'),
(30170, 2069, 'Death Note S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/114280.mp4', 'http://timg.bdta.pro/images/b687ff1046a5656287055122fe98789f.jpg'),
(30171, 2069, 'Death Note S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/114281.mp4', 'http://timg.bdta.pro/images/4e3d3e0456a7a9bee1a2d6dcf1135fb6.jpg'),
(30172, 2069, 'Death Note S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/114282.mp4', 'http://timg.bdta.pro/images/df7086fe4624b8f68c462426c9cab5ae.jpg'),
(30173, 2069, 'Death Note S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/114283.mp4', 'http://timg.bdta.pro/images/3def6ec7cebc9819539b8b399e283556.jpg'),
(30174, 2069, 'Death Note S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/114284.mp4', 'http://timg.bdta.pro/images/7369cd83499a60499e163e800be843f5.jpg'),
(30175, 2069, 'Death Note S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/114285.mp4', 'http://timg.bdta.pro/images/35709f4c2d69b7fd669630cbc88f8211.jpg'),
(30176, 2069, 'Death Note S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/114286.mp4', 'http://timg.bdta.pro/images/239a6706e3d7218e05a1a63bb4680d0a.jpg'),
(30177, 2069, 'Death Note S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/114287.mp4', 'http://timg.bdta.pro/images/ad7e18c63a4266e49684e9247d8e64e2.jpg'),
(30178, 2069, 'Death Note S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/114288.mp4', 'http://timg.bdta.pro/images/52a98ff1f2ee13bdea5222984df7c950.jpg'),
(30179, 2069, 'Death Note S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/114289.mp4', 'http://timg.bdta.pro/images/7e19f148c614f337b53616c8d572d3ff.jpg'),
(30180, 2069, 'Death Note S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/114290.mp4', 'http://timg.bdta.pro/images/df384b9dc509069730d85024579956e7.jpg'),
(30181, 2069, 'Death Note S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/114291.mp4', 'http://timg.bdta.pro/images/5240533f803bbfa7c3b4ce16c7d45aa5.jpg'),
(30182, 2069, 'Death Note S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/114292.mp4', 'http://timg.bdta.pro/images/6a445803c1cd7dab8422c7142c5140c8.jpg'),
(30183, 2069, 'Death Note S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/114293.mp4', 'http://timg.bdta.pro/images/38bc635157ee441c37a551725e690402.jpg'),
(30184, 2069, 'Death Note S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/114294.mp4', 'http://timg.bdta.pro/images/0ee9dfcb933d867e5ea00f6e33b39a27.jpg'),
(30185, 2069, 'Death Note S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/114295.mp4', 'http://timg.bdta.pro/images/3f39b6f936269bd61ed22f5f5fa38671.jpg'),
(30186, 2069, 'Death Note S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/114296.mp4', 'http://timg.bdta.pro/images/f5a716aacc6a868001ac066d7efd9ac2.jpg'),
(30187, 2070, 'Diario de Um Confinado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114254.mp4', 'http://gstaticontent.com/images/r43MlYCteQkXGkhFL7xw5YiFdd7_big.jpg'),
(30188, 2070, 'Diario de Um Confinado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114255.mp4', 'http://gstaticontent.com/images/r43MlYCteQkXGkhFL7xw5YiFdd7_big.jpg'),
(30189, 2070, 'Diario de Um Confinado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114256.mp4', 'http://gstaticontent.com/images/r43MlYCteQkXGkhFL7xw5YiFdd7_big.jpg'),
(30190, 2070, 'Diario de Um Confinado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114257.mp4', 'http://gstaticontent.com/images/r43MlYCteQkXGkhFL7xw5YiFdd7_big.jpg'),
(30191, 2070, 'Diario de Um Confinado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114258.mp4', 'http://gstaticontent.com/images/r43MlYCteQkXGkhFL7xw5YiFdd7_big.jpg'),
(30192, 2070, 'Diario de Um Confinado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114259.mp4', 'http://gstaticontent.com/images/r43MlYCteQkXGkhFL7xw5YiFdd7_big.jpg'),
(30193, 2071, 'Disque Amiga para Matar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114234.mp4', 'http://timg.bdta.pro/images/de954662af4ed76a647a5d80cc832576.jpg'),
(30194, 2071, 'Disque Amiga para Matar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114235.mp4', 'http://timg.bdta.pro/images/8c97a3734b6ad9730c748e6007d8c48d.jpg'),
(30195, 2071, 'Disque Amiga para Matar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114236.mp4', 'http://timg.bdta.pro/images/ddb356555a8023b90d314b82978e1129.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(30196, 2071, 'Disque Amiga para Matar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114237.mp4', 'http://timg.bdta.pro/images/be4da18ce3d63db1141157a4b56b804f.jpg'),
(30197, 2071, 'Disque Amiga para Matar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114238.mp4', 'http://timg.bdta.pro/images/a64e6bedb045b72687d57c8719f96750.jpg'),
(30198, 2071, 'Disque Amiga para Matar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114239.mp4', 'http://timg.bdta.pro/images/1d0a08352f52f9e5edf48a6870ccc09d.jpg'),
(30199, 2071, 'Disque Amiga para Matar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114240.mp4', 'http://timg.bdta.pro/images/01467ea0d98ac319fedb0233cd12ab36.jpg'),
(30200, 2071, 'Disque Amiga para Matar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114241.mp4', 'http://timg.bdta.pro/images/ea2a12032a528b92a5f55a5e07bd3c9b.jpg'),
(30201, 2071, 'Disque Amiga para Matar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114242.mp4', 'http://timg.bdta.pro/images/677b1573fdedd67fadd5011b903594db.jpg'),
(30202, 2071, 'Disque Amiga para Matar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114243.mp4', 'http://gstaticontent.com/images/skSSGAaqPDgftcqjY5gY9lEZ5Kk_big.jpg'),
(30203, 2072, 'Disque Amiga para Matar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114244.mp4', 'http://gstaticontent.com/images/skSSGAaqPDgftcqjY5gY9lEZ5Kk_big.jpg'),
(30204, 2072, 'Disque Amiga para Matar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114245.mp4', 'http://gstaticontent.com/images/skSSGAaqPDgftcqjY5gY9lEZ5Kk_big.jpg'),
(30205, 2072, 'Disque Amiga para Matar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114246.mp4', 'http://gstaticontent.com/images/skSSGAaqPDgftcqjY5gY9lEZ5Kk_big.jpg'),
(30206, 2072, 'Disque Amiga para Matar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114247.mp4', 'http://gstaticontent.com/images/skSSGAaqPDgftcqjY5gY9lEZ5Kk_big.jpg'),
(30207, 2072, 'Disque Amiga para Matar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114248.mp4', 'http://gstaticontent.com/images/skSSGAaqPDgftcqjY5gY9lEZ5Kk_big.jpg'),
(30208, 2072, 'Disque Amiga para Matar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114249.mp4', 'http://timg.bdta.pro/images/af6acc7ff1819df597559c51b111fa64.jpg'),
(30209, 2072, 'Disque Amiga para Matar S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114250.mp4', 'http://timg.bdta.pro/images/7eb52803f13cede19ac73f0d5bae1338.jpg'),
(30210, 2072, 'Disque Amiga para Matar S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114251.mp4', 'http://timg.bdta.pro/images/36ad5ae1026544d66491967c97f50d4b.jpg'),
(30211, 2072, 'Disque Amiga para Matar S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114252.mp4', 'http://timg.bdta.pro/images/63c544903cc662258a7cce381b8899fd.jpg'),
(30212, 2072, 'Disque Amiga para Matar S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114253.mp4', 'http://timg.bdta.pro/images/51de51583a6480b0cef42cd6fe4caad2.jpg'),
(30213, 2073, 'Dorohedoro [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114222.mp4', 'http://timg.bdta.pro/images/a49dbf05cf1d57f965928ff2b9461e2c.jpg'),
(30214, 2073, 'Dorohedoro [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114223.mp4', 'http://timg.bdta.pro/images/bc990e9f6e77c3830b8bb7c9463c3472.jpg'),
(30215, 2073, 'Dorohedoro [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114224.mp4', 'http://timg.bdta.pro/images/c032d28ee38ff539a5c7b611cd9e7826.jpg'),
(30216, 2073, 'Dorohedoro [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114225.mp4', 'http://timg.bdta.pro/images/4231911b9c2557913799fdc80f1f2b67.jpg'),
(30217, 2073, 'Dorohedoro [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114226.mp4', 'http://timg.bdta.pro/images/dc0e2f3d44d5a1cea33e67f894ee34eb.jpg'),
(30218, 2073, 'Dorohedoro [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114227.mp4', 'http://timg.bdta.pro/images/57e514ae242deb014c8902405ef25cd3.jpg'),
(30219, 2073, 'Dorohedoro [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114228.mp4', 'http://timg.bdta.pro/images/1ad34a724fdf8f60ff60afcd0a224e24.jpg'),
(30220, 2073, 'Dorohedoro [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114229.mp4', 'http://timg.bdta.pro/images/612bd9b8c0bed683960588007fd1162b.jpg'),
(30221, 2073, 'Dorohedoro [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114230.mp4', 'http://timg.bdta.pro/images/adfb95228cb2520bf65c03213dcd51ed.jpg'),
(30222, 2073, 'Dorohedoro [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114231.mp4', 'http://timg.bdta.pro/images/e8677aa7d3e2a8f656a4a1ec8bfd2f77.jpg'),
(30223, 2073, 'Dorohedoro [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114232.mp4', 'http://timg.bdta.pro/images/0008ce0c35acb1e12f72b6fc1f7f84c9.jpg'),
(30224, 2073, 'Dorohedoro [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114233.mp4', 'http://timg.bdta.pro/images/b14276b789b542445ab596bc02b39ad5.jpg'),
(30225, 2074, 'Duncanville S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/564473.mp4', 'http://gstaticontent.com/images/d0da7456c1cc32dc39447e529299e60b.jpg'),
(30226, 2074, 'Duncanville S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201000.mp4', 'http://timg.bdta.pro/images/b3d2fb9e617cf4cccd269cb6a0226d61.jpg'),
(30227, 2074, 'Duncanville S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201001.mp4', 'http://timg.bdta.pro/images/9f53127cb4ad5e4fee0b60885549e26e.jpg'),
(30228, 2074, 'Duncanville S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201002.mp4', 'http://timg.bdta.pro/images/4a9bcfdf0681306de680dff9666a0f73.jpg'),
(30229, 2074, 'Duncanville S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201003.mp4', 'http://timg.bdta.pro/images/6117b4c77bf6574cb899e2316e41d0b4.jpg'),
(30230, 2074, 'Duncanville S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201004.mp4', 'http://timg.bdta.pro/images/c3658036587c93939468f4b804ef8a53.jpg'),
(30231, 2074, 'Duncanville S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201005.mp4', 'http://timg.bdta.pro/images/f57250aba37fe10751c575254ce184fd.jpg'),
(30232, 2074, 'Duncanville S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201006.mp4', 'http://timg.bdta.pro/images/a692446c8d38a884adc37edcc4df0cd2.jpg'),
(30233, 2074, 'Duncanville S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201007.mp4', 'http://timg.bdta.pro/images/2b704ac65dfe392b4ea8aca77d020f2c.jpg'),
(30234, 2074, 'Duncanville S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201008.mp4', 'http://timg.bdta.pro/images/fabb0c65bdf39f7b8b24a5bafa1079cf.jpg'),
(30235, 2074, 'Duncanville S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201009.mp4', 'http://timg.bdta.pro/images/a351bd83fd568ed70ef356857afe60a9.jpg'),
(30236, 2075, 'Duncanville S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201010.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30237, 2075, 'Duncanville S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201011.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30238, 2075, 'Duncanville S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201012.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30239, 2075, 'Duncanville S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201013.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30240, 2075, 'Duncanville S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201014.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30241, 2075, 'Duncanville S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201015.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30242, 2075, 'Duncanville S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201016.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30243, 2075, 'Duncanville S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201017.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30244, 2075, 'Duncanville S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201018.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30245, 2075, 'Duncanville S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201019.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30246, 2075, 'Duncanville S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201020.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30247, 2075, 'Duncanville S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201021.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30248, 2076, 'Duncanville S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201022.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30249, 2076, 'Duncanville S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201023.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30250, 2076, 'Duncanville S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201024.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30251, 2076, 'Duncanville S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201025.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30252, 2076, 'Duncanville S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201026.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30253, 2076, 'Duncanville S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201027.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30254, 2076, 'Duncanville S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201028.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30255, 2076, 'Duncanville S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201029.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30256, 2076, 'Duncanville S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201030.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30257, 2076, 'Duncanville S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201031.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30258, 2076, 'Duncanville S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201032.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30259, 2076, 'Duncanville S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201033.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30260, 2076, 'Duncanville S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201034.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30261, 2076, 'Duncanville S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/201035.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30262, 2076, 'Duncanville S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/201036.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30263, 2076, 'Duncanville S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/201037.mp4', 'http://gstaticontent.com/images/x057rR97LpdrsTn1wcfUkJuJuZJ_big.jpg'),
(30264, 2077, 'Em Nome de Deus S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114216.mp4', 'http://gstaticontent.com/images/pMaOhAC0GJUDrDRwRdILVH7gD3r_big.jpg'),
(30265, 2077, 'Em Nome de Deus S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114217.mp4', 'http://gstaticontent.com/images/pMaOhAC0GJUDrDRwRdILVH7gD3r_big.jpg'),
(30266, 2077, 'Em Nome de Deus S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114218.mp4', 'http://gstaticontent.com/images/pMaOhAC0GJUDrDRwRdILVH7gD3r_big.jpg'),
(30267, 2077, 'Em Nome de Deus S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114219.mp4', 'http://gstaticontent.com/images/pMaOhAC0GJUDrDRwRdILVH7gD3r_big.jpg'),
(30268, 2077, 'Em Nome de Deus S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114220.mp4', 'http://gstaticontent.com/images/pMaOhAC0GJUDrDRwRdILVH7gD3r_big.jpg'),
(30269, 2077, 'Em Nome de Deus S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114221.mp4', 'http://gstaticontent.com/images/pMaOhAC0GJUDrDRwRdILVH7gD3r_big.jpg'),
(30270, 2078, 'Agora Morra: O Caso de Michelle Carter S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114214.mp4', 'http://timg.bdta.pro/images/1102453d62c2995e4da7ea1c46f74de5.jpg'),
(30271, 2078, 'Agora Morra: O Caso de Michelle Carter S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114215.mp4', 'http://timg.bdta.pro/images/cf923d39aeae8a94446994ae4e266137.jpg'),
(30272, 2079, 'Expresso do Amanhã S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176651.mp4', 'http://timg.bdta.pro/images/32967de62b23a3eeef87461dfa13e271.jpg'),
(30273, 2079, 'Expresso do Amanhã S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176652.mp4', 'http://timg.bdta.pro/images/8a9c6111f97c3ab73d94e4efe1adffba.jpg'),
(30274, 2079, 'Expresso do Amanhã S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176653.mp4', 'http://timg.bdta.pro/images/09d210fa5a449712a81b7b70fe96afc3.jpg'),
(30275, 2079, 'Expresso do Amanhã S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176654.mp4', 'http://timg.bdta.pro/images/172e4fc43f0d2df82f09aabd7a98200c.jpg'),
(30276, 2079, 'Expresso do Amanhã S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176655.mp4', 'http://timg.bdta.pro/images/1a03821e84dbdd9aa59d5e8a5ce05163.jpg'),
(30277, 2079, 'Expresso do Amanhã S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176656.mp4', 'http://timg.bdta.pro/images/6bebb7ccbc220531713ee360963ef675.jpg'),
(30278, 2079, 'Expresso do Amanhã S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176657.mp4', 'http://timg.bdta.pro/images/389040ea81bd8925aded5bd4c1759e7b.jpg'),
(30279, 2079, 'Expresso do Amanhã S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176658.mp4', 'http://timg.bdta.pro/images/043b1afb0d14d424dae179777b080dd4.jpg'),
(30280, 2079, 'Expresso do Amanhã S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176659.mp4', 'http://timg.bdta.pro/images/cd3cbec1a3d91c3da2e26442a261a4d0.jpg'),
(30281, 2079, 'Expresso do Amanhã S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176660.mp4', 'http://timg.bdta.pro/images/2b8dd98634c1553afbdc0f2e0d94f935.jpg'),
(30282, 2080, 'Expresso do Amanhã S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176661.mp4', 'http://gstaticontent.com/images/7AoS6Oez4C3z8wRnQVHYLwhY3FX_big.jpg'),
(30283, 2080, 'Expresso do Amanhã S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176662.mp4', 'http://gstaticontent.com/images/7AoS6Oez4C3z8wRnQVHYLwhY3FX_big.jpg'),
(30284, 2080, 'Expresso do Amanhã S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176663.mp4', 'http://gstaticontent.com/images/7AoS6Oez4C3z8wRnQVHYLwhY3FX_big.jpg'),
(30285, 2080, 'Expresso do Amanhã S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176664.mp4', 'http://gstaticontent.com/images/7AoS6Oez4C3z8wRnQVHYLwhY3FX_big.jpg'),
(30286, 2080, 'Expresso do Amanhã S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176665.mp4', 'http://gstaticontent.com/images/7AoS6Oez4C3z8wRnQVHYLwhY3FX_big.jpg'),
(30287, 2080, 'Expresso do Amanhã S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176666.mp4', 'http://gstaticontent.com/images/7AoS6Oez4C3z8wRnQVHYLwhY3FX_big.jpg'),
(30288, 2080, 'Expresso do Amanhã S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176667.mp4', 'http://gstaticontent.com/images/7AoS6Oez4C3z8wRnQVHYLwhY3FX_big.jpg'),
(30289, 2080, 'Expresso do Amanhã S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176668.mp4', 'http://gstaticontent.com/images/7AoS6Oez4C3z8wRnQVHYLwhY3FX_big.jpg'),
(30290, 2080, 'Expresso do Amanhã S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176669.mp4', 'http://gstaticontent.com/images/7AoS6Oez4C3z8wRnQVHYLwhY3FX_big.jpg'),
(30291, 2080, 'Expresso do Amanhã S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176670.mp4', 'http://gstaticontent.com/images/7AoS6Oez4C3z8wRnQVHYLwhY3FX_big.jpg'),
(30292, 2081, 'Expresso do Amanhã S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176671.mp4', 'http://timg.bdta.pro/images/7c73048fe3547308acea5aec213e1355.jpg'),
(30293, 2081, 'Expresso do Amanhã S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176672.mp4', 'http://timg.bdta.pro/images/707059e4ad0baea2b1aa676085f5cc28.jpg'),
(30294, 2081, 'Expresso do Amanhã S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176673.mp4', 'http://timg.bdta.pro/images/13a3e7011785337b60c25334ee097c9a.jpg'),
(30295, 2081, 'Expresso do Amanhã S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176674.mp4', 'http://gstaticontent.com/images/7AoS6Oez4C3z8wRnQVHYLwhY3FX_big.jpg'),
(30296, 2081, 'Expresso do Amanhã S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176675.mp4', 'http://timg.bdta.pro/images/9c87c792f00e60ed44c2cd4baf751c22.jpg'),
(30297, 2081, 'Expresso do Amanhã S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176676.mp4', 'http://timg.bdta.pro/images/75f5400ba7826740e83ac51aac1e6869.jpg'),
(30298, 2081, 'Expresso do Amanhã S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176677.mp4', 'http://timg.bdta.pro/images/46977cf589acd163fa1838cc299b2228.jpg'),
(30299, 2081, 'Expresso do Amanhã S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176678.mp4', 'http://timg.bdta.pro/images/60fc6222ec62cc504f51a8a4ad786990.jpg'),
(30300, 2081, 'Expresso do Amanhã S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176679.mp4', 'http://timg.bdta.pro/images/1b47b430389a2827c5d22be0bc8aeb58.jpg'),
(30301, 2081, 'Expresso do Amanhã S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176680.mp4', 'http://timg.bdta.pro/images/8f5506814ba9343c4540ff6344e20ac8.jpg'),
(30302, 2082, 'Flack S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114208.mp4', 'http://timg.bdta.pro/images/57a7e74d6de6c5c7d2aa4a7839f521a3.jpg'),
(30303, 2082, 'Flack S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114209.mp4', 'http://timg.bdta.pro/images/b6ce9e3ec0584c3800344a1119bb344a.jpg'),
(30304, 2082, 'Flack S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114210.mp4', 'http://gstaticontent.com/images/oT35HHKekg7a4g0VzGBsojOTGJu_big.jpg'),
(30305, 2082, 'Flack S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114211.mp4', 'http://gstaticontent.com/images/oT35HHKekg7a4g0VzGBsojOTGJu_big.jpg'),
(30306, 2082, 'Flack S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114212.mp4', 'http://gstaticontent.com/images/oT35HHKekg7a4g0VzGBsojOTGJu_big.jpg'),
(30307, 2082, 'Flack S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114213.mp4', 'http://gstaticontent.com/images/oT35HHKekg7a4g0VzGBsojOTGJu_big.jpg'),
(30308, 2083, 'Gangs of London [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114199.mp4', 'http://timg.bdta.pro/images/ac29060baa93ab4d540be1bde64cd61b.jpg'),
(30309, 2083, 'Gangs of London [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114200.mp4', 'http://timg.bdta.pro/images/a07dea3d634adc824a86875b96c8799e.jpg'),
(30310, 2083, 'Gangs of London [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114201.mp4', 'http://timg.bdta.pro/images/10b481fe1cb148507ca417c2d4807bbc.jpg'),
(30311, 2083, 'Gangs of London [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114202.mp4', 'http://timg.bdta.pro/images/bf840d6fb129d417780510018dc991f7.jpg'),
(30312, 2083, 'Gangs of London [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114203.mp4', 'http://timg.bdta.pro/images/9354ef30041e433a8679a4726e70df3e.jpg'),
(30313, 2083, 'Gangs of London [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114204.mp4', 'http://timg.bdta.pro/images/e0edce7888b0ecd721b4a8f2d74009fd.jpg'),
(30314, 2083, 'Gangs of London [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114205.mp4', 'http://timg.bdta.pro/images/9bcf052c63a1f9e2de9431e189a9fd26.jpg'),
(30315, 2083, 'Gangs of London [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114206.mp4', 'http://timg.bdta.pro/images/245f76826a735ff48207f66c045ffde3.jpg'),
(30316, 2083, 'Gangs of London [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114207.mp4', 'http://timg.bdta.pro/images/95f092e192cdb9af4fd15853d65c094c.jpg'),
(30317, 2084, 'Gangs of London [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/760602.mp4', 'http://gstaticontent.com/images/fVgwa6wGw9ddGM5O7mqrrwB6gHK_big.jpg'),
(30318, 2084, 'Gangs of London [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/760603.mp4', 'http://gstaticontent.com/images/fVgwa6wGw9ddGM5O7mqrrwB6gHK_big.jpg'),
(30319, 2084, 'Gangs of London [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/760604.mp4', 'http://gstaticontent.com/images/fVgwa6wGw9ddGM5O7mqrrwB6gHK_big.jpg'),
(30320, 2084, 'Gangs of London [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/760605.mp4', 'http://gstaticontent.com/images/fVgwa6wGw9ddGM5O7mqrrwB6gHK_big.jpg'),
(30321, 2084, 'Gangs of London [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/760606.mp4', 'http://gstaticontent.com/images/fVgwa6wGw9ddGM5O7mqrrwB6gHK_big.jpg'),
(30322, 2084, 'Gangs of London [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/760607.mp4', 'http://gstaticontent.com/images/fVgwa6wGw9ddGM5O7mqrrwB6gHK_big.jpg'),
(30323, 2084, 'Gangs of London [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/760608.mp4', 'http://gstaticontent.com/images/fVgwa6wGw9ddGM5O7mqrrwB6gHK_big.jpg'),
(30324, 2084, 'Gangs of London [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/760609.mp4', 'http://gstaticontent.com/images/fVgwa6wGw9ddGM5O7mqrrwB6gHK_big.jpg'),
(30325, 2085, 'Gangs of London [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/760610.mp4', 'http://gstaticontent.com/images/fVgwa6wGw9ddGM5O7mqrrwB6gHK_big.jpg'),
(30326, 2085, 'Gangs of London [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/760611.mp4', 'http://gstaticontent.com/images/fVgwa6wGw9ddGM5O7mqrrwB6gHK_big.jpg'),
(30327, 2085, 'Gangs of London [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/760612.mp4', 'http://gstaticontent.com/images/fVgwa6wGw9ddGM5O7mqrrwB6gHK_big.jpg'),
(30328, 2085, 'Gangs of London [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/766804.mp4', 'http://gstaticontent.com/images/fVgwa6wGw9ddGM5O7mqrrwB6gHK_big.jpg'),
(30329, 2085, 'Gangs of London [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/766805.mp4', 'http://gstaticontent.com/images/fVgwa6wGw9ddGM5O7mqrrwB6gHK_big.jpg'),
(30330, 2085, 'Gangs of London [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/766806.mp4', 'http://gstaticontent.com/images/fVgwa6wGw9ddGM5O7mqrrwB6gHK_big.jpg'),
(30331, 2085, 'Gangs of London [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/766807.mp4', 'http://gstaticontent.com/images/fVgwa6wGw9ddGM5O7mqrrwB6gHK_big.jpg'),
(30332, 2085, 'Gangs of London [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/766808.mp4', 'http://gstaticontent.com/images/fVgwa6wGw9ddGM5O7mqrrwB6gHK_big.jpg'),
(30333, 2086, 'Gigantes dos Alimentos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161467.mp4', 'http://timg.bdta.pro/images/31131e318717320a128e1318ba4268e6.jpg'),
(30334, 2086, 'Gigantes dos Alimentos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161468.mp4', 'http://timg.bdta.pro/images/31131e318717320a128e1318ba4268e6.jpg'),
(30335, 2086, 'Gigantes dos Alimentos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161469.mp4', 'http://timg.bdta.pro/images/31131e318717320a128e1318ba4268e6.jpg'),
(30336, 2087, 'Gigantes dos Alimentos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u3TWcoyzDi8sHlypDSh1zm2sq6y.jpg'),
(30337, 2087, 'Gigantes dos Alimentos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aNgk7oPRYtbQxKVXtie04FhgLdK.jpg'),
(30338, 2087, 'Gigantes dos Alimentos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqksdBfswuyLM4B4VwCwEpoH0pM.jpg'),
(30339, 2087, 'Gigantes dos Alimentos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7oDXNytuLmCtU609odqaP9xjDJD.jpg'),
(30340, 2087, 'Gigantes dos Alimentos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dcrILVbwYRaAk76xgJNH1XThjYD.jpg'),
(30341, 2087, 'Gigantes dos Alimentos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6BrFOPJqw1smcwkCizRrSIBTkrb.jpg'),
(30342, 2087, 'Gigantes dos Alimentos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pqDXOjH5wzYsTirxQX4h3fY3qPM.jpg'),
(30343, 2087, 'Gigantes dos Alimentos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ctNBofJj99VZdVcFhCKaNSbWOi.jpg'),
(30344, 2088, 'A Bruxa do Bem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127024.mp4', 'http://timg.bdta.pro/images/b94f9f8e16cfbf02642ffc7ad888e15b.jpg'),
(30345, 2088, 'A Bruxa do Bem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127025.mp4', 'http://timg.bdta.pro/images/af09d790cc56606b32327767c415ceb4.jpg'),
(30346, 2088, 'A Bruxa do Bem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127026.mp4', 'http://timg.bdta.pro/images/cec5b7bab1fe13fac626a74084494892.jpg'),
(30347, 2088, 'A Bruxa do Bem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127027.mp4', 'http://timg.bdta.pro/images/002f2755190b70b3786f2ef37c2068fc.jpg'),
(30348, 2088, 'A Bruxa do Bem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127028.mp4', 'http://timg.bdta.pro/images/e00019ea5cde4395fab9bc34640d0a4c.jpg'),
(30349, 2088, 'A Bruxa do Bem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127029.mp4', 'http://timg.bdta.pro/images/00755c6f1eb1e04666ecf68b278f65df.jpg'),
(30350, 2088, 'A Bruxa do Bem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127030.mp4', 'http://timg.bdta.pro/images/80ed2c1a55c30a2f9a51a462143ddc69.jpg'),
(30351, 2088, 'A Bruxa do Bem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127031.mp4', 'http://timg.bdta.pro/images/02f10cc26e627563dc4d64c2e54da396.jpg'),
(30352, 2088, 'A Bruxa do Bem S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127032.mp4', 'http://gstaticontent.com/images/gucXOzZm9iDky8hL8hSIDzRNEft_big.jpg'),
(30353, 2088, 'A Bruxa do Bem S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127033.mp4', 'http://gstaticontent.com/images/gucXOzZm9iDky8hL8hSIDzRNEft_big.jpg'),
(30354, 2089, 'A Bruxa do Bem S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127034.mp4', 'http://timg.bdta.pro/images/dd4c33f3c99d9a82705a824ee6c3e747.jpg'),
(30355, 2089, 'A Bruxa do Bem S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127035.mp4', 'http://timg.bdta.pro/images/7da719ef13c1b9c4071d780e73ba2dfc.jpg'),
(30356, 2089, 'A Bruxa do Bem S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127036.mp4', 'http://timg.bdta.pro/images/d0fa0f55ce1c337c43eb441e06813bf2.jpg'),
(30357, 2089, 'A Bruxa do Bem S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127037.mp4', 'http://timg.bdta.pro/images/4e3376c8a9d02b4a2a5ce2f8b4a0892a.jpg'),
(30358, 2089, 'A Bruxa do Bem S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127038.mp4', 'http://timg.bdta.pro/images/90b5dac59acbb7ebe0bcd42990f6f552.jpg'),
(30359, 2089, 'A Bruxa do Bem S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127039.mp4', 'http://timg.bdta.pro/images/278093cd7629353f7d1c34777a88d6b2.jpg'),
(30360, 2089, 'A Bruxa do Bem S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127040.mp4', 'http://timg.bdta.pro/images/489963c05650b8dec1b28e6c1be89069.jpg'),
(30361, 2089, 'A Bruxa do Bem S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127041.mp4', 'http://timg.bdta.pro/images/9069c924f26d7ef350c2bf3e1aa279cf.jpg'),
(30362, 2089, 'A Bruxa do Bem S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127042.mp4', 'http://timg.bdta.pro/images/18ec4900444bc57694af7d77f4472cd6.jpg'),
(30363, 2089, 'A Bruxa do Bem S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127043.mp4', 'http://timg.bdta.pro/images/39edd0938c4d1d9d2b235f9cf30aaf9d.jpg'),
(30364, 2089, 'A Bruxa do Bem S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127044.mp4', 'http://gstaticontent.com/images/gucXOzZm9iDky8hL8hSIDzRNEft_big.jpg'),
(30365, 2089, 'A Bruxa do Bem S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127045.mp4', 'http://gstaticontent.com/images/gucXOzZm9iDky8hL8hSIDzRNEft_big.jpg'),
(30366, 2090, 'A Bruxa do Bem S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127046.mp4', 'http://timg.bdta.pro/images/dae5adf57c7d005226e24eb61b8e72de.jpg'),
(30367, 2090, 'A Bruxa do Bem S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127047.mp4', 'http://timg.bdta.pro/images/76a350ec619d89cde87db0fede355d47.jpg'),
(30368, 2090, 'A Bruxa do Bem S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127048.mp4', 'http://timg.bdta.pro/images/b0740c6e4611698b5cdc09708ccf0970.jpg'),
(30369, 2090, 'A Bruxa do Bem S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127049.mp4', 'http://timg.bdta.pro/images/79c577380113f057b2a725e4286741cb.jpg'),
(30370, 2090, 'A Bruxa do Bem S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127050.mp4', 'http://timg.bdta.pro/images/f32185edbf266467c9c04f5de9ff0524.jpg'),
(30371, 2090, 'A Bruxa do Bem S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127051.mp4', 'http://timg.bdta.pro/images/cfe64ef08fda7d40c8c0938d6d76adb3.jpg'),
(30372, 2090, 'A Bruxa do Bem S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127052.mp4', 'http://timg.bdta.pro/images/3e7d26c93f4688613a53abc83d936711.jpg'),
(30373, 2090, 'A Bruxa do Bem S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127053.mp4', 'http://timg.bdta.pro/images/126e8f7e66a42a88844df47a9c8d9a20.jpg'),
(30374, 2090, 'A Bruxa do Bem S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127054.mp4', 'http://timg.bdta.pro/images/76c9753d83d71153af93973485937c05.jpg'),
(30375, 2090, 'A Bruxa do Bem S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127055.mp4', 'http://timg.bdta.pro/images/b0fbd1b5b6d06a15577dc8d43797daea.jpg'),
(30376, 2090, 'A Bruxa do Bem S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127056.mp4', 'http://timg.bdta.pro/images/b0fbd1b5b6d06a15577dc8d43797daea.jpg'),
(30377, 2090, 'A Bruxa do Bem S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127057.mp4', 'http://timg.bdta.pro/images/b0fbd1b5b6d06a15577dc8d43797daea.jpg'),
(30378, 2091, 'A Bruxa do Bem S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127058.mp4', 'http://timg.bdta.pro/images/1615bdd0e5b52f9f16ed51b54f3692b8.jpg'),
(30379, 2091, 'A Bruxa do Bem S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127059.mp4', 'http://timg.bdta.pro/images/924f69bbb09094d5f34fc3e9775b700a.jpg'),
(30380, 2091, 'A Bruxa do Bem S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127060.mp4', 'http://timg.bdta.pro/images/f6589ad6ef52bf1be9b7c498ae7e3f95.jpg'),
(30381, 2091, 'A Bruxa do Bem S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127061.mp4', 'http://timg.bdta.pro/images/317582744f38b149666f19d4d894739c.jpg'),
(30382, 2091, 'A Bruxa do Bem S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127062.mp4', 'http://timg.bdta.pro/images/21fc30aac8753718f481ce87af59d83d.jpg'),
(30383, 2091, 'A Bruxa do Bem S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127063.mp4', 'http://timg.bdta.pro/images/7265d1253c9e7ca457850aea749ac9d6.jpg'),
(30384, 2091, 'A Bruxa do Bem S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127064.mp4', 'http://timg.bdta.pro/images/4edf8941b9235418ce1c17996c0939e7.jpg'),
(30385, 2091, 'A Bruxa do Bem S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127065.mp4', 'http://timg.bdta.pro/images/78ff0ab9c50a889933ddd1a954e02ff6.jpg'),
(30386, 2091, 'A Bruxa do Bem S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127066.mp4', 'http://timg.bdta.pro/images/adc0e451123078fabce7c05f231e048f.jpg'),
(30387, 2091, 'A Bruxa do Bem S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127067.mp4', 'http://timg.bdta.pro/images/a46f85aac8f3288f7c24055278a7325f.jpg'),
(30388, 2091, 'A Bruxa do Bem S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127068.mp4', 'http://timg.bdta.pro/images/a46f85aac8f3288f7c24055278a7325f.jpg'),
(30389, 2091, 'A Bruxa do Bem S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127069.mp4', 'http://timg.bdta.pro/images/a46f85aac8f3288f7c24055278a7325f.jpg'),
(30390, 2092, 'A Bruxa do Bem S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127070.mp4', 'http://timg.bdta.pro/images/ce04f20fea7c51089139b1b2579218ea.jpg'),
(30391, 2092, 'A Bruxa do Bem S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127071.mp4', 'http://timg.bdta.pro/images/54cc5fd7758eae2dfac16cd426d6ca9f.jpg'),
(30392, 2092, 'A Bruxa do Bem S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127072.mp4', 'http://timg.bdta.pro/images/120a81d562e5fc4e5314400a909a683c.jpg'),
(30393, 2092, 'A Bruxa do Bem S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127073.mp4', 'http://timg.bdta.pro/images/7597a8553567536812bafdff8ad5d450.jpg'),
(30394, 2092, 'A Bruxa do Bem S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127074.mp4', 'http://timg.bdta.pro/images/15680eaab1c2b68dcd620761656ffc0e.jpg'),
(30395, 2092, 'A Bruxa do Bem S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127075.mp4', 'http://timg.bdta.pro/images/e14c8246241fa64f397b39de4bd833f8.jpg'),
(30396, 2092, 'A Bruxa do Bem S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127076.mp4', 'http://timg.bdta.pro/images/08c6858c44d5dbeddc2981d68eb775ad.jpg'),
(30397, 2092, 'A Bruxa do Bem S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127077.mp4', 'http://timg.bdta.pro/images/77566a78af260ba1d545b555be0c0d1e.jpg'),
(30398, 2092, 'A Bruxa do Bem S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127078.mp4', 'http://timg.bdta.pro/images/0193dc708548503d4cf0ad1e04fb9c24.jpg'),
(30399, 2092, 'A Bruxa do Bem S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127079.mp4', 'http://timg.bdta.pro/images/18172a0ae9f847e2917beed011fd4e3a.jpg'),
(30400, 2093, 'Historia Direto Ao Assunto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114189.mp4', 'http://timg.bdta.pro/images/ca41780a8e2c283410c0236474fc62d5.jpg'),
(30401, 2093, 'Historia Direto Ao Assunto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114190.mp4', 'http://timg.bdta.pro/images/2d78368fc523787ed17ed374df29c1d4.jpg'),
(30402, 2093, 'Historia Direto Ao Assunto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114191.mp4', 'http://timg.bdta.pro/images/f660409afaf57d719e04922fab39a1ec.jpg'),
(30403, 2093, 'Historia Direto Ao Assunto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114192.mp4', 'http://timg.bdta.pro/images/2abedbe99bdb79fdbe90276a2fd2e0b9.jpg'),
(30404, 2093, 'Historia Direto Ao Assunto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114193.mp4', 'http://timg.bdta.pro/images/1dd65ffcd18c4f35e2fda8a8986b05eb.jpg'),
(30405, 2093, 'Historia Direto Ao Assunto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114194.mp4', 'http://timg.bdta.pro/images/5c698d822815d95a15cba84185e574a2.jpg'),
(30406, 2093, 'Historia Direto Ao Assunto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114195.mp4', 'http://timg.bdta.pro/images/fc79845a0e9ae2c11ab2ea568add8c15.jpg'),
(30407, 2093, 'Historia Direto Ao Assunto S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114196.mp4', 'http://timg.bdta.pro/images/7e4b56d719104dbfac2743e2c560c3ae.jpg'),
(30408, 2093, 'Historia Direto Ao Assunto S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114197.mp4', 'http://timg.bdta.pro/images/3d4b924f82f6c3f9ba2d32cb815cc487.jpg'),
(30409, 2093, 'Historia Direto Ao Assunto S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114198.mp4', 'http://timg.bdta.pro/images/3672ba940fe5dac45fa4d0aa3e950d97.jpg'),
(30410, 2094, 'Hollywood S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114182.mp4', 'http://timg.bdta.pro/images/9beb3a285e0240a8ce25a599dcf5577c.jpg'),
(30411, 2094, 'Hollywood S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114183.mp4', 'http://timg.bdta.pro/images/5934973671e2740cdf7dd9e8adba589e.jpg'),
(30412, 2094, 'Hollywood S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114184.mp4', 'http://timg.bdta.pro/images/c472040c9f9f43e97871cc6091e66ee2.jpg'),
(30413, 2094, 'Hollywood S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114185.mp4', 'http://timg.bdta.pro/images/df0165ddd661bdee9c5275ffea58531b.jpg'),
(30414, 2094, 'Hollywood S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114186.mp4', 'http://timg.bdta.pro/images/72bea2d58648656219e427b8956620c7.jpg'),
(30415, 2094, 'Hollywood S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114187.mp4', 'http://timg.bdta.pro/images/04ccfb07d7c07c6da8b8056a72cc2d45.jpg'),
(30416, 2094, 'Hollywood S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114188.mp4', 'http://timg.bdta.pro/images/45110b17f77d888942daf97d53f5f11f.jpg'),
(30417, 2095, 'Homecoming S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114165.mp4', 'http://gstaticontent.com/images/6GTzd7ZeivgBOrIn45720nsq0TU_big.jpg'),
(30418, 2095, 'Homecoming S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114166.mp4', 'http://gstaticontent.com/images/6GTzd7ZeivgBOrIn45720nsq0TU_big.jpg'),
(30419, 2095, 'Homecoming S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114167.mp4', 'http://gstaticontent.com/images/6GTzd7ZeivgBOrIn45720nsq0TU_big.jpg'),
(30420, 2095, 'Homecoming S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114168.mp4', 'http://gstaticontent.com/images/6GTzd7ZeivgBOrIn45720nsq0TU_big.jpg'),
(30421, 2095, 'Homecoming S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114169.mp4', 'http://gstaticontent.com/images/6GTzd7ZeivgBOrIn45720nsq0TU_big.jpg'),
(30422, 2095, 'Homecoming S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114170.mp4', 'http://gstaticontent.com/images/6GTzd7ZeivgBOrIn45720nsq0TU_big.jpg'),
(30423, 2095, 'Homecoming S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114171.mp4', 'http://gstaticontent.com/images/6GTzd7ZeivgBOrIn45720nsq0TU_big.jpg'),
(30424, 2095, 'Homecoming S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114172.mp4', 'http://gstaticontent.com/images/6GTzd7ZeivgBOrIn45720nsq0TU_big.jpg'),
(30425, 2095, 'Homecoming S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114173.mp4', 'http://gstaticontent.com/images/6GTzd7ZeivgBOrIn45720nsq0TU_big.jpg'),
(30426, 2095, 'Homecoming S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114174.mp4', 'http://gstaticontent.com/images/6GTzd7ZeivgBOrIn45720nsq0TU_big.jpg'),
(30427, 2096, 'Homecoming S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114175.mp4', 'http://gstaticontent.com/images/6GTzd7ZeivgBOrIn45720nsq0TU_big.jpg'),
(30428, 2096, 'Homecoming S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114176.mp4', 'http://gstaticontent.com/images/6GTzd7ZeivgBOrIn45720nsq0TU_big.jpg'),
(30429, 2096, 'Homecoming S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114177.mp4', 'http://gstaticontent.com/images/6GTzd7ZeivgBOrIn45720nsq0TU_big.jpg'),
(30430, 2096, 'Homecoming S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114178.mp4', 'http://gstaticontent.com/images/6GTzd7ZeivgBOrIn45720nsq0TU_big.jpg'),
(30431, 2096, 'Homecoming S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114179.mp4', 'http://gstaticontent.com/images/6GTzd7ZeivgBOrIn45720nsq0TU_big.jpg'),
(30432, 2096, 'Homecoming S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114180.mp4', 'http://gstaticontent.com/images/6GTzd7ZeivgBOrIn45720nsq0TU_big.jpg'),
(30433, 2096, 'Homecoming S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114181.mp4', 'http://gstaticontent.com/images/6GTzd7ZeivgBOrIn45720nsq0TU_big.jpg'),
(30434, 2097, 'Itaewon Class [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114149.mp4', 'http://timg.bdta.pro/images/bc748a3867681b8fa7debcd1bb13281d.jpg'),
(30435, 2097, 'Itaewon Class [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114150.mp4', 'http://timg.bdta.pro/images/9d22d17d5fd60dc3e0dec48056e1c89f.jpg'),
(30436, 2097, 'Itaewon Class [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114151.mp4', 'http://timg.bdta.pro/images/e75dcbe3f62488d12f746433ab8d598e.jpg'),
(30437, 2097, 'Itaewon Class [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114152.mp4', 'http://timg.bdta.pro/images/b37674b39960ca78f45846d23f814ad1.jpg'),
(30438, 2097, 'Itaewon Class [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114153.mp4', 'http://timg.bdta.pro/images/96f6d63b1a093ab2ea1557198da2fe84.jpg'),
(30439, 2097, 'Itaewon Class [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114154.mp4', 'http://timg.bdta.pro/images/f53b4f2cbb91579f849509171e652544.jpg'),
(30440, 2097, 'Itaewon Class [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114155.mp4', 'http://timg.bdta.pro/images/eb267ad4b4f7f66320aa2b33ae982c57.jpg'),
(30441, 2097, 'Itaewon Class [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114156.mp4', 'http://timg.bdta.pro/images/59bd5baee10eb401c4c448bf6e89b15f.jpg'),
(30442, 2097, 'Itaewon Class [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114157.mp4', 'http://timg.bdta.pro/images/656c1c572c3fcf1152c4d7d5b80782ef.jpg'),
(30443, 2097, 'Itaewon Class [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114158.mp4', 'http://timg.bdta.pro/images/a6722a64758b27b91a205f0e18e21a54.jpg'),
(30444, 2097, 'Itaewon Class [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114159.mp4', 'http://timg.bdta.pro/images/bd020a7d3ac750dff60c7bef6d1d639e.jpg'),
(30445, 2097, 'Itaewon Class [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114160.mp4', 'http://timg.bdta.pro/images/8b1e3826fa220e42845848ac4c4b0e8a.jpg'),
(30446, 2097, 'Itaewon Class [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114161.mp4', 'http://timg.bdta.pro/images/7e7b56d853fdd2aa8b304269065c7d59.jpg'),
(30447, 2097, 'Itaewon Class [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/114162.mp4', 'http://timg.bdta.pro/images/4a05d24e86489476c33acb7e651bfaf9.jpg'),
(30448, 2097, 'Itaewon Class [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/114163.mp4', 'http://timg.bdta.pro/images/95068674b0eb0326d91a082d7d1ab422.jpg'),
(30449, 2097, 'Itaewon Class [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/114164.mp4', 'http://timg.bdta.pro/images/1b491653a1ded020d1f08d835cfdc1ec.jpg'),
(30450, 2098, 'Jeffrey Epstein: Poder e Perversão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114145.mp4', 'http://timg.bdta.pro/images/a496cb69e7718bc0326628631d184a5c.jpg'),
(30451, 2098, 'Jeffrey Epstein: Poder e Perversão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114146.mp4', 'http://timg.bdta.pro/images/0522ade43992135087026c33376a1c2d.jpg'),
(30452, 2098, 'Jeffrey Epstein: Poder e Perversão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114147.mp4', 'http://timg.bdta.pro/images/8083453487e1d8ba617c0479e00c14b1.jpg'),
(30453, 2098, 'Jeffrey Epstein: Poder e Perversão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114148.mp4', 'http://timg.bdta.pro/images/60725f8c221ceb3a997df72377c636e3.jpg'),
(30454, 2099, 'Jenny S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114105.mp4', 'http://timg.bdta.pro/images/65150efb4768279261b56ea6d68fc75d.jpg'),
(30455, 2099, 'Jenny S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114106.mp4', 'http://timg.bdta.pro/images/a5d2896e206154e53f7f9d55dfbdc3f4.jpg'),
(30456, 2099, 'Jenny S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114107.mp4', 'http://timg.bdta.pro/images/da02374dea2ac41eba77ce91b94472bd.jpg'),
(30457, 2099, 'Jenny S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114108.mp4', 'http://timg.bdta.pro/images/b84f5036382b2a702997e94fdf305d82.jpg'),
(30458, 2099, 'Jenny S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114109.mp4', 'http://timg.bdta.pro/images/cdd49575d8b20cfe6a0c5eaed8c91b0c.jpg'),
(30459, 2099, 'Jenny S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114110.mp4', 'http://timg.bdta.pro/images/6cc1cee896eee3e602290e2dbe0d259a.jpg'),
(30460, 2099, 'Jenny S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114111.mp4', 'http://timg.bdta.pro/images/45fc24004c2c727d480c4f8d42635f46.jpg'),
(30461, 2099, 'Jenny S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114112.mp4', 'http://timg.bdta.pro/images/a2ab6ba3ff9acd51fb4442b43de4eb80.jpg'),
(30462, 2099, 'Jenny S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114113.mp4', 'http://timg.bdta.pro/images/846b3582f9624f64c978a0e1a44af75c.jpg'),
(30463, 2099, 'Jenny S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114114.mp4', 'http://timg.bdta.pro/images/c9f708a1b5a71fff623a3f73861f534e.jpg'),
(30464, 2099, 'Jenny S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114115.mp4', 'http://timg.bdta.pro/images/58540a1f14b77f2528d8edb4f4ed9950.jpg'),
(30465, 2099, 'Jenny S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114116.mp4', 'http://timg.bdta.pro/images/a6fe2ec0752c144662a43affe4386fdd.jpg'),
(30466, 2099, 'Jenny S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114117.mp4', 'http://timg.bdta.pro/images/136056909711df9377417bfaea78cc36.jpg'),
(30467, 2099, 'Jenny S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/114118.mp4', 'http://timg.bdta.pro/images/ff403d093e9fb9135d328a66bb1ce3b3.jpg'),
(30468, 2099, 'Jenny S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/114119.mp4', 'http://timg.bdta.pro/images/8a260f93c301ec0e5392b30f059af6e7.jpg'),
(30469, 2099, 'Jenny S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/114120.mp4', 'http://timg.bdta.pro/images/cfc438b7aff4712fb87d40250124e60a.jpg'),
(30470, 2099, 'Jenny S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/114121.mp4', 'http://timg.bdta.pro/images/fb7537c662c7f15b2c6ac9ef63c7a3a2.jpg'),
(30471, 2099, 'Jenny S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/114122.mp4', 'http://timg.bdta.pro/images/581a31b7ee0717bb7856a3d283ca4e37.jpg'),
(30472, 2099, 'Jenny S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/114123.mp4', 'http://timg.bdta.pro/images/b68f2daed677a9c45326c15ea29b156e.jpg'),
(30473, 2099, 'Jenny S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/114124.mp4', 'http://timg.bdta.pro/images/83ae521a9e10f6caa7cdceffbc4489b8.jpg'),
(30474, 2100, 'Jenny S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114125.mp4', 'http://timg.bdta.pro/images/4767d64f691657f70d9894b6649ab154.jpg'),
(30475, 2100, 'Jenny S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114126.mp4', 'http://timg.bdta.pro/images/82b71a53859c69391ca341f0fc830ecb.jpg'),
(30476, 2100, 'Jenny S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114127.mp4', 'http://timg.bdta.pro/images/6d40bc72ef09384d83a38dde6ce4f44c.jpg'),
(30477, 2100, 'Jenny S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114128.mp4', 'http://timg.bdta.pro/images/41e951ac250a1c0c574797e104cec49f.jpg'),
(30478, 2100, 'Jenny S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114129.mp4', 'http://timg.bdta.pro/images/b74ce603023f744e14df777fd4a20d5f.jpg'),
(30479, 2100, 'Jenny S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114130.mp4', 'http://timg.bdta.pro/images/418462aeba31dcfcd91c20db24ad49cf.jpg'),
(30480, 2100, 'Jenny S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114131.mp4', 'http://timg.bdta.pro/images/49f85e2e2b67048e221f3946a4e7387f.jpg'),
(30481, 2100, 'Jenny S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114132.mp4', 'http://timg.bdta.pro/images/e755e43dbe7850f3b6e8885fb435ddd9.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(30482, 2100, 'Jenny S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114133.mp4', 'http://timg.bdta.pro/images/a6c1f571abcf55df5cf89b3479ec74c2.jpg'),
(30483, 2100, 'Jenny S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114134.mp4', 'http://timg.bdta.pro/images/8b2b45ce7c8752d7a5fca1a0d695dbfe.jpg'),
(30484, 2100, 'Jenny S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114135.mp4', 'http://timg.bdta.pro/images/4bbabeaa99cd28e5c5f7fe32e37bfcfb.jpg'),
(30485, 2100, 'Jenny S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114136.mp4', 'http://timg.bdta.pro/images/6b92ad03cb06b3cd9a613f86537d88b9.jpg'),
(30486, 2100, 'Jenny S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114137.mp4', 'http://timg.bdta.pro/images/abed04bde9298a27a01fd0df6b16c216.jpg'),
(30487, 2100, 'Jenny S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/114138.mp4', 'http://timg.bdta.pro/images/a49eff453d8381b81ec022aa400258d5.jpg'),
(30488, 2100, 'Jenny S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/114139.mp4', 'http://timg.bdta.pro/images/7b75ec548a50b8c7ea03be479aecfe11.jpg'),
(30489, 2100, 'Jenny S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/114140.mp4', 'http://timg.bdta.pro/images/f2bb70840a659752b9cf8dec869cd9c3.jpg'),
(30490, 2100, 'Jenny S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/114141.mp4', 'http://timg.bdta.pro/images/367cef81b9e4c7b1bf980f516d1c39f2.jpg'),
(30491, 2100, 'Jenny S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/114142.mp4', 'http://timg.bdta.pro/images/71da21dac8ad732491ca56e5da3cebe3.jpg'),
(30492, 2100, 'Jenny S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/114143.mp4', 'http://timg.bdta.pro/images/c0713d8d23e37407947594f0287f7d4c.jpg'),
(30493, 2100, 'Jenny S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/114144.mp4', 'http://timg.bdta.pro/images/2b877af04c988f939d3920e204e4e23f.jpg'),
(30494, 2101, 'Kidding S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114085.mp4', 'http://timg.bdta.pro/images/decef7bb1267581dbb586b5127ae6077.jpg'),
(30495, 2101, 'Kidding S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114086.mp4', 'http://timg.bdta.pro/images/f9d921a87373bcac5f11358ae7981d0a.jpg'),
(30496, 2101, 'Kidding S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114087.mp4', 'http://timg.bdta.pro/images/a58cf2c9f9aedb06faf203a5cff700f8.jpg'),
(30497, 2101, 'Kidding S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114088.mp4', 'http://timg.bdta.pro/images/7e2cfbc50bf828ba4222fc25a17663fb.jpg'),
(30498, 2101, 'Kidding S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114089.mp4', 'http://gstaticontent.com/images/4TeM8li5TeJ4CquL26bbrnCZ8yM_big.jpg'),
(30499, 2101, 'Kidding S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114090.mp4', 'http://gstaticontent.com/images/4TeM8li5TeJ4CquL26bbrnCZ8yM_big.jpg'),
(30500, 2101, 'Kidding S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114091.mp4', 'http://gstaticontent.com/images/4TeM8li5TeJ4CquL26bbrnCZ8yM_big.jpg'),
(30501, 2101, 'Kidding S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114092.mp4', 'http://timg.bdta.pro/images/bb189b109f111e9551c7e3bfcd2cb22a.jpg'),
(30502, 2101, 'Kidding S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114093.mp4', 'http://timg.bdta.pro/images/cac0c64d398c289d8a4aa0e75e33a297.jpg'),
(30503, 2101, 'Kidding S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114094.mp4', 'http://timg.bdta.pro/images/89124cffa17673a25cae1e2d6cd8bf61.jpg'),
(30504, 2102, 'Kidding S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114095.mp4', 'http://timg.bdta.pro/images/29e0beae67f76fab422f9ff0dde29241.jpg'),
(30505, 2102, 'Kidding S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114096.mp4', 'http://timg.bdta.pro/images/1e125fd966ab879c1b518acb83ee724a.jpg'),
(30506, 2102, 'Kidding S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114097.mp4', 'http://timg.bdta.pro/images/06c2b7ea24645c2ffbec6a860770eb85.jpg'),
(30507, 2102, 'Kidding S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114098.mp4', 'http://timg.bdta.pro/images/e6edcf3a3d6bbb157c4dd4cf23fdef43.jpg'),
(30508, 2102, 'Kidding S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114099.mp4', 'http://timg.bdta.pro/images/f5bac10d6cde7a099142d09bd4b5c2b6.jpg'),
(30509, 2102, 'Kidding S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114100.mp4', 'http://timg.bdta.pro/images/ad1f7d1639d036dab39cb60a73a57c6b.jpg'),
(30510, 2102, 'Kidding S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114101.mp4', 'http://timg.bdta.pro/images/d6632876bb636830ad4e42c2a662eb00.jpg'),
(30511, 2102, 'Kidding S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114102.mp4', 'http://timg.bdta.pro/images/99d476c82f843f35c83e68e125c0cf24.jpg'),
(30512, 2102, 'Kidding S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114103.mp4', 'http://timg.bdta.pro/images/39f2e0404f0697ccf2b92b6583e33411.jpg'),
(30513, 2102, 'Kidding S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114104.mp4', 'http://timg.bdta.pro/images/101f8ea56e7eea8acb37cf981ab1fb4f.jpg'),
(30514, 2103, 'Killjoys S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114075.mp4', 'http://timg.bdta.pro/images/432810cfbdf02b4b6a64cbfab6f188fd.jpg'),
(30515, 2103, 'Killjoys S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114076.mp4', 'http://timg.bdta.pro/images/561a2840a357789bbf12c552be4dd6d0.jpg'),
(30516, 2103, 'Killjoys S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114077.mp4', 'http://timg.bdta.pro/images/0fdd10cebab754ba1ee88903deb90960.jpg'),
(30517, 2103, 'Killjoys S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114078.mp4', 'http://timg.bdta.pro/images/9a24f34ae8599e3596efe804945a2201.jpg'),
(30518, 2103, 'Killjoys S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114079.mp4', 'http://timg.bdta.pro/images/aca1e7579bb498bc1988c2006f620db2.jpg'),
(30519, 2103, 'Killjoys S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114080.mp4', 'http://timg.bdta.pro/images/657ecbe1f33a1fad76813c2d7530a73e.jpg'),
(30520, 2103, 'Killjoys S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114081.mp4', 'http://timg.bdta.pro/images/692116ff329b900cf09b0a5bc70003d8.jpg'),
(30521, 2103, 'Killjoys S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114082.mp4', 'http://timg.bdta.pro/images/f201048089255c3b5eb621cd72752565.jpg'),
(30522, 2103, 'Killjoys S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114083.mp4', 'http://timg.bdta.pro/images/7e1bae848e91ae8b0dc7e811fbb5b31b.jpg'),
(30523, 2103, 'Killjoys S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114084.mp4', 'http://timg.bdta.pro/images/074d720a05b9a99eff83481ac684a4a8.jpg'),
(30524, 2104, 'Le Chalet [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114069.mp4', 'http://timg.bdta.pro/images/33a19820bcb55e5fba5bfaa28f1f1a22.jpg'),
(30525, 2104, 'Le Chalet [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114070.mp4', 'http://timg.bdta.pro/images/03f6ec6fd0f578859e8fc44984074cd3.jpg'),
(30526, 2104, 'Le Chalet [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114071.mp4', 'http://timg.bdta.pro/images/1093b44fd51bce352605d82efdf37da4.jpg'),
(30527, 2104, 'Le Chalet [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114072.mp4', 'http://timg.bdta.pro/images/b5c64b82e6e7bb13b5acb925f4ddca3e.jpg'),
(30528, 2104, 'Le Chalet [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114073.mp4', 'http://timg.bdta.pro/images/ce82afddf68e2bf11f55cce02c95c5bf.jpg'),
(30529, 2104, 'Le Chalet [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114074.mp4', 'http://timg.bdta.pro/images/6ce24cb694127f3ee4855821596062bb.jpg'),
(30530, 2105, 'Losers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114061.mp4', 'http://timg.bdta.pro/images/6df7cf476fd9e8bb0bc1f656cbea4c09.jpg'),
(30531, 2105, 'Losers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114062.mp4', 'http://timg.bdta.pro/images/b5acdacb7d9484f93a382b6a6ff2bd08.jpg'),
(30532, 2105, 'Losers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114063.mp4', 'http://timg.bdta.pro/images/141bcc7eeb164296920cf01ca8bd67c2.jpg'),
(30533, 2105, 'Losers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114064.mp4', 'http://timg.bdta.pro/images/647f10919076413a762e6fb18808b555.jpg'),
(30534, 2105, 'Losers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114065.mp4', 'http://timg.bdta.pro/images/7f5ad5d6bf01096febac814c31ad3b52.jpg'),
(30535, 2105, 'Losers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114066.mp4', 'http://timg.bdta.pro/images/217293e04e9bd96d860e04f1120898b8.jpg'),
(30536, 2105, 'Losers S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114067.mp4', 'http://timg.bdta.pro/images/9115acf4cad49a1a0391d734f88ac743.jpg'),
(30537, 2105, 'Losers S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114068.mp4', 'http://timg.bdta.pro/images/2517f87278f78bb6a165bb796e882d6b.jpg'),
(30538, 2106, 'Love Life [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114051.mp4', 'http://timg.bdta.pro/images/dc569799c798a942ff4ec45404b84430.jpg'),
(30539, 2106, 'Love Life [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114052.mp4', 'http://timg.bdta.pro/images/4b1d654a4e9b0ded666256e8c7e123ae.jpg'),
(30540, 2106, 'Love Life [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114053.mp4', 'http://timg.bdta.pro/images/024bb0b1e08ee69853ef49456b4b03bc.jpg'),
(30541, 2106, 'Love Life [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114054.mp4', 'http://timg.bdta.pro/images/a196953596c9570a7e8def9276e9ec95.jpg'),
(30542, 2106, 'Love Life [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114055.mp4', 'http://timg.bdta.pro/images/a2d3ce525f31d37980a323fa107e82fa.jpg'),
(30543, 2106, 'Love Life [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114056.mp4', 'http://timg.bdta.pro/images/da556cea161a6ab45c06e93b4d5a93f3.jpg'),
(30544, 2106, 'Love Life [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114057.mp4', 'http://timg.bdta.pro/images/d798bea827aee4a51c0c2fc2e3f7d710.jpg'),
(30545, 2106, 'Love Life [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114058.mp4', 'http://timg.bdta.pro/images/0d858f41a9a78069432c30220df016d3.jpg'),
(30546, 2106, 'Love Life [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114059.mp4', 'http://timg.bdta.pro/images/2658c026776145566d76df68ebb02b61.jpg'),
(30547, 2106, 'Love Life [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114060.mp4', 'http://timg.bdta.pro/images/7b6cd0e4576d7ece2565120c11deafc0.jpg'),
(30548, 2107, 'Mad Men: Inventando Verdades S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113959.mp4', 'http://timg.bdta.pro/images/7496cefe1bfb152959f296af2eef48b9.jpg'),
(30549, 2107, 'Mad Men: Inventando Verdades S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113960.mp4', 'http://timg.bdta.pro/images/70913180b983f1055b469fceec20e903.jpg'),
(30550, 2107, 'Mad Men: Inventando Verdades S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113961.mp4', 'http://timg.bdta.pro/images/b980749a0e76ad4dcdd339e23774af94.jpg'),
(30551, 2107, 'Mad Men: Inventando Verdades S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113962.mp4', 'http://timg.bdta.pro/images/5aa9893e47634801ef6b4e7fb761ef73.jpg'),
(30552, 2107, 'Mad Men: Inventando Verdades S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113963.mp4', 'http://timg.bdta.pro/images/926b68eac9ae8db622b3062cf379265f.jpg'),
(30553, 2107, 'Mad Men: Inventando Verdades S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113964.mp4', 'http://timg.bdta.pro/images/9ab71f6293e753159363a020a025f171.jpg'),
(30554, 2107, 'Mad Men: Inventando Verdades S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113965.mp4', 'http://timg.bdta.pro/images/75dd6036f6490d1dc73355dcc98b25f9.jpg'),
(30555, 2107, 'Mad Men: Inventando Verdades S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113966.mp4', 'http://timg.bdta.pro/images/63838a0c47be6fc668cbc206c2bbbba4.jpg'),
(30556, 2107, 'Mad Men: Inventando Verdades S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113967.mp4', 'http://timg.bdta.pro/images/2c89a573c5665340923ab9301e0e527b.jpg'),
(30557, 2107, 'Mad Men: Inventando Verdades S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113968.mp4', 'http://timg.bdta.pro/images/6614bda19534a04533e936d6a6634583.jpg'),
(30558, 2107, 'Mad Men: Inventando Verdades S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113969.mp4', 'http://timg.bdta.pro/images/94d53206e19528cee838d8daec4b2045.jpg'),
(30559, 2107, 'Mad Men: Inventando Verdades S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113970.mp4', 'http://timg.bdta.pro/images/4c8f4bb54feda263c052d0e4ab5c42af.jpg'),
(30560, 2107, 'Mad Men: Inventando Verdades S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113971.mp4', 'http://timg.bdta.pro/images/9ff19c6a7e6ca8bb441b517ed4ae6e0b.jpg'),
(30561, 2108, 'Mad Men: Inventando Verdades S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113972.mp4', 'http://timg.bdta.pro/images/510e8fa18316626cb8d8996636b569d4.jpg'),
(30562, 2108, 'Mad Men: Inventando Verdades S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113973.mp4', 'http://timg.bdta.pro/images/e75282e544ef3c7bc3a90839f6c5ebc5.jpg'),
(30563, 2108, 'Mad Men: Inventando Verdades S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113974.mp4', 'http://timg.bdta.pro/images/e6bdc60f731ed1306c5b663a0d0b76f0.jpg'),
(30564, 2108, 'Mad Men: Inventando Verdades S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113975.mp4', 'http://timg.bdta.pro/images/2fb4ef0e48c464760dc9a11b3446b00f.jpg'),
(30565, 2108, 'Mad Men: Inventando Verdades S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113976.mp4', 'http://timg.bdta.pro/images/f9968869d3690cb231b274b2b7eed8a8.jpg'),
(30566, 2108, 'Mad Men: Inventando Verdades S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113977.mp4', 'http://timg.bdta.pro/images/52cd9be454c04ea1cb89b8dc629580f9.jpg'),
(30567, 2108, 'Mad Men: Inventando Verdades S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113978.mp4', 'http://timg.bdta.pro/images/5d6ae9620c93b8f07e699ce125fb9e7b.jpg'),
(30568, 2108, 'Mad Men: Inventando Verdades S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113979.mp4', 'http://timg.bdta.pro/images/9a5d397e4af93c2cf49364a9008405d1.jpg'),
(30569, 2108, 'Mad Men: Inventando Verdades S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113980.mp4', 'http://timg.bdta.pro/images/e33e3b74e17e247cbfae887020efbb6a.jpg'),
(30570, 2108, 'Mad Men: Inventando Verdades S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113981.mp4', 'http://timg.bdta.pro/images/965e74849ffd4ab4187c250727e996ff.jpg'),
(30571, 2108, 'Mad Men: Inventando Verdades S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113982.mp4', 'http://timg.bdta.pro/images/8f836c6847d00dd3e3bb518a5fbefc72.jpg'),
(30572, 2108, 'Mad Men: Inventando Verdades S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113983.mp4', 'http://timg.bdta.pro/images/84b40ac604bb436f85e6bf042c65ed0e.jpg'),
(30573, 2108, 'Mad Men: Inventando Verdades S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113984.mp4', 'http://timg.bdta.pro/images/0716c26be799af765def483364f7209a.jpg'),
(30574, 2109, 'Mad Men: Inventando Verdades S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113985.mp4', 'http://timg.bdta.pro/images/fecec36dc4890127a9178871a2b14b65.jpg'),
(30575, 2109, 'Mad Men: Inventando Verdades S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113986.mp4', 'http://timg.bdta.pro/images/7043dcf10cb65754c6ebc9ecbd740782.jpg'),
(30576, 2109, 'Mad Men: Inventando Verdades S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113987.mp4', 'http://timg.bdta.pro/images/83253aeb6a9dad91f04bd462f0bba3b5.jpg'),
(30577, 2109, 'Mad Men: Inventando Verdades S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113988.mp4', 'http://timg.bdta.pro/images/96fd3a407a7a478d711c40c13b832079.jpg'),
(30578, 2109, 'Mad Men: Inventando Verdades S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113989.mp4', 'http://timg.bdta.pro/images/dda742fabdbfc81e271a924773fd92c7.jpg'),
(30579, 2109, 'Mad Men: Inventando Verdades S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113990.mp4', 'http://timg.bdta.pro/images/2c2a456a6823b7282e52105d653a7e43.jpg'),
(30580, 2109, 'Mad Men: Inventando Verdades S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113991.mp4', 'http://timg.bdta.pro/images/bae41a485b0c9fa9ee7eb98f422be243.jpg'),
(30581, 2109, 'Mad Men: Inventando Verdades S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113992.mp4', 'http://timg.bdta.pro/images/3e5dbb8ed86e9b020454f8a743fefc83.jpg'),
(30582, 2109, 'Mad Men: Inventando Verdades S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113993.mp4', 'http://timg.bdta.pro/images/dfd39fce79dac8a2bb36f6adc03e2863.jpg'),
(30583, 2109, 'Mad Men: Inventando Verdades S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113994.mp4', 'http://timg.bdta.pro/images/4ce5b632c7ab6d68290a70ca326a82ad.jpg'),
(30584, 2109, 'Mad Men: Inventando Verdades S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113995.mp4', 'http://timg.bdta.pro/images/cbedd3235f016bf8babd7723c4ec6c78.jpg'),
(30585, 2109, 'Mad Men: Inventando Verdades S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113996.mp4', 'http://timg.bdta.pro/images/70c35fee6e12566fed7f85fe0569a16d.jpg'),
(30586, 2109, 'Mad Men: Inventando Verdades S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113997.mp4', 'http://timg.bdta.pro/images/334914efbc8d42d7a56fb837da7e21a9.jpg'),
(30587, 2110, 'Mad Men: Inventando Verdades S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113998.mp4', 'http://timg.bdta.pro/images/e5a67ffebbd2f1751dc3b54a4b0a0016.jpg'),
(30588, 2110, 'Mad Men: Inventando Verdades S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113999.mp4', 'http://timg.bdta.pro/images/b28a432cebe98937c2de8f2ee132a0cb.jpg'),
(30589, 2110, 'Mad Men: Inventando Verdades S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114000.mp4', 'http://timg.bdta.pro/images/9118b8725f75266a731c06c80980efcf.jpg'),
(30590, 2110, 'Mad Men: Inventando Verdades S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114001.mp4', 'http://timg.bdta.pro/images/34e3e52fa9c1a05b35d4c9f38b04981c.jpg'),
(30591, 2110, 'Mad Men: Inventando Verdades S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114002.mp4', 'http://timg.bdta.pro/images/53ad185d138e1805c44e6b7691f09d21.jpg'),
(30592, 2110, 'Mad Men: Inventando Verdades S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114003.mp4', 'http://timg.bdta.pro/images/7161dbed093cecd826854d22bd49cb35.jpg'),
(30593, 2110, 'Mad Men: Inventando Verdades S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114004.mp4', 'http://timg.bdta.pro/images/3a88a09258ff03c313a844f3e8952b2a.jpg'),
(30594, 2110, 'Mad Men: Inventando Verdades S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114005.mp4', 'http://timg.bdta.pro/images/16502b2c770d024d46da42bbfc0dbc1a.jpg'),
(30595, 2110, 'Mad Men: Inventando Verdades S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114006.mp4', 'http://timg.bdta.pro/images/261debd3d7a29243fb49cc9c1365bf28.jpg'),
(30596, 2110, 'Mad Men: Inventando Verdades S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114007.mp4', 'http://timg.bdta.pro/images/0146dbef4321a4599553baeffb77092e.jpg'),
(30597, 2110, 'Mad Men: Inventando Verdades S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114008.mp4', 'http://timg.bdta.pro/images/eb27657df306a0370fde8b9ddfb1fa83.jpg'),
(30598, 2110, 'Mad Men: Inventando Verdades S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114009.mp4', 'http://timg.bdta.pro/images/d2c226f61e3095ec99dfddcddfdbe238.jpg'),
(30599, 2110, 'Mad Men: Inventando Verdades S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114010.mp4', 'http://timg.bdta.pro/images/01065aa381a48ceb7a02f8890b7997db.jpg'),
(30600, 2111, 'Mad Men: Inventando Verdades S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114011.mp4', 'http://timg.bdta.pro/images/69e51043a7a5ef0c9136dae92d024cd8.jpg'),
(30601, 2111, 'Mad Men: Inventando Verdades S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114012.mp4', 'http://timg.bdta.pro/images/d60061b2fc011cfab4b5d0f81c1dc857.jpg'),
(30602, 2111, 'Mad Men: Inventando Verdades S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114013.mp4', 'http://timg.bdta.pro/images/bf614f08395e3b91451d5406ab4d3ad1.jpg'),
(30603, 2111, 'Mad Men: Inventando Verdades S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114014.mp4', 'http://timg.bdta.pro/images/7170683ab2659c696593ead6bf1b963e.jpg'),
(30604, 2111, 'Mad Men: Inventando Verdades S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114015.mp4', 'http://timg.bdta.pro/images/be995be13a5ac562b3cc99ccc79eccc3.jpg'),
(30605, 2111, 'Mad Men: Inventando Verdades S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114016.mp4', 'http://timg.bdta.pro/images/6033b6eae2d7db852b6a7226a1f930bc.jpg'),
(30606, 2111, 'Mad Men: Inventando Verdades S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114017.mp4', 'http://timg.bdta.pro/images/396dd8dcc95a7df08fc7261d56a0f1dc.jpg'),
(30607, 2111, 'Mad Men: Inventando Verdades S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114018.mp4', 'http://timg.bdta.pro/images/68cfec28cdcb1a26c56da6e92016df22.jpg'),
(30608, 2111, 'Mad Men: Inventando Verdades S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114019.mp4', 'http://timg.bdta.pro/images/0e46393eec3efd070d6c5c2710566ed1.jpg'),
(30609, 2111, 'Mad Men: Inventando Verdades S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114020.mp4', 'http://timg.bdta.pro/images/5724613432e8a565605c02abe56000cc.jpg'),
(30610, 2111, 'Mad Men: Inventando Verdades S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114021.mp4', 'http://timg.bdta.pro/images/db6c6acb39e7d84faf9ceb4c267d198c.jpg'),
(30611, 2111, 'Mad Men: Inventando Verdades S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114022.mp4', 'http://timg.bdta.pro/images/f93ae98eaf0f6ef30bec700d7dd16e6e.jpg'),
(30612, 2111, 'Mad Men: Inventando Verdades S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114023.mp4', 'http://timg.bdta.pro/images/b4a9f7263fdf8ad40b848e7a4f1acb5d.jpg'),
(30613, 2112, 'Mad Men: Inventando Verdades S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114024.mp4', 'http://timg.bdta.pro/images/9bd90c6c9473da1810aad12411861a5b.jpg'),
(30614, 2112, 'Mad Men: Inventando Verdades S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114025.mp4', 'http://timg.bdta.pro/images/a139055fa5fe501e2273b71e0946c6c0.jpg'),
(30615, 2112, 'Mad Men: Inventando Verdades S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114026.mp4', 'http://timg.bdta.pro/images/c60e1b6f061efdb49d2298dc474bedc7.jpg'),
(30616, 2112, 'Mad Men: Inventando Verdades S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114027.mp4', 'http://timg.bdta.pro/images/71035ba63eb59c0da827aa88ac95cb00.jpg'),
(30617, 2112, 'Mad Men: Inventando Verdades S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114028.mp4', 'http://timg.bdta.pro/images/a6df523dc2ed2a689d61556c53958251.jpg'),
(30618, 2112, 'Mad Men: Inventando Verdades S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114029.mp4', 'http://timg.bdta.pro/images/e1010e127c6eb46e605cadcd563efa09.jpg'),
(30619, 2112, 'Mad Men: Inventando Verdades S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114030.mp4', 'http://timg.bdta.pro/images/8578f59cfc5f0603181301fc643ee94c.jpg'),
(30620, 2112, 'Mad Men: Inventando Verdades S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114031.mp4', 'http://timg.bdta.pro/images/fdae02384137131f1fba6b3792ee01b7.jpg'),
(30621, 2112, 'Mad Men: Inventando Verdades S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114032.mp4', 'http://timg.bdta.pro/images/e3ce25719d7ff4bca81f5cf396fdef11.jpg'),
(30622, 2112, 'Mad Men: Inventando Verdades S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114033.mp4', 'http://timg.bdta.pro/images/6fd040116ee44cb3e759a8c93a2f56be.jpg'),
(30623, 2112, 'Mad Men: Inventando Verdades S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114034.mp4', 'http://timg.bdta.pro/images/1f591b815febe51033404b9424f27b81.jpg'),
(30624, 2112, 'Mad Men: Inventando Verdades S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114035.mp4', 'http://timg.bdta.pro/images/50a2680ee21cfb27d225fa173fa07364.jpg'),
(30625, 2112, 'Mad Men: Inventando Verdades S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114036.mp4', 'http://timg.bdta.pro/images/2e94b1a402636ef5ae8da8b9d147017c.jpg'),
(30626, 2113, 'Mad Men: Inventando Verdades S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114037.mp4', 'http://timg.bdta.pro/images/c8b19fe493cdc637a070c43758cd35d6.jpg'),
(30627, 2113, 'Mad Men: Inventando Verdades S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114038.mp4', 'http://timg.bdta.pro/images/f9e59a8ba5a9c4e4f1e40463ea3e3c45.jpg'),
(30628, 2113, 'Mad Men: Inventando Verdades S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114039.mp4', 'http://timg.bdta.pro/images/8698105f898c7a8aab880f5a302acb1a.jpg'),
(30629, 2113, 'Mad Men: Inventando Verdades S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114040.mp4', 'http://timg.bdta.pro/images/c131eaf9cb428d2b4dbc236d1f938176.jpg'),
(30630, 2113, 'Mad Men: Inventando Verdades S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114041.mp4', 'http://timg.bdta.pro/images/dcd035886c83a592b3c6daf9e3be6fd4.jpg'),
(30631, 2113, 'Mad Men: Inventando Verdades S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114042.mp4', 'http://timg.bdta.pro/images/80a1111f9eb5fcdc8bd9f2823703ee56.jpg'),
(30632, 2113, 'Mad Men: Inventando Verdades S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114043.mp4', 'http://timg.bdta.pro/images/f717e8ff0f4c452d3d51a1557a62faf1.jpg'),
(30633, 2113, 'Mad Men: Inventando Verdades S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114044.mp4', 'http://timg.bdta.pro/images/3ec3308bb88044706c6fd91d47a67725.jpg'),
(30634, 2113, 'Mad Men: Inventando Verdades S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114045.mp4', 'http://timg.bdta.pro/images/5a3410a4d09cc3ccb55bf43b3a3b7403.jpg'),
(30635, 2113, 'Mad Men: Inventando Verdades S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114046.mp4', 'http://timg.bdta.pro/images/84e06134027c377fce67e3c969c139c5.jpg'),
(30636, 2113, 'Mad Men: Inventando Verdades S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114047.mp4', 'http://timg.bdta.pro/images/83a4d686be68366133bc2ea32b82cacc.jpg'),
(30637, 2113, 'Mad Men: Inventando Verdades S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114048.mp4', 'http://timg.bdta.pro/images/1dce8d86710d0a7bd7fd8c382d485d9b.jpg'),
(30638, 2113, 'Mad Men: Inventando Verdades S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114049.mp4', 'http://timg.bdta.pro/images/ee7157a5ddc1943b5710ce70d7053c1e.jpg'),
(30639, 2113, 'Mad Men: Inventando Verdades S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/114050.mp4', 'http://timg.bdta.pro/images/56cd3b2864995153fc2eea0a12353ac7.jpg'),
(30640, 2114, 'Marcella S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113935.mp4', 'http://timg.bdta.pro/images/0a4295f1fc190742efebf842fb59d34f.jpg'),
(30641, 2114, 'Marcella S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113936.mp4', 'http://timg.bdta.pro/images/3d1fedb3330168988b69fddb8f41845b.jpg'),
(30642, 2114, 'Marcella S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113937.mp4', 'http://timg.bdta.pro/images/b733de552aa3cb555a32be5177de1986.jpg'),
(30643, 2114, 'Marcella S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113938.mp4', 'http://image.tmdb.org/t/p/w300/haIPucjkoiuD0nI9BgLtuFP2xY2.jpg'),
(30644, 2114, 'Marcella S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113939.mp4', 'http://timg.bdta.pro/images/ac7466a08126f4130afb6c8493c6e940.jpg'),
(30645, 2114, 'Marcella S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113940.mp4', 'http://timg.bdta.pro/images/ec5bae9cb2e600ff15c0eacc52275286.jpg'),
(30646, 2114, 'Marcella S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113941.mp4', 'http://timg.bdta.pro/images/bc6f21f1d7cd2e3c8630dfc0d4d5544f.jpg'),
(30647, 2114, 'Marcella S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113942.mp4', 'http://timg.bdta.pro/images/85e266b725a59fbdb5893850b29885bf.jpg'),
(30648, 2115, 'Marcella S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113943.mp4', 'http://timg.bdta.pro/images/ce39af8babb62f73fcb0e124dcb9c788.jpg'),
(30649, 2115, 'Marcella S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113944.mp4', 'http://timg.bdta.pro/images/ce39af8babb62f73fcb0e124dcb9c788.jpg'),
(30650, 2115, 'Marcella S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113945.mp4', 'http://timg.bdta.pro/images/ce39af8babb62f73fcb0e124dcb9c788.jpg'),
(30651, 2115, 'Marcella S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113946.mp4', 'http://timg.bdta.pro/images/ce39af8babb62f73fcb0e124dcb9c788.jpg'),
(30652, 2115, 'Marcella S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113947.mp4', 'http://timg.bdta.pro/images/ce39af8babb62f73fcb0e124dcb9c788.jpg'),
(30653, 2115, 'Marcella S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113948.mp4', 'http://timg.bdta.pro/images/ce39af8babb62f73fcb0e124dcb9c788.jpg'),
(30654, 2115, 'Marcella S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113949.mp4', 'http://timg.bdta.pro/images/ce39af8babb62f73fcb0e124dcb9c788.jpg'),
(30655, 2115, 'Marcella S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113950.mp4', 'http://timg.bdta.pro/images/ce39af8babb62f73fcb0e124dcb9c788.jpg'),
(30656, 2116, 'Marcella S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113951.mp4', 'http://timg.bdta.pro/images/df402840a4af0b58104c5821b6bf20b5.jpg'),
(30657, 2116, 'Marcella S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113952.mp4', 'http://timg.bdta.pro/images/f58b5a84365079409c56a6cb212f1d69.jpg'),
(30658, 2116, 'Marcella S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113953.mp4', 'http://timg.bdta.pro/images/3597025e32a1058afdda9e6f889dbf7e.jpg'),
(30659, 2116, 'Marcella S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113954.mp4', 'http://timg.bdta.pro/images/e3e083b5f312e764ec95ed04b33565ed.jpg'),
(30660, 2116, 'Marcella S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113955.mp4', 'http://timg.bdta.pro/images/301e3219d2afd305650c8c56772724db.jpg'),
(30661, 2116, 'Marcella S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113956.mp4', 'http://timg.bdta.pro/images/fce5f5bd139ea430bec7dfc82650671b.jpg'),
(30662, 2116, 'Marcella S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113957.mp4', 'http://timg.bdta.pro/images/ed93e9bb12e4a31f68edd26deb8d186b.jpg'),
(30663, 2116, 'Marcella S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113958.mp4', 'http://timg.bdta.pro/images/567c14648547abb5ade5be1fe9d97629.jpg'),
(30664, 2117, 'Mestre do Sabor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149307.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30665, 2117, 'Mestre do Sabor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149308.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30666, 2117, 'Mestre do Sabor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149309.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30667, 2117, 'Mestre do Sabor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149310.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30668, 2117, 'Mestre do Sabor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149311.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30669, 2117, 'Mestre do Sabor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149312.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30670, 2117, 'Mestre do Sabor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149313.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30671, 2117, 'Mestre do Sabor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149314.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30672, 2117, 'Mestre do Sabor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149315.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30673, 2117, 'Mestre do Sabor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149316.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30674, 2117, 'Mestre do Sabor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149317.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30675, 2117, 'Mestre do Sabor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149318.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30676, 2118, 'Mestre do Sabor S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149319.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30677, 2118, 'Mestre do Sabor S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149320.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30678, 2118, 'Mestre do Sabor S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149321.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30679, 2118, 'Mestre do Sabor S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149322.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30680, 2118, 'Mestre do Sabor S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149323.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30681, 2118, 'Mestre do Sabor S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149324.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30682, 2118, 'Mestre do Sabor S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149325.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30683, 2118, 'Mestre do Sabor S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149326.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30684, 2118, 'Mestre do Sabor S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149327.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30685, 2118, 'Mestre do Sabor S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149328.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30686, 2118, 'Mestre do Sabor S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149329.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30687, 2118, 'Mestre do Sabor S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149330.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30688, 2118, 'Mestre do Sabor S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/149331.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30689, 2119, 'Mestre do Sabor S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149332.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30690, 2119, 'Mestre do Sabor S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149333.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30691, 2119, 'Mestre do Sabor S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149334.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30692, 2119, 'Mestre do Sabor S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149335.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30693, 2119, 'Mestre do Sabor S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149336.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30694, 2119, 'Mestre do Sabor S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149337.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30695, 2119, 'Mestre do Sabor S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149338.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30696, 2119, 'Mestre do Sabor S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149339.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30697, 2119, 'Mestre do Sabor S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149340.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30698, 2119, 'Mestre do Sabor S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149341.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30699, 2119, 'Mestre do Sabor S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149342.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30700, 2119, 'Mestre do Sabor S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149343.mp4', 'http://gstaticontent.com/images/bd760946a203a4088ea84d133d66bc32.jpg'),
(30701, 2120, 'Mestres da Sobrevivência S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113929.mp4', 'https://i.bj-share.info/68e2e01511286ef9263b098a7ef65c92.jpg'),
(30702, 2120, 'Mestres da Sobrevivência S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113930.mp4', 'https://i.bj-share.info/68e2e01511286ef9263b098a7ef65c92.jpg'),
(30703, 2120, 'Mestres da Sobrevivência S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113931.mp4', 'https://i.bj-share.info/68e2e01511286ef9263b098a7ef65c92.jpg'),
(30704, 2120, 'Mestres da Sobrevivência S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113932.mp4', 'https://i.bj-share.info/68e2e01511286ef9263b098a7ef65c92.jpg'),
(30705, 2120, 'Mestres da Sobrevivência S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113933.mp4', 'https://i.bj-share.info/68e2e01511286ef9263b098a7ef65c92.jpg'),
(30706, 2120, 'Mestres da Sobrevivência S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113934.mp4', 'https://i.bj-share.info/68e2e01511286ef9263b098a7ef65c92.jpg'),
(30707, 2121, 'Morando Na Estrada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113890.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30708, 2121, 'Morando Na Estrada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113891.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30709, 2121, 'Morando Na Estrada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113892.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30710, 2121, 'Morando Na Estrada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113893.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30711, 2121, 'Morando Na Estrada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113894.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30712, 2121, 'Morando Na Estrada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113895.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30713, 2121, 'Morando Na Estrada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113896.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30714, 2121, 'Morando Na Estrada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113897.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30715, 2121, 'Morando Na Estrada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113898.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30716, 2121, 'Morando Na Estrada S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113899.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30717, 2122, 'Morando Na Estrada S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113900.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30718, 2122, 'Morando Na Estrada S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113901.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30719, 2122, 'Morando Na Estrada S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113902.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30720, 2122, 'Morando Na Estrada S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113903.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30721, 2122, 'Morando Na Estrada S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113904.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30722, 2122, 'Morando Na Estrada S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113905.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30723, 2122, 'Morando Na Estrada S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113906.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30724, 2122, 'Morando Na Estrada S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113907.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30725, 2122, 'Morando Na Estrada S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113908.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30726, 2122, 'Morando Na Estrada S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113909.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30727, 2122, 'Morando Na Estrada S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113910.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30728, 2122, 'Morando Na Estrada S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113911.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30729, 2122, 'Morando Na Estrada S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113912.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30730, 2123, 'Morando Na Estrada S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113913.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30731, 2123, 'Morando Na Estrada S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113914.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30732, 2123, 'Morando Na Estrada S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113915.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30733, 2123, 'Morando Na Estrada S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113916.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30734, 2123, 'Morando Na Estrada S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113917.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30735, 2123, 'Morando Na Estrada S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113918.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30736, 2123, 'Morando Na Estrada S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113919.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30737, 2123, 'Morando Na Estrada S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113920.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30738, 2123, 'Morando Na Estrada S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113921.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30739, 2123, 'Morando Na Estrada S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113922.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30740, 2123, 'Morando Na Estrada S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113923.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30741, 2123, 'Morando Na Estrada S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113924.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30742, 2123, 'Morando Na Estrada S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113925.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30743, 2123, 'Morando Na Estrada S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113926.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30744, 2123, 'Morando Na Estrada S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113927.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30745, 2123, 'Morando Na Estrada S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113928.mp4', 'https://i.bj-share.info/4ba114VtXGofEmD2k7MreuVmkrZFex6ZuJU3h.jpg'),
(30746, 2124, 'Most Dangerous Game [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124490.mp4', 'http://timg.bdta.pro/images/c35a0fd3a4644db0efc07f8e4f753fc1.jpg'),
(30747, 2124, 'Most Dangerous Game [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124491.mp4', 'http://timg.bdta.pro/images/57429880313fb21a3fd741e98c6df5c0.jpg'),
(30748, 2124, 'Most Dangerous Game [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124492.mp4', 'http://timg.bdta.pro/images/7f0b33c5d7303916cd01ad9e651192fe.jpg'),
(30749, 2124, 'Most Dangerous Game [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124493.mp4', 'http://timg.bdta.pro/images/0b20d70a44049b2c67a506f6117ad86d.jpg'),
(30750, 2124, 'Most Dangerous Game [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124494.mp4', 'http://timg.bdta.pro/images/6716236a2370e6c509afd9f866555fca.jpg'),
(30751, 2124, 'Most Dangerous Game [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124495.mp4', 'http://timg.bdta.pro/images/8b2aab4aa9a75cb65b5715a1c2f03e84.jpg'),
(30752, 2124, 'Most Dangerous Game [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124496.mp4', 'http://timg.bdta.pro/images/dd72d6da3ff92d57bc9d82c43b40552c.jpg'),
(30753, 2124, 'Most Dangerous Game [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124497.mp4', 'http://timg.bdta.pro/images/bd100b276de50583cebbc3543d80b32e.jpg'),
(30754, 2124, 'Most Dangerous Game [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124498.mp4', 'http://timg.bdta.pro/images/d9804b281141bc549285db9dc362eac1.jpg'),
(30755, 2124, 'Most Dangerous Game [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124499.mp4', 'http://timg.bdta.pro/images/34fd32cbd2bc31b105f162cea7d130af.jpg'),
(30756, 2124, 'Most Dangerous Game [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124500.mp4', 'http://timg.bdta.pro/images/85254b30cc050801eed94341cff40605.jpg'),
(30757, 2124, 'Most Dangerous Game [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124501.mp4', 'http://timg.bdta.pro/images/5587380449375e663c8348d270019b3a.jpg'),
(30758, 2124, 'Most Dangerous Game [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124502.mp4', 'http://timg.bdta.pro/images/78219bf23af5b974d37bd2c1075d27c0.jpg'),
(30759, 2124, 'Most Dangerous Game [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/124503.mp4', 'http://timg.bdta.pro/images/6321383e1dd7bcd0db21bf68e21d9df6.jpg'),
(30760, 2124, 'Most Dangerous Game [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/124504.mp4', 'http://timg.bdta.pro/images/ff47a2ce0d82eac53e6bf373de8cd9c2.jpg'),
(30761, 2125, 'Sin: Nanatsu no Taizai S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161071.mp4', 'http://timg.bdta.pro/images/c22b511ab9969326741a2d3327b67a6e.jpg'),
(30762, 2125, 'Sin: Nanatsu no Taizai S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161072.mp4', 'http://timg.bdta.pro/images/c870d435371deea6a874e596c22d9a1d.jpg'),
(30763, 2125, 'Sin: Nanatsu no Taizai S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161073.mp4', 'http://timg.bdta.pro/images/00a320b6aa83ef11d077ae661a119ad9.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(30764, 2125, 'Sin: Nanatsu no Taizai S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161074.mp4', 'http://timg.bdta.pro/images/e0dc7ced26357898acf257206d128583.jpg'),
(30765, 2125, 'Sin: Nanatsu no Taizai S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161075.mp4', 'http://timg.bdta.pro/images/5c5c456049ef8a1a013bbb7400e7a77f.jpg'),
(30766, 2125, 'Sin: Nanatsu no Taizai S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161076.mp4', 'http://timg.bdta.pro/images/8200b1866fb878c1550f3b5216d82148.jpg'),
(30767, 2125, 'Sin: Nanatsu no Taizai S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161077.mp4', 'http://timg.bdta.pro/images/fa711454ea6c6850d9b1a41a68acdb5d.jpg'),
(30768, 2125, 'Sin: Nanatsu no Taizai S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161078.mp4', 'http://timg.bdta.pro/images/d5716eb539d6aa21ee8779b3f62d4560.jpg'),
(30769, 2125, 'Sin: Nanatsu no Taizai S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161079.mp4', 'http://timg.bdta.pro/images/b4e24d1fd00681fcdb588733a68c400b.jpg'),
(30770, 2125, 'Sin: Nanatsu no Taizai S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161080.mp4', 'http://timg.bdta.pro/images/1d90f1c4f4b3130e867835d3444770ee.jpg'),
(30771, 2125, 'Sin: Nanatsu no Taizai S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161081.mp4', 'http://timg.bdta.pro/images/c1cad1e8a6cbf61fd01f3a4fcb6013e9.jpg'),
(30772, 2125, 'Sin: Nanatsu no Taizai S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161082.mp4', 'http://timg.bdta.pro/images/49243b9ad1d5905a56b6af6ea3883299.jpg'),
(30773, 2125, 'Sin: Nanatsu no Taizai S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161083.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30774, 2125, 'Sin: Nanatsu no Taizai S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161084.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30775, 2125, 'Sin: Nanatsu no Taizai S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161085.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30776, 2125, 'Sin: Nanatsu no Taizai S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161086.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30777, 2125, 'Sin: Nanatsu no Taizai S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161087.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30778, 2125, 'Sin: Nanatsu no Taizai S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161088.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30779, 2125, 'Sin: Nanatsu no Taizai S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/161089.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30780, 2125, 'Sin: Nanatsu no Taizai S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/161090.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30781, 2125, 'Sin: Nanatsu no Taizai S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/161091.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30782, 2125, 'Sin: Nanatsu no Taizai S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/161092.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30783, 2125, 'Sin: Nanatsu no Taizai S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/161093.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30784, 2125, 'Sin: Nanatsu no Taizai S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/161094.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30785, 2126, 'Sin: Nanatsu no Taizai S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161095.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30786, 2126, 'Sin: Nanatsu no Taizai S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161096.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30787, 2126, 'Sin: Nanatsu no Taizai S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161097.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30788, 2126, 'Sin: Nanatsu no Taizai S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161098.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30789, 2126, 'Sin: Nanatsu no Taizai S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161099.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30790, 2126, 'Sin: Nanatsu no Taizai S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161100.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30791, 2126, 'Sin: Nanatsu no Taizai S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161101.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30792, 2126, 'Sin: Nanatsu no Taizai S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161102.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30793, 2126, 'Sin: Nanatsu no Taizai S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161103.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30794, 2126, 'Sin: Nanatsu no Taizai S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161104.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30795, 2126, 'Sin: Nanatsu no Taizai S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161105.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30796, 2126, 'Sin: Nanatsu no Taizai S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161106.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30797, 2126, 'Sin: Nanatsu no Taizai S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161107.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30798, 2126, 'Sin: Nanatsu no Taizai S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161108.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30799, 2126, 'Sin: Nanatsu no Taizai S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161109.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30800, 2126, 'Sin: Nanatsu no Taizai S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161110.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30801, 2126, 'Sin: Nanatsu no Taizai S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161111.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30802, 2126, 'Sin: Nanatsu no Taizai S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161112.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30803, 2126, 'Sin: Nanatsu no Taizai S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/161113.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30804, 2126, 'Sin: Nanatsu no Taizai S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/161114.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30805, 2126, 'Sin: Nanatsu no Taizai S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/161115.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30806, 2126, 'Sin: Nanatsu no Taizai S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/161116.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30807, 2126, 'Sin: Nanatsu no Taizai S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/161117.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30808, 2126, 'Sin: Nanatsu no Taizai S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/161118.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30809, 2127, 'Sin: Nanatsu no Taizai S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161119.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30810, 2127, 'Sin: Nanatsu no Taizai S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161120.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30811, 2127, 'Sin: Nanatsu no Taizai S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161121.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30812, 2127, 'Sin: Nanatsu no Taizai S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161122.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30813, 2127, 'Sin: Nanatsu no Taizai S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161123.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30814, 2127, 'Sin: Nanatsu no Taizai S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161124.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30815, 2127, 'Sin: Nanatsu no Taizai S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161125.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30816, 2127, 'Sin: Nanatsu no Taizai S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161126.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30817, 2127, 'Sin: Nanatsu no Taizai S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161127.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30818, 2127, 'Sin: Nanatsu no Taizai S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161128.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30819, 2127, 'Sin: Nanatsu no Taizai S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161129.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30820, 2127, 'Sin: Nanatsu no Taizai S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161130.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30821, 2127, 'Sin: Nanatsu no Taizai S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161131.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30822, 2127, 'Sin: Nanatsu no Taizai S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161132.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30823, 2127, 'Sin: Nanatsu no Taizai S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161133.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30824, 2127, 'Sin: Nanatsu no Taizai S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161134.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30825, 2127, 'Sin: Nanatsu no Taizai S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161135.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30826, 2127, 'Sin: Nanatsu no Taizai S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161136.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30827, 2127, 'Sin: Nanatsu no Taizai S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/161137.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30828, 2127, 'Sin: Nanatsu no Taizai S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/161138.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30829, 2127, 'Sin: Nanatsu no Taizai S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/161139.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30830, 2127, 'Sin: Nanatsu no Taizai S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/161140.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30831, 2127, 'Sin: Nanatsu no Taizai S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/161141.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30832, 2127, 'Sin: Nanatsu no Taizai S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/161142.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30833, 2128, 'Sin: Nanatsu no Taizai S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161143.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30834, 2128, 'Sin: Nanatsu no Taizai S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161144.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30835, 2128, 'Sin: Nanatsu no Taizai S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161145.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30836, 2128, 'Sin: Nanatsu no Taizai S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161146.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30837, 2128, 'Sin: Nanatsu no Taizai S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161147.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30838, 2128, 'Sin: Nanatsu no Taizai S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161148.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30839, 2128, 'Sin: Nanatsu no Taizai S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161149.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30840, 2128, 'Sin: Nanatsu no Taizai S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161150.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30841, 2128, 'Sin: Nanatsu no Taizai S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161151.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30842, 2128, 'Sin: Nanatsu no Taizai S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161152.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30843, 2128, 'Sin: Nanatsu no Taizai S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161153.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30844, 2128, 'Sin: Nanatsu no Taizai S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161154.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30845, 2128, 'Sin: Nanatsu no Taizai S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161155.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30846, 2128, 'Sin: Nanatsu no Taizai S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161156.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30847, 2128, 'Sin: Nanatsu no Taizai S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161157.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30848, 2128, 'Sin: Nanatsu no Taizai S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161158.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30849, 2128, 'Sin: Nanatsu no Taizai S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161159.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30850, 2128, 'Sin: Nanatsu no Taizai S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161160.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30851, 2128, 'Sin: Nanatsu no Taizai S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/161161.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30852, 2128, 'Sin: Nanatsu no Taizai S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/161162.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30853, 2128, 'Sin: Nanatsu no Taizai S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/161163.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30854, 2128, 'Sin: Nanatsu no Taizai S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/161164.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30855, 2128, 'Sin: Nanatsu no Taizai S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/161165.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30856, 2128, 'Sin: Nanatsu no Taizai S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/161166.mp4', 'http://gstaticontent.com/images/qsnMdt6bqjssgnUMeZe9FQVWEfP_big.jpg'),
(30857, 2129, 'Nancy Drew S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242551.mp4', 'http://timg.bdta.pro/images/a93166b28f64f1d0f9d0bc9d25eb747a.jpg'),
(30858, 2129, 'Nancy Drew S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242552.mp4', 'http://timg.bdta.pro/images/9c901dd2c2fad069e8a8b5e2557d4667.jpg'),
(30859, 2129, 'Nancy Drew S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242553.mp4', 'http://timg.bdta.pro/images/1619d12a3c997eba310855094bb389c9.jpg'),
(30860, 2129, 'Nancy Drew S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242554.mp4', 'http://timg.bdta.pro/images/0a0927f4441621b495a61855a989df6d.jpg'),
(30861, 2129, 'Nancy Drew S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242555.mp4', 'http://timg.bdta.pro/images/506546e6b653933aec271ad82e7a8fec.jpg'),
(30862, 2129, 'Nancy Drew S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242556.mp4', 'http://timg.bdta.pro/images/c13daabea124ce06d72f502e41af19be.jpg'),
(30863, 2129, 'Nancy Drew S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242557.mp4', 'http://timg.bdta.pro/images/357aad57d8eb4bc777f766ee83671e5e.jpg'),
(30864, 2129, 'Nancy Drew S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242558.mp4', 'http://timg.bdta.pro/images/c801d2a68bf5856f7117726d36ab7855.jpg'),
(30865, 2129, 'Nancy Drew S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242559.mp4', 'http://timg.bdta.pro/images/71d31a38dec16bda85f55ea951c055a0.jpg'),
(30866, 2129, 'Nancy Drew S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242560.mp4', 'http://timg.bdta.pro/images/72e6d0616a4c543b4346dee5fa816ea0.jpg'),
(30867, 2129, 'Nancy Drew S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/242561.mp4', 'http://timg.bdta.pro/images/709ca8091b91b783e2402792171c8284.jpg'),
(30868, 2129, 'Nancy Drew S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/242562.mp4', 'http://timg.bdta.pro/images/3bd74a3f67f2b69f3f2eafe2975a9b7b.jpg'),
(30869, 2129, 'Nancy Drew S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/242563.mp4', 'http://timg.bdta.pro/images/40b512cad4f64845410a15a63782a900.jpg'),
(30870, 2129, 'Nancy Drew S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/242564.mp4', 'http://timg.bdta.pro/images/3ae54e0fcf836f7f3307ea48fec56701.jpg'),
(30871, 2129, 'Nancy Drew S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/242565.mp4', 'http://timg.bdta.pro/images/8330e800b39dff089cd4b5722453d94b.jpg'),
(30872, 2129, 'Nancy Drew S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/242566.mp4', 'http://timg.bdta.pro/images/93cb2668bec94587a91a0f59d054909f.jpg'),
(30873, 2129, 'Nancy Drew S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/242567.mp4', 'http://timg.bdta.pro/images/910246495a4106fdd6c83b25ae0d4293.jpg'),
(30874, 2129, 'Nancy Drew S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/242568.mp4', 'http://timg.bdta.pro/images/1b4a0217f940491952fe3da918da4726.jpg'),
(30875, 2130, 'Nancy Drew S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242569.mp4', 'http://timg.bdta.pro/images/11663dc31d9cbb9775a67da4acbdc10e.jpg'),
(30876, 2130, 'Nancy Drew S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242570.mp4', 'http://timg.bdta.pro/images/26bd58175fe702796ca0a18222f2b0d9.jpg'),
(30877, 2130, 'Nancy Drew S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242571.mp4', 'http://timg.bdta.pro/images/cf3e76990487ff3893ce4e16a0286f8b.jpg'),
(30878, 2130, 'Nancy Drew S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242572.mp4', 'http://timg.bdta.pro/images/324b7af9f4c6c14a25766bf6d50d1945.jpg'),
(30879, 2130, 'Nancy Drew S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242573.mp4', 'http://timg.bdta.pro/images/c889bb5887818cd26ec662beea5c4a4b.jpg'),
(30880, 2130, 'Nancy Drew S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242574.mp4', 'http://timg.bdta.pro/images/3cd442078072ebbee050e9eeb4e55c6e.jpg'),
(30881, 2130, 'Nancy Drew S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242575.mp4', 'http://timg.bdta.pro/images/68f44920110a73fd67591c796877eec0.jpg'),
(30882, 2130, 'Nancy Drew S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242576.mp4', 'http://timg.bdta.pro/images/5dbca3ec5d14e51d2bfc1a8f74679323.jpg'),
(30883, 2130, 'Nancy Drew S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242577.mp4', 'http://timg.bdta.pro/images/f640e82ea547cb6c96aa3968d67f06d0.jpg'),
(30884, 2130, 'Nancy Drew S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242578.mp4', 'http://timg.bdta.pro/images/15b9ab2a8517aa81a88e5517b8ad573e.jpg'),
(30885, 2130, 'Nancy Drew S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/242579.mp4', 'http://timg.bdta.pro/images/7371ebdcaf930fbcefea8d47cf9c1a35.jpg'),
(30886, 2130, 'Nancy Drew S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/242580.mp4', 'http://timg.bdta.pro/images/223b213fe3c21110d2872366ff918e01.jpg'),
(30887, 2130, 'Nancy Drew S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/242581.mp4', 'http://timg.bdta.pro/images/5db4ea90582c48ee421e56c3d614c1cc.jpg'),
(30888, 2130, 'Nancy Drew S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/242582.mp4', 'http://timg.bdta.pro/images/d14311bf8fc7f20fad10f120d4f16e50.jpg'),
(30889, 2130, 'Nancy Drew S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/242583.mp4', 'http://timg.bdta.pro/images/57e9d979bf0d2b3039fc572a389af4a4.jpg'),
(30890, 2130, 'Nancy Drew S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/242584.mp4', 'http://timg.bdta.pro/images/d8ce7e67b8fa0025f4230cbe55ea9d63.jpg'),
(30891, 2130, 'Nancy Drew S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/242585.mp4', 'http://timg.bdta.pro/images/b5f7cf83a9046533f76dae594597d0d9.jpg'),
(30892, 2130, 'Nancy Drew S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/242586.mp4', 'http://timg.bdta.pro/images/b68bf153d9ac0619e392eee64652cb3d.jpg'),
(30893, 2131, 'Nancy Drew S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gL9UWpOUS9eJrRuVglYzcJ8RiS4.jpg'),
(30894, 2131, 'Nancy Drew S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wYAGGBJNombaTOTLaoyhZdM2CRC.jpg'),
(30895, 2131, 'Nancy Drew S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iW3K9p4OOt34zIASB0D2nOX5Gei.jpg'),
(30896, 2131, 'Nancy Drew S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xYcA7KmZzQuDJTWbtnFG57RNgwN.jpg'),
(30897, 2131, 'Nancy Drew S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9GmaQ3thLogRa6XvTZcE2dhpP4f.jpg'),
(30898, 2131, 'Nancy Drew S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEmV52JEc476YrAP7hvirwJcBNB.jpg'),
(30899, 2131, 'Nancy Drew S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hwKBlqhz6JDep1H21gESTxnlOrv.jpg'),
(30900, 2131, 'Nancy Drew S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rwk4D0LJwFQ1aWQAyhA8JRUxks9.jpg'),
(30901, 2131, 'Nancy Drew S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rr3eYMWvWV369nSJs18YlWPfUTa.jpg'),
(30902, 2131, 'Nancy Drew S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bObzL8Sy3upRSR9lWLIxuGaj9WC.jpg'),
(30903, 2131, 'Nancy Drew S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/242597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a869yjzaUiUecFvxQqbaBjHWUxT.jpg'),
(30904, 2131, 'Nancy Drew S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/242598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqfHRAfqL8s8caDY2vM1g9UnWFr.jpg'),
(30905, 2131, 'Nancy Drew S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/242599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g8z9y4bnnbm3Xz2EcyKJW59bd8R.jpg'),
(30906, 2132, 'Nancy Drew S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242600.mp4', 'http://gstaticontent.com/images/zSa24rXwk1Uwnw91kvdOTWuyOTI_big.jpg'),
(30907, 2132, 'Nancy Drew S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242601.mp4', 'http://gstaticontent.com/images/zSa24rXwk1Uwnw91kvdOTWuyOTI_big.jpg'),
(30908, 2132, 'Nancy Drew S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242602.mp4', 'http://gstaticontent.com/images/zSa24rXwk1Uwnw91kvdOTWuyOTI_big.jpg'),
(30909, 2132, 'Nancy Drew S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242603.mp4', 'http://gstaticontent.com/images/zSa24rXwk1Uwnw91kvdOTWuyOTI_big.jpg'),
(30910, 2132, 'Nancy Drew S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242604.mp4', 'http://gstaticontent.com/images/zSa24rXwk1Uwnw91kvdOTWuyOTI_big.jpg'),
(30911, 2132, 'Nancy Drew S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242605.mp4', 'http://gstaticontent.com/images/zSa24rXwk1Uwnw91kvdOTWuyOTI_big.jpg'),
(30912, 2132, 'Nancy Drew S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242606.mp4', 'http://gstaticontent.com/images/zSa24rXwk1Uwnw91kvdOTWuyOTI_big.jpg'),
(30913, 2132, 'Nancy Drew S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242607.mp4', 'http://gstaticontent.com/images/zSa24rXwk1Uwnw91kvdOTWuyOTI_big.jpg'),
(30914, 2132, 'Nancy Drew S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242608.mp4', 'http://gstaticontent.com/images/zSa24rXwk1Uwnw91kvdOTWuyOTI_big.jpg'),
(30915, 2132, 'Nancy Drew S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242609.mp4', 'http://gstaticontent.com/images/zSa24rXwk1Uwnw91kvdOTWuyOTI_big.jpg'),
(30916, 2132, 'Nancy Drew S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/242610.mp4', 'http://gstaticontent.com/images/zSa24rXwk1Uwnw91kvdOTWuyOTI_big.jpg'),
(30917, 2132, 'Nancy Drew S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/242611.mp4', 'http://gstaticontent.com/images/zSa24rXwk1Uwnw91kvdOTWuyOTI_big.jpg'),
(30918, 2132, 'Nancy Drew S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/242612.mp4', 'http://gstaticontent.com/images/zSa24rXwk1Uwnw91kvdOTWuyOTI_big.jpg'),
(30919, 2133, 'Nikita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113819.mp4', 'http://timg.bdta.pro/images/79171f3943a0f76399a1c5699569d7bf.jpg'),
(30920, 2133, 'Nikita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113820.mp4', 'http://timg.bdta.pro/images/de2d1d9407a8e38d8c741911f74790e7.jpg'),
(30921, 2133, 'Nikita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113821.mp4', 'http://timg.bdta.pro/images/ca3e8b7609b5d7a6520d2e81810ca2f2.jpg'),
(30922, 2133, 'Nikita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113822.mp4', 'http://timg.bdta.pro/images/1b8f1a947c74057015d009a8cbe45d20.jpg'),
(30923, 2133, 'Nikita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113823.mp4', 'http://timg.bdta.pro/images/467c855bed8f4e3b3f6265b322f37841.jpg'),
(30924, 2133, 'Nikita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113824.mp4', 'http://timg.bdta.pro/images/db1950a95c5f0b47543909a7c3c70bc3.jpg'),
(30925, 2133, 'Nikita S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113825.mp4', 'http://timg.bdta.pro/images/5913f33b08c53f7c0bf05db820628693.jpg'),
(30926, 2133, 'Nikita S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113826.mp4', 'http://timg.bdta.pro/images/c64a4a053e1ebdaf012dc5c56c5631e0.jpg'),
(30927, 2133, 'Nikita S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113827.mp4', 'http://timg.bdta.pro/images/06706c571b3119b1ba1cd8f1a3d071c4.jpg'),
(30928, 2133, 'Nikita S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113828.mp4', 'http://timg.bdta.pro/images/b230451b600b415af593e173208e3cd5.jpg'),
(30929, 2133, 'Nikita S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113829.mp4', 'http://timg.bdta.pro/images/ddf28200aa2bf2e7bc0b4d7fc5af8945.jpg'),
(30930, 2133, 'Nikita S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113830.mp4', 'http://timg.bdta.pro/images/123650060d88d4330f0581879744a052.jpg'),
(30931, 2133, 'Nikita S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113831.mp4', 'http://timg.bdta.pro/images/35005921b4bc9811c92e1612fdaff6db.jpg'),
(30932, 2133, 'Nikita S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113832.mp4', 'http://timg.bdta.pro/images/a897b91ee11610e1736e5b55f89efcbc.jpg'),
(30933, 2133, 'Nikita S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113833.mp4', 'http://timg.bdta.pro/images/5ac5158d398acb2a448b4aa99092c43b.jpg'),
(30934, 2133, 'Nikita S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113834.mp4', 'http://timg.bdta.pro/images/629e57cc450ac7909d2c1286281d8410.jpg'),
(30935, 2133, 'Nikita S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113835.mp4', 'http://timg.bdta.pro/images/0a78c6e38458f1daaaced8bac1f00c55.jpg'),
(30936, 2133, 'Nikita S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113836.mp4', 'http://timg.bdta.pro/images/32a27bfb52309ce7e0d5549584013b6c.jpg'),
(30937, 2133, 'Nikita S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113837.mp4', 'http://timg.bdta.pro/images/85f4070048696a51d516288245bd5117.jpg'),
(30938, 2133, 'Nikita S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/113838.mp4', 'http://timg.bdta.pro/images/120b9a628cf52b70f0972d0ee4a5172f.jpg'),
(30939, 2134, 'Nikita S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113839.mp4', 'http://timg.bdta.pro/images/07908261c44304777e208c8e4baa4367.jpg'),
(30940, 2134, 'Nikita S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113840.mp4', 'http://timg.bdta.pro/images/fb769175256b714fba105149c22461c4.jpg'),
(30941, 2134, 'Nikita S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113841.mp4', 'http://timg.bdta.pro/images/00b870ae22350521cbf0dace43efce30.jpg'),
(30942, 2134, 'Nikita S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113842.mp4', 'http://timg.bdta.pro/images/68518bcf392b36d77817df60c6503c5c.jpg'),
(30943, 2134, 'Nikita S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113843.mp4', 'http://timg.bdta.pro/images/3d83089b7ab90c5ed1dff97b7fb70d2c.jpg'),
(30944, 2134, 'Nikita S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113844.mp4', 'http://timg.bdta.pro/images/b0beae272a741e4e1d7a10a9c7e3eda5.jpg'),
(30945, 2134, 'Nikita S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113845.mp4', 'http://timg.bdta.pro/images/1ee6268ece79ae719764ec9564eaa31a.jpg'),
(30946, 2134, 'Nikita S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113846.mp4', 'http://timg.bdta.pro/images/2ac10e4ea46db07e52ed8ecf4d94c9bf.jpg'),
(30947, 2134, 'Nikita S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113847.mp4', 'http://timg.bdta.pro/images/0e697da6c49b800c21ddd778095e6ee1.jpg'),
(30948, 2134, 'Nikita S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113848.mp4', 'http://timg.bdta.pro/images/b57d9ffd755f6024fc28bb11d1c6edb5.jpg'),
(30949, 2134, 'Nikita S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113849.mp4', 'http://timg.bdta.pro/images/17fa258d528d21d045790aa4d911007b.jpg'),
(30950, 2134, 'Nikita S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113850.mp4', 'http://timg.bdta.pro/images/522f167401c354a02d260cc87e8391b7.jpg'),
(30951, 2134, 'Nikita S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113851.mp4', 'http://timg.bdta.pro/images/bcc77f1d0518aa419d2bef05815729ef.jpg'),
(30952, 2134, 'Nikita S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113852.mp4', 'http://timg.bdta.pro/images/4f4f9a41c98e589be4aa1f39ad31bbd0.jpg'),
(30953, 2134, 'Nikita S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113853.mp4', 'http://timg.bdta.pro/images/0c7f53011ca5121c73ec53f2211337a7.jpg'),
(30954, 2134, 'Nikita S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113854.mp4', 'http://timg.bdta.pro/images/46ff8a547d9746e446ca58d818ca79d7.jpg'),
(30955, 2134, 'Nikita S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113855.mp4', 'http://timg.bdta.pro/images/b9f6e6e8d5bda8cf1a9ba15a4a2bf657.jpg'),
(30956, 2134, 'Nikita S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113856.mp4', 'http://timg.bdta.pro/images/2a8c6ad0655a8fd08851cf69767195f5.jpg'),
(30957, 2134, 'Nikita S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113857.mp4', 'http://timg.bdta.pro/images/41ff7aa6c7e0e891568514529f3fe93d.jpg'),
(30958, 2134, 'Nikita S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/113858.mp4', 'http://timg.bdta.pro/images/a05f5c049475aae0c827d5c845ff50dd.jpg'),
(30959, 2134, 'Nikita S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/113859.mp4', 'http://timg.bdta.pro/images/36e24e53b9fb52db4c0893ce126af3a1.jpg'),
(30960, 2134, 'Nikita S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/113860.mp4', 'http://timg.bdta.pro/images/30d52c407431ef3717390af7abc25b2b.jpg'),
(30961, 2134, 'Nikita S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/113861.mp4', 'http://timg.bdta.pro/images/531e91823b7c05f6694764e45e1da60d.jpg'),
(30962, 2135, 'Nikita S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113862.mp4', 'http://timg.bdta.pro/images/a7f80ae818ae2520e2b2f76a78bb528b.jpg'),
(30963, 2135, 'Nikita S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113863.mp4', 'http://timg.bdta.pro/images/56ce76942cac69027f778eeed6b13e8e.jpg'),
(30964, 2135, 'Nikita S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113864.mp4', 'http://timg.bdta.pro/images/acce68292b9513741704bc87fd63f998.jpg'),
(30965, 2135, 'Nikita S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113865.mp4', 'http://timg.bdta.pro/images/539689f90507d14c20a1abdd32e4d85f.jpg'),
(30966, 2135, 'Nikita S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113866.mp4', 'http://timg.bdta.pro/images/eb8ea3c2b54456007d687704fb14bcee.jpg'),
(30967, 2135, 'Nikita S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113867.mp4', 'http://timg.bdta.pro/images/dce700be1ccfb3672942ae9eebe1b101.jpg'),
(30968, 2135, 'Nikita S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113868.mp4', 'http://timg.bdta.pro/images/96d8dd0cda56917fbe83d89d3a1aed71.jpg'),
(30969, 2135, 'Nikita S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113869.mp4', 'http://timg.bdta.pro/images/b95c52d3717188493d83c259fcab853b.jpg'),
(30970, 2135, 'Nikita S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113870.mp4', 'http://timg.bdta.pro/images/c8316fcc13b6eb58d42781b57dfc5739.jpg'),
(30971, 2135, 'Nikita S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113871.mp4', 'http://timg.bdta.pro/images/96217286aca7499d9603b7793991548d.jpg'),
(30972, 2135, 'Nikita S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113872.mp4', 'http://timg.bdta.pro/images/1da72f32262a2e25e279593d950a116b.jpg'),
(30973, 2135, 'Nikita S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113873.mp4', 'http://timg.bdta.pro/images/df5bf34fa5f2a3f4d1bf7ad59304a04a.jpg'),
(30974, 2135, 'Nikita S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113874.mp4', 'http://timg.bdta.pro/images/b3b10278388938590113773f49ca8776.jpg'),
(30975, 2135, 'Nikita S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113875.mp4', 'http://timg.bdta.pro/images/11bf72b58b39f466066516afbf95a33d.jpg'),
(30976, 2135, 'Nikita S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113876.mp4', 'http://timg.bdta.pro/images/66d1af0e471b33e23b03fe63021e5a30.jpg'),
(30977, 2135, 'Nikita S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113877.mp4', 'http://timg.bdta.pro/images/0ec925fcba16a9f500b576e433250ef0.jpg'),
(30978, 2135, 'Nikita S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113878.mp4', 'http://timg.bdta.pro/images/04e60421c35d8ac26484a4825a29f965.jpg'),
(30979, 2135, 'Nikita S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113879.mp4', 'http://timg.bdta.pro/images/d603becb80911a683d3052d6a2a9aa47.jpg'),
(30980, 2135, 'Nikita S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113880.mp4', 'http://timg.bdta.pro/images/c96f03c33a760940d214404d5ab5bac6.jpg'),
(30981, 2135, 'Nikita S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/113881.mp4', 'http://timg.bdta.pro/images/7e3c96122128f974b11a061e75707016.jpg'),
(30982, 2135, 'Nikita S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/113882.mp4', 'http://timg.bdta.pro/images/2c3bbaed31e68991cfaa1fe7210856db.jpg'),
(30983, 2135, 'Nikita S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/113883.mp4', 'http://timg.bdta.pro/images/bee34a9e982e13dea9c611d347988b61.jpg'),
(30984, 2136, 'Nikita S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113884.mp4', 'http://timg.bdta.pro/images/e01433e1c3140f0dc03472a0dceef99d.jpg'),
(30985, 2136, 'Nikita S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113885.mp4', 'http://timg.bdta.pro/images/7999985c1fa8b7c29d429da36b3d0e7a.jpg'),
(30986, 2136, 'Nikita S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113886.mp4', 'http://timg.bdta.pro/images/77709701826cd4f62b8af26fb68be15a.jpg'),
(30987, 2136, 'Nikita S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113887.mp4', 'http://timg.bdta.pro/images/78c8cddc3fdd6780db7c91ec137ac184.jpg'),
(30988, 2136, 'Nikita S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113888.mp4', 'http://timg.bdta.pro/images/04f09cd57fe8db8f99f2201024a29f76.jpg'),
(30989, 2136, 'Nikita S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113889.mp4', 'http://timg.bdta.pro/images/8a251d28b09200f833d8b924b4e73bae.jpg'),
(30990, 2137, 'O Dia de Amanhã S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124707.mp4', 'http://gstaticontent.com/images/isVsQkbmSxKrwF0RQvNsXPTNvRZ_big.jpg'),
(30991, 2137, 'O Dia de Amanhã S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124708.mp4', 'http://gstaticontent.com/images/isVsQkbmSxKrwF0RQvNsXPTNvRZ_big.jpg'),
(30992, 2137, 'O Dia de Amanhã S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124709.mp4', 'http://gstaticontent.com/images/isVsQkbmSxKrwF0RQvNsXPTNvRZ_big.jpg'),
(30993, 2137, 'O Dia de Amanhã S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124710.mp4', 'http://gstaticontent.com/images/isVsQkbmSxKrwF0RQvNsXPTNvRZ_big.jpg'),
(30994, 2137, 'O Dia de Amanhã S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124711.mp4', 'http://gstaticontent.com/images/isVsQkbmSxKrwF0RQvNsXPTNvRZ_big.jpg'),
(30995, 2138, 'O Sucessor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113796.mp4', 'http://timg.bdta.pro/images/d60ec13db7559d3c8dc57623bd42072a.jpg'),
(30996, 2138, 'O Sucessor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113797.mp4', 'http://timg.bdta.pro/images/38f091f7de76e44a6f875d3e2f0837ff.jpg'),
(30997, 2138, 'O Sucessor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113798.mp4', 'http://timg.bdta.pro/images/fbc4249455f5abaf3eeaf42466e62b89.jpg'),
(30998, 2138, 'O Sucessor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113799.mp4', 'http://timg.bdta.pro/images/ab444704ea91a4501af89a93a5433935.jpg'),
(30999, 2138, 'O Sucessor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113800.mp4', 'http://timg.bdta.pro/images/fbac3a131c9d7ca098b9cb922597d53a.jpg'),
(31000, 2138, 'O Sucessor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113801.mp4', 'http://timg.bdta.pro/images/2eeb6fa9c4af2bde5595df147600fe4a.jpg'),
(31001, 2138, 'O Sucessor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113802.mp4', 'http://timg.bdta.pro/images/0ef4b5a94e57650f5f46e812a9dd935b.jpg'),
(31002, 2138, 'O Sucessor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113803.mp4', 'http://timg.bdta.pro/images/dc782410ad5c33513513cde106e07407.jpg'),
(31003, 2138, 'O Sucessor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113804.mp4', 'http://timg.bdta.pro/images/21b85933a4b49c09aff78229f2263526.jpg'),
(31004, 2138, 'O Sucessor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113805.mp4', 'http://timg.bdta.pro/images/e1ecb22183de5b17330acd45f34650c4.jpg'),
(31005, 2138, 'O Sucessor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113806.mp4', 'http://timg.bdta.pro/images/4902858ccd55e9ab0dfffcb02a1ad1a6.jpg'),
(31006, 2138, 'O Sucessor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113807.mp4', 'http://timg.bdta.pro/images/c7936376d587c92480c0e719e806434c.jpg'),
(31007, 2138, 'O Sucessor S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113808.mp4', 'http://timg.bdta.pro/images/c5223acedda9d8264d7564086e3a04a5.jpg'),
(31008, 2139, 'O Sucessor S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113809.mp4', 'http://timg.bdta.pro/images/a1ea5bf1ab92250e96ea28a7e477821a.jpg'),
(31009, 2139, 'O Sucessor S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113810.mp4', 'http://timg.bdta.pro/images/fcd35e5cc37f995fdbf535cc952951c5.jpg'),
(31010, 2139, 'O Sucessor S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113811.mp4', 'http://timg.bdta.pro/images/acf63b6d6cd7bb3a6323e8f2723728a1.jpg'),
(31011, 2139, 'O Sucessor S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113812.mp4', 'http://timg.bdta.pro/images/39ec7f4a13488ba79290ed70cfa67cd4.jpg'),
(31012, 2139, 'O Sucessor S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113813.mp4', 'http://timg.bdta.pro/images/c8f5f29f6baa576982ee2e671c13f22a.jpg'),
(31013, 2139, 'O Sucessor S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113814.mp4', 'http://timg.bdta.pro/images/e2fda0f644cba3c3c5a8aea474934ff7.jpg'),
(31014, 2139, 'O Sucessor S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113815.mp4', 'http://timg.bdta.pro/images/8bb4845cf89c54bc590743c99d0a52bd.jpg'),
(31015, 2139, 'O Sucessor S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113816.mp4', 'http://timg.bdta.pro/images/1a55dce1a720376d9ec5ed4fedf02da3.jpg'),
(31016, 2139, 'O Sucessor S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113817.mp4', 'http://timg.bdta.pro/images/6f7d9a74cfe25ee2d6d342eae927e88d.jpg'),
(31017, 2139, 'O Sucessor S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113818.mp4', 'http://timg.bdta.pro/images/e186f007a519fe3f8a871227141c63fe.jpg'),
(31018, 2140, 'Os Roni S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166038.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31019, 2140, 'Os Roni S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166039.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31020, 2140, 'Os Roni S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166040.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31021, 2140, 'Os Roni S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166041.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31022, 2140, 'Os Roni S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166042.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31023, 2140, 'Os Roni S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166043.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31024, 2140, 'Os Roni S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166044.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31025, 2140, 'Os Roni S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166045.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31026, 2140, 'Os Roni S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166046.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31027, 2140, 'Os Roni S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166047.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31028, 2141, 'Os Roni S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166048.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31029, 2141, 'Os Roni S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166049.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31030, 2141, 'Os Roni S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166050.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31031, 2141, 'Os Roni S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166051.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31032, 2141, 'Os Roni S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166052.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31033, 2141, 'Os Roni S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166053.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31034, 2141, 'Os Roni S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166054.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31035, 2141, 'Os Roni S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166055.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31036, 2141, 'Os Roni S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166056.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31037, 2141, 'Os Roni S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166057.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31038, 2142, 'Os Roni S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166058.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31039, 2142, 'Os Roni S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166059.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31040, 2142, 'Os Roni S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166060.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31041, 2142, 'Os Roni S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166061.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31042, 2142, 'Os Roni S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166062.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31043, 2142, 'Os Roni S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166063.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31044, 2142, 'Os Roni S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166064.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31045, 2142, 'Os Roni S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166065.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31046, 2142, 'Os Roni S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166066.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31047, 2142, 'Os Roni S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166067.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31048, 2142, 'Os Roni S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166068.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31049, 2142, 'Os Roni S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166069.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31050, 2142, 'Os Roni S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166070.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31051, 2142, 'Os Roni S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166071.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31052, 2142, 'Os Roni S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166072.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(31053, 2142, 'Os Roni S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166073.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31054, 2142, 'Os Roni S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166074.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31055, 2142, 'Os Roni S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166075.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31056, 2142, 'Os Roni S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/166076.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31057, 2142, 'Os Roni S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/166077.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31058, 2143, 'Os Roni S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166078.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31059, 2143, 'Os Roni S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166079.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31060, 2143, 'Os Roni S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166080.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31061, 2143, 'Os Roni S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166081.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31062, 2143, 'Os Roni S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166082.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31063, 2143, 'Os Roni S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166083.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31064, 2143, 'Os Roni S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166084.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31065, 2143, 'Os Roni S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166085.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31066, 2143, 'Os Roni S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166086.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31067, 2143, 'Os Roni S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166087.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31068, 2143, 'Os Roni S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166088.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31069, 2143, 'Os Roni S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166089.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31070, 2143, 'Os Roni S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166090.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31071, 2143, 'Os Roni S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166091.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31072, 2143, 'Os Roni S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166092.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31073, 2143, 'Os Roni S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166093.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31074, 2143, 'Os Roni S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166094.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31075, 2143, 'Os Roni S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166095.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31076, 2143, 'Os Roni S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/166096.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31077, 2143, 'Os Roni S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/166097.mp4', 'http://gstaticontent.com/images/livmfhbo7ho3DWL64oU1I2Vwl3j_big.jpg'),
(31078, 2144, 'Perdida [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113785.mp4', 'http://timg.bdta.pro/images/fca989e7a0907f347d79a383e58638e1.jpg'),
(31079, 2144, 'Perdida [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113786.mp4', 'http://timg.bdta.pro/images/00ce652fc687a95a9a5fc752e764fd0a.jpg'),
(31080, 2144, 'Perdida [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113787.mp4', 'http://timg.bdta.pro/images/f937b91df38acc7349c3ff014b47f935.jpg'),
(31081, 2144, 'Perdida [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113788.mp4', 'http://timg.bdta.pro/images/6a099fad3e32b7785c6e8cf435d6e46c.jpg'),
(31082, 2144, 'Perdida [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113789.mp4', 'http://timg.bdta.pro/images/d90f45b8ae5d9757872060c092db8e29.jpg'),
(31083, 2144, 'Perdida [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113790.mp4', 'http://timg.bdta.pro/images/34c51c2d3cc9f5d3205be7a1055aa52d.jpg'),
(31084, 2144, 'Perdida [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113791.mp4', 'http://timg.bdta.pro/images/215c2334953b86e87dd17cf857cef538.jpg'),
(31085, 2144, 'Perdida [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113792.mp4', 'http://timg.bdta.pro/images/5a0732737f981c51367e8599e684346a.jpg'),
(31086, 2144, 'Perdida [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113793.mp4', 'http://timg.bdta.pro/images/410cd70e885d211c2d70302493461f16.jpg'),
(31087, 2144, 'Perdida [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113794.mp4', 'http://timg.bdta.pro/images/e6d20491b4e60795094f0bb35e6c83ae.jpg'),
(31088, 2144, 'Perdida [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113795.mp4', 'http://timg.bdta.pro/images/805f5cfd91d0392cba4d6c91ec7693dc.jpg'),
(31089, 2145, 'Perry Mason S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210895.mp4', 'http://timg.bdta.pro/images/315a7253e9bf146bd2235de77ce06d3c.jpg'),
(31090, 2145, 'Perry Mason S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210896.mp4', 'http://timg.bdta.pro/images/77f3915fe91ed18992df122c7f7f7ad7.jpg'),
(31091, 2145, 'Perry Mason S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210897.mp4', 'http://timg.bdta.pro/images/397a4c6c9acf20b8bb0bc183a7e00f50.jpg'),
(31092, 2145, 'Perry Mason S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210898.mp4', 'http://timg.bdta.pro/images/6923ea2cef9e7b2a7c08749ed726ab19.jpg'),
(31093, 2145, 'Perry Mason S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210899.mp4', 'http://timg.bdta.pro/images/798b637390a303225cb6b26f8097a63e.jpg'),
(31094, 2145, 'Perry Mason S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210900.mp4', 'http://timg.bdta.pro/images/ccda0862f9505068b78a06866acec564.jpg'),
(31095, 2145, 'Perry Mason S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210901.mp4', 'http://timg.bdta.pro/images/fa8fbd814568a230760c89867cd0317b.jpg'),
(31096, 2145, 'Perry Mason S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210902.mp4', 'http://timg.bdta.pro/images/5cc1c07be6d0963dda662cd95a8d5d8c.jpg'),
(31097, 2146, 'Perry Mason S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210903.mp4', 'http://image.tmdb.org/t/p/w1280/9l81E9o6UpT1SQsORaqb3GPKluD.jpg'),
(31098, 2146, 'Perry Mason S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210904.mp4', 'http://image.tmdb.org/t/p/w1280/558PmIghii6y3jbkdEDWgQyPs1F.jpg'),
(31099, 2146, 'Perry Mason S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210905.mp4', 'http://image.tmdb.org/t/p/w1280/tevCPzWpFh8xJkt6a8D0cDMm21b.jpg'),
(31100, 2146, 'Perry Mason S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210906.mp4', 'http://image.tmdb.org/t/p/w1280/3NF5Qv6nrhwGdKU6sdeyEKeLEVh.jpg'),
(31101, 2146, 'Perry Mason S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210907.mp4', 'http://image.tmdb.org/t/p/w1280/8OSqtfzl0ePlY5ALt6bq3TxVPPo.jpg'),
(31102, 2146, 'Perry Mason S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210908.mp4', 'http://image.tmdb.org/t/p/w1280/zmu2KdMUxPvEpcarSbMP2erCSbI.jpg'),
(31103, 2146, 'Perry Mason S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210909.mp4', 'http://image.tmdb.org/t/p/w1280/srJb9QfpSNPGAlOf7InyfJmHsex.jpg'),
(31104, 2146, 'Perry Mason S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210910.mp4', 'http://image.tmdb.org/t/p/w1280/eLMqp2OwOFi3ubSCFk1X936oDHc.jpg'),
(31105, 2147, 'Psych Agentes Especiais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/545892.mp4', 'http://gstaticontent.com/images/e2e99aefc9fe93db5d51d09601d6d98b.jpg'),
(31106, 2147, 'Psych Agentes Especiais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/545894.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31107, 2147, 'Psych Agentes Especiais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/545896.mp4', 'http://gstaticontent.com/images/7a35dc2db49cf2e87879eada37f061d6.jpg'),
(31108, 2147, 'Psych Agentes Especiais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/545898.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31109, 2147, 'Psych Agentes Especiais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/545900.mp4', 'http://gstaticontent.com/images/8ecd47259b5e6a2b16505900e984677e.jpg'),
(31110, 2147, 'Psych Agentes Especiais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/545902.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31111, 2147, 'Psych Agentes Especiais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/545904.mp4', 'http://gstaticontent.com/images/7dc1aba2b42a9a26e2b977feda09be72.jpg'),
(31112, 2147, 'Psych Agentes Especiais S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/545906.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31113, 2147, 'Psych Agentes Especiais S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/545908.mp4', 'http://gstaticontent.com/images/b8e1aeb6df8d1fec29c704e2b4d7eaa7.jpg'),
(31114, 2147, 'Psych Agentes Especiais S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/545910.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31115, 2147, 'Psych Agentes Especiais S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/545912.mp4', 'http://gstaticontent.com/images/2e2d119f916f5a7f211dc939a88b810f.jpg'),
(31116, 2147, 'Psych Agentes Especiais S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/545914.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31117, 2147, 'Psych Agentes Especiais S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/545916.mp4', 'http://gstaticontent.com/images/4a74dc6bdf415d3f873fc4202f06e7b6.jpg'),
(31118, 2147, 'Psych Agentes Especiais S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/545918.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31119, 2147, 'Psych Agentes Especiais S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/545920.mp4', 'http://gstaticontent.com/images/99877252f7a9789dfbc314c11b231aa4.jpg'),
(31120, 2148, 'Psych Agentes Especiais S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/545922.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31121, 2148, 'Psych Agentes Especiais S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/545924.mp4', 'http://gstaticontent.com/images/eff5b18cc32e9dd4f76bbfb8d90cac6c.jpg'),
(31122, 2148, 'Psych Agentes Especiais S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/545926.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31123, 2148, 'Psych Agentes Especiais S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/545928.mp4', 'http://gstaticontent.com/images/7a98a9b696476eb58ac35069d78e1521.jpg'),
(31124, 2148, 'Psych Agentes Especiais S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/545930.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31125, 2148, 'Psych Agentes Especiais S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/545932.mp4', 'http://gstaticontent.com/images/a1b220e04648cd7a56ecc8916eeee401.jpg'),
(31126, 2148, 'Psych Agentes Especiais S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/545934.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31127, 2148, 'Psych Agentes Especiais S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/545936.mp4', 'http://gstaticontent.com/images/c3c1afeaa4d3c7e0a1150ea42a4701ac.jpg'),
(31128, 2148, 'Psych Agentes Especiais S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/545938.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31129, 2148, 'Psych Agentes Especiais S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/545940.mp4', 'http://gstaticontent.com/images/caa4a15cbdbc5df7470ccebfb1b6625e.jpg'),
(31130, 2148, 'Psych Agentes Especiais S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/545942.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31131, 2148, 'Psych Agentes Especiais S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/545944.mp4', 'http://gstaticontent.com/images/dd0e0ff393621426dc65dfc407c0044a.jpg'),
(31132, 2148, 'Psych Agentes Especiais S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/545946.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31133, 2148, 'Psych Agentes Especiais S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/545948.mp4', 'http://gstaticontent.com/images/68f65e7565b06f347948d4bd23bce1ba.jpg'),
(31134, 2148, 'Psych Agentes Especiais S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/545950.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31135, 2148, 'Psych Agentes Especiais S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/545952.mp4', 'http://gstaticontent.com/images/d469e9726c5ddd6936aed844adf80370.jpg'),
(31136, 2149, 'Psych Agentes Especiais S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/545954.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31137, 2149, 'Psych Agentes Especiais S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/545956.mp4', 'http://gstaticontent.com/images/e9bcb4acd292b30e71725903d3d9dcb6.jpg'),
(31138, 2149, 'Psych Agentes Especiais S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/545958.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31139, 2149, 'Psych Agentes Especiais S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/545960.mp4', 'http://gstaticontent.com/images/e1b1313d997848252313b8988cd5ff74.jpg'),
(31140, 2149, 'Psych Agentes Especiais S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/545962.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31141, 2149, 'Psych Agentes Especiais S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/545964.mp4', 'http://gstaticontent.com/images/13614d9c942a1a971355a03f7b3064c6.jpg'),
(31142, 2149, 'Psych Agentes Especiais S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/545966.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31143, 2149, 'Psych Agentes Especiais S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/545968.mp4', 'http://gstaticontent.com/images/8e5756590fd9380e2f711618af2e582c.jpg'),
(31144, 2149, 'Psych Agentes Especiais S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/545970.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31145, 2149, 'Psych Agentes Especiais S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/545972.mp4', 'http://gstaticontent.com/images/16490779594eb0022dd447b9a9bcada9.jpg'),
(31146, 2149, 'Psych Agentes Especiais S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/545974.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31147, 2149, 'Psych Agentes Especiais S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/545976.mp4', 'http://gstaticontent.com/images/f24641bf434164c0d14f893542946cbc.jpg'),
(31148, 2149, 'Psych Agentes Especiais S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/545978.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31149, 2149, 'Psych Agentes Especiais S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/545980.mp4', 'http://gstaticontent.com/images/654caa0e0c07ffc590d6df42e025b20b.jpg'),
(31150, 2149, 'Psych Agentes Especiais S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/545982.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31151, 2149, 'Psych Agentes Especiais S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/545984.mp4', 'http://gstaticontent.com/images/652f98da3980a028c80aa09b6bbecd3e.jpg'),
(31152, 2150, 'Psych Agentes Especiais S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/545986.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31153, 2150, 'Psych Agentes Especiais S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/545988.mp4', 'http://gstaticontent.com/images/8dc77cdb7fe16db4a8a555f4fffc8c75.jpg'),
(31154, 2150, 'Psych Agentes Especiais S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/545990.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31155, 2150, 'Psych Agentes Especiais S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/545992.mp4', 'http://gstaticontent.com/images/bfcb466f35d021b63442189ded398ca3.jpg'),
(31156, 2150, 'Psych Agentes Especiais S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/545994.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31157, 2150, 'Psych Agentes Especiais S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/545996.mp4', 'http://gstaticontent.com/images/790506634c156e5b8d58cf81ebb8c12d.jpg'),
(31158, 2150, 'Psych Agentes Especiais S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/545998.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31159, 2150, 'Psych Agentes Especiais S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/546000.mp4', 'http://gstaticontent.com/images/4d71a10aa1993e2cf52840c00d5eb05a.jpg'),
(31160, 2150, 'Psych Agentes Especiais S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/546002.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31161, 2150, 'Psych Agentes Especiais S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/546004.mp4', 'http://gstaticontent.com/images/28b2466936986351e28f92f9a90faa97.jpg'),
(31162, 2150, 'Psych Agentes Especiais S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/546006.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31163, 2150, 'Psych Agentes Especiais S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/546008.mp4', 'http://gstaticontent.com/images/dc9a72ebbaeb10d344e41ba5ec429775.jpg'),
(31164, 2150, 'Psych Agentes Especiais S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/546010.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31165, 2150, 'Psych Agentes Especiais S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/546012.mp4', 'http://gstaticontent.com/images/afa948d9af7e391f63df0e3f0cc498a1.jpg'),
(31166, 2150, 'Psych Agentes Especiais S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/546014.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31167, 2150, 'Psych Agentes Especiais S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/546016.mp4', 'http://gstaticontent.com/images/8b46a5494c06ac88f73f46c8733f7904.jpg'),
(31168, 2151, 'Psych Agentes Especiais S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/546018.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31169, 2151, 'Psych Agentes Especiais S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/546020.mp4', 'http://gstaticontent.com/images/5f4ae53079af7683f598077a192e8eda.jpg'),
(31170, 2151, 'Psych Agentes Especiais S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/546022.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31171, 2151, 'Psych Agentes Especiais S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/546024.mp4', 'http://gstaticontent.com/images/714dab7129cb52d436eb1e589f4edb63.jpg'),
(31172, 2151, 'Psych Agentes Especiais S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/546026.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31173, 2151, 'Psych Agentes Especiais S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/546028.mp4', 'http://gstaticontent.com/images/5714000423d48a601d34136c96a21d25.jpg'),
(31174, 2151, 'Psych Agentes Especiais S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/546030.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31175, 2151, 'Psych Agentes Especiais S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/546032.mp4', 'http://gstaticontent.com/images/dd031d56e7ea247e8e04070afc7ae419.jpg'),
(31176, 2151, 'Psych Agentes Especiais S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/546034.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31177, 2151, 'Psych Agentes Especiais S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/546036.mp4', 'http://gstaticontent.com/images/a4890fddae76e3bf6b7ae16b47048668.jpg'),
(31178, 2151, 'Psych Agentes Especiais S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/546038.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31179, 2151, 'Psych Agentes Especiais S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/546040.mp4', 'http://gstaticontent.com/images/d8a6d0426a42bc27e66b431771b90ffb.jpg'),
(31180, 2151, 'Psych Agentes Especiais S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/546042.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31181, 2151, 'Psych Agentes Especiais S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/546044.mp4', 'http://gstaticontent.com/images/6d6cae0300e83e24ae7dd8cf9b1afb49.jpg'),
(31182, 2151, 'Psych Agentes Especiais S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/546046.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31183, 2151, 'Psych Agentes Especiais S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/546048.mp4', 'http://gstaticontent.com/images/744a8f37069d2406c903bb10b847bb89.jpg'),
(31184, 2152, 'Psych Agentes Especiais S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/546050.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31185, 2152, 'Psych Agentes Especiais S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/546052.mp4', 'http://gstaticontent.com/images/baf8c392df982d36f5774f049eb7540c.jpg'),
(31186, 2152, 'Psych Agentes Especiais S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/546054.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31187, 2152, 'Psych Agentes Especiais S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/546056.mp4', 'http://gstaticontent.com/images/c6504aea10ad7dc10f3963a2dc5fd1ee.jpg'),
(31188, 2152, 'Psych Agentes Especiais S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/546058.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31189, 2152, 'Psych Agentes Especiais S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/546060.mp4', 'http://gstaticontent.com/images/63fb3913e946214c3a29973d553efb26.jpg'),
(31190, 2152, 'Psych Agentes Especiais S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/546062.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31191, 2152, 'Psych Agentes Especiais S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/546064.mp4', 'http://gstaticontent.com/images/b5659b8dd32f40ff902fa793003b9f5b.jpg'),
(31192, 2152, 'Psych Agentes Especiais S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/546066.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31193, 2152, 'Psych Agentes Especiais S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/546068.mp4', 'http://gstaticontent.com/images/675e1def406f934410810a08c2101c05.jpg'),
(31194, 2152, 'Psych Agentes Especiais S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/546070.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31195, 2152, 'Psych Agentes Especiais S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/546072.mp4', 'http://gstaticontent.com/images/a3cb421073e6a4a891786fe2e08957ba.jpg'),
(31196, 2152, 'Psych Agentes Especiais S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/546074.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31197, 2152, 'Psych Agentes Especiais S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/546076.mp4', 'http://gstaticontent.com/images/c1f12da42b1264a0b844e4b2ca90d464.jpg'),
(31198, 2152, 'Psych Agentes Especiais S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/546078.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31199, 2152, 'Psych Agentes Especiais S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/546080.mp4', 'http://gstaticontent.com/images/d7f312ce4bc26c12053d5f1abc36bff3.jpg'),
(31200, 2153, 'Psych Agentes Especiais S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/546082.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31201, 2153, 'Psych Agentes Especiais S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/546084.mp4', 'http://gstaticontent.com/images/0ce00ae5e3d95255bb5a838961de22fa.jpg'),
(31202, 2153, 'Psych Agentes Especiais S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/546086.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31203, 2153, 'Psych Agentes Especiais S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/546088.mp4', 'http://gstaticontent.com/images/cdb38b420eddd751f285570bee4f3447.jpg'),
(31204, 2153, 'Psych Agentes Especiais S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/546090.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31205, 2153, 'Psych Agentes Especiais S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/546092.mp4', 'http://gstaticontent.com/images/d12cc82b645e75e6edfb7a3c2127ddb0.jpg'),
(31206, 2153, 'Psych Agentes Especiais S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/546094.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31207, 2153, 'Psych Agentes Especiais S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/546096.mp4', 'http://gstaticontent.com/images/c2991edca1776f0bd569bcaf0e29f8d6.jpg'),
(31208, 2153, 'Psych Agentes Especiais S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/546098.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31209, 2153, 'Psych Agentes Especiais S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/546100.mp4', 'http://gstaticontent.com/images/be70c2c247116af8b3febb42a84537cd.jpg'),
(31210, 2153, 'Psych Agentes Especiais S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/546102.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31211, 2153, 'Psych Agentes Especiais S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/546104.mp4', 'http://gstaticontent.com/images/ed9e5ba656f5bdcdf12430c68a900518.jpg'),
(31212, 2153, 'Psych Agentes Especiais S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/546106.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31213, 2153, 'Psych Agentes Especiais S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/546108.mp4', 'http://gstaticontent.com/images/6f83373bebd26c5ee71cd9f3b1f55067.jpg'),
(31214, 2153, 'Psych Agentes Especiais S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/546110.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31215, 2153, 'Psych Agentes Especiais S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/546112.mp4', 'http://gstaticontent.com/images/75008cb2e51222446d00fd6089a7cc22.jpg'),
(31216, 2154, 'Psych Agentes Especiais S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138323.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31217, 2154, 'Psych Agentes Especiais S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138324.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31218, 2154, 'Psych Agentes Especiais S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138325.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31219, 2154, 'Psych Agentes Especiais S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138326.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31220, 2154, 'Psych Agentes Especiais S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138327.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31221, 2154, 'Psych Agentes Especiais S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138328.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31222, 2154, 'Psych Agentes Especiais S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138329.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31223, 2154, 'Psych Agentes Especiais S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138330.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31224, 2154, 'Psych Agentes Especiais S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138331.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31225, 2154, 'Psych Agentes Especiais S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138332.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31226, 2154, 'Psych Agentes Especiais S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138333.mp4', 'http://gstaticontent.com/images/24aca3437ceede46861c1e059deda021.jpg'),
(31227, 2155, 'Reality Z S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113775.mp4', 'http://timg.bdta.pro/images/c1f92adab98418449813281787ca7363.jpg'),
(31228, 2155, 'Reality Z S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113776.mp4', 'http://timg.bdta.pro/images/7204fcce6eb77aa5b6011ee39383b517.jpg'),
(31229, 2155, 'Reality Z S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113777.mp4', 'http://timg.bdta.pro/images/feffc245746e70fbdf5e8f4f7419613a.jpg'),
(31230, 2155, 'Reality Z S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113778.mp4', 'http://timg.bdta.pro/images/3e4952005b2f45f6ae4dbf32fcf9377f.jpg'),
(31231, 2155, 'Reality Z S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113779.mp4', 'http://timg.bdta.pro/images/9c049223151a477f3e36ce9cfa45e401.jpg'),
(31232, 2155, 'Reality Z S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113780.mp4', 'http://timg.bdta.pro/images/b98ec64c507080facf5407683f191e65.jpg'),
(31233, 2155, 'Reality Z S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113781.mp4', 'http://timg.bdta.pro/images/38654bab29a72a8a8392962cdd9d6e9c.jpg'),
(31234, 2155, 'Reality Z S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113782.mp4', 'http://timg.bdta.pro/images/650cc1a6938025dee7f12de2fe3c2e08.jpg'),
(31235, 2155, 'Reality Z S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113783.mp4', 'http://timg.bdta.pro/images/75229d9a989e7d472716256273f0c47d.jpg'),
(31236, 2155, 'Reality Z S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113784.mp4', 'http://timg.bdta.pro/images/6fbfef62e03848b5f243ec944ba3a81f.jpg'),
(31237, 2156, 'Run Coyote Run S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113762.mp4', 'http://timg.bdta.pro/images/082470002cc6809284f234d55f21c9ab.jpg'),
(31238, 2156, 'Run Coyote Run S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113763.mp4', 'http://timg.bdta.pro/images/54b19f31f095bd6cbe162bb6ddb82035.jpg'),
(31239, 2156, 'Run Coyote Run S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113764.mp4', 'http://timg.bdta.pro/images/ea9335951277ce176203097b2d96474c.jpg'),
(31240, 2156, 'Run Coyote Run S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113765.mp4', 'http://timg.bdta.pro/images/89c0b94091a9bbd04ab9c9360d85e534.jpg'),
(31241, 2156, 'Run Coyote Run S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113766.mp4', 'http://timg.bdta.pro/images/2f4b567746e376e46eda2b4fbc7082c6.jpg'),
(31242, 2156, 'Run Coyote Run S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113767.mp4', 'http://timg.bdta.pro/images/fa7028f52f8858ede33c4a6f605e884e.jpg'),
(31243, 2156, 'Run Coyote Run S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113768.mp4', 'http://timg.bdta.pro/images/5bd4a3368e7d0369b4ccc69ebff92175.jpg'),
(31244, 2156, 'Run Coyote Run S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113769.mp4', 'http://timg.bdta.pro/images/ded307e94ea4fcf163821cc3041d221d.jpg'),
(31245, 2156, 'Run Coyote Run S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113770.mp4', 'http://timg.bdta.pro/images/56dfffe84542dec62dc050bb907479a7.jpg'),
(31246, 2156, 'Run Coyote Run S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113771.mp4', 'http://timg.bdta.pro/images/b738c803b591a424b70ebfee8fbddc12.jpg'),
(31247, 2156, 'Run Coyote Run S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113772.mp4', 'http://timg.bdta.pro/images/dc557be14247d793d07caf53bed73445.jpg'),
(31248, 2156, 'Run Coyote Run S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113773.mp4', 'http://timg.bdta.pro/images/fd31d8f01c4dfeb1b7eb197009dbc766.jpg'),
(31249, 2156, 'Run Coyote Run S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113774.mp4', 'http://timg.bdta.pro/images/ada2082a97ded94bdf840d11257a94a8.jpg'),
(31250, 2157, 'Secretos de Estado [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113749.mp4', 'http://gstaticontent.com/images/jVLTq2jOIeN7sNHej4AZfTzBR0J_big.jpg'),
(31251, 2157, 'Secretos de Estado [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113750.mp4', 'http://gstaticontent.com/images/jVLTq2jOIeN7sNHej4AZfTzBR0J_big.jpg'),
(31252, 2157, 'Secretos de Estado [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113751.mp4', 'http://timg.bdta.pro/images/3ee275bf4f21d78bbee8d522701bc26c.jpg'),
(31253, 2157, 'Secretos de Estado [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113752.mp4', 'http://gstaticontent.com/images/jVLTq2jOIeN7sNHej4AZfTzBR0J_big.jpg'),
(31254, 2157, 'Secretos de Estado [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113753.mp4', 'http://timg.bdta.pro/images/9a4b04c17d51a35a85e734c9143763e0.jpg'),
(31255, 2157, 'Secretos de Estado [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113754.mp4', 'http://timg.bdta.pro/images/c58ad41e302aa36b096117052ec611cd.jpg'),
(31256, 2157, 'Secretos de Estado [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113755.mp4', 'http://timg.bdta.pro/images/c2669779b88b8dece19f36a979756921.jpg'),
(31257, 2157, 'Secretos de Estado [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113756.mp4', 'http://gstaticontent.com/images/jVLTq2jOIeN7sNHej4AZfTzBR0J_big.jpg'),
(31258, 2157, 'Secretos de Estado [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113757.mp4', 'http://gstaticontent.com/images/jVLTq2jOIeN7sNHej4AZfTzBR0J_big.jpg'),
(31259, 2157, 'Secretos de Estado [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113758.mp4', 'http://gstaticontent.com/images/jVLTq2jOIeN7sNHej4AZfTzBR0J_big.jpg'),
(31260, 2157, 'Secretos de Estado [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113759.mp4', 'http://gstaticontent.com/images/jVLTq2jOIeN7sNHej4AZfTzBR0J_big.jpg'),
(31261, 2157, 'Secretos de Estado [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113760.mp4', 'http://gstaticontent.com/images/jVLTq2jOIeN7sNHej4AZfTzBR0J_big.jpg'),
(31262, 2157, 'Secretos de Estado [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113761.mp4', 'http://timg.bdta.pro/images/e34f20672427824cf5f820880640dc7a.jpg'),
(31263, 2158, 'Seja Nosso Chef S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113738.mp4', 'http://timg.bdta.pro/images/ca85c4ea5122daf6f08759ede826e42a.jpg'),
(31264, 2158, 'Seja Nosso Chef S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113739.mp4', 'http://gstaticontent.com/images/6htXifchsp1aQqYqOFVNjdx3tsr_big.jpg'),
(31265, 2158, 'Seja Nosso Chef S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113740.mp4', 'http://gstaticontent.com/images/6htXifchsp1aQqYqOFVNjdx3tsr_big.jpg'),
(31266, 2158, 'Seja Nosso Chef S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113741.mp4', 'http://gstaticontent.com/images/6htXifchsp1aQqYqOFVNjdx3tsr_big.jpg'),
(31267, 2158, 'Seja Nosso Chef S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113742.mp4', 'http://gstaticontent.com/images/6htXifchsp1aQqYqOFVNjdx3tsr_big.jpg'),
(31268, 2158, 'Seja Nosso Chef S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113743.mp4', 'http://gstaticontent.com/images/6htXifchsp1aQqYqOFVNjdx3tsr_big.jpg'),
(31269, 2158, 'Seja Nosso Chef S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113744.mp4', 'http://gstaticontent.com/images/6htXifchsp1aQqYqOFVNjdx3tsr_big.jpg'),
(31270, 2158, 'Seja Nosso Chef S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113745.mp4', 'http://gstaticontent.com/images/6htXifchsp1aQqYqOFVNjdx3tsr_big.jpg'),
(31271, 2158, 'Seja Nosso Chef S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113746.mp4', 'http://gstaticontent.com/images/6htXifchsp1aQqYqOFVNjdx3tsr_big.jpg'),
(31272, 2158, 'Seja Nosso Chef S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113747.mp4', 'http://gstaticontent.com/images/6htXifchsp1aQqYqOFVNjdx3tsr_big.jpg'),
(31273, 2158, 'Seja Nosso Chef S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113748.mp4', 'http://gstaticontent.com/images/6htXifchsp1aQqYqOFVNjdx3tsr_big.jpg'),
(31274, 2159, 'Space Force S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174660.mp4', 'http://timg.bdta.pro/images/66333bebdecd1b12f1f6a1e36b9a45dd.jpg'),
(31275, 2159, 'Space Force S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174661.mp4', 'http://timg.bdta.pro/images/f1a926387f954b5dd15584c85b989bf9.jpg'),
(31276, 2159, 'Space Force S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174662.mp4', 'http://timg.bdta.pro/images/480ad012a8fb9d46702678b0c8642505.jpg'),
(31277, 2159, 'Space Force S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174663.mp4', 'http://timg.bdta.pro/images/2a4b0ebf44c0bd1eb449b2e326fbaa3d.jpg'),
(31278, 2159, 'Space Force S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174664.mp4', 'http://timg.bdta.pro/images/e12767b0c3206d9218932052b9da7f3e.jpg'),
(31279, 2159, 'Space Force S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174665.mp4', 'http://timg.bdta.pro/images/e5d047bfd8f8e952d8421b2cdd9efbda.jpg'),
(31280, 2159, 'Space Force S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174666.mp4', 'http://timg.bdta.pro/images/ead8352e4e5068a368b6ca381838a7c2.jpg'),
(31281, 2159, 'Space Force S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174667.mp4', 'http://timg.bdta.pro/images/a4f98c0e431248bb109cd088f378d65b.jpg'),
(31282, 2159, 'Space Force S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174668.mp4', 'http://timg.bdta.pro/images/e599add1c676010c61747469de0b96fa.jpg'),
(31283, 2159, 'Space Force S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174669.mp4', 'http://timg.bdta.pro/images/84120d75c3352c9eea9f2cb6ce33fc45.jpg'),
(31284, 2160, 'Space Force S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174670.mp4', 'http://timg.bdta.pro/images/8177ae5d45aaca0fad8ecc594f0111b5.jpg'),
(31285, 2160, 'Space Force S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174671.mp4', 'http://timg.bdta.pro/images/0dfef0476c93fc4edd331cdb7186919e.jpg'),
(31286, 2160, 'Space Force S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174672.mp4', 'http://timg.bdta.pro/images/61275cdc2822ce572ad63af5015af3bb.jpg'),
(31287, 2160, 'Space Force S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174673.mp4', 'http://timg.bdta.pro/images/1fe86c26ac962884daf9cd65df12ac2f.jpg'),
(31288, 2160, 'Space Force S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174674.mp4', 'http://timg.bdta.pro/images/f7779852ab62e99fcadcd9726b7673fb.jpg'),
(31289, 2160, 'Space Force S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174675.mp4', 'http://timg.bdta.pro/images/35108e04f738cb08e19e1b403cdbf559.jpg'),
(31290, 2160, 'Space Force S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174676.mp4', 'http://timg.bdta.pro/images/c2057ce6bd40f25621b62ae74d738f39.jpg'),
(31291, 2161, 'Spides [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113730.mp4', 'http://timg.bdta.pro/images/fd3d5e06ee4bfc0d7d65987ef02fefaa.jpg'),
(31292, 2161, 'Spides [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113731.mp4', 'http://timg.bdta.pro/images/7490200ea9dd41271bf8716d5e5e6653.jpg'),
(31293, 2161, 'Spides [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113732.mp4', 'http://timg.bdta.pro/images/d014d0ffbd9f3cf05aadc1f2f8180799.jpg'),
(31294, 2161, 'Spides [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113733.mp4', 'http://timg.bdta.pro/images/4db9abfc0bd8b874ed064fc14e7e3c18.jpg'),
(31295, 2161, 'Spides [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113734.mp4', 'http://timg.bdta.pro/images/1f60852ea7abcb7e26bae8a55cec8bba.jpg'),
(31296, 2161, 'Spides [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113735.mp4', 'http://timg.bdta.pro/images/ede9b06894d416dedb97f45440bbccae.jpg'),
(31297, 2161, 'Spides [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113736.mp4', 'http://timg.bdta.pro/images/32ce1fdd9db0d543cbd6d7719de1a9f1.jpg'),
(31298, 2161, 'Spides [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113737.mp4', 'http://timg.bdta.pro/images/17cc21f6b939b27b26ed0034b1f3e725.jpg'),
(31299, 2162, 'Star vs. As Forças do Mal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113653.mp4', 'http://timg.bdta.pro/images/ad9236f55e2949a5c24c561dea7f0a1f.jpg'),
(31300, 2162, 'Star vs. As Forças do Mal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113654.mp4', 'http://timg.bdta.pro/images/770cbb197a3b8c96a2a83d85c2afa715.jpg'),
(31301, 2162, 'Star vs. As Forças do Mal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113655.mp4', 'http://timg.bdta.pro/images/72c4ccd5f9124a1e4f4213049da450c5.jpg'),
(31302, 2162, 'Star vs. As Forças do Mal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113656.mp4', 'http://timg.bdta.pro/images/a66d92408260bc567d99f2ac0d678168.jpg'),
(31303, 2162, 'Star vs. As Forças do Mal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113657.mp4', 'http://timg.bdta.pro/images/8b2bba1d247badbb0df2c0e16511e0ec.jpg'),
(31304, 2162, 'Star vs. As Forças do Mal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113658.mp4', 'http://timg.bdta.pro/images/af6a2cd8f1bad678537536ce1587c8c9.jpg'),
(31305, 2162, 'Star vs. As Forças do Mal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113659.mp4', 'http://timg.bdta.pro/images/ec014dcac9b2a65fc3bff07f9a770e8b.jpg'),
(31306, 2162, 'Star vs. As Forças do Mal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113660.mp4', 'http://timg.bdta.pro/images/efe4bb63541f8387013c40e0bf2c0026.jpg'),
(31307, 2162, 'Star vs. As Forças do Mal S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113661.mp4', 'http://timg.bdta.pro/images/494419becdb7791f9f4a4d6534e709f2.jpg'),
(31308, 2162, 'Star vs. As Forças do Mal S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113662.mp4', 'http://gstaticontent.com/images/szInjlmMxTOO2qPiizNAihjAO00_big.jpg'),
(31309, 2162, 'Star vs. As Forças do Mal S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113663.mp4', 'http://gstaticontent.com/images/szInjlmMxTOO2qPiizNAihjAO00_big.jpg'),
(31310, 2162, 'Star vs. As Forças do Mal S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113664.mp4', 'http://timg.bdta.pro/images/a8e81fe1c19e5a90871b2682e44d7d23.jpg'),
(31311, 2162, 'Star vs. As Forças do Mal S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113665.mp4', 'http://timg.bdta.pro/images/f6104c376cb4a2ab643207944bb17396.jpg'),
(31312, 2163, 'Star vs. As Forças do Mal S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113666.mp4', 'http://gstaticontent.com/images/szInjlmMxTOO2qPiizNAihjAO00_big.jpg'),
(31313, 2163, 'Star vs. As Forças do Mal S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113667.mp4', 'http://timg.bdta.pro/images/542a69aee7ceabeb654fa5e8024f92a9.jpg'),
(31314, 2163, 'Star vs. As Forças do Mal S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113668.mp4', 'http://timg.bdta.pro/images/b23c78351062b1ce4c135757b270a26d.jpg'),
(31315, 2163, 'Star vs. As Forças do Mal S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113669.mp4', 'http://timg.bdta.pro/images/0443835766b5baef444ef68f221579f3.jpg'),
(31316, 2163, 'Star vs. As Forças do Mal S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113670.mp4', 'http://timg.bdta.pro/images/d233311ace0e877de343d7341d5bd505.jpg'),
(31317, 2163, 'Star vs. As Forças do Mal S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113671.mp4', 'http://timg.bdta.pro/images/aeab778742c94e34c2331a26e538da7c.jpg'),
(31318, 2163, 'Star vs. As Forças do Mal S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113672.mp4', 'http://timg.bdta.pro/images/4a87205b8c2706fa89a6fc39233cb98b.jpg'),
(31319, 2163, 'Star vs. As Forças do Mal S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113673.mp4', 'http://timg.bdta.pro/images/21cafca1880c63634f867906dbfa49e4.jpg'),
(31320, 2163, 'Star vs. As Forças do Mal S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113674.mp4', 'http://timg.bdta.pro/images/c97cb79ffb2a0e9eb7802c70ab080198.jpg'),
(31321, 2163, 'Star vs. As Forças do Mal S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113675.mp4', 'http://timg.bdta.pro/images/c6b7e952ffa6fe96af3f5a08c66c225b.jpg'),
(31322, 2163, 'Star vs. As Forças do Mal S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113676.mp4', 'http://timg.bdta.pro/images/c56fd4f7161e96c442d0c1901bb7cbb1.jpg'),
(31323, 2163, 'Star vs. As Forças do Mal S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113677.mp4', 'http://timg.bdta.pro/images/818047c187ea86c803f8b59a6e162ba1.jpg'),
(31324, 2163, 'Star vs. As Forças do Mal S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113678.mp4', 'http://timg.bdta.pro/images/078b81235a1f230d5c15f00a5c15853e.jpg'),
(31325, 2163, 'Star vs. As Forças do Mal S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113679.mp4', 'http://timg.bdta.pro/images/6280452fb45c683210d90c847e8fd18c.jpg'),
(31326, 2163, 'Star vs. As Forças do Mal S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113680.mp4', 'http://timg.bdta.pro/images/792287ef7e8254af26fd8a86aa302305.jpg'),
(31327, 2163, 'Star vs. As Forças do Mal S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113681.mp4', 'http://timg.bdta.pro/images/da3f5c6fea918ea3115186200cea7a2a.jpg'),
(31328, 2163, 'Star vs. As Forças do Mal S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113682.mp4', 'http://timg.bdta.pro/images/73973141491571144582e2b7069c96e5.jpg'),
(31329, 2163, 'Star vs. As Forças do Mal S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113683.mp4', 'http://timg.bdta.pro/images/2e4744f3f4c73cfca8575bdca4bbdfd5.jpg'),
(31330, 2163, 'Star vs. As Forças do Mal S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113684.mp4', 'http://timg.bdta.pro/images/008d0a43456be6349fb7229073e11145.jpg'),
(31331, 2163, 'Star vs. As Forças do Mal S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/113685.mp4', 'http://timg.bdta.pro/images/ede54a00c21e975a78bd08de48825beb.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(31332, 2163, 'Star vs. As Forças do Mal S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/113686.mp4', 'http://timg.bdta.pro/images/e4ab33d3c28997abff5a9b86da6e14cc.jpg'),
(31333, 2163, 'Star vs. As Forças do Mal S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/113687.mp4', 'http://timg.bdta.pro/images/754253074cd1a4242ace0d6796dc789e.jpg'),
(31334, 2164, 'Star vs. As Forças do Mal S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113688.mp4', 'http://timg.bdta.pro/images/3faa114aecf12c59c08415b74b8bfaff.jpg'),
(31335, 2164, 'Star vs. As Forças do Mal S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113689.mp4', 'http://timg.bdta.pro/images/c665fa5e27d2df58f5093cbafe68ae10.jpg'),
(31336, 2164, 'Star vs. As Forças do Mal S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113690.mp4', 'http://timg.bdta.pro/images/45fb99b6101c37703d59d7ba516e806d.jpg'),
(31337, 2164, 'Star vs. As Forças do Mal S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113691.mp4', 'http://timg.bdta.pro/images/ca8394c80f39c5f6fc4921f78917fa5b.jpg'),
(31338, 2164, 'Star vs. As Forças do Mal S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113692.mp4', 'http://timg.bdta.pro/images/7ef5bbaba2c043be58d7efb6711db5f5.jpg'),
(31339, 2164, 'Star vs. As Forças do Mal S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113693.mp4', 'http://timg.bdta.pro/images/e40a4ace0aaaa8f102af80b8cdd27380.jpg'),
(31340, 2164, 'Star vs. As Forças do Mal S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113694.mp4', 'http://timg.bdta.pro/images/65c067f5647f651d93e4846b7221953c.jpg'),
(31341, 2164, 'Star vs. As Forças do Mal S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113695.mp4', 'http://timg.bdta.pro/images/f66f619bde055778a9306489e8916dc8.jpg'),
(31342, 2164, 'Star vs. As Forças do Mal S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113696.mp4', 'http://timg.bdta.pro/images/6a1437a4cb5ce47116ae887d6a29537b.jpg'),
(31343, 2164, 'Star vs. As Forças do Mal S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113697.mp4', 'http://timg.bdta.pro/images/61910b4c5e19935afc3bdbd9d7f44059.jpg'),
(31344, 2164, 'Star vs. As Forças do Mal S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113698.mp4', 'http://timg.bdta.pro/images/41ab9832251cc69c3b9420ad03770434.jpg'),
(31345, 2164, 'Star vs. As Forças do Mal S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113699.mp4', 'http://timg.bdta.pro/images/cde3a9617864b53f132a472bd913cb5b.jpg'),
(31346, 2164, 'Star vs. As Forças do Mal S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113700.mp4', 'http://timg.bdta.pro/images/8719bc06d271a211a1d266e8f7a09185.jpg'),
(31347, 2164, 'Star vs. As Forças do Mal S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113701.mp4', 'http://timg.bdta.pro/images/bea11f47e709068145b09cf61507727f.jpg'),
(31348, 2164, 'Star vs. As Forças do Mal S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113702.mp4', 'http://timg.bdta.pro/images/5f66f5dd4bfead5afeeb944b98617b4c.jpg'),
(31349, 2164, 'Star vs. As Forças do Mal S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113703.mp4', 'http://timg.bdta.pro/images/32b067935f69d39c79c4bacc81ecda5c.jpg'),
(31350, 2164, 'Star vs. As Forças do Mal S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113704.mp4', 'http://timg.bdta.pro/images/ccbd5e4b50486ba63ceb48b52a2966cb.jpg'),
(31351, 2164, 'Star vs. As Forças do Mal S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113705.mp4', 'http://timg.bdta.pro/images/c267b5fbc1df5e3195ed58f81289d28f.jpg'),
(31352, 2164, 'Star vs. As Forças do Mal S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113706.mp4', 'http://timg.bdta.pro/images/b5e6c04fe8758f34f0056b5ec2844af7.jpg'),
(31353, 2164, 'Star vs. As Forças do Mal S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/113707.mp4', 'http://timg.bdta.pro/images/71998409ab5c8986c5441aeb2feca8d0.jpg'),
(31354, 2164, 'Star vs. As Forças do Mal S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/113708.mp4', 'http://timg.bdta.pro/images/ebfd276fe0fb8dcf175cfd6dcbe6e27d.jpg'),
(31355, 2165, 'Star vs. As Forças do Mal S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113709.mp4', 'http://timg.bdta.pro/images/270a6be76c3ebb792584d900aa38e2bf.jpg'),
(31356, 2165, 'Star vs. As Forças do Mal S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113710.mp4', 'http://timg.bdta.pro/images/f9cddfb55e89d4d64add83a78d0f9280.jpg'),
(31357, 2165, 'Star vs. As Forças do Mal S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113711.mp4', 'http://timg.bdta.pro/images/e17571a8106db80f32adf4a4dd35d4ee.jpg'),
(31358, 2165, 'Star vs. As Forças do Mal S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113712.mp4', 'http://timg.bdta.pro/images/6ee263fccd0795de20f9b93ca5e30554.jpg'),
(31359, 2165, 'Star vs. As Forças do Mal S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113713.mp4', 'http://timg.bdta.pro/images/b4ef5f055d1e6f16a6dbb1773615a582.jpg'),
(31360, 2165, 'Star vs. As Forças do Mal S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113714.mp4', 'http://timg.bdta.pro/images/ebe152cc02ced3033756f15048840d11.jpg'),
(31361, 2165, 'Star vs. As Forças do Mal S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113715.mp4', 'http://timg.bdta.pro/images/17671ac046b226b8280b1956e987f0e9.jpg'),
(31362, 2165, 'Star vs. As Forças do Mal S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113716.mp4', 'http://timg.bdta.pro/images/f23ce36ca0f67c44d5d5389641cd0bf9.jpg'),
(31363, 2165, 'Star vs. As Forças do Mal S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113717.mp4', 'http://timg.bdta.pro/images/297cb6432d7aed78274c793ea37d3cb6.jpg'),
(31364, 2165, 'Star vs. As Forças do Mal S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113718.mp4', 'http://timg.bdta.pro/images/f0a4c6a9baae1626ea947438911283f8.jpg'),
(31365, 2165, 'Star vs. As Forças do Mal S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113719.mp4', 'http://timg.bdta.pro/images/a3d6f663defc296676f2b89bbbeabda1.jpg'),
(31366, 2165, 'Star vs. As Forças do Mal S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113720.mp4', 'http://timg.bdta.pro/images/07d9e49ef0859122159a05dd6f821877.jpg'),
(31367, 2165, 'Star vs. As Forças do Mal S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113721.mp4', 'http://timg.bdta.pro/images/36dc47799fa5bffab39a316633bc3df1.jpg'),
(31368, 2165, 'Star vs. As Forças do Mal S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113722.mp4', 'http://timg.bdta.pro/images/a14af0f85e022cdadc3f4f7f2549fbfd.jpg'),
(31369, 2165, 'Star vs. As Forças do Mal S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113723.mp4', 'http://timg.bdta.pro/images/9186c6cd826511396826de142acc8364.jpg'),
(31370, 2165, 'Star vs. As Forças do Mal S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113724.mp4', 'http://timg.bdta.pro/images/88186e79f587ca04441e22629c3e6cb9.jpg'),
(31371, 2165, 'Star vs. As Forças do Mal S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113725.mp4', 'http://timg.bdta.pro/images/9558e71410e33c04f12d6420e9cb027f.jpg'),
(31372, 2165, 'Star vs. As Forças do Mal S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113726.mp4', 'http://timg.bdta.pro/images/5c85ce973a220e1936ad54d5c95b072a.jpg'),
(31373, 2165, 'Star vs. As Forças do Mal S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113727.mp4', 'http://timg.bdta.pro/images/65d28f362a48eebe35bb802826a1776e.jpg'),
(31374, 2165, 'Star vs. As Forças do Mal S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/113728.mp4', 'http://timg.bdta.pro/images/4398cdc5231b984fad4e747ef91ed656.jpg'),
(31375, 2165, 'Star vs. As Forças do Mal S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/113729.mp4', 'http://timg.bdta.pro/images/9b0d84a8bdf6fc189366ad5b07907ef7.jpg'),
(31376, 2166, 'Star Wars: A Guerra dos Clones S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113520.mp4', 'http://timg.bdta.pro/images/fddd24e5ca28ddcbb8d5552c36978757.jpg'),
(31377, 2166, 'Star Wars: A Guerra dos Clones S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113521.mp4', 'http://timg.bdta.pro/images/a6443209ad276786495471fef0ecc66d.jpg'),
(31378, 2166, 'Star Wars: A Guerra dos Clones S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113522.mp4', 'http://timg.bdta.pro/images/2e609673142e735dbaa8c6952e745980.jpg'),
(31379, 2166, 'Star Wars: A Guerra dos Clones S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113523.mp4', 'http://timg.bdta.pro/images/8d6e79e512f3d00b367157d1294d95a6.jpg'),
(31380, 2166, 'Star Wars: A Guerra dos Clones S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113524.mp4', 'http://timg.bdta.pro/images/2f69d63bc0be1f50b29fc089987e0bec.jpg'),
(31381, 2166, 'Star Wars: A Guerra dos Clones S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113525.mp4', 'http://timg.bdta.pro/images/8709cc64aa0aecbd76ed9647a2184711.jpg'),
(31382, 2166, 'Star Wars: A Guerra dos Clones S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113526.mp4', 'http://timg.bdta.pro/images/7f43df7646ea774e1f6fed90483d19b9.jpg'),
(31383, 2166, 'Star Wars: A Guerra dos Clones S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113527.mp4', 'http://timg.bdta.pro/images/21c525466db1830862ab3964041744ab.jpg'),
(31384, 2166, 'Star Wars: A Guerra dos Clones S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113528.mp4', 'http://timg.bdta.pro/images/f1ab454d4eb9da7b159fe380f3a4319c.jpg'),
(31385, 2166, 'Star Wars: A Guerra dos Clones S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113529.mp4', 'http://timg.bdta.pro/images/fce6795e75f583614f7ccb45d4182a27.jpg'),
(31386, 2166, 'Star Wars: A Guerra dos Clones S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113530.mp4', 'http://timg.bdta.pro/images/fc740a937c3c98ea9154efac4c62f824.jpg'),
(31387, 2166, 'Star Wars: A Guerra dos Clones S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113531.mp4', 'http://timg.bdta.pro/images/68aedf603adc33b4656af33c8ddb5e1b.jpg'),
(31388, 2166, 'Star Wars: A Guerra dos Clones S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113532.mp4', 'http://timg.bdta.pro/images/575d8c7d43cd17740ba4322955d7e929.jpg'),
(31389, 2166, 'Star Wars: A Guerra dos Clones S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113533.mp4', 'http://timg.bdta.pro/images/6c2748bd4fb4f32c338249ab9fd579f6.jpg'),
(31390, 2166, 'Star Wars: A Guerra dos Clones S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113534.mp4', 'http://timg.bdta.pro/images/468dd8807c60b2b0292bc4ec88f000d7.jpg'),
(31391, 2166, 'Star Wars: A Guerra dos Clones S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113535.mp4', 'http://timg.bdta.pro/images/685e50a1ae53b8e71d94fb3c6fe77c01.jpg'),
(31392, 2166, 'Star Wars: A Guerra dos Clones S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113536.mp4', 'http://timg.bdta.pro/images/1339899064b265656b3275559ed320a2.jpg'),
(31393, 2166, 'Star Wars: A Guerra dos Clones S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113537.mp4', 'http://timg.bdta.pro/images/0890c6b056984575293276785b732dce.jpg'),
(31394, 2166, 'Star Wars: A Guerra dos Clones S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113538.mp4', 'http://timg.bdta.pro/images/7c202e02a439ae123cfa1fd74c8fa22d.jpg'),
(31395, 2166, 'Star Wars: A Guerra dos Clones S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/113539.mp4', 'http://timg.bdta.pro/images/ad1deba490a6204c43afda69551dc418.jpg'),
(31396, 2166, 'Star Wars: A Guerra dos Clones S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/113540.mp4', 'http://timg.bdta.pro/images/d107ea2af08b8374c2dc7f9a3ad13bcd.jpg'),
(31397, 2166, 'Star Wars: A Guerra dos Clones S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/113541.mp4', 'http://timg.bdta.pro/images/0a6e04608a448d6b07c00639e6f1654a.jpg'),
(31398, 2167, 'Star Wars: A Guerra dos Clones S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113542.mp4', 'http://timg.bdta.pro/images/15d92f32f833374d66f7daf1c6d372f4.jpg'),
(31399, 2167, 'Star Wars: A Guerra dos Clones S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113543.mp4', 'http://timg.bdta.pro/images/8d7d4cb8957af0c183ccb85d15d097fb.jpg'),
(31400, 2167, 'Star Wars: A Guerra dos Clones S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113544.mp4', 'http://timg.bdta.pro/images/395b8de59ec14e17f6286b68b8104eb7.jpg'),
(31401, 2167, 'Star Wars: A Guerra dos Clones S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113545.mp4', 'http://timg.bdta.pro/images/b237a9ac563e7817d55c3f783c1249c3.jpg'),
(31402, 2167, 'Star Wars: A Guerra dos Clones S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113546.mp4', 'http://timg.bdta.pro/images/a71e909252ba194d1812c003d90aa4e4.jpg'),
(31403, 2167, 'Star Wars: A Guerra dos Clones S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113547.mp4', 'http://timg.bdta.pro/images/b292daaf18502f15bf6d7e66677e94ba.jpg'),
(31404, 2167, 'Star Wars: A Guerra dos Clones S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113548.mp4', 'http://timg.bdta.pro/images/df36e6866e1dee41546dca8cf08b994f.jpg'),
(31405, 2167, 'Star Wars: A Guerra dos Clones S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113549.mp4', 'http://timg.bdta.pro/images/060272eef525c2a8dfe44209ec230c74.jpg'),
(31406, 2167, 'Star Wars: A Guerra dos Clones S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113550.mp4', 'http://timg.bdta.pro/images/890ba4a828bb652c0e526e0a251e54e2.jpg'),
(31407, 2167, 'Star Wars: A Guerra dos Clones S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113551.mp4', 'http://timg.bdta.pro/images/26b86bcc28b384768eb0f4c75ab4dd9f.jpg'),
(31408, 2167, 'Star Wars: A Guerra dos Clones S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113552.mp4', 'http://timg.bdta.pro/images/fd9a97978cd9da39cd24e636af94fca9.jpg'),
(31409, 2167, 'Star Wars: A Guerra dos Clones S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113553.mp4', 'http://timg.bdta.pro/images/a718ba25313549ea44fe49974f070ec0.jpg'),
(31410, 2167, 'Star Wars: A Guerra dos Clones S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113554.mp4', 'http://timg.bdta.pro/images/70f07b0e8bbc6214b32dd848ab675181.jpg'),
(31411, 2167, 'Star Wars: A Guerra dos Clones S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113555.mp4', 'http://timg.bdta.pro/images/10a00603646daaaa66a3df6f2ea9d3e0.jpg'),
(31412, 2167, 'Star Wars: A Guerra dos Clones S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113556.mp4', 'http://timg.bdta.pro/images/250304c5b0caaf54796d7a43f4668bcf.jpg'),
(31413, 2167, 'Star Wars: A Guerra dos Clones S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113557.mp4', 'http://timg.bdta.pro/images/ffd0d2319cd133797390a29a0f9eb104.jpg'),
(31414, 2167, 'Star Wars: A Guerra dos Clones S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113558.mp4', 'http://timg.bdta.pro/images/59285499e5de0c512a3b8c2813bb4876.jpg'),
(31415, 2167, 'Star Wars: A Guerra dos Clones S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113559.mp4', 'http://timg.bdta.pro/images/ab2886ad8d8b622f059b166d3d2d357f.jpg'),
(31416, 2167, 'Star Wars: A Guerra dos Clones S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113560.mp4', 'http://timg.bdta.pro/images/4126cd1fed8394573440528b64e5777c.jpg'),
(31417, 2167, 'Star Wars: A Guerra dos Clones S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/113561.mp4', 'http://timg.bdta.pro/images/d17d15e17a25addda1933e5827ec354f.jpg'),
(31418, 2167, 'Star Wars: A Guerra dos Clones S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/113562.mp4', 'http://timg.bdta.pro/images/0c31315d3603465a7f5f84867f9bad6f.jpg'),
(31419, 2167, 'Star Wars: A Guerra dos Clones S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/113563.mp4', 'http://timg.bdta.pro/images/c21ab1890d4e74904c2161b4040e95d0.jpg'),
(31420, 2168, 'Star Wars: A Guerra dos Clones S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113564.mp4', 'http://timg.bdta.pro/images/92dc3f99d74235255e63adb8d6d990d0.jpg'),
(31421, 2168, 'Star Wars: A Guerra dos Clones S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113565.mp4', 'http://timg.bdta.pro/images/08d9476021d43408bd8bbafbfa3e52ad.jpg'),
(31422, 2168, 'Star Wars: A Guerra dos Clones S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113566.mp4', 'http://timg.bdta.pro/images/7ea0fde51dca585685b6b531251d3f05.jpg'),
(31423, 2168, 'Star Wars: A Guerra dos Clones S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113567.mp4', 'http://timg.bdta.pro/images/355dc5f7bb0670b6ffe89253171f6c93.jpg'),
(31424, 2168, 'Star Wars: A Guerra dos Clones S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113568.mp4', 'http://timg.bdta.pro/images/9b21ebbedbf43752af03194d0f702e23.jpg'),
(31425, 2168, 'Star Wars: A Guerra dos Clones S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113569.mp4', 'http://timg.bdta.pro/images/d402064f96cd98ea14ab8cb3abd0c83a.jpg'),
(31426, 2168, 'Star Wars: A Guerra dos Clones S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113570.mp4', 'http://timg.bdta.pro/images/f05d2087a35b29ce250f3bb3133be676.jpg'),
(31427, 2168, 'Star Wars: A Guerra dos Clones S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113571.mp4', 'http://timg.bdta.pro/images/8622487b3a613e46b3f7a70f5257ae4c.jpg'),
(31428, 2168, 'Star Wars: A Guerra dos Clones S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113572.mp4', 'http://timg.bdta.pro/images/1c5393d9b9dd23f90fea1d70d2f526e1.jpg'),
(31429, 2168, 'Star Wars: A Guerra dos Clones S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113573.mp4', 'http://timg.bdta.pro/images/8b168b5f6716bb265133ed15b3fda224.jpg'),
(31430, 2168, 'Star Wars: A Guerra dos Clones S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113574.mp4', 'http://timg.bdta.pro/images/af859b0faea9c24f8c7c9a952045de66.jpg'),
(31431, 2168, 'Star Wars: A Guerra dos Clones S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113575.mp4', 'http://timg.bdta.pro/images/70f120b24afda3920321a1f2319fe408.jpg'),
(31432, 2168, 'Star Wars: A Guerra dos Clones S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113576.mp4', 'http://timg.bdta.pro/images/ecebb213edd4efb3775edcb7d64e15e7.jpg'),
(31433, 2168, 'Star Wars: A Guerra dos Clones S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113577.mp4', 'http://timg.bdta.pro/images/0e290f0ab4db9321d5534e853a1c5b05.jpg'),
(31434, 2168, 'Star Wars: A Guerra dos Clones S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113578.mp4', 'http://timg.bdta.pro/images/d210d3bd0c0f556fbc9e0b2e9b247c79.jpg'),
(31435, 2168, 'Star Wars: A Guerra dos Clones S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113579.mp4', 'http://timg.bdta.pro/images/57b5e4b5fa2be77613d53e366bc63181.jpg'),
(31436, 2168, 'Star Wars: A Guerra dos Clones S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113580.mp4', 'http://timg.bdta.pro/images/eeecf51e4195b1109168584b5393ee07.jpg'),
(31437, 2168, 'Star Wars: A Guerra dos Clones S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113581.mp4', 'http://timg.bdta.pro/images/194e628260c94edd93a44ed58066cff6.jpg'),
(31438, 2168, 'Star Wars: A Guerra dos Clones S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113582.mp4', 'http://timg.bdta.pro/images/0b49e4b7330bd6db300a1a299ba16034.jpg'),
(31439, 2168, 'Star Wars: A Guerra dos Clones S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/113583.mp4', 'http://timg.bdta.pro/images/02390b11e85634477fb46659da52bbeb.jpg'),
(31440, 2168, 'Star Wars: A Guerra dos Clones S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/113584.mp4', 'http://timg.bdta.pro/images/3c2aecd532220edcc1e695d24d7fabc6.jpg'),
(31441, 2168, 'Star Wars: A Guerra dos Clones S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/113585.mp4', 'http://timg.bdta.pro/images/2d578bb7b18f2a5ebf909ac92eee4a04.jpg'),
(31442, 2169, 'Star Wars: A Guerra dos Clones S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113586.mp4', 'http://timg.bdta.pro/images/b0790a46aca83da9c83f7e06a20459ec.jpg'),
(31443, 2169, 'Star Wars: A Guerra dos Clones S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113587.mp4', 'http://timg.bdta.pro/images/23c936034ecb0d9c5ba852bae24a3ca0.jpg'),
(31444, 2169, 'Star Wars: A Guerra dos Clones S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113588.mp4', 'http://timg.bdta.pro/images/09f297829cdc6d16a88e3dc3b7d730b0.jpg'),
(31445, 2169, 'Star Wars: A Guerra dos Clones S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113589.mp4', 'http://timg.bdta.pro/images/2b063f5060f8d525ec59e5bd87c310b8.jpg'),
(31446, 2169, 'Star Wars: A Guerra dos Clones S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113590.mp4', 'http://timg.bdta.pro/images/b4fd0317f095a730a54a93bdcfd264ad.jpg'),
(31447, 2169, 'Star Wars: A Guerra dos Clones S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113591.mp4', 'http://timg.bdta.pro/images/2c8f8b83c955255dd7361a10845dd15e.jpg'),
(31448, 2169, 'Star Wars: A Guerra dos Clones S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113592.mp4', 'http://timg.bdta.pro/images/a2c2a10395e12948832a52843421cdbd.jpg'),
(31449, 2169, 'Star Wars: A Guerra dos Clones S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113593.mp4', 'http://timg.bdta.pro/images/1944bedafbb4425229eb167ed0129fb1.jpg'),
(31450, 2169, 'Star Wars: A Guerra dos Clones S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113594.mp4', 'http://timg.bdta.pro/images/97d37117e02252df8801021fa43c004f.jpg'),
(31451, 2169, 'Star Wars: A Guerra dos Clones S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113595.mp4', 'http://timg.bdta.pro/images/d714c162a45e15d4e8d5e5968d8a0f8b.jpg'),
(31452, 2169, 'Star Wars: A Guerra dos Clones S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113596.mp4', 'http://timg.bdta.pro/images/7ce0d887148127c1ecc266affc3cbe69.jpg'),
(31453, 2169, 'Star Wars: A Guerra dos Clones S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113597.mp4', 'http://timg.bdta.pro/images/aa64d26305d374a36f169e4d40c97ab1.jpg'),
(31454, 2169, 'Star Wars: A Guerra dos Clones S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113598.mp4', 'http://timg.bdta.pro/images/da16157ef15961e0e16e2724b5fbd8f4.jpg'),
(31455, 2169, 'Star Wars: A Guerra dos Clones S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113599.mp4', 'http://timg.bdta.pro/images/50523e098b340a51e9e80a42299a15dc.jpg'),
(31456, 2169, 'Star Wars: A Guerra dos Clones S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113600.mp4', 'http://timg.bdta.pro/images/e9e5c7e2833fe7928c430bd78e551fcc.jpg'),
(31457, 2169, 'Star Wars: A Guerra dos Clones S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113601.mp4', 'http://timg.bdta.pro/images/7e2870446911871ce527ef8768a12b37.jpg'),
(31458, 2169, 'Star Wars: A Guerra dos Clones S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113602.mp4', 'http://timg.bdta.pro/images/e5ddd175e8d07b0dfa2bc89bc4146635.jpg'),
(31459, 2169, 'Star Wars: A Guerra dos Clones S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113603.mp4', 'http://timg.bdta.pro/images/e35ce3405a2fcb859cbf1f8e1d8482b1.jpg'),
(31460, 2169, 'Star Wars: A Guerra dos Clones S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113604.mp4', 'http://timg.bdta.pro/images/7001db10d5935f0fff2f818791555d5c.jpg'),
(31461, 2169, 'Star Wars: A Guerra dos Clones S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/113605.mp4', 'http://timg.bdta.pro/images/b7a0d48d1f03317b3196cba64337d48c.jpg'),
(31462, 2169, 'Star Wars: A Guerra dos Clones S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/113606.mp4', 'http://timg.bdta.pro/images/ac80ba89641b1ecb613c580b277dd574.jpg'),
(31463, 2169, 'Star Wars: A Guerra dos Clones S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/113607.mp4', 'http://timg.bdta.pro/images/e8f9200953de04a255d07bc121184b54.jpg'),
(31464, 2170, 'Star Wars: A Guerra dos Clones S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113608.mp4', 'http://timg.bdta.pro/images/c225c3e58d396977302a02cf84208e82.jpg'),
(31465, 2170, 'Star Wars: A Guerra dos Clones S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113609.mp4', 'http://timg.bdta.pro/images/72225d67db84ea8ace1de2d3a7bcb572.jpg'),
(31466, 2170, 'Star Wars: A Guerra dos Clones S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113610.mp4', 'http://timg.bdta.pro/images/ccd48ae235d677015aa08a1604458fe6.jpg'),
(31467, 2170, 'Star Wars: A Guerra dos Clones S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113611.mp4', 'http://timg.bdta.pro/images/f20dc5464de95b4b9e71fad2638fbaae.jpg'),
(31468, 2170, 'Star Wars: A Guerra dos Clones S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113612.mp4', 'http://timg.bdta.pro/images/88cc8f39ae6557534dad434b67bc4d17.jpg'),
(31469, 2170, 'Star Wars: A Guerra dos Clones S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113613.mp4', 'http://timg.bdta.pro/images/6fcf11f1deccdf4f39f0d4f1d2f80dca.jpg'),
(31470, 2170, 'Star Wars: A Guerra dos Clones S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113614.mp4', 'http://timg.bdta.pro/images/a7e02a98bb4807205f8b3ce4eb3a7986.jpg'),
(31471, 2170, 'Star Wars: A Guerra dos Clones S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113615.mp4', 'http://timg.bdta.pro/images/b2af4326470e9e6946543bae446f1ca1.jpg'),
(31472, 2170, 'Star Wars: A Guerra dos Clones S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113616.mp4', 'http://timg.bdta.pro/images/a6f979647e40a62e542e4fcb95c498c6.jpg'),
(31473, 2170, 'Star Wars: A Guerra dos Clones S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113617.mp4', 'http://timg.bdta.pro/images/63311e980ca1ade241e1c462b60c9bef.jpg'),
(31474, 2170, 'Star Wars: A Guerra dos Clones S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113618.mp4', 'http://timg.bdta.pro/images/f66aca517cd1e98a0174482918575f32.jpg'),
(31475, 2170, 'Star Wars: A Guerra dos Clones S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113619.mp4', 'http://timg.bdta.pro/images/2548553aff8b020789f7bb4672d5a68a.jpg'),
(31476, 2170, 'Star Wars: A Guerra dos Clones S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113620.mp4', 'http://timg.bdta.pro/images/bed219820a55ad4baabb8627d99b2245.jpg'),
(31477, 2170, 'Star Wars: A Guerra dos Clones S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113621.mp4', 'http://timg.bdta.pro/images/2d2e8852e276c8cf1981dc9ae13b30a0.jpg'),
(31478, 2170, 'Star Wars: A Guerra dos Clones S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113622.mp4', 'http://timg.bdta.pro/images/ca9a5f53c33a595ea7c9ad6e4e745a25.jpg'),
(31479, 2170, 'Star Wars: A Guerra dos Clones S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113623.mp4', 'http://timg.bdta.pro/images/cb9e17955d94c5fdbab28608f187a399.jpg'),
(31480, 2170, 'Star Wars: A Guerra dos Clones S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113624.mp4', 'http://timg.bdta.pro/images/51507c5755b2828a5a14c4fdd56747fe.jpg'),
(31481, 2170, 'Star Wars: A Guerra dos Clones S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113625.mp4', 'http://timg.bdta.pro/images/69bb2c47d4571b6a4d63d2ebc3f84498.jpg'),
(31482, 2170, 'Star Wars: A Guerra dos Clones S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113626.mp4', 'http://timg.bdta.pro/images/2bf2da0beb0099b05ec4893ff788c58b.jpg'),
(31483, 2170, 'Star Wars: A Guerra dos Clones S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/113627.mp4', 'http://timg.bdta.pro/images/248745599a2516304de6269bb361c614.jpg'),
(31484, 2171, 'Star Wars: A Guerra dos Clones S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113628.mp4', 'http://timg.bdta.pro/images/f7ddd740ed24d10babf6c67b1e7a7056.jpg'),
(31485, 2171, 'Star Wars: A Guerra dos Clones S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113629.mp4', 'http://timg.bdta.pro/images/d7691a0e0ae7255fecd8aee79f1eff0a.jpg'),
(31486, 2171, 'Star Wars: A Guerra dos Clones S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113630.mp4', 'http://timg.bdta.pro/images/7db92c091b4983c79266a287411b37b1.jpg'),
(31487, 2171, 'Star Wars: A Guerra dos Clones S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113631.mp4', 'http://timg.bdta.pro/images/9b6921d963c008956793bd2402a42701.jpg'),
(31488, 2171, 'Star Wars: A Guerra dos Clones S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113632.mp4', 'http://timg.bdta.pro/images/de146dd2a8eff6126750694047610b94.jpg'),
(31489, 2171, 'Star Wars: A Guerra dos Clones S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113633.mp4', 'http://timg.bdta.pro/images/c5cb8d72ff925712cbd6f1baf7df1e4f.jpg'),
(31490, 2171, 'Star Wars: A Guerra dos Clones S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113634.mp4', 'http://timg.bdta.pro/images/c07e01f26a2facdb6a29f60a76b46a3e.jpg'),
(31491, 2171, 'Star Wars: A Guerra dos Clones S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113635.mp4', 'http://timg.bdta.pro/images/3bc17ee3d7f2e45b9c21f2bf7f32a9dc.jpg'),
(31492, 2171, 'Star Wars: A Guerra dos Clones S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113636.mp4', 'http://timg.bdta.pro/images/c2a293a5ec032db4f9a2b0c7757dde8b.jpg'),
(31493, 2171, 'Star Wars: A Guerra dos Clones S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113637.mp4', 'http://timg.bdta.pro/images/a4011915f6126d77e2b124db5b5e6ca1.jpg'),
(31494, 2171, 'Star Wars: A Guerra dos Clones S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113638.mp4', 'http://timg.bdta.pro/images/fe7c25c6050ee7f229443af5fe01a467.jpg'),
(31495, 2171, 'Star Wars: A Guerra dos Clones S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113639.mp4', 'http://timg.bdta.pro/images/30d2e52e06ab63fcd14ce8cec9ac22ce.jpg'),
(31496, 2171, 'Star Wars: A Guerra dos Clones S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113640.mp4', 'http://timg.bdta.pro/images/129066730fd7ca36061e8dba5069eb08.jpg'),
(31497, 2172, 'Star Wars: A Guerra dos Clones S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113641.mp4', 'http://timg.bdta.pro/images/f2d4378fa681775a8dcee6404655abe7.jpg'),
(31498, 2172, 'Star Wars: A Guerra dos Clones S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113642.mp4', 'http://timg.bdta.pro/images/322ab52be92570585929a157dd9543da.jpg'),
(31499, 2172, 'Star Wars: A Guerra dos Clones S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113643.mp4', 'http://timg.bdta.pro/images/14951a32c6a08f56f66f0c9fd7d28b41.jpg'),
(31500, 2172, 'Star Wars: A Guerra dos Clones S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113644.mp4', 'http://timg.bdta.pro/images/cd6a6e0284f5546104184499afe4950a.jpg'),
(31501, 2172, 'Star Wars: A Guerra dos Clones S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113645.mp4', 'http://timg.bdta.pro/images/b100c70571d87f8ded5a4758fa8d6f24.jpg'),
(31502, 2172, 'Star Wars: A Guerra dos Clones S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113646.mp4', 'http://timg.bdta.pro/images/5c19a2704405ac0e1fd7f011c0fa39e1.jpg'),
(31503, 2172, 'Star Wars: A Guerra dos Clones S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113647.mp4', 'http://timg.bdta.pro/images/c0c5c24a659d44be4facc22b22687033.jpg'),
(31504, 2172, 'Star Wars: A Guerra dos Clones S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113648.mp4', 'http://timg.bdta.pro/images/5ab52ac40fa4d8403028567fd5910508.jpg'),
(31505, 2172, 'Star Wars: A Guerra dos Clones S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113649.mp4', 'http://timg.bdta.pro/images/dbaf2e20dcfee36153b333e8b29f9d9f.jpg'),
(31506, 2172, 'Star Wars: A Guerra dos Clones S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113650.mp4', 'http://timg.bdta.pro/images/7e17dc81861d0ffb483aebf2baf312dd.jpg'),
(31507, 2172, 'Star Wars: A Guerra dos Clones S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113651.mp4', 'http://timg.bdta.pro/images/1743a1ce107b34b0a2e126ce40e3ab34.jpg'),
(31508, 2172, 'Star Wars: A Guerra dos Clones S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113652.mp4', 'http://timg.bdta.pro/images/fa08f6211d5d30db9139164479a35742.jpg'),
(31509, 2173, 'StarGirl [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161987.mp4', 'http://timg.bdta.pro/images/6e283267be2c310abe81591f1f07603c.jpg'),
(31510, 2173, 'StarGirl [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161988.mp4', 'http://timg.bdta.pro/images/07f214c5f052513e2275c7c589c5290b.jpg'),
(31511, 2173, 'StarGirl [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161989.mp4', 'http://timg.bdta.pro/images/1eba8e729fd2d7b0a403fe899469e265.jpg'),
(31512, 2173, 'StarGirl [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161990.mp4', 'http://timg.bdta.pro/images/66bc7704809d1a5404e39ddd733beb74.jpg'),
(31513, 2173, 'StarGirl [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161991.mp4', 'http://timg.bdta.pro/images/989f5b699dae5853c8a09cd04cfe9ff9.jpg'),
(31514, 2173, 'StarGirl [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161992.mp4', 'http://timg.bdta.pro/images/8e11a915e7f3d9516c77e6714177563d.jpg'),
(31515, 2173, 'StarGirl [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161993.mp4', 'http://timg.bdta.pro/images/e73a4e85418279266bafddb8956df3eb.jpg'),
(31516, 2173, 'StarGirl [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161994.mp4', 'http://timg.bdta.pro/images/78f1f4b60fecb21564bee600399ebd67.jpg'),
(31517, 2173, 'StarGirl [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161995.mp4', 'http://timg.bdta.pro/images/5d8e9fce2b7d545e6575d935ef99da65.jpg'),
(31518, 2173, 'StarGirl [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161996.mp4', 'http://timg.bdta.pro/images/bf1ccbd2095efcd295b15e3d97be3fc4.jpg'),
(31519, 2173, 'StarGirl [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161997.mp4', 'http://timg.bdta.pro/images/0c4b49f89f7f06d0c8a39cfbfa6ec77d.jpg'),
(31520, 2173, 'StarGirl [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161998.mp4', 'http://timg.bdta.pro/images/91e86caba60c1144a4f9ec52c9a7b1ab.jpg'),
(31521, 2173, 'StarGirl [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161999.mp4', 'http://timg.bdta.pro/images/e99d4393239be8896cdfa4b97af32968.jpg'),
(31522, 2174, 'StarGirl [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162000.mp4', 'http://timg.bdta.pro/images/2618940c78d1c7fb1837aacae97e0f9f.jpg'),
(31523, 2174, 'StarGirl [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162001.mp4', 'http://timg.bdta.pro/images/da143d3597b0c489101d07a91ee26b7b.jpg'),
(31524, 2174, 'StarGirl [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162002.mp4', 'http://timg.bdta.pro/images/17a809644845416a055198a15c9fed1d.jpg'),
(31525, 2174, 'StarGirl [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162003.mp4', 'http://timg.bdta.pro/images/e04e83b6302be00dc5a492450270bb70.jpg'),
(31526, 2174, 'StarGirl [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162004.mp4', 'http://timg.bdta.pro/images/976a814504a3520931ecbb800362a051.jpg'),
(31527, 2174, 'StarGirl [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162005.mp4', 'http://timg.bdta.pro/images/f060094bc4e810b9dd4d112acf6c6325.jpg'),
(31528, 2174, 'StarGirl [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/162006.mp4', 'http://image.tmdb.org/t/p/w1280/5E9Bl1ZvmzoESyHqy5PZIOAkTC8.jpg'),
(31529, 2174, 'StarGirl [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/162007.mp4', 'http://image.tmdb.org/t/p/w1280/93hhZ0pEPOKu2UUhV9ElMlJsvIZ.jpg'),
(31530, 2174, 'StarGirl [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/162008.mp4', 'http://image.tmdb.org/t/p/w1280/AgRaK59FBu0ACQOGUHk68JN7SOm.jpg'),
(31531, 2174, 'StarGirl [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/162009.mp4', 'http://image.tmdb.org/t/p/w1280/sOQoMKeVDnQKXpSYJrkEsTGul1k.jpg'),
(31532, 2174, 'StarGirl [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/162010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eVlmdHnbYLloN5mKhIA7OcvJE1h.jpg'),
(31533, 2174, 'StarGirl [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/162011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sawbfuca1b6zO3qxWHCM55NZCd4.jpg'),
(31534, 2174, 'StarGirl [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/162012.mp4', 'http://image.tmdb.org/t/p/w1280/1Mwv8tUi9vtszJ8H0zmnCpay6wo.jpg'),
(31535, 2175, 'Super Campeoes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113474.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31536, 2175, 'Super Campeoes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113475.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31537, 2175, 'Super Campeoes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113476.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31538, 2175, 'Super Campeoes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113477.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31539, 2175, 'Super Campeoes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113478.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31540, 2175, 'Super Campeoes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113479.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31541, 2175, 'Super Campeoes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113480.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31542, 2175, 'Super Campeoes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113481.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31543, 2175, 'Super Campeoes S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113482.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31544, 2175, 'Super Campeoes S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113483.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31545, 2175, 'Super Campeoes S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113484.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31546, 2175, 'Super Campeoes S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113485.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31547, 2175, 'Super Campeoes S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113486.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31548, 2175, 'Super Campeoes S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113487.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31549, 2175, 'Super Campeoes S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113488.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31550, 2175, 'Super Campeoes S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113489.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31551, 2175, 'Super Campeoes S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113490.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31552, 2175, 'Super Campeoes S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113491.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31553, 2175, 'Super Campeoes S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113492.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31554, 2175, 'Super Campeoes S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/113493.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31555, 2175, 'Super Campeoes S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/113494.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31556, 2175, 'Super Campeoes S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/113495.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31557, 2175, 'Super Campeoes S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/113496.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31558, 2175, 'Super Campeoes S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/113497.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31559, 2175, 'Super Campeoes S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/113498.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31560, 2175, 'Super Campeoes S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/113499.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31561, 2175, 'Super Campeoes S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/113500.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31562, 2175, 'Super Campeoes S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/113501.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31563, 2175, 'Super Campeoes S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/113502.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31564, 2175, 'Super Campeoes S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/113503.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31565, 2175, 'Super Campeoes S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/113504.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31566, 2175, 'Super Campeoes S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/113505.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31567, 2175, 'Super Campeoes S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/113506.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31568, 2175, 'Super Campeoes S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/113507.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31569, 2175, 'Super Campeoes S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/113508.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31570, 2175, 'Super Campeoes S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/113509.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31571, 2175, 'Super Campeoes S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/113510.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31572, 2175, 'Super Campeoes S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/113511.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31573, 2175, 'Super Campeoes S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/113512.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31574, 2175, 'Super Campeoes S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/113513.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31575, 2175, 'Super Campeoes S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/113514.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31576, 2175, 'Super Campeoes S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/113515.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31577, 2175, 'Super Campeoes S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/113516.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31578, 2175, 'Super Campeoes S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/113517.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31579, 2175, 'Super Campeoes S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/113518.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31580, 2175, 'Super Campeoes S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/113519.mp4', 'http://gstaticontent.com/images/utlvq1mRI77yO8JZTWTTgfoIUHc_big.jpg'),
(31581, 2176, 'Super Campeoes Road To 2002 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113422.mp4', 'http://timg.bdta.pro/images/ec1ab3ec1c805f888e5f47dc9d1ea390.jpg'),
(31582, 2176, 'Super Campeoes Road To 2002 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113423.mp4', 'http://timg.bdta.pro/images/3bb03242817a1f59747d8020551c027b.jpg'),
(31583, 2176, 'Super Campeoes Road To 2002 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113424.mp4', 'http://timg.bdta.pro/images/087c9ea2e4a9b7711a5f9968022124f9.jpg'),
(31584, 2176, 'Super Campeoes Road To 2002 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113425.mp4', 'http://timg.bdta.pro/images/326c9e71fec0eb360729bd1217c01585.jpg'),
(31585, 2176, 'Super Campeoes Road To 2002 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113426.mp4', 'http://timg.bdta.pro/images/7fc76eaa531770a8562a429a6985a5bc.jpg'),
(31586, 2176, 'Super Campeoes Road To 2002 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113427.mp4', 'http://timg.bdta.pro/images/acc95b15f1d65276a3c5f336a228f5c7.jpg'),
(31587, 2176, 'Super Campeoes Road To 2002 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113428.mp4', 'http://timg.bdta.pro/images/12f18c78a2fe09f7a5308a2d4d6be7a6.jpg'),
(31588, 2176, 'Super Campeoes Road To 2002 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113429.mp4', 'http://timg.bdta.pro/images/2aaa8131e8c0d60bc7baf0886f9a195b.jpg'),
(31589, 2176, 'Super Campeoes Road To 2002 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113430.mp4', 'http://timg.bdta.pro/images/3a0ad7de72342efff95c2ce60236d1b1.jpg'),
(31590, 2176, 'Super Campeoes Road To 2002 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113431.mp4', 'http://timg.bdta.pro/images/c57ab5cc33d9c62fc3eb99d6c5e70ca2.jpg'),
(31591, 2176, 'Super Campeoes Road To 2002 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113432.mp4', 'http://timg.bdta.pro/images/8ac8ffe874519286e1f07560f1bd0ed4.jpg'),
(31592, 2176, 'Super Campeoes Road To 2002 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113433.mp4', 'http://timg.bdta.pro/images/7066aee8ab07b7be0285c2ff3b0d4a29.jpg'),
(31593, 2176, 'Super Campeoes Road To 2002 S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113434.mp4', 'http://timg.bdta.pro/images/05cbf84e3e96c3a921d04ee7b2fd4173.jpg'),
(31594, 2176, 'Super Campeoes Road To 2002 S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/113435.mp4', 'http://timg.bdta.pro/images/6efef849c2114f090c71914ed006b04e.jpg'),
(31595, 2176, 'Super Campeoes Road To 2002 S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/113436.mp4', 'http://timg.bdta.pro/images/d3b8eccdf0d0b37d4bf8ee9d45960108.jpg'),
(31596, 2176, 'Super Campeoes Road To 2002 S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/113437.mp4', 'http://timg.bdta.pro/images/60120a32033f1f06200d6cc846fa2b80.jpg'),
(31597, 2176, 'Super Campeoes Road To 2002 S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/113438.mp4', 'http://timg.bdta.pro/images/258c3e1a3ada6a31e943cde64ba9e6fc.jpg'),
(31598, 2176, 'Super Campeoes Road To 2002 S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/113439.mp4', 'http://timg.bdta.pro/images/bc2910b769036d0813cc729b3213e4e9.jpg'),
(31599, 2176, 'Super Campeoes Road To 2002 S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/113440.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31600, 2176, 'Super Campeoes Road To 2002 S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/113441.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31601, 2176, 'Super Campeoes Road To 2002 S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/113442.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31602, 2176, 'Super Campeoes Road To 2002 S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/113443.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31603, 2176, 'Super Campeoes Road To 2002 S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/113444.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(31604, 2176, 'Super Campeoes Road To 2002 S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/113445.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31605, 2176, 'Super Campeoes Road To 2002 S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/113446.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31606, 2176, 'Super Campeoes Road To 2002 S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/113447.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31607, 2176, 'Super Campeoes Road To 2002 S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/113448.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31608, 2176, 'Super Campeoes Road To 2002 S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/113449.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31609, 2176, 'Super Campeoes Road To 2002 S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/113450.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31610, 2176, 'Super Campeoes Road To 2002 S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/113451.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31611, 2176, 'Super Campeoes Road To 2002 S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/113452.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31612, 2176, 'Super Campeoes Road To 2002 S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/113453.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31613, 2176, 'Super Campeoes Road To 2002 S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/113454.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31614, 2176, 'Super Campeoes Road To 2002 S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/113455.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31615, 2176, 'Super Campeoes Road To 2002 S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/113456.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31616, 2176, 'Super Campeoes Road To 2002 S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/113457.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31617, 2176, 'Super Campeoes Road To 2002 S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/113458.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31618, 2176, 'Super Campeoes Road To 2002 S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/113459.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31619, 2176, 'Super Campeoes Road To 2002 S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/113460.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31620, 2176, 'Super Campeoes Road To 2002 S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/113461.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31621, 2176, 'Super Campeoes Road To 2002 S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/113462.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31622, 2176, 'Super Campeoes Road To 2002 S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/113463.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31623, 2176, 'Super Campeoes Road To 2002 S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/113464.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31624, 2176, 'Super Campeoes Road To 2002 S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/113465.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31625, 2176, 'Super Campeoes Road To 2002 S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/113466.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31626, 2176, 'Super Campeoes Road To 2002 S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/113467.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31627, 2176, 'Super Campeoes Road To 2002 S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/113468.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31628, 2176, 'Super Campeoes Road To 2002 S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/113469.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31629, 2176, 'Super Campeoes Road To 2002 S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/113470.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31630, 2176, 'Super Campeoes Road To 2002 S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/113471.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31631, 2176, 'Super Campeoes Road To 2002 S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/113472.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31632, 2176, 'Super Campeoes Road To 2002 S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/113473.mp4', 'http://timg.bdta.pro/images/e35608a5baad5d0a342c6d38283ea8d5.jpg'),
(31633, 2177, 'Aquela Doença Com C. S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114416.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31634, 2177, 'Aquela Doença Com C. S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114417.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31635, 2177, 'Aquela Doença Com C. S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114418.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31636, 2177, 'Aquela Doença Com C. S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114419.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31637, 2177, 'Aquela Doença Com C. S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114420.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31638, 2177, 'Aquela Doença Com C. S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114421.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31639, 2177, 'Aquela Doença Com C. S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114422.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31640, 2177, 'Aquela Doença Com C. S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114423.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31641, 2177, 'Aquela Doença Com C. S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114424.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31642, 2177, 'Aquela Doença Com C. S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114425.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31643, 2177, 'Aquela Doença Com C. S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114426.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31644, 2177, 'Aquela Doença Com C. S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114427.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31645, 2177, 'Aquela Doença Com C. S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114428.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31646, 2178, 'Aquela Doença Com C. S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114429.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31647, 2178, 'Aquela Doença Com C. S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114430.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31648, 2178, 'Aquela Doença Com C. S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114431.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31649, 2178, 'Aquela Doença Com C. S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114432.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31650, 2178, 'Aquela Doença Com C. S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114433.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31651, 2178, 'Aquela Doença Com C. S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114434.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31652, 2178, 'Aquela Doença Com C. S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114435.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31653, 2178, 'Aquela Doença Com C. S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114436.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31654, 2178, 'Aquela Doença Com C. S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114437.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31655, 2178, 'Aquela Doença Com C. S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114438.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31656, 2178, 'Aquela Doença Com C. S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/114439.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31657, 2178, 'Aquela Doença Com C. S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/114440.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31658, 2178, 'Aquela Doença Com C. S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/114441.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31659, 2179, 'Aquela Doença Com C. S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114442.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31660, 2179, 'Aquela Doença Com C. S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114443.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31661, 2179, 'Aquela Doença Com C. S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114444.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31662, 2179, 'Aquela Doença Com C. S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114445.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31663, 2179, 'Aquela Doença Com C. S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114446.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31664, 2179, 'Aquela Doença Com C. S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114447.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31665, 2179, 'Aquela Doença Com C. S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114448.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31666, 2179, 'Aquela Doença Com C. S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114449.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31667, 2179, 'Aquela Doença Com C. S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/114450.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31668, 2179, 'Aquela Doença Com C. S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/114451.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31669, 2180, 'Aquela Doença Com C. S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/114452.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31670, 2180, 'Aquela Doença Com C. S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/114453.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31671, 2180, 'Aquela Doença Com C. S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/114454.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31672, 2180, 'Aquela Doença Com C. S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/114455.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31673, 2180, 'Aquela Doença Com C. S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/114456.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31674, 2180, 'Aquela Doença Com C. S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/114457.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31675, 2180, 'Aquela Doença Com C. S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/114458.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31676, 2180, 'Aquela Doença Com C. S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/114459.mp4', 'http://gstaticontent.com/images/dox8lFjzihZZbu1Equ7VznNifdX_big.jpg'),
(31677, 2181, 'Os Goldbergs S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216573.mp4', 'http://timg.bdta.pro/images/ec788b79658808571aee42e2bf61c7da.jpg'),
(31678, 2181, 'Os Goldbergs S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216574.mp4', 'http://timg.bdta.pro/images/db2d38df78d924ad9bfa24ef3e0e2eee.jpg'),
(31679, 2181, 'Os Goldbergs S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216575.mp4', 'http://timg.bdta.pro/images/0379230576dd446b05835830b685c7ab.jpg'),
(31680, 2181, 'Os Goldbergs S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216576.mp4', 'http://timg.bdta.pro/images/7bde036c6e457334e8d31fafd5eb79a1.jpg'),
(31681, 2181, 'Os Goldbergs S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216577.mp4', 'http://timg.bdta.pro/images/ef31d26905d423fa00a6a4cdd23d0fc9.jpg'),
(31682, 2181, 'Os Goldbergs S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216578.mp4', 'http://timg.bdta.pro/images/864bd68141909521efc8ec1a50546b07.jpg'),
(31683, 2181, 'Os Goldbergs S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216579.mp4', 'http://timg.bdta.pro/images/e08c289b647d23b70cea7e9f2a8a281f.jpg'),
(31684, 2181, 'Os Goldbergs S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216580.mp4', 'http://timg.bdta.pro/images/7c9e9698aea36a18c2f90e21722e4ee8.jpg'),
(31685, 2181, 'Os Goldbergs S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216581.mp4', 'http://timg.bdta.pro/images/94c0143af1069a0b8432bfa8fc469968.jpg'),
(31686, 2181, 'Os Goldbergs S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216582.mp4', 'http://timg.bdta.pro/images/add7a84f7edc588f855bfa53ce4da8db.jpg'),
(31687, 2181, 'Os Goldbergs S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216583.mp4', 'http://timg.bdta.pro/images/ee8c21409c94ec2eabe3ba95b967bd99.jpg'),
(31688, 2181, 'Os Goldbergs S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216584.mp4', 'http://timg.bdta.pro/images/104753b08192cfe86df69eac835a77cb.jpg'),
(31689, 2181, 'Os Goldbergs S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216585.mp4', 'http://timg.bdta.pro/images/7ac7095aa700d67a57120c55fe575dad.jpg'),
(31690, 2181, 'Os Goldbergs S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216586.mp4', 'http://timg.bdta.pro/images/7292e3826ca20e220627020a3e0d66e3.jpg'),
(31691, 2181, 'Os Goldbergs S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/216587.mp4', 'http://timg.bdta.pro/images/a1ec87473ee74573528b256446be71d3.jpg'),
(31692, 2181, 'Os Goldbergs S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/216588.mp4', 'http://timg.bdta.pro/images/a0c8a807fc04e28d61bc1e33450287a5.jpg'),
(31693, 2181, 'Os Goldbergs S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/216589.mp4', 'http://timg.bdta.pro/images/9761a8432d991a660945da19358a3c04.jpg'),
(31694, 2181, 'Os Goldbergs S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/216590.mp4', 'http://timg.bdta.pro/images/4f46e004959c186fe9cb737949deda4d.jpg'),
(31695, 2181, 'Os Goldbergs S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/216591.mp4', 'http://timg.bdta.pro/images/c26fb766d0d961f53493040706004c0f.jpg'),
(31696, 2181, 'Os Goldbergs S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/216592.mp4', 'http://timg.bdta.pro/images/4f4ab10d66debc42d796486954df2128.jpg'),
(31697, 2181, 'Os Goldbergs S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/216593.mp4', 'http://timg.bdta.pro/images/b382c331b4e3c9ac6aa6dfdc599f7b9d.jpg'),
(31698, 2181, 'Os Goldbergs S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/216594.mp4', 'http://timg.bdta.pro/images/d7c48400e0efac28a73ac55c96496c35.jpg'),
(31699, 2181, 'Os Goldbergs S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/216595.mp4', 'http://timg.bdta.pro/images/0b10c3aff1cddf275a0b2d83ff5476a5.jpg'),
(31700, 2182, 'Os Goldbergs S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216596.mp4', 'http://timg.bdta.pro/images/95eb8392eb3775872c5ea935ae71753f.jpg'),
(31701, 2182, 'Os Goldbergs S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216597.mp4', 'http://timg.bdta.pro/images/74b37b68629fc8aeb1aec7ef3dd7334e.jpg'),
(31702, 2182, 'Os Goldbergs S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216598.mp4', 'http://timg.bdta.pro/images/323314d777c716f09884b4c315e51dd7.jpg'),
(31703, 2182, 'Os Goldbergs S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216599.mp4', 'http://timg.bdta.pro/images/3923e77dd3a92da8b91ac0af18e026a5.jpg'),
(31704, 2182, 'Os Goldbergs S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216600.mp4', 'http://timg.bdta.pro/images/ae63af649eafc6e30bd7011530d73457.jpg'),
(31705, 2182, 'Os Goldbergs S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216601.mp4', 'http://timg.bdta.pro/images/4b1a7edaf79a68a5933f183a614c0eda.jpg'),
(31706, 2182, 'Os Goldbergs S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216602.mp4', 'http://timg.bdta.pro/images/1208827ba75fc0dc5811f9876f0290aa.jpg'),
(31707, 2182, 'Os Goldbergs S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216603.mp4', 'http://timg.bdta.pro/images/9b6f9996d3b983347ba97dbfb463ed0a.jpg'),
(31708, 2182, 'Os Goldbergs S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216604.mp4', 'http://timg.bdta.pro/images/82b8e8256ca6b9dadd80ce5f264d7183.jpg'),
(31709, 2182, 'Os Goldbergs S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216605.mp4', 'http://timg.bdta.pro/images/b24bdc360f9c26535ce72e0ee9877dd5.jpg'),
(31710, 2182, 'Os Goldbergs S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216606.mp4', 'http://timg.bdta.pro/images/d9b92556832c069658dfdc7bbcc84f21.jpg'),
(31711, 2182, 'Os Goldbergs S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216607.mp4', 'http://timg.bdta.pro/images/4f675ced74d0f605b9eefc9e1bd66f4e.jpg'),
(31712, 2182, 'Os Goldbergs S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216608.mp4', 'http://timg.bdta.pro/images/1608d2f489a9f49a8ba335c872efeb4b.jpg'),
(31713, 2182, 'Os Goldbergs S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216609.mp4', 'http://timg.bdta.pro/images/db3e4b87c05c76d7fe71386e4d77b67e.jpg'),
(31714, 2182, 'Os Goldbergs S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/216610.mp4', 'http://timg.bdta.pro/images/4a96e61675349066400628a25ef553fb.jpg'),
(31715, 2182, 'Os Goldbergs S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/216611.mp4', 'http://timg.bdta.pro/images/c15309c6f0417e5c66540d31de9ca7e5.jpg'),
(31716, 2182, 'Os Goldbergs S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/216612.mp4', 'http://timg.bdta.pro/images/5d12342e220395076604cdb7732d053f.jpg'),
(31717, 2182, 'Os Goldbergs S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/216613.mp4', 'http://timg.bdta.pro/images/9a6d8e211271f9902e1515dd587a0a54.jpg'),
(31718, 2182, 'Os Goldbergs S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/216614.mp4', 'http://timg.bdta.pro/images/93541addeaca4630cd50c07882f40a2f.jpg'),
(31719, 2182, 'Os Goldbergs S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/216615.mp4', 'http://timg.bdta.pro/images/abac7fe57a5ec0ae06234cc22aca36de.jpg'),
(31720, 2182, 'Os Goldbergs S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/216616.mp4', 'http://timg.bdta.pro/images/284c8c5f8816b3d99a4ee9e935a01899.jpg'),
(31721, 2182, 'Os Goldbergs S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/216617.mp4', 'http://timg.bdta.pro/images/0adc2e276d7f7545ec5001a735c0922f.jpg'),
(31722, 2182, 'Os Goldbergs S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/216618.mp4', 'http://timg.bdta.pro/images/f2d41ef65a7f6aa9c8d103d9d4f41e94.jpg'),
(31723, 2183, 'Os Goldbergs S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216619.mp4', 'http://timg.bdta.pro/images/d2b19040f1baf67d798dded8e30bea64.jpg'),
(31724, 2183, 'Os Goldbergs S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216620.mp4', 'http://timg.bdta.pro/images/b0237b3a0fa9e42aaa6d412d20dfd0b4.jpg'),
(31725, 2183, 'Os Goldbergs S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216621.mp4', 'http://timg.bdta.pro/images/c69bc2e1cba329facd81a62475b9b554.jpg'),
(31726, 2183, 'Os Goldbergs S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216622.mp4', 'http://timg.bdta.pro/images/f44d726bd26bd7879191bfb70f821bcd.jpg'),
(31727, 2183, 'Os Goldbergs S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216623.mp4', 'http://timg.bdta.pro/images/bf281698446fd2890277ec2ca3c12d28.jpg'),
(31728, 2183, 'Os Goldbergs S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216624.mp4', 'http://timg.bdta.pro/images/477bbfbe95e7528bb2c36e5763dded17.jpg'),
(31729, 2183, 'Os Goldbergs S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216625.mp4', 'http://timg.bdta.pro/images/9874ef86107954ce3f1cf34b3f690598.jpg'),
(31730, 2183, 'Os Goldbergs S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216626.mp4', 'http://timg.bdta.pro/images/2d2a10674015e79948d72afb14396976.jpg'),
(31731, 2183, 'Os Goldbergs S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216627.mp4', 'http://timg.bdta.pro/images/6d6446e403c5dab9339681cb007a6699.jpg'),
(31732, 2183, 'Os Goldbergs S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216628.mp4', 'http://timg.bdta.pro/images/1d7a45e549f371807ac312c1e6101645.jpg'),
(31733, 2183, 'Os Goldbergs S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216629.mp4', 'http://timg.bdta.pro/images/1741dec301bdfb0922c7627dff76734f.jpg'),
(31734, 2183, 'Os Goldbergs S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216630.mp4', 'http://timg.bdta.pro/images/05dddf1ddac6e41a9ea4bf1cd8aa4980.jpg'),
(31735, 2183, 'Os Goldbergs S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216631.mp4', 'http://timg.bdta.pro/images/9dd22766436381f4c7b79b60bf1f1e14.jpg'),
(31736, 2183, 'Os Goldbergs S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216632.mp4', 'http://timg.bdta.pro/images/cb34ad2254653af86a43a15e33b77f31.jpg'),
(31737, 2183, 'Os Goldbergs S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/216633.mp4', 'http://timg.bdta.pro/images/e6071c96835c56632a3dd45b5dc8ff88.jpg'),
(31738, 2183, 'Os Goldbergs S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/216634.mp4', 'http://timg.bdta.pro/images/da2d2d6ee2042f574e8eec8b847203ab.jpg'),
(31739, 2183, 'Os Goldbergs S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/216635.mp4', 'http://timg.bdta.pro/images/40596d756cda1729541937c49e1c398a.jpg'),
(31740, 2183, 'Os Goldbergs S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/216636.mp4', 'http://timg.bdta.pro/images/791ab1c1ce4be39c468fb8f1af0a1483.jpg'),
(31741, 2183, 'Os Goldbergs S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/216637.mp4', 'http://timg.bdta.pro/images/5b23efa98b2b317787d4bba7c9b95bf9.jpg'),
(31742, 2183, 'Os Goldbergs S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/216638.mp4', 'http://timg.bdta.pro/images/ecb6682ef00c7d992073755887c4d2b6.jpg'),
(31743, 2183, 'Os Goldbergs S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/216639.mp4', 'http://timg.bdta.pro/images/ecb6682ef00c7d992073755887c4d2b6.jpg'),
(31744, 2183, 'Os Goldbergs S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/216640.mp4', 'http://timg.bdta.pro/images/ecb6682ef00c7d992073755887c4d2b6.jpg'),
(31745, 2183, 'Os Goldbergs S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/216641.mp4', 'http://timg.bdta.pro/images/ecb6682ef00c7d992073755887c4d2b6.jpg'),
(31746, 2183, 'Os Goldbergs S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/216642.mp4', 'http://timg.bdta.pro/images/ecb6682ef00c7d992073755887c4d2b6.jpg'),
(31747, 2183, 'Os Goldbergs S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/216643.mp4', 'http://gstaticontent.com/images/7QhULsJ0eXq3fhpGYuGifbfWy1I_big.jpg'),
(31748, 2184, 'Os Goldbergs S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216644.mp4', 'http://timg.bdta.pro/images/ef1c75ec2e9b6f8b0ea15349f6b4e48c.jpg'),
(31749, 2184, 'Os Goldbergs S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216645.mp4', 'http://timg.bdta.pro/images/ed773de05f93328359747cf6374e9466.jpg'),
(31750, 2184, 'Os Goldbergs S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216646.mp4', 'http://timg.bdta.pro/images/b4a54e893cce08c1e7a37640e9d5b980.jpg'),
(31751, 2184, 'Os Goldbergs S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216647.mp4', 'http://timg.bdta.pro/images/adc0af72887ad395bcce697b44595ee7.jpg'),
(31752, 2184, 'Os Goldbergs S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216648.mp4', 'http://timg.bdta.pro/images/ba2c067d9544a79822237b714b1a3865.jpg'),
(31753, 2184, 'Os Goldbergs S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216649.mp4', 'http://timg.bdta.pro/images/3bf441221aa3d6663ffc5d424d3d3bed.jpg'),
(31754, 2184, 'Os Goldbergs S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216650.mp4', 'http://timg.bdta.pro/images/fa329d6b8e67e2410678bdc522f7c38b.jpg'),
(31755, 2184, 'Os Goldbergs S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216651.mp4', 'http://timg.bdta.pro/images/95b97ed42722594683391873fa734b2d.jpg'),
(31756, 2184, 'Os Goldbergs S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216652.mp4', 'http://timg.bdta.pro/images/74ed1ec9edcef86f61fc2c2a2fe6aeca.jpg'),
(31757, 2184, 'Os Goldbergs S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216653.mp4', 'http://timg.bdta.pro/images/d9822062dd6d5b4494427b0ba177685e.jpg'),
(31758, 2184, 'Os Goldbergs S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216654.mp4', 'http://timg.bdta.pro/images/c1b6c863ef220fee89bb97e739c4449e.jpg'),
(31759, 2184, 'Os Goldbergs S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216655.mp4', 'http://timg.bdta.pro/images/af40b0bccbd8894601314b2aafb0d381.jpg'),
(31760, 2184, 'Os Goldbergs S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216656.mp4', 'http://timg.bdta.pro/images/80578d6ab67e530f0568bdb932ca23b9.jpg'),
(31761, 2184, 'Os Goldbergs S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216657.mp4', 'http://timg.bdta.pro/images/1f06fa7eb28e439125f9b204cfc210c4.jpg'),
(31762, 2184, 'Os Goldbergs S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/216658.mp4', 'http://timg.bdta.pro/images/38a9b63e58c898456aa94350c1feff13.jpg'),
(31763, 2184, 'Os Goldbergs S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/216659.mp4', 'http://timg.bdta.pro/images/c09961ec092b9859ff2bcc2b7feb3632.jpg'),
(31764, 2184, 'Os Goldbergs S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/216660.mp4', 'http://timg.bdta.pro/images/27845485160b315fdd303738256d753e.jpg'),
(31765, 2184, 'Os Goldbergs S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/216661.mp4', 'http://timg.bdta.pro/images/9167b8783a5a812ceae641537e5c0ff8.jpg'),
(31766, 2184, 'Os Goldbergs S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/216662.mp4', 'http://timg.bdta.pro/images/7f6b59294b05b05c8f863c971d4ec149.jpg'),
(31767, 2184, 'Os Goldbergs S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/216663.mp4', 'http://timg.bdta.pro/images/92b5422f4eb0f42676c698ad6447b65e.jpg'),
(31768, 2184, 'Os Goldbergs S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/216664.mp4', 'http://timg.bdta.pro/images/5cdb2c6bb02af0831720622d0f852dc5.jpg'),
(31769, 2184, 'Os Goldbergs S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/216665.mp4', 'http://timg.bdta.pro/images/c4928a6723cb03d9f876729bc7b06d19.jpg'),
(31770, 2184, 'Os Goldbergs S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/216666.mp4', 'http://timg.bdta.pro/images/d9ad6f6ce047141ca8e8b94c5a8a64e3.jpg'),
(31771, 2184, 'Os Goldbergs S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/216667.mp4', 'http://timg.bdta.pro/images/d3eac71df23cd0acd41bfd2a0286b691.jpg'),
(31772, 2185, 'Os Goldbergs S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216668.mp4', 'http://timg.bdta.pro/images/5e633cbab2c004223f556ce441279198.jpg'),
(31773, 2185, 'Os Goldbergs S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216669.mp4', 'http://timg.bdta.pro/images/015ba9ea2c40fedc4497a6f9eeb59638.jpg'),
(31774, 2185, 'Os Goldbergs S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216670.mp4', 'http://timg.bdta.pro/images/cbab511dd5b67ae966036e78c51296a9.jpg'),
(31775, 2185, 'Os Goldbergs S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216671.mp4', 'http://timg.bdta.pro/images/56ec127eb670eba94c058060a88dc1f1.jpg'),
(31776, 2185, 'Os Goldbergs S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216672.mp4', 'http://timg.bdta.pro/images/94bf7f82f45cad29cdfb3c35e2b880e7.jpg'),
(31777, 2185, 'Os Goldbergs S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216673.mp4', 'http://timg.bdta.pro/images/03766a58bc82feec31cb9c42293c73d0.jpg'),
(31778, 2185, 'Os Goldbergs S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216674.mp4', 'http://timg.bdta.pro/images/68ec9251d685d65018d2def811d35483.jpg'),
(31779, 2185, 'Os Goldbergs S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216675.mp4', 'http://timg.bdta.pro/images/7a8fe59299f3d2f74f20825c2d1ff015.jpg'),
(31780, 2185, 'Os Goldbergs S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216676.mp4', 'http://timg.bdta.pro/images/633bdc78a11e0a7256946f588a1ef8c5.jpg'),
(31781, 2185, 'Os Goldbergs S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216677.mp4', 'http://timg.bdta.pro/images/038b2f9760d84fc4e72c4d9723e6ecdd.jpg'),
(31782, 2185, 'Os Goldbergs S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216678.mp4', 'http://timg.bdta.pro/images/63e77253e263f5cd042780fafa6e853b.jpg'),
(31783, 2185, 'Os Goldbergs S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216679.mp4', 'http://timg.bdta.pro/images/70a4c7ad19c4a1d61bfbd09db2c6342b.jpg'),
(31784, 2185, 'Os Goldbergs S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216680.mp4', 'http://timg.bdta.pro/images/af74ba6963619cd2aa8ba84d23fae09e.jpg'),
(31785, 2185, 'Os Goldbergs S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216681.mp4', 'http://timg.bdta.pro/images/263f9bffe41c95925e296e71a0dc3172.jpg'),
(31786, 2185, 'Os Goldbergs S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/216682.mp4', 'http://timg.bdta.pro/images/bb6c31002ef053631808a8f76d1e7a2f.jpg'),
(31787, 2185, 'Os Goldbergs S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/216683.mp4', 'http://timg.bdta.pro/images/c5b4bdb0efb867c394f8725b0ae3ed65.jpg'),
(31788, 2185, 'Os Goldbergs S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/216684.mp4', 'http://timg.bdta.pro/images/3d05b8f04438055bb6be1480b56661cd.jpg'),
(31789, 2185, 'Os Goldbergs S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/216685.mp4', 'http://timg.bdta.pro/images/83e7cb23f04592b9dcd244960392c6aa.jpg'),
(31790, 2185, 'Os Goldbergs S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/216686.mp4', 'http://timg.bdta.pro/images/ebf4c3f76b7b78dc55bf5de331591dbc.jpg'),
(31791, 2185, 'Os Goldbergs S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/216687.mp4', 'http://timg.bdta.pro/images/4f9b18795f67a49e9296e7b4532497f9.jpg'),
(31792, 2185, 'Os Goldbergs S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/216688.mp4', 'http://timg.bdta.pro/images/a96c45ac38e3beed7f5660fe73d27ca1.jpg'),
(31793, 2185, 'Os Goldbergs S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/216689.mp4', 'http://timg.bdta.pro/images/c4b174455cfd601736bd381bbdd73555.jpg'),
(31794, 2186, 'Os Goldbergs S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8kn3bpAeTfCgsl65Xmdu7pn2WCY.jpg'),
(31795, 2186, 'Os Goldbergs S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ycYgcYyo8Wlj7ZUctqdFyBMWHzT.jpg'),
(31796, 2186, 'Os Goldbergs S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qgbVeaG0fO3RKV1RGXJnA4VxV04.jpg'),
(31797, 2186, 'Os Goldbergs S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4fqKGl7duphLdGhWfLYX0O0U6X1.jpg'),
(31798, 2186, 'Os Goldbergs S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ai47kvIgwJVqMivWopXpzsu1TaS.jpg'),
(31799, 2186, 'Os Goldbergs S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uj9m4zjySrFWQawMVbpoCTJMSd9.jpg'),
(31800, 2186, 'Os Goldbergs S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hP1nBZJrtuFsl9BiUdHQvIQNvzL.jpg'),
(31801, 2186, 'Os Goldbergs S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xuNZJL41PkPTelUygNQeMX1jIVV.jpg'),
(31802, 2186, 'Os Goldbergs S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qzBLoV4nsbUVkjJ55sb8ZvBPrOU.jpg'),
(31803, 2186, 'Os Goldbergs S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cvNJ6jIVimWIVqtOlqpy29w7Brv.jpg'),
(31804, 2186, 'Os Goldbergs S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/OAZEmnzoNregbEibtuDmAqgKrM.jpg'),
(31805, 2186, 'Os Goldbergs S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n9PH3Sx3JR5CyH7zLFPjNk5twH9.jpg'),
(31806, 2186, 'Os Goldbergs S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8SJ3cj9cMfnTLx0lsqHueYlCLTL.jpg'),
(31807, 2186, 'Os Goldbergs S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qwCM2ItfCEzHSqwZT1X8OajgqqH.jpg'),
(31808, 2186, 'Os Goldbergs S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/216704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bJCBx4SzZA6qejLYTx4HMFbc5QE.jpg'),
(31809, 2186, 'Os Goldbergs S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/216705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3hnu0nURLmePglmDtll9tyTCrW.jpg'),
(31810, 2186, 'Os Goldbergs S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/216706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9RgM4uv1dPHSCqSbUobFMDnbjKk.jpg'),
(31811, 2186, 'Os Goldbergs S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/216707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pEuUNiUtN6T9bmUdYYJjOkFVMDN.jpg'),
(31812, 2186, 'Os Goldbergs S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/216708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oj21WknI1Q5r4EIsZ3Lxkr03Yyb.jpg'),
(31813, 2186, 'Os Goldbergs S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/216709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3NrJrGwbqygYGpoEFnaCZdAlDdJ.jpg'),
(31814, 2186, 'Os Goldbergs S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/216710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s7JZPBRLSDfgEkTUftiLhph4odK.jpg'),
(31815, 2186, 'Os Goldbergs S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/216711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tXVlePesZ3eBs0Tj1GzJWfylgsS.jpg'),
(31816, 2186, 'Os Goldbergs S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/216712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oOTxE44VVlE5puAv651vyY2QXT1.jpg'),
(31817, 2187, 'Os Goldbergs S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7BZMPt4xYLfIbMZ7ZeJ4pTM1bJY.jpg'),
(31818, 2187, 'Os Goldbergs S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3utSLVZ9TUtbL3gbTxsPtWQcDx4.jpg'),
(31819, 2187, 'Os Goldbergs S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xU5Bccu3JUGOdnysjYkVA5CF3h3.jpg'),
(31820, 2187, 'Os Goldbergs S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zoZ4EopHZ9ojzLwiP5CGuPiejuw.jpg'),
(31821, 2187, 'Os Goldbergs S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bWRqHqnajTHnLnVorwXCcGAr8HK.jpg'),
(31822, 2187, 'Os Goldbergs S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f34IvpVScOaO7PJ3yfKs3zstPz4.jpg'),
(31823, 2187, 'Os Goldbergs S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8s9BgAKeeT1L5xjimkkhxUqE7N8.jpg'),
(31824, 2187, 'Os Goldbergs S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qsiSAlK5cWoCgBcNpOi9h7TkChR.jpg'),
(31825, 2187, 'Os Goldbergs S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z37kBKYGMNNqMUcAkl8Qz59yWbq.jpg'),
(31826, 2187, 'Os Goldbergs S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9HlVoD3n1VVEh1RgcRhRslsJI0I.jpg'),
(31827, 2187, 'Os Goldbergs S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oRoouakkQTvaS9V8HrBPXwRBc1x.jpg'),
(31828, 2187, 'Os Goldbergs S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/56xweie3AlfBD0RMNm804z9OHK9.jpg'),
(31829, 2187, 'Os Goldbergs S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cpECeuNdZV0wmRI3lGNOrzCe9J7.jpg'),
(31830, 2187, 'Os Goldbergs S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hI7wsNJ9Gx5wuXzMD3nnWRcHOEc.jpg'),
(31831, 2187, 'Os Goldbergs S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/216727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/czcXeND5NEqEcT2tXdrDmSfGAFS.jpg'),
(31832, 2187, 'Os Goldbergs S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/216728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cC6D9Gfo1oLS5woXFJ8nMJuZ36A.jpg'),
(31833, 2187, 'Os Goldbergs S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/216729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bXC4Zbe1RYJhKwyg9m4QDry7FHv.jpg'),
(31834, 2187, 'Os Goldbergs S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/216730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gbtjSuzr2xMVwifyqmcnXDUIO0G.jpg'),
(31835, 2187, 'Os Goldbergs S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/216731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sj97PWC6ivJu3WVp1BvzLkMIi7B.jpg'),
(31836, 2187, 'Os Goldbergs S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/216732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cTI6G4sX94gbW5ZIsp89Nk6uyn6.jpg'),
(31837, 2187, 'Os Goldbergs S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/216733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yEy3rkvg2IzZYajdLbGhB0LPDwt.jpg'),
(31838, 2187, 'Os Goldbergs S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/216734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5syUjeXyo9uQc53odBTgIuqz7Ug.jpg'),
(31839, 2187, 'Os Goldbergs S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/216735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hlbkRWYRwtD2c5iCCJ0L0xwgVi5.jpg'),
(31840, 2188, 'Os Goldbergs S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xn6KDcLaa0rX2qmRfkCKhY4oSNU.jpg'),
(31841, 2188, 'Os Goldbergs S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mjrl9aCu2UrmqGR8CcpglN3tFB2.jpg'),
(31842, 2188, 'Os Goldbergs S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/77cKRxW8rfgw32ysaKs63kuYReI.jpg'),
(31843, 2188, 'Os Goldbergs S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ljGNvqQAN2HMzkhk8RzEYD3WSHa.jpg'),
(31844, 2188, 'Os Goldbergs S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/moDnkq5LV5UP1SReZEArNH2c9Eq.jpg'),
(31845, 2188, 'Os Goldbergs S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cT5VtovdqGqZqUT1mCPEg1986BP.jpg'),
(31846, 2188, 'Os Goldbergs S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3KsdPutqoQwoc4VvjDVND73e4ro.jpg'),
(31847, 2188, 'Os Goldbergs S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u0SLUdkOj24bS9bhOMbnWEKAERS.jpg'),
(31848, 2188, 'Os Goldbergs S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ZdLHwdlB97BZvSmUCS5Kz0Nxg0.jpg'),
(31849, 2188, 'Os Goldbergs S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bX11PtNOeb6p9CtrBuMvNfc8dXk.jpg'),
(31850, 2188, 'Os Goldbergs S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/klOFG5Cv6sQi7lLbvR3DsUM1CT1.jpg'),
(31851, 2188, 'Os Goldbergs S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/exsLBJoZYj5GgAkZ8qdJUbakjTq.jpg'),
(31852, 2188, 'Os Goldbergs S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kCFn1Ag7P02a4NElxckTynXOEqu.jpg'),
(31853, 2188, 'Os Goldbergs S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cjN9PI95LqwdlNMkt4syMcbYNza.jpg'),
(31854, 2188, 'Os Goldbergs S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/216750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aVdjXsD33Y2pN1jzp73GtUItQAs.jpg'),
(31855, 2188, 'Os Goldbergs S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/216751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dAY6dvaS5c6N92jVL72MKI4XzFs.jpg'),
(31856, 2188, 'Os Goldbergs S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/216752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7YiK3BQHvLZ0dAi4GCZfCFm9grE.jpg'),
(31857, 2188, 'Os Goldbergs S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/216753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6j3LL9NwDj2etVq1cfSsCNfkGyp.jpg'),
(31858, 2188, 'Os Goldbergs S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/216754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jJjXSmJiaVkgv1rbxvwfPixxcD9.jpg'),
(31859, 2188, 'Os Goldbergs S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/216755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7EhM3GdrjipHnt7yehnYlq6egPv.jpg'),
(31860, 2188, 'Os Goldbergs S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/216756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lV8qxk4ZcBDvIYaxKb8ZXW152CA.jpg'),
(31861, 2188, 'Os Goldbergs S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/216757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKdzNX2KVeUKkBZ9SQjFPcwDGCR.jpg'),
(31862, 2189, 'The L Word: Generation Q S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113414.mp4', 'http://timg.bdta.pro/images/3d147b6691a7945a7b1e06de4ed55c5b.jpg'),
(31863, 2189, 'The L Word: Generation Q S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113415.mp4', 'http://timg.bdta.pro/images/223a386941ee4bedec17cf539fce6f4f.jpg'),
(31864, 2189, 'The L Word: Generation Q S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113416.mp4', 'http://timg.bdta.pro/images/dbfbed7e41ce1da752f152cac2936282.jpg'),
(31865, 2189, 'The L Word: Generation Q S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113417.mp4', 'http://timg.bdta.pro/images/c0e00fd612f64b7105a4b273549be52d.jpg'),
(31866, 2189, 'The L Word: Generation Q S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113418.mp4', 'http://timg.bdta.pro/images/6d7a4e6c787b8ab1027801f5c53c0a3f.jpg'),
(31867, 2189, 'The L Word: Generation Q S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113419.mp4', 'http://timg.bdta.pro/images/0f594039dc57e244149173ee3bc6f5e8.jpg'),
(31868, 2189, 'The L Word: Generation Q S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113420.mp4', 'http://timg.bdta.pro/images/9a2fc0172111230684b73bdece84033e.jpg'),
(31869, 2189, 'The L Word: Generation Q S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113421.mp4', 'http://timg.bdta.pro/images/6454e7cb7276776ce2bef532143d5685.jpg'),
(31870, 2190, 'The Luminaries [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113408.mp4', 'http://timg.bdta.pro/images/ec3c95b4a039cc739b308cf6277ddf6a.jpg'),
(31871, 2190, 'The Luminaries [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113409.mp4', 'http://timg.bdta.pro/images/9cc046ca2ea9213e0fa28193f018221f.jpg'),
(31872, 2190, 'The Luminaries [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113410.mp4', 'http://timg.bdta.pro/images/62b3d6c9b1d581197247b81bc56d79d2.jpg'),
(31873, 2190, 'The Luminaries [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113411.mp4', 'http://timg.bdta.pro/images/522433310b322e004762707d636e26b4.jpg'),
(31874, 2190, 'The Luminaries [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113412.mp4', 'http://timg.bdta.pro/images/2d8f04f0bcc8cce3e06aaadc1bbfc622.jpg'),
(31875, 2190, 'The Luminaries [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113413.mp4', 'http://timg.bdta.pro/images/b89b04d51ed384fb0a2babf23bc0fe08.jpg'),
(31876, 2191, 'The Morning Show S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239444.mp4', 'http://timg.bdta.pro/images/e760bd8a3f981694926c844a6c311047.jpg'),
(31877, 2191, 'The Morning Show S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239445.mp4', 'http://timg.bdta.pro/images/a8a0c5624a994466a93bf17e7801b36a.jpg'),
(31878, 2191, 'The Morning Show S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239446.mp4', 'http://timg.bdta.pro/images/0a3ca875720a048073b7bd2216bb26b0.jpg'),
(31879, 2191, 'The Morning Show S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239447.mp4', 'http://timg.bdta.pro/images/efb81b58c6907b2413a9eafada5b6dba.jpg'),
(31880, 2191, 'The Morning Show S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239448.mp4', 'http://timg.bdta.pro/images/02e459dfbb24484b39c072dfd189c438.jpg'),
(31881, 2191, 'The Morning Show S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239449.mp4', 'http://timg.bdta.pro/images/5eaffc73f379a584bcdc4a2795e2dd9e.jpg'),
(31882, 2191, 'The Morning Show S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239450.mp4', 'http://timg.bdta.pro/images/9946a852e628b6f3e654e303a6867cab.jpg'),
(31883, 2191, 'The Morning Show S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239451.mp4', 'http://timg.bdta.pro/images/9175bcd19d61181a02bd3390bf05892b.jpg'),
(31884, 2191, 'The Morning Show S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239452.mp4', 'http://timg.bdta.pro/images/414079451fc9066f69417ab42a9915dc.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(31885, 2191, 'The Morning Show S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239453.mp4', 'http://timg.bdta.pro/images/9c9d4b6cba3222c215f6611b78c6b5ce.jpg'),
(31886, 2192, 'The Morning Show S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9K4Al9Si4O0oeMb533OLtpmhxd3.jpg'),
(31887, 2192, 'The Morning Show S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9vlh4yWz6G7PJ7ZfPsLEpEwqQMr.jpg'),
(31888, 2192, 'The Morning Show S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zSPNYNaa2hpYeeZZSHVUdjpVLVu.jpg'),
(31889, 2192, 'The Morning Show S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/opiT8Qu9f2eQUyo8nE8Bl9RT7vg.jpg'),
(31890, 2192, 'The Morning Show S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ypnMWwkU1GSSqVw2nZCyMUntUIN.jpg'),
(31891, 2192, 'The Morning Show S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5WesHVha6WvJEfHdinMYOFJQ3Tk.jpg'),
(31892, 2192, 'The Morning Show S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lNa2gEkb4gSJxhc8Lf76Wby0qhs.jpg'),
(31893, 2192, 'The Morning Show S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sSm7oNOc2xo2K2WI2a6qIxmyt0L.jpg'),
(31894, 2192, 'The Morning Show S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p8QO6MagM2PVzUB6AZRRJZbhq00.jpg'),
(31895, 2192, 'The Morning Show S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7oArsNe9z2IiJLREsvPuRQK3aDG.jpg'),
(31896, 2193, 'The Morning Show S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jKjbVTNKXrC2yFdy1xQxpPOiXjI.jpg'),
(31897, 2193, 'The Morning Show S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jKjbVTNKXrC2yFdy1xQxpPOiXjI.jpg'),
(31898, 2193, 'The Morning Show S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jKjbVTNKXrC2yFdy1xQxpPOiXjI.jpg'),
(31899, 2193, 'The Morning Show S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jKjbVTNKXrC2yFdy1xQxpPOiXjI.jpg'),
(31900, 2193, 'The Morning Show S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jKjbVTNKXrC2yFdy1xQxpPOiXjI.jpg'),
(31901, 2193, 'The Morning Show S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jKjbVTNKXrC2yFdy1xQxpPOiXjI.jpg'),
(31902, 2193, 'The Morning Show S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jKjbVTNKXrC2yFdy1xQxpPOiXjI.jpg'),
(31903, 2193, 'The Morning Show S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jKjbVTNKXrC2yFdy1xQxpPOiXjI.jpg'),
(31904, 2193, 'The Morning Show S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jKjbVTNKXrC2yFdy1xQxpPOiXjI.jpg'),
(31905, 2193, 'The Morning Show S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jKjbVTNKXrC2yFdy1xQxpPOiXjI.jpg'),
(31906, 2194, 'The Morning Show S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/885305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jKjbVTNKXrC2yFdy1xQxpPOiXjI.jpg'),
(31907, 2194, 'The Morning Show S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/886056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jKjbVTNKXrC2yFdy1xQxpPOiXjI.jpg'),
(31908, 2194, 'The Morning Show S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/887550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jKjbVTNKXrC2yFdy1xQxpPOiXjI.jpg'),
(31909, 2194, 'The Morning Show S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/888136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jKjbVTNKXrC2yFdy1xQxpPOiXjI.jpg'),
(31910, 2194, 'The Morning Show S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/889603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jKjbVTNKXrC2yFdy1xQxpPOiXjI.jpg'),
(31911, 2194, 'The Morning Show S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/890646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jKjbVTNKXrC2yFdy1xQxpPOiXjI.jpg'),
(31912, 2194, 'The Morning Show S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/890647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jKjbVTNKXrC2yFdy1xQxpPOiXjI.jpg'),
(31913, 2194, 'The Morning Show S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/891825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jKjbVTNKXrC2yFdy1xQxpPOiXjI.jpg'),
(31914, 2194, 'The Morning Show S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/892413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jKjbVTNKXrC2yFdy1xQxpPOiXjI.jpg'),
(31915, 2194, 'The Morning Show S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/893060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jKjbVTNKXrC2yFdy1xQxpPOiXjI.jpg'),
(31916, 2195, 'The Politician S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113400.mp4', 'http://timg.bdta.pro/images/e25d2d918957acbb0544dd5541a6cb93.jpg'),
(31917, 2195, 'The Politician S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113401.mp4', 'http://timg.bdta.pro/images/779b0c3b90232424bb62765e0faf282b.jpg'),
(31918, 2195, 'The Politician S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113402.mp4', 'http://timg.bdta.pro/images/2356045de27eb0f502d831669dba7cfe.jpg'),
(31919, 2195, 'The Politician S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113403.mp4', 'http://timg.bdta.pro/images/330c141934996b4564e8bd7ae50423b7.jpg'),
(31920, 2195, 'The Politician S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113404.mp4', 'http://timg.bdta.pro/images/d4c758ab7997379ccae9a7788c3eaafe.jpg'),
(31921, 2195, 'The Politician S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113405.mp4', 'http://timg.bdta.pro/images/46cd031da81180b457f6ff0089a5bb93.jpg'),
(31922, 2195, 'The Politician S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113406.mp4', 'http://timg.bdta.pro/images/e628ca8d52df9620ab2619a2ca586e0b.jpg'),
(31923, 2195, 'The Politician S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113407.mp4', 'http://timg.bdta.pro/images/0b3f431c0363c4804f0ddf48f083be9b.jpg'),
(31924, 2196, 'The Red Line Vidas Cruzadas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113398.mp4', 'http://timg.bdta.pro/images/450a0e92f47634e0de693c49322e3bfa.jpg'),
(31925, 2196, 'The Red Line Vidas Cruzadas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113399.mp4', 'http://timg.bdta.pro/images/4315e8bc2527bd661861c7538ee8178c.jpg'),
(31926, 2197, 'The Spanish Princess S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130694.mp4', 'http://timg.bdta.pro/images/a02afa58f80bbae81d51b54dbc571d07.jpg'),
(31927, 2197, 'The Spanish Princess S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130695.mp4', 'http://timg.bdta.pro/images/c49fa9dee68a770b94f2b407cd5ffe8e.jpg'),
(31928, 2197, 'The Spanish Princess S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130696.mp4', 'http://timg.bdta.pro/images/250995868f54eb035c7873f7e1723a05.jpg'),
(31929, 2197, 'The Spanish Princess S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130697.mp4', 'http://timg.bdta.pro/images/9e0eb33edb729c5fff5edf0569e6f639.jpg'),
(31930, 2197, 'The Spanish Princess S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130698.mp4', 'http://timg.bdta.pro/images/3576e0a0a3e7ca6845fffcf763c27da7.jpg'),
(31931, 2197, 'The Spanish Princess S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130699.mp4', 'http://timg.bdta.pro/images/6fa893c3aee72483bced74a6e20185eb.jpg'),
(31932, 2197, 'The Spanish Princess S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130700.mp4', 'http://timg.bdta.pro/images/9557ddcdc92f3a92dbaa97c231066b97.jpg'),
(31933, 2197, 'The Spanish Princess S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130701.mp4', 'http://timg.bdta.pro/images/f3be1e595c85ce0c6c2120873fa35877.jpg'),
(31934, 2198, 'The Spanish Princess S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130702.mp4', 'http://timg.bdta.pro/images/80e0e320c7790da3a91849ae2606b4ad.jpg'),
(31935, 2198, 'The Spanish Princess S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130703.mp4', 'http://timg.bdta.pro/images/8a599ffb3f5a5334b0d8b33148763dfb.jpg'),
(31936, 2198, 'The Spanish Princess S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130704.mp4', 'http://timg.bdta.pro/images/764faa40bc2428116fff0dc6a8213b5e.jpg'),
(31937, 2198, 'The Spanish Princess S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3VyBuFHIK8ZgPYxq6Pg8NR5vIno.jpg'),
(31938, 2198, 'The Spanish Princess S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l6OA8mblWri3YCHxfXIzORBcBUm.jpg'),
(31939, 2198, 'The Spanish Princess S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130707.mp4', 'http://gstaticontent.com/images/4Ec0jIkctpiyKuywPSRj4Pd2jEl_big.jpg'),
(31940, 2198, 'The Spanish Princess S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130708.mp4', 'http://gstaticontent.com/images/4Ec0jIkctpiyKuywPSRj4Pd2jEl_big.jpg'),
(31941, 2198, 'The Spanish Princess S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130709.mp4', 'http://gstaticontent.com/images/4Ec0jIkctpiyKuywPSRj4Pd2jEl_big.jpg'),
(31942, 2199, 'ThunderCats Roar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169190.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31943, 2199, 'ThunderCats Roar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169191.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31944, 2199, 'ThunderCats Roar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169192.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31945, 2199, 'ThunderCats Roar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169193.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31946, 2199, 'ThunderCats Roar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169194.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31947, 2199, 'ThunderCats Roar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169195.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31948, 2199, 'ThunderCats Roar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169196.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31949, 2199, 'ThunderCats Roar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169197.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31950, 2199, 'ThunderCats Roar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169198.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31951, 2199, 'ThunderCats Roar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169199.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31952, 2199, 'ThunderCats Roar S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/169200.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31953, 2199, 'ThunderCats Roar S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/169201.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31954, 2199, 'ThunderCats Roar S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/169202.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31955, 2199, 'ThunderCats Roar S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/169203.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31956, 2199, 'ThunderCats Roar S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/169204.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31957, 2199, 'ThunderCats Roar S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/169205.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31958, 2199, 'ThunderCats Roar S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/169206.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31959, 2199, 'ThunderCats Roar S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/169207.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31960, 2199, 'ThunderCats Roar S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/169208.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31961, 2199, 'ThunderCats Roar S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/169209.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31962, 2199, 'ThunderCats Roar S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/169210.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31963, 2199, 'ThunderCats Roar S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/169211.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31964, 2199, 'ThunderCats Roar S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/169212.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31965, 2199, 'ThunderCats Roar S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/169213.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31966, 2199, 'ThunderCats Roar S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/169214.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31967, 2199, 'ThunderCats Roar S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/169215.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31968, 2199, 'ThunderCats Roar S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/169216.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31969, 2199, 'ThunderCats Roar S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/169217.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31970, 2199, 'ThunderCats Roar S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/169218.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31971, 2199, 'ThunderCats Roar S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/169219.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31972, 2199, 'ThunderCats Roar S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/169220.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31973, 2199, 'ThunderCats Roar S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/169221.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31974, 2199, 'ThunderCats Roar S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/169222.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31975, 2199, 'ThunderCats Roar S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/169223.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31976, 2199, 'ThunderCats Roar S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/169224.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31977, 2199, 'ThunderCats Roar S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/169225.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31978, 2199, 'ThunderCats Roar S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/169226.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31979, 2199, 'ThunderCats Roar S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/169227.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31980, 2199, 'ThunderCats Roar S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/169228.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31981, 2199, 'ThunderCats Roar S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/169229.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31982, 2199, 'ThunderCats Roar S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/169230.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31983, 2199, 'ThunderCats Roar S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/169231.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31984, 2199, 'ThunderCats Roar S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/169232.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31985, 2199, 'ThunderCats Roar S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/169233.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31986, 2199, 'ThunderCats Roar S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/169234.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31987, 2199, 'ThunderCats Roar S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/169235.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31988, 2199, 'ThunderCats Roar S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/169236.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31989, 2199, 'ThunderCats Roar S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/169237.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31990, 2199, 'ThunderCats Roar S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/169238.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31991, 2199, 'ThunderCats Roar S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/169239.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31992, 2199, 'ThunderCats Roar S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/169240.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31993, 2199, 'ThunderCats Roar S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/169241.mp4', 'http://gstaticontent.com/images/ixXYN0ODQ1NtObDYXVfh6enuxbo_big.jpg'),
(31994, 2200, 'Trackers [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124685.mp4', 'http://timg.bdta.pro/images/e74818ca7946c2bc874a1b8e05ea90b7.jpg'),
(31995, 2200, 'Trackers [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124686.mp4', 'http://timg.bdta.pro/images/17eaed9b4f906a7bc57e7d90dde85f91.jpg'),
(31996, 2200, 'Trackers [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124687.mp4', 'http://timg.bdta.pro/images/76a7763fe4c61428f919d5b0cf42d330.jpg'),
(31997, 2200, 'Trackers [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124688.mp4', 'http://timg.bdta.pro/images/b780bd706701cc6aea3ed9dd536cd566.jpg'),
(31998, 2200, 'Trackers [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124689.mp4', 'http://timg.bdta.pro/images/0fe8d098895d6f54294dc934db6ebfd0.jpg'),
(31999, 2200, 'Trackers [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124690.mp4', 'http://timg.bdta.pro/images/77622e8c9c07361096610f7ecd600ee9.jpg'),
(32000, 2201, 'Um Dia de Cada Vez S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113359.mp4', 'http://timg.bdta.pro/images/0a5fc87088c65090167b3b40cce57749.jpg'),
(32001, 2201, 'Um Dia de Cada Vez S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113360.mp4', 'http://timg.bdta.pro/images/9e0fe25072ba52a4cd71b599cb068307.jpg'),
(32002, 2201, 'Um Dia de Cada Vez S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113361.mp4', 'http://timg.bdta.pro/images/14f04f382b40b058754394fa52842a87.jpg'),
(32003, 2201, 'Um Dia de Cada Vez S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113362.mp4', 'http://timg.bdta.pro/images/850978a07db7203a83f4b757ba9d6425.jpg'),
(32004, 2201, 'Um Dia de Cada Vez S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113363.mp4', 'http://timg.bdta.pro/images/000d1657e6bc6ee2e468fbfe37094246.jpg'),
(32005, 2201, 'Um Dia de Cada Vez S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113364.mp4', 'http://timg.bdta.pro/images/ae65c7864577908a04d12598712913fc.jpg'),
(32006, 2201, 'Um Dia de Cada Vez S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113365.mp4', 'http://timg.bdta.pro/images/b93bed5d708cfcc81ade2d617c423780.jpg'),
(32007, 2201, 'Um Dia de Cada Vez S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113366.mp4', 'http://timg.bdta.pro/images/3166f8da29e84c851038c302b9aad63c.jpg'),
(32008, 2201, 'Um Dia de Cada Vez S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113367.mp4', 'http://timg.bdta.pro/images/e4aac4e2587b96857c95941c8a4b3c2d.jpg'),
(32009, 2201, 'Um Dia de Cada Vez S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113368.mp4', 'http://timg.bdta.pro/images/30193abb354c01b4c04965e843804df5.jpg'),
(32010, 2201, 'Um Dia de Cada Vez S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113369.mp4', 'http://timg.bdta.pro/images/2b84c8c3b8aca4dacfe9237bddad156a.jpg'),
(32011, 2201, 'Um Dia de Cada Vez S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113370.mp4', 'http://timg.bdta.pro/images/fd324f5f876e20ba4c7515eebe61c4fb.jpg'),
(32012, 2201, 'Um Dia de Cada Vez S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113371.mp4', 'http://timg.bdta.pro/images/8cc396f264883ab896cda697e5b2c851.jpg'),
(32013, 2202, 'Um Dia de Cada Vez S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113372.mp4', 'http://timg.bdta.pro/images/ae001cea77228fdf3eec63ae6718276a.jpg'),
(32014, 2202, 'Um Dia de Cada Vez S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113373.mp4', 'http://timg.bdta.pro/images/673dfe5cb842565bac892bdad32fa39b.jpg'),
(32015, 2202, 'Um Dia de Cada Vez S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113374.mp4', 'http://timg.bdta.pro/images/1509215cb3f14ce3e1ff2e701c4dda13.jpg'),
(32016, 2202, 'Um Dia de Cada Vez S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113375.mp4', 'http://timg.bdta.pro/images/265740b6519b742720051fdf578a84a5.jpg'),
(32017, 2202, 'Um Dia de Cada Vez S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113376.mp4', 'http://timg.bdta.pro/images/212a0cf59a5f87f245cb2e8660e1ad2a.jpg'),
(32018, 2202, 'Um Dia de Cada Vez S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113377.mp4', 'http://timg.bdta.pro/images/8ddc002bf39c3d356c95e94fbd32d05c.jpg'),
(32019, 2202, 'Um Dia de Cada Vez S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113378.mp4', 'http://timg.bdta.pro/images/f32c500d88469e435de808498125b50e.jpg'),
(32020, 2202, 'Um Dia de Cada Vez S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113379.mp4', 'http://timg.bdta.pro/images/8ac12087ece4a0761646eac4fcc0edbc.jpg'),
(32021, 2202, 'Um Dia de Cada Vez S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113380.mp4', 'http://timg.bdta.pro/images/fc4ab30ea6ac63331f3d55ca295a397b.jpg'),
(32022, 2202, 'Um Dia de Cada Vez S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113381.mp4', 'http://timg.bdta.pro/images/ca9da63f7cb4c2caa3b6e5ffaef30bb2.jpg'),
(32023, 2202, 'Um Dia de Cada Vez S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113382.mp4', 'http://timg.bdta.pro/images/1c0cda75207d0532bdd96efea8ec1962.jpg'),
(32024, 2202, 'Um Dia de Cada Vez S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113383.mp4', 'http://timg.bdta.pro/images/1e58912b164265ef64f8609a026ee551.jpg'),
(32025, 2202, 'Um Dia de Cada Vez S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113384.mp4', 'http://timg.bdta.pro/images/affac474a2e3c4cab58d598187011129.jpg'),
(32026, 2203, 'Um Dia de Cada Vez S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113385.mp4', 'http://timg.bdta.pro/images/affac474a2e3c4cab58d598187011129.jpg'),
(32027, 2203, 'Um Dia de Cada Vez S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113386.mp4', 'http://timg.bdta.pro/images/affac474a2e3c4cab58d598187011129.jpg'),
(32028, 2203, 'Um Dia de Cada Vez S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113387.mp4', 'http://timg.bdta.pro/images/affac474a2e3c4cab58d598187011129.jpg'),
(32029, 2203, 'Um Dia de Cada Vez S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113388.mp4', 'http://timg.bdta.pro/images/affac474a2e3c4cab58d598187011129.jpg'),
(32030, 2203, 'Um Dia de Cada Vez S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113389.mp4', 'http://timg.bdta.pro/images/affac474a2e3c4cab58d598187011129.jpg'),
(32031, 2203, 'Um Dia de Cada Vez S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113390.mp4', 'http://timg.bdta.pro/images/affac474a2e3c4cab58d598187011129.jpg'),
(32032, 2203, 'Um Dia de Cada Vez S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113391.mp4', 'http://timg.bdta.pro/images/affac474a2e3c4cab58d598187011129.jpg'),
(32033, 2203, 'Um Dia de Cada Vez S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113392.mp4', 'http://timg.bdta.pro/images/affac474a2e3c4cab58d598187011129.jpg'),
(32034, 2203, 'Um Dia de Cada Vez S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113393.mp4', 'http://timg.bdta.pro/images/affac474a2e3c4cab58d598187011129.jpg'),
(32035, 2203, 'Um Dia de Cada Vez S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113394.mp4', 'http://timg.bdta.pro/images/affac474a2e3c4cab58d598187011129.jpg'),
(32036, 2203, 'Um Dia de Cada Vez S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/113395.mp4', 'http://timg.bdta.pro/images/affac474a2e3c4cab58d598187011129.jpg'),
(32037, 2203, 'Um Dia de Cada Vez S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/113396.mp4', 'http://timg.bdta.pro/images/affac474a2e3c4cab58d598187011129.jpg'),
(32038, 2203, 'Um Dia de Cada Vez S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/113397.mp4', 'http://timg.bdta.pro/images/affac474a2e3c4cab58d598187011129.jpg'),
(32039, 2204, 'Versailles [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113329.mp4', 'http://timg.bdta.pro/images/6dc8ff71d69408aa214cc7602bc7caeb.jpg'),
(32040, 2204, 'Versailles [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113330.mp4', 'http://timg.bdta.pro/images/32a00163421cd56793f06e3f042f8e82.jpg'),
(32041, 2204, 'Versailles [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113331.mp4', 'http://timg.bdta.pro/images/cad030d72336dbbd589837913d95aea4.jpg'),
(32042, 2204, 'Versailles [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113332.mp4', 'http://timg.bdta.pro/images/83af945c7615d3787c7673dc9df63592.jpg'),
(32043, 2204, 'Versailles [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113333.mp4', 'http://timg.bdta.pro/images/87961d02e582b5eaf9fe907814c77508.jpg'),
(32044, 2204, 'Versailles [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113334.mp4', 'http://timg.bdta.pro/images/d6da14a1c338b146e598473143dab16c.jpg'),
(32045, 2204, 'Versailles [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113335.mp4', 'http://timg.bdta.pro/images/b731963483fdf7de4ef6eb043883d7b9.jpg'),
(32046, 2204, 'Versailles [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113336.mp4', 'http://timg.bdta.pro/images/138476dfc8bdbca320e22b81dae37603.jpg'),
(32047, 2204, 'Versailles [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113337.mp4', 'http://timg.bdta.pro/images/69792b67025b75979d8f4eab2100f78e.jpg'),
(32048, 2204, 'Versailles [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113338.mp4', 'http://timg.bdta.pro/images/8412e74a66df5a99d24200997b31c650.jpg'),
(32049, 2205, 'Versailles [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113339.mp4', 'http://timg.bdta.pro/images/db54c11398855c96962e9af0337b53ae.jpg'),
(32050, 2205, 'Versailles [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113340.mp4', 'http://timg.bdta.pro/images/35d1810836e79adee451cf0f29d03abe.jpg'),
(32051, 2205, 'Versailles [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113341.mp4', 'http://timg.bdta.pro/images/3387d55328858ec92ed3c756469aa228.jpg'),
(32052, 2205, 'Versailles [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113342.mp4', 'http://timg.bdta.pro/images/ae0d3ea42f8d55b5e6ac101bf5431cae.jpg'),
(32053, 2205, 'Versailles [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113343.mp4', 'http://timg.bdta.pro/images/963aa2d31630d73d807d4fdb65e6fc7c.jpg'),
(32054, 2205, 'Versailles [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113344.mp4', 'http://timg.bdta.pro/images/7b88286f720844ddcc1860d4aed66562.jpg'),
(32055, 2205, 'Versailles [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113345.mp4', 'http://timg.bdta.pro/images/5c96d23efa588330c540080479c8a6e4.jpg'),
(32056, 2205, 'Versailles [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113346.mp4', 'http://timg.bdta.pro/images/0e9eb15fda56dc85efb7d63af584f5b0.jpg'),
(32057, 2205, 'Versailles [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113347.mp4', 'http://timg.bdta.pro/images/99886cbeeb33254fff146dfa73f32a9a.jpg'),
(32058, 2205, 'Versailles [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113348.mp4', 'http://timg.bdta.pro/images/9c0cf329a32510a71ace46ff2edeb482.jpg'),
(32059, 2206, 'Versailles [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/113349.mp4', 'http://timg.bdta.pro/images/280cac02155bb53306cb87bc9ff12860.jpg'),
(32060, 2206, 'Versailles [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/113350.mp4', 'http://timg.bdta.pro/images/9341c96e533a0c5cf6ea8fb67970bddf.jpg'),
(32061, 2206, 'Versailles [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/113351.mp4', 'http://timg.bdta.pro/images/90ab1a21023eccb2b0b58c6f29502a99.jpg'),
(32062, 2206, 'Versailles [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/113352.mp4', 'http://timg.bdta.pro/images/1557d999c6604fbf3a840d616d06f9b3.jpg'),
(32063, 2206, 'Versailles [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/113353.mp4', 'http://timg.bdta.pro/images/f5289096aba74fb4e38e76a429628c9a.jpg'),
(32064, 2206, 'Versailles [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/113354.mp4', 'http://timg.bdta.pro/images/7b77d03634a320693e04162ea39090da.jpg'),
(32065, 2206, 'Versailles [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/113355.mp4', 'http://timg.bdta.pro/images/fa4a3c5f8edef1a0cdf935ce1b0a7b25.jpg'),
(32066, 2206, 'Versailles [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/113356.mp4', 'http://timg.bdta.pro/images/1d62fa26869910b1a02d8319863c412f.jpg'),
(32067, 2206, 'Versailles [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/113357.mp4', 'http://timg.bdta.pro/images/84204b06c57ad415337c1d42ba489424.jpg'),
(32068, 2206, 'Versailles [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/113358.mp4', 'http://timg.bdta.pro/images/38ed17994ef3a8391313292855241fd7.jpg'),
(32069, 2207, 'Que Mundo é Esse? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111837.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32070, 2207, 'Que Mundo é Esse? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111838.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32071, 2207, 'Que Mundo é Esse? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111839.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32072, 2207, 'Que Mundo é Esse? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111840.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32073, 2208, 'Que Mundo é Esse? S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111841.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32074, 2208, 'Que Mundo é Esse? S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111842.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32075, 2208, 'Que Mundo é Esse? S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111843.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32076, 2208, 'Que Mundo é Esse? S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111844.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32077, 2209, 'Que Mundo é Esse? S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111845.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32078, 2209, 'Que Mundo é Esse? S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111846.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32079, 2209, 'Que Mundo é Esse? S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111847.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32080, 2209, 'Que Mundo é Esse? S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111848.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32081, 2209, 'Que Mundo é Esse? S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111849.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32082, 2210, 'Que Mundo é Esse? S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111850.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32083, 2210, 'Que Mundo é Esse? S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111851.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32084, 2210, 'Que Mundo é Esse? S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111852.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32085, 2210, 'Que Mundo é Esse? S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111853.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32086, 2211, 'Que Mundo é Esse? S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111854.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32087, 2211, 'Que Mundo é Esse? S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111855.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32088, 2211, 'Que Mundo é Esse? S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111856.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32089, 2211, 'Que Mundo é Esse? S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111857.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32090, 2211, 'Que Mundo é Esse? S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111858.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32091, 2212, 'Que Mundo é Esse? S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111859.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32092, 2212, 'Que Mundo é Esse? S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111860.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32093, 2212, 'Que Mundo é Esse? S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111861.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32094, 2212, 'Que Mundo é Esse? S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111862.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32095, 2212, 'Que Mundo é Esse? S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111863.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32096, 2213, 'Que Mundo é Esse? S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111864.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32097, 2213, 'Que Mundo é Esse? S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111865.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32098, 2213, 'Que Mundo é Esse? S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111866.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32099, 2213, 'Que Mundo é Esse? S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111867.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32100, 2213, 'Que Mundo é Esse? S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111868.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32101, 2214, 'Que Mundo é Esse? S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111869.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32102, 2214, 'Que Mundo é Esse? S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111870.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32103, 2214, 'Que Mundo é Esse? S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111871.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32104, 2214, 'Que Mundo é Esse? S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111872.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32105, 2215, 'Que Mundo é Esse? S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111873.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32106, 2215, 'Que Mundo é Esse? S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111874.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32107, 2215, 'Que Mundo é Esse? S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111875.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32108, 2215, 'Que Mundo é Esse? S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111876.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32109, 2216, 'Que Mundo é Esse? S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111877.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32110, 2216, 'Que Mundo é Esse? S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111878.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32111, 2216, 'Que Mundo é Esse? S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111879.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32112, 2216, 'Que Mundo é Esse? S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111880.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32113, 2216, 'Que Mundo é Esse? S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111881.mp4', 'http://gstaticontent.com/images/6f01d9cd8da4b315ab64acf15a96bcd7.png'),
(32114, 2217, 'Digimon Adventure S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/111783.mp4', 'http://timg.bdta.pro/images/305ab0301c899c51eff969d8c70bef18.jpg'),
(32115, 2217, 'Digimon Adventure S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/111784.mp4', 'http://timg.bdta.pro/images/db10741733d858b46f7a4141270a777a.jpg'),
(32116, 2217, 'Digimon Adventure S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/111785.mp4', 'http://timg.bdta.pro/images/f46412dbf1e8ff019e9c6d30a5f39c8b.jpg'),
(32117, 2217, 'Digimon Adventure S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/111786.mp4', 'http://timg.bdta.pro/images/0dd414129dc910a0dd43639d5ca4ca7d.jpg'),
(32118, 2217, 'Digimon Adventure S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/111787.mp4', 'http://timg.bdta.pro/images/21534cdece0e1a1a6d528f30f7aab876.jpg'),
(32119, 2217, 'Digimon Adventure S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/111788.mp4', 'http://timg.bdta.pro/images/788b4ada6ccbfef1a85df8d7d83937c2.jpg'),
(32120, 2217, 'Digimon Adventure S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/111789.mp4', 'http://timg.bdta.pro/images/b6f8da7573cc176ec25c0c1ab428e6e6.jpg'),
(32121, 2217, 'Digimon Adventure S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/111790.mp4', 'http://timg.bdta.pro/images/456ad25d62a321b51a52c920acc46a33.jpg'),
(32122, 2217, 'Digimon Adventure S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/111791.mp4', 'http://timg.bdta.pro/images/d342e22d9963f2b89e30a7e66b6a1fb4.jpg'),
(32123, 2217, 'Digimon Adventure S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/111792.mp4', 'http://timg.bdta.pro/images/21ed5348ea6548bb0102ccfe3074bcd2.jpg'),
(32124, 2217, 'Digimon Adventure S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/111793.mp4', 'http://timg.bdta.pro/images/575495add2aca37f5ce924d1802961b5.jpg'),
(32125, 2217, 'Digimon Adventure S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/111794.mp4', 'http://timg.bdta.pro/images/bcbe4da5ac7786ecb19e34e8d101a754.jpg'),
(32126, 2217, 'Digimon Adventure S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/111795.mp4', 'http://timg.bdta.pro/images/af54a6f4ec63324aacea1f46e042178a.jpg'),
(32127, 2217, 'Digimon Adventure S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/111796.mp4', 'http://timg.bdta.pro/images/c5fdfb7f6003e94447c8d0ce1703f4c9.jpg'),
(32128, 2217, 'Digimon Adventure S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/111797.mp4', 'http://timg.bdta.pro/images/206e4db118ff485fe7afb8079dff65ba.jpg'),
(32129, 2217, 'Digimon Adventure S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/111798.mp4', 'http://timg.bdta.pro/images/6278652d7b37da93974193766d0b78b2.jpg'),
(32130, 2217, 'Digimon Adventure S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/111799.mp4', 'http://timg.bdta.pro/images/b24163c8beb30fa391d5c3d388c4c879.jpg'),
(32131, 2217, 'Digimon Adventure S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/111800.mp4', 'http://timg.bdta.pro/images/0b144a0b2b19257958e08da7543f53f0.jpg'),
(32132, 2217, 'Digimon Adventure S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/111801.mp4', 'http://timg.bdta.pro/images/4e148ea3ac866aae00988977b6513ab0.jpg'),
(32133, 2217, 'Digimon Adventure S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/111802.mp4', 'http://timg.bdta.pro/images/e1dda355e3d668ccb8549969a6addaac.jpg'),
(32134, 2217, 'Digimon Adventure S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/111803.mp4', 'http://timg.bdta.pro/images/95787a88df5a706aacbd00f080557bf4.jpg'),
(32135, 2217, 'Digimon Adventure S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/111804.mp4', 'http://timg.bdta.pro/images/f73514cb25f5647797d4664050c2a6e0.jpg'),
(32136, 2217, 'Digimon Adventure S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/111805.mp4', 'http://timg.bdta.pro/images/26f5ae4dcbdc5edb92f44573d06f725e.jpg'),
(32137, 2217, 'Digimon Adventure S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/111806.mp4', 'http://timg.bdta.pro/images/eb45f1aa1f6650f8ab2626c66c35b7de.jpg'),
(32138, 2217, 'Digimon Adventure S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/111807.mp4', 'http://timg.bdta.pro/images/a67c3778ed31b100bb19c63887f4dc1f.jpg'),
(32139, 2217, 'Digimon Adventure S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/111808.mp4', 'http://timg.bdta.pro/images/db803ea82f063d56c4f5a6c48c955cc5.jpg'),
(32140, 2217, 'Digimon Adventure S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/111809.mp4', 'http://timg.bdta.pro/images/4bbedadb5867af6750f9a4493406b49d.jpg'),
(32141, 2217, 'Digimon Adventure S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/111810.mp4', 'http://timg.bdta.pro/images/f5b324e36726fb198faa32cabf714809.jpg'),
(32142, 2217, 'Digimon Adventure S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/111811.mp4', 'http://timg.bdta.pro/images/3afd5484ab7f9c7234a4d7fc9c1a7210.jpg'),
(32143, 2217, 'Digimon Adventure S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/111812.mp4', 'http://timg.bdta.pro/images/925fc2b49e4b21b87db51c66ecbd48c5.jpg'),
(32144, 2217, 'Digimon Adventure S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/111813.mp4', 'http://timg.bdta.pro/images/ae06d78a81da940c639171b4dde4f728.jpg'),
(32145, 2217, 'Digimon Adventure S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/111814.mp4', 'http://timg.bdta.pro/images/754875a4a1a705c87cbeff1214a27ed2.jpg'),
(32146, 2217, 'Digimon Adventure S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/111815.mp4', 'http://timg.bdta.pro/images/eedbc4b22048cd5d68282ff250118790.jpg'),
(32147, 2217, 'Digimon Adventure S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/111816.mp4', 'http://timg.bdta.pro/images/95ab88a7fa817bc9c59c20888809c7a5.jpg'),
(32148, 2217, 'Digimon Adventure S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/111817.mp4', 'http://timg.bdta.pro/images/6feb069c135a6ce947f154fc7e784b39.jpg'),
(32149, 2217, 'Digimon Adventure S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/111818.mp4', 'http://timg.bdta.pro/images/f4337dc04adf8ea15a4d79561b8bef23.jpg'),
(32150, 2217, 'Digimon Adventure S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/111819.mp4', 'http://timg.bdta.pro/images/07cf18a4b4071584ce597a58008c8c61.jpg'),
(32151, 2217, 'Digimon Adventure S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/111820.mp4', 'http://timg.bdta.pro/images/ffa13d0bb637efaa5c75ef4450b6ba0b.jpg'),
(32152, 2217, 'Digimon Adventure S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/111821.mp4', 'http://timg.bdta.pro/images/66def1dca1f001682a1223156079506a.jpg'),
(32153, 2217, 'Digimon Adventure S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/111822.mp4', 'http://timg.bdta.pro/images/4f8bfa1aed001bf220318921f6df16df.jpg'),
(32154, 2217, 'Digimon Adventure S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/111823.mp4', 'http://timg.bdta.pro/images/7e7425e099c6241f76d437d9eb2135a8.jpg'),
(32155, 2217, 'Digimon Adventure S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/111824.mp4', 'http://timg.bdta.pro/images/38fb2625207c632700ccc8ca6d4676d0.jpg'),
(32156, 2217, 'Digimon Adventure S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/111825.mp4', 'http://timg.bdta.pro/images/f186c954f6cb3f6741f3fdd97444cd1b.jpg'),
(32157, 2217, 'Digimon Adventure S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/111826.mp4', 'http://timg.bdta.pro/images/285fbe145ddf98a52cd0d157478bcbab.jpg'),
(32158, 2217, 'Digimon Adventure S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/111827.mp4', 'http://timg.bdta.pro/images/81cc90c15226c5da3c40225332d5abc5.jpg'),
(32159, 2217, 'Digimon Adventure S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/111828.mp4', 'http://timg.bdta.pro/images/dd8c054714dc4504e36d661a950503ed.jpg'),
(32160, 2217, 'Digimon Adventure S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/111829.mp4', 'http://timg.bdta.pro/images/524652be5166567fa0d7eb92b10b784d.jpg'),
(32161, 2217, 'Digimon Adventure S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/111830.mp4', 'http://timg.bdta.pro/images/90fe8f0197d4ee6b1b120df882967f8c.jpg'),
(32162, 2217, 'Digimon Adventure S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/111831.mp4', 'http://timg.bdta.pro/images/96bf62a9c74de2fc8c41d62c03b9042a.jpg'),
(32163, 2217, 'Digimon Adventure S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/111832.mp4', 'http://timg.bdta.pro/images/7c2cfd30bfdfa326aae2818a2c6b4daa.jpg'),
(32164, 2217, 'Digimon Adventure S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/111833.mp4', 'http://timg.bdta.pro/images/3ccfdb84f03037b37877884179371ee3.jpg'),
(32165, 2217, 'Digimon Adventure S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/111834.mp4', 'http://timg.bdta.pro/images/ea6ed0ab324eaf3da56258645d51f8d4.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(32166, 2217, 'Digimon Adventure S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/111835.mp4', 'http://timg.bdta.pro/images/46703ef9a0548c4c43b36b10df47f97e.jpg'),
(32167, 2217, 'Digimon Adventure S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/111836.mp4', 'http://timg.bdta.pro/images/3c345820ea89bc532867c7eda3546c6f.jpg'),
(32168, 2218, 'A Grande Família S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/117048.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32169, 2218, 'A Grande Família S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/117049.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32170, 2218, 'A Grande Família S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/117050.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32171, 2218, 'A Grande Família S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/117051.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32172, 2218, 'A Grande Família S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/117052.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32173, 2218, 'A Grande Família S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/117053.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32174, 2218, 'A Grande Família S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/117054.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32175, 2218, 'A Grande Família S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/117055.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32176, 2218, 'A Grande Família S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/117056.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32177, 2218, 'A Grande Família S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/117057.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32178, 2218, 'A Grande Família S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/117058.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32179, 2218, 'A Grande Família S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/117059.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32180, 2218, 'A Grande Família S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/117060.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32181, 2218, 'A Grande Família S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/117061.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32182, 2218, 'A Grande Família S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/117062.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32183, 2218, 'A Grande Família S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/117063.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32184, 2218, 'A Grande Família S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/117064.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32185, 2218, 'A Grande Família S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/117065.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32186, 2218, 'A Grande Família S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/117066.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32187, 2218, 'A Grande Família S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/117067.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32188, 2218, 'A Grande Família S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/117068.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32189, 2218, 'A Grande Família S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/117069.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32190, 2218, 'A Grande Família S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/117070.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32191, 2218, 'A Grande Família S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/117071.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32192, 2218, 'A Grande Família S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/117072.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32193, 2218, 'A Grande Família S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/117073.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32194, 2218, 'A Grande Família S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/117074.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32195, 2218, 'A Grande Família S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/117075.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32196, 2218, 'A Grande Família S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/117076.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32197, 2218, 'A Grande Família S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/117077.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32198, 2218, 'A Grande Família S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/117078.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32199, 2218, 'A Grande Família S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/117079.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32200, 2218, 'A Grande Família S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/117080.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32201, 2218, 'A Grande Família S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/117081.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32202, 2218, 'A Grande Família S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/117082.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32203, 2218, 'A Grande Família S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/117083.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32204, 2219, 'A Grande Família S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/117084.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32205, 2219, 'A Grande Família S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/117085.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32206, 2219, 'A Grande Família S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/117086.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32207, 2219, 'A Grande Família S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/117087.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32208, 2219, 'A Grande Família S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/117088.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32209, 2219, 'A Grande Família S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/117089.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32210, 2219, 'A Grande Família S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/117090.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32211, 2219, 'A Grande Família S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/117091.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32212, 2219, 'A Grande Família S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/117092.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32213, 2219, 'A Grande Família S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/117093.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32214, 2219, 'A Grande Família S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/117094.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32215, 2219, 'A Grande Família S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/117095.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32216, 2219, 'A Grande Família S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/117096.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32217, 2219, 'A Grande Família S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/117097.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32218, 2219, 'A Grande Família S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/117098.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32219, 2219, 'A Grande Família S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/117099.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32220, 2219, 'A Grande Família S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/117100.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32221, 2219, 'A Grande Família S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/117101.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32222, 2219, 'A Grande Família S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/117102.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32223, 2219, 'A Grande Família S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/117103.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32224, 2219, 'A Grande Família S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/117104.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32225, 2219, 'A Grande Família S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/117105.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32226, 2219, 'A Grande Família S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/117106.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32227, 2219, 'A Grande Família S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/117107.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32228, 2219, 'A Grande Família S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/117108.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32229, 2219, 'A Grande Família S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/117109.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32230, 2219, 'A Grande Família S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/117110.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32231, 2219, 'A Grande Família S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/117111.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32232, 2219, 'A Grande Família S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/117112.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32233, 2219, 'A Grande Família S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/117113.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32234, 2219, 'A Grande Família S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/117114.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32235, 2219, 'A Grande Família S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/117115.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32236, 2219, 'A Grande Família S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/117116.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32237, 2219, 'A Grande Família S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/117117.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32238, 2219, 'A Grande Família S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/117118.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32239, 2219, 'A Grande Família S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/117119.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32240, 2219, 'A Grande Família S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/117120.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32241, 2220, 'A Grande Família S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/117121.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32242, 2220, 'A Grande Família S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/117122.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32243, 2220, 'A Grande Família S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/117123.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32244, 2220, 'A Grande Família S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/117124.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32245, 2220, 'A Grande Família S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/117125.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32246, 2220, 'A Grande Família S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/117126.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32247, 2220, 'A Grande Família S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/117127.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32248, 2220, 'A Grande Família S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/117128.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32249, 2220, 'A Grande Família S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/117129.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32250, 2220, 'A Grande Família S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/117130.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32251, 2220, 'A Grande Família S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/117131.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32252, 2220, 'A Grande Família S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/117132.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32253, 2220, 'A Grande Família S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/117133.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32254, 2220, 'A Grande Família S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/117134.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32255, 2220, 'A Grande Família S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/117135.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32256, 2220, 'A Grande Família S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/117136.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32257, 2220, 'A Grande Família S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/117137.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32258, 2220, 'A Grande Família S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/117138.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32259, 2220, 'A Grande Família S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/117139.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32260, 2220, 'A Grande Família S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/117140.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32261, 2220, 'A Grande Família S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/117141.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32262, 2220, 'A Grande Família S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/117142.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32263, 2220, 'A Grande Família S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/117143.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32264, 2220, 'A Grande Família S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/117144.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32265, 2220, 'A Grande Família S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/117145.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32266, 2220, 'A Grande Família S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/117146.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32267, 2220, 'A Grande Família S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/117147.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32268, 2220, 'A Grande Família S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/117148.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32269, 2220, 'A Grande Família S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/117149.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32270, 2220, 'A Grande Família S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/117150.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32271, 2220, 'A Grande Família S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/117151.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32272, 2220, 'A Grande Família S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/117152.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32273, 2220, 'A Grande Família S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/117153.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32274, 2220, 'A Grande Família S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/117154.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32275, 2220, 'A Grande Família S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/117155.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32276, 2220, 'A Grande Família S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/117156.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32277, 2221, 'A Grande Família S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/117157.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32278, 2221, 'A Grande Família S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/117158.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32279, 2221, 'A Grande Família S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/117159.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32280, 2221, 'A Grande Família S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/117160.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32281, 2221, 'A Grande Família S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/117161.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32282, 2221, 'A Grande Família S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/117162.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32283, 2221, 'A Grande Família S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/117163.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32284, 2221, 'A Grande Família S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/117164.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32285, 2221, 'A Grande Família S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/117165.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32286, 2221, 'A Grande Família S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/117166.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32287, 2221, 'A Grande Família S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/117167.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32288, 2221, 'A Grande Família S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/117168.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32289, 2221, 'A Grande Família S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/117169.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32290, 2221, 'A Grande Família S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/117170.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32291, 2221, 'A Grande Família S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/117171.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32292, 2221, 'A Grande Família S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/117172.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32293, 2221, 'A Grande Família S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/117173.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32294, 2221, 'A Grande Família S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/117174.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32295, 2221, 'A Grande Família S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/117175.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32296, 2221, 'A Grande Família S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/117176.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32297, 2221, 'A Grande Família S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/117177.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32298, 2221, 'A Grande Família S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/117178.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32299, 2221, 'A Grande Família S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/117179.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32300, 2221, 'A Grande Família S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/117180.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32301, 2221, 'A Grande Família S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/117181.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32302, 2221, 'A Grande Família S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/117182.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32303, 2221, 'A Grande Família S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/117183.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32304, 2221, 'A Grande Família S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/117184.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32305, 2221, 'A Grande Família S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/117185.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32306, 2221, 'A Grande Família S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/117186.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32307, 2222, 'A Grande Família S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/117187.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32308, 2222, 'A Grande Família S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/117188.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32309, 2222, 'A Grande Família S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/117189.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32310, 2222, 'A Grande Família S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/117190.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32311, 2222, 'A Grande Família S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/117191.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32312, 2222, 'A Grande Família S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/117192.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32313, 2222, 'A Grande Família S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/117193.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32314, 2222, 'A Grande Família S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/117194.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32315, 2222, 'A Grande Família S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/117195.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32316, 2222, 'A Grande Família S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/117196.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32317, 2222, 'A Grande Família S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/117197.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32318, 2222, 'A Grande Família S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/117198.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32319, 2222, 'A Grande Família S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/117199.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32320, 2222, 'A Grande Família S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/117200.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32321, 2222, 'A Grande Família S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/117201.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32322, 2222, 'A Grande Família S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/117202.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32323, 2222, 'A Grande Família S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/117203.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32324, 2222, 'A Grande Família S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/117204.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32325, 2222, 'A Grande Família S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/117205.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32326, 2222, 'A Grande Família S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/117206.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32327, 2222, 'A Grande Família S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/117207.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32328, 2222, 'A Grande Família S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/117208.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32329, 2222, 'A Grande Família S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/117209.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32330, 2222, 'A Grande Família S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/117210.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32331, 2222, 'A Grande Família S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/117211.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32332, 2222, 'A Grande Família S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/117212.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32333, 2222, 'A Grande Família S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/117213.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32334, 2222, 'A Grande Família S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/117214.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32335, 2222, 'A Grande Família S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/117215.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32336, 2222, 'A Grande Família S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/117216.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32337, 2222, 'A Grande Família S05 E31', 'http://sinalprivado.info:80/series/1533784/1533784/117217.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32338, 2222, 'A Grande Família S05 E32', 'http://sinalprivado.info:80/series/1533784/1533784/117218.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32339, 2222, 'A Grande Família S05 E33', 'http://sinalprivado.info:80/series/1533784/1533784/117219.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32340, 2222, 'A Grande Família S05 E34', 'http://sinalprivado.info:80/series/1533784/1533784/117220.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32341, 2222, 'A Grande Família S05 E35', 'http://sinalprivado.info:80/series/1533784/1533784/117221.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32342, 2222, 'A Grande Família S05 E36', 'http://sinalprivado.info:80/series/1533784/1533784/117222.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32343, 2223, 'A Grande Família S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/117223.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32344, 2223, 'A Grande Família S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/117224.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32345, 2223, 'A Grande Família S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/117225.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32346, 2223, 'A Grande Família S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/117226.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32347, 2223, 'A Grande Família S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/117227.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32348, 2223, 'A Grande Família S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/117228.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32349, 2223, 'A Grande Família S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/117229.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32350, 2223, 'A Grande Família S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/117230.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32351, 2223, 'A Grande Família S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/117231.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32352, 2223, 'A Grande Família S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/117232.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32353, 2223, 'A Grande Família S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/117233.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32354, 2223, 'A Grande Família S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/117234.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32355, 2223, 'A Grande Família S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/117235.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32356, 2223, 'A Grande Família S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/117236.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32357, 2223, 'A Grande Família S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/117237.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32358, 2223, 'A Grande Família S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/117238.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32359, 2223, 'A Grande Família S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/117239.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32360, 2223, 'A Grande Família S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/117240.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32361, 2223, 'A Grande Família S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/117241.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32362, 2223, 'A Grande Família S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/117242.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32363, 2223, 'A Grande Família S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/117243.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32364, 2223, 'A Grande Família S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/117244.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32365, 2223, 'A Grande Família S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/117245.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32366, 2223, 'A Grande Família S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/117246.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32367, 2223, 'A Grande Família S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/117247.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32368, 2223, 'A Grande Família S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/117248.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32369, 2223, 'A Grande Família S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/117249.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32370, 2223, 'A Grande Família S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/117250.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32371, 2223, 'A Grande Família S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/117251.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32372, 2223, 'A Grande Família S06 E30', 'http://sinalprivado.info:80/series/1533784/1533784/117252.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32373, 2223, 'A Grande Família S06 E31', 'http://sinalprivado.info:80/series/1533784/1533784/117253.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32374, 2223, 'A Grande Família S06 E32', 'http://sinalprivado.info:80/series/1533784/1533784/117254.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32375, 2223, 'A Grande Família S06 E33', 'http://sinalprivado.info:80/series/1533784/1533784/117255.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32376, 2223, 'A Grande Família S06 E34', 'http://sinalprivado.info:80/series/1533784/1533784/117256.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32377, 2223, 'A Grande Família S06 E35', 'http://sinalprivado.info:80/series/1533784/1533784/117257.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32378, 2223, 'A Grande Família S06 E36', 'http://sinalprivado.info:80/series/1533784/1533784/117258.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32379, 2223, 'A Grande Família S06 E37', 'http://sinalprivado.info:80/series/1533784/1533784/117259.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32380, 2224, 'A Grande Família S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/117260.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32381, 2224, 'A Grande Família S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/117261.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32382, 2224, 'A Grande Família S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/117262.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32383, 2224, 'A Grande Família S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/117263.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32384, 2224, 'A Grande Família S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/117264.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32385, 2224, 'A Grande Família S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/117265.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32386, 2224, 'A Grande Família S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/117266.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32387, 2224, 'A Grande Família S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/117267.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32388, 2224, 'A Grande Família S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/117268.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32389, 2224, 'A Grande Família S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/117269.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32390, 2224, 'A Grande Família S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/117270.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32391, 2224, 'A Grande Família S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/117271.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32392, 2224, 'A Grande Família S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/117272.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32393, 2224, 'A Grande Família S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/117273.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32394, 2224, 'A Grande Família S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/117274.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32395, 2224, 'A Grande Família S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/117275.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32396, 2224, 'A Grande Família S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/117276.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32397, 2224, 'A Grande Família S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/117277.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32398, 2224, 'A Grande Família S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/117278.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32399, 2224, 'A Grande Família S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/117279.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32400, 2224, 'A Grande Família S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/117280.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32401, 2224, 'A Grande Família S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/117281.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32402, 2224, 'A Grande Família S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/117282.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32403, 2224, 'A Grande Família S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/117283.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32404, 2224, 'A Grande Família S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/117284.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32405, 2224, 'A Grande Família S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/117285.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32406, 2224, 'A Grande Família S07 E27', 'http://sinalprivado.info:80/series/1533784/1533784/117286.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32407, 2224, 'A Grande Família S07 E28', 'http://sinalprivado.info:80/series/1533784/1533784/117287.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32408, 2224, 'A Grande Família S07 E29', 'http://sinalprivado.info:80/series/1533784/1533784/117288.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32409, 2224, 'A Grande Família S07 E30', 'http://sinalprivado.info:80/series/1533784/1533784/117289.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32410, 2224, 'A Grande Família S07 E31', 'http://sinalprivado.info:80/series/1533784/1533784/117290.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32411, 2224, 'A Grande Família S07 E32', 'http://sinalprivado.info:80/series/1533784/1533784/117291.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32412, 2224, 'A Grande Família S07 E33', 'http://sinalprivado.info:80/series/1533784/1533784/117292.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32413, 2224, 'A Grande Família S07 E34', 'http://sinalprivado.info:80/series/1533784/1533784/117293.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32414, 2224, 'A Grande Família S07 E35', 'http://sinalprivado.info:80/series/1533784/1533784/117294.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32415, 2224, 'A Grande Família S07 E36', 'http://sinalprivado.info:80/series/1533784/1533784/117295.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32416, 2224, 'A Grande Família S07 E37', 'http://sinalprivado.info:80/series/1533784/1533784/117296.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32417, 2225, 'A Grande Família S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/117297.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32418, 2225, 'A Grande Família S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/117298.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32419, 2225, 'A Grande Família S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/117299.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32420, 2225, 'A Grande Família S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/117300.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32421, 2225, 'A Grande Família S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/117301.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32422, 2225, 'A Grande Família S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/117302.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32423, 2225, 'A Grande Família S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/117303.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32424, 2225, 'A Grande Família S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/117304.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32425, 2225, 'A Grande Família S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/117305.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32426, 2225, 'A Grande Família S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/117306.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32427, 2225, 'A Grande Família S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/117307.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32428, 2225, 'A Grande Família S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/117308.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32429, 2225, 'A Grande Família S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/117309.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32430, 2225, 'A Grande Família S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/117310.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32431, 2225, 'A Grande Família S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/117311.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32432, 2225, 'A Grande Família S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/117312.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32433, 2225, 'A Grande Família S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/117313.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32434, 2225, 'A Grande Família S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/117314.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32435, 2225, 'A Grande Família S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/117315.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32436, 2225, 'A Grande Família S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/117316.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32437, 2225, 'A Grande Família S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/117317.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32438, 2225, 'A Grande Família S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/117318.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32439, 2225, 'A Grande Família S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/117319.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32440, 2225, 'A Grande Família S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/117320.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32441, 2225, 'A Grande Família S08 E25', 'http://sinalprivado.info:80/series/1533784/1533784/117321.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32442, 2225, 'A Grande Família S08 E26', 'http://sinalprivado.info:80/series/1533784/1533784/117322.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32443, 2225, 'A Grande Família S08 E27', 'http://sinalprivado.info:80/series/1533784/1533784/117323.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32444, 2225, 'A Grande Família S08 E28', 'http://sinalprivado.info:80/series/1533784/1533784/117324.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32445, 2225, 'A Grande Família S08 E29', 'http://sinalprivado.info:80/series/1533784/1533784/117325.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32446, 2225, 'A Grande Família S08 E30', 'http://sinalprivado.info:80/series/1533784/1533784/117326.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32447, 2225, 'A Grande Família S08 E31', 'http://sinalprivado.info:80/series/1533784/1533784/117327.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32448, 2225, 'A Grande Família S08 E32', 'http://sinalprivado.info:80/series/1533784/1533784/117328.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32449, 2225, 'A Grande Família S08 E33', 'http://sinalprivado.info:80/series/1533784/1533784/117329.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32450, 2225, 'A Grande Família S08 E34', 'http://sinalprivado.info:80/series/1533784/1533784/117330.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32451, 2225, 'A Grande Família S08 E35', 'http://sinalprivado.info:80/series/1533784/1533784/117331.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(32452, 2225, 'A Grande Família S08 E36', 'http://sinalprivado.info:80/series/1533784/1533784/117332.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32453, 2225, 'A Grande Família S08 E37', 'http://sinalprivado.info:80/series/1533784/1533784/117333.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32454, 2225, 'A Grande Família S08 E38', 'http://sinalprivado.info:80/series/1533784/1533784/117334.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32455, 2226, 'A Grande Família S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/117335.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32456, 2226, 'A Grande Família S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/117336.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32457, 2226, 'A Grande Família S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/117337.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32458, 2226, 'A Grande Família S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/117338.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32459, 2226, 'A Grande Família S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/117339.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32460, 2226, 'A Grande Família S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/117340.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32461, 2226, 'A Grande Família S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/117341.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32462, 2226, 'A Grande Família S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/117342.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32463, 2226, 'A Grande Família S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/117343.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32464, 2226, 'A Grande Família S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/117344.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32465, 2226, 'A Grande Família S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/117345.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32466, 2226, 'A Grande Família S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/117346.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32467, 2226, 'A Grande Família S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/117347.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32468, 2226, 'A Grande Família S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/117348.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32469, 2226, 'A Grande Família S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/117349.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32470, 2226, 'A Grande Família S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/117350.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32471, 2226, 'A Grande Família S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/117351.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32472, 2226, 'A Grande Família S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/117352.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32473, 2226, 'A Grande Família S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/117353.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32474, 2226, 'A Grande Família S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/117354.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32475, 2226, 'A Grande Família S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/117355.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32476, 2226, 'A Grande Família S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/117356.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32477, 2226, 'A Grande Família S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/117357.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32478, 2226, 'A Grande Família S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/117358.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32479, 2226, 'A Grande Família S09 E25', 'http://sinalprivado.info:80/series/1533784/1533784/117359.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32480, 2226, 'A Grande Família S09 E26', 'http://sinalprivado.info:80/series/1533784/1533784/117360.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32481, 2226, 'A Grande Família S09 E27', 'http://sinalprivado.info:80/series/1533784/1533784/117361.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32482, 2226, 'A Grande Família S09 E28', 'http://sinalprivado.info:80/series/1533784/1533784/117362.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32483, 2226, 'A Grande Família S09 E29', 'http://sinalprivado.info:80/series/1533784/1533784/117363.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32484, 2226, 'A Grande Família S09 E30', 'http://sinalprivado.info:80/series/1533784/1533784/117364.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32485, 2226, 'A Grande Família S09 E31', 'http://sinalprivado.info:80/series/1533784/1533784/117365.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32486, 2226, 'A Grande Família S09 E32', 'http://sinalprivado.info:80/series/1533784/1533784/117366.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32487, 2226, 'A Grande Família S09 E33', 'http://sinalprivado.info:80/series/1533784/1533784/117367.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32488, 2226, 'A Grande Família S09 E34', 'http://sinalprivado.info:80/series/1533784/1533784/117368.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32489, 2226, 'A Grande Família S09 E35', 'http://sinalprivado.info:80/series/1533784/1533784/117369.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32490, 2226, 'A Grande Família S09 E36', 'http://sinalprivado.info:80/series/1533784/1533784/117370.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32491, 2227, 'A Grande Família S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/117371.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32492, 2227, 'A Grande Família S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/117372.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32493, 2227, 'A Grande Família S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/117373.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32494, 2227, 'A Grande Família S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/117374.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32495, 2227, 'A Grande Família S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/117375.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32496, 2227, 'A Grande Família S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/117376.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32497, 2227, 'A Grande Família S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/117377.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32498, 2227, 'A Grande Família S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/117378.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32499, 2227, 'A Grande Família S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/117379.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32500, 2227, 'A Grande Família S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/117380.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32501, 2227, 'A Grande Família S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/117381.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32502, 2227, 'A Grande Família S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/117382.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32503, 2227, 'A Grande Família S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/117383.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32504, 2227, 'A Grande Família S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/117384.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32505, 2227, 'A Grande Família S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/117385.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32506, 2227, 'A Grande Família S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/117386.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32507, 2227, 'A Grande Família S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/117387.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32508, 2227, 'A Grande Família S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/117388.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32509, 2227, 'A Grande Família S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/117389.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32510, 2227, 'A Grande Família S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/117390.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32511, 2227, 'A Grande Família S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/117391.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32512, 2227, 'A Grande Família S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/117392.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32513, 2227, 'A Grande Família S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/117393.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32514, 2227, 'A Grande Família S10 E24', 'http://sinalprivado.info:80/series/1533784/1533784/117394.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32515, 2227, 'A Grande Família S10 E25', 'http://sinalprivado.info:80/series/1533784/1533784/117395.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32516, 2227, 'A Grande Família S10 E26', 'http://sinalprivado.info:80/series/1533784/1533784/117396.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32517, 2227, 'A Grande Família S10 E27', 'http://sinalprivado.info:80/series/1533784/1533784/117397.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32518, 2227, 'A Grande Família S10 E28', 'http://sinalprivado.info:80/series/1533784/1533784/117398.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32519, 2227, 'A Grande Família S10 E29', 'http://sinalprivado.info:80/series/1533784/1533784/117399.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32520, 2227, 'A Grande Família S10 E30', 'http://sinalprivado.info:80/series/1533784/1533784/117400.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32521, 2227, 'A Grande Família S10 E31', 'http://sinalprivado.info:80/series/1533784/1533784/117401.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32522, 2227, 'A Grande Família S10 E32', 'http://sinalprivado.info:80/series/1533784/1533784/117402.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32523, 2227, 'A Grande Família S10 E33', 'http://sinalprivado.info:80/series/1533784/1533784/117403.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32524, 2227, 'A Grande Família S10 E34', 'http://sinalprivado.info:80/series/1533784/1533784/117404.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32525, 2227, 'A Grande Família S10 E35', 'http://sinalprivado.info:80/series/1533784/1533784/117405.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32526, 2228, 'A Grande Família S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/117406.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32527, 2228, 'A Grande Família S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/117407.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32528, 2228, 'A Grande Família S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/117408.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32529, 2228, 'A Grande Família S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/117409.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32530, 2228, 'A Grande Família S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/117410.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32531, 2228, 'A Grande Família S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/117411.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32532, 2228, 'A Grande Família S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/117412.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32533, 2228, 'A Grande Família S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/117413.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32534, 2228, 'A Grande Família S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/117414.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32535, 2228, 'A Grande Família S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/117415.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32536, 2228, 'A Grande Família S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/117416.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32537, 2228, 'A Grande Família S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/117417.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32538, 2228, 'A Grande Família S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/117418.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32539, 2228, 'A Grande Família S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/117419.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32540, 2228, 'A Grande Família S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/117420.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32541, 2228, 'A Grande Família S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/117421.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32542, 2228, 'A Grande Família S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/117422.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32543, 2228, 'A Grande Família S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/117423.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32544, 2228, 'A Grande Família S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/117424.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32545, 2228, 'A Grande Família S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/117425.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32546, 2228, 'A Grande Família S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/117426.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32547, 2228, 'A Grande Família S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/117427.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32548, 2228, 'A Grande Família S11 E23', 'http://sinalprivado.info:80/series/1533784/1533784/117428.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32549, 2228, 'A Grande Família S11 E24', 'http://sinalprivado.info:80/series/1533784/1533784/117429.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32550, 2228, 'A Grande Família S11 E25', 'http://sinalprivado.info:80/series/1533784/1533784/117430.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32551, 2228, 'A Grande Família S11 E26', 'http://sinalprivado.info:80/series/1533784/1533784/117431.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32552, 2228, 'A Grande Família S11 E27', 'http://sinalprivado.info:80/series/1533784/1533784/117432.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32553, 2228, 'A Grande Família S11 E28', 'http://sinalprivado.info:80/series/1533784/1533784/117433.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32554, 2228, 'A Grande Família S11 E29', 'http://sinalprivado.info:80/series/1533784/1533784/117434.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32555, 2228, 'A Grande Família S11 E30', 'http://sinalprivado.info:80/series/1533784/1533784/117435.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32556, 2228, 'A Grande Família S11 E31', 'http://sinalprivado.info:80/series/1533784/1533784/117436.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32557, 2228, 'A Grande Família S11 E32', 'http://sinalprivado.info:80/series/1533784/1533784/117437.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32558, 2228, 'A Grande Família S11 E33', 'http://sinalprivado.info:80/series/1533784/1533784/117438.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32559, 2228, 'A Grande Família S11 E34', 'http://sinalprivado.info:80/series/1533784/1533784/117439.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32560, 2228, 'A Grande Família S11 E35', 'http://sinalprivado.info:80/series/1533784/1533784/117440.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32561, 2228, 'A Grande Família S11 E36', 'http://sinalprivado.info:80/series/1533784/1533784/117441.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32562, 2228, 'A Grande Família S11 E37', 'http://sinalprivado.info:80/series/1533784/1533784/117442.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32563, 2228, 'A Grande Família S11 E38', 'http://sinalprivado.info:80/series/1533784/1533784/117443.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32564, 2229, 'A Grande Família S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/117444.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32565, 2229, 'A Grande Família S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/117445.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32566, 2229, 'A Grande Família S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/117446.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32567, 2229, 'A Grande Família S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/117447.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32568, 2229, 'A Grande Família S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/117448.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32569, 2229, 'A Grande Família S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/117449.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32570, 2229, 'A Grande Família S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/117450.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32571, 2229, 'A Grande Família S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/117451.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32572, 2229, 'A Grande Família S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/117452.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32573, 2229, 'A Grande Família S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/117453.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32574, 2229, 'A Grande Família S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/117454.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32575, 2229, 'A Grande Família S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/117455.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32576, 2229, 'A Grande Família S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/117456.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32577, 2229, 'A Grande Família S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/117457.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32578, 2229, 'A Grande Família S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/117458.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32579, 2229, 'A Grande Família S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/117459.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32580, 2229, 'A Grande Família S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/117460.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32581, 2229, 'A Grande Família S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/117461.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32582, 2229, 'A Grande Família S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/117462.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32583, 2229, 'A Grande Família S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/117463.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32584, 2229, 'A Grande Família S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/117464.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32585, 2229, 'A Grande Família S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/117465.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32586, 2229, 'A Grande Família S12 E23', 'http://sinalprivado.info:80/series/1533784/1533784/117466.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32587, 2229, 'A Grande Família S12 E24', 'http://sinalprivado.info:80/series/1533784/1533784/117467.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32588, 2229, 'A Grande Família S12 E25', 'http://sinalprivado.info:80/series/1533784/1533784/117468.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32589, 2229, 'A Grande Família S12 E26', 'http://sinalprivado.info:80/series/1533784/1533784/117469.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32590, 2229, 'A Grande Família S12 E27', 'http://sinalprivado.info:80/series/1533784/1533784/117470.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32591, 2229, 'A Grande Família S12 E28', 'http://sinalprivado.info:80/series/1533784/1533784/117471.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32592, 2229, 'A Grande Família S12 E29', 'http://sinalprivado.info:80/series/1533784/1533784/117472.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32593, 2229, 'A Grande Família S12 E30', 'http://sinalprivado.info:80/series/1533784/1533784/117473.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32594, 2229, 'A Grande Família S12 E31', 'http://sinalprivado.info:80/series/1533784/1533784/117474.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32595, 2229, 'A Grande Família S12 E32', 'http://sinalprivado.info:80/series/1533784/1533784/117475.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32596, 2229, 'A Grande Família S12 E33', 'http://sinalprivado.info:80/series/1533784/1533784/117476.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32597, 2229, 'A Grande Família S12 E34', 'http://sinalprivado.info:80/series/1533784/1533784/117477.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32598, 2229, 'A Grande Família S12 E35', 'http://sinalprivado.info:80/series/1533784/1533784/117478.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32599, 2229, 'A Grande Família S12 E36', 'http://sinalprivado.info:80/series/1533784/1533784/117479.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32600, 2229, 'A Grande Família S12 E37', 'http://sinalprivado.info:80/series/1533784/1533784/117480.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32601, 2229, 'A Grande Família S12 E38', 'http://sinalprivado.info:80/series/1533784/1533784/117481.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32602, 2230, 'A Grande Família S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/117482.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32603, 2230, 'A Grande Família S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/117483.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32604, 2230, 'A Grande Família S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/117484.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32605, 2230, 'A Grande Família S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/117485.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32606, 2230, 'A Grande Família S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/117486.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32607, 2230, 'A Grande Família S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/117487.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32608, 2230, 'A Grande Família S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/117488.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32609, 2230, 'A Grande Família S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/117489.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32610, 2230, 'A Grande Família S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/117490.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32611, 2230, 'A Grande Família S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/117491.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32612, 2230, 'A Grande Família S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/117492.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32613, 2230, 'A Grande Família S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/117493.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32614, 2230, 'A Grande Família S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/117494.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32615, 2230, 'A Grande Família S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/117495.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32616, 2230, 'A Grande Família S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/117496.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32617, 2230, 'A Grande Família S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/117497.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32618, 2230, 'A Grande Família S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/117498.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32619, 2230, 'A Grande Família S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/117499.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32620, 2230, 'A Grande Família S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/117500.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32621, 2230, 'A Grande Família S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/117501.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32622, 2230, 'A Grande Família S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/117502.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32623, 2230, 'A Grande Família S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/117503.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32624, 2230, 'A Grande Família S13 E23', 'http://sinalprivado.info:80/series/1533784/1533784/117504.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32625, 2230, 'A Grande Família S13 E24', 'http://sinalprivado.info:80/series/1533784/1533784/117505.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32626, 2230, 'A Grande Família S13 E25', 'http://sinalprivado.info:80/series/1533784/1533784/117506.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32627, 2230, 'A Grande Família S13 E26', 'http://sinalprivado.info:80/series/1533784/1533784/117507.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32628, 2231, 'A Grande Família S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/117508.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32629, 2231, 'A Grande Família S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/117509.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32630, 2231, 'A Grande Família S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/117510.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32631, 2231, 'A Grande Família S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/117511.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32632, 2231, 'A Grande Família S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/117512.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32633, 2231, 'A Grande Família S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/117513.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32634, 2231, 'A Grande Família S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/117514.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32635, 2231, 'A Grande Família S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/117515.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32636, 2231, 'A Grande Família S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/117516.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32637, 2231, 'A Grande Família S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/117517.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32638, 2231, 'A Grande Família S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/117518.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32639, 2231, 'A Grande Família S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/117519.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32640, 2231, 'A Grande Família S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/117520.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32641, 2231, 'A Grande Família S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/117521.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32642, 2231, 'A Grande Família S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/117522.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32643, 2231, 'A Grande Família S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/117523.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32644, 2231, 'A Grande Família S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/117524.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32645, 2231, 'A Grande Família S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/117525.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32646, 2231, 'A Grande Família S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/117526.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32647, 2231, 'A Grande Família S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/117527.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32648, 2231, 'A Grande Família S14 E21', 'http://sinalprivado.info:80/series/1533784/1533784/117528.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32649, 2231, 'A Grande Família S14 E22', 'http://sinalprivado.info:80/series/1533784/1533784/117529.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32650, 2231, 'A Grande Família S14 E23', 'http://sinalprivado.info:80/series/1533784/1533784/117530.mp4', 'http://image.tmdb.org/images/yodQvpSyugeYoPyu8MQdFvCYKEi_big.jpg'),
(32651, 2232, 'O Auto da Compadecida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124929.mp4', 'http://timg.bdta.pro/images/8bc25eec2cc5da812705c47856f59d81.jpg'),
(32652, 2232, 'O Auto da Compadecida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124930.mp4', 'http://timg.bdta.pro/images/b513d1f579cfd85623e923e4c8ce62a0.jpg'),
(32653, 2232, 'O Auto da Compadecida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124931.mp4', 'http://timg.bdta.pro/images/d5a29f201b7d598dc753ee6b30831ddd.jpg'),
(32654, 2232, 'O Auto da Compadecida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124932.mp4', 'http://timg.bdta.pro/images/53aa8af6cf2be938196e9649cc5ad12b.jpg'),
(32655, 2233, 'Jovens Bruxas (1998) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129042.mp4', 'http://timg.bdta.pro/images/b9b2003e7e796c980b7c92e445d5c234.jpg'),
(32656, 2233, 'Jovens Bruxas (1998) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129043.mp4', 'http://timg.bdta.pro/images/77794acd5397f6142c155a41c313ec58.jpg'),
(32657, 2233, 'Jovens Bruxas (1998) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129044.mp4', 'http://timg.bdta.pro/images/2ff2e8ef052c72c87d185fa21d43bde2.jpg'),
(32658, 2233, 'Jovens Bruxas (1998) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129045.mp4', 'http://timg.bdta.pro/images/08ec5ce0640292fcccb8ba48097919db.jpg'),
(32659, 2233, 'Jovens Bruxas (1998) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129046.mp4', 'http://timg.bdta.pro/images/de868b05ec30b1898f8aa8332b143946.jpg'),
(32660, 2233, 'Jovens Bruxas (1998) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129047.mp4', 'http://timg.bdta.pro/images/a4584004b9049fe04b4100cfe02c6efd.jpg'),
(32661, 2233, 'Jovens Bruxas (1998) S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129048.mp4', 'http://timg.bdta.pro/images/7b6143f334b484a3bd137039d1a3aadb.jpg'),
(32662, 2233, 'Jovens Bruxas (1998) S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129049.mp4', 'http://timg.bdta.pro/images/cbc84c415e239879f0d0dc6e62d028d5.jpg'),
(32663, 2233, 'Jovens Bruxas (1998) S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129050.mp4', 'http://timg.bdta.pro/images/b08a8338c0e3ce2ba38eea4095c3be66.jpg'),
(32664, 2233, 'Jovens Bruxas (1998) S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129051.mp4', 'http://timg.bdta.pro/images/abbdc05e3f6fa148655f5ee4469e844c.jpg'),
(32665, 2233, 'Jovens Bruxas (1998) S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129052.mp4', 'http://timg.bdta.pro/images/8bcb4db7b65fc4d9ef54e021389caf2e.jpg'),
(32666, 2233, 'Jovens Bruxas (1998) S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129053.mp4', 'http://timg.bdta.pro/images/695ad1a4e8b01dd6f13a522233bd7d14.jpg'),
(32667, 2233, 'Jovens Bruxas (1998) S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129054.mp4', 'http://timg.bdta.pro/images/fe0cf18e003f87adf3f95bb74ec70818.jpg'),
(32668, 2233, 'Jovens Bruxas (1998) S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129055.mp4', 'http://timg.bdta.pro/images/390c5b56c6a94b932c1afded3069cd97.jpg'),
(32669, 2233, 'Jovens Bruxas (1998) S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129056.mp4', 'http://timg.bdta.pro/images/89c5231868c600324c05087fa4e60375.jpg'),
(32670, 2233, 'Jovens Bruxas (1998) S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129057.mp4', 'http://timg.bdta.pro/images/3bc5136f6e0b2b9a9f883abfb28a03a9.jpg'),
(32671, 2233, 'Jovens Bruxas (1998) S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129058.mp4', 'http://timg.bdta.pro/images/97531807c8f9f4227e0bd4e713f4f130.jpg'),
(32672, 2233, 'Jovens Bruxas (1998) S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129059.mp4', 'http://timg.bdta.pro/images/ec786e612c6dfc3e64ac762eb52aef99.jpg'),
(32673, 2233, 'Jovens Bruxas (1998) S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129060.mp4', 'http://timg.bdta.pro/images/16f44e0f0f35b377ab5f3eb205e6af4b.jpg'),
(32674, 2233, 'Jovens Bruxas (1998) S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129061.mp4', 'http://timg.bdta.pro/images/fa4cfa3b17a88fa6670050a699b9b8fe.jpg'),
(32675, 2233, 'Jovens Bruxas (1998) S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129062.mp4', 'http://timg.bdta.pro/images/e73273b07e65f40884b05aca31a7ab89.jpg'),
(32676, 2233, 'Jovens Bruxas (1998) S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129063.mp4', 'http://timg.bdta.pro/images/6618304ac361c849c13fa78b236f4d3a.jpg'),
(32677, 2234, 'Jovens Bruxas (1998) S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129064.mp4', 'http://timg.bdta.pro/images/ca1bd30dd1c4dddcfbd3b9c172411e25.jpg'),
(32678, 2234, 'Jovens Bruxas (1998) S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129065.mp4', 'http://timg.bdta.pro/images/0574549707964792ece8e6e559792a0c.jpg'),
(32679, 2234, 'Jovens Bruxas (1998) S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129066.mp4', 'http://timg.bdta.pro/images/f278d105ceebc3f815f0d7f2670e2789.jpg'),
(32680, 2234, 'Jovens Bruxas (1998) S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129067.mp4', 'http://gstaticontent.com/images/z4bPJ1BWU2EtV69NII2GVvsugQ2_big.jpg'),
(32681, 2234, 'Jovens Bruxas (1998) S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129068.mp4', 'http://timg.bdta.pro/images/f20742d4f0d86b310bb36896fa6b1f3a.jpg'),
(32682, 2234, 'Jovens Bruxas (1998) S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129069.mp4', 'http://timg.bdta.pro/images/f6215264c8dba8044b5e4d14f95800d5.jpg'),
(32683, 2234, 'Jovens Bruxas (1998) S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129070.mp4', 'http://timg.bdta.pro/images/4e6b1a9e09339397727ee0df63dcc544.jpg'),
(32684, 2234, 'Jovens Bruxas (1998) S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129071.mp4', 'http://timg.bdta.pro/images/ecef73ceca9a8b5e1331669ff2b4df34.jpg'),
(32685, 2234, 'Jovens Bruxas (1998) S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129072.mp4', 'http://timg.bdta.pro/images/04811f6497f4d8859bc6bfea7085bbce.jpg'),
(32686, 2234, 'Jovens Bruxas (1998) S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129073.mp4', 'http://timg.bdta.pro/images/15e9742c48dc596479541ff29a955d70.jpg'),
(32687, 2234, 'Jovens Bruxas (1998) S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129074.mp4', 'http://timg.bdta.pro/images/f49397b5e330d705ff2a5ff07c7bce3b.jpg'),
(32688, 2234, 'Jovens Bruxas (1998) S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129075.mp4', 'http://timg.bdta.pro/images/4e385ab374717b9a480f15cb9c463717.jpg'),
(32689, 2234, 'Jovens Bruxas (1998) S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129076.mp4', 'http://timg.bdta.pro/images/f52b0d00fd15472646edc4ddfc3addc2.jpg'),
(32690, 2234, 'Jovens Bruxas (1998) S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129077.mp4', 'http://timg.bdta.pro/images/bfce51bc5ab6fb34fbae195513b29884.jpg'),
(32691, 2234, 'Jovens Bruxas (1998) S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129078.mp4', 'http://timg.bdta.pro/images/f6d756369e156bceae182ae5ba0c07af.jpg'),
(32692, 2234, 'Jovens Bruxas (1998) S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129079.mp4', 'http://timg.bdta.pro/images/6e5a076be6fb38008c17a9424b38509b.jpg'),
(32693, 2234, 'Jovens Bruxas (1998) S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129080.mp4', 'http://timg.bdta.pro/images/c84b8b00ed5aa72d1bf83114e5a9c487.jpg'),
(32694, 2234, 'Jovens Bruxas (1998) S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129081.mp4', 'http://timg.bdta.pro/images/db5f9e3f8ee030e52b6b3f42499102d7.jpg'),
(32695, 2234, 'Jovens Bruxas (1998) S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129082.mp4', 'http://timg.bdta.pro/images/62793554856149c583f5135ac79fb17a.jpg'),
(32696, 2234, 'Jovens Bruxas (1998) S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129083.mp4', 'http://timg.bdta.pro/images/98fe2c1eeab1b40bb23dc67bb7a3ba11.jpg'),
(32697, 2234, 'Jovens Bruxas (1998) S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129084.mp4', 'http://timg.bdta.pro/images/c2573ab299c1415c4fdfaf775d01c7b1.jpg'),
(32698, 2234, 'Jovens Bruxas (1998) S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129085.mp4', 'http://timg.bdta.pro/images/df9ac2690b5c4b871ff4dae273a1af3e.jpg'),
(32699, 2235, 'Jovens Bruxas (1998) S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129086.mp4', 'http://timg.bdta.pro/images/ebb649e17e7012b5ae033f5e5e71e8cb.jpg'),
(32700, 2235, 'Jovens Bruxas (1998) S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129087.mp4', 'http://timg.bdta.pro/images/5c1e3f615683efd48e4647d0eeee2800.jpg'),
(32701, 2235, 'Jovens Bruxas (1998) S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129088.mp4', 'http://timg.bdta.pro/images/6eaba9942a9626ccd885e1196c520126.jpg'),
(32702, 2235, 'Jovens Bruxas (1998) S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129089.mp4', 'http://timg.bdta.pro/images/e2b6333de6e8ab792ad0afed24fd7505.jpg'),
(32703, 2235, 'Jovens Bruxas (1998) S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129090.mp4', 'http://timg.bdta.pro/images/99e672ab41974e926af35c5e90345997.jpg'),
(32704, 2235, 'Jovens Bruxas (1998) S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129091.mp4', 'http://timg.bdta.pro/images/22bc3a44fe697f7e4e464d760ff9b2f0.jpg'),
(32705, 2235, 'Jovens Bruxas (1998) S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129092.mp4', 'http://timg.bdta.pro/images/09a43c49233c1e51f417f0f1ca8e1640.jpg'),
(32706, 2235, 'Jovens Bruxas (1998) S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129093.mp4', 'http://timg.bdta.pro/images/cf31d11b6ee70f898eb2348020fce81f.jpg'),
(32707, 2235, 'Jovens Bruxas (1998) S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129094.mp4', 'http://timg.bdta.pro/images/8c9905870088214fa8f2b6d0b98ebbe9.jpg'),
(32708, 2235, 'Jovens Bruxas (1998) S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129095.mp4', 'http://timg.bdta.pro/images/812e595b0e81a3ccf6e7e58a243cb260.jpg'),
(32709, 2235, 'Jovens Bruxas (1998) S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129096.mp4', 'http://timg.bdta.pro/images/b25581ca34115de21bc17883dd8f1c9e.jpg'),
(32710, 2235, 'Jovens Bruxas (1998) S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129097.mp4', 'http://timg.bdta.pro/images/2edf5a6d5362b8609a45922dd03e8c1d.jpg'),
(32711, 2235, 'Jovens Bruxas (1998) S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129098.mp4', 'http://timg.bdta.pro/images/77426615e3c68c3d5944e229944f8c19.jpg'),
(32712, 2235, 'Jovens Bruxas (1998) S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129099.mp4', 'http://timg.bdta.pro/images/3a8eae8f48f5fc44e8fe16ee2d7afd11.jpg'),
(32713, 2235, 'Jovens Bruxas (1998) S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129100.mp4', 'http://timg.bdta.pro/images/f6b00f9f5ac744025c974959077972c9.jpg'),
(32714, 2235, 'Jovens Bruxas (1998) S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129101.mp4', 'http://timg.bdta.pro/images/c2ca6f7a7a4946e4d34df9c5852b07ad.jpg'),
(32715, 2235, 'Jovens Bruxas (1998) S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129102.mp4', 'http://timg.bdta.pro/images/8ec747d5ce560a7ca37639b581d42504.jpg'),
(32716, 2235, 'Jovens Bruxas (1998) S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129103.mp4', 'http://timg.bdta.pro/images/266bab0b5f0b8355a6a58cc33384aa4b.jpg'),
(32717, 2235, 'Jovens Bruxas (1998) S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129104.mp4', 'http://timg.bdta.pro/images/4e6e2eff37a61f69b5ed4ee87dc8a029.jpg'),
(32718, 2235, 'Jovens Bruxas (1998) S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129105.mp4', 'http://timg.bdta.pro/images/494278abd305c0cdd69c7c3e4c528755.jpg'),
(32719, 2235, 'Jovens Bruxas (1998) S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129106.mp4', 'http://timg.bdta.pro/images/0357f84df38acf7edb4da7fb3b605553.jpg'),
(32720, 2235, 'Jovens Bruxas (1998) S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129107.mp4', 'http://timg.bdta.pro/images/ec5a4f62b49452b4ea6435085a6005f5.jpg'),
(32721, 2236, 'Jovens Bruxas (1998) S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129108.mp4', 'http://timg.bdta.pro/images/ab41c21fcefe8dd104e1ebd448a404fc.jpg'),
(32722, 2236, 'Jovens Bruxas (1998) S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129109.mp4', 'http://timg.bdta.pro/images/22efd38834c169208f71a7558dc3438d.jpg'),
(32723, 2236, 'Jovens Bruxas (1998) S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129110.mp4', 'http://timg.bdta.pro/images/d1ce3ed78c3022fbc12de88517e22163.jpg'),
(32724, 2236, 'Jovens Bruxas (1998) S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129111.mp4', 'http://timg.bdta.pro/images/0ccf8b0ae636fb00bb389610e7df026c.jpg'),
(32725, 2236, 'Jovens Bruxas (1998) S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129112.mp4', 'http://timg.bdta.pro/images/c7b5bf13a82f0ebccdf8d66af0fbd5e3.jpg'),
(32726, 2236, 'Jovens Bruxas (1998) S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129113.mp4', 'http://timg.bdta.pro/images/5544cbb243922e02561bb6024c1189ba.jpg'),
(32727, 2236, 'Jovens Bruxas (1998) S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129114.mp4', 'http://timg.bdta.pro/images/97b13d4d7fca85f3d5896fd6007ae78c.jpg'),
(32728, 2236, 'Jovens Bruxas (1998) S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129115.mp4', 'http://timg.bdta.pro/images/3e2cd5387214258d152511825f615639.jpg'),
(32729, 2236, 'Jovens Bruxas (1998) S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129116.mp4', 'http://timg.bdta.pro/images/979e1f97e324bfb99f1b7e49b49cc68d.jpg'),
(32730, 2236, 'Jovens Bruxas (1998) S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129117.mp4', 'http://timg.bdta.pro/images/2eff4d0077b53a7955fa5624be98cc5c.jpg'),
(32731, 2236, 'Jovens Bruxas (1998) S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129118.mp4', 'http://timg.bdta.pro/images/24ca38a887ab2240bf5660f4960a553a.jpg'),
(32732, 2236, 'Jovens Bruxas (1998) S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129119.mp4', 'http://timg.bdta.pro/images/3f6795c31980d030b63e77d4d0c6a0f2.jpg'),
(32733, 2236, 'Jovens Bruxas (1998) S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129120.mp4', 'http://timg.bdta.pro/images/c42aa88df47b635c8432e1ba74227ae4.jpg'),
(32734, 2236, 'Jovens Bruxas (1998) S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129121.mp4', 'http://timg.bdta.pro/images/67f3e55d385c4d39baa39dc3d28fd66c.jpg'),
(32735, 2236, 'Jovens Bruxas (1998) S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129122.mp4', 'http://timg.bdta.pro/images/0b1a20069bd8a8f5e61e3df2958ecdfc.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(32736, 2236, 'Jovens Bruxas (1998) S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129123.mp4', 'http://timg.bdta.pro/images/99f7ec0c80090c21e6312a2a032d0487.jpg'),
(32737, 2236, 'Jovens Bruxas (1998) S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129124.mp4', 'http://timg.bdta.pro/images/1c9cb94be6612c93876234e55380f7f9.jpg'),
(32738, 2236, 'Jovens Bruxas (1998) S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129125.mp4', 'http://timg.bdta.pro/images/c902a658d18dbbf852c1274069f2b852.jpg'),
(32739, 2236, 'Jovens Bruxas (1998) S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129126.mp4', 'http://timg.bdta.pro/images/9a8289d764c855b24c2e9c30f233f7a7.jpg'),
(32740, 2236, 'Jovens Bruxas (1998) S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129127.mp4', 'http://timg.bdta.pro/images/9b5e75e447bb0abd9af67c59ecb5f40c.jpg'),
(32741, 2236, 'Jovens Bruxas (1998) S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129128.mp4', 'http://timg.bdta.pro/images/37f11a9a8abc12e591943a3ebf1141f2.jpg'),
(32742, 2236, 'Jovens Bruxas (1998) S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129129.mp4', 'http://timg.bdta.pro/images/aef88dcb048068ea54e5ee52042f69ee.jpg'),
(32743, 2237, 'Jovens Bruxas (1998) S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129130.mp4', 'http://timg.bdta.pro/images/856894590e3827ac3e9780a85ea55d24.jpg'),
(32744, 2237, 'Jovens Bruxas (1998) S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129131.mp4', 'http://timg.bdta.pro/images/6ea36cbd8f65007ac174d5e998878bdb.jpg'),
(32745, 2237, 'Jovens Bruxas (1998) S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129132.mp4', 'http://timg.bdta.pro/images/d112a34d69efa8ead6a647605dba0fe2.jpg'),
(32746, 2237, 'Jovens Bruxas (1998) S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129133.mp4', 'http://timg.bdta.pro/images/85f9b56b1e4ab419a3b08fa3a4a16fdd.jpg'),
(32747, 2237, 'Jovens Bruxas (1998) S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129134.mp4', 'http://timg.bdta.pro/images/7a7006f7e86b4e97e6216b19b043dba4.jpg'),
(32748, 2237, 'Jovens Bruxas (1998) S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129135.mp4', 'http://timg.bdta.pro/images/6cdd8a16ebeb98d43a80d621e64423e1.jpg'),
(32749, 2237, 'Jovens Bruxas (1998) S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129136.mp4', 'http://timg.bdta.pro/images/cdda3f9b9e1d1234fd7b359939fbe0b9.jpg'),
(32750, 2237, 'Jovens Bruxas (1998) S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129137.mp4', 'http://timg.bdta.pro/images/1257c3105e29ea496f539e6755cfcd5c.jpg'),
(32751, 2237, 'Jovens Bruxas (1998) S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129138.mp4', 'http://timg.bdta.pro/images/957117385897662868c4a9b37d787469.jpg'),
(32752, 2237, 'Jovens Bruxas (1998) S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129139.mp4', 'http://timg.bdta.pro/images/316222dd206d1f471a16f3adddc43226.jpg'),
(32753, 2237, 'Jovens Bruxas (1998) S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129140.mp4', 'http://timg.bdta.pro/images/fbc692a64400f1c7d4f6e803c72695ce.jpg'),
(32754, 2237, 'Jovens Bruxas (1998) S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129141.mp4', 'http://timg.bdta.pro/images/a457b7c56bb007a7b7bfd354c761ba74.jpg'),
(32755, 2237, 'Jovens Bruxas (1998) S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129142.mp4', 'http://timg.bdta.pro/images/f757594e2fa41b2543e4f48b7cbdfc27.jpg'),
(32756, 2237, 'Jovens Bruxas (1998) S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129143.mp4', 'http://timg.bdta.pro/images/918229a1ccc21e7945e38283bd38981b.jpg'),
(32757, 2237, 'Jovens Bruxas (1998) S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129144.mp4', 'http://timg.bdta.pro/images/421c3baefcee90ce6ab54d648b28c123.jpg'),
(32758, 2237, 'Jovens Bruxas (1998) S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129145.mp4', 'http://timg.bdta.pro/images/9310fa94b360468fac3e3db1ccfbda1a.jpg'),
(32759, 2237, 'Jovens Bruxas (1998) S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129146.mp4', 'http://timg.bdta.pro/images/562f6e828d8591edfecf6c3ebadf558e.jpg'),
(32760, 2237, 'Jovens Bruxas (1998) S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129147.mp4', 'http://timg.bdta.pro/images/cb0e4d4c4f2adfbb99c178597553b247.jpg'),
(32761, 2237, 'Jovens Bruxas (1998) S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129148.mp4', 'http://timg.bdta.pro/images/2d64932f30de5a2dee7744bedc2e2a4b.jpg'),
(32762, 2237, 'Jovens Bruxas (1998) S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129149.mp4', 'http://timg.bdta.pro/images/e02efe6d367ad159c6dc873e38cdc5fe.jpg'),
(32763, 2237, 'Jovens Bruxas (1998) S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129150.mp4', 'http://timg.bdta.pro/images/bbb86332f2b0b3e8b7f0a64e931772e7.jpg'),
(32764, 2237, 'Jovens Bruxas (1998) S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129151.mp4', 'http://timg.bdta.pro/images/0544e4b8fb057d14f52a3f7a212088f2.jpg'),
(32765, 2238, 'Jovens Bruxas (1998) S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129152.mp4', 'http://timg.bdta.pro/images/5e39f0aa1250a505cbb7740b12e6080c.jpg'),
(32766, 2238, 'Jovens Bruxas (1998) S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129153.mp4', 'http://timg.bdta.pro/images/d89ba44f558dcdd1302631f5f21936e2.jpg'),
(32767, 2238, 'Jovens Bruxas (1998) S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129154.mp4', 'http://timg.bdta.pro/images/104d9af8463c7bac445d8e913c814a87.jpg'),
(32768, 2238, 'Jovens Bruxas (1998) S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129155.mp4', 'http://timg.bdta.pro/images/a00c97eddde89e78eb71951bc9187292.jpg'),
(32769, 2238, 'Jovens Bruxas (1998) S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129156.mp4', 'http://timg.bdta.pro/images/21ec9d346f7dcc68781ae4c96b27ef31.jpg'),
(32770, 2238, 'Jovens Bruxas (1998) S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129157.mp4', 'http://timg.bdta.pro/images/b45d91b69ee2d1bf0ddc0702aa6a53cb.jpg'),
(32771, 2238, 'Jovens Bruxas (1998) S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129158.mp4', 'http://timg.bdta.pro/images/74ef3dc4fdfc436d8d59139660205c18.jpg'),
(32772, 2238, 'Jovens Bruxas (1998) S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129159.mp4', 'http://timg.bdta.pro/images/e6babc44ffcd759d80f576874146ef6a.jpg'),
(32773, 2238, 'Jovens Bruxas (1998) S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129160.mp4', 'http://timg.bdta.pro/images/a044ef54dbb6e2804111e5d791f100ed.jpg'),
(32774, 2238, 'Jovens Bruxas (1998) S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129161.mp4', 'http://timg.bdta.pro/images/d2dc2358a81b48b06633f92bfe3e7f1a.jpg'),
(32775, 2238, 'Jovens Bruxas (1998) S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129162.mp4', 'http://timg.bdta.pro/images/bbedca86e2691515a134fec0258eceb8.jpg'),
(32776, 2238, 'Jovens Bruxas (1998) S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129163.mp4', 'http://timg.bdta.pro/images/5d84ee1cb9f4005577211a454e542dd5.jpg'),
(32777, 2238, 'Jovens Bruxas (1998) S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129164.mp4', 'http://timg.bdta.pro/images/fc386ede2ef4e831177457b595d69999.jpg'),
(32778, 2238, 'Jovens Bruxas (1998) S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129165.mp4', 'http://timg.bdta.pro/images/234cebfcab016c334ac573dd3701cd75.jpg'),
(32779, 2238, 'Jovens Bruxas (1998) S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129166.mp4', 'http://timg.bdta.pro/images/3b949e2fb2e55fb886bd242afcc5d342.jpg'),
(32780, 2238, 'Jovens Bruxas (1998) S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129167.mp4', 'http://timg.bdta.pro/images/57ea50a8283a27496a1c7ed6ed387d20.jpg'),
(32781, 2238, 'Jovens Bruxas (1998) S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129168.mp4', 'http://timg.bdta.pro/images/144ad32120f524b1230d756882baee03.jpg'),
(32782, 2238, 'Jovens Bruxas (1998) S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129169.mp4', 'http://timg.bdta.pro/images/80985648f655c3fa002e8dcbbc815a5d.jpg'),
(32783, 2238, 'Jovens Bruxas (1998) S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129170.mp4', 'http://timg.bdta.pro/images/42f5b5ad2430340dc90dde07b7ad05b1.jpg'),
(32784, 2238, 'Jovens Bruxas (1998) S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129171.mp4', 'http://timg.bdta.pro/images/e262dc4568df7e76ebe64e8901cb0262.jpg'),
(32785, 2238, 'Jovens Bruxas (1998) S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129172.mp4', 'http://timg.bdta.pro/images/2f8e3890cf7fc6f48fb6b0b0be62b9cd.jpg'),
(32786, 2238, 'Jovens Bruxas (1998) S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129173.mp4', 'http://timg.bdta.pro/images/696b98e4394762edf40ca06a23570327.jpg'),
(32787, 2238, 'Jovens Bruxas (1998) S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/129174.mp4', 'http://timg.bdta.pro/images/88f36bcdc78944b55a6bca780876b423.jpg'),
(32788, 2239, 'Jovens Bruxas (1998) S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129175.mp4', 'http://timg.bdta.pro/images/adcec8ffdf27ce72db61d1143df9f109.jpg'),
(32789, 2239, 'Jovens Bruxas (1998) S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129176.mp4', 'http://timg.bdta.pro/images/634ea6d92cc38626a0ce6637b80e09a9.jpg'),
(32790, 2239, 'Jovens Bruxas (1998) S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129177.mp4', 'http://timg.bdta.pro/images/d8bf20d2b7854d9db191549f48f2a56b.jpg'),
(32791, 2239, 'Jovens Bruxas (1998) S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129178.mp4', 'http://timg.bdta.pro/images/a5255601d7cfef97eefd414fc395e469.jpg'),
(32792, 2239, 'Jovens Bruxas (1998) S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129179.mp4', 'http://timg.bdta.pro/images/5e320c20e6025d5d439fc6190ed8ab95.jpg'),
(32793, 2239, 'Jovens Bruxas (1998) S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129180.mp4', 'http://timg.bdta.pro/images/5c20cbe52fc87980f38a1e6d459c11e7.jpg'),
(32794, 2239, 'Jovens Bruxas (1998) S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129181.mp4', 'http://timg.bdta.pro/images/77cffc9c2b0d5875ba931fd6d48d9ed3.jpg'),
(32795, 2239, 'Jovens Bruxas (1998) S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129182.mp4', 'http://timg.bdta.pro/images/1274eb8d9e3dc935c2b7fbdb38f90454.jpg'),
(32796, 2239, 'Jovens Bruxas (1998) S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129183.mp4', 'http://timg.bdta.pro/images/37a99a508d08533ac11edc1e244a7d00.jpg'),
(32797, 2239, 'Jovens Bruxas (1998) S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129184.mp4', 'http://timg.bdta.pro/images/c112fd6a23daf40e923583921c41ee0a.jpg'),
(32798, 2239, 'Jovens Bruxas (1998) S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129185.mp4', 'http://timg.bdta.pro/images/b700b44352e38013a98c101840262427.jpg'),
(32799, 2239, 'Jovens Bruxas (1998) S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129186.mp4', 'http://timg.bdta.pro/images/4f8b86aa69f7142f649d0cdeef4d08ff.jpg'),
(32800, 2239, 'Jovens Bruxas (1998) S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129187.mp4', 'http://timg.bdta.pro/images/fe7c0354751a3db664e2dfe9435e662b.jpg'),
(32801, 2239, 'Jovens Bruxas (1998) S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129188.mp4', 'http://timg.bdta.pro/images/6178e5706115d49dbc8c0664a5ce1ffe.jpg'),
(32802, 2239, 'Jovens Bruxas (1998) S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129189.mp4', 'http://timg.bdta.pro/images/b38c22a733e836fe79c6b6d42f3a0d6e.jpg'),
(32803, 2239, 'Jovens Bruxas (1998) S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129190.mp4', 'http://timg.bdta.pro/images/29bd70bea9a6cd8dfdb04fb25acd4772.jpg'),
(32804, 2239, 'Jovens Bruxas (1998) S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129191.mp4', 'http://timg.bdta.pro/images/68adcb641e84f7cccc2a7e845651474d.jpg'),
(32805, 2239, 'Jovens Bruxas (1998) S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129192.mp4', 'http://timg.bdta.pro/images/164d90b4d436e981727bc20e4a7a9b52.jpg'),
(32806, 2239, 'Jovens Bruxas (1998) S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129193.mp4', 'http://timg.bdta.pro/images/c6b1569a6a0b62e643b33db390695593.jpg'),
(32807, 2239, 'Jovens Bruxas (1998) S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129194.mp4', 'http://timg.bdta.pro/images/da8dc111f88d7ebd49777719285ad031.jpg'),
(32808, 2239, 'Jovens Bruxas (1998) S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129195.mp4', 'http://timg.bdta.pro/images/daf87fe6928d17217b819ea5bff0657d.jpg'),
(32809, 2239, 'Jovens Bruxas (1998) S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129196.mp4', 'http://timg.bdta.pro/images/14477b6a4ee1265936ae0ed7d481ced7.jpg'),
(32810, 2240, 'Jovens Bruxas (1998) S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129197.mp4', 'http://timg.bdta.pro/images/b3d31977597f563d6c45d90d55ae4506.jpg'),
(32811, 2240, 'Jovens Bruxas (1998) S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129198.mp4', 'http://timg.bdta.pro/images/fcc1210331687baf46200e2becd49bca.jpg'),
(32812, 2240, 'Jovens Bruxas (1998) S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129199.mp4', 'http://timg.bdta.pro/images/56f51d086f78315f52c009346b93b452.jpg'),
(32813, 2240, 'Jovens Bruxas (1998) S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129200.mp4', 'http://timg.bdta.pro/images/0455a9e4d9dca01b3a11e03dde1a63a4.jpg'),
(32814, 2240, 'Jovens Bruxas (1998) S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129201.mp4', 'http://timg.bdta.pro/images/060f2c5e48f9bdb5180d8c1922e09040.jpg'),
(32815, 2240, 'Jovens Bruxas (1998) S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129202.mp4', 'http://timg.bdta.pro/images/94b96e0306d788657f138102776ba314.jpg'),
(32816, 2240, 'Jovens Bruxas (1998) S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129203.mp4', 'http://timg.bdta.pro/images/d2330a926f7089de2bee8dc8e2f341f1.jpg'),
(32817, 2240, 'Jovens Bruxas (1998) S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129204.mp4', 'http://timg.bdta.pro/images/f41c24d6989eeb451d6520496f38df4c.jpg'),
(32818, 2240, 'Jovens Bruxas (1998) S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129205.mp4', 'http://timg.bdta.pro/images/ce0110adcea9654fc3d68154b46eacc8.jpg'),
(32819, 2240, 'Jovens Bruxas (1998) S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129206.mp4', 'http://timg.bdta.pro/images/3e97aea6f43e561b9cebabf8fcad120f.jpg'),
(32820, 2240, 'Jovens Bruxas (1998) S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129207.mp4', 'http://timg.bdta.pro/images/52b8aef6d402dd32d370a21cb90d3d9c.jpg'),
(32821, 2240, 'Jovens Bruxas (1998) S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129208.mp4', 'http://timg.bdta.pro/images/82fb631e0f03a9e911c9d06013b3ff4a.jpg'),
(32822, 2240, 'Jovens Bruxas (1998) S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129209.mp4', 'http://timg.bdta.pro/images/c5128e0cf6bfb3f1137e584843164033.jpg'),
(32823, 2240, 'Jovens Bruxas (1998) S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129210.mp4', 'http://timg.bdta.pro/images/e29a0a6de8a1feb99f11c3593430754c.jpg'),
(32824, 2240, 'Jovens Bruxas (1998) S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129211.mp4', 'http://timg.bdta.pro/images/e0cf29fd9ef76c053620bdb062257d6b.jpg'),
(32825, 2240, 'Jovens Bruxas (1998) S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129212.mp4', 'http://timg.bdta.pro/images/3f0f4992006a9fda013b3e77d497e21b.jpg'),
(32826, 2240, 'Jovens Bruxas (1998) S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129213.mp4', 'http://timg.bdta.pro/images/11e4faeec9617bd7de5906b6cacbc4b2.jpg'),
(32827, 2240, 'Jovens Bruxas (1998) S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129214.mp4', 'http://timg.bdta.pro/images/b875d130bc82a409e4f92c68fde61fe1.jpg'),
(32828, 2240, 'Jovens Bruxas (1998) S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129215.mp4', 'http://timg.bdta.pro/images/71d9587b39381d42753b9ee627611407.jpg'),
(32829, 2240, 'Jovens Bruxas (1998) S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129216.mp4', 'http://timg.bdta.pro/images/197f61d476fbc5c54fe0c496d62bf68c.jpg'),
(32830, 2240, 'Jovens Bruxas (1998) S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129217.mp4', 'http://timg.bdta.pro/images/fe94c5b3d71df6319c32dd443eaf7960.jpg'),
(32831, 2240, 'Jovens Bruxas (1998) S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129218.mp4', 'http://timg.bdta.pro/images/2d8a22b22e10e89e9af2f158779cf5cd.jpg'),
(32832, 2241, 'Sandy & Junior: A História S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124922.mp4', 'http://timg.bdta.pro/images/d63ac76ae8661f070b69ed93db4c45c3.jpg'),
(32833, 2241, 'Sandy & Junior: A História S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124923.mp4', 'http://timg.bdta.pro/images/ba36de27b2912e2f4eac78a40cc9600e.jpg'),
(32834, 2241, 'Sandy & Junior: A História S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124924.mp4', 'http://timg.bdta.pro/images/3a098b965f43d2bd4a396370041a6c76.jpg'),
(32835, 2241, 'Sandy & Junior: A História S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124925.mp4', 'http://timg.bdta.pro/images/07b2abc9106564dedf9058bd7a28ea68.jpg'),
(32836, 2241, 'Sandy & Junior: A História S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124926.mp4', 'http://timg.bdta.pro/images/c2247bb431399cd1f3999f16cff9ffb8.jpg'),
(32837, 2241, 'Sandy & Junior: A História S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124927.mp4', 'http://timg.bdta.pro/images/f34c2b001226f5f8988cf8d380ae5057.jpg'),
(32838, 2241, 'Sandy & Junior: A História S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124928.mp4', 'http://timg.bdta.pro/images/f1edbe564b62422c63e05aa6e2a9cbfa.jpg'),
(32839, 2242, 'A Paixão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124916.mp4', 'http://gstaticontent.com/images/A8W2bFdSJLeZWAFNHz37m8mFTJd_big.jpg'),
(32840, 2242, 'A Paixão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124917.mp4', 'http://gstaticontent.com/images/A8W2bFdSJLeZWAFNHz37m8mFTJd_big.jpg'),
(32841, 2242, 'A Paixão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124918.mp4', 'http://gstaticontent.com/images/A8W2bFdSJLeZWAFNHz37m8mFTJd_big.jpg'),
(32842, 2242, 'A Paixão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124919.mp4', 'http://gstaticontent.com/images/A8W2bFdSJLeZWAFNHz37m8mFTJd_big.jpg'),
(32843, 2242, 'A Paixão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124920.mp4', 'http://gstaticontent.com/images/A8W2bFdSJLeZWAFNHz37m8mFTJd_big.jpg'),
(32844, 2242, 'A Paixão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124921.mp4', 'http://gstaticontent.com/images/A8W2bFdSJLeZWAFNHz37m8mFTJd_big.jpg'),
(32845, 2243, 'Curta Essa com Zac Efron S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201695.mp4', 'http://timg.bdta.pro/images/f9e784fabb3b122e854be7c35f1a5a25.jpg'),
(32846, 2243, 'Curta Essa com Zac Efron S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201696.mp4', 'http://timg.bdta.pro/images/35c52785c05449cba1d251840d47f50e.jpg'),
(32847, 2243, 'Curta Essa com Zac Efron S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201697.mp4', 'http://timg.bdta.pro/images/ebd4d4dee68f4243aed1631fb4a7d27b.jpg'),
(32848, 2243, 'Curta Essa com Zac Efron S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201698.mp4', 'http://timg.bdta.pro/images/b0b6e222bff1d7d8e7840be9799839bc.jpg'),
(32849, 2243, 'Curta Essa com Zac Efron S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201699.mp4', 'http://timg.bdta.pro/images/0fe15cd5dc4f220df6ae7452df4fd802.jpg'),
(32850, 2243, 'Curta Essa com Zac Efron S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201700.mp4', 'http://timg.bdta.pro/images/00079456352467da6fb3a47815ba7f86.jpg'),
(32851, 2243, 'Curta Essa com Zac Efron S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201701.mp4', 'http://timg.bdta.pro/images/cf85ddc95963c9213c1f9e397e5b0d7c.jpg'),
(32852, 2243, 'Curta Essa com Zac Efron S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201702.mp4', 'http://timg.bdta.pro/images/2ee8d8b14cfe0c3c438803577653c7b6.jpg'),
(32853, 2244, 'Curta Essa com Zac Efron S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201703.mp4', 'http://gstaticontent.com/images/eGGHsfDkZXek0qGJ1wsuoVzHEOh_big.jpg'),
(32854, 2244, 'Curta Essa com Zac Efron S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201704.mp4', 'http://gstaticontent.com/images/eGGHsfDkZXek0qGJ1wsuoVzHEOh_big.jpg'),
(32855, 2244, 'Curta Essa com Zac Efron S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201705.mp4', 'http://gstaticontent.com/images/eGGHsfDkZXek0qGJ1wsuoVzHEOh_big.jpg'),
(32856, 2244, 'Curta Essa com Zac Efron S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201706.mp4', 'http://gstaticontent.com/images/eGGHsfDkZXek0qGJ1wsuoVzHEOh_big.jpg'),
(32857, 2244, 'Curta Essa com Zac Efron S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201707.mp4', 'http://gstaticontent.com/images/eGGHsfDkZXek0qGJ1wsuoVzHEOh_big.jpg'),
(32858, 2244, 'Curta Essa com Zac Efron S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201708.mp4', 'http://gstaticontent.com/images/eGGHsfDkZXek0qGJ1wsuoVzHEOh_big.jpg'),
(32859, 2244, 'Curta Essa com Zac Efron S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201709.mp4', 'http://gstaticontent.com/images/eGGHsfDkZXek0qGJ1wsuoVzHEOh_big.jpg'),
(32860, 2244, 'Curta Essa com Zac Efron S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201710.mp4', 'http://gstaticontent.com/images/eGGHsfDkZXek0qGJ1wsuoVzHEOh_big.jpg'),
(32861, 2245, 'Doze Jurados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124906.mp4', 'http://timg.bdta.pro/images/97c333f9b3fb4dd98b2e8ab00cde4eeb.jpg'),
(32862, 2245, 'Doze Jurados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124907.mp4', 'http://timg.bdta.pro/images/8b6fbaed28cbd40bf2a5af4d28a25858.jpg'),
(32863, 2245, 'Doze Jurados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124908.mp4', 'http://timg.bdta.pro/images/0b30d6056a82e7da73df9ff4d8b89d1b.jpg'),
(32864, 2245, 'Doze Jurados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124909.mp4', 'http://timg.bdta.pro/images/9204853543189d9c1f6dbcfd890d2ece.jpg'),
(32865, 2245, 'Doze Jurados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124910.mp4', 'http://timg.bdta.pro/images/7b431283095daa5531439724f40ee527.jpg'),
(32866, 2245, 'Doze Jurados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124911.mp4', 'http://timg.bdta.pro/images/9c9bf9dddac2f42e956900ea9ad969fd.jpg'),
(32867, 2245, 'Doze Jurados S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124912.mp4', 'http://timg.bdta.pro/images/1a14f26554952e593071c74417bda330.jpg'),
(32868, 2245, 'Doze Jurados S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124913.mp4', 'http://timg.bdta.pro/images/f2512c0e29cc93e47126e12118af6245.jpg'),
(32869, 2245, 'Doze Jurados S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124914.mp4', 'http://timg.bdta.pro/images/32d2cbc2faa48cdd328ad12f21a71279.jpg'),
(32870, 2245, 'Doze Jurados S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124915.mp4', 'http://timg.bdta.pro/images/15098dca2dc430d99906e42ece5cf17b.jpg'),
(32871, 2246, 'Drogas Oferta e Demanda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124900.mp4', 'http://timg.bdta.pro/images/ac7c4d85d9b7e5d1d311f824874ee645.jpg'),
(32872, 2246, 'Drogas Oferta e Demanda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124901.mp4', 'http://timg.bdta.pro/images/6ebc7afe155fdbb4c1f735c4832974b1.jpg'),
(32873, 2246, 'Drogas Oferta e Demanda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124902.mp4', 'http://timg.bdta.pro/images/ee1cadb9d6fa65aca550d413790f38e2.jpg'),
(32874, 2246, 'Drogas Oferta e Demanda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124903.mp4', 'http://timg.bdta.pro/images/87275eef3da5bb0eff63e06e98527f29.jpg'),
(32875, 2246, 'Drogas Oferta e Demanda S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124904.mp4', 'http://timg.bdta.pro/images/bca83a94af3da18dc60b4367e4f2b2a8.jpg'),
(32876, 2246, 'Drogas Oferta e Demanda S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124905.mp4', 'http://timg.bdta.pro/images/3ddebd19af209d02ad2889dcf29480e0.jpg'),
(32877, 2247, 'Harrow [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144363.mp4', 'http://timg.bdta.pro/images/38406d328e59708cdeb26aa2968f9c1e.jpg'),
(32878, 2247, 'Harrow [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144364.mp4', 'http://timg.bdta.pro/images/00c36be8aecc188e677024705cfdcdb9.jpg'),
(32879, 2247, 'Harrow [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144365.mp4', 'http://timg.bdta.pro/images/5a39bbb9c157080453c3d8bf40f22c65.jpg'),
(32880, 2247, 'Harrow [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144366.mp4', 'http://timg.bdta.pro/images/c54e85a6e45c32166a6c518c2a574afd.jpg'),
(32881, 2247, 'Harrow [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144367.mp4', 'http://timg.bdta.pro/images/b743bf40b34187762b6f9549b55848d1.jpg'),
(32882, 2247, 'Harrow [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144368.mp4', 'http://timg.bdta.pro/images/0761420c960ca1c24d01f6c194d127e4.jpg'),
(32883, 2247, 'Harrow [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144369.mp4', 'http://timg.bdta.pro/images/9ab2e632bbbdbf0de33b201574e27352.jpg'),
(32884, 2247, 'Harrow [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144370.mp4', 'http://timg.bdta.pro/images/1c8165f99aa7532c649553883d2b50f9.jpg'),
(32885, 2247, 'Harrow [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144371.mp4', 'http://timg.bdta.pro/images/fd97e6a464dfe9bceda7ba220ed9c227.jpg'),
(32886, 2247, 'Harrow [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144372.mp4', 'http://timg.bdta.pro/images/ef244e8a9cd9ea5a26d6648b1454e9ec.jpg'),
(32887, 2248, 'Harrow [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144373.mp4', 'http://timg.bdta.pro/images/3fd3121c91c136d16dfb6b3c68df4d4e.jpg'),
(32888, 2248, 'Harrow [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144374.mp4', 'http://timg.bdta.pro/images/d412d08216b2a88f9e63e050456cad8c.jpg'),
(32889, 2248, 'Harrow [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144375.mp4', 'http://timg.bdta.pro/images/494f36d1275222707e1e8b5400e644fb.jpg'),
(32890, 2248, 'Harrow [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144376.mp4', 'http://timg.bdta.pro/images/4cd7d6185e960978bd64a8e48b37a823.jpg'),
(32891, 2248, 'Harrow [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144377.mp4', 'http://timg.bdta.pro/images/410489fe31978275561722e9311db5fe.jpg'),
(32892, 2248, 'Harrow [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144378.mp4', 'http://timg.bdta.pro/images/e04715ffbc3a0783da5def5506773f40.jpg'),
(32893, 2248, 'Harrow [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144379.mp4', 'http://timg.bdta.pro/images/95873eb8a43f80e77f52d1ae965c5757.jpg'),
(32894, 2248, 'Harrow [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144380.mp4', 'http://timg.bdta.pro/images/7e14d29cef17cd142cf999ea1282ec26.jpg'),
(32895, 2248, 'Harrow [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144381.mp4', 'http://timg.bdta.pro/images/d0dbaf32537a051fa6dac54b899d92d6.jpg'),
(32896, 2248, 'Harrow [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144382.mp4', 'http://timg.bdta.pro/images/ab46330b47752d4292bcab61877b91e3.jpg'),
(32897, 2249, 'Harrow [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144383.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(32898, 2249, 'Harrow [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144384.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(32899, 2249, 'Harrow [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144385.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(32900, 2249, 'Harrow [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144386.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(32901, 2249, 'Harrow [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144387.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(32902, 2249, 'Harrow [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144388.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(32903, 2249, 'Harrow [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144389.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(32904, 2249, 'Harrow [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144390.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(32905, 2249, 'Harrow [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144391.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(32906, 2249, 'Harrow [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144392.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(32907, 2250, 'Inexplicável: com William Shatner S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124891.mp4', 'http://timg.bdta.pro/images/9f3fa74c76270725037d537218adbc89.jpg'),
(32908, 2250, 'Inexplicável: com William Shatner S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124892.mp4', 'http://timg.bdta.pro/images/9b5c0b0f9e5f5766619993d6fb0d350f.jpg'),
(32909, 2250, 'Inexplicável: com William Shatner S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124893.mp4', 'http://timg.bdta.pro/images/1bd2a1f4929e8f874281361ab97bcf3b.jpg'),
(32910, 2250, 'Inexplicável: com William Shatner S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124894.mp4', 'http://timg.bdta.pro/images/2153918fcd4938b37efd27e18ebfb9e8.jpg'),
(32911, 2250, 'Inexplicável: com William Shatner S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124895.mp4', 'http://timg.bdta.pro/images/654647e608aa3eefa44eecfe08ac9219.jpg'),
(32912, 2250, 'Inexplicável: com William Shatner S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124896.mp4', 'http://timg.bdta.pro/images/2e106e5417c703fae70dc05498ac276e.jpg'),
(32913, 2250, 'Inexplicável: com William Shatner S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124897.mp4', 'http://timg.bdta.pro/images/e44b20b0b3f61c6659f0707807845156.jpg'),
(32914, 2250, 'Inexplicável: com William Shatner S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124898.mp4', 'http://timg.bdta.pro/images/84e8625519b380fe8a41eb82dffe307c.jpg'),
(32915, 2251, 'Inexplicável: com William Shatner S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124899.mp4', 'http://timg.bdta.pro/images/6937e1e685762271e0bd83ead4570974.jpg'),
(32916, 2251, 'Inexplicável: com William Shatner S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449335.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7rI4W3ZGxq6OJVRvzDo5WB0yW8Z.jpg'),
(32917, 2251, 'Inexplicável: com William Shatner S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449336.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wluE7ZueYuj9ASkqXhUwrEatYPC.jpg'),
(32918, 2251, 'Inexplicável: com William Shatner S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449337.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sLZLIUtYGhoOJwJ2RxKYiAiHf6H.jpg'),
(32919, 2251, 'Inexplicável: com William Shatner S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449338.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7HkZl9hWHjZApzof6FwEeDIf5dB.jpg'),
(32920, 2251, 'Inexplicável: com William Shatner S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449339.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/olvwkGRg0onB2tArFSahkO9HsMz.jpg'),
(32921, 2251, 'Inexplicável: com William Shatner S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449340.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p6K3doCW5cXT0ns1KJKNkXXpUXH.jpg'),
(32922, 2251, 'Inexplicável: com William Shatner S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449341.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sMP5ZiZ2bi8dT42Z8T0EnffulgU.jpg'),
(32923, 2251, 'Inexplicável: com William Shatner S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449342.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t7Lb2ze4JzSFNYGBOxW5oCj4twc.jpg'),
(32924, 2251, 'Inexplicável: com William Shatner S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/449343.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pEKiXyLswtgCxUiQ9lILBWAKLwP.jpg'),
(32925, 2251, 'Inexplicável: com William Shatner S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/449344.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z8JGRZVJgoCDq4IEGj3Hmjirhtb.jpg'),
(32926, 2251, 'Inexplicável: com William Shatner S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/449345.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4GkHKXEPNFXzA7mwcvXoYLQgtLy.jpg'),
(32927, 2251, 'Inexplicável: com William Shatner S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/449346.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7C9JNp2CVB0aK84zIHm9oAZ6vah.jpg'),
(32928, 2251, 'Inexplicável: com William Shatner S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/449347.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1IdkZ2EKVgOn3KvVIfcNGvfZaj2.jpg'),
(32929, 2251, 'Inexplicável: com William Shatner S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/449348.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8p25TzNkwTAkVFcTiE4NVB6ufAd.jpg'),
(32930, 2251, 'Inexplicável: com William Shatner S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/449349.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/34FbNgQCQjPloOhEs9ZBowZ1om6.jpg'),
(32931, 2251, 'Inexplicável: com William Shatner S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/449350.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/26skEJ7cOVtCkqQNUsdyw6mrWL3.jpg'),
(32932, 2251, 'Inexplicável: com William Shatner S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/449351.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qiLBrBnDeb7SpqbfqIRX81udv1y.jpg'),
(32933, 2252, 'Little Voice S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130231.mp4', 'http://timg.bdta.pro/images/52d0899381e89f741230833963989d88.jpg'),
(32934, 2252, 'Little Voice S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130232.mp4', 'http://timg.bdta.pro/images/edb6a7a7bc3503ec7fddc5d3bfe723fc.jpg'),
(32935, 2252, 'Little Voice S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130233.mp4', 'http://timg.bdta.pro/images/02c34763a4f604097bc6b40b49f67afe.jpg'),
(32936, 2252, 'Little Voice S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130234.mp4', 'http://timg.bdta.pro/images/e82d27e5e791ae52e0db8f66063d0700.jpg'),
(32937, 2252, 'Little Voice S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130235.mp4', 'http://timg.bdta.pro/images/d52853f14f89c3358d62f3275bfbf550.jpg'),
(32938, 2252, 'Little Voice S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130236.mp4', 'http://timg.bdta.pro/images/f3b7848f61239aa0e351ee39134debe1.jpg'),
(32939, 2252, 'Little Voice S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130237.mp4', 'http://timg.bdta.pro/images/5f24fa46eebcb2987001fd5a3a6d5906.jpg'),
(32940, 2252, 'Little Voice S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130238.mp4', 'http://timg.bdta.pro/images/d0db767e900dd4800c2c49f321c46f49.jpg'),
(32941, 2252, 'Little Voice S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130239.mp4', 'http://timg.bdta.pro/images/614bc95ee1e653eb8743eae30582078f.jpg'),
(32942, 2253, 'Mom S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161167.mp4', 'http://timg.bdta.pro/images/9917ab83e9262f4c4afd31b82b0a954a.jpg'),
(32943, 2253, 'Mom S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161168.mp4', 'http://timg.bdta.pro/images/7e60fd045ebdcbd6da9b8d231f7719e1.jpg'),
(32944, 2253, 'Mom S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161169.mp4', 'http://timg.bdta.pro/images/97a4a37b99caae9f22a2538219ada90e.jpg'),
(32945, 2253, 'Mom S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161170.mp4', 'http://timg.bdta.pro/images/67a7855b7892f38faa03338d2a64233d.jpg'),
(32946, 2253, 'Mom S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161171.mp4', 'http://timg.bdta.pro/images/aa735efe53558a222d9f52d4aa4e26a5.jpg'),
(32947, 2253, 'Mom S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161172.mp4', 'http://timg.bdta.pro/images/96c1dcd049b7622f86fbf43122690cc2.jpg'),
(32948, 2253, 'Mom S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161173.mp4', 'http://timg.bdta.pro/images/9ddf379c6842aff9f0a92750678d8310.jpg'),
(32949, 2253, 'Mom S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161174.mp4', 'http://timg.bdta.pro/images/44961411ae94f3e8a4d000fe6c865a53.jpg'),
(32950, 2253, 'Mom S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161175.mp4', 'http://timg.bdta.pro/images/a5233f3780f5b6df84167dd70585e4f2.jpg'),
(32951, 2253, 'Mom S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161176.mp4', 'http://timg.bdta.pro/images/3ba4d9c13046e49c25cc2c3e005e0830.jpg'),
(32952, 2253, 'Mom S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161177.mp4', 'http://timg.bdta.pro/images/28ed6fb49d8f9633f13c0717b49025fb.jpg'),
(32953, 2253, 'Mom S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161178.mp4', 'http://timg.bdta.pro/images/a1f6445e1eebaf9e5fed020d7c59381a.jpg'),
(32954, 2253, 'Mom S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161179.mp4', 'http://timg.bdta.pro/images/7c8143d24fc82225b74eafc896246844.jpg'),
(32955, 2253, 'Mom S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161180.mp4', 'http://timg.bdta.pro/images/be5c37cf3aebf8d92a1e070e4fe99e7f.jpg'),
(32956, 2253, 'Mom S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161181.mp4', 'http://timg.bdta.pro/images/23f3579151fa710eb6744c82559da8a2.jpg'),
(32957, 2253, 'Mom S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161182.mp4', 'http://timg.bdta.pro/images/63fb948b443f013dc1b49cc0d3d245cc.jpg'),
(32958, 2253, 'Mom S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161183.mp4', 'http://timg.bdta.pro/images/46857b959e1740fcebeab8f6bc23e54e.jpg'),
(32959, 2253, 'Mom S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161184.mp4', 'http://timg.bdta.pro/images/a537684247c1970eefb864f54858e5c7.jpg'),
(32960, 2253, 'Mom S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/161185.mp4', 'http://timg.bdta.pro/images/ba2995a1b1137bc1d01fa20ba070148b.jpg'),
(32961, 2253, 'Mom S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/161186.mp4', 'http://timg.bdta.pro/images/9816c42e0cf2d940f0636674e05c92a1.jpg'),
(32962, 2253, 'Mom S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/161187.mp4', 'http://timg.bdta.pro/images/e8db9a7eea84c815bb5876bbfb256e29.jpg'),
(32963, 2253, 'Mom S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/161188.mp4', 'http://timg.bdta.pro/images/1a9dc83592b9656ddbeb2501449335f6.jpg'),
(32964, 2254, 'Mom S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161189.mp4', 'http://timg.bdta.pro/images/4070e5214a486f8924812e8a7841513f.jpg'),
(32965, 2254, 'Mom S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161190.mp4', 'http://timg.bdta.pro/images/59c00ff67a2b5fab894058d8b3ff8424.jpg'),
(32966, 2254, 'Mom S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161191.mp4', 'http://timg.bdta.pro/images/37d1467f5b57e2a53aaee656fe7bbcf4.jpg'),
(32967, 2254, 'Mom S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161192.mp4', 'http://timg.bdta.pro/images/ead426e8919a91aac03537c0004100c6.jpg'),
(32968, 2254, 'Mom S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161193.mp4', 'http://timg.bdta.pro/images/a3e643c4a5e4b7623d030dc9cc140208.jpg'),
(32969, 2254, 'Mom S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161194.mp4', 'http://timg.bdta.pro/images/29043ef1df2d1a30b8501c655e0812cd.jpg'),
(32970, 2254, 'Mom S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161195.mp4', 'http://timg.bdta.pro/images/ccb12a5c4e8c351a45279f48c0ffa1fa.jpg'),
(32971, 2254, 'Mom S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161196.mp4', 'http://timg.bdta.pro/images/6abc2f64e73e73d52243b33359d0fded.jpg'),
(32972, 2254, 'Mom S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161197.mp4', 'http://timg.bdta.pro/images/ab3c13437a1f42f6342437ead8acc43d.jpg'),
(32973, 2254, 'Mom S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161198.mp4', 'http://timg.bdta.pro/images/87355597c5fe78540cc030d898bbcd65.jpg'),
(32974, 2254, 'Mom S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161199.mp4', 'http://timg.bdta.pro/images/c2525aa6bb42d3f0809ad6ff2e3052b6.jpg'),
(32975, 2254, 'Mom S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161200.mp4', 'http://timg.bdta.pro/images/1e9518b364dc35688e18889e57e4697b.jpg'),
(32976, 2254, 'Mom S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161201.mp4', 'http://timg.bdta.pro/images/68499ba6ea6e0ebfbe26bbe15981cbe7.jpg'),
(32977, 2254, 'Mom S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161202.mp4', 'http://timg.bdta.pro/images/16d60446bafd6e08d3c4a7cbb14a6370.jpg'),
(32978, 2254, 'Mom S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161203.mp4', 'http://timg.bdta.pro/images/4ad102d8080d26fee297f54795e9ece0.jpg'),
(32979, 2254, 'Mom S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161204.mp4', 'http://timg.bdta.pro/images/7ffa12db65c513e4e5342a3bce59d8a7.jpg'),
(32980, 2254, 'Mom S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161205.mp4', 'http://timg.bdta.pro/images/bea8271830fe8ba43861c2439591803f.jpg'),
(32981, 2254, 'Mom S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161206.mp4', 'http://timg.bdta.pro/images/7bce91e938f319b1e2a2a297af81fe31.jpg'),
(32982, 2254, 'Mom S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/161207.mp4', 'http://timg.bdta.pro/images/1f7909e9f0232dcf004eff0b3f695923.jpg'),
(32983, 2254, 'Mom S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/161208.mp4', 'http://timg.bdta.pro/images/0f633b530d9c88f78fbebc14b7ad65ec.jpg'),
(32984, 2254, 'Mom S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/161209.mp4', 'http://timg.bdta.pro/images/22a7e721f725195ef1ab7b60e8b6ba79.jpg'),
(32985, 2254, 'Mom S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/161210.mp4', 'http://timg.bdta.pro/images/68feff734e2ad59a9ae0bb1079d2bdc9.jpg'),
(32986, 2255, 'Mom S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161211.mp4', 'http://timg.bdta.pro/images/19e335ec965cdd4a3edf0acac34bbec4.jpg'),
(32987, 2255, 'Mom S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161212.mp4', 'http://timg.bdta.pro/images/d935eeff700e460cd9f617e738877c57.jpg'),
(32988, 2255, 'Mom S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161213.mp4', 'http://timg.bdta.pro/images/c92c029b49ec4cb7c760c46d629641e1.jpg'),
(32989, 2255, 'Mom S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161214.mp4', 'http://timg.bdta.pro/images/be16d9f20ad0f82fb59d36dd29a34078.jpg'),
(32990, 2255, 'Mom S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161215.mp4', 'http://timg.bdta.pro/images/ad729d7f21e312c41953b6c670cb3f00.jpg'),
(32991, 2255, 'Mom S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161216.mp4', 'http://timg.bdta.pro/images/d824f6b8aa58979b4db2adcf4c34d469.jpg'),
(32992, 2255, 'Mom S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161217.mp4', 'http://timg.bdta.pro/images/019064f34e6754b30c0f6ed0f44ad514.jpg'),
(32993, 2255, 'Mom S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161218.mp4', 'http://timg.bdta.pro/images/45248023e4dd1f5b447625f6209950fe.jpg'),
(32994, 2255, 'Mom S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161219.mp4', 'http://timg.bdta.pro/images/6bc1a47f5d920e9b340bfad05206081c.jpg'),
(32995, 2255, 'Mom S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161220.mp4', 'http://timg.bdta.pro/images/3ceb78c76181aadb01949bb5dda311f7.jpg'),
(32996, 2255, 'Mom S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161221.mp4', 'http://timg.bdta.pro/images/2e223cbf217ef379fed480bbc99910bc.jpg'),
(32997, 2255, 'Mom S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161222.mp4', 'http://timg.bdta.pro/images/fef13596bdd84ac27724ead3e57f2cde.jpg'),
(32998, 2255, 'Mom S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161223.mp4', 'http://timg.bdta.pro/images/12ad50c14d0db3ddfa872c535b7547a4.jpg'),
(32999, 2255, 'Mom S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161224.mp4', 'http://timg.bdta.pro/images/7c5e057a7749c974f0c3c75e06b16fb0.jpg'),
(33000, 2255, 'Mom S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161225.mp4', 'http://timg.bdta.pro/images/d052a5217d7f09e99b95137545ed1e9e.jpg'),
(33001, 2255, 'Mom S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161226.mp4', 'http://timg.bdta.pro/images/93cd61d2d10a40a6293246c2d672d859.jpg'),
(33002, 2255, 'Mom S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161227.mp4', 'http://timg.bdta.pro/images/d1d317835610280089a3094f28944e8c.jpg'),
(33003, 2255, 'Mom S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161228.mp4', 'http://timg.bdta.pro/images/d7ea6373d25af60789746c617e61e356.jpg'),
(33004, 2255, 'Mom S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/161229.mp4', 'http://timg.bdta.pro/images/cd740d501f032f6442e9222208f5d964.jpg'),
(33005, 2255, 'Mom S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/161230.mp4', 'http://timg.bdta.pro/images/00df41b2e838df8ee58ebf86991e866c.jpg'),
(33006, 2255, 'Mom S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/161231.mp4', 'http://timg.bdta.pro/images/33ede565ca23dd9b1989f13b9c55e383.jpg'),
(33007, 2255, 'Mom S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/161232.mp4', 'http://timg.bdta.pro/images/07290d2c29aa3612114cd074061aca25.jpg'),
(33008, 2256, 'Mom S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161233.mp4', 'http://timg.bdta.pro/images/fb5947cce73ebd32fc967690932d0e37.jpg'),
(33009, 2256, 'Mom S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161234.mp4', 'http://timg.bdta.pro/images/0e97d788828e4f6daf5685aa4cb015a6.jpg'),
(33010, 2256, 'Mom S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161235.mp4', 'http://timg.bdta.pro/images/9af80b39062bab891db98889bf2e64b8.jpg'),
(33011, 2256, 'Mom S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161236.mp4', 'http://timg.bdta.pro/images/1c19c14396901979c861499b7bd72374.jpg'),
(33012, 2256, 'Mom S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161237.mp4', 'http://timg.bdta.pro/images/47471be7a457d2d2ffc7e9639a75903d.jpg'),
(33013, 2256, 'Mom S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161238.mp4', 'http://timg.bdta.pro/images/a77df1bba352dbd960c2ca97bc214c5f.jpg'),
(33014, 2256, 'Mom S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161239.mp4', 'http://timg.bdta.pro/images/841cd56001ab6e0874110060431f2168.jpg'),
(33015, 2256, 'Mom S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161240.mp4', 'http://timg.bdta.pro/images/3afe9e377d9c145f057b3ba089ac8236.jpg'),
(33016, 2256, 'Mom S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161241.mp4', 'http://timg.bdta.pro/images/1ab438ddfcd2ad2146f8c915cc7138cf.jpg'),
(33017, 2256, 'Mom S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161242.mp4', 'http://timg.bdta.pro/images/f3311c8772ff590cad073e3189a6bda5.jpg'),
(33018, 2256, 'Mom S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161243.mp4', 'http://timg.bdta.pro/images/e683272926841d3c12e4c4f8d14cbd36.jpg'),
(33019, 2256, 'Mom S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161244.mp4', 'http://timg.bdta.pro/images/f4392c3360d4bcb6d0c4aaf344b804f2.jpg'),
(33020, 2256, 'Mom S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161245.mp4', 'http://timg.bdta.pro/images/114cf9e360e29c4652a907545516ed2d.jpg'),
(33021, 2256, 'Mom S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161246.mp4', 'http://timg.bdta.pro/images/0badfb74b73c4c818fe38b05c47018e0.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(33022, 2256, 'Mom S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161247.mp4', 'http://timg.bdta.pro/images/aff332539b3239b0f053278d6ec0c3b4.jpg'),
(33023, 2256, 'Mom S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161248.mp4', 'http://timg.bdta.pro/images/5a6ebcf43bd4cd48c657f1c1e228ca79.jpg'),
(33024, 2256, 'Mom S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161249.mp4', 'http://timg.bdta.pro/images/2fc233a19b2bd8a18bf29f0494abea2c.jpg'),
(33025, 2256, 'Mom S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161250.mp4', 'http://timg.bdta.pro/images/79cf0c1bc69c52160749ec8a174be9f1.jpg'),
(33026, 2256, 'Mom S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/161251.mp4', 'http://timg.bdta.pro/images/888db775b808fb9e7b4a9279f4ac37da.jpg'),
(33027, 2256, 'Mom S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/161252.mp4', 'http://timg.bdta.pro/images/7fabfdf7a5dc4679f874eeb4eacfe701.jpg'),
(33028, 2256, 'Mom S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/161253.mp4', 'http://timg.bdta.pro/images/de20a5563b25c131d4e7142254ed885d.jpg'),
(33029, 2256, 'Mom S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/161254.mp4', 'http://timg.bdta.pro/images/e8e1bbab35000ec8d40772b3a3373064.jpg'),
(33030, 2257, 'Mom S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161255.mp4', 'http://timg.bdta.pro/images/9e9bb0ec791e8d4238aaae269aed5317.jpg'),
(33031, 2257, 'Mom S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161256.mp4', 'http://timg.bdta.pro/images/878e8893e2d1153e3b1238abee1438c4.jpg'),
(33032, 2257, 'Mom S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161257.mp4', 'http://timg.bdta.pro/images/001018f81da12bd055d2d17592e93168.jpg'),
(33033, 2257, 'Mom S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161258.mp4', 'http://timg.bdta.pro/images/6563ee97ebe6aff96f6d076030abcfeb.jpg'),
(33034, 2257, 'Mom S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161259.mp4', 'http://timg.bdta.pro/images/97d25ba4887364113cdb21b0d0700f70.jpg'),
(33035, 2257, 'Mom S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161260.mp4', 'http://timg.bdta.pro/images/cff3a55000682e3fb86b7419a6c3b03e.jpg'),
(33036, 2257, 'Mom S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161261.mp4', 'http://timg.bdta.pro/images/d37a068c30ddfbca1d80d69ccff5e8cf.jpg'),
(33037, 2257, 'Mom S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161262.mp4', 'http://timg.bdta.pro/images/17325e5b2d811849d614c8f75921eec8.jpg'),
(33038, 2257, 'Mom S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161263.mp4', 'http://timg.bdta.pro/images/ba8e725e00279ab2b2b0d043e10ab255.jpg'),
(33039, 2257, 'Mom S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161264.mp4', 'http://timg.bdta.pro/images/fe46ab3b69a17f02bf39b5b6bb13ef5f.jpg'),
(33040, 2257, 'Mom S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161265.mp4', 'http://timg.bdta.pro/images/573484c93893130dfc1a75313ddbd935.jpg'),
(33041, 2257, 'Mom S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161266.mp4', 'http://timg.bdta.pro/images/9b20cd2d69bd1ae8a7f1bb1b8d11ee04.jpg'),
(33042, 2257, 'Mom S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161267.mp4', 'http://timg.bdta.pro/images/8f48788ff4b6a90f04b893c619979f23.jpg'),
(33043, 2257, 'Mom S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161268.mp4', 'http://timg.bdta.pro/images/a29d636e9b5d3e95f8e700cde6bd2603.jpg'),
(33044, 2257, 'Mom S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161269.mp4', 'http://timg.bdta.pro/images/d2a2a206ee5a9c5e2e09b7f601b161e5.jpg'),
(33045, 2257, 'Mom S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161270.mp4', 'http://timg.bdta.pro/images/3a8f6edfd630cf972dbe3000a0c54e7e.jpg'),
(33046, 2257, 'Mom S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161271.mp4', 'http://timg.bdta.pro/images/b4cf9af901fdf6e4378d21647ee3aa7a.jpg'),
(33047, 2257, 'Mom S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161272.mp4', 'http://timg.bdta.pro/images/238141909fcca67448ca690a77a03557.jpg'),
(33048, 2257, 'Mom S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/161273.mp4', 'http://timg.bdta.pro/images/91a67fb3f2ba681de4208d3e4f603f35.jpg'),
(33049, 2257, 'Mom S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/161274.mp4', 'http://timg.bdta.pro/images/fe70a5749537a20e943d437f1543e749.jpg'),
(33050, 2257, 'Mom S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/161275.mp4', 'http://timg.bdta.pro/images/728e200bca15d1480bd6ac1b3eec61ac.jpg'),
(33051, 2257, 'Mom S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/161276.mp4', 'http://timg.bdta.pro/images/16ac128406921ad9077a703ec7d5bb05.jpg'),
(33052, 2258, 'Mom S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161277.mp4', 'http://timg.bdta.pro/images/0dd48c0741302f0452dd64ed992026ac.jpg'),
(33053, 2258, 'Mom S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161278.mp4', 'http://timg.bdta.pro/images/97c1265e45345f62cbd4a6e8628b61a0.jpg'),
(33054, 2258, 'Mom S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161279.mp4', 'http://timg.bdta.pro/images/423b5ff4f784e013a0248ebca768ff8f.jpg'),
(33055, 2258, 'Mom S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161280.mp4', 'http://timg.bdta.pro/images/8e76496c38016453aa43d326490d8060.jpg'),
(33056, 2258, 'Mom S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161281.mp4', 'http://timg.bdta.pro/images/958d4b51a1598c7e9b3124b9dec584cf.jpg'),
(33057, 2258, 'Mom S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161282.mp4', 'http://timg.bdta.pro/images/9d0ce69933a790200cc4d013113b930f.jpg'),
(33058, 2258, 'Mom S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161283.mp4', 'http://timg.bdta.pro/images/3e681ed99a26abffde6b3615e9fc85ae.jpg'),
(33059, 2258, 'Mom S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161284.mp4', 'http://timg.bdta.pro/images/eaf61642bd35e1729f05549ac7b1442f.jpg'),
(33060, 2258, 'Mom S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161285.mp4', 'http://timg.bdta.pro/images/270c8cad7d94df861dcd90919361af34.jpg'),
(33061, 2258, 'Mom S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161286.mp4', 'http://timg.bdta.pro/images/1e7ba854d009710da5986146c19f287e.jpg'),
(33062, 2258, 'Mom S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161287.mp4', 'http://timg.bdta.pro/images/95ee021db608b71518ffc16dd3f9ace2.jpg'),
(33063, 2258, 'Mom S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161288.mp4', 'http://timg.bdta.pro/images/a8a26faba512d08848542bcf9bcaa424.jpg'),
(33064, 2258, 'Mom S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161289.mp4', 'http://timg.bdta.pro/images/ebefebbe41fe1d766b126343a5f6da78.jpg'),
(33065, 2258, 'Mom S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161290.mp4', 'http://timg.bdta.pro/images/86316eb0e5ec48857aa4115685ff4f0b.jpg'),
(33066, 2258, 'Mom S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161291.mp4', 'http://timg.bdta.pro/images/b4a1400bba551581434a110502c858a0.jpg'),
(33067, 2258, 'Mom S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161292.mp4', 'http://timg.bdta.pro/images/ed3b4923ae54abb4f24cefdade63445e.jpg'),
(33068, 2258, 'Mom S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161293.mp4', 'http://timg.bdta.pro/images/fff3036660eec2aeb9d5eb64cd756289.jpg'),
(33069, 2258, 'Mom S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161294.mp4', 'http://timg.bdta.pro/images/5a3b4ebbbc1a98feaf4be2b093f3a503.jpg'),
(33070, 2258, 'Mom S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/161295.mp4', 'http://timg.bdta.pro/images/6af8a147db82076930a29fa89d46af12.jpg'),
(33071, 2258, 'Mom S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/161296.mp4', 'http://timg.bdta.pro/images/0df5c25bc4a816e9553b3b03aafffdef.jpg'),
(33072, 2258, 'Mom S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/161297.mp4', 'http://timg.bdta.pro/images/eec12db64ed1cae889f1f2bd9b8b71e5.jpg'),
(33073, 2258, 'Mom S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/161298.mp4', 'http://timg.bdta.pro/images/d5786b17d649bdd89baa7744ab4e08f8.jpg'),
(33074, 2259, 'Mom S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161299.mp4', 'http://gstaticontent.com/images/fKsBjE0o9qfJkGTe2axlvprNmja_big.jpg'),
(33075, 2259, 'Mom S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161300.mp4', 'http://gstaticontent.com/images/fKsBjE0o9qfJkGTe2axlvprNmja_big.jpg'),
(33076, 2259, 'Mom S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161301.mp4', 'http://gstaticontent.com/images/fKsBjE0o9qfJkGTe2axlvprNmja_big.jpg'),
(33077, 2259, 'Mom S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161302.mp4', 'http://gstaticontent.com/images/fKsBjE0o9qfJkGTe2axlvprNmja_big.jpg'),
(33078, 2259, 'Mom S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161303.mp4', 'http://gstaticontent.com/images/fKsBjE0o9qfJkGTe2axlvprNmja_big.jpg'),
(33079, 2259, 'Mom S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161304.mp4', 'http://gstaticontent.com/images/fKsBjE0o9qfJkGTe2axlvprNmja_big.jpg'),
(33080, 2259, 'Mom S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161305.mp4', 'http://gstaticontent.com/images/fKsBjE0o9qfJkGTe2axlvprNmja_big.jpg'),
(33081, 2259, 'Mom S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161306.mp4', 'http://gstaticontent.com/images/fKsBjE0o9qfJkGTe2axlvprNmja_big.jpg'),
(33082, 2259, 'Mom S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161307.mp4', 'http://gstaticontent.com/images/fKsBjE0o9qfJkGTe2axlvprNmja_big.jpg'),
(33083, 2259, 'Mom S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161308.mp4', 'http://gstaticontent.com/images/fKsBjE0o9qfJkGTe2axlvprNmja_big.jpg'),
(33084, 2259, 'Mom S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161309.mp4', 'http://gstaticontent.com/images/fKsBjE0o9qfJkGTe2axlvprNmja_big.jpg'),
(33085, 2259, 'Mom S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161310.mp4', 'http://gstaticontent.com/images/fKsBjE0o9qfJkGTe2axlvprNmja_big.jpg'),
(33086, 2259, 'Mom S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161311.mp4', 'http://gstaticontent.com/images/fKsBjE0o9qfJkGTe2axlvprNmja_big.jpg'),
(33087, 2259, 'Mom S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161312.mp4', 'http://gstaticontent.com/images/fKsBjE0o9qfJkGTe2axlvprNmja_big.jpg'),
(33088, 2259, 'Mom S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161313.mp4', 'http://gstaticontent.com/images/fKsBjE0o9qfJkGTe2axlvprNmja_big.jpg'),
(33089, 2259, 'Mom S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161314.mp4', 'http://gstaticontent.com/images/fKsBjE0o9qfJkGTe2axlvprNmja_big.jpg'),
(33090, 2259, 'Mom S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161315.mp4', 'http://gstaticontent.com/images/fKsBjE0o9qfJkGTe2axlvprNmja_big.jpg'),
(33091, 2259, 'Mom S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161316.mp4', 'http://gstaticontent.com/images/fKsBjE0o9qfJkGTe2axlvprNmja_big.jpg'),
(33092, 2259, 'Mom S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/161317.mp4', 'http://gstaticontent.com/images/fKsBjE0o9qfJkGTe2axlvprNmja_big.jpg'),
(33093, 2259, 'Mom S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/161318.mp4', 'http://gstaticontent.com/images/fKsBjE0o9qfJkGTe2axlvprNmja_big.jpg'),
(33094, 2260, 'Mom S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nrbKg63F0Oam0PLWyhmkGKaIdBZ.jpg'),
(33095, 2260, 'Mom S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/78KAZwLpKU6kCxOK9XmKAQhbgC5.jpg'),
(33096, 2260, 'Mom S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qzg2v2sBStrIgcFgxAVvBjWiFwt.jpg'),
(33097, 2260, 'Mom S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/TDoTaDn1WQ04waQAfRK0vCJGqR.jpg'),
(33098, 2260, 'Mom S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/otrzDzeHHe67v0TowvzVV3TEgAg.jpg'),
(33099, 2260, 'Mom S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sxfmiZsCoCnORBTZIoYEzpwPQLo.jpg'),
(33100, 2260, 'Mom S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r45pmMrooFzl4UO3MSy651DsxXJ.jpg'),
(33101, 2260, 'Mom S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d7CH8lCL6Gjw0RYd6SB39NUjeZf.jpg'),
(33102, 2260, 'Mom S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhASSInndvTslqjGn7rk3iCRem2.jpg'),
(33103, 2260, 'Mom S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b7R39TQ9S86siad9BtzOtP1pWkN.jpg'),
(33104, 2260, 'Mom S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xAzJJrXbNzmSF8WgwGwrjDAxpS0.jpg'),
(33105, 2260, 'Mom S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lNjzi4ltKkguy4yUrC9ucIbG1JQ.jpg'),
(33106, 2260, 'Mom S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wUFNSdvHQLX8ZGLTO2Q0jaUsXpi.jpg'),
(33107, 2260, 'Mom S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6jX7qxb7tBVgLDQlbZ0QpcMsjtc.jpg'),
(33108, 2260, 'Mom S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wbr0tXuL30B0AHHYpgwT9HA3LKR.jpg'),
(33109, 2260, 'Mom S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nu5G2eW1MoMnO0dGnGBIhBgECST.jpg'),
(33110, 2260, 'Mom S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uvtbClBIpYcrNQkGMzHqW8dlVEf.jpg'),
(33111, 2260, 'Mom S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lrABAB6h5ogr2RNY9zuYphbKLBr.jpg'),
(33112, 2261, 'O Crush Perfeito S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124885.mp4', 'http://timg.bdta.pro/images/2ec9382829b733e26ceb1a040c36c7de.jpg'),
(33113, 2261, 'O Crush Perfeito S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124886.mp4', 'http://timg.bdta.pro/images/385b948f4ac4cf5145a03454f7b7bcc3.jpg'),
(33114, 2261, 'O Crush Perfeito S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124887.mp4', 'http://timg.bdta.pro/images/03e013ae6481621eebf0804f9ae84e58.jpg'),
(33115, 2261, 'O Crush Perfeito S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124888.mp4', 'http://timg.bdta.pro/images/1b6d8843416db520b5ee290b5b3e6f54.jpg'),
(33116, 2261, 'O Crush Perfeito S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124889.mp4', 'http://timg.bdta.pro/images/9b02b2352b2ce9ec1fdba7e025caaf29.jpg'),
(33117, 2261, 'O Crush Perfeito S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124890.mp4', 'http://timg.bdta.pro/images/23148e0d3c5d812216078c3530d02dab.jpg'),
(33118, 2262, 'Pequenos Incendios por Toda Parte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130002.mp4', 'http://timg.bdta.pro/images/04ac009b35bfa276617c4aab9b1fa7af.jpg'),
(33119, 2262, 'Pequenos Incendios por Toda Parte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130003.mp4', 'http://timg.bdta.pro/images/c02784abe33cea695727990bfbe987ea.jpg'),
(33120, 2262, 'Pequenos Incendios por Toda Parte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130004.mp4', 'http://timg.bdta.pro/images/dbadb98d99cd3ca4c82fba4b2e1d192a.jpg'),
(33121, 2262, 'Pequenos Incendios por Toda Parte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130005.mp4', 'http://timg.bdta.pro/images/ad45ab23dc1e16f09a456d3045ff3a3d.jpg'),
(33122, 2262, 'Pequenos Incendios por Toda Parte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130006.mp4', 'http://timg.bdta.pro/images/346f6b235644c1c4d5645e54e07b5bb0.jpg'),
(33123, 2262, 'Pequenos Incendios por Toda Parte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130007.mp4', 'http://timg.bdta.pro/images/ebcd1e05754b581e8fb5cb160c6c2b89.jpg'),
(33124, 2262, 'Pequenos Incendios por Toda Parte S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130008.mp4', 'http://timg.bdta.pro/images/884966a8ff1e64fe75dc353f7bafb7c3.jpg'),
(33125, 2262, 'Pequenos Incendios por Toda Parte S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130009.mp4', 'http://timg.bdta.pro/images/51419abf48122fac4e79fa561753a114.jpg'),
(33126, 2263, 'Sonhadores S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124877.mp4', 'http://gstaticontent.com/images/919a9a4a07996bde77ab661b035ca2ee.jpg'),
(33127, 2263, 'Sonhadores S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124878.mp4', 'http://gstaticontent.com/images/919a9a4a07996bde77ab661b035ca2ee.jpg'),
(33128, 2263, 'Sonhadores S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124879.mp4', 'http://gstaticontent.com/images/919a9a4a07996bde77ab661b035ca2ee.jpg'),
(33129, 2263, 'Sonhadores S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124880.mp4', 'http://gstaticontent.com/images/919a9a4a07996bde77ab661b035ca2ee.jpg'),
(33130, 2263, 'Sonhadores S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124881.mp4', 'http://gstaticontent.com/images/919a9a4a07996bde77ab661b035ca2ee.jpg'),
(33131, 2263, 'Sonhadores S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124882.mp4', 'http://gstaticontent.com/images/919a9a4a07996bde77ab661b035ca2ee.jpg'),
(33132, 2263, 'Sonhadores S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124883.mp4', 'http://gstaticontent.com/images/919a9a4a07996bde77ab661b035ca2ee.jpg'),
(33133, 2263, 'Sonhadores S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124884.mp4', 'http://gstaticontent.com/images/919a9a4a07996bde77ab661b035ca2ee.jpg'),
(33134, 2264, 'Lucky Man S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124849.mp4', 'http://timg.bdta.pro/images/d225d1ab431b48eff7b0c20d90d38890.jpg'),
(33135, 2264, 'Lucky Man S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124850.mp4', 'http://timg.bdta.pro/images/8b940f58b94fe44f69c84f20c4c9e1de.jpg'),
(33136, 2264, 'Lucky Man S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124851.mp4', 'http://timg.bdta.pro/images/05bab9d2da3459d17404044c8003c5fb.jpg'),
(33137, 2264, 'Lucky Man S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124852.mp4', 'http://timg.bdta.pro/images/9775f7c54827960ea655b635b7747f46.jpg'),
(33138, 2264, 'Lucky Man S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124853.mp4', 'http://timg.bdta.pro/images/0d7856ca1facc72291762b84bcff64a0.jpg'),
(33139, 2264, 'Lucky Man S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124854.mp4', 'http://timg.bdta.pro/images/ad8758b3cfc46824f50663f65526a1fe.jpg'),
(33140, 2264, 'Lucky Man S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124855.mp4', 'http://timg.bdta.pro/images/8f862a421c61c013b03988ae214c1a6f.jpg'),
(33141, 2264, 'Lucky Man S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124856.mp4', 'http://timg.bdta.pro/images/d811bf921d6bf5d4af5fcd8e7c20920c.jpg'),
(33142, 2264, 'Lucky Man S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124857.mp4', 'http://timg.bdta.pro/images/1cd6d1fb25bcc57d981fb83fcec88f88.jpg'),
(33143, 2264, 'Lucky Man S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124858.mp4', 'http://timg.bdta.pro/images/1a4a858eedf053122594dc9eb8d45822.jpg'),
(33144, 2265, 'Lucky Man S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124859.mp4', 'http://timg.bdta.pro/images/97b862d452b045c55a9b9a077443189d.jpg'),
(33145, 2265, 'Lucky Man S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124860.mp4', 'http://timg.bdta.pro/images/b51a4af3bbb24feac33cce2e59799bc8.jpg'),
(33146, 2265, 'Lucky Man S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124861.mp4', 'http://timg.bdta.pro/images/160261367e35d0d6289ad9581600c5ff.jpg'),
(33147, 2265, 'Lucky Man S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124862.mp4', 'http://timg.bdta.pro/images/3a924cc8ff6bfb97ee79d0e44517ecd2.jpg'),
(33148, 2265, 'Lucky Man S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124863.mp4', 'http://timg.bdta.pro/images/82accd668c5a37a3bd99cbc863cfaaca.jpg'),
(33149, 2265, 'Lucky Man S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124864.mp4', 'http://timg.bdta.pro/images/bdba0be0bbacbe29a68652a99cfda4a6.jpg'),
(33150, 2265, 'Lucky Man S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124865.mp4', 'http://timg.bdta.pro/images/6bcb861da6c202ef2b3e6cb70e58caae.jpg'),
(33151, 2265, 'Lucky Man S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124866.mp4', 'http://timg.bdta.pro/images/0d346bf7942be2d2f3a173705193527d.jpg'),
(33152, 2265, 'Lucky Man S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124867.mp4', 'http://timg.bdta.pro/images/913481e1028583be524dbdb4afb36bd4.jpg'),
(33153, 2265, 'Lucky Man S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124868.mp4', 'http://timg.bdta.pro/images/414ebec17c6595f9d3d9c400f75f6aca.jpg'),
(33154, 2266, 'Lucky Man S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124869.mp4', 'http://timg.bdta.pro/images/1ac26afd6dab4b7381634755009fe908.jpg'),
(33155, 2266, 'Lucky Man S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124870.mp4', 'http://timg.bdta.pro/images/544fe7019110e33b4edcf59576e5f873.jpg'),
(33156, 2266, 'Lucky Man S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124871.mp4', 'http://timg.bdta.pro/images/73acd27298674df7c6f082986ecd1a3a.jpg'),
(33157, 2266, 'Lucky Man S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124872.mp4', 'http://timg.bdta.pro/images/d78bc887ab5a4a0c9b1d61f04cd2f9bc.jpg'),
(33158, 2266, 'Lucky Man S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124873.mp4', 'http://timg.bdta.pro/images/4cb8ab4229e3655c863a5fc989797a07.jpg'),
(33159, 2266, 'Lucky Man S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124874.mp4', 'http://timg.bdta.pro/images/8f89ab9d171fa11a0a7f51a20b24df78.jpg'),
(33160, 2266, 'Lucky Man S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124875.mp4', 'http://timg.bdta.pro/images/a1b2e949cec960170b50bce1eba6bf68.jpg'),
(33161, 2266, 'Lucky Man S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124876.mp4', 'http://timg.bdta.pro/images/e36b6a8b0b3decfb1f059933f535d05b.jpg'),
(33162, 2267, 'Unforgettable S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124788.mp4', 'http://timg.bdta.pro/images/137c0c258b185c62c1452ec1d7c195c4.jpg'),
(33163, 2267, 'Unforgettable S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124789.mp4', 'http://timg.bdta.pro/images/d07d34e0276581d94447a19ede15f821.jpg'),
(33164, 2267, 'Unforgettable S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124790.mp4', 'http://timg.bdta.pro/images/40a2d5cb4fb43574e0fa34d2180dbfa3.jpg'),
(33165, 2267, 'Unforgettable S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124791.mp4', 'http://timg.bdta.pro/images/729d93aeb24e4487ff9f943c263c8f34.jpg'),
(33166, 2267, 'Unforgettable S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124792.mp4', 'http://timg.bdta.pro/images/9fd914044008832a48c17cd88ee2d30b.jpg'),
(33167, 2267, 'Unforgettable S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124793.mp4', 'http://timg.bdta.pro/images/31c3892773f688ae6e023ef32e1d20a1.jpg'),
(33168, 2267, 'Unforgettable S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124794.mp4', 'http://timg.bdta.pro/images/4a6ec5c5d9a1eaed7981eb57ed841724.jpg'),
(33169, 2267, 'Unforgettable S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124795.mp4', 'http://timg.bdta.pro/images/4192723368bc5f38a44939f3fc16eceb.jpg'),
(33170, 2267, 'Unforgettable S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124796.mp4', 'http://timg.bdta.pro/images/b9bfeaac7c53e87f4a2ac74f67ade615.jpg'),
(33171, 2267, 'Unforgettable S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124797.mp4', 'http://timg.bdta.pro/images/7be37bb8c63315da8a413ba6ae232b95.jpg'),
(33172, 2267, 'Unforgettable S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124798.mp4', 'http://timg.bdta.pro/images/aa7490ccd2815e312523ab2b56139e12.jpg'),
(33173, 2267, 'Unforgettable S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124799.mp4', 'http://timg.bdta.pro/images/fdc5a024ee1bde63ab334c838809af2b.jpg'),
(33174, 2267, 'Unforgettable S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124800.mp4', 'http://timg.bdta.pro/images/b9b38af5046d713f535d537c4e9457c0.jpg'),
(33175, 2267, 'Unforgettable S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/124801.mp4', 'http://timg.bdta.pro/images/be4f2b514bdbfd6f7ef0805ffbfa7ee1.jpg'),
(33176, 2267, 'Unforgettable S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/124802.mp4', 'http://timg.bdta.pro/images/5e2c1b3da2f031bfbbd60ac15e9b3976.jpg'),
(33177, 2267, 'Unforgettable S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/124803.mp4', 'http://timg.bdta.pro/images/194742aecd448cb65e3ca9e57077555e.jpg'),
(33178, 2267, 'Unforgettable S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/124804.mp4', 'http://timg.bdta.pro/images/babef0a208f944e483a2a706895e623c.jpg'),
(33179, 2267, 'Unforgettable S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/124805.mp4', 'http://timg.bdta.pro/images/8af320c71b54c3b9a61a6f19b7f7afa9.jpg'),
(33180, 2267, 'Unforgettable S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/124806.mp4', 'http://timg.bdta.pro/images/c7c0fbe568f5af6237d773aa01538ef1.jpg'),
(33181, 2267, 'Unforgettable S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/124807.mp4', 'http://timg.bdta.pro/images/7f1213709cde083fdafeba4cbc111d99.jpg'),
(33182, 2267, 'Unforgettable S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/124808.mp4', 'http://timg.bdta.pro/images/465490165240157bf9cbdc499cec588a.jpg'),
(33183, 2267, 'Unforgettable S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/124809.mp4', 'http://timg.bdta.pro/images/d49b3b459911db5e1033c9898be2fea4.jpg'),
(33184, 2268, 'Unforgettable S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124810.mp4', 'http://timg.bdta.pro/images/e7273bbce248b31c5e6be43ad9c338a7.jpg'),
(33185, 2268, 'Unforgettable S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124811.mp4', 'http://timg.bdta.pro/images/4dce3c933872a0570fc9eb5a56da4d1e.jpg'),
(33186, 2268, 'Unforgettable S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124812.mp4', 'http://timg.bdta.pro/images/b4529f7561af5b04864b90203b5da2a5.jpg'),
(33187, 2268, 'Unforgettable S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124813.mp4', 'http://timg.bdta.pro/images/b43f1fbaf4a34e1e0533c44508fe75eb.jpg'),
(33188, 2268, 'Unforgettable S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124814.mp4', 'http://timg.bdta.pro/images/e36b1ecade34704498ab5bd3f1f3eb74.jpg'),
(33189, 2268, 'Unforgettable S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124815.mp4', 'http://timg.bdta.pro/images/46952ac4e1a8ce4c9ca1017f94ac0135.jpg'),
(33190, 2268, 'Unforgettable S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124816.mp4', 'http://timg.bdta.pro/images/48f1ad14d80d6e350e476765709c231f.jpg'),
(33191, 2268, 'Unforgettable S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124817.mp4', 'http://timg.bdta.pro/images/58ede68b1e2f9642a46737ab6c5c93e0.jpg'),
(33192, 2268, 'Unforgettable S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124818.mp4', 'http://timg.bdta.pro/images/4626828b4de78bff8b74cea87081a783.jpg'),
(33193, 2268, 'Unforgettable S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124819.mp4', 'http://timg.bdta.pro/images/72b4b17871a215e41ec802cac8622c20.jpg'),
(33194, 2268, 'Unforgettable S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124820.mp4', 'http://timg.bdta.pro/images/0f9e82d6cf3db1d828c1203b3f4b952c.jpg'),
(33195, 2268, 'Unforgettable S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124821.mp4', 'http://timg.bdta.pro/images/fe9320fcd7ff50b676cc6fb8e7603e86.jpg'),
(33196, 2268, 'Unforgettable S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124822.mp4', 'http://timg.bdta.pro/images/8914d862edab98fd1270b623aa86bea7.jpg'),
(33197, 2269, 'Unforgettable S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124823.mp4', 'http://timg.bdta.pro/images/33acab7e23344216ca56e00d1fc543ed.jpg'),
(33198, 2269, 'Unforgettable S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124824.mp4', 'http://timg.bdta.pro/images/b5bfeff9f3c27a8060b474455ae04b25.jpg'),
(33199, 2269, 'Unforgettable S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124825.mp4', 'http://timg.bdta.pro/images/37fbe53257f4a717465d01efeffdc0f5.jpg'),
(33200, 2269, 'Unforgettable S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124826.mp4', 'http://timg.bdta.pro/images/7f7235195007e05c1652a885ae03c022.jpg'),
(33201, 2269, 'Unforgettable S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124827.mp4', 'http://timg.bdta.pro/images/a1e888eb0aa8cb788366fd75d74f78ae.jpg'),
(33202, 2269, 'Unforgettable S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124828.mp4', 'http://timg.bdta.pro/images/d12db852c81438ab647b8b4de1f26513.jpg'),
(33203, 2269, 'Unforgettable S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124829.mp4', 'http://timg.bdta.pro/images/2d27f3e660c7f928c5978931ef9b089e.jpg'),
(33204, 2269, 'Unforgettable S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124830.mp4', 'http://timg.bdta.pro/images/c17f4147ee8aa568de9aed5e80cd9644.jpg'),
(33205, 2269, 'Unforgettable S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124831.mp4', 'http://timg.bdta.pro/images/daea8d4c89b29bfbd01f55f38c93c4f1.jpg'),
(33206, 2269, 'Unforgettable S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124832.mp4', 'http://timg.bdta.pro/images/35595708e12155214e15bfffc9a5304c.jpg'),
(33207, 2269, 'Unforgettable S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124833.mp4', 'http://timg.bdta.pro/images/aedb658006dcde9d778bff3c4aecf93a.jpg'),
(33208, 2269, 'Unforgettable S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124834.mp4', 'http://timg.bdta.pro/images/ae65b55badc4ec8f56af13524cc2bc42.jpg'),
(33209, 2269, 'Unforgettable S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124835.mp4', 'http://timg.bdta.pro/images/4dc91f5a8ed8eb21b113c9592aa01d09.jpg'),
(33210, 2270, 'Unforgettable S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124836.mp4', 'http://timg.bdta.pro/images/245d0788117ebfdedd14359d948c29a1.jpg'),
(33211, 2270, 'Unforgettable S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124837.mp4', 'http://timg.bdta.pro/images/403512b07d53131a24afd4576cb75e56.jpg'),
(33212, 2270, 'Unforgettable S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124838.mp4', 'http://timg.bdta.pro/images/f9d24ed1d1d29fbc6bd7e447c5fb29fd.jpg'),
(33213, 2270, 'Unforgettable S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124839.mp4', 'http://timg.bdta.pro/images/c3942d8e4810e67082d48bb743d5fecf.jpg'),
(33214, 2270, 'Unforgettable S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124840.mp4', 'http://timg.bdta.pro/images/5b62be70e42316c3bd44a69bbac53028.jpg'),
(33215, 2270, 'Unforgettable S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124841.mp4', 'http://timg.bdta.pro/images/577ad85e5632d3cb181e63c7183d0cca.jpg'),
(33216, 2270, 'Unforgettable S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124842.mp4', 'http://timg.bdta.pro/images/b1b9e6b0479274e979ac2c7ff69de920.jpg'),
(33217, 2270, 'Unforgettable S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124843.mp4', 'http://timg.bdta.pro/images/c165cd6fbf3da193763181fccb1e477a.jpg'),
(33218, 2270, 'Unforgettable S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124844.mp4', 'http://timg.bdta.pro/images/7001982fa95e645bec2bbefe7f2e305c.jpg'),
(33219, 2270, 'Unforgettable S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124845.mp4', 'http://timg.bdta.pro/images/ba5f48e33b5469fb7b9997fd6ac04176.jpg'),
(33220, 2270, 'Unforgettable S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124846.mp4', 'http://timg.bdta.pro/images/240508ee9bbdb268de00fbb42713c3fe.jpg'),
(33221, 2270, 'Unforgettable S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124847.mp4', 'http://timg.bdta.pro/images/3862e224525c78cec5c405270176ca8e.jpg'),
(33222, 2270, 'Unforgettable S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124848.mp4', 'http://timg.bdta.pro/images/9bf1ebb74ef6785a1f5164261b7e9116.jpg'),
(33223, 2271, 'Warrior Nun S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201649.mp4', 'http://timg.bdta.pro/images/f9dc4200750d108941a82127d860f21e.jpg'),
(33224, 2271, 'Warrior Nun S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201650.mp4', 'http://timg.bdta.pro/images/b9e237bec6637d34fa5d5f170d984e33.jpg'),
(33225, 2271, 'Warrior Nun S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201651.mp4', 'http://timg.bdta.pro/images/49dbe33b1d674062637ca98e2133e611.jpg'),
(33226, 2271, 'Warrior Nun S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201652.mp4', 'http://timg.bdta.pro/images/c0dc20ced6d1e7c3822aca7e10732515.jpg'),
(33227, 2271, 'Warrior Nun S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201653.mp4', 'http://timg.bdta.pro/images/20146470b44efe18aa1cb4737c0f685f.jpg'),
(33228, 2271, 'Warrior Nun S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201654.mp4', 'http://timg.bdta.pro/images/7ea2b9d183e2d11f3da3d228ff426ed8.jpg'),
(33229, 2271, 'Warrior Nun S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201655.mp4', 'http://timg.bdta.pro/images/29d501a8ecdf23ea727bce708a52fe27.jpg'),
(33230, 2271, 'Warrior Nun S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201656.mp4', 'http://timg.bdta.pro/images/db4a250ba7414f49169d886c8a75c0b8.jpg'),
(33231, 2271, 'Warrior Nun S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201657.mp4', 'http://timg.bdta.pro/images/672af251103f042044dcedfef5eb9b8e.jpg'),
(33232, 2271, 'Warrior Nun S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201658.mp4', 'http://timg.bdta.pro/images/927b739e27914d151547fe6742bed386.jpg'),
(33233, 2272, 'Warrior Nun S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/utb8RuOEkfLoLmcch6DdT63wOfi.jpg'),
(33234, 2272, 'Warrior Nun S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mPA15tRyxzUzfu3PSehsPBkXANH.jpg'),
(33235, 2272, 'Warrior Nun S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3oMracuxR01Zc2LPpt7bmAWMQvt.jpg'),
(33236, 2272, 'Warrior Nun S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9iBOOiWUhKI9eaztNInQto9cEbf.jpg'),
(33237, 2272, 'Warrior Nun S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qO4a1WGn91SjZKr4enjCh12YFs.jpg'),
(33238, 2272, 'Warrior Nun S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e0me0GeDF3vNIx4cY69PiV0CtNw.jpg'),
(33239, 2272, 'Warrior Nun S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lgjyO4FF1IxEWlKatRTiT1ovFfo.jpg'),
(33240, 2272, 'Warrior Nun S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fY7PAkTbnhaoVj3j9IOgui5Y1Ky.jpg'),
(33241, 2273, 'X-Men Serie Animada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124712.mp4', 'http://timg.bdta.pro/images/3173c05dbb0cd212adbdb568a9ef2f00.jpg'),
(33242, 2273, 'X-Men Serie Animada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124713.mp4', 'http://timg.bdta.pro/images/40f3cd919bed2df2501d97c21d272f15.jpg'),
(33243, 2273, 'X-Men Serie Animada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124714.mp4', 'http://timg.bdta.pro/images/5b979773899647ac1a884bd52584dd66.jpg'),
(33244, 2273, 'X-Men Serie Animada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124715.mp4', 'http://timg.bdta.pro/images/a59698d461b810ee2ef722ca26203373.jpg'),
(33245, 2273, 'X-Men Serie Animada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124716.mp4', 'http://timg.bdta.pro/images/f581c40ea49c3156f0e9749b37d676d7.jpg'),
(33246, 2273, 'X-Men Serie Animada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124717.mp4', 'http://timg.bdta.pro/images/2542bb5bd1dff629bf36716b4d1e3066.jpg'),
(33247, 2273, 'X-Men Serie Animada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124718.mp4', 'http://timg.bdta.pro/images/588c206b7790547e8f8776738a944037.jpg'),
(33248, 2273, 'X-Men Serie Animada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124719.mp4', 'http://timg.bdta.pro/images/f69723413d0af32fd4ec6be8a5b7d41d.jpg'),
(33249, 2273, 'X-Men Serie Animada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124720.mp4', 'http://timg.bdta.pro/images/740000147609bed74998ae97193562e7.jpg'),
(33250, 2273, 'X-Men Serie Animada S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124721.mp4', 'http://timg.bdta.pro/images/de5be241c09dfa9c8545dc4d060b49d8.jpg'),
(33251, 2273, 'X-Men Serie Animada S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124722.mp4', 'http://timg.bdta.pro/images/d3e59e5bad5029aeb98b56cd82496720.jpg'),
(33252, 2273, 'X-Men Serie Animada S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124723.mp4', 'http://timg.bdta.pro/images/145bdeb82e6d1015b0443a9f74a57ac2.jpg'),
(33253, 2273, 'X-Men Serie Animada S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124724.mp4', 'http://timg.bdta.pro/images/451bdac98210ef65022126df7cf4c3ee.jpg'),
(33254, 2274, 'X-Men Serie Animada S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124725.mp4', 'http://timg.bdta.pro/images/b3833378f583ca45e4f440385c402264.jpg'),
(33255, 2274, 'X-Men Serie Animada S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124726.mp4', 'http://timg.bdta.pro/images/3efc528f09124f2675be910fdaa30f41.jpg'),
(33256, 2274, 'X-Men Serie Animada S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124727.mp4', 'http://timg.bdta.pro/images/405b61ef58e1771888343adda7beefa0.jpg'),
(33257, 2274, 'X-Men Serie Animada S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124728.mp4', 'http://timg.bdta.pro/images/4eccac60f1fa649e7c02fc460e5620c1.jpg'),
(33258, 2274, 'X-Men Serie Animada S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124729.mp4', 'http://timg.bdta.pro/images/338f9bd26de1399843c084a345e2e643.jpg'),
(33259, 2274, 'X-Men Serie Animada S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124730.mp4', 'http://timg.bdta.pro/images/f5dc5fc5f511cd8739fef64f6d041fc9.jpg'),
(33260, 2274, 'X-Men Serie Animada S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124731.mp4', 'http://timg.bdta.pro/images/7b6178753a9b40e880f8084872a49495.jpg'),
(33261, 2274, 'X-Men Serie Animada S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124732.mp4', 'http://timg.bdta.pro/images/874df9a74923f32b8eeef192d2cccb41.jpg'),
(33262, 2274, 'X-Men Serie Animada S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124733.mp4', 'http://timg.bdta.pro/images/a5df8734c30663afb79e7368c54581f0.jpg'),
(33263, 2274, 'X-Men Serie Animada S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124734.mp4', 'http://timg.bdta.pro/images/e061e9247061553ae7a80c7e0e4770d4.jpg'),
(33264, 2274, 'X-Men Serie Animada S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124735.mp4', 'http://timg.bdta.pro/images/97818e77abb3dd23c2f122c026779db1.jpg'),
(33265, 2274, 'X-Men Serie Animada S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124736.mp4', 'http://timg.bdta.pro/images/f9eb362a160d8b46efc0118d3e8ae81a.jpg'),
(33266, 2274, 'X-Men Serie Animada S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124737.mp4', 'http://timg.bdta.pro/images/4d21da84d1c4e8a184f83cccb788dbde.jpg'),
(33267, 2275, 'X-Men Serie Animada S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124738.mp4', 'http://timg.bdta.pro/images/c178fbc11fba473d974e090a0b93725f.jpg'),
(33268, 2275, 'X-Men Serie Animada S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124739.mp4', 'http://timg.bdta.pro/images/97f44957bb9a560649bfdc9f9987eac2.jpg'),
(33269, 2275, 'X-Men Serie Animada S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124740.mp4', 'http://timg.bdta.pro/images/67413374fdc45fc4462596e98f46505a.jpg'),
(33270, 2275, 'X-Men Serie Animada S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124741.mp4', 'http://timg.bdta.pro/images/7f211c620ef50c82ab5a833779b3a849.jpg'),
(33271, 2275, 'X-Men Serie Animada S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124742.mp4', 'http://timg.bdta.pro/images/781be66a73c09835949a35aec850729b.jpg'),
(33272, 2275, 'X-Men Serie Animada S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124743.mp4', 'http://timg.bdta.pro/images/44cc9b7e5915c26fa0474e937d2d6468.jpg'),
(33273, 2275, 'X-Men Serie Animada S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124744.mp4', 'http://timg.bdta.pro/images/9e1b9326dd32b34e977e05f8289746be.jpg'),
(33274, 2275, 'X-Men Serie Animada S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124745.mp4', 'http://timg.bdta.pro/images/b8b4ff8a8e1ed296eefceee77237861f.jpg'),
(33275, 2275, 'X-Men Serie Animada S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124746.mp4', 'http://timg.bdta.pro/images/26aeadd91d7320d15c124aa0865171af.jpg'),
(33276, 2275, 'X-Men Serie Animada S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124747.mp4', 'http://timg.bdta.pro/images/657e75bbbafdd645d3844aec858aa8e1.jpg'),
(33277, 2275, 'X-Men Serie Animada S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124748.mp4', 'http://timg.bdta.pro/images/30cb2982f9897e3f0fca193f10fc0dce.jpg'),
(33278, 2275, 'X-Men Serie Animada S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124749.mp4', 'http://timg.bdta.pro/images/2b2b4b195bbc197f231d7d373ff0de54.jpg'),
(33279, 2275, 'X-Men Serie Animada S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124750.mp4', 'http://timg.bdta.pro/images/341310e511904af2b7492579990fee6d.jpg'),
(33280, 2275, 'X-Men Serie Animada S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/124751.mp4', 'http://timg.bdta.pro/images/b8b0642ef05afd5e8991a9f4b0a32823.jpg'),
(33281, 2275, 'X-Men Serie Animada S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/124752.mp4', 'http://timg.bdta.pro/images/96748b6885b82e5f02a2048dcf3cbfd1.jpg'),
(33282, 2275, 'X-Men Serie Animada S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/124753.mp4', 'http://timg.bdta.pro/images/51d61898b1939fdb1d9f96d958096de8.jpg'),
(33283, 2275, 'X-Men Serie Animada S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/124754.mp4', 'http://timg.bdta.pro/images/6bfc7631b09e17f4cfb471ca475d295f.jpg'),
(33284, 2275, 'X-Men Serie Animada S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/124755.mp4', 'http://timg.bdta.pro/images/775c4fc47ab2a48bacbae4a883e47f3d.jpg'),
(33285, 2275, 'X-Men Serie Animada S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/124756.mp4', 'http://timg.bdta.pro/images/605cf8fdd694affc8a9403d50afeb51b.jpg'),
(33286, 2276, 'X-Men Serie Animada S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124757.mp4', 'http://timg.bdta.pro/images/fe57381295e86f34134dd919586ca1ea.jpg'),
(33287, 2276, 'X-Men Serie Animada S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124758.mp4', 'http://timg.bdta.pro/images/13ac6b99bcefc2883ce7245f1fd45154.jpg'),
(33288, 2276, 'X-Men Serie Animada S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124759.mp4', 'http://timg.bdta.pro/images/b2217b6b1b895ae7ce5704f3180659c9.jpg'),
(33289, 2276, 'X-Men Serie Animada S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124760.mp4', 'http://timg.bdta.pro/images/4754fa25a3ed134bfabcd4d43910b65b.jpg'),
(33290, 2276, 'X-Men Serie Animada S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124761.mp4', 'http://timg.bdta.pro/images/dcacf43af15bf620c71fd39a5903fdbe.jpg'),
(33291, 2276, 'X-Men Serie Animada S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124762.mp4', 'http://timg.bdta.pro/images/214f3e77ed30c414903a5a3bb216d380.jpg'),
(33292, 2276, 'X-Men Serie Animada S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124763.mp4', 'http://timg.bdta.pro/images/991f7a5badf7847dd7ff19f7d15a5b0e.jpg'),
(33293, 2276, 'X-Men Serie Animada S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124764.mp4', 'http://timg.bdta.pro/images/c1e4aec02572e0117b6ce225145c48ef.jpg'),
(33294, 2276, 'X-Men Serie Animada S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124765.mp4', 'http://timg.bdta.pro/images/9cbaaa7f11e53d24e59574e1956daa87.jpg'),
(33295, 2276, 'X-Men Serie Animada S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124766.mp4', 'http://timg.bdta.pro/images/4abd1050986ebf5222985be6d7326998.jpg'),
(33296, 2276, 'X-Men Serie Animada S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124767.mp4', 'http://timg.bdta.pro/images/e27891a534f3b239fa20cb38cc01a375.jpg'),
(33297, 2276, 'X-Men Serie Animada S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124768.mp4', 'http://timg.bdta.pro/images/f7aaa9de7f48bf83beaffd6c75b33e6a.jpg'),
(33298, 2276, 'X-Men Serie Animada S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124769.mp4', 'http://timg.bdta.pro/images/70e51ef4f99d1573ce3f8ef12868a9b1.jpg'),
(33299, 2276, 'X-Men Serie Animada S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/124770.mp4', 'http://timg.bdta.pro/images/281b295c8db0861403796bc718c9d84c.jpg'),
(33300, 2276, 'X-Men Serie Animada S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/124771.mp4', 'http://timg.bdta.pro/images/f6df6e0f52569da2c1a57dfeb539c1be.jpg'),
(33301, 2276, 'X-Men Serie Animada S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/124772.mp4', 'http://timg.bdta.pro/images/3e2b95d2a6dae49b619773a422e93389.jpg'),
(33302, 2276, 'X-Men Serie Animada S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/124773.mp4', 'http://timg.bdta.pro/images/6302d1a34cfa2dce4b141939e8412236.jpg'),
(33303, 2277, 'X-Men Serie Animada S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124774.mp4', 'http://timg.bdta.pro/images/27b6db37601aae4d0648a765aea6cc3f.jpg'),
(33304, 2277, 'X-Men Serie Animada S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124775.mp4', 'http://timg.bdta.pro/images/63790b327e341c8078f1e6f2c49f10ad.jpg'),
(33305, 2277, 'X-Men Serie Animada S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124776.mp4', 'http://timg.bdta.pro/images/b79a87adc898274612cbae60520f9657.jpg'),
(33306, 2277, 'X-Men Serie Animada S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124777.mp4', 'http://timg.bdta.pro/images/f3c835ccf4a7aa27d6e86cb64da756e0.jpg'),
(33307, 2277, 'X-Men Serie Animada S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124778.mp4', 'http://timg.bdta.pro/images/56567f13563ec9b4a8ee514fc60c7ffd.jpg'),
(33308, 2277, 'X-Men Serie Animada S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124779.mp4', 'http://timg.bdta.pro/images/8d0fceceb4fb7f5817c42e4b447cfd14.jpg'),
(33309, 2277, 'X-Men Serie Animada S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124780.mp4', 'http://timg.bdta.pro/images/bc1cfbb001a69799db1d68e7697f8184.jpg'),
(33310, 2277, 'X-Men Serie Animada S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124781.mp4', 'http://timg.bdta.pro/images/6cc1c956e3b209c0239d30bfc9ec4841.jpg'),
(33311, 2277, 'X-Men Serie Animada S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124782.mp4', 'http://timg.bdta.pro/images/733a30544792816e17d24c4034746e14.jpg'),
(33312, 2277, 'X-Men Serie Animada S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124783.mp4', 'http://timg.bdta.pro/images/9c8425fd4c45d968ababce9a50a71472.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(33313, 2277, 'X-Men Serie Animada S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124784.mp4', 'http://timg.bdta.pro/images/149d01b09b2adca43ed1b8ee8b7c973e.jpg'),
(33314, 2277, 'X-Men Serie Animada S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124785.mp4', 'http://timg.bdta.pro/images/594195ec99ccac9e8dbb92193bad7323.jpg'),
(33315, 2277, 'X-Men Serie Animada S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124786.mp4', 'http://timg.bdta.pro/images/c7bdc34d2492600af699e466ec422a27.jpg'),
(33316, 2277, 'X-Men Serie Animada S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/124787.mp4', 'http://timg.bdta.pro/images/8ea7dd80f2e7440e8f874ddf2ef8a302.jpg'),
(33317, 2278, 'Desejo Sombrio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r8ClIdl3x0CwrVW8rFNjhQNVJp3.jpg'),
(33318, 2278, 'Desejo Sombrio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gRzJXRCFXjdxgBOvCIKdcG5oXOu.jpg'),
(33319, 2278, 'Desejo Sombrio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tmwC66ttOn5G34hBADFqcIYclJ7.jpg'),
(33320, 2278, 'Desejo Sombrio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFNUYwn2RA1MMvQzyKLskXCAOky.jpg'),
(33321, 2278, 'Desejo Sombrio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/SCMGc6Q5OUtSGtID5AnrII13UK.jpg'),
(33322, 2278, 'Desejo Sombrio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJ8smExoYhyEQ2eL2d996EpogA0.jpg'),
(33323, 2278, 'Desejo Sombrio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5qDWvDladI4kbIXG5t4QIOPmJOk.jpg'),
(33324, 2278, 'Desejo Sombrio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/imiZBAFQkwr7huYfIcSqFgmObi2.jpg'),
(33325, 2278, 'Desejo Sombrio S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wu1s1MTPRHgHFMLoyyHknQLLEeZ.jpg'),
(33326, 2278, 'Desejo Sombrio S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4iuHtKSOLOiBVUdv3sAlYGRJF5L.jpg'),
(33327, 2278, 'Desejo Sombrio S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cGDmfsYvrdQQPX23fXjdsxERyQw.jpg'),
(33328, 2278, 'Desejo Sombrio S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fRmZeBLPmZAQCyBwUPCaGWHfsXb.jpg'),
(33329, 2278, 'Desejo Sombrio S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kbzBPoHnEM7oiTwe5C9iQ5BoKAw.jpg'),
(33330, 2278, 'Desejo Sombrio S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z9POwT0paqklaUM77tK5rG5hEoj.jpg'),
(33331, 2278, 'Desejo Sombrio S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/172980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yu6ZHhk4al5VhU3ZhNFOH46F0ix.jpg'),
(33332, 2278, 'Desejo Sombrio S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/172981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Kjf9Kanc3BKRclrMyo1mGWgLME.jpg'),
(33333, 2278, 'Desejo Sombrio S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/172982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vbNymsWCpkWBUUxVGhIQU18uw0H.jpg'),
(33334, 2278, 'Desejo Sombrio S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/172983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Mj2WjKvCSJABtYXFBSHdusISR4.jpg'),
(33335, 2279, 'Desejo Sombrio S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172984.mp4', 'http://timg.bdta.pro/images/ee9864be4c1d40fddd7a81cc7d6da9df.jpg'),
(33336, 2279, 'Desejo Sombrio S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172985.mp4', 'http://timg.bdta.pro/images/32d4130415742f3ed6b45ee01ce0c514.jpg'),
(33337, 2279, 'Desejo Sombrio S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172986.mp4', 'http://timg.bdta.pro/images/0ee1a1860f91ea13960e5a409c3b69ff.jpg'),
(33338, 2279, 'Desejo Sombrio S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172987.mp4', 'http://timg.bdta.pro/images/5043d277f044fefb4b4ad6bd2c874ad1.jpg'),
(33339, 2279, 'Desejo Sombrio S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172988.mp4', 'http://timg.bdta.pro/images/fbe11f530b34dc90415403cc1d028de6.jpg'),
(33340, 2279, 'Desejo Sombrio S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172989.mp4', 'http://timg.bdta.pro/images/384425da9a6d7e13414890b68422a9f7.jpg'),
(33341, 2279, 'Desejo Sombrio S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172990.mp4', 'http://timg.bdta.pro/images/d0ffa8d771db3390bea8d50bcc788723.jpg'),
(33342, 2279, 'Desejo Sombrio S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172991.mp4', 'http://timg.bdta.pro/images/5f1a5337fb29e0243807a1a065880d44.jpg'),
(33343, 2279, 'Desejo Sombrio S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172992.mp4', 'http://timg.bdta.pro/images/2307f2ae60c0ab931aceacd86907eb1b.jpg'),
(33344, 2279, 'Desejo Sombrio S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172993.mp4', 'http://timg.bdta.pro/images/e01899ad6438c412a7b4541b42f5958e.jpg'),
(33345, 2279, 'Desejo Sombrio S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172994.mp4', 'http://timg.bdta.pro/images/6f9de112361586a4afc6f03ec408d7eb.jpg'),
(33346, 2279, 'Desejo Sombrio S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172995.mp4', 'http://timg.bdta.pro/images/4b452f23f3527c54a9e0d736f88049dc.jpg'),
(33347, 2279, 'Desejo Sombrio S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172996.mp4', 'http://timg.bdta.pro/images/4b18b96e88c91653576dbe410047b383.jpg'),
(33348, 2279, 'Desejo Sombrio S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172997.mp4', 'http://timg.bdta.pro/images/86fb60952ccbf2a55ecf61b30c904acb.jpg'),
(33349, 2279, 'Desejo Sombrio S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/172998.mp4', 'http://timg.bdta.pro/images/dc6a427ac85292a22a70799761a27679.jpg'),
(33350, 2280, '19-2 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123780.mp4', 'http://timg.bdta.pro/images/965a3e013dbde93856c26794c0b1f8af.jpg'),
(33351, 2280, '19-2 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123781.mp4', 'http://timg.bdta.pro/images/75562c0ba46166bfa1f5a8cb3a2e4fef.jpg'),
(33352, 2280, '19-2 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123782.mp4', 'http://timg.bdta.pro/images/32251d23fdd825feb29e480ab3d1641c.jpg'),
(33353, 2280, '19-2 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123783.mp4', 'http://timg.bdta.pro/images/1c6d587204aba8f92ec3bf660f3ae41c.jpg'),
(33354, 2280, '19-2 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123784.mp4', 'http://timg.bdta.pro/images/c64cee52a2a97f153f59cd3f3f0d608d.jpg'),
(33355, 2280, '19-2 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123785.mp4', 'http://timg.bdta.pro/images/74419f913b1cf4b65874675e416b3095.jpg'),
(33356, 2280, '19-2 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123786.mp4', 'http://timg.bdta.pro/images/9f53b47a9af5501f000c930cf38a907d.jpg'),
(33357, 2280, '19-2 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123787.mp4', 'http://timg.bdta.pro/images/3113ac760d87a555bca5af2a15f8df4c.jpg'),
(33358, 2280, '19-2 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123788.mp4', 'http://timg.bdta.pro/images/8327c7f627844ac5ce8305e1cad3cdb0.jpg'),
(33359, 2280, '19-2 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123789.mp4', 'http://timg.bdta.pro/images/0ef47b28ba78f2e521e8a2115c778c80.jpg'),
(33360, 2281, '19-2 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123790.mp4', 'http://timg.bdta.pro/images/d31250ecdada3b56d5adccba4b5de107.jpg'),
(33361, 2281, '19-2 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123791.mp4', 'http://timg.bdta.pro/images/35ef46ae261da328054f08b22ffdbe1e.jpg'),
(33362, 2281, '19-2 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123792.mp4', 'http://timg.bdta.pro/images/d0f11ce1a11ab18835cc9dd8309cd878.jpg'),
(33363, 2281, '19-2 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123793.mp4', 'http://timg.bdta.pro/images/d6d8bac47217f60f05ac1e0609e82841.jpg'),
(33364, 2281, '19-2 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123794.mp4', 'http://timg.bdta.pro/images/9194d9572156f1143ca38c2526fdb1c6.jpg'),
(33365, 2281, '19-2 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123795.mp4', 'http://timg.bdta.pro/images/c26c356291e2b91e31786c9839d89b4f.jpg'),
(33366, 2281, '19-2 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123796.mp4', 'http://timg.bdta.pro/images/506de41d1baaa2cc61caccfd9305a0dc.jpg'),
(33367, 2281, '19-2 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123797.mp4', 'http://timg.bdta.pro/images/506de41d1baaa2cc61caccfd9305a0dc.jpg'),
(33368, 2281, '19-2 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123798.mp4', 'http://timg.bdta.pro/images/4251f03a4d95251ef122250eae36c162.jpg'),
(33369, 2281, '19-2 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123799.mp4', 'http://timg.bdta.pro/images/4251f03a4d95251ef122250eae36c162.jpg'),
(33370, 2282, '19-2 S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123800.mp4', 'http://timg.bdta.pro/images/7f8f5fae8d9e3c4cb262827f40883fba.jpg'),
(33371, 2282, '19-2 S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123801.mp4', 'http://timg.bdta.pro/images/0eec75f27a3b38295b223cc876b47822.jpg'),
(33372, 2282, '19-2 S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123802.mp4', 'http://timg.bdta.pro/images/b4afedc3fbde26e99a76b65a1901fcab.jpg'),
(33373, 2282, '19-2 S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123803.mp4', 'http://timg.bdta.pro/images/a4a5c32ef4868ac86a9fb39b88e8a1d2.jpg'),
(33374, 2282, '19-2 S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123804.mp4', 'http://timg.bdta.pro/images/5d3f729dae5eba494fdc1be30eea2dd2.jpg'),
(33375, 2282, '19-2 S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123805.mp4', 'http://timg.bdta.pro/images/7482199f9d0828def85c58162bdc33aa.jpg'),
(33376, 2282, '19-2 S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123806.mp4', 'http://timg.bdta.pro/images/4896edf01457955295efa56cd90ad15c.jpg'),
(33377, 2282, '19-2 S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123807.mp4', 'http://timg.bdta.pro/images/b97762fc274badaef9b30cca261989f0.jpg'),
(33378, 2282, '19-2 S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123808.mp4', 'http://timg.bdta.pro/images/5ce8d8660678935404f2be68fb4af021.jpg'),
(33379, 2282, '19-2 S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123809.mp4', 'http://timg.bdta.pro/images/898a217b3b360a8c68d2c133bf9278e4.jpg'),
(33380, 2283, '19-2 S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123810.mp4', 'http://timg.bdta.pro/images/488a260df1b37dcb8c2cf44dbd4a0da7.jpg'),
(33381, 2283, '19-2 S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123811.mp4', 'http://timg.bdta.pro/images/e250f3e34575bd16deee2a47b3a8abd5.jpg'),
(33382, 2283, '19-2 S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123812.mp4', 'http://timg.bdta.pro/images/e250f3e34575bd16deee2a47b3a8abd5.jpg'),
(33383, 2283, '19-2 S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123813.mp4', 'http://timg.bdta.pro/images/e250f3e34575bd16deee2a47b3a8abd5.jpg'),
(33384, 2283, '19-2 S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123814.mp4', 'http://timg.bdta.pro/images/e250f3e34575bd16deee2a47b3a8abd5.jpg'),
(33385, 2283, '19-2 S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123815.mp4', 'http://timg.bdta.pro/images/e250f3e34575bd16deee2a47b3a8abd5.jpg'),
(33386, 2283, '19-2 S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123816.mp4', 'http://timg.bdta.pro/images/e250f3e34575bd16deee2a47b3a8abd5.jpg'),
(33387, 2283, '19-2 S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123817.mp4', 'http://timg.bdta.pro/images/e250f3e34575bd16deee2a47b3a8abd5.jpg'),
(33388, 2284, 'A Favorita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6goaIdTwHhI5aGiS9Q1nZixn0La.jpg'),
(33389, 2284, 'A Favorita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/46SAWTZfldMf3KJu6DmX2fdVwy8.jpg'),
(33390, 2284, 'A Favorita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5S1rw2fPl9MNEXyalD3yExGIKZ6.jpg'),
(33391, 2284, 'A Favorita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mKcR9cEBZTHU6BIEP0IMfgWNsTW.jpg'),
(33392, 2284, 'A Favorita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2IQPVKI0Ghaq70Cq0VawhOub5c0.jpg'),
(33393, 2284, 'A Favorita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kNsgx1guLI5VpCnFYVxBsVtDpFh.jpg'),
(33394, 2284, 'A Favorita S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/162268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUwsz30bVup3aQDz8Ox56NPblkn.jpg'),
(33395, 2284, 'A Favorita S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/162269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eSBmcV1XqyzCB1rjDGgQF5dDRgT.jpg'),
(33396, 2284, 'A Favorita S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/162270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbt1dOG61FNIc5y6wywf6MxRRhy.jpg'),
(33397, 2284, 'A Favorita S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/162271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mBFfPyyQ6sbR1fOoEHFTA8qVJb4.jpg'),
(33398, 2284, 'A Favorita S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/162272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o6nrKeVISbfDWFPqohgRsvLBgDd.jpg'),
(33399, 2284, 'A Favorita S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/162273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y4blxuJvVLipkeobo0cqwrFW6fB.jpg'),
(33400, 2284, 'A Favorita S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/162274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4au6vOPqEBRKMWIg4aIQuuK5M3r.jpg'),
(33401, 2284, 'A Favorita S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/162275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hAcsOkd9XZhrqi8Mpl0r6JUt5Qx.jpg'),
(33402, 2284, 'A Favorita S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/162276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9qcuJhp4dcF8BGprwiYdZlZDHkd.jpg'),
(33403, 2284, 'A Favorita S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/162277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/832aeJaxa8urywGE7Sy0RJVVDkK.jpg'),
(33404, 2284, 'A Favorita S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/162278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zE1rcu8YLwH1shOJGktyxL7wtKr.jpg'),
(33405, 2284, 'A Favorita S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/162279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vmWM4gIclpuPZZ2bEK4bc5gjRV.jpg'),
(33406, 2284, 'A Favorita S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/162280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tLnKIn4eNwYDNoHX79mRftSk69j.jpg'),
(33407, 2284, 'A Favorita S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/162281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a1NQRTwQ5fxnkOTaigLiOzey6OG.jpg'),
(33408, 2284, 'A Favorita S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/162282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZqamDczDfj1LAp41abaZQl1VmV.jpg'),
(33409, 2284, 'A Favorita S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/162283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nCQigB5mELS3xUwrYZuOBUF7V3I.jpg'),
(33410, 2284, 'A Favorita S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/162284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6BFocc6mjNpamGPLGd8rwxklI6F.jpg'),
(33411, 2284, 'A Favorita S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/162285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5oaLdvB2xP4Gzq4t3sP2CNGFo3g.jpg'),
(33412, 2284, 'A Favorita S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/162286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13UJDYUrSs8h2bYgydzonsAZxMV.jpg'),
(33413, 2284, 'A Favorita S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/162287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ilqVy9IMOjgKEFZhsun2996PQuA.jpg'),
(33414, 2284, 'A Favorita S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/162288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7xSk3kooAdZPSxV2DrCfSNCKBh1.jpg'),
(33415, 2284, 'A Favorita S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/162289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/14LF9H4LmScsiM2npEiQZ8MSDou.jpg'),
(33416, 2284, 'A Favorita S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/162290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eb6NzBY7BDpdL3Tomrxmq6DAdfG.jpg'),
(33417, 2284, 'A Favorita S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/162291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rKcwlq4iOWtJT1y6cILkAXSmTua.jpg'),
(33418, 2284, 'A Favorita S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/162292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0eaub84VYUi0sBfRucdLc0BPI2.jpg'),
(33419, 2284, 'A Favorita S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/162293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gcDpDBOMyr9cIU45evWOq4EDpWH.jpg'),
(33420, 2284, 'A Favorita S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/162294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11M39h9ooBAKPBc5CIO0bFRK3Uh.jpg'),
(33421, 2284, 'A Favorita S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/162295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBiqh823jIcXSun5jLRP5j1FFnc.jpg'),
(33422, 2284, 'A Favorita S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/162296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rPCMyuBsJhwXCIUXteOblEnx98q.jpg'),
(33423, 2284, 'A Favorita S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/162297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xz3l8c5JgGE5sBKnKMWQqGg8v7S.jpg'),
(33424, 2284, 'A Favorita S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/162298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vsCqeKsW3bZf5hOKqZ3PWbJtPkZ.jpg'),
(33425, 2284, 'A Favorita S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/162299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mISdIGfsMxs6KWkvn3ydsWa0oSf.jpg'),
(33426, 2284, 'A Favorita S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/162300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zZMWSPLwZMsRcrrkiCu5n0JG7QJ.jpg'),
(33427, 2284, 'A Favorita S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/162301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9aoZ3bg4tdcHKhhH9q8zzOHEZIL.jpg'),
(33428, 2284, 'A Favorita S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/162302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pRjzF6GNu9RrRRgerLWcsPYqrE3.jpg'),
(33429, 2284, 'A Favorita S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/162303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i1uGb3seOFzdxNiemtlfrzHLk1S.jpg'),
(33430, 2284, 'A Favorita S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/162304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kUNgPK7ubhM6HKLIOFs9TONjOVf.jpg'),
(33431, 2284, 'A Favorita S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/162305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gDhfHhBlDV1HyhcABzczn8iAoOJ.jpg'),
(33432, 2284, 'A Favorita S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/162306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xSFNBTh1BurBbD0MiAoYMAmoEwm.jpg'),
(33433, 2284, 'A Favorita S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/162307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dOvJsJISohMUZ5SHc9I1mQNmt9D.jpg'),
(33434, 2284, 'A Favorita S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/162308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rttBtdZfIXljWNcEScmQaBpN3C2.jpg'),
(33435, 2284, 'A Favorita S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/162309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/emvAYJyGZDrp5KbxeJ369wjzdpA.jpg'),
(33436, 2284, 'A Favorita S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/162310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8p0mrMViptpTmmFMGxTOI2J6dUe.jpg'),
(33437, 2284, 'A Favorita S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/162311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uOo85zTXpFdfYP9nqMRZOPnaMiT.jpg'),
(33438, 2284, 'A Favorita S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/162312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vfxzc8LPkhvXMx2rnbnqpiDom5B.jpg'),
(33439, 2284, 'A Favorita S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/162313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tfYItqzQi5kvF3ec7cgSlokzQrz.jpg'),
(33440, 2284, 'A Favorita S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/162314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/59WZzYaewSV1DKY7BK2J6wsd9Yt.jpg'),
(33441, 2284, 'A Favorita S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/162315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/KfItEZuGo8kktIbPYcr2KJGeSR.jpg'),
(33442, 2284, 'A Favorita S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/162316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qsGlyYesIOKXnbVIVRbnRoRmT8p.jpg'),
(33443, 2284, 'A Favorita S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/162317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pRKqfof9NMN5qoXEcMPTZgU5kht.jpg'),
(33444, 2284, 'A Favorita S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/162318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vWjVTKAJxqnUI6dqSzXZs22Cc3X.jpg'),
(33445, 2284, 'A Favorita S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/162319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o78lxq2VvlbyZ85NfO7UxZD3SHI.jpg'),
(33446, 2284, 'A Favorita S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/162320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mv8aePICRfNS4c4Ir1EiF2bjqrn.jpg'),
(33447, 2284, 'A Favorita S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/162321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLJipQF9o9uSh0yp6077ipztEUF.jpg'),
(33448, 2284, 'A Favorita S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/162322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mpx9H41XbKmIldrf1xXohq0jBo3.jpg'),
(33449, 2284, 'A Favorita S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/162323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4HKwLwu2xA0Mv1MnKtQkFeTSA8A.jpg'),
(33450, 2284, 'A Favorita S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/162324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/PIDtGmGA05T7UioZvcY2tKR05A.jpg'),
(33451, 2284, 'A Favorita S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/162325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wneZXSoYP65PopqiorM0n1aTrjc.jpg'),
(33452, 2284, 'A Favorita S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/162326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5kZaOlY5WTUZN2YrqUqtXs3cWuz.jpg'),
(33453, 2284, 'A Favorita S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/162327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mkQWHUB3Q8hcRiBATEl7yygjxzm.jpg'),
(33454, 2284, 'A Favorita S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/162328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yAuII7S0mpuwsMXVDM0icdYSmKB.jpg'),
(33455, 2284, 'A Favorita S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/162329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bs176ku0z1NZwM8rQoEs7Fa6M3.jpg'),
(33456, 2284, 'A Favorita S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/162330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bYDq8gqFOceoSEKDsRlRCcbVBLu.jpg'),
(33457, 2284, 'A Favorita S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/162331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eoTXqIEbhM2uPj6KIRHxCWbxbdQ.jpg'),
(33458, 2284, 'A Favorita S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/162332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/53ODHeDeE2unRK8RH5yKv8f6gyf.jpg'),
(33459, 2284, 'A Favorita S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/162333.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33460, 2284, 'A Favorita S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/162334.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33461, 2284, 'A Favorita S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/162335.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33462, 2284, 'A Favorita S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/162336.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33463, 2284, 'A Favorita S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/162337.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33464, 2284, 'A Favorita S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/162338.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33465, 2284, 'A Favorita S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/162339.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33466, 2284, 'A Favorita S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/162340.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33467, 2284, 'A Favorita S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/162341.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33468, 2284, 'A Favorita S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/162342.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33469, 2284, 'A Favorita S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/162343.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33470, 2284, 'A Favorita S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/162344.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33471, 2284, 'A Favorita S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/162345.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33472, 2284, 'A Favorita S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/162346.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33473, 2284, 'A Favorita S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/162347.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33474, 2284, 'A Favorita S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/162348.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33475, 2284, 'A Favorita S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/162349.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33476, 2284, 'A Favorita S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/162350.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33477, 2284, 'A Favorita S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/162351.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33478, 2284, 'A Favorita S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/162352.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33479, 2284, 'A Favorita S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/162353.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33480, 2284, 'A Favorita S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/162354.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33481, 2284, 'A Favorita S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/162355.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33482, 2284, 'A Favorita S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/162356.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33483, 2284, 'A Favorita S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/162357.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33484, 2284, 'A Favorita S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/162358.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33485, 2284, 'A Favorita S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/162359.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33486, 2284, 'A Favorita S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/162360.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33487, 2284, 'A Favorita S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/162361.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33488, 2284, 'A Favorita S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/162362.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33489, 2284, 'A Favorita S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/162363.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33490, 2284, 'A Favorita S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/162364.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33491, 2284, 'A Favorita S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/162365.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33492, 2284, 'A Favorita S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/162366.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33493, 2284, 'A Favorita S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/162367.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33494, 2284, 'A Favorita S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/162368.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33495, 2284, 'A Favorita S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/162369.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33496, 2284, 'A Favorita S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/162370.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33497, 2284, 'A Favorita S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/162371.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33498, 2284, 'A Favorita S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/162372.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33499, 2284, 'A Favorita S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/162373.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33500, 2284, 'A Favorita S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/162374.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33501, 2284, 'A Favorita S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/162375.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33502, 2284, 'A Favorita S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/162376.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33503, 2284, 'A Favorita S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/162377.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33504, 2284, 'A Favorita S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/162378.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33505, 2284, 'A Favorita S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/162379.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33506, 2284, 'A Favorita S01 E119', 'http://sinalprivado.info:80/series/1533784/1533784/162380.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33507, 2284, 'A Favorita S01 E120', 'http://sinalprivado.info:80/series/1533784/1533784/162381.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33508, 2284, 'A Favorita S01 E121', 'http://sinalprivado.info:80/series/1533784/1533784/162382.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33509, 2284, 'A Favorita S01 E122', 'http://sinalprivado.info:80/series/1533784/1533784/162383.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33510, 2284, 'A Favorita S01 E123', 'http://sinalprivado.info:80/series/1533784/1533784/162384.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33511, 2284, 'A Favorita S01 E124', 'http://sinalprivado.info:80/series/1533784/1533784/162385.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33512, 2284, 'A Favorita S01 E125', 'http://sinalprivado.info:80/series/1533784/1533784/162386.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33513, 2284, 'A Favorita S01 E126', 'http://sinalprivado.info:80/series/1533784/1533784/162387.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33514, 2284, 'A Favorita S01 E127', 'http://sinalprivado.info:80/series/1533784/1533784/162388.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33515, 2284, 'A Favorita S01 E128', 'http://sinalprivado.info:80/series/1533784/1533784/162389.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33516, 2284, 'A Favorita S01 E129', 'http://sinalprivado.info:80/series/1533784/1533784/162390.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33517, 2284, 'A Favorita S01 E130', 'http://sinalprivado.info:80/series/1533784/1533784/162391.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33518, 2284, 'A Favorita S01 E131', 'http://sinalprivado.info:80/series/1533784/1533784/162392.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33519, 2284, 'A Favorita S01 E132', 'http://sinalprivado.info:80/series/1533784/1533784/162393.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33520, 2284, 'A Favorita S01 E133', 'http://sinalprivado.info:80/series/1533784/1533784/162394.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33521, 2284, 'A Favorita S01 E134', 'http://sinalprivado.info:80/series/1533784/1533784/162395.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33522, 2284, 'A Favorita S01 E135', 'http://sinalprivado.info:80/series/1533784/1533784/162396.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33523, 2284, 'A Favorita S01 E136', 'http://sinalprivado.info:80/series/1533784/1533784/162397.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33524, 2284, 'A Favorita S01 E137', 'http://sinalprivado.info:80/series/1533784/1533784/162398.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33525, 2284, 'A Favorita S01 E138', 'http://sinalprivado.info:80/series/1533784/1533784/162399.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33526, 2284, 'A Favorita S01 E139', 'http://sinalprivado.info:80/series/1533784/1533784/162400.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33527, 2284, 'A Favorita S01 E140', 'http://sinalprivado.info:80/series/1533784/1533784/162401.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33528, 2284, 'A Favorita S01 E141', 'http://sinalprivado.info:80/series/1533784/1533784/162402.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33529, 2284, 'A Favorita S01 E142', 'http://sinalprivado.info:80/series/1533784/1533784/162403.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33530, 2284, 'A Favorita S01 E143', 'http://sinalprivado.info:80/series/1533784/1533784/162404.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33531, 2284, 'A Favorita S01 E144', 'http://sinalprivado.info:80/series/1533784/1533784/162405.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33532, 2284, 'A Favorita S01 E145', 'http://sinalprivado.info:80/series/1533784/1533784/162406.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33533, 2284, 'A Favorita S01 E146', 'http://sinalprivado.info:80/series/1533784/1533784/162407.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33534, 2284, 'A Favorita S01 E147', 'http://sinalprivado.info:80/series/1533784/1533784/162408.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33535, 2284, 'A Favorita S01 E148', 'http://sinalprivado.info:80/series/1533784/1533784/162409.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33536, 2284, 'A Favorita S01 E149', 'http://sinalprivado.info:80/series/1533784/1533784/162410.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33537, 2284, 'A Favorita S01 E150', 'http://sinalprivado.info:80/series/1533784/1533784/162411.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33538, 2284, 'A Favorita S01 E151', 'http://sinalprivado.info:80/series/1533784/1533784/162412.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33539, 2284, 'A Favorita S01 E152', 'http://sinalprivado.info:80/series/1533784/1533784/162413.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33540, 2284, 'A Favorita S01 E153', 'http://sinalprivado.info:80/series/1533784/1533784/162414.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33541, 2284, 'A Favorita S01 E154', 'http://sinalprivado.info:80/series/1533784/1533784/162415.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33542, 2284, 'A Favorita S01 E155', 'http://sinalprivado.info:80/series/1533784/1533784/162416.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33543, 2284, 'A Favorita S01 E156', 'http://sinalprivado.info:80/series/1533784/1533784/162417.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33544, 2284, 'A Favorita S01 E157', 'http://sinalprivado.info:80/series/1533784/1533784/162418.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33545, 2284, 'A Favorita S01 E158', 'http://sinalprivado.info:80/series/1533784/1533784/162419.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33546, 2284, 'A Favorita S01 E159', 'http://sinalprivado.info:80/series/1533784/1533784/162420.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33547, 2284, 'A Favorita S01 E160', 'http://sinalprivado.info:80/series/1533784/1533784/162421.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33548, 2284, 'A Favorita S01 E161', 'http://sinalprivado.info:80/series/1533784/1533784/162422.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33549, 2284, 'A Favorita S01 E162', 'http://sinalprivado.info:80/series/1533784/1533784/162423.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33550, 2284, 'A Favorita S01 E163', 'http://sinalprivado.info:80/series/1533784/1533784/162424.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33551, 2284, 'A Favorita S01 E164', 'http://sinalprivado.info:80/series/1533784/1533784/162425.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33552, 2284, 'A Favorita S01 E165', 'http://sinalprivado.info:80/series/1533784/1533784/162426.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33553, 2284, 'A Favorita S01 E166', 'http://sinalprivado.info:80/series/1533784/1533784/162427.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33554, 2284, 'A Favorita S01 E167', 'http://sinalprivado.info:80/series/1533784/1533784/162428.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33555, 2284, 'A Favorita S01 E168', 'http://sinalprivado.info:80/series/1533784/1533784/162429.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33556, 2284, 'A Favorita S01 E169', 'http://sinalprivado.info:80/series/1533784/1533784/162430.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33557, 2284, 'A Favorita S01 E170', 'http://sinalprivado.info:80/series/1533784/1533784/162431.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33558, 2284, 'A Favorita S01 E171', 'http://sinalprivado.info:80/series/1533784/1533784/162432.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33559, 2284, 'A Favorita S01 E172', 'http://sinalprivado.info:80/series/1533784/1533784/162433.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33560, 2284, 'A Favorita S01 E173', 'http://sinalprivado.info:80/series/1533784/1533784/162434.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33561, 2284, 'A Favorita S01 E174', 'http://sinalprivado.info:80/series/1533784/1533784/162435.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33562, 2284, 'A Favorita S01 E175', 'http://sinalprivado.info:80/series/1533784/1533784/162436.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33563, 2284, 'A Favorita S01 E176', 'http://sinalprivado.info:80/series/1533784/1533784/162437.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33564, 2284, 'A Favorita S01 E177', 'http://sinalprivado.info:80/series/1533784/1533784/162438.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33565, 2284, 'A Favorita S01 E178', 'http://sinalprivado.info:80/series/1533784/1533784/162439.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33566, 2284, 'A Favorita S01 E179', 'http://sinalprivado.info:80/series/1533784/1533784/162440.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33567, 2284, 'A Favorita S01 E180', 'http://sinalprivado.info:80/series/1533784/1533784/162441.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33568, 2284, 'A Favorita S01 E181', 'http://sinalprivado.info:80/series/1533784/1533784/162442.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33569, 2284, 'A Favorita S01 E182', 'http://sinalprivado.info:80/series/1533784/1533784/162443.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33570, 2284, 'A Favorita S01 E183', 'http://sinalprivado.info:80/series/1533784/1533784/162444.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33571, 2284, 'A Favorita S01 E184', 'http://sinalprivado.info:80/series/1533784/1533784/162445.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33572, 2284, 'A Favorita S01 E185', 'http://sinalprivado.info:80/series/1533784/1533784/162446.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33573, 2284, 'A Favorita S01 E186', 'http://sinalprivado.info:80/series/1533784/1533784/162447.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33574, 2284, 'A Favorita S01 E187', 'http://sinalprivado.info:80/series/1533784/1533784/162448.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33575, 2284, 'A Favorita S01 E188', 'http://sinalprivado.info:80/series/1533784/1533784/162449.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33576, 2284, 'A Favorita S01 E189', 'http://sinalprivado.info:80/series/1533784/1533784/162450.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33577, 2284, 'A Favorita S01 E190', 'http://sinalprivado.info:80/series/1533784/1533784/162451.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33578, 2284, 'A Favorita S01 E191', 'http://sinalprivado.info:80/series/1533784/1533784/162452.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33579, 2284, 'A Favorita S01 E192', 'http://sinalprivado.info:80/series/1533784/1533784/162453.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33580, 2284, 'A Favorita S01 E193', 'http://sinalprivado.info:80/series/1533784/1533784/162454.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33581, 2284, 'A Favorita S01 E194', 'http://sinalprivado.info:80/series/1533784/1533784/162455.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33582, 2284, 'A Favorita S01 E195', 'http://sinalprivado.info:80/series/1533784/1533784/162456.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33583, 2284, 'A Favorita S01 E196', 'http://sinalprivado.info:80/series/1533784/1533784/162457.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33584, 2284, 'A Favorita S01 E197', 'http://sinalprivado.info:80/series/1533784/1533784/162458.mp4', 'http://gstaticontent.com/images/19aeBWMyI8nZczAAbcF1oMUZLMk_big.jpg'),
(33585, 2285, 'American Housewife S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136841.mp4', 'http://timg.bdta.pro/images/52cfbe21a19b7ade2268b253f854e72f.jpg'),
(33586, 2285, 'American Housewife S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136842.mp4', 'http://timg.bdta.pro/images/e327c8297be9036c0f3968c6549b3507.jpg'),
(33587, 2285, 'American Housewife S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136843.mp4', 'http://timg.bdta.pro/images/443aafaab88203ddbf12476ba8452bb6.jpg'),
(33588, 2285, 'American Housewife S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136844.mp4', 'http://timg.bdta.pro/images/b3b620cd4a41ef55cffe718561bdf501.jpg'),
(33589, 2285, 'American Housewife S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136845.mp4', 'http://timg.bdta.pro/images/28060a4ad41bd1a8f374cee97ff420bd.jpg'),
(33590, 2285, 'American Housewife S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136846.mp4', 'http://timg.bdta.pro/images/a411f68f82f4ba3aba202cc5519e851a.jpg'),
(33591, 2285, 'American Housewife S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136847.mp4', 'http://timg.bdta.pro/images/21b67d18304531bcfb1c2037b2489ded.jpg'),
(33592, 2285, 'American Housewife S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136848.mp4', 'http://timg.bdta.pro/images/060775ff6bf969e8b65ade0a67e277b7.jpg'),
(33593, 2285, 'American Housewife S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136849.mp4', 'http://timg.bdta.pro/images/213c162b0660e31a0e62806171838d0a.jpg'),
(33594, 2285, 'American Housewife S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136850.mp4', 'http://timg.bdta.pro/images/c3ba3021b0aec969183fad17006fbffc.jpg'),
(33595, 2285, 'American Housewife S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136851.mp4', 'http://timg.bdta.pro/images/d615f3655e1ecd6911ea02b6f28b61cc.jpg'),
(33596, 2285, 'American Housewife S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136852.mp4', 'http://timg.bdta.pro/images/2e3bcf2d3f9d65dbea478607b594be0e.jpg'),
(33597, 2285, 'American Housewife S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136853.mp4', 'http://timg.bdta.pro/images/d7dfa594d982afb76c6759c69d3ad8a6.jpg'),
(33598, 2285, 'American Housewife S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/136854.mp4', 'http://timg.bdta.pro/images/b1930d8f7269fe83cc846fcd5fef9d03.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(33599, 2285, 'American Housewife S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/136855.mp4', 'http://timg.bdta.pro/images/590bf3c98defc8e9d983eac590d00b85.jpg'),
(33600, 2285, 'American Housewife S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/136856.mp4', 'http://timg.bdta.pro/images/af1a6ba0d3fce5dbc46d27a2b13cb1a7.jpg'),
(33601, 2285, 'American Housewife S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/136857.mp4', 'http://timg.bdta.pro/images/b987720780e8ee0e39e177af71b611ef.jpg'),
(33602, 2285, 'American Housewife S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/136858.mp4', 'http://timg.bdta.pro/images/5b1de9a0ed1e68bf3352a9dec1b30f4b.jpg'),
(33603, 2285, 'American Housewife S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/136859.mp4', 'http://timg.bdta.pro/images/468e2e94b5ec83ccae0e40fce6cad4c4.jpg'),
(33604, 2285, 'American Housewife S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/136860.mp4', 'http://timg.bdta.pro/images/460fa0a45d943e5b49578e9ed5faeb72.jpg'),
(33605, 2285, 'American Housewife S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/136861.mp4', 'http://timg.bdta.pro/images/1fb4e52c20d1c996c7fff8eafd256973.jpg'),
(33606, 2285, 'American Housewife S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/136862.mp4', 'http://timg.bdta.pro/images/8afe7e20700dd9510ff5ca681e4d4b4b.jpg'),
(33607, 2285, 'American Housewife S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/136863.mp4', 'http://timg.bdta.pro/images/a7d2a2a62400850d3b3d15257aff5d6a.jpg'),
(33608, 2286, 'American Housewife S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136864.mp4', 'http://timg.bdta.pro/images/d45a98a798ac00427b477a65f27bce8e.jpg'),
(33609, 2286, 'American Housewife S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136865.mp4', 'http://timg.bdta.pro/images/fdafe128f4619437204449219485a898.jpg'),
(33610, 2286, 'American Housewife S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136866.mp4', 'http://timg.bdta.pro/images/67c36a67aeeacb97d3e6e05ef37eb28d.jpg'),
(33611, 2286, 'American Housewife S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136867.mp4', 'http://timg.bdta.pro/images/699aed7592159331ada2525f90cbea4a.jpg'),
(33612, 2286, 'American Housewife S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136868.mp4', 'http://timg.bdta.pro/images/e4b22d8420b3a3a332da69e6b2fb477b.jpg'),
(33613, 2286, 'American Housewife S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136869.mp4', 'http://timg.bdta.pro/images/490fccadfa08c25d96ba3cc8a3508f88.jpg'),
(33614, 2286, 'American Housewife S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136870.mp4', 'http://timg.bdta.pro/images/5719b95414fb5d272530f29558835c40.jpg'),
(33615, 2286, 'American Housewife S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136871.mp4', 'http://timg.bdta.pro/images/d88350f5cf69a41251c868a491ed70bb.jpg'),
(33616, 2286, 'American Housewife S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136872.mp4', 'http://timg.bdta.pro/images/e87301fe7473f755938c6de7fa785067.jpg'),
(33617, 2286, 'American Housewife S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136873.mp4', 'http://timg.bdta.pro/images/3db4ce956dbb132ff7878ff82f85cba8.jpg'),
(33618, 2286, 'American Housewife S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136874.mp4', 'http://timg.bdta.pro/images/f8f09aef79234799ec189041f7714bee.jpg'),
(33619, 2286, 'American Housewife S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136875.mp4', 'http://timg.bdta.pro/images/bdb4b6c3a73f7313fa65cf42b4556a68.jpg'),
(33620, 2286, 'American Housewife S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136876.mp4', 'http://timg.bdta.pro/images/f8cf6e0c259bc101a173be0c32c9db7b.jpg'),
(33621, 2286, 'American Housewife S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/136877.mp4', 'http://timg.bdta.pro/images/14eaf34a71c964eafbe22a8766b55585.jpg'),
(33622, 2286, 'American Housewife S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/136878.mp4', 'http://timg.bdta.pro/images/451a60175699dc1234758aed8fbd4edd.jpg'),
(33623, 2286, 'American Housewife S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/136879.mp4', 'http://timg.bdta.pro/images/76ff0df8f9d2bc147e305870c65c623e.jpg'),
(33624, 2286, 'American Housewife S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/136880.mp4', 'http://timg.bdta.pro/images/4defef224d08f5151f0cd4070bcd00bf.jpg'),
(33625, 2286, 'American Housewife S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/136881.mp4', 'http://timg.bdta.pro/images/eda78d4eaf58bc6122447ec3d1fd7fe6.jpg'),
(33626, 2286, 'American Housewife S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/136882.mp4', 'http://timg.bdta.pro/images/6ed6ee11f0854f1bb1c478e7bdb94d03.jpg'),
(33627, 2286, 'American Housewife S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/136883.mp4', 'http://timg.bdta.pro/images/f3672df3b2d403faaf0cc514a3bc56c3.jpg'),
(33628, 2286, 'American Housewife S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/136884.mp4', 'http://timg.bdta.pro/images/92468599f62f0052b073edead337ffcb.jpg'),
(33629, 2286, 'American Housewife S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/136885.mp4', 'http://timg.bdta.pro/images/0682ff77260f1c6ecc63a40f70671744.jpg'),
(33630, 2286, 'American Housewife S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/136886.mp4', 'http://timg.bdta.pro/images/d73ed7b49834e12b1c7e872d31fb76ce.jpg'),
(33631, 2286, 'American Housewife S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/136887.mp4', 'http://timg.bdta.pro/images/f318f7bce3fa4c5cad5b10c280c22cec.jpg'),
(33632, 2287, 'American Housewife S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136888.mp4', 'http://timg.bdta.pro/images/df6748b744faeb6fbf1110cd52d11c5a.jpg'),
(33633, 2287, 'American Housewife S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136889.mp4', 'http://timg.bdta.pro/images/5dc08ebab231ff7e24c0f5f491a1c9f4.jpg'),
(33634, 2287, 'American Housewife S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136890.mp4', 'http://timg.bdta.pro/images/96063071e3f630cea7f9c4c0f59cffc4.jpg'),
(33635, 2287, 'American Housewife S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136891.mp4', 'http://timg.bdta.pro/images/ae987b773a80f616ace890bb636031cb.jpg'),
(33636, 2287, 'American Housewife S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136892.mp4', 'http://timg.bdta.pro/images/b14b8a4976571eb096541a9ba173e6e1.jpg'),
(33637, 2287, 'American Housewife S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136893.mp4', 'http://timg.bdta.pro/images/32de9ee5a25381593c694b2453e45cbd.jpg'),
(33638, 2287, 'American Housewife S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136894.mp4', 'http://timg.bdta.pro/images/9e003181dee66480a502b0d658e73ff0.jpg'),
(33639, 2287, 'American Housewife S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136895.mp4', 'http://timg.bdta.pro/images/13b71db8597140503e59970e023120a3.jpg'),
(33640, 2287, 'American Housewife S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136896.mp4', 'http://timg.bdta.pro/images/1e24d9af89fd1e6ede1c16014f5279ef.jpg'),
(33641, 2287, 'American Housewife S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136897.mp4', 'http://timg.bdta.pro/images/ea917e787313ddda120b00a071103ef6.jpg'),
(33642, 2287, 'American Housewife S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136898.mp4', 'http://timg.bdta.pro/images/aae1137a0c81cdc3ca24f6698549a897.jpg'),
(33643, 2287, 'American Housewife S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136899.mp4', 'http://timg.bdta.pro/images/dc18ce32bc13b19d5918ef187c685c57.jpg'),
(33644, 2287, 'American Housewife S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136900.mp4', 'http://timg.bdta.pro/images/425212fbcda2e5b14bbf530a591ab7b1.jpg'),
(33645, 2287, 'American Housewife S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/136901.mp4', 'http://timg.bdta.pro/images/45446031d79c4694cd2304d0e850cca1.jpg'),
(33646, 2287, 'American Housewife S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/136902.mp4', 'http://timg.bdta.pro/images/eda19d37ccbf810b93179e69353379da.jpg'),
(33647, 2287, 'American Housewife S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/136903.mp4', 'http://timg.bdta.pro/images/691b161b3ae6ee3b491324f814ac5246.jpg'),
(33648, 2287, 'American Housewife S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/136904.mp4', 'http://timg.bdta.pro/images/5724be31b1179955c911ad8a7bdb3766.jpg'),
(33649, 2287, 'American Housewife S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/136905.mp4', 'http://timg.bdta.pro/images/9ba25c53bb4be6fd69a6a7542b3a3b5d.jpg'),
(33650, 2287, 'American Housewife S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/136906.mp4', 'http://timg.bdta.pro/images/7fc01d526d1c0ed3a30e2303490fa8ec.jpg'),
(33651, 2287, 'American Housewife S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/136907.mp4', 'http://timg.bdta.pro/images/7eb15326c9164621fd75056b06a38ab7.jpg'),
(33652, 2287, 'American Housewife S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/136908.mp4', 'http://timg.bdta.pro/images/1998c10cb126e9e68d0517f1d43b4ee0.jpg'),
(33653, 2287, 'American Housewife S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/136909.mp4', 'http://timg.bdta.pro/images/63a0bdebc1233e7dd0eb335490e8a541.jpg'),
(33654, 2287, 'American Housewife S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/136910.mp4', 'http://timg.bdta.pro/images/bb949dab3b077de514afad2aadc02fa8.jpg'),
(33655, 2288, 'American Housewife S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136911.mp4', 'http://gstaticontent.com/images/uDXPOk3fx1kPM1tQdrTdE2f76p2_big.jpg'),
(33656, 2288, 'American Housewife S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136912.mp4', 'http://gstaticontent.com/images/uDXPOk3fx1kPM1tQdrTdE2f76p2_big.jpg'),
(33657, 2288, 'American Housewife S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136913.mp4', 'http://gstaticontent.com/images/uDXPOk3fx1kPM1tQdrTdE2f76p2_big.jpg'),
(33658, 2288, 'American Housewife S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136914.mp4', 'http://gstaticontent.com/images/uDXPOk3fx1kPM1tQdrTdE2f76p2_big.jpg'),
(33659, 2288, 'American Housewife S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136915.mp4', 'http://gstaticontent.com/images/uDXPOk3fx1kPM1tQdrTdE2f76p2_big.jpg'),
(33660, 2288, 'American Housewife S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136916.mp4', 'http://gstaticontent.com/images/uDXPOk3fx1kPM1tQdrTdE2f76p2_big.jpg'),
(33661, 2288, 'American Housewife S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136917.mp4', 'http://gstaticontent.com/images/uDXPOk3fx1kPM1tQdrTdE2f76p2_big.jpg'),
(33662, 2288, 'American Housewife S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136918.mp4', 'http://gstaticontent.com/images/uDXPOk3fx1kPM1tQdrTdE2f76p2_big.jpg'),
(33663, 2288, 'American Housewife S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136919.mp4', 'http://gstaticontent.com/images/uDXPOk3fx1kPM1tQdrTdE2f76p2_big.jpg'),
(33664, 2288, 'American Housewife S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136920.mp4', 'http://gstaticontent.com/images/uDXPOk3fx1kPM1tQdrTdE2f76p2_big.jpg'),
(33665, 2288, 'American Housewife S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136921.mp4', 'http://gstaticontent.com/images/uDXPOk3fx1kPM1tQdrTdE2f76p2_big.jpg'),
(33666, 2288, 'American Housewife S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136922.mp4', 'http://gstaticontent.com/images/uDXPOk3fx1kPM1tQdrTdE2f76p2_big.jpg'),
(33667, 2288, 'American Housewife S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136923.mp4', 'http://gstaticontent.com/images/uDXPOk3fx1kPM1tQdrTdE2f76p2_big.jpg'),
(33668, 2288, 'American Housewife S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/136924.mp4', 'http://gstaticontent.com/images/uDXPOk3fx1kPM1tQdrTdE2f76p2_big.jpg'),
(33669, 2288, 'American Housewife S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/136925.mp4', 'http://gstaticontent.com/images/uDXPOk3fx1kPM1tQdrTdE2f76p2_big.jpg'),
(33670, 2288, 'American Housewife S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/136926.mp4', 'http://gstaticontent.com/images/uDXPOk3fx1kPM1tQdrTdE2f76p2_big.jpg'),
(33671, 2288, 'American Housewife S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/136927.mp4', 'http://gstaticontent.com/images/uDXPOk3fx1kPM1tQdrTdE2f76p2_big.jpg'),
(33672, 2288, 'American Housewife S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/136928.mp4', 'http://gstaticontent.com/images/uDXPOk3fx1kPM1tQdrTdE2f76p2_big.jpg'),
(33673, 2288, 'American Housewife S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/136929.mp4', 'http://gstaticontent.com/images/uDXPOk3fx1kPM1tQdrTdE2f76p2_big.jpg'),
(33674, 2288, 'American Housewife S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/136930.mp4', 'http://gstaticontent.com/images/uDXPOk3fx1kPM1tQdrTdE2f76p2_big.jpg'),
(33675, 2289, 'As Grandes Ferias Grandes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123818.mp4', 'http://gstaticontent.com/images/jXi1duk0nD3rByuEx4AUuJVlsIT_big.jpg'),
(33676, 2289, 'As Grandes Ferias Grandes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123819.mp4', 'http://gstaticontent.com/images/jXi1duk0nD3rByuEx4AUuJVlsIT_big.jpg'),
(33677, 2289, 'As Grandes Ferias Grandes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123820.mp4', 'http://gstaticontent.com/images/jXi1duk0nD3rByuEx4AUuJVlsIT_big.jpg'),
(33678, 2289, 'As Grandes Ferias Grandes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123821.mp4', 'http://gstaticontent.com/images/jXi1duk0nD3rByuEx4AUuJVlsIT_big.jpg'),
(33679, 2289, 'As Grandes Ferias Grandes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123822.mp4', 'http://gstaticontent.com/images/jXi1duk0nD3rByuEx4AUuJVlsIT_big.jpg'),
(33680, 2290, 'Avatar: A Lenda de Aang S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123823.mp4', 'http://timg.bdta.pro/images/6e1847c46101afd9051179c4e7675266.jpg'),
(33681, 2290, 'Avatar: A Lenda de Aang S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123824.mp4', 'http://timg.bdta.pro/images/93a06254b31018ec40f4ef7fc963723c.jpg'),
(33682, 2290, 'Avatar: A Lenda de Aang S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123825.mp4', 'http://timg.bdta.pro/images/9b9bb88f7f1652def8ff4904391b70ad.jpg'),
(33683, 2290, 'Avatar: A Lenda de Aang S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123826.mp4', 'http://timg.bdta.pro/images/814fcdcfe7051758e4397fbb9a320bb9.jpg'),
(33684, 2290, 'Avatar: A Lenda de Aang S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123827.mp4', 'http://timg.bdta.pro/images/7f3d9dcdc69d2bdc8d573261e2687f2f.jpg'),
(33685, 2290, 'Avatar: A Lenda de Aang S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123828.mp4', 'http://timg.bdta.pro/images/563e38af6eea318372aa92ff4ee73de4.jpg'),
(33686, 2290, 'Avatar: A Lenda de Aang S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123829.mp4', 'http://timg.bdta.pro/images/0a548b2f0bcab95d2845d688130707e9.jpg'),
(33687, 2290, 'Avatar: A Lenda de Aang S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123830.mp4', 'http://timg.bdta.pro/images/42cec453ad5c8b70b63ff3d18c82db1b.jpg'),
(33688, 2290, 'Avatar: A Lenda de Aang S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123831.mp4', 'http://timg.bdta.pro/images/59e94cbefa33ec97c20142cbd7a7e50c.jpg'),
(33689, 2290, 'Avatar: A Lenda de Aang S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123832.mp4', 'http://timg.bdta.pro/images/f89a5a239463d57838395b4c737b3fa1.jpg'),
(33690, 2290, 'Avatar: A Lenda de Aang S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/123833.mp4', 'http://timg.bdta.pro/images/3a97894bf11fda4fb2d19fa3c08adaba.jpg'),
(33691, 2290, 'Avatar: A Lenda de Aang S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/123834.mp4', 'http://timg.bdta.pro/images/87723f40e5e9965a82502fe91ae3a5fd.jpg'),
(33692, 2290, 'Avatar: A Lenda de Aang S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/123835.mp4', 'http://timg.bdta.pro/images/6a4026f845501ebb62f3e239aaa5f73b.jpg'),
(33693, 2290, 'Avatar: A Lenda de Aang S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/123836.mp4', 'http://timg.bdta.pro/images/1d95aa86fe5d0f589eb4c7f379150cea.jpg'),
(33694, 2290, 'Avatar: A Lenda de Aang S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/123837.mp4', 'http://timg.bdta.pro/images/c690ca175c5d98d4e5ed2c6b1cdacda7.jpg'),
(33695, 2290, 'Avatar: A Lenda de Aang S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/123838.mp4', 'http://timg.bdta.pro/images/bbb6a74a057425a0a4ad2278f050f7f0.jpg'),
(33696, 2290, 'Avatar: A Lenda de Aang S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/123839.mp4', 'http://timg.bdta.pro/images/513ffe6d0bc54f93ac389b3809679ed2.jpg'),
(33697, 2290, 'Avatar: A Lenda de Aang S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/123840.mp4', 'http://timg.bdta.pro/images/e9245a8787e29197ff4d2c6f1bdf817a.jpg'),
(33698, 2290, 'Avatar: A Lenda de Aang S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/123841.mp4', 'http://timg.bdta.pro/images/8d04cf3e8b84bac9f08309ebbad59609.jpg'),
(33699, 2290, 'Avatar: A Lenda de Aang S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/123842.mp4', 'http://timg.bdta.pro/images/68b12ea477b49a43bbaad5764c811e0b.jpg'),
(33700, 2290, 'Avatar: A Lenda de Aang S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/123843.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33701, 2290, 'Avatar: A Lenda de Aang S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/123844.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33702, 2290, 'Avatar: A Lenda de Aang S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/123845.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33703, 2290, 'Avatar: A Lenda de Aang S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/123846.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33704, 2290, 'Avatar: A Lenda de Aang S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/123847.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33705, 2290, 'Avatar: A Lenda de Aang S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/123848.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33706, 2290, 'Avatar: A Lenda de Aang S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/123849.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33707, 2290, 'Avatar: A Lenda de Aang S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/123850.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33708, 2290, 'Avatar: A Lenda de Aang S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/123851.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33709, 2290, 'Avatar: A Lenda de Aang S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/123852.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33710, 2290, 'Avatar: A Lenda de Aang S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/123853.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33711, 2290, 'Avatar: A Lenda de Aang S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/123854.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33712, 2290, 'Avatar: A Lenda de Aang S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/123855.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33713, 2290, 'Avatar: A Lenda de Aang S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/123856.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33714, 2290, 'Avatar: A Lenda de Aang S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/123857.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33715, 2290, 'Avatar: A Lenda de Aang S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/123858.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33716, 2290, 'Avatar: A Lenda de Aang S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/123859.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33717, 2290, 'Avatar: A Lenda de Aang S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/123860.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33718, 2290, 'Avatar: A Lenda de Aang S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/123861.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33719, 2290, 'Avatar: A Lenda de Aang S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/123862.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33720, 2290, 'Avatar: A Lenda de Aang S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/123863.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33721, 2290, 'Avatar: A Lenda de Aang S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/123864.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33722, 2290, 'Avatar: A Lenda de Aang S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/123865.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33723, 2290, 'Avatar: A Lenda de Aang S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/123866.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33724, 2290, 'Avatar: A Lenda de Aang S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/123867.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33725, 2290, 'Avatar: A Lenda de Aang S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/123868.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33726, 2290, 'Avatar: A Lenda de Aang S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/123869.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33727, 2290, 'Avatar: A Lenda de Aang S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/123870.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33728, 2290, 'Avatar: A Lenda de Aang S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/123871.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33729, 2290, 'Avatar: A Lenda de Aang S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/123872.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33730, 2290, 'Avatar: A Lenda de Aang S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/123873.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33731, 2290, 'Avatar: A Lenda de Aang S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/123874.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33732, 2290, 'Avatar: A Lenda de Aang S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/123875.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33733, 2290, 'Avatar: A Lenda de Aang S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/123876.mp4', 'http://gstaticontent.com/images/r25xIY4gEhK6pHr6JUF51Z6UBlr_big.jpg'),
(33734, 2291, 'Boca a Boca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123877.mp4', 'http://timg.bdta.pro/images/79d7056e4dcd3e756d8d99daffdf3837.jpg'),
(33735, 2291, 'Boca a Boca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123878.mp4', 'http://timg.bdta.pro/images/fd02cbf6bca77e3f7a889f49fed11d27.jpg'),
(33736, 2291, 'Boca a Boca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123879.mp4', 'http://timg.bdta.pro/images/f45c2fd22d32297b17abc2fde97d0021.jpg'),
(33737, 2291, 'Boca a Boca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123880.mp4', 'http://timg.bdta.pro/images/823f6cb29d988d64d16a14952ec83ec9.jpg'),
(33738, 2291, 'Boca a Boca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123881.mp4', 'http://timg.bdta.pro/images/f8b7aca16fe2f27c1b55ee2dc28ae392.jpg'),
(33739, 2291, 'Boca a Boca S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123882.mp4', 'http://timg.bdta.pro/images/1d7cc95198fac18256f5bcab3d0036ce.jpg'),
(33740, 2292, 'Brave New World S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123755.mp4', 'http://timg.bdta.pro/images/64d418eaaf38a5d4eea062ef438d9002.jpg'),
(33741, 2292, 'Brave New World S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123756.mp4', 'http://timg.bdta.pro/images/206eaf0cb7087edf5d58988e30fc8b5e.jpg'),
(33742, 2292, 'Brave New World S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123757.mp4', 'http://timg.bdta.pro/images/d52bc1aa04315bdaaaaa3704380c5d42.jpg'),
(33743, 2292, 'Brave New World S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123758.mp4', 'http://timg.bdta.pro/images/dc4cc1c56b08630fca05b06b3d643e9d.jpg'),
(33744, 2292, 'Brave New World S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123759.mp4', 'http://timg.bdta.pro/images/3ed9f8a68c70d651b68ed6061e471154.jpg'),
(33745, 2292, 'Brave New World S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123760.mp4', 'http://timg.bdta.pro/images/e20bca7abd12861d47a2950f895fba1c.jpg'),
(33746, 2292, 'Brave New World S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123761.mp4', 'http://timg.bdta.pro/images/42853eaa575bd0c7adc24158c2d19de0.jpg'),
(33747, 2292, 'Brave New World S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123762.mp4', 'http://timg.bdta.pro/images/21c4e3a4b23cdad7c0f9c9a24b199e84.jpg'),
(33748, 2292, 'Brave New World S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123763.mp4', 'http://timg.bdta.pro/images/e39fbcf70889e0e763c7f37e4cc06d48.jpg'),
(33749, 2293, 'Cursed - A Lenda do Lago S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123883.mp4', 'http://timg.bdta.pro/images/9d3ac9876559be516159e4528f7ad4f7.jpg'),
(33750, 2293, 'Cursed - A Lenda do Lago S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123884.mp4', 'http://timg.bdta.pro/images/bedbc34ece5b8572abdc466c738f59e2.jpg'),
(33751, 2293, 'Cursed - A Lenda do Lago S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123885.mp4', 'http://timg.bdta.pro/images/7166d1afca7c3282684f163e08680924.jpg'),
(33752, 2293, 'Cursed - A Lenda do Lago S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123886.mp4', 'http://timg.bdta.pro/images/c89cd406afb66bf5cbc50d51877c3a6d.jpg'),
(33753, 2293, 'Cursed - A Lenda do Lago S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123887.mp4', 'http://timg.bdta.pro/images/271dfd279cfa164d18b1289820eeea63.jpg'),
(33754, 2293, 'Cursed - A Lenda do Lago S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123888.mp4', 'http://timg.bdta.pro/images/b5e778726e7b2eb7ebe262a589ae1fe9.jpg'),
(33755, 2293, 'Cursed - A Lenda do Lago S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123889.mp4', 'http://timg.bdta.pro/images/3797fbcee95ee19ae9c41e98dd80c9e2.jpg'),
(33756, 2293, 'Cursed - A Lenda do Lago S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123890.mp4', 'http://timg.bdta.pro/images/c94bff71f72bbf9748050168cb8e1242.jpg'),
(33757, 2293, 'Cursed - A Lenda do Lago S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123891.mp4', 'http://timg.bdta.pro/images/a0a767e3a3bc8f566ffb29ce5b4ca494.jpg'),
(33758, 2293, 'Cursed - A Lenda do Lago S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123892.mp4', 'http://timg.bdta.pro/images/611f9124775c4e79009d068e8eaa7852.jpg'),
(33759, 2294, 'El Presidente [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b6WwBBY16tlOgHAA4LRHVQCVdm0.jpg'),
(33760, 2294, 'El Presidente [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfQUM5CV1CHyxDgmYBqE698UPuN.jpg'),
(33761, 2294, 'El Presidente [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Xbrj2o7UjdzbYLATFJ5lUwzHmI.jpg'),
(33762, 2294, 'El Presidente [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63GDayBu7vSNeiXBCVd8453wfKN.jpg'),
(33763, 2294, 'El Presidente [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lSi77fzSZ0bqAq4G6Il7f6xjUWA.jpg'),
(33764, 2294, 'El Presidente [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wfdaJ6u7To5ewSQJWczZE8yJpPK.jpg'),
(33765, 2294, 'El Presidente [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4gqsxthCgxOYWUgNXyodYXz0uNS.jpg'),
(33766, 2294, 'El Presidente [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c0xqZak4KjctSGqMxLwjT9X2Vng.jpg'),
(33767, 2295, 'Forever S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123893.mp4', 'http://timg.bdta.pro/images/9c368ce10a512dba40fa4a044b1084ed.jpg'),
(33768, 2295, 'Forever S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123894.mp4', 'http://timg.bdta.pro/images/69e711a189477d3ef511b0d3d93af853.jpg'),
(33769, 2295, 'Forever S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123895.mp4', 'http://timg.bdta.pro/images/845349777e68e695d7dd994409099b72.jpg'),
(33770, 2295, 'Forever S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123896.mp4', 'http://timg.bdta.pro/images/51a38c4f8331703878c602abb20d88c7.jpg'),
(33771, 2295, 'Forever S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123897.mp4', 'http://timg.bdta.pro/images/aeb532a19ce211a043e8adbfb16ca39f.jpg'),
(33772, 2295, 'Forever S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123898.mp4', 'http://timg.bdta.pro/images/3954c9df438491bc25a92a8868dd6db4.jpg'),
(33773, 2295, 'Forever S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123899.mp4', 'http://timg.bdta.pro/images/43d3b137b1efbb6866937fcaf9ecbcbc.jpg'),
(33774, 2295, 'Forever S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123900.mp4', 'http://timg.bdta.pro/images/de49dcc832bfb08e874ac95a92b989b3.jpg'),
(33775, 2296, 'Heroes Reborn S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123901.mp4', 'http://timg.bdta.pro/images/2c5f692e8928f763cece2052facf1848.jpg'),
(33776, 2296, 'Heroes Reborn S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123902.mp4', 'http://timg.bdta.pro/images/773ff76c0640c696064660bffdcd67d8.jpg'),
(33777, 2296, 'Heroes Reborn S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123903.mp4', 'http://timg.bdta.pro/images/171f329cc73dd690f6092b640f3d3c05.jpg'),
(33778, 2296, 'Heroes Reborn S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123904.mp4', 'http://timg.bdta.pro/images/7745b37d0095f0ef2e2e81181338d91a.jpg'),
(33779, 2296, 'Heroes Reborn S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123905.mp4', 'http://timg.bdta.pro/images/cc6fe39b61901cc5ac353952508fd711.jpg'),
(33780, 2296, 'Heroes Reborn S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123906.mp4', 'http://timg.bdta.pro/images/febbc709b55c12e90f7df4a798d0746d.jpg'),
(33781, 2296, 'Heroes Reborn S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123907.mp4', 'http://timg.bdta.pro/images/f2c14d1afc9d72da57cc79d52bd43972.jpg'),
(33782, 2296, 'Heroes Reborn S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123908.mp4', 'http://timg.bdta.pro/images/5479c5083d9a76fb5c147043f2e531d2.jpg'),
(33783, 2296, 'Heroes Reborn S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123909.mp4', 'http://timg.bdta.pro/images/9e13abecd9db5c58bd8b6e3795d70716.jpg'),
(33784, 2296, 'Heroes Reborn S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123910.mp4', 'http://timg.bdta.pro/images/c50dcccbbf712aedd59ee3d5759315fd.jpg'),
(33785, 2296, 'Heroes Reborn S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/123911.mp4', 'http://timg.bdta.pro/images/109c57a0f7a4374f5a41db4c49a46b8b.jpg'),
(33786, 2296, 'Heroes Reborn S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/123912.mp4', 'http://timg.bdta.pro/images/3783e3051a2270adfba417ede25ee3cb.jpg'),
(33787, 2296, 'Heroes Reborn S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/123913.mp4', 'http://timg.bdta.pro/images/43584379ea55d1d45a473e85e4a7aef2.jpg'),
(33788, 2297, 'How To Survive Being Single [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123914.mp4', 'http://timg.bdta.pro/images/e79c27b52147da244161e650c8b41fc7.jpg'),
(33789, 2297, 'How To Survive Being Single [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123915.mp4', 'http://timg.bdta.pro/images/2aaab39a10153bee79ef9ef1e3c61a34.jpg'),
(33790, 2297, 'How To Survive Being Single [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123916.mp4', 'http://timg.bdta.pro/images/d508370c03d3bea510c85acadc80571c.jpg'),
(33791, 2297, 'How To Survive Being Single [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123917.mp4', 'http://timg.bdta.pro/images/4d280178637b40553245340f4488dde7.jpg'),
(33792, 2297, 'How To Survive Being Single [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123918.mp4', 'http://timg.bdta.pro/images/fee0bc7378f54c23b53b934416e3ab8e.jpg'),
(33793, 2297, 'How To Survive Being Single [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123919.mp4', 'http://timg.bdta.pro/images/c5a4184ed1e4825538745ce7f33ad36a.jpg'),
(33794, 2297, 'How To Survive Being Single [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123920.mp4', 'http://timg.bdta.pro/images/a5f7e9b742845c85d5aa3fd8133b2d67.jpg'),
(33795, 2297, 'How To Survive Being Single [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123921.mp4', 'http://timg.bdta.pro/images/c8354ec08776ef2d0ac3af726d22c77d.jpg'),
(33796, 2297, 'How To Survive Being Single [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123922.mp4', 'http://timg.bdta.pro/images/ce46b2b519f1f99ad45af0b79b8e63ce.jpg'),
(33797, 2297, 'How To Survive Being Single [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123923.mp4', 'http://timg.bdta.pro/images/ea80d9d3cd0d21acedb75dd5f67e1abf.jpg'),
(33798, 2298, 'Intelligence S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123924.mp4', 'http://timg.bdta.pro/images/7a93d74b27065d8303f9a4e3ec25adc6.jpg'),
(33799, 2298, 'Intelligence S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123925.mp4', 'http://timg.bdta.pro/images/acba1534fe9690b6e1565758e767efa5.jpg'),
(33800, 2298, 'Intelligence S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123926.mp4', 'http://timg.bdta.pro/images/2bde60960a844c741bcb4e606529c14d.jpg'),
(33801, 2298, 'Intelligence S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123927.mp4', 'http://timg.bdta.pro/images/65da3041334a53f3a2b89f2947519d35.jpg'),
(33802, 2298, 'Intelligence S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123928.mp4', 'http://timg.bdta.pro/images/7488206361fe3fbe4fee2cc2eee6ec55.jpg'),
(33803, 2298, 'Intelligence S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123929.mp4', 'http://timg.bdta.pro/images/ee83adc3573a251938ce13306a232773.jpg'),
(33804, 2299, 'Japao Submerso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123930.mp4', 'http://timg.bdta.pro/images/03b6983eb4123af25764394275a11465.jpg'),
(33805, 2299, 'Japao Submerso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123931.mp4', 'http://timg.bdta.pro/images/8a7fc0dcfc425c1f8bbcb52273d97145.jpg'),
(33806, 2299, 'Japao Submerso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123932.mp4', 'http://timg.bdta.pro/images/0e9346edb5639c985a818959634d71d7.jpg'),
(33807, 2299, 'Japao Submerso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123933.mp4', 'http://timg.bdta.pro/images/6715d6a68cb943ba864716b239e5d580.jpg'),
(33808, 2299, 'Japao Submerso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123934.mp4', 'http://timg.bdta.pro/images/da17925a8f0dcc863311dc374118a8a6.jpg'),
(33809, 2299, 'Japao Submerso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123935.mp4', 'http://timg.bdta.pro/images/a6f84de4b2d1ccacb7301c4dfa6b12b2.jpg'),
(33810, 2299, 'Japao Submerso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123936.mp4', 'http://timg.bdta.pro/images/ac55e96aaab98b6a9c6ffbf9f55f6a02.jpg'),
(33811, 2299, 'Japao Submerso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123937.mp4', 'http://timg.bdta.pro/images/eb985fd6f9bb11d4f6eb99e7c227104f.jpg'),
(33812, 2299, 'Japao Submerso S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123938.mp4', 'http://timg.bdta.pro/images/a49ed156ceeffd4cc1961f2713bf3022.jpg'),
(33813, 2299, 'Japao Submerso S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123939.mp4', 'http://timg.bdta.pro/images/2aef90aed78d898e282ad0f967aca038.jpg'),
(33814, 2300, 'Loudermilk S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123940.mp4', 'http://timg.bdta.pro/images/2924376fcc20869de0007ae0bf1b14b8.jpg'),
(33815, 2300, 'Loudermilk S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123941.mp4', 'http://timg.bdta.pro/images/3f8f1f421ae4501455d7f8b0f9ad4431.jpg'),
(33816, 2300, 'Loudermilk S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123942.mp4', 'http://timg.bdta.pro/images/ff0c6b7129c65bb3d1025e60d90214b6.jpg'),
(33817, 2300, 'Loudermilk S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123943.mp4', 'http://timg.bdta.pro/images/2209496a1fff8d02ca037ca0cd78e9a8.jpg'),
(33818, 2300, 'Loudermilk S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123944.mp4', 'http://timg.bdta.pro/images/2d723298ffb9ff151f1e9d730cd72781.jpg'),
(33819, 2300, 'Loudermilk S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123945.mp4', 'http://timg.bdta.pro/images/33a7220199b780471a176d45c87c34f7.jpg'),
(33820, 2300, 'Loudermilk S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123946.mp4', 'http://timg.bdta.pro/images/27dfd806ac2f018d085249417ee672b0.jpg'),
(33821, 2300, 'Loudermilk S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123947.mp4', 'http://timg.bdta.pro/images/09da821659aa3aee3272a9b10dd1683e.jpg'),
(33822, 2300, 'Loudermilk S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123948.mp4', 'http://timg.bdta.pro/images/486c364644a9886ffc318047cecdfe03.jpg'),
(33823, 2300, 'Loudermilk S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123949.mp4', 'http://timg.bdta.pro/images/1fa57d0d4203bdbac54e14810b06b77b.jpg'),
(33824, 2301, 'Medium S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123950.mp4', 'http://timg.bdta.pro/images/e9d2a82d1376a640810e149b81b5adba.jpg'),
(33825, 2301, 'Medium S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123951.mp4', 'http://timg.bdta.pro/images/49d23321456a9b45dc8e6323bcb7a51f.jpg'),
(33826, 2301, 'Medium S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123952.mp4', 'http://timg.bdta.pro/images/fe98fbff80db9b7e6bf0c9300fdb7cf1.jpg'),
(33827, 2301, 'Medium S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123953.mp4', 'http://timg.bdta.pro/images/973379b400884613f9432d45550ca699.jpg'),
(33828, 2301, 'Medium S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123954.mp4', 'http://timg.bdta.pro/images/e3eba71e500f03b0b31c8a864b9d7b64.jpg'),
(33829, 2301, 'Medium S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123955.mp4', 'http://timg.bdta.pro/images/68ab9741ab461564b9ad5e76c8c1ca0a.jpg'),
(33830, 2301, 'Medium S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123956.mp4', 'http://timg.bdta.pro/images/8a548405d5e97d9b83df005dae134dee.jpg'),
(33831, 2301, 'Medium S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123957.mp4', 'http://timg.bdta.pro/images/0e1960ac0b2ebd8e0c613145f48bb65d.jpg'),
(33832, 2301, 'Medium S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123958.mp4', 'http://timg.bdta.pro/images/6e61b910b72221d55c705a1165dc68d4.jpg'),
(33833, 2301, 'Medium S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123959.mp4', 'http://timg.bdta.pro/images/e6716f4faa5512005da0614686e5319a.jpg'),
(33834, 2301, 'Medium S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/123960.mp4', 'http://timg.bdta.pro/images/6a32314ca4b7af56e49cda4eae601269.jpg'),
(33835, 2301, 'Medium S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/123961.mp4', 'http://timg.bdta.pro/images/48702a7b163f484a1ec328fd2d727d81.jpg'),
(33836, 2301, 'Medium S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/123962.mp4', 'http://timg.bdta.pro/images/a5b09977f978301b09a92c28dcc4d44b.jpg'),
(33837, 2301, 'Medium S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/123963.mp4', 'http://timg.bdta.pro/images/e01c3840c630074a854e04e1656272c6.jpg'),
(33838, 2301, 'Medium S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/123964.mp4', 'http://timg.bdta.pro/images/e69d181cfc3fab92cab5ef7462d3e29f.jpg'),
(33839, 2301, 'Medium S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/123965.mp4', 'http://timg.bdta.pro/images/8b87459a4a9756c665b39e50d4325852.jpg'),
(33840, 2302, 'Medium S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123966.mp4', 'http://timg.bdta.pro/images/54438893a0df28ceb3827111c6b72c19.jpg'),
(33841, 2302, 'Medium S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123967.mp4', 'http://timg.bdta.pro/images/4685c0cdf32fff6ac124df2fc7187158.jpg'),
(33842, 2302, 'Medium S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123968.mp4', 'http://timg.bdta.pro/images/48358f29e269553f4c33787c2c2b5657.jpg'),
(33843, 2302, 'Medium S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123969.mp4', 'http://timg.bdta.pro/images/3d42fb47a6471ff36eebc256ebcc83b4.jpg'),
(33844, 2302, 'Medium S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123970.mp4', 'http://timg.bdta.pro/images/c36937085f57919e68e6e431499b8fa2.jpg'),
(33845, 2302, 'Medium S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123971.mp4', 'http://timg.bdta.pro/images/7a562436915e8e0a83dfd2ca08dda61c.jpg'),
(33846, 2302, 'Medium S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123972.mp4', 'http://timg.bdta.pro/images/480d700cf07897abd71aacebf5b9469e.jpg'),
(33847, 2302, 'Medium S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123973.mp4', 'http://timg.bdta.pro/images/d89bec3f3a17ebd5035d22a5e0b987ba.jpg'),
(33848, 2302, 'Medium S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123974.mp4', 'http://timg.bdta.pro/images/66b0eb91f1a730b6389dd8bde8c921e2.jpg'),
(33849, 2302, 'Medium S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123975.mp4', 'http://timg.bdta.pro/images/6ff4f3ec92e1555dd55ff1fc77a48d96.jpg'),
(33850, 2302, 'Medium S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/123976.mp4', 'http://timg.bdta.pro/images/a4e9dd9c272cd42e3f4562fc74ac786c.jpg'),
(33851, 2302, 'Medium S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/123977.mp4', 'http://timg.bdta.pro/images/f5f622c1507e687ca1b26b3bcc409f7f.jpg'),
(33852, 2302, 'Medium S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/123978.mp4', 'http://timg.bdta.pro/images/813960f9447df94900a99009bbcb47c2.jpg'),
(33853, 2302, 'Medium S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/123979.mp4', 'http://timg.bdta.pro/images/71458fa4019f1887105ce14cb55f2059.jpg'),
(33854, 2302, 'Medium S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/123980.mp4', 'http://timg.bdta.pro/images/bdc3ed9f3c36c93d019a3c3cd0ae363b.jpg'),
(33855, 2302, 'Medium S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/123981.mp4', 'http://timg.bdta.pro/images/02a53eabcb7f01b703f1028e9b461abe.jpg'),
(33856, 2302, 'Medium S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/123982.mp4', 'http://timg.bdta.pro/images/9317d5ed5d47df31804304b7f673ee25.jpg'),
(33857, 2302, 'Medium S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/123983.mp4', 'http://timg.bdta.pro/images/6e95c715a514e9802c0a5192188d0d9b.jpg'),
(33858, 2302, 'Medium S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/123984.mp4', 'http://timg.bdta.pro/images/01218031bfa47220e83362642bb95e45.jpg'),
(33859, 2302, 'Medium S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/123985.mp4', 'http://timg.bdta.pro/images/5adddb729bbd646f39db74a8ed8b03f9.jpg'),
(33860, 2302, 'Medium S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/123986.mp4', 'http://timg.bdta.pro/images/b14d4fd0eb7bb230c3168d47e157167a.jpg'),
(33861, 2302, 'Medium S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/123987.mp4', 'http://timg.bdta.pro/images/cb3fc5c4b554328eca9324ee2bf988a0.jpg'),
(33862, 2303, 'Medium S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123988.mp4', 'http://timg.bdta.pro/images/9469f913ab144de4c56e09b52935deff.jpg'),
(33863, 2303, 'Medium S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123989.mp4', 'http://timg.bdta.pro/images/0242c55c14fd65c628c6d846e4915d33.jpg'),
(33864, 2303, 'Medium S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123990.mp4', 'http://timg.bdta.pro/images/11b951d0e5b1e7c415bdee84ec75a2e7.jpg'),
(33865, 2303, 'Medium S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123991.mp4', 'http://timg.bdta.pro/images/49e94dd6a6df3426a85c49fe40ec8197.jpg'),
(33866, 2303, 'Medium S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123992.mp4', 'http://timg.bdta.pro/images/899779c4624f49ef872b7bcdb4c350b6.jpg'),
(33867, 2303, 'Medium S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123993.mp4', 'http://timg.bdta.pro/images/9fb777eabb89e1dbcb4895c2e95a76f9.jpg'),
(33868, 2303, 'Medium S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123994.mp4', 'http://timg.bdta.pro/images/663769725ccf2424c377d68fd5447d3c.jpg'),
(33869, 2303, 'Medium S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123995.mp4', 'http://timg.bdta.pro/images/6610b9ef3d4fc0491daf5fd57be3761c.jpg'),
(33870, 2303, 'Medium S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123996.mp4', 'http://timg.bdta.pro/images/e067def5142c005d679df62cec0f2314.jpg'),
(33871, 2303, 'Medium S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123997.mp4', 'http://timg.bdta.pro/images/c935ffed59866fc8cdd0043abd78b661.jpg'),
(33872, 2303, 'Medium S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/123998.mp4', 'http://timg.bdta.pro/images/1314858068515172d668f85f0fb04b4b.jpg'),
(33873, 2303, 'Medium S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/123999.mp4', 'http://timg.bdta.pro/images/ca8b3cdfacec6acae988519c100f3b43.jpg'),
(33874, 2303, 'Medium S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124000.mp4', 'http://timg.bdta.pro/images/f6a9a124ec25abc4122b5845ce12aa85.jpg'),
(33875, 2303, 'Medium S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/124001.mp4', 'http://timg.bdta.pro/images/f7515fae566ff7b643c16700e1477712.jpg'),
(33876, 2303, 'Medium S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/124002.mp4', 'http://timg.bdta.pro/images/755853b3e562bb91555452dd9a2db3e4.jpg'),
(33877, 2303, 'Medium S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/124003.mp4', 'http://timg.bdta.pro/images/8a0b491a45b120865b645682c9f74005.jpg'),
(33878, 2303, 'Medium S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/124004.mp4', 'http://timg.bdta.pro/images/25927ea24bb7c8a9bb766fe425b6b496.jpg'),
(33879, 2303, 'Medium S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/124005.mp4', 'http://timg.bdta.pro/images/cfacaef05432793fb93d283dc13ac6f0.jpg'),
(33880, 2303, 'Medium S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/124006.mp4', 'http://timg.bdta.pro/images/8d12b0b0ae9c1658a8492044f454b4f0.jpg'),
(33881, 2303, 'Medium S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/124007.mp4', 'http://timg.bdta.pro/images/cd43116736d211ae17129c1092ed849a.jpg'),
(33882, 2303, 'Medium S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/124008.mp4', 'http://timg.bdta.pro/images/05e061f1d4620b366f65da5a222c8b61.jpg'),
(33883, 2303, 'Medium S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/124009.mp4', 'http://timg.bdta.pro/images/9fb99b219103c3f5c41bf4cde4f7c1ae.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(33884, 2304, 'Medium S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124010.mp4', 'http://timg.bdta.pro/images/7672bd9cb896d08ea1c4256640bb0b2f.jpg'),
(33885, 2304, 'Medium S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124011.mp4', 'http://timg.bdta.pro/images/54b9a0e747bae29968fff9c8bc07476f.jpg'),
(33886, 2304, 'Medium S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124012.mp4', 'http://timg.bdta.pro/images/a0e8cd37874d02db6f15dbd3006ec9d4.jpg'),
(33887, 2304, 'Medium S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124013.mp4', 'http://timg.bdta.pro/images/d69a05bbb8840710c0f76b53bca78e16.jpg'),
(33888, 2304, 'Medium S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124014.mp4', 'http://timg.bdta.pro/images/f9bd44bb4633107c3f61d1b3cf21b642.jpg'),
(33889, 2304, 'Medium S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124015.mp4', 'http://timg.bdta.pro/images/a459d1f13437f6235fbc20ba5a5a9456.jpg'),
(33890, 2304, 'Medium S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124016.mp4', 'http://timg.bdta.pro/images/a69f0a721f2f9ebdc8fdfbcf184931f1.jpg'),
(33891, 2304, 'Medium S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124017.mp4', 'http://timg.bdta.pro/images/60eebdf329bb4170e3d8960a04db0dfa.jpg'),
(33892, 2304, 'Medium S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124018.mp4', 'http://timg.bdta.pro/images/61e6f73b654ad1fa8c374e7fae14b85a.jpg'),
(33893, 2304, 'Medium S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124019.mp4', 'http://timg.bdta.pro/images/36dd351987b6de66d2900f26a9ed4219.jpg'),
(33894, 2304, 'Medium S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124020.mp4', 'http://timg.bdta.pro/images/1861189dc6f5872a4dd8fe41003a5bae.jpg'),
(33895, 2304, 'Medium S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124021.mp4', 'http://timg.bdta.pro/images/250126832878e8b77d0a4fed2f7d3dd0.jpg'),
(33896, 2304, 'Medium S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124022.mp4', 'http://timg.bdta.pro/images/42a6bfddd92c998ea1a6fcc9fe43832b.jpg'),
(33897, 2304, 'Medium S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/124023.mp4', 'http://timg.bdta.pro/images/580085469f32eb3d6f7b92814b50d789.jpg'),
(33898, 2304, 'Medium S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/124024.mp4', 'http://timg.bdta.pro/images/c6829cf2785606f507487a3605ce5da8.jpg'),
(33899, 2304, 'Medium S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/124025.mp4', 'http://timg.bdta.pro/images/aaa3e4eb47844b1e27ffed6ca97c6cc3.jpg'),
(33900, 2305, 'Medium S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124026.mp4', 'http://timg.bdta.pro/images/8bb1e4eedbf2c7c8453797755a388c69.jpg'),
(33901, 2305, 'Medium S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124027.mp4', 'http://timg.bdta.pro/images/9f9f7ed615ed840293b6fe56d93710af.jpg'),
(33902, 2305, 'Medium S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124028.mp4', 'http://timg.bdta.pro/images/676e41d746cffbe41e60172ae39c76c7.jpg'),
(33903, 2305, 'Medium S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124029.mp4', 'http://timg.bdta.pro/images/ae418c9fc3265323b5140c76f6fbfe53.jpg'),
(33904, 2305, 'Medium S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124030.mp4', 'http://timg.bdta.pro/images/e248dcca3d22e8421d8285e7c2232ea5.jpg'),
(33905, 2305, 'Medium S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124031.mp4', 'http://timg.bdta.pro/images/3edeef9f5a8c8797d5f796ac72485454.jpg'),
(33906, 2305, 'Medium S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124032.mp4', 'http://timg.bdta.pro/images/68abcff25ffc290d25721a75e9878740.jpg'),
(33907, 2305, 'Medium S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124033.mp4', 'http://timg.bdta.pro/images/73219294d771545fb8f8a4f95167b25f.jpg'),
(33908, 2305, 'Medium S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124034.mp4', 'http://timg.bdta.pro/images/320fdb4c68d62c7733ba5c8605452cb1.jpg'),
(33909, 2305, 'Medium S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124035.mp4', 'http://timg.bdta.pro/images/8046c04085f9a0ccbda1ebe33090bea2.jpg'),
(33910, 2305, 'Medium S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124036.mp4', 'http://timg.bdta.pro/images/08da1d904d4a923c668bba903ac215ce.jpg'),
(33911, 2305, 'Medium S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124037.mp4', 'http://timg.bdta.pro/images/153f217307c1185ff135b3d669a5d189.jpg'),
(33912, 2305, 'Medium S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124038.mp4', 'http://timg.bdta.pro/images/1e0ed77923ece90bf4b4fee81e2ed7da.jpg'),
(33913, 2305, 'Medium S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/124039.mp4', 'http://timg.bdta.pro/images/cb0e28a1e62b3a1144268e4b1c6a05c3.jpg'),
(33914, 2305, 'Medium S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/124040.mp4', 'http://timg.bdta.pro/images/ab02ecdc963179b0516957669fd92537.jpg'),
(33915, 2305, 'Medium S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/124041.mp4', 'http://timg.bdta.pro/images/85b0a09471ac878525776e165cc8fa39.jpg'),
(33916, 2305, 'Medium S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/124042.mp4', 'http://timg.bdta.pro/images/b32b2ffe2603d29191269b5e5a3900e6.jpg'),
(33917, 2305, 'Medium S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/124043.mp4', 'http://timg.bdta.pro/images/c826720f0259e9c4a2569344810bfbf2.jpg'),
(33918, 2305, 'Medium S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/124044.mp4', 'http://timg.bdta.pro/images/2b6d5f20a932d66e98f7563d80c91899.jpg'),
(33919, 2306, 'Medium S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124045.mp4', 'http://timg.bdta.pro/images/c532397e69952e4ef695d3694edd12ad.jpg'),
(33920, 2306, 'Medium S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124046.mp4', 'http://timg.bdta.pro/images/977e785a8cb272c4a9bca03da03e42ab.jpg'),
(33921, 2306, 'Medium S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124047.mp4', 'http://timg.bdta.pro/images/8417241396f780f8fd397b2599850095.jpg'),
(33922, 2306, 'Medium S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124048.mp4', 'http://timg.bdta.pro/images/2376f1512f36211a1208ae257a43ba0f.jpg'),
(33923, 2306, 'Medium S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124049.mp4', 'http://timg.bdta.pro/images/f7a53c48e07c5edcd9be1ed711f596f5.jpg'),
(33924, 2306, 'Medium S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124050.mp4', 'http://timg.bdta.pro/images/5ff26e370da4e4348a28c39101caa9d7.jpg'),
(33925, 2306, 'Medium S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124051.mp4', 'http://timg.bdta.pro/images/f449cde7f680ccd8b43ba61eeaf87a47.jpg'),
(33926, 2306, 'Medium S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124052.mp4', 'http://timg.bdta.pro/images/8034bb084e9e7b6574d60e58e93686fb.jpg'),
(33927, 2306, 'Medium S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124053.mp4', 'http://timg.bdta.pro/images/a1b0005f746da5a476cd761da8e060e2.jpg'),
(33928, 2306, 'Medium S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124054.mp4', 'http://timg.bdta.pro/images/8ad6b5e7cde9b4b9cf6ae4fbf0bec45b.jpg'),
(33929, 2306, 'Medium S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124055.mp4', 'http://timg.bdta.pro/images/2b4df99b3b7429033c49707bda51c8e5.jpg'),
(33930, 2306, 'Medium S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124056.mp4', 'http://timg.bdta.pro/images/1f414cfa91945f8bd7ef91b6bcdb3cf0.jpg'),
(33931, 2306, 'Medium S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124057.mp4', 'http://timg.bdta.pro/images/cb6b5f0d63958b59521214e20e285cdf.jpg'),
(33932, 2306, 'Medium S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/124058.mp4', 'http://timg.bdta.pro/images/5637fa8660d5f2976549ef05a805adad.jpg'),
(33933, 2306, 'Medium S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/124059.mp4', 'http://timg.bdta.pro/images/ae3ca88fb03dde8c27af074841d90db4.jpg'),
(33934, 2306, 'Medium S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/124060.mp4', 'http://timg.bdta.pro/images/fe90628920b202dcb82edea1bdf5c743.jpg'),
(33935, 2306, 'Medium S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/124061.mp4', 'http://timg.bdta.pro/images/73fd1d94e19cb3413688d0e1b8294a6a.jpg'),
(33936, 2306, 'Medium S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/124062.mp4', 'http://timg.bdta.pro/images/f0173607e03605acefdba0924523ea25.jpg'),
(33937, 2306, 'Medium S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/124063.mp4', 'http://timg.bdta.pro/images/d8aa99f3bee7f036f23d479590e803be.jpg'),
(33938, 2306, 'Medium S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/124064.mp4', 'http://timg.bdta.pro/images/7eb12518345408669cc912bc34d8765a.jpg'),
(33939, 2306, 'Medium S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/124065.mp4', 'http://timg.bdta.pro/images/1f5241fb90908475e388b4a81b25dc0b.jpg'),
(33940, 2306, 'Medium S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/124066.mp4', 'http://timg.bdta.pro/images/722ed80ef0aafa1bb787282b6984f2c1.jpg'),
(33941, 2307, 'Medium S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124067.mp4', 'http://timg.bdta.pro/images/ad6a042cb206619d942a86c5ef9d2554.jpg'),
(33942, 2307, 'Medium S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124068.mp4', 'http://timg.bdta.pro/images/b24283cca29d30ac68262972443e3a66.jpg'),
(33943, 2307, 'Medium S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124069.mp4', 'http://timg.bdta.pro/images/1e481123d7ec934b63741ed14b66cb7d.jpg'),
(33944, 2307, 'Medium S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124070.mp4', 'http://timg.bdta.pro/images/24470d604369bbec087a6c6f5c749d44.jpg'),
(33945, 2307, 'Medium S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124071.mp4', 'http://timg.bdta.pro/images/58626d4e01b568fb8e003a9fd4676175.jpg'),
(33946, 2307, 'Medium S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124072.mp4', 'http://timg.bdta.pro/images/b87d6636bb323e43b51fbcddd03d6b3b.jpg'),
(33947, 2307, 'Medium S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124073.mp4', 'http://timg.bdta.pro/images/9dc541cdf12dc44a2d40e411582ccd0f.jpg'),
(33948, 2307, 'Medium S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124074.mp4', 'http://timg.bdta.pro/images/7c91be251ec17e62ed4db1f60556698c.jpg'),
(33949, 2307, 'Medium S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124075.mp4', 'http://timg.bdta.pro/images/6dbcf5df0bd14c5a965343d125a13559.jpg'),
(33950, 2307, 'Medium S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124076.mp4', 'http://timg.bdta.pro/images/c39630ee6b0583c0ae7ec8fb63a274f1.jpg'),
(33951, 2307, 'Medium S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124077.mp4', 'http://timg.bdta.pro/images/4dd4a4a5dd7b4c8997def7e1341ef2f4.jpg'),
(33952, 2307, 'Medium S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124078.mp4', 'http://timg.bdta.pro/images/352a7ee90491265028557c60417bf805.jpg'),
(33953, 2307, 'Medium S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124079.mp4', 'http://timg.bdta.pro/images/1d5464a0a739ee0f9f295d7f4b99241b.jpg'),
(33954, 2308, 'O Show do Garfield S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124080.mp4', 'http://timg.bdta.pro/images/38dd54664537228d8cd6aebb6c27714e.jpg'),
(33955, 2308, 'O Show do Garfield S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124081.mp4', 'http://timg.bdta.pro/images/ae3ebc6a5f0bb085b71490770e2401ec.jpg'),
(33956, 2308, 'O Show do Garfield S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124082.mp4', 'http://timg.bdta.pro/images/7670757b689f4b78b6b3a25791101925.jpg'),
(33957, 2308, 'O Show do Garfield S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124083.mp4', 'http://timg.bdta.pro/images/6acd2e391d5797d0407725f10591ebeb.jpg'),
(33958, 2308, 'O Show do Garfield S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124084.mp4', 'http://timg.bdta.pro/images/3d18bdf9a93ed5ee273375747cdf39ea.jpg'),
(33959, 2308, 'O Show do Garfield S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124085.mp4', 'http://timg.bdta.pro/images/2e47fdcbf9a4022fad16d3fafbe70709.jpg'),
(33960, 2308, 'O Show do Garfield S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124086.mp4', 'http://timg.bdta.pro/images/8f4865916cd44050b837f5a456ac6cfb.jpg'),
(33961, 2308, 'O Show do Garfield S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124087.mp4', 'http://timg.bdta.pro/images/795ed6e6b5bb9f79b0c016ea36ca2e72.jpg'),
(33962, 2308, 'O Show do Garfield S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124088.mp4', 'http://timg.bdta.pro/images/a050d14ef94f95228b788469f8c23294.jpg'),
(33963, 2308, 'O Show do Garfield S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124089.mp4', 'http://timg.bdta.pro/images/01d96a4c16063b68a2858898d5551105.jpg'),
(33964, 2308, 'O Show do Garfield S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124090.mp4', 'http://timg.bdta.pro/images/ab3761bd4414f8a83ef710de4c59bfde.jpg'),
(33965, 2308, 'O Show do Garfield S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124091.mp4', 'http://timg.bdta.pro/images/d2e0592ed4a026d6d38307d27e83ca45.jpg'),
(33966, 2308, 'O Show do Garfield S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124092.mp4', 'http://timg.bdta.pro/images/538b669ef6eca562541e7c3725bee130.jpg'),
(33967, 2308, 'O Show do Garfield S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/124093.mp4', 'http://timg.bdta.pro/images/49b5f6cee7e28fdac5a2925e8a2860b8.jpg'),
(33968, 2308, 'O Show do Garfield S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/124094.mp4', 'http://timg.bdta.pro/images/fe1eba7c7f8d0861646c8c760adc7c48.jpg'),
(33969, 2308, 'O Show do Garfield S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/124095.mp4', 'http://timg.bdta.pro/images/9ddebd5330166c7c09b7a6d650d1518f.jpg'),
(33970, 2308, 'O Show do Garfield S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/124096.mp4', 'http://timg.bdta.pro/images/7e34f18bc06d993969ec1e475303b198.jpg'),
(33971, 2308, 'O Show do Garfield S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/124097.mp4', 'http://timg.bdta.pro/images/be119a5bcf278836fe7e74ece051f5a3.jpg'),
(33972, 2308, 'O Show do Garfield S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/124098.mp4', 'http://timg.bdta.pro/images/ceb79342e100b28fd4014061b7983a4f.jpg'),
(33973, 2308, 'O Show do Garfield S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/124099.mp4', 'http://timg.bdta.pro/images/43e3e5c39289fe2faa97acabff6cbac0.jpg'),
(33974, 2308, 'O Show do Garfield S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/124100.mp4', 'http://timg.bdta.pro/images/49cebf22c34d6a0983f974cd97804888.jpg'),
(33975, 2308, 'O Show do Garfield S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/124101.mp4', 'http://timg.bdta.pro/images/9d183f2c312e72e151479bb23d2cfa70.jpg'),
(33976, 2308, 'O Show do Garfield S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/124102.mp4', 'http://timg.bdta.pro/images/30af649aa9a5fa623d4760ce2bae61a2.jpg'),
(33977, 2308, 'O Show do Garfield S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/124103.mp4', 'http://timg.bdta.pro/images/c179f7c821f335d2a7b37956c4a79044.jpg'),
(33978, 2308, 'O Show do Garfield S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/124104.mp4', 'http://timg.bdta.pro/images/4ed98cc0f24788602c6e03ea6a5246ca.jpg'),
(33979, 2308, 'O Show do Garfield S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/124105.mp4', 'http://timg.bdta.pro/images/bb3941b9ddabfbd31fd2701f63f33beb.jpg'),
(33980, 2309, 'Paradise PD S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140375.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(33981, 2309, 'Paradise PD S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140376.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(33982, 2309, 'Paradise PD S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140377.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(33983, 2309, 'Paradise PD S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140378.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(33984, 2309, 'Paradise PD S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140379.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(33985, 2309, 'Paradise PD S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140380.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(33986, 2309, 'Paradise PD S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140381.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(33987, 2309, 'Paradise PD S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140382.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(33988, 2309, 'Paradise PD S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140383.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(33989, 2309, 'Paradise PD S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140384.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(33990, 2310, 'Paradise PD S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140385.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(33991, 2310, 'Paradise PD S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140386.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(33992, 2310, 'Paradise PD S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140387.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(33993, 2310, 'Paradise PD S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140388.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(33994, 2310, 'Paradise PD S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140389.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(33995, 2310, 'Paradise PD S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140390.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(33996, 2310, 'Paradise PD S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140391.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(33997, 2310, 'Paradise PD S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140392.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(33998, 2311, 'Paradise PD S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140393.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(33999, 2311, 'Paradise PD S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140394.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(34000, 2311, 'Paradise PD S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140395.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(34001, 2311, 'Paradise PD S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140396.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(34002, 2311, 'Paradise PD S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140397.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(34003, 2311, 'Paradise PD S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140398.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(34004, 2311, 'Paradise PD S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140399.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(34005, 2311, 'Paradise PD S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140400.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(34006, 2311, 'Paradise PD S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140401.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(34007, 2311, 'Paradise PD S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140402.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(34008, 2311, 'Paradise PD S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140403.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(34009, 2311, 'Paradise PD S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140404.mp4', 'http://gstaticontent.com/images/desSj4kx0y9p61vm9QBE3Wm8GxK_big.jpg'),
(34010, 2312, 'Project Mc S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124106.mp4', 'http://timg.bdta.pro/images/c29e87902cafe65a9d5cfef7a6d72788.jpg'),
(34011, 2312, 'Project Mc S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124107.mp4', 'http://timg.bdta.pro/images/6b2485a100ef67ff3f23aa65b0a7018e.jpg'),
(34012, 2312, 'Project Mc S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124108.mp4', 'http://timg.bdta.pro/images/334b28b80c89956f781597e45b58d63c.jpg'),
(34013, 2313, 'Project Mc S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124109.mp4', 'http://timg.bdta.pro/images/3cc3e70c72a4a456c810a4d5ded74b7c.jpg'),
(34014, 2313, 'Project Mc S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124110.mp4', 'http://timg.bdta.pro/images/617a94bde351e3fb8a2d03bda3294f3b.jpg'),
(34015, 2313, 'Project Mc S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124111.mp4', 'http://timg.bdta.pro/images/c5f91073759c30041fda70beb7bd958b.jpg'),
(34016, 2313, 'Project Mc S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124112.mp4', 'http://timg.bdta.pro/images/4fded27348a32819c23786bf1fb2a308.jpg'),
(34017, 2313, 'Project Mc S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124113.mp4', 'http://timg.bdta.pro/images/e3f316094fe0e517c806d51e561e0cfd.jpg'),
(34018, 2313, 'Project Mc S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124114.mp4', 'http://timg.bdta.pro/images/4869491005161cda2d16b13df8528782.jpg'),
(34019, 2314, 'Project Mc S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124115.mp4', 'http://timg.bdta.pro/images/44a7ade1eedb57a9b54ba70be1e3ab14.jpg'),
(34020, 2314, 'Project Mc S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124116.mp4', 'http://timg.bdta.pro/images/cedad9cfce9721628c83e6e58647668c.jpg'),
(34021, 2314, 'Project Mc S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124117.mp4', 'http://timg.bdta.pro/images/91b16f54eaa4f2c33adf38929edc6e81.jpg'),
(34022, 2314, 'Project Mc S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124118.mp4', 'http://timg.bdta.pro/images/c09eb8d4a9844d03ecda46f4eb50e6e1.jpg'),
(34023, 2314, 'Project Mc S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124119.mp4', 'http://timg.bdta.pro/images/844466b5718b5189d2d962d55cfe09b6.jpg'),
(34024, 2314, 'Project Mc S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124120.mp4', 'http://timg.bdta.pro/images/a2a45a15799de97e4932870932b4a0be.jpg'),
(34025, 2315, 'Project Mc S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124121.mp4', 'http://timg.bdta.pro/images/21c322ccc456b24aaa58729daa48adaf.jpg'),
(34026, 2316, 'Project Mc S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124122.mp4', 'http://timg.bdta.pro/images/778e12c5fe788e7bc5d1c36a43a8f736.jpg'),
(34027, 2316, 'Project Mc S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124123.mp4', 'http://timg.bdta.pro/images/9f668a1432d3b66648b72ca6db7c943e.jpg'),
(34028, 2316, 'Project Mc S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124124.mp4', 'http://timg.bdta.pro/images/d84f817f3e410e51034a5347e177875b.jpg'),
(34029, 2316, 'Project Mc S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124125.mp4', 'http://timg.bdta.pro/images/5530f295af9fdcd1541d5524f0cc3886.jpg'),
(34030, 2316, 'Project Mc S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124126.mp4', 'http://timg.bdta.pro/images/2f064377bd26cfc19c94c4ff216e65a5.jpg'),
(34031, 2317, 'Project Mc S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124127.mp4', 'http://timg.bdta.pro/images/22520cbe4143f92200213ab067fb7833.jpg'),
(34032, 2317, 'Project Mc S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124128.mp4', 'http://timg.bdta.pro/images/2403b6d5499d8db0b0795ae7d28ac941.jpg'),
(34033, 2317, 'Project Mc S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124129.mp4', 'http://timg.bdta.pro/images/8512916b84ba4b745e92d3516fbdbae8.jpg'),
(34034, 2317, 'Project Mc S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124130.mp4', 'http://timg.bdta.pro/images/ffce277cb98833a0728fc5e38bc15f17.jpg'),
(34035, 2317, 'Project Mc S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124131.mp4', 'http://timg.bdta.pro/images/2577315a627cb023ad0cd7bf8cd9b7bb.jpg'),
(34036, 2318, 'Rua Do Sobe E Desce Numero Que Desaparece S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124311.mp4', 'http://gstaticontent.com/images/yioxliStcX5P7LfMdVDxWtrN6T7_big.jpg'),
(34037, 2318, 'Rua Do Sobe E Desce Numero Que Desaparece S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124312.mp4', 'http://gstaticontent.com/images/yioxliStcX5P7LfMdVDxWtrN6T7_big.jpg'),
(34038, 2318, 'Rua Do Sobe E Desce Numero Que Desaparece S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124313.mp4', 'http://gstaticontent.com/images/yioxliStcX5P7LfMdVDxWtrN6T7_big.jpg'),
(34039, 2318, 'Rua Do Sobe E Desce Numero Que Desaparece S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124314.mp4', 'http://gstaticontent.com/images/yioxliStcX5P7LfMdVDxWtrN6T7_big.jpg'),
(34040, 2318, 'Rua Do Sobe E Desce Numero Que Desaparece S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124315.mp4', 'http://gstaticontent.com/images/yioxliStcX5P7LfMdVDxWtrN6T7_big.jpg'),
(34041, 2318, 'Rua Do Sobe E Desce Numero Que Desaparece S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124316.mp4', 'http://gstaticontent.com/images/yioxliStcX5P7LfMdVDxWtrN6T7_big.jpg'),
(34042, 2319, 'Stargate SG-1 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222752.mp4', 'http://timg.bdta.pro/images/7dec48081b94b8bf18fcb137701dc963.jpg'),
(34043, 2319, 'Stargate SG-1 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222753.mp4', 'http://timg.bdta.pro/images/b0165e5586085c5c0a7c3323534e3f24.jpg'),
(34044, 2319, 'Stargate SG-1 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222754.mp4', 'http://timg.bdta.pro/images/adcff668658688a9b334887cbbe6a711.jpg'),
(34045, 2319, 'Stargate SG-1 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222755.mp4', 'http://timg.bdta.pro/images/1835a52beacce103b549f0bbfcae83fe.jpg'),
(34046, 2319, 'Stargate SG-1 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222756.mp4', 'http://timg.bdta.pro/images/4e87883f01c1973ff07e712e03a08777.jpg'),
(34047, 2319, 'Stargate SG-1 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222757.mp4', 'http://timg.bdta.pro/images/ffaf8b855dc3261d042a0d9f3f3afd73.jpg'),
(34048, 2319, 'Stargate SG-1 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222758.mp4', 'http://timg.bdta.pro/images/80610cc2eac4393cb9af0d0fa94ff6c6.jpg'),
(34049, 2319, 'Stargate SG-1 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222759.mp4', 'http://timg.bdta.pro/images/ae6a25f336f384f7002343d602059135.jpg'),
(34050, 2319, 'Stargate SG-1 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222760.mp4', 'http://timg.bdta.pro/images/0d6c95b61fce9c1ec526b04ed41f2382.jpg'),
(34051, 2319, 'Stargate SG-1 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222761.mp4', 'http://timg.bdta.pro/images/8ad50f2059b60f979db534391c65ea75.jpg'),
(34052, 2319, 'Stargate SG-1 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222762.mp4', 'http://timg.bdta.pro/images/0236fe45948c57f36f0c2a1d4e86d9da.jpg'),
(34053, 2319, 'Stargate SG-1 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222763.mp4', 'http://timg.bdta.pro/images/3f6bbf6bf84d04aa6cbc02d37033ff24.jpg'),
(34054, 2319, 'Stargate SG-1 S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222764.mp4', 'http://timg.bdta.pro/images/21221627d7586f049c8f94d5819dd748.jpg'),
(34055, 2319, 'Stargate SG-1 S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222765.mp4', 'http://timg.bdta.pro/images/11215f40e220ecca011587006f678fe6.jpg'),
(34056, 2319, 'Stargate SG-1 S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222766.mp4', 'http://timg.bdta.pro/images/0c7125ae6007a16d741e8eae7ea7925c.jpg'),
(34057, 2319, 'Stargate SG-1 S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222767.mp4', 'http://timg.bdta.pro/images/98e604d443518e0d850e71c3d3a8930f.jpg'),
(34058, 2319, 'Stargate SG-1 S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222768.mp4', 'http://timg.bdta.pro/images/0a77eb29156038acc6653964632f3e43.jpg'),
(34059, 2319, 'Stargate SG-1 S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222769.mp4', 'http://timg.bdta.pro/images/1504c31d1ab3aaf477089ad83de993e3.jpg'),
(34060, 2319, 'Stargate SG-1 S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222770.mp4', 'http://timg.bdta.pro/images/c68dd06b32b79ebabce3c676c8bb5e3a.jpg'),
(34061, 2319, 'Stargate SG-1 S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222771.mp4', 'http://timg.bdta.pro/images/0aac51715e7ff68c6f6e8094626651ba.jpg'),
(34062, 2319, 'Stargate SG-1 S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222772.mp4', 'http://timg.bdta.pro/images/df0fcbfb3c6bc8b72b6f70c3506dc6f4.jpg'),
(34063, 2319, 'Stargate SG-1 S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222773.mp4', 'http://timg.bdta.pro/images/eb265e8b78d155e770446872b45a9c53.jpg'),
(34064, 2320, 'Stargate SG-1 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222774.mp4', 'http://timg.bdta.pro/images/43c37033822d8466cd0ec2d62f3e7d44.jpg'),
(34065, 2320, 'Stargate SG-1 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222775.mp4', 'http://timg.bdta.pro/images/7eb2e3ec2c98b34a4a8b53315ead991c.jpg'),
(34066, 2320, 'Stargate SG-1 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222776.mp4', 'http://timg.bdta.pro/images/e658e93c19d9f81d7b3b8f37d0fb7251.jpg'),
(34067, 2320, 'Stargate SG-1 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222777.mp4', 'http://timg.bdta.pro/images/56f1b35d8a9636967fd39d046306bea7.jpg'),
(34068, 2320, 'Stargate SG-1 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222778.mp4', 'http://timg.bdta.pro/images/5578fafc085737df0080515189995ba8.jpg'),
(34069, 2320, 'Stargate SG-1 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222779.mp4', 'http://timg.bdta.pro/images/14011491280788d67853a9dd5946fc85.jpg'),
(34070, 2320, 'Stargate SG-1 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222780.mp4', 'http://timg.bdta.pro/images/ec70f2ac72890144798720d0a09ac946.jpg'),
(34071, 2320, 'Stargate SG-1 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222781.mp4', 'http://timg.bdta.pro/images/f4a744609b360e498a521d1ac4e58c37.jpg'),
(34072, 2320, 'Stargate SG-1 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222782.mp4', 'http://timg.bdta.pro/images/8ad67e8a28cb8488ea73dcc56537dc54.jpg'),
(34073, 2320, 'Stargate SG-1 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222783.mp4', 'http://timg.bdta.pro/images/833a71320f858f6395868965fb656feb.jpg'),
(34074, 2320, 'Stargate SG-1 S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222784.mp4', 'http://timg.bdta.pro/images/4cbb601aad9fb0d9832e8c614412d7e7.jpg'),
(34075, 2320, 'Stargate SG-1 S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222785.mp4', 'http://timg.bdta.pro/images/446184bfb1cd7a004b460529620f9f73.jpg'),
(34076, 2320, 'Stargate SG-1 S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222786.mp4', 'http://timg.bdta.pro/images/7a59eae52af532584f00b55b7ad50438.jpg'),
(34077, 2320, 'Stargate SG-1 S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222787.mp4', 'http://timg.bdta.pro/images/3d27011e87f1d5f897f9ad7a2278e9da.jpg'),
(34078, 2320, 'Stargate SG-1 S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222788.mp4', 'http://timg.bdta.pro/images/24fc0cb50e32bcadd523641e263bd463.jpg'),
(34079, 2320, 'Stargate SG-1 S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222789.mp4', 'http://timg.bdta.pro/images/727c94dcb2f9a750c830d7da7d76e002.jpg'),
(34080, 2320, 'Stargate SG-1 S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222790.mp4', 'http://timg.bdta.pro/images/a82d2f45e878f8783373c05766c9eafc.jpg'),
(34081, 2320, 'Stargate SG-1 S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222791.mp4', 'http://timg.bdta.pro/images/3958b8732e0ff656e356cd1309b7e18c.jpg'),
(34082, 2320, 'Stargate SG-1 S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222792.mp4', 'http://timg.bdta.pro/images/6f294dfef29c6db12e7bfa1a02e12228.jpg'),
(34083, 2320, 'Stargate SG-1 S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222793.mp4', 'http://timg.bdta.pro/images/cc9e44ea339a15223eee8fa1b08f7b82.jpg'),
(34084, 2320, 'Stargate SG-1 S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222794.mp4', 'http://timg.bdta.pro/images/a13bf8333faf651a90a6b74508299a6b.jpg'),
(34085, 2320, 'Stargate SG-1 S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222795.mp4', 'http://timg.bdta.pro/images/58921a46800755bba3b0d6888edcdf53.jpg'),
(34086, 2321, 'Stargate SG-1 S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222796.mp4', 'http://timg.bdta.pro/images/49afe6f39bd58ef1c96d3896e928725b.jpg'),
(34087, 2321, 'Stargate SG-1 S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222797.mp4', 'http://timg.bdta.pro/images/fcb95ae2ba692fd20118e6640f8ede6a.jpg'),
(34088, 2321, 'Stargate SG-1 S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222798.mp4', 'http://timg.bdta.pro/images/9235b1db226e8a5e4a543cb821397fad.jpg'),
(34089, 2321, 'Stargate SG-1 S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222799.mp4', 'http://timg.bdta.pro/images/7dd849989f84248793d87e840ad1c152.jpg'),
(34090, 2321, 'Stargate SG-1 S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222800.mp4', 'http://timg.bdta.pro/images/b402340a93f33fd57eed76b1f8b033a9.jpg'),
(34091, 2321, 'Stargate SG-1 S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222801.mp4', 'http://timg.bdta.pro/images/d613fea422fab396789259be4f35559c.jpg'),
(34092, 2321, 'Stargate SG-1 S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222802.mp4', 'http://timg.bdta.pro/images/9e001fa1f1253e8cf23f156852139955.jpg'),
(34093, 2321, 'Stargate SG-1 S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222803.mp4', 'http://timg.bdta.pro/images/1f1fb88f3ae1dd304b867a92194ebb39.jpg'),
(34094, 2321, 'Stargate SG-1 S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222804.mp4', 'http://timg.bdta.pro/images/8322d58f3811cbf423b4284f63fe2f34.jpg'),
(34095, 2321, 'Stargate SG-1 S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222805.mp4', 'http://timg.bdta.pro/images/87ef5c0bc187b07f9219c7dfa350caa5.jpg'),
(34096, 2321, 'Stargate SG-1 S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222806.mp4', 'http://timg.bdta.pro/images/dfa8e81700c944208827afeb3786dc2c.jpg'),
(34097, 2321, 'Stargate SG-1 S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222807.mp4', 'http://timg.bdta.pro/images/6a97ad151eab7ba316f80bec89264800.jpg'),
(34098, 2321, 'Stargate SG-1 S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222808.mp4', 'http://timg.bdta.pro/images/62c08ed75171f1fe61648b3c4208c9e6.jpg'),
(34099, 2321, 'Stargate SG-1 S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222809.mp4', 'http://timg.bdta.pro/images/389ddc7d1ea087a123c14e5cefe84771.jpg'),
(34100, 2321, 'Stargate SG-1 S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222810.mp4', 'http://timg.bdta.pro/images/2ba5d30ee202d2d6bd21019f526c3a65.jpg'),
(34101, 2321, 'Stargate SG-1 S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222811.mp4', 'http://timg.bdta.pro/images/74650dcfb87fe7ceaebb0daf1ef33f3c.jpg'),
(34102, 2321, 'Stargate SG-1 S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222812.mp4', 'http://timg.bdta.pro/images/6f8bddb8b074c98c6e38f4e342b420a6.jpg'),
(34103, 2321, 'Stargate SG-1 S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222813.mp4', 'http://timg.bdta.pro/images/f2e9dd165d2061c56ad6482f8e6a1d5a.jpg'),
(34104, 2321, 'Stargate SG-1 S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222814.mp4', 'http://timg.bdta.pro/images/d848fccd4e7c66834b04b5b417b4d0d9.jpg'),
(34105, 2321, 'Stargate SG-1 S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222815.mp4', 'http://timg.bdta.pro/images/4a1b6ee67046fcb8bfb930e448fe2481.jpg'),
(34106, 2321, 'Stargate SG-1 S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222816.mp4', 'http://timg.bdta.pro/images/4a019f456b2820d1fcbd07ad5132dc8f.jpg'),
(34107, 2321, 'Stargate SG-1 S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222817.mp4', 'http://timg.bdta.pro/images/6dc71ad78b67892e00b580eabd8895b7.jpg'),
(34108, 2322, 'Stargate SG-1 S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222818.mp4', 'http://timg.bdta.pro/images/6d9dba8ed9ea2e4d43c4d2906dd4220d.jpg'),
(34109, 2322, 'Stargate SG-1 S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222819.mp4', 'http://timg.bdta.pro/images/22bf96d24713525a1ce97ddf5122d293.jpg'),
(34110, 2322, 'Stargate SG-1 S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222820.mp4', 'http://timg.bdta.pro/images/c5c03b274164ba0636b0f292b43de8fe.jpg'),
(34111, 2322, 'Stargate SG-1 S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222821.mp4', 'http://timg.bdta.pro/images/b2ba1a2fcc3f30a938c77926fa75e48a.jpg'),
(34112, 2322, 'Stargate SG-1 S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222822.mp4', 'http://timg.bdta.pro/images/5a1c6a48a7455a8da97ed8b286e74cb1.jpg'),
(34113, 2322, 'Stargate SG-1 S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222823.mp4', 'http://timg.bdta.pro/images/909e973a8aff0f17601d9d179b4514f1.jpg'),
(34114, 2322, 'Stargate SG-1 S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222824.mp4', 'http://timg.bdta.pro/images/9aec2d2811e7495904359541a4e163f7.jpg'),
(34115, 2322, 'Stargate SG-1 S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222825.mp4', 'http://timg.bdta.pro/images/f62a872db2336da143b8639609b0821b.jpg'),
(34116, 2322, 'Stargate SG-1 S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222826.mp4', 'http://timg.bdta.pro/images/ca7f44b37a56ae633f4eff21a364c887.jpg'),
(34117, 2322, 'Stargate SG-1 S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222827.mp4', 'http://timg.bdta.pro/images/068bee050aca079556510cdc5a95bb5c.jpg'),
(34118, 2322, 'Stargate SG-1 S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222828.mp4', 'http://timg.bdta.pro/images/9007203b6ffbe45f68514fe33aa1b8c2.jpg'),
(34119, 2322, 'Stargate SG-1 S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222829.mp4', 'http://timg.bdta.pro/images/a08cbd9d003a14bc9689d79938217b96.jpg'),
(34120, 2322, 'Stargate SG-1 S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222830.mp4', 'http://timg.bdta.pro/images/16f228eed4bd56a7f3a77cacf5c88f24.jpg'),
(34121, 2322, 'Stargate SG-1 S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222831.mp4', 'http://timg.bdta.pro/images/d88ab20ade741aafcb7f0a49de34a23f.jpg'),
(34122, 2322, 'Stargate SG-1 S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222832.mp4', 'http://timg.bdta.pro/images/63f2dbfc645b72972282057a360b3bd1.jpg'),
(34123, 2322, 'Stargate SG-1 S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222833.mp4', 'http://timg.bdta.pro/images/1c5b04dc4c829afe4744232035d43175.jpg'),
(34124, 2322, 'Stargate SG-1 S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222834.mp4', 'http://timg.bdta.pro/images/2dc9618c53c9f47cc4703bce38262671.jpg'),
(34125, 2322, 'Stargate SG-1 S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222835.mp4', 'http://timg.bdta.pro/images/3123001ddd86a7610445ada4dd1d3769.jpg'),
(34126, 2322, 'Stargate SG-1 S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222836.mp4', 'http://timg.bdta.pro/images/75c890105d1c3735b48592b6aeb3bd02.jpg'),
(34127, 2322, 'Stargate SG-1 S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222837.mp4', 'http://timg.bdta.pro/images/39029e613d9c46c6f84bcfed120c89a5.jpg'),
(34128, 2322, 'Stargate SG-1 S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222838.mp4', 'http://timg.bdta.pro/images/75ca4a90fee3b62e70598c33364ce26e.jpg'),
(34129, 2322, 'Stargate SG-1 S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222839.mp4', 'http://timg.bdta.pro/images/6948f0c0f22093e75e8fbfe6ac56b16a.jpg'),
(34130, 2323, 'Stargate SG-1 S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222840.mp4', 'http://timg.bdta.pro/images/56460abdcfd641cf2cfdd1f3abe5e665.jpg'),
(34131, 2323, 'Stargate SG-1 S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222841.mp4', 'http://timg.bdta.pro/images/2e2ce2078d23b0e37039a540295e6d52.jpg'),
(34132, 2323, 'Stargate SG-1 S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222842.mp4', 'http://timg.bdta.pro/images/ad6f1e117dcf3147566257b13a0d98b8.jpg'),
(34133, 2323, 'Stargate SG-1 S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222843.mp4', 'http://timg.bdta.pro/images/47b4c289a0dab6b8c343a2dd59ad78ed.jpg'),
(34134, 2323, 'Stargate SG-1 S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222844.mp4', 'http://timg.bdta.pro/images/8ad2c41fdb50aba14115e24e3c5634a2.jpg'),
(34135, 2323, 'Stargate SG-1 S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222845.mp4', 'http://timg.bdta.pro/images/bb185ffbae145124e13096b78eb23296.jpg'),
(34136, 2323, 'Stargate SG-1 S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222846.mp4', 'http://timg.bdta.pro/images/189ca53ddba8b52ede1dffc127cbd15c.jpg'),
(34137, 2323, 'Stargate SG-1 S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222847.mp4', 'http://timg.bdta.pro/images/ca47d7b9012b00752d9dfe4dc92480ee.jpg'),
(34138, 2323, 'Stargate SG-1 S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222848.mp4', 'http://timg.bdta.pro/images/0096b8e402a0571949df4b5569a7944d.jpg'),
(34139, 2323, 'Stargate SG-1 S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222849.mp4', 'http://timg.bdta.pro/images/86fb23f2b85695499e8eb132f5190e78.jpg'),
(34140, 2323, 'Stargate SG-1 S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222850.mp4', 'http://timg.bdta.pro/images/2761ebb574000b8f80579b8a1cb2bbaf.jpg'),
(34141, 2323, 'Stargate SG-1 S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222851.mp4', 'http://timg.bdta.pro/images/7698e5555ba9c077d0692d161d5443c6.jpg'),
(34142, 2323, 'Stargate SG-1 S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222852.mp4', 'http://timg.bdta.pro/images/2b8d56f9e76d2a4eaf97e270c1b6f6bf.jpg'),
(34143, 2323, 'Stargate SG-1 S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222853.mp4', 'http://timg.bdta.pro/images/5621cf06129dbdb88f1be7b5cdf297ee.jpg'),
(34144, 2323, 'Stargate SG-1 S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222854.mp4', 'http://timg.bdta.pro/images/b7e3650a6263ca63712fae5a927dd742.jpg'),
(34145, 2323, 'Stargate SG-1 S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222855.mp4', 'http://timg.bdta.pro/images/a96045d1c86e689bba0f500bfe004602.jpg'),
(34146, 2323, 'Stargate SG-1 S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222856.mp4', 'http://timg.bdta.pro/images/9b7e6ed4d9b179a0673012a8b8fd9665.jpg'),
(34147, 2323, 'Stargate SG-1 S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222857.mp4', 'http://timg.bdta.pro/images/f2f6d8cae3d9ee3711c2da6290eea80e.jpg'),
(34148, 2323, 'Stargate SG-1 S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222858.mp4', 'http://timg.bdta.pro/images/4de4b219f6319cd0c21fdd1550952cb3.jpg'),
(34149, 2323, 'Stargate SG-1 S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222859.mp4', 'http://timg.bdta.pro/images/9b7d164e813a2dc224747379676b2b42.jpg'),
(34150, 2323, 'Stargate SG-1 S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222860.mp4', 'http://timg.bdta.pro/images/985bdd031bcc7177aa35e718eb670154.jpg'),
(34151, 2323, 'Stargate SG-1 S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222861.mp4', 'http://timg.bdta.pro/images/76017dfd3a4a386be410567a93f84269.jpg'),
(34152, 2324, 'Stargate SG-1 S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222862.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34153, 2324, 'Stargate SG-1 S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222863.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34154, 2324, 'Stargate SG-1 S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222864.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34155, 2324, 'Stargate SG-1 S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222865.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34156, 2324, 'Stargate SG-1 S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222866.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34157, 2324, 'Stargate SG-1 S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222867.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34158, 2324, 'Stargate SG-1 S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222868.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34159, 2324, 'Stargate SG-1 S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222869.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34160, 2324, 'Stargate SG-1 S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222870.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34161, 2324, 'Stargate SG-1 S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222871.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34162, 2324, 'Stargate SG-1 S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222872.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34163, 2324, 'Stargate SG-1 S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222873.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34164, 2324, 'Stargate SG-1 S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222874.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34165, 2324, 'Stargate SG-1 S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222875.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34166, 2324, 'Stargate SG-1 S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222876.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34167, 2324, 'Stargate SG-1 S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222877.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34168, 2324, 'Stargate SG-1 S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222878.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34169, 2324, 'Stargate SG-1 S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222879.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34170, 2324, 'Stargate SG-1 S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222880.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34171, 2324, 'Stargate SG-1 S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222881.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34172, 2324, 'Stargate SG-1 S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222882.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34173, 2324, 'Stargate SG-1 S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222883.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34174, 2325, 'Stargate SG-1 S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222884.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34175, 2325, 'Stargate SG-1 S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222885.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(34176, 2325, 'Stargate SG-1 S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222886.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34177, 2325, 'Stargate SG-1 S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222887.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34178, 2325, 'Stargate SG-1 S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222888.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34179, 2325, 'Stargate SG-1 S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222889.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34180, 2325, 'Stargate SG-1 S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222890.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34181, 2325, 'Stargate SG-1 S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222891.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34182, 2325, 'Stargate SG-1 S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222892.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34183, 2325, 'Stargate SG-1 S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222893.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34184, 2325, 'Stargate SG-1 S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222894.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34185, 2325, 'Stargate SG-1 S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222895.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34186, 2325, 'Stargate SG-1 S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222896.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34187, 2325, 'Stargate SG-1 S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222897.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34188, 2325, 'Stargate SG-1 S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222898.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34189, 2325, 'Stargate SG-1 S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222899.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34190, 2325, 'Stargate SG-1 S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222900.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34191, 2325, 'Stargate SG-1 S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222901.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34192, 2325, 'Stargate SG-1 S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222902.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34193, 2325, 'Stargate SG-1 S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222903.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34194, 2325, 'Stargate SG-1 S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222904.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34195, 2326, 'Stargate SG-1 S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222905.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34196, 2326, 'Stargate SG-1 S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222906.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34197, 2326, 'Stargate SG-1 S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222907.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34198, 2326, 'Stargate SG-1 S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222908.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34199, 2326, 'Stargate SG-1 S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222909.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34200, 2326, 'Stargate SG-1 S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222910.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34201, 2326, 'Stargate SG-1 S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222911.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34202, 2326, 'Stargate SG-1 S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222912.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34203, 2326, 'Stargate SG-1 S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222913.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34204, 2326, 'Stargate SG-1 S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222914.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34205, 2326, 'Stargate SG-1 S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222915.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34206, 2326, 'Stargate SG-1 S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222916.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34207, 2326, 'Stargate SG-1 S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222917.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34208, 2326, 'Stargate SG-1 S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222918.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34209, 2326, 'Stargate SG-1 S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222919.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34210, 2326, 'Stargate SG-1 S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222920.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34211, 2326, 'Stargate SG-1 S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222921.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34212, 2326, 'Stargate SG-1 S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222922.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34213, 2326, 'Stargate SG-1 S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222923.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34214, 2326, 'Stargate SG-1 S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222924.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34215, 2327, 'Stargate SG-1 S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222925.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34216, 2327, 'Stargate SG-1 S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222926.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34217, 2327, 'Stargate SG-1 S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222927.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34218, 2327, 'Stargate SG-1 S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222928.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34219, 2327, 'Stargate SG-1 S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222929.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34220, 2327, 'Stargate SG-1 S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222930.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34221, 2327, 'Stargate SG-1 S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222931.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34222, 2327, 'Stargate SG-1 S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222932.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34223, 2327, 'Stargate SG-1 S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222933.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34224, 2327, 'Stargate SG-1 S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222934.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34225, 2327, 'Stargate SG-1 S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222935.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34226, 2327, 'Stargate SG-1 S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222936.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34227, 2327, 'Stargate SG-1 S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222937.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34228, 2327, 'Stargate SG-1 S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222938.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34229, 2327, 'Stargate SG-1 S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222939.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34230, 2327, 'Stargate SG-1 S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222940.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34231, 2327, 'Stargate SG-1 S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222941.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34232, 2327, 'Stargate SG-1 S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222942.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34233, 2327, 'Stargate SG-1 S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222943.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34234, 2327, 'Stargate SG-1 S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222944.mp4', 'http://gstaticontent.com/images/9Jegw0yle4x8jlmLNZon37Os27h_big.jpg'),
(34235, 2328, 'Stargate SG-1 S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vXaNlFuKU7rQ6UdpTvKGrOd9462.jpg'),
(34236, 2328, 'Stargate SG-1 S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dcSwT9gfLGKfMqWNhx1wC6Qg9Tt.jpg'),
(34237, 2328, 'Stargate SG-1 S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7aEfZrAzxPodOrj52T4G2H5UqBI.jpg'),
(34238, 2328, 'Stargate SG-1 S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/43gpwBWUUVfVwJlKbOSOEQ5rgIx.jpg'),
(34239, 2328, 'Stargate SG-1 S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4OivLTXkcEnlg9RQpT1fnQ2uFs3.jpg'),
(34240, 2328, 'Stargate SG-1 S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5oVyGKufli84YBqCTNj8Kat0m15.jpg'),
(34241, 2328, 'Stargate SG-1 S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8N4vzdUgZyUUEGaOopz0qMbHFT.jpg'),
(34242, 2328, 'Stargate SG-1 S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vathci5olWWyvlZYpWx1k6Q28g0.jpg'),
(34243, 2328, 'Stargate SG-1 S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jXLgCGDGLMkT3ql4f2YG4PMInnH.jpg'),
(34244, 2328, 'Stargate SG-1 S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x2lqlY6XhmH9eOH659duZ5QkQZ5.jpg'),
(34245, 2328, 'Stargate SG-1 S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7xdSCWj21DgrD5QJTOgvVkGb2Ub.jpg'),
(34246, 2328, 'Stargate SG-1 S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/73EAw0e85F2OJ2UwSHroPgFplLo.jpg'),
(34247, 2328, 'Stargate SG-1 S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gsSMQSy26xWaISGHb62fwmxMhbV.jpg'),
(34248, 2328, 'Stargate SG-1 S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rtK56hA0v19gB99UCEGgOlTR4dx.jpg'),
(34249, 2328, 'Stargate SG-1 S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m629DIIQshE2REuY4TcCIHJz1CO.jpg'),
(34250, 2328, 'Stargate SG-1 S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gsQO88sxjg3CPSKxtVQ6vPIqcVo.jpg'),
(34251, 2328, 'Stargate SG-1 S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9TOS8ELbN6r31yHwneVXqIGZRhi.jpg'),
(34252, 2328, 'Stargate SG-1 S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3gG16dO33YujhfyIvAQl7280W7.jpg'),
(34253, 2328, 'Stargate SG-1 S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUs9cultvBXeJMo6z6XN1aRJJFi.jpg'),
(34254, 2328, 'Stargate SG-1 S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oY0JQv3nx7x8cUgo2qlA8aqNtYs.jpg'),
(34255, 2329, 'Survive [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123743.mp4', 'http://timg.bdta.pro/images/7cb2be074f99801fb4c196ad690af404.jpg'),
(34256, 2329, 'Survive [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123744.mp4', 'http://timg.bdta.pro/images/144b8605d92ace0411d7d2b71331a0b3.jpg'),
(34257, 2329, 'Survive [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123745.mp4', 'http://timg.bdta.pro/images/8e7651cde7acdb66944f2e012fc0a4a9.jpg'),
(34258, 2329, 'Survive [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123746.mp4', 'http://timg.bdta.pro/images/69e4e4a6b3988f35338ff2c46ac81295.jpg'),
(34259, 2329, 'Survive [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123747.mp4', 'http://timg.bdta.pro/images/5d0d580a0fd22d1d58ddbfc5fc7cba5f.jpg'),
(34260, 2329, 'Survive [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123748.mp4', 'http://timg.bdta.pro/images/8ae9e167a246e5e92379f11453d1f216.jpg'),
(34261, 2329, 'Survive [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123749.mp4', 'http://timg.bdta.pro/images/286ca7a7ce15290b516072843a06d95a.jpg'),
(34262, 2329, 'Survive [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123750.mp4', 'http://timg.bdta.pro/images/0fd33df1888c280198f98448fba0d13c.jpg'),
(34263, 2329, 'Survive [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123751.mp4', 'http://timg.bdta.pro/images/6c9617fb5519941171686ba525c79823.jpg'),
(34264, 2329, 'Survive [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123752.mp4', 'http://timg.bdta.pro/images/e250fd322bbb3eed89abdca7bd48c81b.jpg'),
(34265, 2329, 'Survive [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/123753.mp4', 'http://timg.bdta.pro/images/559fff5578b1f072610dcb6a05c6364f.jpg'),
(34266, 2329, 'Survive [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/123754.mp4', 'http://timg.bdta.pro/images/06420d73efab253ef2a73f4cf8d80b94.jpg'),
(34267, 2330, 'The Head [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124317.mp4', 'http://gstaticontent.com/images/vLNRamoZlSfODRvPucp1vi4Fqeh_big.jpg'),
(34268, 2330, 'The Head [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124318.mp4', 'http://gstaticontent.com/images/vLNRamoZlSfODRvPucp1vi4Fqeh_big.jpg'),
(34269, 2330, 'The Head [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124319.mp4', 'http://gstaticontent.com/images/vLNRamoZlSfODRvPucp1vi4Fqeh_big.jpg'),
(34270, 2330, 'The Head [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124320.mp4', 'http://gstaticontent.com/images/vLNRamoZlSfODRvPucp1vi4Fqeh_big.jpg'),
(34271, 2330, 'The Head [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124321.mp4', 'http://gstaticontent.com/images/vLNRamoZlSfODRvPucp1vi4Fqeh_big.jpg'),
(34272, 2330, 'The Head [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124322.mp4', 'http://gstaticontent.com/images/vLNRamoZlSfODRvPucp1vi4Fqeh_big.jpg'),
(34273, 2331, 'The Killing S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124323.mp4', 'http://timg.bdta.pro/images/96e6137277bb676584caefe07668389d.jpg'),
(34274, 2331, 'The Killing S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124324.mp4', 'http://timg.bdta.pro/images/dc82c929b9804537d76cc7c0823a91fb.jpg'),
(34275, 2331, 'The Killing S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124325.mp4', 'http://timg.bdta.pro/images/5ab1668224681b4e3075378c8bd5e5cb.jpg'),
(34276, 2331, 'The Killing S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124326.mp4', 'http://timg.bdta.pro/images/e6f329f63930a9ab43c6e4b2f4587208.jpg'),
(34277, 2331, 'The Killing S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124327.mp4', 'http://timg.bdta.pro/images/da814bb1afd37c771de057b2001cfc6e.jpg'),
(34278, 2331, 'The Killing S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124328.mp4', 'http://timg.bdta.pro/images/e05d57a855b843c1e9bceafe74138499.jpg'),
(34279, 2331, 'The Killing S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124329.mp4', 'http://timg.bdta.pro/images/7f02482bee0958b25c5a4c00b3ef8df1.jpg'),
(34280, 2331, 'The Killing S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124330.mp4', 'http://timg.bdta.pro/images/da8ada7c3600d9d4e849d3ac3d900bbb.jpg'),
(34281, 2331, 'The Killing S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124331.mp4', 'http://timg.bdta.pro/images/a5f1d53b97bc8b78ca029a017ec32afc.jpg'),
(34282, 2331, 'The Killing S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124332.mp4', 'http://timg.bdta.pro/images/7c3f4681682e5f7881e6836218cd4db2.jpg'),
(34283, 2331, 'The Killing S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124333.mp4', 'http://timg.bdta.pro/images/9c2c1435787c10ab84dea05413e99661.jpg'),
(34284, 2331, 'The Killing S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124334.mp4', 'http://timg.bdta.pro/images/f20b6282637fd92f9614e78a398b94bf.jpg'),
(34285, 2331, 'The Killing S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124335.mp4', 'http://timg.bdta.pro/images/64b5842cf0a7317ff1632b6d89985671.jpg'),
(34286, 2332, 'The Killing S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124336.mp4', 'http://timg.bdta.pro/images/21c079b0a8e18592e91859130d71cc01.jpg'),
(34287, 2332, 'The Killing S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124337.mp4', 'http://timg.bdta.pro/images/ae5158619cf90b7812d84f5f7436de1b.jpg'),
(34288, 2332, 'The Killing S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124338.mp4', 'http://timg.bdta.pro/images/9e9237112553a53187aae92e68444cbf.jpg'),
(34289, 2332, 'The Killing S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124339.mp4', 'http://timg.bdta.pro/images/9d820eef8fb11008995d74eef0eb6b02.jpg'),
(34290, 2332, 'The Killing S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124340.mp4', 'http://timg.bdta.pro/images/7a19f47bb0e8dcd0d246c4df2716b3d7.jpg'),
(34291, 2332, 'The Killing S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124341.mp4', 'http://timg.bdta.pro/images/f77084c894aaa394a87d354839c191b3.jpg'),
(34292, 2332, 'The Killing S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124342.mp4', 'http://timg.bdta.pro/images/5ae621dd42a4e087d63f4b512d3846a7.jpg'),
(34293, 2332, 'The Killing S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124343.mp4', 'http://timg.bdta.pro/images/23d85df867cac41c030b87c1f37994da.jpg'),
(34294, 2332, 'The Killing S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124344.mp4', 'http://timg.bdta.pro/images/e2564a5bdec7651a79425e3eb4a70e09.jpg'),
(34295, 2332, 'The Killing S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124345.mp4', 'http://timg.bdta.pro/images/b8d16be76c3d4300de34197a0539744c.jpg'),
(34296, 2332, 'The Killing S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124346.mp4', 'http://timg.bdta.pro/images/f1e8b86dcd2dd1c89f37e1612a5e41fe.jpg'),
(34297, 2332, 'The Killing S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124347.mp4', 'http://timg.bdta.pro/images/92b8e8737ab101b7c04ea3fdf6980e89.jpg'),
(34298, 2332, 'The Killing S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124348.mp4', 'http://timg.bdta.pro/images/a8cf9aee356836339514bcfa7d05f710.jpg'),
(34299, 2333, 'The Killing S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124349.mp4', 'http://timg.bdta.pro/images/f2bf85b5a0792b4223979f0d7794fcb3.jpg'),
(34300, 2333, 'The Killing S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124350.mp4', 'http://timg.bdta.pro/images/688221b0383020beaae34df79ca441cd.jpg'),
(34301, 2333, 'The Killing S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124351.mp4', 'http://timg.bdta.pro/images/8f022670488f90a1877bda55708c79bd.jpg'),
(34302, 2333, 'The Killing S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124352.mp4', 'http://timg.bdta.pro/images/cf97f80c6d5f2c13e3dc6a7464038d71.jpg'),
(34303, 2333, 'The Killing S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124353.mp4', 'http://timg.bdta.pro/images/cc203944fb80d29c44924b63d6259605.jpg'),
(34304, 2333, 'The Killing S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124354.mp4', 'http://timg.bdta.pro/images/2f4a489e1e2279f56aab2c17402f301b.jpg'),
(34305, 2333, 'The Killing S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124355.mp4', 'http://timg.bdta.pro/images/89f2c4d62dba1626b715c07a8cbe1f7d.jpg'),
(34306, 2333, 'The Killing S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124356.mp4', 'http://timg.bdta.pro/images/111c2d53159e7eb5079c6f6df931f98b.jpg'),
(34307, 2333, 'The Killing S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124357.mp4', 'http://timg.bdta.pro/images/6aebba2010ba40babe0107fd4f6fd8a9.jpg'),
(34308, 2333, 'The Killing S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124358.mp4', 'http://timg.bdta.pro/images/ded0a3e1c759f63304ec0c5f3c5443d4.jpg'),
(34309, 2334, 'The Killing S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124359.mp4', 'http://timg.bdta.pro/images/dc4717c8ba67870e1d6b32e762a901b9.jpg'),
(34310, 2334, 'The Killing S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124360.mp4', 'http://timg.bdta.pro/images/54a2b578dffb0a4070e2090c492b1f56.jpg'),
(34311, 2334, 'The Killing S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124361.mp4', 'http://timg.bdta.pro/images/e42b70fb1bb2806d024ec0f70c9530b8.jpg'),
(34312, 2334, 'The Killing S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124362.mp4', 'http://timg.bdta.pro/images/c370d7b6833f17b8b9175ac490de5249.jpg'),
(34313, 2334, 'The Killing S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124363.mp4', 'http://timg.bdta.pro/images/c4fc2d2e065f602e8fb4e1c44b9d91c2.jpg'),
(34314, 2334, 'The Killing S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124364.mp4', 'http://timg.bdta.pro/images/3f773e5287f5ce7b246dc3341752eb4f.jpg'),
(34315, 2335, 'The Odd Couple S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124365.mp4', 'http://timg.bdta.pro/images/495db35ef6ffeb861c7a4e389041c470.jpg'),
(34316, 2335, 'The Odd Couple S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124366.mp4', 'http://timg.bdta.pro/images/a1112a9351860e46e1e0515a0bd437ac.jpg'),
(34317, 2335, 'The Odd Couple S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124367.mp4', 'http://timg.bdta.pro/images/72b61a8365c11185ad6577bf5f5dbd9e.jpg'),
(34318, 2335, 'The Odd Couple S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124368.mp4', 'http://timg.bdta.pro/images/baaaa0a79a34179c821a19e44091c191.jpg'),
(34319, 2335, 'The Odd Couple S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124369.mp4', 'http://timg.bdta.pro/images/6f9e362d0622bfc13c854ffdc1572236.jpg'),
(34320, 2335, 'The Odd Couple S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124370.mp4', 'http://timg.bdta.pro/images/50c152e5e2dad4aa01b45bde13a39bc6.jpg'),
(34321, 2335, 'The Odd Couple S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124371.mp4', 'http://timg.bdta.pro/images/cdcfbfad179844b8a90b37cbd87fc100.jpg'),
(34322, 2335, 'The Odd Couple S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124372.mp4', 'http://timg.bdta.pro/images/1a30330f6da7ab4cc36750789e7dd9dc.jpg'),
(34323, 2335, 'The Odd Couple S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124373.mp4', 'http://timg.bdta.pro/images/b73508cb959db94afc15333096a194de.jpg'),
(34324, 2335, 'The Odd Couple S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124374.mp4', 'http://timg.bdta.pro/images/93d4efcf6822b47ad9ac2207a807fca9.jpg'),
(34325, 2335, 'The Odd Couple S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124375.mp4', 'http://timg.bdta.pro/images/2bde3011a86191ad38b23608942f04a6.jpg'),
(34326, 2335, 'The Odd Couple S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124376.mp4', 'http://timg.bdta.pro/images/4e689bf41bfc1e008c09d855a16c951a.jpg'),
(34327, 2336, 'The Odd Couple S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124377.mp4', 'http://timg.bdta.pro/images/44d3bbfdc20834811d253aca52b2284f.jpg'),
(34328, 2336, 'The Odd Couple S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124378.mp4', 'http://timg.bdta.pro/images/36e5b64af06936947dd7a4658527235f.jpg'),
(34329, 2336, 'The Odd Couple S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124379.mp4', 'http://timg.bdta.pro/images/f31c6a54bbbc2500b3a4d0decb856ccf.jpg'),
(34330, 2336, 'The Odd Couple S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124380.mp4', 'http://timg.bdta.pro/images/597631f195dfe16ed48c45776affe630.jpg'),
(34331, 2336, 'The Odd Couple S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124381.mp4', 'http://timg.bdta.pro/images/1ade8ed7d27b6a9453d1fe4bcddd4f80.jpg'),
(34332, 2336, 'The Odd Couple S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124382.mp4', 'http://timg.bdta.pro/images/a8e73de99c1a3f8517ea78baa51ec103.jpg'),
(34333, 2336, 'The Odd Couple S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124383.mp4', 'http://timg.bdta.pro/images/11f8b999d2577ea1f8c380805e63dd20.jpg'),
(34334, 2336, 'The Odd Couple S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124384.mp4', 'http://timg.bdta.pro/images/722c5f1766eaa8e2f498f5f299fe2272.jpg'),
(34335, 2336, 'The Odd Couple S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124385.mp4', 'http://timg.bdta.pro/images/45aac2cb85ac83fa3e6757b46b5383b5.jpg'),
(34336, 2336, 'The Odd Couple S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124386.mp4', 'http://timg.bdta.pro/images/c630fbc47049d438a597dfd6649198f9.jpg'),
(34337, 2336, 'The Odd Couple S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124387.mp4', 'http://timg.bdta.pro/images/a555f6c60503cf7192193264f7fe0610.jpg'),
(34338, 2336, 'The Odd Couple S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124388.mp4', 'http://timg.bdta.pro/images/13e3636e17cc457696f64bf9b5c6bd6f.jpg'),
(34339, 2336, 'The Odd Couple S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/124389.mp4', 'http://timg.bdta.pro/images/59e87e5117cce2e112609b705040f510.jpg'),
(34340, 2337, 'The Odd Couple S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/124390.mp4', 'http://timg.bdta.pro/images/16bf944dca2252c349aa1eb943d90c93.jpg'),
(34341, 2337, 'The Odd Couple S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/124391.mp4', 'http://timg.bdta.pro/images/73d1339cc7da8418166f8f5d58992de2.jpg'),
(34342, 2337, 'The Odd Couple S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/124392.mp4', 'http://timg.bdta.pro/images/191b92607175b0a6ba82eec303d871e1.jpg'),
(34343, 2337, 'The Odd Couple S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/124393.mp4', 'http://timg.bdta.pro/images/5275c094afac07ee28b7662dc37a5184.jpg'),
(34344, 2337, 'The Odd Couple S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/124394.mp4', 'http://timg.bdta.pro/images/dbcb14703bd74ba9b7ce3a7954d1d444.jpg'),
(34345, 2337, 'The Odd Couple S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/124395.mp4', 'http://timg.bdta.pro/images/e3fb549ae37edc601ee107229559aee7.jpg'),
(34346, 2337, 'The Odd Couple S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/124396.mp4', 'http://timg.bdta.pro/images/04fd8310d0a8ff0563de696d61737fe6.jpg'),
(34347, 2337, 'The Odd Couple S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/124397.mp4', 'http://timg.bdta.pro/images/4617e09c713e1c868942c789e68128eb.jpg'),
(34348, 2337, 'The Odd Couple S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/124398.mp4', 'http://timg.bdta.pro/images/5be5f6c03fa292f2ab667702218757ec.jpg'),
(34349, 2337, 'The Odd Couple S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/124399.mp4', 'http://timg.bdta.pro/images/d8ff5b6ed270d3fd97602fbf0b0684e1.jpg'),
(34350, 2337, 'The Odd Couple S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/124400.mp4', 'http://timg.bdta.pro/images/250a599ef29897cd43f4684763d6b0f3.jpg'),
(34351, 2337, 'The Odd Couple S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/124401.mp4', 'http://timg.bdta.pro/images/ffb29d58c4c5a3b4a16d62c9c7913ffe.jpg'),
(34352, 2338, 'Washington S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123740.mp4', 'http://timg.bdta.pro/images/bd206768e80256161457bf2b55823ef8.jpg'),
(34353, 2338, 'Washington S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123741.mp4', 'http://timg.bdta.pro/images/b7128c56241db8bcea7a0ce1fdc214ae.jpg'),
(34354, 2338, 'Washington S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123742.mp4', 'http://timg.bdta.pro/images/451017c42a80a64e2973d1fef62fdac6.jpg'),
(34355, 2339, 'Vis a Vis: El Oasis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123764.mp4', 'http://timg.bdta.pro/images/e32a8f541e02e3f9baa4b9d5c72f9b88.jpg'),
(34356, 2339, 'Vis a Vis: El Oasis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123765.mp4', 'http://timg.bdta.pro/images/6981fc2b5ab82bd1a40e20221e7585da.jpg'),
(34357, 2339, 'Vis a Vis: El Oasis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123766.mp4', 'http://timg.bdta.pro/images/ece6019a6bbaa35a283bf9d74e2f4415.jpg'),
(34358, 2339, 'Vis a Vis: El Oasis S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123767.mp4', 'http://timg.bdta.pro/images/60ba3aaf02dafa498ca3fcb23336ac54.jpg'),
(34359, 2339, 'Vis a Vis: El Oasis S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123768.mp4', 'http://timg.bdta.pro/images/f6532d13e99098246ccab5cc423ae85b.jpg'),
(34360, 2339, 'Vis a Vis: El Oasis S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123769.mp4', 'http://timg.bdta.pro/images/e6fa15893dde92aecc78e56cdfcebd13.jpg'),
(34361, 2339, 'Vis a Vis: El Oasis S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123770.mp4', 'http://timg.bdta.pro/images/31490b5dfd576e50ec432d06371b096b.jpg'),
(34362, 2339, 'Vis a Vis: El Oasis S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123771.mp4', 'http://timg.bdta.pro/images/ba485ef66d240e740b8d5db915894d7a.jpg'),
(34363, 2340, 'A Era dos Dados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123734.mp4', 'http://timg.bdta.pro/images/cd677b775583b9f5cf2f4988bc55afd1.jpg'),
(34364, 2340, 'A Era dos Dados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123735.mp4', 'http://timg.bdta.pro/images/e2b44ac15147b47c222fe935e7010c60.jpg'),
(34365, 2340, 'A Era dos Dados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123736.mp4', 'http://timg.bdta.pro/images/cbd39c7c8496ea3d42adb022b2d2dbcc.jpg'),
(34366, 2340, 'A Era dos Dados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123737.mp4', 'http://timg.bdta.pro/images/4347dbc08b71717ea36e4706ca2c4b71.jpg'),
(34367, 2340, 'A Era dos Dados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123738.mp4', 'http://timg.bdta.pro/images/4cb29a73f69b5bbb04da7baccdc30d02.jpg'),
(34368, 2340, 'A Era dos Dados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123739.mp4', 'http://timg.bdta.pro/images/b617ced9eebe464d1f916b8798bd1e26.jpg'),
(34369, 2341, 'A História de Deus com Morgan Freeman S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123719.mp4', 'http://timg.bdta.pro/images/826c98ca8d78bd7949f0da1fdd09cee4.jpg'),
(34370, 2341, 'A História de Deus com Morgan Freeman S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123720.mp4', 'http://timg.bdta.pro/images/72add4cc00ba3694f2b0619f7189655f.jpg'),
(34371, 2341, 'A História de Deus com Morgan Freeman S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123721.mp4', 'http://timg.bdta.pro/images/525bdcc7edb3f0750cc5b08a9032d02b.jpg'),
(34372, 2341, 'A História de Deus com Morgan Freeman S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123722.mp4', 'http://timg.bdta.pro/images/e086c9bb4754d48c269bf4867e33d47d.jpg'),
(34373, 2341, 'A História de Deus com Morgan Freeman S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123723.mp4', 'http://timg.bdta.pro/images/62b0d435fbd18583e7b08512d6113237.jpg'),
(34374, 2341, 'A História de Deus com Morgan Freeman S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123724.mp4', 'http://timg.bdta.pro/images/5f8dc1e0ce87e483688c343286216e25.jpg'),
(34375, 2342, 'A História de Deus com Morgan Freeman S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123725.mp4', 'http://timg.bdta.pro/images/2ac3ee3bedd38be3649e67189501bf3d.jpg'),
(34376, 2342, 'A História de Deus com Morgan Freeman S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123726.mp4', 'http://timg.bdta.pro/images/b75f5bbf80b91569d75742bde25bd152.jpg'),
(34377, 2342, 'A História de Deus com Morgan Freeman S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123727.mp4', 'http://timg.bdta.pro/images/b10553f1a426332e6fd850c6b6a78c77.jpg'),
(34378, 2343, 'A História de Deus com Morgan Freeman S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123728.mp4', 'http://timg.bdta.pro/images/ff821d543066881bafa8f22ce5cfa01b.jpg'),
(34379, 2343, 'A História de Deus com Morgan Freeman S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123729.mp4', 'http://timg.bdta.pro/images/ff821d543066881bafa8f22ce5cfa01b.jpg'),
(34380, 2343, 'A História de Deus com Morgan Freeman S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123730.mp4', 'http://timg.bdta.pro/images/ff821d543066881bafa8f22ce5cfa01b.jpg'),
(34381, 2343, 'A História de Deus com Morgan Freeman S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123731.mp4', 'http://timg.bdta.pro/images/ff821d543066881bafa8f22ce5cfa01b.jpg'),
(34382, 2343, 'A História de Deus com Morgan Freeman S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123732.mp4', 'http://timg.bdta.pro/images/ff821d543066881bafa8f22ce5cfa01b.jpg'),
(34383, 2343, 'A História de Deus com Morgan Freeman S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123733.mp4', 'http://timg.bdta.pro/images/ff821d543066881bafa8f22ce5cfa01b.jpg'),
(34384, 2344, 'A Xerife Callie no Oeste S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123674.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34385, 2344, 'A Xerife Callie no Oeste S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123675.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34386, 2344, 'A Xerife Callie no Oeste S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123676.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34387, 2344, 'A Xerife Callie no Oeste S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123677.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34388, 2344, 'A Xerife Callie no Oeste S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123678.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34389, 2344, 'A Xerife Callie no Oeste S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123679.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34390, 2344, 'A Xerife Callie no Oeste S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123680.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34391, 2344, 'A Xerife Callie no Oeste S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123681.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34392, 2344, 'A Xerife Callie no Oeste S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123682.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34393, 2344, 'A Xerife Callie no Oeste S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123683.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34394, 2344, 'A Xerife Callie no Oeste S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/123684.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34395, 2344, 'A Xerife Callie no Oeste S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/123685.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34396, 2344, 'A Xerife Callie no Oeste S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/123686.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34397, 2344, 'A Xerife Callie no Oeste S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/123687.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34398, 2344, 'A Xerife Callie no Oeste S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/123688.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34399, 2344, 'A Xerife Callie no Oeste S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/123689.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34400, 2344, 'A Xerife Callie no Oeste S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/123690.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34401, 2344, 'A Xerife Callie no Oeste S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/123691.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34402, 2344, 'A Xerife Callie no Oeste S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/123692.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34403, 2344, 'A Xerife Callie no Oeste S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/123693.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34404, 2344, 'A Xerife Callie no Oeste S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/123694.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34405, 2344, 'A Xerife Callie no Oeste S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/123695.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34406, 2344, 'A Xerife Callie no Oeste S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/123696.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34407, 2345, 'A Xerife Callie no Oeste S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123697.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34408, 2345, 'A Xerife Callie no Oeste S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123698.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34409, 2345, 'A Xerife Callie no Oeste S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123699.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34410, 2345, 'A Xerife Callie no Oeste S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123700.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34411, 2345, 'A Xerife Callie no Oeste S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123701.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34412, 2345, 'A Xerife Callie no Oeste S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123702.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34413, 2345, 'A Xerife Callie no Oeste S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123703.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34414, 2345, 'A Xerife Callie no Oeste S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123704.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34415, 2345, 'A Xerife Callie no Oeste S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123705.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34416, 2345, 'A Xerife Callie no Oeste S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123706.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34417, 2345, 'A Xerife Callie no Oeste S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/123707.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34418, 2345, 'A Xerife Callie no Oeste S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/123708.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34419, 2345, 'A Xerife Callie no Oeste S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/123709.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34420, 2345, 'A Xerife Callie no Oeste S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/123710.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34421, 2345, 'A Xerife Callie no Oeste S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/123711.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34422, 2345, 'A Xerife Callie no Oeste S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/123712.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34423, 2345, 'A Xerife Callie no Oeste S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/123713.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34424, 2345, 'A Xerife Callie no Oeste S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/123714.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34425, 2345, 'A Xerife Callie no Oeste S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/123715.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34426, 2345, 'A Xerife Callie no Oeste S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/123716.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34427, 2345, 'A Xerife Callie no Oeste S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/123717.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34428, 2345, 'A Xerife Callie no Oeste S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/123718.mp4', 'http://gstaticontent.com/images/maT6jmgmYDQnqkueTCsNi8dQ1Ux_big.jpg'),
(34429, 2346, 'Aqui na Terra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123658.mp4', 'http://timg.bdta.pro/images/db8170b942a02bf87f20581d75f5fdf7.jpg'),
(34430, 2346, 'Aqui na Terra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123659.mp4', 'http://timg.bdta.pro/images/b19c84a167b06ccb23a398af34758f97.jpg'),
(34431, 2346, 'Aqui na Terra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123660.mp4', 'http://timg.bdta.pro/images/bc2ca20b12715be5ce5703e68549e39b.jpg'),
(34432, 2346, 'Aqui na Terra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123661.mp4', 'http://timg.bdta.pro/images/b0cc03ae06f578e59c985b68c8930368.jpg'),
(34433, 2346, 'Aqui na Terra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123662.mp4', 'http://timg.bdta.pro/images/14f26aa66cc2b3c9993dbc3727c4ac1a.jpg'),
(34434, 2346, 'Aqui na Terra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123663.mp4', 'http://timg.bdta.pro/images/72b2dd46f3dd9f3ab8f7f570c44ba622.jpg'),
(34435, 2346, 'Aqui na Terra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123664.mp4', 'http://timg.bdta.pro/images/1b1acce6c97c814e823f0e03d8bb5996.jpg'),
(34436, 2346, 'Aqui na Terra S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123665.mp4', 'http://timg.bdta.pro/images/143f68164e3e57fc4415add0c0d7e8a5.jpg'),
(34437, 2347, 'Aqui na Terra S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123666.mp4', 'http://timg.bdta.pro/images/143f68164e3e57fc4415add0c0d7e8a5.jpg'),
(34438, 2347, 'Aqui na Terra S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123667.mp4', 'http://timg.bdta.pro/images/143f68164e3e57fc4415add0c0d7e8a5.jpg'),
(34439, 2347, 'Aqui na Terra S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123668.mp4', 'http://timg.bdta.pro/images/143f68164e3e57fc4415add0c0d7e8a5.jpg'),
(34440, 2347, 'Aqui na Terra S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123669.mp4', 'http://timg.bdta.pro/images/143f68164e3e57fc4415add0c0d7e8a5.jpg'),
(34441, 2347, 'Aqui na Terra S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123670.mp4', 'http://timg.bdta.pro/images/143f68164e3e57fc4415add0c0d7e8a5.jpg'),
(34442, 2347, 'Aqui na Terra S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123671.mp4', 'http://timg.bdta.pro/images/143f68164e3e57fc4415add0c0d7e8a5.jpg'),
(34443, 2347, 'Aqui na Terra S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123672.mp4', 'http://timg.bdta.pro/images/143f68164e3e57fc4415add0c0d7e8a5.jpg'),
(34444, 2347, 'Aqui na Terra S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123673.mp4', 'http://timg.bdta.pro/images/143f68164e3e57fc4415add0c0d7e8a5.jpg'),
(34445, 2348, 'Einstein S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123625.mp4', 'http://timg.bdta.pro/images/a958493539a8366ff04239ce4eb483a5.jpg'),
(34446, 2348, 'Einstein S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123626.mp4', 'http://timg.bdta.pro/images/2005d338ca6c7fa6c332b85ced9ba042.jpg'),
(34447, 2348, 'Einstein S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123627.mp4', 'http://timg.bdta.pro/images/38e3aff6c4b596621a563c107c23c300.jpg'),
(34448, 2348, 'Einstein S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123628.mp4', 'http://timg.bdta.pro/images/c540c988eb6f1180056718ccb0072656.jpg'),
(34449, 2348, 'Einstein S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123629.mp4', 'http://timg.bdta.pro/images/e6252b5d951d491aa750e3b7c6e4a62d.jpg'),
(34450, 2348, 'Einstein S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123630.mp4', 'http://timg.bdta.pro/images/8e6663b499bbe3d8d4058e3ae977ffcc.jpg'),
(34451, 2348, 'Einstein S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123631.mp4', 'http://timg.bdta.pro/images/f6b7a92a86d9a09b5ece3281edd7ea92.jpg'),
(34452, 2348, 'Einstein S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123632.mp4', 'http://timg.bdta.pro/images/fd35885a14b80a6a6937284e4f25a964.jpg'),
(34453, 2348, 'Einstein S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123633.mp4', 'http://timg.bdta.pro/images/6de5ca07168ffb8f45c04d41e0740d8f.jpg'),
(34454, 2348, 'Einstein S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123634.mp4', 'http://timg.bdta.pro/images/e24bc5e6abab945cc2e01352e9a9fb98.jpg'),
(34455, 2348, 'Einstein S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/123635.mp4', 'http://gstaticontent.com/images/f9ynvnKq1LACJaaUgT26VCmOtOu_big.jpg'),
(34456, 2349, 'Einstein S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123636.mp4', 'http://timg.bdta.pro/images/f4ad2e619726e4c5892f9b54235c3a35.jpg'),
(34457, 2349, 'Einstein S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123637.mp4', 'http://timg.bdta.pro/images/20fa5a888c6bf1318c7b6e64de40926d.jpg'),
(34458, 2349, 'Einstein S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123638.mp4', 'http://timg.bdta.pro/images/5f586f42632018ab7f857b5d462526fb.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(34459, 2349, 'Einstein S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123639.mp4', 'http://timg.bdta.pro/images/0fc5df79f9354c8313ad238c31876a65.jpg'),
(34460, 2349, 'Einstein S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123640.mp4', 'http://timg.bdta.pro/images/62cd3b7a76935a5136ad18c2319c6e3d.jpg'),
(34461, 2349, 'Einstein S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123641.mp4', 'http://timg.bdta.pro/images/62cd3b7a76935a5136ad18c2319c6e3d.jpg'),
(34462, 2349, 'Einstein S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123642.mp4', 'http://timg.bdta.pro/images/6affde3b9fe6a8a00191f45b77be6be4.jpg'),
(34463, 2349, 'Einstein S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123643.mp4', 'http://timg.bdta.pro/images/6affde3b9fe6a8a00191f45b77be6be4.jpg'),
(34464, 2349, 'Einstein S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123644.mp4', 'http://timg.bdta.pro/images/137c8a35442b6944a381fb5bb6426fe8.jpg'),
(34465, 2349, 'Einstein S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123645.mp4', 'http://timg.bdta.pro/images/2d1e81994d11f63bcaaa527dbb844d22.jpg'),
(34466, 2350, 'Einstein S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123646.mp4', 'http://timg.bdta.pro/images/d49b7a9c9d24e916409761c02f5ce56a.jpg'),
(34467, 2350, 'Einstein S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123647.mp4', 'http://timg.bdta.pro/images/d49b7a9c9d24e916409761c02f5ce56a.jpg'),
(34468, 2350, 'Einstein S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123648.mp4', 'http://timg.bdta.pro/images/5f57d3cf151aec7357fc8317eb60918f.jpg'),
(34469, 2350, 'Einstein S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123649.mp4', 'http://timg.bdta.pro/images/7dac1eaad496ed4fd2a9bfd36d83a58d.jpg'),
(34470, 2350, 'Einstein S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123650.mp4', 'http://timg.bdta.pro/images/aa682fe574b4991b851edb4d9fdeea26.jpg'),
(34471, 2350, 'Einstein S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123651.mp4', 'http://timg.bdta.pro/images/a94ac0b1dac0c39e4b43a47c81a1186c.jpg'),
(34472, 2350, 'Einstein S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123652.mp4', 'http://timg.bdta.pro/images/7681d0e38f8960a66b848f933443e0f9.jpg'),
(34473, 2350, 'Einstein S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123653.mp4', 'http://timg.bdta.pro/images/60b7cc7f9bdd730109f2d3e03579d8f0.jpg'),
(34474, 2350, 'Einstein S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123654.mp4', 'http://timg.bdta.pro/images/60b7cc7f9bdd730109f2d3e03579d8f0.jpg'),
(34475, 2350, 'Einstein S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123655.mp4', 'http://timg.bdta.pro/images/203f6c91e18661e67c6fa4c96060d93f.jpg'),
(34476, 2350, 'Einstein S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/123656.mp4', 'http://timg.bdta.pro/images/203f6c91e18661e67c6fa4c96060d93f.jpg'),
(34477, 2350, 'Einstein S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/123657.mp4', 'http://timg.bdta.pro/images/203f6c91e18661e67c6fa4c96060d93f.jpg'),
(34478, 2351, 'Em Busca das Luzes do Norte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123619.mp4', 'https://s2.glbimg.com/ctCf7NwhDDQXj6Yu0VyvueLlZg0=/362x536/https://s2.glbimg.com/71uTM0h1pQSwPHWqwnBFA3_xFfU=/i.s3.glbimg.com/v1/AUTH_c3c606ff68e7478091d1ca496f9c5625/internal_photos/bs/2020/V/m/wUa9m8RYGlvxl06lLG0Q/2020-luzes-do-norte-poster.jpg'),
(34479, 2351, 'Em Busca das Luzes do Norte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123620.mp4', 'https://s2.glbimg.com/ctCf7NwhDDQXj6Yu0VyvueLlZg0=/362x536/https://s2.glbimg.com/71uTM0h1pQSwPHWqwnBFA3_xFfU=/i.s3.glbimg.com/v1/AUTH_c3c606ff68e7478091d1ca496f9c5625/internal_photos/bs/2020/V/m/wUa9m8RYGlvxl06lLG0Q/2020-luzes-do-norte-poster.jpg'),
(34480, 2351, 'Em Busca das Luzes do Norte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123621.mp4', 'https://s2.glbimg.com/ctCf7NwhDDQXj6Yu0VyvueLlZg0=/362x536/https://s2.glbimg.com/71uTM0h1pQSwPHWqwnBFA3_xFfU=/i.s3.glbimg.com/v1/AUTH_c3c606ff68e7478091d1ca496f9c5625/internal_photos/bs/2020/V/m/wUa9m8RYGlvxl06lLG0Q/2020-luzes-do-norte-poster.jpg'),
(34481, 2351, 'Em Busca das Luzes do Norte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123622.mp4', 'https://s2.glbimg.com/ctCf7NwhDDQXj6Yu0VyvueLlZg0=/362x536/https://s2.glbimg.com/71uTM0h1pQSwPHWqwnBFA3_xFfU=/i.s3.glbimg.com/v1/AUTH_c3c606ff68e7478091d1ca496f9c5625/internal_photos/bs/2020/V/m/wUa9m8RYGlvxl06lLG0Q/2020-luzes-do-norte-poster.jpg'),
(34482, 2351, 'Em Busca das Luzes do Norte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123623.mp4', 'https://s2.glbimg.com/ctCf7NwhDDQXj6Yu0VyvueLlZg0=/362x536/https://s2.glbimg.com/71uTM0h1pQSwPHWqwnBFA3_xFfU=/i.s3.glbimg.com/v1/AUTH_c3c606ff68e7478091d1ca496f9c5625/internal_photos/bs/2020/V/m/wUa9m8RYGlvxl06lLG0Q/2020-luzes-do-norte-poster.jpg'),
(34483, 2351, 'Em Busca das Luzes do Norte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123624.mp4', 'https://s2.glbimg.com/ctCf7NwhDDQXj6Yu0VyvueLlZg0=/362x536/https://s2.glbimg.com/71uTM0h1pQSwPHWqwnBFA3_xFfU=/i.s3.glbimg.com/v1/AUTH_c3c606ff68e7478091d1ca496f9c5625/internal_photos/bs/2020/V/m/wUa9m8RYGlvxl06lLG0Q/2020-luzes-do-norte-poster.jpg'),
(34484, 2352, 'Hatfields & McCoys S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123478.mp4', 'http://timg.bdta.pro/images/a63c319b9b4cf4079479371b27cb7170.jpg'),
(34485, 2352, 'Hatfields & McCoys S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123479.mp4', 'http://timg.bdta.pro/images/bb42a06e391342f5bbffa274f76476ae.jpg'),
(34486, 2352, 'Hatfields & McCoys S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123480.mp4', 'http://timg.bdta.pro/images/de8515fb13b79dee0081e08c4ad95ed7.jpg'),
(34487, 2353, 'Hightown S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168838.mp4', 'http://timg.bdta.pro/images/7ada2189eac50496da2f8d30ed146621.jpg'),
(34488, 2353, 'Hightown S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168839.mp4', 'http://timg.bdta.pro/images/dfb87d850c53fbb2701ccde2f71f2039.jpg'),
(34489, 2353, 'Hightown S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168840.mp4', 'http://timg.bdta.pro/images/dd911ea9eae0b0c66ecda20a18ee2038.jpg'),
(34490, 2353, 'Hightown S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168841.mp4', 'http://timg.bdta.pro/images/5a04011e052457ebee7a77bf35b87d2e.jpg'),
(34491, 2353, 'Hightown S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168842.mp4', 'http://timg.bdta.pro/images/d7ebbaba4ef1fe6be39cd9f26e41c0ba.jpg'),
(34492, 2353, 'Hightown S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168843.mp4', 'http://timg.bdta.pro/images/75a209556a7eaae3c7e88e08c04e1d6c.jpg'),
(34493, 2353, 'Hightown S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168844.mp4', 'http://timg.bdta.pro/images/6db98debc6dd6a8fb1ae809d954864cc.jpg'),
(34494, 2353, 'Hightown S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168845.mp4', 'http://timg.bdta.pro/images/035364c8a530dea941bb880b7694d6e4.jpg'),
(34495, 2354, 'Hightown S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tisDX3QwNuOi1rFVaQaGwH7QfTx.jpg'),
(34496, 2354, 'Hightown S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wQLqc6w5OOyy9fLKi00RbYOYCta.jpg'),
(34497, 2354, 'Hightown S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s8WErNwzxzJJrrA7ZK2dYnUpnul.jpg'),
(34498, 2354, 'Hightown S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kHzA4XDdYr7J0OzK4QUaBWACKhz.jpg'),
(34499, 2354, 'Hightown S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168850.mp4', 'http://image.tmdb.org/t/p/w1280/fCVJyWp96JUh6ml5P4MQ9rIcZdP.jpg'),
(34500, 2354, 'Hightown S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168851.mp4', 'http://image.tmdb.org/t/p/w1280/gFzSdSmF1ng0J2baleiCV3c1H0o.jpg'),
(34501, 2354, 'Hightown S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168852.mp4', 'http://image.tmdb.org/t/p/w1280/iiz3Zrl7843ENH3RJWYEbmY2lWw.jpg'),
(34502, 2354, 'Hightown S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168853.mp4', 'http://image.tmdb.org/t/p/w1280/ypALw43Y37enI8HOzFx8Y99nviB.jpg'),
(34503, 2354, 'Hightown S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/168854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7HUo6hHYIAHEVsQuu7lArZGrRXT.jpg'),
(34504, 2354, 'Hightown S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/168855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wmZtiYXoA0ZSHmx4nBiVhi0YpXe.jpg'),
(34505, 2355, 'Immigration Nation S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123472.mp4', 'http://gstaticontent.com/images/lqMU6yRjho7w6advYliIK2Od4n4_big.jpg'),
(34506, 2355, 'Immigration Nation S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123473.mp4', 'http://gstaticontent.com/images/lqMU6yRjho7w6advYliIK2Od4n4_big.jpg'),
(34507, 2355, 'Immigration Nation S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123474.mp4', 'http://gstaticontent.com/images/lqMU6yRjho7w6advYliIK2Od4n4_big.jpg'),
(34508, 2355, 'Immigration Nation S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123475.mp4', 'http://gstaticontent.com/images/lqMU6yRjho7w6advYliIK2Od4n4_big.jpg'),
(34509, 2355, 'Immigration Nation S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123476.mp4', 'http://gstaticontent.com/images/lqMU6yRjho7w6advYliIK2Od4n4_big.jpg'),
(34510, 2355, 'Immigration Nation S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123477.mp4', 'http://gstaticontent.com/images/lqMU6yRjho7w6advYliIK2Od4n4_big.jpg'),
(34511, 2356, 'Interrogation [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123462.mp4', 'http://timg.bdta.pro/images/b86fedc503c04528b8812b15b867ce01.jpg'),
(34512, 2356, 'Interrogation [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123463.mp4', 'http://timg.bdta.pro/images/6631246c4c205fbea3eafc250e233410.jpg'),
(34513, 2356, 'Interrogation [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123464.mp4', 'http://timg.bdta.pro/images/93e4f5f6a47ed68a4954845c4b069c7e.jpg'),
(34514, 2356, 'Interrogation [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123465.mp4', 'http://timg.bdta.pro/images/631a75ff17810314eae756935b24527e.jpg'),
(34515, 2356, 'Interrogation [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123466.mp4', 'http://timg.bdta.pro/images/ee43d21d1faa801229f994e78f12be29.jpg'),
(34516, 2356, 'Interrogation [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123467.mp4', 'http://timg.bdta.pro/images/a911599028d77a5e6454865a025687d6.jpg'),
(34517, 2356, 'Interrogation [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123468.mp4', 'http://timg.bdta.pro/images/20ac4fa76029e47f2df8a2cf552b7552.jpg'),
(34518, 2356, 'Interrogation [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123469.mp4', 'http://timg.bdta.pro/images/0d210f4df83c806507386a175db3c6cc.jpg'),
(34519, 2356, 'Interrogation [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123470.mp4', 'http://timg.bdta.pro/images/d1aba78ff2be4e2159a770c74a84df46.jpg'),
(34520, 2356, 'Interrogation [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123471.mp4', 'http://timg.bdta.pro/images/29ee6253104dad2d699a7794a09fdabf.jpg'),
(34521, 2357, 'Jamestown S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123439.mp4', 'http://timg.bdta.pro/images/a5347521050036d25a2361f991421a0f.jpg'),
(34522, 2357, 'Jamestown S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123440.mp4', 'http://timg.bdta.pro/images/caec91cdb1e5ca2aa5faf4c112bfd891.jpg'),
(34523, 2357, 'Jamestown S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123441.mp4', 'http://timg.bdta.pro/images/68a96094df2a712a46cc6c51ff094fd9.jpg'),
(34524, 2357, 'Jamestown S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123442.mp4', 'http://timg.bdta.pro/images/f508179fee1c9e39291394bdf53c37df.jpg'),
(34525, 2357, 'Jamestown S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123443.mp4', 'http://timg.bdta.pro/images/ff8c688e62345c1c89820fb05e37432b.jpg'),
(34526, 2357, 'Jamestown S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123444.mp4', 'http://timg.bdta.pro/images/2b036ea1b167daf6b6325b43ac312e33.jpg'),
(34527, 2357, 'Jamestown S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123445.mp4', 'http://timg.bdta.pro/images/5e4f2fdad1bac6e2ea74132e02dca4e7.jpg'),
(34528, 2357, 'Jamestown S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123446.mp4', 'http://timg.bdta.pro/images/6e3410a7020cba0a858f77bd20cf2c4d.jpg'),
(34529, 2358, 'Jamestown S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123447.mp4', 'http://timg.bdta.pro/images/30ac808511d31e84aeda2f1a8c90dcf8.jpg'),
(34530, 2358, 'Jamestown S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123448.mp4', 'http://timg.bdta.pro/images/dcb1607b499a5d7c645cf5ffa645037b.jpg'),
(34531, 2358, 'Jamestown S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123449.mp4', 'http://timg.bdta.pro/images/5a3313438ad87ae9710c9dc1133ba094.jpg'),
(34532, 2358, 'Jamestown S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123450.mp4', 'http://timg.bdta.pro/images/9c280b2dd85ebcef23cc0f82d6c4594f.jpg'),
(34533, 2358, 'Jamestown S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123451.mp4', 'http://timg.bdta.pro/images/15a7feb3384dbf0b3cf9ff24ae6ffe7e.jpg'),
(34534, 2358, 'Jamestown S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123452.mp4', 'http://timg.bdta.pro/images/2bbc611391389eae20c6f385d595fb17.jpg'),
(34535, 2358, 'Jamestown S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123453.mp4', 'http://timg.bdta.pro/images/e21413810fe51e2ffb6f97fe77dfba16.jpg'),
(34536, 2359, 'Jamestown S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123454.mp4', 'http://timg.bdta.pro/images/0b6971e22346c298bcc5e51102197fef.jpg'),
(34537, 2359, 'Jamestown S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123455.mp4', 'http://timg.bdta.pro/images/60e62a5ad5746a7587811dea761142ba.jpg'),
(34538, 2359, 'Jamestown S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123456.mp4', 'http://timg.bdta.pro/images/b028cda043ba2d9bc1460aff4a0414ca.jpg'),
(34539, 2359, 'Jamestown S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123457.mp4', 'http://timg.bdta.pro/images/77cae138430b4e623af44b9ae55316d1.jpg'),
(34540, 2359, 'Jamestown S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123458.mp4', 'http://timg.bdta.pro/images/7f933cdb6aca9e29cb3cd7dbda86219a.jpg'),
(34541, 2359, 'Jamestown S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123459.mp4', 'http://timg.bdta.pro/images/75fd8ebbe398a031698ded24ac726ca9.jpg'),
(34542, 2359, 'Jamestown S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123460.mp4', 'http://timg.bdta.pro/images/7468369d169190463bead51bc028c801.jpg'),
(34543, 2359, 'Jamestown S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123461.mp4', 'http://timg.bdta.pro/images/7d38e55a091755282b8d7088952329bb.jpg'),
(34544, 2360, 'Mundo Mistério S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123431.mp4', 'http://timg.bdta.pro/images/e0a17c907c06a8f8eaf253aa578a790e.jpg'),
(34545, 2360, 'Mundo Mistério S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123432.mp4', 'http://timg.bdta.pro/images/0a463d194e1388f38ccab628bb69a2cd.jpg'),
(34546, 2360, 'Mundo Mistério S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123433.mp4', 'http://timg.bdta.pro/images/bcdadeadb1b0a04648b69dda8a18b8fe.jpg'),
(34547, 2360, 'Mundo Mistério S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123434.mp4', 'http://timg.bdta.pro/images/136408f6307c7616da12885796d4b81e.jpg'),
(34548, 2360, 'Mundo Mistério S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123435.mp4', 'http://timg.bdta.pro/images/90fb30c7be718c0e4361015bf3f64232.jpg'),
(34549, 2360, 'Mundo Mistério S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123436.mp4', 'http://timg.bdta.pro/images/e481b7bc54a3af4b6007d33439351128.jpg'),
(34550, 2360, 'Mundo Mistério S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123437.mp4', 'http://timg.bdta.pro/images/72cecabcd9212ee353ed02fbbb21a69a.jpg'),
(34551, 2360, 'Mundo Mistério S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123438.mp4', 'http://timg.bdta.pro/images/547631ca3c2c52486f8fe0e91ac36233.jpg'),
(34552, 2361, 'Muppets Now [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129038.mp4', 'http://timg.bdta.pro/images/56847ad4a49f3fbf3b447b28b95b1b6f.jpg'),
(34553, 2361, 'Muppets Now [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129039.mp4', 'http://timg.bdta.pro/images/1260011409c2cde83ceb7ff2bf10719c.jpg'),
(34554, 2361, 'Muppets Now [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129040.mp4', 'http://timg.bdta.pro/images/210c532365ac9335d695181943d8d712.jpg'),
(34555, 2361, 'Muppets Now [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129041.mp4', 'http://timg.bdta.pro/images/9b2c79d91996aafa6458e143b1cae74a.jpg'),
(34556, 2362, 'Ninguém Mandou S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123421.mp4', 'http://timg.bdta.pro/images/63c86a7c30a7022143b11182747a9c14.jpg'),
(34557, 2362, 'Ninguém Mandou S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123422.mp4', 'http://timg.bdta.pro/images/ba120e78b8b6cf73d4b4d7630737c6bb.jpg'),
(34558, 2362, 'Ninguém Mandou S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123423.mp4', 'http://timg.bdta.pro/images/76c1cfedc2325d57aaf3124a87362f9d.jpg'),
(34559, 2362, 'Ninguém Mandou S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123424.mp4', 'http://timg.bdta.pro/images/a8fd3cfc59d485577ca094bd6bb910c5.jpg'),
(34560, 2362, 'Ninguém Mandou S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123425.mp4', 'http://timg.bdta.pro/images/f91ec79bca5e089394dd37d7b4b251d5.jpg'),
(34561, 2362, 'Ninguém Mandou S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123426.mp4', 'http://timg.bdta.pro/images/9598bd226b407458ad2221ebddf15c02.jpg'),
(34562, 2362, 'Ninguém Mandou S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123427.mp4', 'http://timg.bdta.pro/images/873de441e8e23ca71999eea957c59b74.jpg'),
(34563, 2362, 'Ninguém Mandou S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123428.mp4', 'http://timg.bdta.pro/images/5b0a6ef1869e47c6ebcb58e93ede6d9e.jpg'),
(34564, 2362, 'Ninguém Mandou S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123429.mp4', 'http://timg.bdta.pro/images/024188a206bf6ddb247da977fbaa4144.jpg'),
(34565, 2362, 'Ninguém Mandou S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123430.mp4', 'http://timg.bdta.pro/images/f33d22aea45fefc16ae3c4a93c4e9ca3.jpg'),
(34566, 2363, 'Nomade 7 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123412.mp4', 'http://gstaticontent.com/images/z5m7he2YII5OEcTZUyJbkw8AuDG_big.jpg'),
(34567, 2363, 'Nomade 7 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123413.mp4', 'http://gstaticontent.com/images/z5m7he2YII5OEcTZUyJbkw8AuDG_big.jpg'),
(34568, 2363, 'Nomade 7 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123414.mp4', 'http://gstaticontent.com/images/z5m7he2YII5OEcTZUyJbkw8AuDG_big.jpg'),
(34569, 2363, 'Nomade 7 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123415.mp4', 'http://gstaticontent.com/images/z5m7he2YII5OEcTZUyJbkw8AuDG_big.jpg'),
(34570, 2363, 'Nomade 7 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123416.mp4', 'http://gstaticontent.com/images/z5m7he2YII5OEcTZUyJbkw8AuDG_big.jpg'),
(34571, 2363, 'Nomade 7 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123417.mp4', 'http://gstaticontent.com/images/z5m7he2YII5OEcTZUyJbkw8AuDG_big.jpg'),
(34572, 2363, 'Nomade 7 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123418.mp4', 'http://gstaticontent.com/images/z5m7he2YII5OEcTZUyJbkw8AuDG_big.jpg'),
(34573, 2363, 'Nomade 7 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123419.mp4', 'http://gstaticontent.com/images/z5m7he2YII5OEcTZUyJbkw8AuDG_big.jpg'),
(34574, 2363, 'Nomade 7 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123420.mp4', 'http://gstaticontent.com/images/z5m7he2YII5OEcTZUyJbkw8AuDG_big.jpg'),
(34575, 2364, 'Normal People S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123400.mp4', 'http://timg.bdta.pro/images/96239f7414cc178f6d22ccfe93230038.jpg'),
(34576, 2364, 'Normal People S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123401.mp4', 'http://timg.bdta.pro/images/0daa464f0b23a390cf93f3d3b8e26284.jpg'),
(34577, 2364, 'Normal People S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123402.mp4', 'http://timg.bdta.pro/images/e134f0169affc6cf0df39aa12d2959e6.jpg'),
(34578, 2364, 'Normal People S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123403.mp4', 'http://timg.bdta.pro/images/e649f047c369befb93a1563da906e691.jpg'),
(34579, 2364, 'Normal People S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123404.mp4', 'http://timg.bdta.pro/images/f70990adcbe56fb377ab6cb5951b0960.jpg'),
(34580, 2364, 'Normal People S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123405.mp4', 'http://timg.bdta.pro/images/a86c1fe0864a43a6f0bbc05d3be5aed4.jpg'),
(34581, 2364, 'Normal People S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123406.mp4', 'http://timg.bdta.pro/images/4ae5a46171bafd89715e386e743ca41b.jpg'),
(34582, 2364, 'Normal People S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123407.mp4', 'http://timg.bdta.pro/images/0f1519c59d40299144d98d3b98f9189a.jpg'),
(34583, 2364, 'Normal People S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123408.mp4', 'http://timg.bdta.pro/images/df25d8f8c3af91c442fa3a35b16597b0.jpg'),
(34584, 2364, 'Normal People S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123409.mp4', 'http://timg.bdta.pro/images/911f1262518d62d0862cd0394053f495.jpg'),
(34585, 2364, 'Normal People S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/123410.mp4', 'http://timg.bdta.pro/images/ef20405987b0dbc6e92075144a01c75b.jpg'),
(34586, 2364, 'Normal People S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/123411.mp4', 'http://timg.bdta.pro/images/a0d97a696ce41c38e899e4a551166848.jpg'),
(34587, 2365, 'Norsemen [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123382.mp4', 'http://timg.bdta.pro/images/97a15d1b75838cb2c7e147fb22834e6f.jpg'),
(34588, 2365, 'Norsemen [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123383.mp4', 'http://timg.bdta.pro/images/796bb07040f3d9f3cb33135153a31656.jpg'),
(34589, 2365, 'Norsemen [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123384.mp4', 'http://timg.bdta.pro/images/1b6da7a5bfc3a63e29f49babaed9c0b5.jpg'),
(34590, 2365, 'Norsemen [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123385.mp4', 'http://timg.bdta.pro/images/cf852d0d626fb545fe44179aa86e24b8.jpg'),
(34591, 2365, 'Norsemen [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123386.mp4', 'http://timg.bdta.pro/images/558839164bf470d67864106aa74a9788.jpg'),
(34592, 2365, 'Norsemen [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123387.mp4', 'http://timg.bdta.pro/images/bb1c42449f388187f8e9a7213fe640b9.jpg'),
(34593, 2366, 'Norsemen [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123388.mp4', 'http://timg.bdta.pro/images/f56c71e2b92e901bbf7c9a6b55bb0ab7.jpg'),
(34594, 2366, 'Norsemen [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123389.mp4', 'http://timg.bdta.pro/images/91ce48c77eb2f84db9cff29164ea3eb4.jpg'),
(34595, 2366, 'Norsemen [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123390.mp4', 'http://timg.bdta.pro/images/7547892652895431e55273dfc697374e.jpg'),
(34596, 2366, 'Norsemen [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123391.mp4', 'http://timg.bdta.pro/images/13bf1709ec9dae4ab695fba14788871b.jpg'),
(34597, 2366, 'Norsemen [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123392.mp4', 'http://timg.bdta.pro/images/98ed098113f961eaa3ec4d62684984bf.jpg'),
(34598, 2366, 'Norsemen [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123393.mp4', 'http://timg.bdta.pro/images/e33d4e50d8ce371b25d913af112955e8.jpg'),
(34599, 2367, 'Norsemen [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123394.mp4', 'http://timg.bdta.pro/images/6dfac713e49f19404fcf223e700fc4f4.jpg'),
(34600, 2367, 'Norsemen [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123395.mp4', 'http://timg.bdta.pro/images/0749adf05dc239dcc9e279bead08cc57.jpg'),
(34601, 2367, 'Norsemen [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123396.mp4', 'http://timg.bdta.pro/images/16ba5e2ee2df1108def6219425f623ee.jpg'),
(34602, 2367, 'Norsemen [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123397.mp4', 'http://timg.bdta.pro/images/40dc02f00d6d53116e3358901c7890e2.jpg'),
(34603, 2367, 'Norsemen [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123398.mp4', 'http://timg.bdta.pro/images/1cca3cfdf19e7a1da6464fcc22ff6adb.jpg'),
(34604, 2367, 'Norsemen [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123399.mp4', 'http://timg.bdta.pro/images/a3b968c606c38b9c36dd0632919516f3.jpg'),
(34605, 2368, 'Nova York Contra a Máfia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123379.mp4', 'http://timg.bdta.pro/images/69a398adda89ce5a960f44de535dddc8.jpg'),
(34606, 2368, 'Nova York Contra a Máfia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123380.mp4', 'http://timg.bdta.pro/images/69b1126108c7b20606be0d8aa7ca65c7.jpg'),
(34607, 2368, 'Nova York Contra a Máfia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123381.mp4', 'http://timg.bdta.pro/images/7ae4ed7cd4b09eab31f928a09d26d0b6.jpg'),
(34608, 2369, 'Os Mais Procurados do Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123374.mp4', 'http://gstaticontent.com/images/dDaIGQvHHP4xixwqwhgwn8WMZx_big.jpg'),
(34609, 2369, 'Os Mais Procurados do Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123375.mp4', 'http://gstaticontent.com/images/dDaIGQvHHP4xixwqwhgwn8WMZx_big.jpg'),
(34610, 2369, 'Os Mais Procurados do Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123376.mp4', 'http://gstaticontent.com/images/dDaIGQvHHP4xixwqwhgwn8WMZx_big.jpg'),
(34611, 2369, 'Os Mais Procurados do Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123377.mp4', 'http://gstaticontent.com/images/dDaIGQvHHP4xixwqwhgwn8WMZx_big.jpg'),
(34612, 2369, 'Os Mais Procurados do Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123378.mp4', 'http://gstaticontent.com/images/dDaIGQvHHP4xixwqwhgwn8WMZx_big.jpg'),
(34613, 2370, 'P Valley S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194555.mp4', 'http://timg.bdta.pro/images/62ba23be3dc3b0e10bc285d3c3417ccd.jpg'),
(34614, 2370, 'P Valley S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194556.mp4', 'http://timg.bdta.pro/images/9c6a6725c4e148cee4bf8076a172effe.jpg'),
(34615, 2370, 'P Valley S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194557.mp4', 'http://timg.bdta.pro/images/40f7eb7e9ed5fe9bb5a70d8d0e244d9c.jpg'),
(34616, 2370, 'P Valley S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194558.mp4', 'http://timg.bdta.pro/images/07e93437d27a1d8d399f476bba8dc442.jpg'),
(34617, 2370, 'P Valley S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194559.mp4', 'http://timg.bdta.pro/images/289adfa076f66b19af1d860912cdeec5.jpg'),
(34618, 2370, 'P Valley S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194560.mp4', 'http://timg.bdta.pro/images/9d6cc22973a2bdba71321f17604439b5.jpg'),
(34619, 2370, 'P Valley S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194561.mp4', 'http://timg.bdta.pro/images/8dedb834b2095211854cbb352688204e.jpg'),
(34620, 2370, 'P Valley S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194562.mp4', 'http://gstaticontent.com/images/3ccce7a36eb250fcb3f596cc20bd870f.jpg'),
(34621, 2371, 'P Valley S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194563.mp4', 'http://timg.bdta.pro/images/21a277b78b10cc4689c8ee4b4154ad60.jpg'),
(34622, 2371, 'P Valley S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194564.mp4', 'http://timg.bdta.pro/images/b74ef55d0a9a917826a818da23095ee8.jpg'),
(34623, 2371, 'P Valley S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194565.mp4', 'http://timg.bdta.pro/images/40e93f41ca10dd261dc199a878521f67.jpg'),
(34624, 2371, 'P Valley S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194566.mp4', 'http://timg.bdta.pro/images/4be5ed0717735892f47556a58216a482.jpg'),
(34625, 2371, 'P Valley S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194567.mp4', 'http://timg.bdta.pro/images/53aa869cd8875a893b31c40ed9b353c1.jpg'),
(34626, 2371, 'P Valley S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194568.mp4', 'http://timg.bdta.pro/images/a5dcd021c4393830200166f28d00bea2.jpg'),
(34627, 2371, 'P Valley S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194569.mp4', 'http://timg.bdta.pro/images/9ea0b4206d7ea53b0ee37d3c1417b427.jpg'),
(34628, 2371, 'P Valley S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194570.mp4', 'http://timg.bdta.pro/images/35eae71ad277f9e5c437c0b851aec5ca.jpg'),
(34629, 2371, 'P Valley S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194571.mp4', 'http://timg.bdta.pro/images/ef4448fcdc8f6beaddc2e021b052ebc9.jpg'),
(34630, 2371, 'P Valley S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194572.mp4', 'http://timg.bdta.pro/images/3c5d9db1cdfda7d406040a4ce74795b9.jpg'),
(34631, 2372, 'Por Dentro das Prisoes Mais Severas do Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236632.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34632, 2372, 'Por Dentro das Prisoes Mais Severas do Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236633.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34633, 2372, 'Por Dentro das Prisoes Mais Severas do Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236634.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34634, 2372, 'Por Dentro das Prisoes Mais Severas do Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236635.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34635, 2373, 'Por Dentro das Prisoes Mais Severas do Mundo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236636.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34636, 2373, 'Por Dentro das Prisoes Mais Severas do Mundo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236637.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34637, 2373, 'Por Dentro das Prisoes Mais Severas do Mundo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236638.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34638, 2373, 'Por Dentro das Prisoes Mais Severas do Mundo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236639.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34639, 2374, 'Por Dentro das Prisoes Mais Severas do Mundo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236640.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34640, 2374, 'Por Dentro das Prisoes Mais Severas do Mundo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236641.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34641, 2374, 'Por Dentro das Prisoes Mais Severas do Mundo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236642.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34642, 2374, 'Por Dentro das Prisoes Mais Severas do Mundo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236643.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34643, 2375, 'Por Dentro das Prisoes Mais Severas do Mundo S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236644.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34644, 2375, 'Por Dentro das Prisoes Mais Severas do Mundo S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236645.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34645, 2375, 'Por Dentro das Prisoes Mais Severas do Mundo S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236646.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34646, 2375, 'Por Dentro das Prisoes Mais Severas do Mundo S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236647.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34647, 2376, 'Por Dentro das Prisoes Mais Severas do Mundo S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236648.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34648, 2376, 'Por Dentro das Prisoes Mais Severas do Mundo S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236649.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34649, 2376, 'Por Dentro das Prisoes Mais Severas do Mundo S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236650.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34650, 2377, 'Por Dentro das Prisoes Mais Severas do Mundo S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236651.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34651, 2377, 'Por Dentro das Prisoes Mais Severas do Mundo S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236652.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34652, 2377, 'Por Dentro das Prisoes Mais Severas do Mundo S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236653.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34653, 2377, 'Por Dentro das Prisoes Mais Severas do Mundo S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236654.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34654, 2378, 'Por Dentro das Prisoes Mais Severas do Mundo S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236655.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34655, 2378, 'Por Dentro das Prisoes Mais Severas do Mundo S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236656.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34656, 2378, 'Por Dentro das Prisoes Mais Severas do Mundo S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236657.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34657, 2378, 'Por Dentro das Prisoes Mais Severas do Mundo S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236658.mp4', 'http://gstaticontent.com/images/cc8cefd1823b28bcea2e6d861e26b18d.jpg'),
(34658, 2379, 'Case S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228687.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34659, 2379, 'Case S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228688.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34660, 2379, 'Case S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228689.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34661, 2379, 'Case S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228690.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34662, 2379, 'Case S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228691.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34663, 2379, 'Case S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228692.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34664, 2379, 'Case S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228693.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34665, 2379, 'Case S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228694.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34666, 2379, 'Case S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228695.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34667, 2379, 'Case S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228696.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34668, 2379, 'Case S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228697.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34669, 2379, 'Case S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228698.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34670, 2379, 'Case S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228699.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34671, 2379, 'Case S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228700.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34672, 2379, 'Case S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228701.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34673, 2379, 'Case S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/228702.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34674, 2379, 'Case S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/228703.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34675, 2379, 'Case S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/228704.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34676, 2379, 'Case S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/228705.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34677, 2379, 'Case S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/228706.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34678, 2380, 'Case S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228707.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34679, 2380, 'Case S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228708.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34680, 2380, 'Case S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228709.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34681, 2380, 'Case S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228710.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34682, 2380, 'Case S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228711.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34683, 2380, 'Case S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228712.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34684, 2380, 'Case S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228713.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34685, 2380, 'Case S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228714.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34686, 2380, 'Case S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228715.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34687, 2380, 'Case S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228716.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34688, 2380, 'Case S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228717.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34689, 2380, 'Case S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228718.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34690, 2380, 'Case S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228719.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34691, 2380, 'Case S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228720.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34692, 2380, 'Case S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228721.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34693, 2380, 'Case S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/228722.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34694, 2380, 'Case S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/228723.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34695, 2380, 'Case S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/228724.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34696, 2380, 'Case S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/228725.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34697, 2380, 'Case S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/228726.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34698, 2381, 'Case S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228727.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34699, 2381, 'Case S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228728.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34700, 2381, 'Case S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228729.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34701, 2381, 'Case S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228730.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34702, 2381, 'Case S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228731.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34703, 2381, 'Case S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228732.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34704, 2381, 'Case S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228733.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34705, 2381, 'Case S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228734.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34706, 2381, 'Case S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228735.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34707, 2381, 'Case S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228736.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34708, 2381, 'Case S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228737.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34709, 2381, 'Case S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228738.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34710, 2381, 'Case S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228739.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34711, 2381, 'Case S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228740.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34712, 2381, 'Case S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228741.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34713, 2381, 'Case S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/228742.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34714, 2381, 'Case S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/228743.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34715, 2381, 'Case S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/228744.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34716, 2381, 'Case S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/228745.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34717, 2381, 'Case S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/228746.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34718, 2382, 'Case S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228747.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34719, 2382, 'Case S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228748.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34720, 2382, 'Case S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228749.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34721, 2382, 'Case S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228750.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34722, 2382, 'Case S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228751.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34723, 2382, 'Case S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228752.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34724, 2382, 'Case S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228753.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34725, 2382, 'Case S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228754.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34726, 2382, 'Case S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228755.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34727, 2382, 'Case S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228756.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34728, 2382, 'Case S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228757.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34729, 2382, 'Case S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228758.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34730, 2382, 'Case S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228759.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34731, 2382, 'Case S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228760.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34732, 2382, 'Case S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228761.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34733, 2382, 'Case S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/228762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9LNp4wA2DzZhdYUbTan3shbC8j8.jpg'),
(34734, 2382, 'Case S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/228763.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34735, 2382, 'Case S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/228764.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34736, 2382, 'Case S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/228765.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34737, 2382, 'Case S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/228766.mp4', 'http://gstaticontent.com/images/9hrx5UZCe5IQGo6wVUgfawqcK1s_big.jpg'),
(34738, 2383, 'Sherwood [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123161.mp4', 'http://timg.bdta.pro/images/4e2f95dd3c9dcc5974cd222c2a661fdd.jpg'),
(34739, 2383, 'Sherwood [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123162.mp4', 'http://timg.bdta.pro/images/523edcc3a2f811eb7c21d26fe3e8b83b.jpg'),
(34740, 2383, 'Sherwood [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123163.mp4', 'http://timg.bdta.pro/images/c963adb28cfd1192c66bdbdb89607da2.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(34741, 2383, 'Sherwood [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123164.mp4', 'http://timg.bdta.pro/images/46b1204cb151fbbb59b7bb2d3eab95b9.jpg'),
(34742, 2383, 'Sherwood [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123165.mp4', 'http://timg.bdta.pro/images/8f714dd956fd2c2d989cf423d37ead32.jpg'),
(34743, 2383, 'Sherwood [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123166.mp4', 'http://timg.bdta.pro/images/c0695e2d8faa344e18ef860dde514304.jpg'),
(34744, 2383, 'Sherwood [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123167.mp4', 'http://timg.bdta.pro/images/b24b051b950d4fdeced49d6c84838022.jpg'),
(34745, 2383, 'Sherwood [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123168.mp4', 'http://timg.bdta.pro/images/4b6eb7938241dd646f6b13ef8574b87b.jpg'),
(34746, 2383, 'Sherwood [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123169.mp4', 'http://timg.bdta.pro/images/d96211d9fa2d12d9d86dc153e6dc8677.jpg'),
(34747, 2383, 'Sherwood [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123170.mp4', 'http://timg.bdta.pro/images/845529cdbe9a4a5e3f4b3f476fb5c0d4.jpg'),
(34748, 2384, 'Nas Montanhas da Coruja S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128119.mp4', 'http://timg.bdta.pro/images/14530871a94a567b6d6ae5bce0ebb05b.jpg'),
(34749, 2384, 'Nas Montanhas da Coruja S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128120.mp4', 'http://timg.bdta.pro/images/e9bf3b683e3499213fd2d09a05a7a720.jpg'),
(34750, 2384, 'Nas Montanhas da Coruja S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128121.mp4', 'http://timg.bdta.pro/images/6139aa712c916b9aefb1f3e482ffe5ac.jpg'),
(34751, 2384, 'Nas Montanhas da Coruja S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128122.mp4', 'http://timg.bdta.pro/images/99e2de2785f7c26dd5e0ceba4c9d3683.jpg'),
(34752, 2384, 'Nas Montanhas da Coruja S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128123.mp4', 'http://timg.bdta.pro/images/d2f39f5d87c7eb5db9564f21680aee7c.jpg'),
(34753, 2384, 'Nas Montanhas da Coruja S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128124.mp4', 'http://timg.bdta.pro/images/39f5684085bc41ce621617cb41dbed4e.jpg'),
(34754, 2384, 'Nas Montanhas da Coruja S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128125.mp4', 'http://timg.bdta.pro/images/aad987ffa987f8c11f25f278ac3d0da1.jpg'),
(34755, 2384, 'Nas Montanhas da Coruja S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128126.mp4', 'http://timg.bdta.pro/images/20bcf46f55ccbf9a025d9a88995c99a8.jpg'),
(34756, 2385, 'Nas Montanhas da Coruja S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128127.mp4', 'http://timg.bdta.pro/images/38fa76a43c5aed9b0418cf52a03a97dd.jpg'),
(34757, 2385, 'Nas Montanhas da Coruja S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128128.mp4', 'http://timg.bdta.pro/images/5e33dd18ce03eefa26d3aac3287cdac9.jpg'),
(34758, 2385, 'Nas Montanhas da Coruja S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128129.mp4', 'http://timg.bdta.pro/images/d4ddf169caed6229ed5ac5500ff34f61.jpg'),
(34759, 2385, 'Nas Montanhas da Coruja S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128130.mp4', 'http://gstaticontent.com/images/wSpt2zsUh2mDrzhIiZzKW4v31Cj_big.jpg'),
(34760, 2385, 'Nas Montanhas da Coruja S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128131.mp4', 'http://gstaticontent.com/images/wSpt2zsUh2mDrzhIiZzKW4v31Cj_big.jpg'),
(34761, 2385, 'Nas Montanhas da Coruja S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128132.mp4', 'http://gstaticontent.com/images/wSpt2zsUh2mDrzhIiZzKW4v31Cj_big.jpg'),
(34762, 2385, 'Nas Montanhas da Coruja S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128133.mp4', 'http://gstaticontent.com/images/wSpt2zsUh2mDrzhIiZzKW4v31Cj_big.jpg'),
(34763, 2385, 'Nas Montanhas da Coruja S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128134.mp4', 'http://gstaticontent.com/images/wSpt2zsUh2mDrzhIiZzKW4v31Cj_big.jpg'),
(34764, 2386, 'The Great S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237062.mp4', 'http://timg.bdta.pro/images/6401e94b46b4008f07c4fe395343d824.jpg'),
(34765, 2386, 'The Great S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237063.mp4', 'http://timg.bdta.pro/images/7af9a9ea1e22cbf3e24b39a22180234b.jpg'),
(34766, 2386, 'The Great S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237064.mp4', 'http://timg.bdta.pro/images/d626a9c7fa7341621e6d056be7988b64.jpg'),
(34767, 2386, 'The Great S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237065.mp4', 'http://timg.bdta.pro/images/b20397669634ffb7b4af8f5c53e25a1c.jpg'),
(34768, 2386, 'The Great S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237066.mp4', 'http://timg.bdta.pro/images/e683dbd45c669a649761ecb3d0b9f400.jpg'),
(34769, 2386, 'The Great S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237067.mp4', 'http://timg.bdta.pro/images/ceda820369a46922aece44c8d830b11c.jpg'),
(34770, 2386, 'The Great S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237068.mp4', 'http://timg.bdta.pro/images/f185724056bafbf191054abb3e59f943.jpg'),
(34771, 2386, 'The Great S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237069.mp4', 'http://timg.bdta.pro/images/0ab65b354ac58ca4e1f6ccd0c339264d.jpg'),
(34772, 2386, 'The Great S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237070.mp4', 'http://timg.bdta.pro/images/d793751a9ef5785dd7cf4780ed8e56f2.jpg'),
(34773, 2386, 'The Great S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237071.mp4', 'http://timg.bdta.pro/images/0af8eef3280f4802a1c2c7be89181a25.jpg'),
(34774, 2387, 'The Great S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FeNgeXmvTk8aNcuswzJ45lUAT1.jpg'),
(34775, 2387, 'The Great S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7QMMitXOXlrnB328rnXpPGjRFmd.jpg'),
(34776, 2387, 'The Great S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237074.mp4', 'http://timg.bdta.pro/images/ac7a51d76c2e2bb00310cc6425900424.jpg'),
(34777, 2387, 'The Great S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237075.mp4', 'http://timg.bdta.pro/images/2fe16ea46d0167c2f6830b86f469717a.jpg'),
(34778, 2387, 'The Great S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237076.mp4', 'http://timg.bdta.pro/images/f6373daf6bfb930e476ed34c1077676d.jpg'),
(34779, 2387, 'The Great S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237077.mp4', 'http://timg.bdta.pro/images/1b78433aa3f58b1892fdc39caa1a3af4.jpg'),
(34780, 2387, 'The Great S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237078.mp4', 'http://timg.bdta.pro/images/41fad966adfd46b424d4ddd401cf60e3.jpg'),
(34781, 2387, 'The Great S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237079.mp4', 'http://timg.bdta.pro/images/b8f6224d6f781f842c695a8010e42338.jpg'),
(34782, 2387, 'The Great S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237080.mp4', 'http://timg.bdta.pro/images/a9a2c1362c0ce4c27cd609d9d37eeb95.jpg'),
(34783, 2387, 'The Great S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237081.mp4', 'http://timg.bdta.pro/images/3c6711c32211f1e0ac30cb8f13a4d990.jpg'),
(34784, 2388, 'The Great S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237082.mp4', 'http://image.tmdb.org/t/p/w1280/gvqPTU2BxN9fmWg1hZNF6XgtsvX.jpg'),
(34785, 2388, 'The Great S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237083.mp4', 'http://image.tmdb.org/t/p/w1280/dUa5VYRhTBJGGpBwdDOnu2dkwoj.jpg'),
(34786, 2388, 'The Great S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237084.mp4', 'http://image.tmdb.org/t/p/w1280/szbpVtq1XiVJk9AcvwAgKmvgAWH.jpg'),
(34787, 2388, 'The Great S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237085.mp4', 'http://image.tmdb.org/t/p/w1280/eEgN3PunwOY4KwXnISnh1LULJCP.jpg'),
(34788, 2388, 'The Great S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237086.mp4', 'http://image.tmdb.org/t/p/w1280/fjY6DVaqcjhtuZxQosAjky1RlWS.jpg'),
(34789, 2388, 'The Great S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237087.mp4', 'http://image.tmdb.org/t/p/w1280/s4KLpYpQO793fSgG4V0Rb3M4U7y.jpg'),
(34790, 2388, 'The Great S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237088.mp4', 'http://image.tmdb.org/t/p/w1280/wtd6GJpnGAMGJjojtNCGx4kWO3L.jpg'),
(34791, 2388, 'The Great S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237089.mp4', 'http://image.tmdb.org/t/p/w1280/rHfsdvyszMBvVenj1Bt8mLqFi1Q.jpg'),
(34792, 2388, 'The Great S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237090.mp4', 'http://gstaticontent.com/images/85oRnKwJIicUlLNFhYlY3nmEimX_big.jpg'),
(34793, 2388, 'The Great S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237091.mp4', 'http://gstaticontent.com/images/85oRnKwJIicUlLNFhYlY3nmEimX_big.jpg'),
(34794, 2389, 'The White Queen S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123151.mp4', 'http://timg.bdta.pro/images/8eba99688d226e6d4c56ef005e59f31f.jpg'),
(34795, 2389, 'The White Queen S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ow5Ze7XsTrakQGX2TnTYCRh5yr.jpg'),
(34796, 2389, 'The White Queen S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123153.mp4', 'http://timg.bdta.pro/images/f3038bf89892e525528ed7bff02158ee.jpg'),
(34797, 2389, 'The White Queen S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123154.mp4', 'http://timg.bdta.pro/images/238d7211ae9c81ac1fae1d4231793543.jpg'),
(34798, 2389, 'The White Queen S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123155.mp4', 'http://timg.bdta.pro/images/616e3e3d124521fe0a37e1914da4e4ba.jpg'),
(34799, 2389, 'The White Queen S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123156.mp4', 'http://timg.bdta.pro/images/77f67973ee23cdd0ae021219212bfd9e.jpg'),
(34800, 2389, 'The White Queen S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123157.mp4', 'http://timg.bdta.pro/images/6dd2462e05395ad5c86c11a0e0417116.jpg'),
(34801, 2389, 'The White Queen S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123158.mp4', 'http://timg.bdta.pro/images/8f5b8b668f001f33df8434faaccc664e.jpg'),
(34802, 2389, 'The White Queen S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123159.mp4', 'http://timg.bdta.pro/images/c9d6423ce9ceda04a72241918bfa32d3.jpg'),
(34803, 2389, 'The White Queen S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123160.mp4', 'http://timg.bdta.pro/images/4265f7741e5e9117c3739c409b19f772.jpg'),
(34804, 2390, 'A Arte do Crime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130505.mp4', 'http://timg.bdta.pro/images/438ed9491953c04fa828a003de58ceae.jpg'),
(34805, 2390, 'A Arte do Crime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130506.mp4', 'http://timg.bdta.pro/images/c9fa833a6907d68aefd6f18952ab71fe.jpg'),
(34806, 2390, 'A Arte do Crime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130507.mp4', 'http://timg.bdta.pro/images/dd9b4a958e15e4ab9d65e340f52d395f.jpg'),
(34807, 2390, 'A Arte do Crime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130508.mp4', 'http://timg.bdta.pro/images/c454748a6f1e2b150dcfd2232ed2904d.jpg'),
(34808, 2390, 'A Arte do Crime S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130509.mp4', 'http://timg.bdta.pro/images/7f63e7070188ad30ef740d5958a939fc.jpg'),
(34809, 2390, 'A Arte do Crime S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130510.mp4', 'http://timg.bdta.pro/images/8aefce3b8d164b8e845061a1fbfbd03c.jpg'),
(34810, 2390, 'A Arte do Crime S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130511.mp4', 'http://timg.bdta.pro/images/2bc8a53010107314a282674c699e2799.jpg'),
(34811, 2390, 'A Arte do Crime S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130512.mp4', 'http://timg.bdta.pro/images/f1d87165b52c83f397e5fe339d782dc4.jpg'),
(34812, 2390, 'A Arte do Crime S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130513.mp4', 'http://timg.bdta.pro/images/91b5a219ee6b895ea4d745652f2ef888.jpg'),
(34813, 2390, 'A Arte do Crime S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130514.mp4', 'http://timg.bdta.pro/images/fb7361be7c94bf7cff242724c5bae5e2.jpg'),
(34814, 2391, 'A Indústria da Cura S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130515.mp4', 'http://timg.bdta.pro/images/9e7827dd56c9819652629716f7d367bb.jpg'),
(34815, 2391, 'A Indústria da Cura S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130516.mp4', 'http://timg.bdta.pro/images/940dd8778144bcdaeb8fdc2f7cf669a3.jpg'),
(34816, 2391, 'A Indústria da Cura S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130517.mp4', 'http://timg.bdta.pro/images/2de54c308a09875a9dcdb04a73283d96.jpg'),
(34817, 2391, 'A Indústria da Cura S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130518.mp4', 'http://timg.bdta.pro/images/5024e6c800b5858f920065db7d344c1f.jpg'),
(34818, 2391, 'A Indústria da Cura S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130519.mp4', 'http://timg.bdta.pro/images/0a81d9c74e33328021483969c198cb58.jpg'),
(34819, 2391, 'A Indústria da Cura S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130520.mp4', 'http://timg.bdta.pro/images/90a85da3418d1652b14eb73e70ee9376.jpg'),
(34820, 2392, 'A Morte do Patriarca [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130521.mp4', 'http://timg.bdta.pro/images/8433c653d6211621261edbb609327905.jpg'),
(34821, 2392, 'A Morte do Patriarca [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130522.mp4', 'http://timg.bdta.pro/images/304fb1661af3ce158dd5cfb22e6877e7.jpg'),
(34822, 2392, 'A Morte do Patriarca [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130523.mp4', 'http://timg.bdta.pro/images/56308d849c9650568c20cd3b2bded525.jpg'),
(34823, 2392, 'A Morte do Patriarca [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130524.mp4', 'http://timg.bdta.pro/images/40aa5b53daf5fc706c6086c17bf4260e.jpg'),
(34824, 2392, 'A Morte do Patriarca [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130525.mp4', 'http://timg.bdta.pro/images/7252d01dd348d7b09a04307071043c2e.jpg'),
(34825, 2392, 'A Morte do Patriarca [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130526.mp4', 'http://timg.bdta.pro/images/b744a0741be25a0a9840f6d079857b09.jpg'),
(34826, 2392, 'A Morte do Patriarca [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130527.mp4', 'http://timg.bdta.pro/images/6c859736822c3ac679d13d1624097688.jpg'),
(34827, 2392, 'A Morte do Patriarca [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130528.mp4', 'http://timg.bdta.pro/images/c1934fbe0b2b31ecb1b6e2c4d409642a.jpg'),
(34828, 2393, 'Barbie Dreamhouse Adventures S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/122792.mp4', 'http://timg.bdta.pro/images/1ae4067f84ff75cb50503e6bbf4fb393.jpg'),
(34829, 2393, 'Barbie Dreamhouse Adventures S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/122793.mp4', 'http://timg.bdta.pro/images/f250b27c033d1858695047695e92c18d.jpg'),
(34830, 2393, 'Barbie Dreamhouse Adventures S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/122794.mp4', 'http://timg.bdta.pro/images/3e5f81a33de71b61f409d5103a6e1482.jpg'),
(34831, 2393, 'Barbie Dreamhouse Adventures S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/122795.mp4', 'http://timg.bdta.pro/images/f8af8a2ace2a6551e61782b0d1b90080.jpg'),
(34832, 2393, 'Barbie Dreamhouse Adventures S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/122796.mp4', 'http://timg.bdta.pro/images/faa08f89dee7a3683880c005402b0d0f.jpg'),
(34833, 2393, 'Barbie Dreamhouse Adventures S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/122797.mp4', 'http://timg.bdta.pro/images/93e9a5014e10286b5e0a80c80fcba19d.jpg'),
(34834, 2393, 'Barbie Dreamhouse Adventures S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/122798.mp4', 'http://timg.bdta.pro/images/ebc7debd88abaa5428bd52578f7f642f.jpg'),
(34835, 2393, 'Barbie Dreamhouse Adventures S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/122799.mp4', 'http://timg.bdta.pro/images/b698377ebb04b127772656af67b823d7.jpg'),
(34836, 2394, 'Barbie Dreamhouse Adventures S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/122800.mp4', 'http://timg.bdta.pro/images/a2339ec878f03404a1103fee03655193.jpg'),
(34837, 2394, 'Barbie Dreamhouse Adventures S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/122801.mp4', 'http://timg.bdta.pro/images/823a6343691a995c5a5102cce5988b76.jpg'),
(34838, 2394, 'Barbie Dreamhouse Adventures S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/122802.mp4', 'http://timg.bdta.pro/images/380f73c4beab93057c265c1b93a8cb66.jpg'),
(34839, 2394, 'Barbie Dreamhouse Adventures S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/122803.mp4', 'http://timg.bdta.pro/images/f003b7a4e851fa821a3e93cfba62f78c.jpg'),
(34840, 2394, 'Barbie Dreamhouse Adventures S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/122804.mp4', 'http://timg.bdta.pro/images/cdb6eaf44bf82554c639b9d5aea0bcec.jpg'),
(34841, 2394, 'Barbie Dreamhouse Adventures S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/122805.mp4', 'http://timg.bdta.pro/images/b4ab0f8b9f157c48ec83e9ab0deb16d7.jpg'),
(34842, 2394, 'Barbie Dreamhouse Adventures S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/122806.mp4', 'http://timg.bdta.pro/images/9206ef15fb7ee56f14577512bbd2e05f.jpg'),
(34843, 2394, 'Barbie Dreamhouse Adventures S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/122807.mp4', 'http://timg.bdta.pro/images/d4fc0ccfbb01ead1bb5375e65503b23c.jpg'),
(34844, 2394, 'Barbie Dreamhouse Adventures S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/122808.mp4', 'http://timg.bdta.pro/images/9a953a858ccfa83651781223e3ed289f.jpg'),
(34845, 2395, 'Barbie Dreamhouse Adventures S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/122809.mp4', 'http://timg.bdta.pro/images/97aa35df9992b1ee46af540ee5b0cef9.jpg'),
(34846, 2395, 'Barbie Dreamhouse Adventures S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/122810.mp4', 'http://timg.bdta.pro/images/2158444d7d7fb4517ca8f11e6b140452.jpg'),
(34847, 2395, 'Barbie Dreamhouse Adventures S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/122811.mp4', 'http://timg.bdta.pro/images/4e9f4fe87eec18582e758a90ed08116d.jpg'),
(34848, 2395, 'Barbie Dreamhouse Adventures S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/122812.mp4', 'http://timg.bdta.pro/images/4f6351ed1c56636622413d586aceb564.jpg'),
(34849, 2395, 'Barbie Dreamhouse Adventures S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/122813.mp4', 'http://timg.bdta.pro/images/825b2081199b56c4d7df7cb238f4ea8b.jpg'),
(34850, 2395, 'Barbie Dreamhouse Adventures S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/122814.mp4', 'http://timg.bdta.pro/images/babe7f01aea66049dcee531fa7bc8950.jpg'),
(34851, 2395, 'Barbie Dreamhouse Adventures S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/122815.mp4', 'http://timg.bdta.pro/images/96d8488149272d2a1975e0456ce0cb53.jpg'),
(34852, 2395, 'Barbie Dreamhouse Adventures S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/122816.mp4', 'http://timg.bdta.pro/images/5f9b2d30af8cab19fc3911de4a7813de.jpg'),
(34853, 2395, 'Barbie Dreamhouse Adventures S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/122817.mp4', 'http://timg.bdta.pro/images/3949278ac8ba41b07f5cabf1d2ffdd90.jpg'),
(34854, 2396, 'Big Dogs [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/122818.mp4', 'http://timg.bdta.pro/images/fbc9f3ca25e62485ba11e7f514654c6b.jpg'),
(34855, 2396, 'Big Dogs [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/122819.mp4', 'http://timg.bdta.pro/images/c4473ef327a52e8c5a31ef38573e6ca4.jpg'),
(34856, 2396, 'Big Dogs [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/122820.mp4', 'http://timg.bdta.pro/images/a6acbbc1448aae695f8d4d657266ae43.jpg'),
(34857, 2396, 'Big Dogs [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/122821.mp4', 'http://timg.bdta.pro/images/4f496e3113d98a185633082274e75169.jpg'),
(34858, 2396, 'Big Dogs [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/122822.mp4', 'http://timg.bdta.pro/images/6d25a491f2942a5a6152a3d1a4df4581.jpg'),
(34859, 2396, 'Big Dogs [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/122823.mp4', 'http://timg.bdta.pro/images/22f1e4914c4d693425086f507a105e4a.jpg'),
(34860, 2396, 'Big Dogs [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/122824.mp4', 'http://timg.bdta.pro/images/7a87990c68d5c5dc2004ff7cd6b282e3.jpg'),
(34861, 2396, 'Big Dogs [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/122825.mp4', 'http://timg.bdta.pro/images/1cdb2a1e70bdc14a1a57ef62c1b5564a.jpg'),
(34862, 2397, 'Caçadoras de Recompensas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/122826.mp4', 'http://timg.bdta.pro/images/6cd54511a0fb2852762f99ef13ff65a8.jpg'),
(34863, 2397, 'Caçadoras de Recompensas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/122827.mp4', 'http://timg.bdta.pro/images/a9d7a85f595a76b1d044fe064acc8fca.jpg'),
(34864, 2397, 'Caçadoras de Recompensas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/122828.mp4', 'http://timg.bdta.pro/images/972049e1deae60a644e792e906defcea.jpg'),
(34865, 2397, 'Caçadoras de Recompensas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/122829.mp4', 'http://timg.bdta.pro/images/8024445b788dce56b5d25ab4566add13.jpg'),
(34866, 2397, 'Caçadoras de Recompensas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/122830.mp4', 'http://timg.bdta.pro/images/25711a8ff632fc379d33dbeffc557784.jpg'),
(34867, 2397, 'Caçadoras de Recompensas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/122831.mp4', 'http://timg.bdta.pro/images/d2b6fec5935fb920491d17aa0653367a.jpg'),
(34868, 2397, 'Caçadoras de Recompensas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/122832.mp4', 'http://timg.bdta.pro/images/7a12444e92fe12dbcb3e11a15a856b0f.jpg'),
(34869, 2397, 'Caçadoras de Recompensas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/122833.mp4', 'http://timg.bdta.pro/images/d21e6019c436d10e29bde420c5a7a69b.jpg'),
(34870, 2397, 'Caçadoras de Recompensas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/122834.mp4', 'http://timg.bdta.pro/images/2c0bfb89426a9e983b71eeef6113cf26.jpg'),
(34871, 2397, 'Caçadoras de Recompensas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/122835.mp4', 'http://timg.bdta.pro/images/5a7962c3b19b8a3d171d41803af6d813.jpg'),
(34872, 2398, 'Caçadores de Bugs S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/122836.mp4', 'http://timg.bdta.pro/images/2898829c7325bf4addebc5c4067f4f8b.jpg'),
(34873, 2398, 'Caçadores de Bugs S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/122837.mp4', 'http://timg.bdta.pro/images/25bcd5c9877f9187e36bbf92483f2509.jpg'),
(34874, 2398, 'Caçadores de Bugs S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/122838.mp4', 'http://timg.bdta.pro/images/bbda42878c6fcf81b644d6bf440efe41.jpg'),
(34875, 2398, 'Caçadores de Bugs S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/122839.mp4', 'http://timg.bdta.pro/images/3ad1df5deb5f8b45da901cfdd92abdc1.jpg'),
(34876, 2398, 'Caçadores de Bugs S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/122840.mp4', 'http://timg.bdta.pro/images/b762c8f76292015db179eb496e5a70d8.jpg'),
(34877, 2398, 'Caçadores de Bugs S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/122841.mp4', 'http://timg.bdta.pro/images/4830704a3bd134d69bc8e4dce1af1e5d.jpg'),
(34878, 2398, 'Caçadores de Bugs S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/122842.mp4', 'http://timg.bdta.pro/images/e3af0316a9d17c1f3663cde75c0a53f5.jpg'),
(34879, 2398, 'Caçadores de Bugs S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/122843.mp4', 'http://timg.bdta.pro/images/af240f70a691ab2ead92a46805e2dd6e.jpg'),
(34880, 2398, 'Caçadores de Bugs S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/122844.mp4', 'http://timg.bdta.pro/images/a5a4715542d91e22a27457bbfb11b627.jpg'),
(34881, 2399, 'Caçadores de Bugs S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/122845.mp4', 'http://timg.bdta.pro/images/e31c716c057fdc8fd38ec5303af13b10.jpg'),
(34882, 2399, 'Caçadores de Bugs S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/122846.mp4', 'http://timg.bdta.pro/images/e2d213760c8ece9906204b7735beb94d.jpg'),
(34883, 2399, 'Caçadores de Bugs S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/122847.mp4', 'http://timg.bdta.pro/images/86dd11850415f2feabd37365380690f5.jpg'),
(34884, 2399, 'Caçadores de Bugs S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/122848.mp4', 'http://timg.bdta.pro/images/e048401b75fc1627ee4bb4d4830321cc.jpg'),
(34885, 2399, 'Caçadores de Bugs S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/122849.mp4', 'http://timg.bdta.pro/images/8c4ceb3b623875b5130b6ebb95428db9.jpg'),
(34886, 2399, 'Caçadores de Bugs S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/122850.mp4', 'http://timg.bdta.pro/images/593c9aa919fd46998f6f2d50bb7b1335.jpg'),
(34887, 2399, 'Caçadores de Bugs S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/122851.mp4', 'http://timg.bdta.pro/images/dc5fe0c32fe631b925f98c68e571d30c.jpg'),
(34888, 2399, 'Caçadores de Bugs S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/122852.mp4', 'http://timg.bdta.pro/images/2c9f64d629697642f5c3faafe9a77cc3.jpg'),
(34889, 2399, 'Caçadores de Bugs S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/122853.mp4', 'http://timg.bdta.pro/images/c5863497524257dd72fe1e808cacf578.jpg'),
(34890, 2399, 'Caçadores de Bugs S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/122854.mp4', 'http://timg.bdta.pro/images/1994ec7117632636a53d67290113f8d1.jpg'),
(34891, 2400, 'Curon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/122855.mp4', 'http://timg.bdta.pro/images/0eb79142b6a5a344ccaf28e90eac4e78.jpg'),
(34892, 2400, 'Curon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/122856.mp4', 'http://timg.bdta.pro/images/017f785e61c972a55e7569a2dd74295b.jpg'),
(34893, 2400, 'Curon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/122857.mp4', 'http://timg.bdta.pro/images/67829db14e1d70d8ae4ccf3cb9c796b1.jpg'),
(34894, 2400, 'Curon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/122858.mp4', 'http://timg.bdta.pro/images/da3e35dd922ff2572a6554bdde1ce4a0.jpg'),
(34895, 2400, 'Curon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/122859.mp4', 'http://timg.bdta.pro/images/cdeb60615d080f6a05cc80117d3b7bd9.jpg'),
(34896, 2400, 'Curon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/122860.mp4', 'http://timg.bdta.pro/images/349537866d7922870387573dd8e94b72.jpg'),
(34897, 2400, 'Curon S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/122861.mp4', 'http://timg.bdta.pro/images/74a6b3f8134d8ba6af407f446f320f18.jpg'),
(34898, 2401, 'Dirty John: O Golpe do Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/122862.mp4', 'http://timg.bdta.pro/images/a8d00ce05f67e9141a433d1096caede2.jpg'),
(34899, 2401, 'Dirty John: O Golpe do Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/122863.mp4', 'http://timg.bdta.pro/images/b0cd81870cb55d0f89c50a8f84eba974.jpg'),
(34900, 2401, 'Dirty John: O Golpe do Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/122864.mp4', 'http://timg.bdta.pro/images/c314c48ed2f06bd5ea55e5e6747a288c.jpg'),
(34901, 2401, 'Dirty John: O Golpe do Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/122865.mp4', 'http://timg.bdta.pro/images/be2c633482ad5f4c05a5944c6c5163cb.jpg'),
(34902, 2401, 'Dirty John: O Golpe do Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/122866.mp4', 'http://timg.bdta.pro/images/4e518f8d2e3718b676a713aec007d8d1.jpg'),
(34903, 2401, 'Dirty John: O Golpe do Amor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/122867.mp4', 'http://timg.bdta.pro/images/2cbf5ef0c8efec7c2b4c1efccbaa3216.jpg'),
(34904, 2401, 'Dirty John: O Golpe do Amor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/122868.mp4', 'http://timg.bdta.pro/images/65032671ad6530d87b758452600df2d9.jpg'),
(34905, 2401, 'Dirty John: O Golpe do Amor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/122869.mp4', 'http://timg.bdta.pro/images/f925cfae3a6e4e5433777f8d88ab9a2a.jpg'),
(34906, 2402, 'Dirty John: O Golpe do Amor S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/122870.mp4', 'http://timg.bdta.pro/images/47a080ca70b202992cf12beb4855ea54.jpg'),
(34907, 2402, 'Dirty John: O Golpe do Amor S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/122871.mp4', 'http://timg.bdta.pro/images/6fbfed664127b5a6ca42c3d21bacc0d6.jpg'),
(34908, 2402, 'Dirty John: O Golpe do Amor S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/122872.mp4', 'http://timg.bdta.pro/images/6e25cb5f5aeb5e011eb134cafbf15258.jpg'),
(34909, 2402, 'Dirty John: O Golpe do Amor S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/122873.mp4', 'http://timg.bdta.pro/images/53ef4f439bfb06311cc085bdd839dbff.jpg'),
(34910, 2402, 'Dirty John: O Golpe do Amor S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/122874.mp4', 'http://timg.bdta.pro/images/6605cec810210f9646594f7db06f8ef8.jpg'),
(34911, 2402, 'Dirty John: O Golpe do Amor S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/122875.mp4', 'http://timg.bdta.pro/images/bd57c641fe9749f20af9a1a420b8cc31.jpg'),
(34912, 2402, 'Dirty John: O Golpe do Amor S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/122876.mp4', 'http://timg.bdta.pro/images/b2cedab8fe540f96e5b848681607901f.jpg'),
(34913, 2402, 'Dirty John: O Golpe do Amor S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/122877.mp4', 'http://timg.bdta.pro/images/e0399604f0559cd1d7f673007c9d8178.jpg'),
(34914, 2403, 'Drake & Josh S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/122878.mp4', 'http://timg.bdta.pro/images/9eb3b104d6c148a10412bc901074174f.jpg'),
(34915, 2403, 'Drake & Josh S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/122879.mp4', 'http://timg.bdta.pro/images/053391e3dca6713a4ffd43e7c99f6f58.jpg'),
(34916, 2403, 'Drake & Josh S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/122880.mp4', 'http://timg.bdta.pro/images/645e5bd5f1c7e16dbc88540b21a98b1f.jpg'),
(34917, 2403, 'Drake & Josh S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/122881.mp4', 'http://timg.bdta.pro/images/bad88261d78cee7d6b883821c92058e8.jpg'),
(34918, 2403, 'Drake & Josh S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/122882.mp4', 'http://timg.bdta.pro/images/8b8bd906b963563c49841d8b7aea9c47.jpg'),
(34919, 2403, 'Drake & Josh S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/122883.mp4', 'http://timg.bdta.pro/images/27a94ef0e43218abbfa0951d37a35a10.jpg'),
(34920, 2404, 'Drake & Josh S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/122884.mp4', 'http://timg.bdta.pro/images/f06625663a3df9327377bc1dd50c8c32.jpg'),
(34921, 2404, 'Drake & Josh S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/122885.mp4', 'http://timg.bdta.pro/images/19c9101107a5b22b031ed38466296472.jpg'),
(34922, 2404, 'Drake & Josh S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/122886.mp4', 'http://timg.bdta.pro/images/105d9dacc6fcde9118fe823c06a475de.jpg'),
(34923, 2404, 'Drake & Josh S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/122887.mp4', 'http://timg.bdta.pro/images/b67a3cb4d12d820246a63f6237fee821.jpg'),
(34924, 2404, 'Drake & Josh S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/122888.mp4', 'http://timg.bdta.pro/images/b9ba3ced4004deeeaef29223db516df5.jpg'),
(34925, 2404, 'Drake & Josh S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/122889.mp4', 'http://timg.bdta.pro/images/9d52513febe94966280b6909e765bef2.jpg'),
(34926, 2404, 'Drake & Josh S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/122890.mp4', 'http://timg.bdta.pro/images/7a7d7124b65804efba0a3eca285cbe82.jpg'),
(34927, 2404, 'Drake & Josh S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/122891.mp4', 'http://timg.bdta.pro/images/ef5c4222b409d8dc9b3ab89fa27a1e0c.jpg'),
(34928, 2404, 'Drake & Josh S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/122892.mp4', 'http://timg.bdta.pro/images/211ea0806a59042ff4691e6bef13584a.jpg'),
(34929, 2404, 'Drake & Josh S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/122893.mp4', 'http://timg.bdta.pro/images/3bc8d6d7951e2f6371ef61698cde19bb.jpg'),
(34930, 2404, 'Drake & Josh S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/122894.mp4', 'http://timg.bdta.pro/images/ae18e815367062661859451baa6196aa.jpg'),
(34931, 2404, 'Drake & Josh S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/122895.mp4', 'http://timg.bdta.pro/images/8d91b73d997fbd9f49893841ef035b9d.jpg'),
(34932, 2404, 'Drake & Josh S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/122896.mp4', 'http://timg.bdta.pro/images/daff39a04936b97bb3c6568dccb7672c.jpg'),
(34933, 2404, 'Drake & Josh S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/122897.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34934, 2405, 'Drake & Josh S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/122898.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34935, 2405, 'Drake & Josh S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/122899.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34936, 2405, 'Drake & Josh S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/122900.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34937, 2405, 'Drake & Josh S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/122901.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34938, 2405, 'Drake & Josh S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/122902.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34939, 2405, 'Drake & Josh S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/122903.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34940, 2405, 'Drake & Josh S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/122904.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34941, 2405, 'Drake & Josh S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/122905.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34942, 2405, 'Drake & Josh S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/122906.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34943, 2405, 'Drake & Josh S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/122907.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34944, 2405, 'Drake & Josh S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/122908.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34945, 2405, 'Drake & Josh S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/122909.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34946, 2405, 'Drake & Josh S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/122910.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34947, 2405, 'Drake & Josh S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/122911.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34948, 2405, 'Drake & Josh S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/122912.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34949, 2405, 'Drake & Josh S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/122913.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34950, 2405, 'Drake & Josh S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/122914.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34951, 2405, 'Drake & Josh S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/122915.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34952, 2405, 'Drake & Josh S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/122916.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34953, 2405, 'Drake & Josh S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/122917.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34954, 2406, 'Drake & Josh S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/122918.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34955, 2406, 'Drake & Josh S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/122919.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34956, 2406, 'Drake & Josh S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/122920.mp4', 'http://timg.bdta.pro/images/85a82d607926c81e5ccf0e39e38e6b1f.jpg'),
(34957, 2406, 'Drake & Josh S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/122921.mp4', 'http://timg.bdta.pro/images/c85dd9a1b41f4b8491297b29468da621.jpg'),
(34958, 2406, 'Drake & Josh S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/122922.mp4', 'http://timg.bdta.pro/images/c85dd9a1b41f4b8491297b29468da621.jpg'),
(34959, 2406, 'Drake & Josh S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/122923.mp4', 'http://timg.bdta.pro/images/c85dd9a1b41f4b8491297b29468da621.jpg'),
(34960, 2406, 'Drake & Josh S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/122924.mp4', 'http://timg.bdta.pro/images/c85dd9a1b41f4b8491297b29468da621.jpg'),
(34961, 2406, 'Drake & Josh S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/122925.mp4', 'http://timg.bdta.pro/images/c85dd9a1b41f4b8491297b29468da621.jpg'),
(34962, 2406, 'Drake & Josh S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/122926.mp4', 'http://timg.bdta.pro/images/c85dd9a1b41f4b8491297b29468da621.jpg'),
(34963, 2406, 'Drake & Josh S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/122927.mp4', 'http://timg.bdta.pro/images/c85dd9a1b41f4b8491297b29468da621.jpg'),
(34964, 2406, 'Drake & Josh S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/122928.mp4', 'http://timg.bdta.pro/images/c85dd9a1b41f4b8491297b29468da621.jpg'),
(34965, 2406, 'Drake & Josh S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/122929.mp4', 'http://timg.bdta.pro/images/c77396be03970f8da63e5403f9f387e7.jpg'),
(34966, 2406, 'Drake & Josh S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/122930.mp4', 'http://timg.bdta.pro/images/c77396be03970f8da63e5403f9f387e7.jpg'),
(34967, 2406, 'Drake & Josh S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/122931.mp4', 'http://timg.bdta.pro/images/c77396be03970f8da63e5403f9f387e7.jpg'),
(34968, 2406, 'Drake & Josh S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/122932.mp4', 'http://timg.bdta.pro/images/c77396be03970f8da63e5403f9f387e7.jpg'),
(34969, 2406, 'Drake & Josh S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/122933.mp4', 'http://timg.bdta.pro/images/c77396be03970f8da63e5403f9f387e7.jpg'),
(34970, 2406, 'Drake & Josh S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/122934.mp4', 'http://timg.bdta.pro/images/c77396be03970f8da63e5403f9f387e7.jpg'),
(34971, 2406, 'Drake & Josh S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/122935.mp4', 'http://timg.bdta.pro/images/c77396be03970f8da63e5403f9f387e7.jpg'),
(34972, 2406, 'Drake & Josh S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/122936.mp4', 'http://timg.bdta.pro/images/c77396be03970f8da63e5403f9f387e7.jpg'),
(34973, 2406, 'Drake & Josh S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/122937.mp4', 'http://gstaticontent.com/images/sVHs1XFdXbFl9GznwKHw2iSgq2e_big.jpg'),
(34974, 2407, 'Elena de Avalor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/122938.mp4', 'http://timg.bdta.pro/images/f804667fa5764a1d996f7c5aa622e701.jpg'),
(34975, 2407, 'Elena de Avalor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/122939.mp4', 'http://timg.bdta.pro/images/9d8a381390c91ba0e54d0fd41e743ca4.jpg'),
(34976, 2407, 'Elena de Avalor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/122940.mp4', 'http://timg.bdta.pro/images/569b6420482dbc592180b582fcfe8c6e.jpg'),
(34977, 2407, 'Elena de Avalor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/122941.mp4', 'http://timg.bdta.pro/images/7ae0a2abb7c58593b61cdd8191a1978e.jpg'),
(34978, 2407, 'Elena de Avalor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/122942.mp4', 'http://timg.bdta.pro/images/96a9a0e1c559acbcf1675207dc8b987b.jpg'),
(34979, 2407, 'Elena de Avalor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/122943.mp4', 'http://timg.bdta.pro/images/7520d794a722e2606b2942198f250e01.jpg'),
(34980, 2407, 'Elena de Avalor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/122944.mp4', 'http://timg.bdta.pro/images/dc0a918cef7d40a91a4788338231eccd.jpg'),
(34981, 2407, 'Elena de Avalor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/122945.mp4', 'http://timg.bdta.pro/images/ea11e25858a2963edff8c2c25e9023c6.jpg'),
(34982, 2407, 'Elena de Avalor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/122946.mp4', 'http://timg.bdta.pro/images/207cf2deef72cf4b17c6662a7c9c4140.jpg'),
(34983, 2407, 'Elena de Avalor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/122947.mp4', 'http://timg.bdta.pro/images/13b26803df2828377e1a64f3f210ccd1.jpg'),
(34984, 2407, 'Elena de Avalor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/122948.mp4', 'http://timg.bdta.pro/images/ff5b5b04696815d1ab8070d9c68db3a3.jpg'),
(34985, 2407, 'Elena de Avalor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/122949.mp4', 'http://timg.bdta.pro/images/8ca64098115de00c2d61f7797c630781.jpg'),
(34986, 2407, 'Elena de Avalor S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/122950.mp4', 'http://timg.bdta.pro/images/f5c857b73356073bacdba0e918652ac9.jpg'),
(34987, 2407, 'Elena de Avalor S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/122951.mp4', 'http://timg.bdta.pro/images/09ba4e11540f60651bf3617ad369aabe.jpg'),
(34988, 2407, 'Elena de Avalor S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/122952.mp4', 'http://timg.bdta.pro/images/7f86fbbb032d8d56a3175f86abb12202.jpg'),
(34989, 2407, 'Elena de Avalor S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/122953.mp4', 'http://timg.bdta.pro/images/42be7dac54befe3c45680ea4b6e1d510.jpg'),
(34990, 2407, 'Elena de Avalor S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/122954.mp4', 'http://timg.bdta.pro/images/18858459ca3edf6042ead1daa1d88e9c.jpg'),
(34991, 2407, 'Elena de Avalor S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/122955.mp4', 'http://timg.bdta.pro/images/97c74239b3203b84e8e2e4add3202f15.jpg'),
(34992, 2407, 'Elena de Avalor S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/122956.mp4', 'http://timg.bdta.pro/images/1166d9564290826bf7313fd4ad133381.jpg'),
(34993, 2407, 'Elena de Avalor S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/122957.mp4', 'http://timg.bdta.pro/images/c33dd182d03f4b24478a68a41a24a9ea.jpg'),
(34994, 2407, 'Elena de Avalor S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/122958.mp4', 'http://timg.bdta.pro/images/0d2a11230dd8302b0eed3f7cd89e669f.jpg'),
(34995, 2407, 'Elena de Avalor S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/122959.mp4', 'http://timg.bdta.pro/images/33987ac75a302ba0a9c6e82f2f68507e.jpg'),
(34996, 2407, 'Elena de Avalor S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/122960.mp4', 'http://timg.bdta.pro/images/0d7d71bc587c11a81021b15ff48b84e2.jpg'),
(34997, 2407, 'Elena de Avalor S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/122961.mp4', 'http://timg.bdta.pro/images/c5b58642ad6f8d9eb9db4b9591618283.jpg'),
(34998, 2407, 'Elena de Avalor S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/122962.mp4', 'http://timg.bdta.pro/images/5800ada805df8e1e4009a19b640fdb2a.jpg'),
(34999, 2408, 'Godfather of Harlem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213816.mp4', 'http://timg.bdta.pro/images/c1e023ced97994f405b83c659512fbee.jpg'),
(35000, 2408, 'Godfather of Harlem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213817.mp4', 'http://timg.bdta.pro/images/e27958aff1b71e157a23c49ce0a16084.jpg'),
(35001, 2408, 'Godfather of Harlem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213818.mp4', 'http://timg.bdta.pro/images/5465f4b5efc2eb9c4100c03d4ea7f48f.jpg'),
(35002, 2408, 'Godfather of Harlem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213819.mp4', 'http://timg.bdta.pro/images/7dbbbd6c442f06ffe0dcb51e371fc214.jpg'),
(35003, 2408, 'Godfather of Harlem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213820.mp4', 'http://timg.bdta.pro/images/5f564a913b43d396c2272b96d78bb64d.jpg'),
(35004, 2408, 'Godfather of Harlem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213821.mp4', 'http://timg.bdta.pro/images/021cde7b11a77746c559da5191639e01.jpg'),
(35005, 2408, 'Godfather of Harlem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213822.mp4', 'http://timg.bdta.pro/images/f3069c1a1b2438a020091ab1e413f510.jpg'),
(35006, 2408, 'Godfather of Harlem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213823.mp4', 'http://timg.bdta.pro/images/35aa2381c07716fb8360469e503e24c6.jpg'),
(35007, 2408, 'Godfather of Harlem S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213824.mp4', 'http://timg.bdta.pro/images/b0bafe8809895727fb746e52172fbba7.jpg'),
(35008, 2408, 'Godfather of Harlem S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213825.mp4', 'http://timg.bdta.pro/images/bb3ec6182189c83b73db56a6a129c522.jpg'),
(35009, 2409, 'Godfather of Harlem S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213826.mp4', 'http://timg.bdta.pro/images/e45c51cebee6aaf47e072d7e06b23c4a.jpg'),
(35010, 2409, 'Godfather of Harlem S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213827.mp4', 'http://timg.bdta.pro/images/df7b967515da7862ad80d7859bc6ec07.jpg'),
(35011, 2409, 'Godfather of Harlem S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213828.mp4', 'http://timg.bdta.pro/images/898dc9b792af680c6fff38c53ecf3693.jpg'),
(35012, 2409, 'Godfather of Harlem S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213829.mp4', 'http://timg.bdta.pro/images/1d000994927d2dcb8fd66662977d4f14.jpg'),
(35013, 2409, 'Godfather of Harlem S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213830.mp4', 'http://timg.bdta.pro/images/2faadcb7b1251d3d4b5eb071c1d8aade.jpg'),
(35014, 2409, 'Godfather of Harlem S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213831.mp4', 'http://timg.bdta.pro/images/033d3544c249a663570e16ee7b0f35ce.jpg'),
(35015, 2409, 'Godfather of Harlem S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213832.mp4', 'http://timg.bdta.pro/images/0fcdc2969ff009cc62b85381f31dc056.jpg'),
(35016, 2409, 'Godfather of Harlem S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213833.mp4', 'http://timg.bdta.pro/images/1763e71d9d0393ca85a08fe8dea07ab4.jpg'),
(35017, 2409, 'Godfather of Harlem S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213834.mp4', 'http://timg.bdta.pro/images/32bb5ab36361ed9e2361c639923aad25.jpg'),
(35018, 2409, 'Godfather of Harlem S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213835.mp4', 'http://timg.bdta.pro/images/9280f6cae1a44d743e0be598a179d722.jpg'),
(35019, 2410, 'Godfather of Harlem S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nSGeoA52jKxo3tneLCKiTnn9o9J.jpg'),
(35020, 2410, 'Godfather of Harlem S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/894oZzKl87eR1l8RGsZhzhOqkUj.jpg'),
(35021, 2410, 'Godfather of Harlem S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0wzQOddxvOhYdorcnrC2Nf4e6C.jpg'),
(35022, 2410, 'Godfather of Harlem S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dYA0oazWrY05FvLGE6mqu0ORD4d.jpg'),
(35023, 2410, 'Godfather of Harlem S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vTZGPpDVgvDRQq0wXLwvLBalaa4.jpg'),
(35024, 2410, 'Godfather of Harlem S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSZY97U3r7Cg5Lp2d8JQ9B9BzkV.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(35025, 2410, 'Godfather of Harlem S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wEKKqO0WCwyfRO7SXNGSaFWs4zs.jpg'),
(35026, 2410, 'Godfather of Harlem S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4yVAKs2HAeNLBzZngVWB6TfQdqR.jpg'),
(35027, 2410, 'Godfather of Harlem S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rQxunkUmOgmubqgGOOAG3cKHJcn.jpg'),
(35028, 2410, 'Godfather of Harlem S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6HXeNdEmnCUcwdfHJ0TRq1dsAm2.jpg'),
(35029, 2411, 'Godfather of Harlem S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/843092.mp4', 'http://gstaticontent.com/images/dWE4w6MqkrjakY3pY6YhHHr4XpW_big.jpg'),
(35030, 2411, 'Godfather of Harlem S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/843093.mp4', 'http://gstaticontent.com/images/dWE4w6MqkrjakY3pY6YhHHr4XpW_big.jpg'),
(35031, 2411, 'Godfather of Harlem S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/843094.mp4', 'http://gstaticontent.com/images/dWE4w6MqkrjakY3pY6YhHHr4XpW_big.jpg'),
(35032, 2411, 'Godfather of Harlem S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/843095.mp4', 'http://gstaticontent.com/images/dWE4w6MqkrjakY3pY6YhHHr4XpW_big.jpg'),
(35033, 2411, 'Godfather of Harlem S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/843096.mp4', 'http://gstaticontent.com/images/dWE4w6MqkrjakY3pY6YhHHr4XpW_big.jpg'),
(35034, 2411, 'Godfather of Harlem S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/843097.mp4', 'http://gstaticontent.com/images/dWE4w6MqkrjakY3pY6YhHHr4XpW_big.jpg'),
(35035, 2411, 'Godfather of Harlem S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/843098.mp4', 'http://gstaticontent.com/images/dWE4w6MqkrjakY3pY6YhHHr4XpW_big.jpg'),
(35036, 2411, 'Godfather of Harlem S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/843099.mp4', 'http://gstaticontent.com/images/dWE4w6MqkrjakY3pY6YhHHr4XpW_big.jpg'),
(35037, 2411, 'Godfather of Harlem S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/843100.mp4', 'http://gstaticontent.com/images/dWE4w6MqkrjakY3pY6YhHHr4XpW_big.jpg'),
(35038, 2411, 'Godfather of Harlem S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/843101.mp4', 'http://gstaticontent.com/images/dWE4w6MqkrjakY3pY6YhHHr4XpW_big.jpg'),
(35039, 2412, 'High Score S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/122963.mp4', 'http://timg.bdta.pro/images/498e2a302eb6964e5d5f6149f42e3306.jpg'),
(35040, 2412, 'High Score S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/122964.mp4', 'http://timg.bdta.pro/images/3c2b5eb0570d9f75d89fd6fd4581f451.jpg'),
(35041, 2412, 'High Score S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/122965.mp4', 'http://timg.bdta.pro/images/3b99383ffdb479d4dd7d2f9f39a8b9c4.jpg'),
(35042, 2412, 'High Score S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/122966.mp4', 'http://timg.bdta.pro/images/05f72de880d7394d17aad7456315b9b5.jpg'),
(35043, 2412, 'High Score S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/122967.mp4', 'http://timg.bdta.pro/images/26e3444c6fda6a03aa7646d373c12265.jpg'),
(35044, 2412, 'High Score S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/122968.mp4', 'http://timg.bdta.pro/images/4a175e2a8360b15da3d82ad77f8d08ef.jpg'),
(35045, 2413, 'Hoops S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/122969.mp4', 'http://timg.bdta.pro/images/baff18320a5e7f6d50e0bc879a9e7ce0.jpg'),
(35046, 2413, 'Hoops S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/122970.mp4', 'http://timg.bdta.pro/images/be086120d5d1d0d2dd3aa3b4d46ef505.jpg'),
(35047, 2413, 'Hoops S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/122971.mp4', 'http://timg.bdta.pro/images/bb15da17e3f7f1d9727d043a0fcb6ee2.jpg'),
(35048, 2413, 'Hoops S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/122972.mp4', 'http://timg.bdta.pro/images/4e520dc93f57fb85cdd53d40dccd3dd7.jpg'),
(35049, 2413, 'Hoops S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/122973.mp4', 'http://timg.bdta.pro/images/206001db1534a35efd62e86ebadf9cec.jpg'),
(35050, 2413, 'Hoops S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/122974.mp4', 'http://timg.bdta.pro/images/a27901a93b8328e0d92093519ab5bdaf.jpg'),
(35051, 2413, 'Hoops S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/122975.mp4', 'http://timg.bdta.pro/images/085d82dedba42cec3e4bac60e81ce103.jpg'),
(35052, 2413, 'Hoops S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/122976.mp4', 'http://timg.bdta.pro/images/a2eed6b1d934dbe66885e7dc4583cfa0.jpg'),
(35053, 2413, 'Hoops S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/122977.mp4', 'http://timg.bdta.pro/images/03c1575977cfc51e31085ec62b836245.jpg'),
(35054, 2413, 'Hoops S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/122978.mp4', 'http://timg.bdta.pro/images/60191ac8e371696f507285874d8931b1.jpg'),
(35055, 2414, 'Lenox Hill S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/122979.mp4', 'http://timg.bdta.pro/images/0aaf467fd4d15fab5620941cf4fd3eeb.jpg'),
(35056, 2414, 'Lenox Hill S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/122980.mp4', 'http://timg.bdta.pro/images/acdd6be0852c8d9e4a87bd89c6f0419d.jpg'),
(35057, 2414, 'Lenox Hill S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/122981.mp4', 'http://timg.bdta.pro/images/29ca4c3af38e9cde6a6e300953f03f9f.jpg'),
(35058, 2414, 'Lenox Hill S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/122982.mp4', 'http://timg.bdta.pro/images/0e5dab816a8b2a36d035863e97269c59.jpg'),
(35059, 2414, 'Lenox Hill S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/122983.mp4', 'http://timg.bdta.pro/images/ad73e0570a9b0b95f5a9e9a14ed47b9d.jpg'),
(35060, 2414, 'Lenox Hill S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/122984.mp4', 'http://timg.bdta.pro/images/67dfad6afc1d8b786aad6b3a77641a79.jpg'),
(35061, 2414, 'Lenox Hill S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/122985.mp4', 'http://timg.bdta.pro/images/1f9f62d2299e18b328a69a4eadefc571.jpg'),
(35062, 2414, 'Lenox Hill S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/122986.mp4', 'http://timg.bdta.pro/images/270861027de2d765941508ebd024e57c.jpg'),
(35063, 2414, 'Lenox Hill S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/122987.mp4', 'http://gstaticontent.com/images/1MvaZ5WbRAqjhkiMGH3trRXcYgG_big.jpg'),
(35064, 2415, 'Lovecraft Country S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132839.mp4', 'http://timg.bdta.pro/images/bcc58f9636844f6f02c464d347e62f18.jpg'),
(35065, 2415, 'Lovecraft Country S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132840.mp4', 'http://timg.bdta.pro/images/c9c77134e7551584c0f8f7c52dcd9782.jpg'),
(35066, 2415, 'Lovecraft Country S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132841.mp4', 'http://timg.bdta.pro/images/4abc60bd4a5460778333be9a120f20bc.jpg'),
(35067, 2415, 'Lovecraft Country S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132842.mp4', 'http://timg.bdta.pro/images/9d8f9a2d38365d4b735913d0780746a9.jpg'),
(35068, 2415, 'Lovecraft Country S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132843.mp4', 'http://timg.bdta.pro/images/cf05b43c921bce946f1c9a816a4bcb41.jpg'),
(35069, 2415, 'Lovecraft Country S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132844.mp4', 'http://timg.bdta.pro/images/4e303dddfa3919fa5d6d6bb69b485888.jpg'),
(35070, 2415, 'Lovecraft Country S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132845.mp4', 'http://timg.bdta.pro/images/b4e902bb038f77ffa438933f009905c0.jpg'),
(35071, 2415, 'Lovecraft Country S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132846.mp4', 'http://timg.bdta.pro/images/12069b527fac8520d38e7f032f119f30.jpg'),
(35072, 2415, 'Lovecraft Country S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132847.mp4', 'http://timg.bdta.pro/images/8b7136f1571c55af03d01a48a5593433.jpg'),
(35073, 2415, 'Lovecraft Country S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132848.mp4', 'http://timg.bdta.pro/images/152e3ad7a75b62a6bcbcf2376642aa22.jpg'),
(35074, 2416, 'Matchday S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/122988.mp4', 'http://gstaticontent.com/images/dHB3uysBq2hiyDmkYKrH7QqVXAR_big.jpg'),
(35075, 2416, 'Matchday S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/122989.mp4', 'http://gstaticontent.com/images/dHB3uysBq2hiyDmkYKrH7QqVXAR_big.jpg'),
(35076, 2416, 'Matchday S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/122990.mp4', 'http://gstaticontent.com/images/dHB3uysBq2hiyDmkYKrH7QqVXAR_big.jpg'),
(35077, 2416, 'Matchday S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/122991.mp4', 'http://gstaticontent.com/images/dHB3uysBq2hiyDmkYKrH7QqVXAR_big.jpg'),
(35078, 2416, 'Matchday S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/122992.mp4', 'http://gstaticontent.com/images/dHB3uysBq2hiyDmkYKrH7QqVXAR_big.jpg'),
(35079, 2416, 'Matchday S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/122993.mp4', 'http://gstaticontent.com/images/dHB3uysBq2hiyDmkYKrH7QqVXAR_big.jpg'),
(35080, 2416, 'Matchday S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/122994.mp4', 'http://gstaticontent.com/images/dHB3uysBq2hiyDmkYKrH7QqVXAR_big.jpg'),
(35081, 2416, 'Matchday S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/122995.mp4', 'http://gstaticontent.com/images/dHB3uysBq2hiyDmkYKrH7QqVXAR_big.jpg'),
(35082, 2417, 'Na Linha de Frente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127098.mp4', 'http://gstaticontent.com/images/2913b042a079d06dc6b9984304405bc6.jpg'),
(35083, 2417, 'Na Linha de Frente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127099.mp4', 'http://gstaticontent.com/images/2913b042a079d06dc6b9984304405bc6.jpg'),
(35084, 2417, 'Na Linha de Frente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127100.mp4', 'http://gstaticontent.com/images/2913b042a079d06dc6b9984304405bc6.jpg'),
(35085, 2417, 'Na Linha de Frente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127101.mp4', 'http://gstaticontent.com/images/2913b042a079d06dc6b9984304405bc6.jpg'),
(35086, 2417, 'Na Linha de Frente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127102.mp4', 'http://gstaticontent.com/images/2913b042a079d06dc6b9984304405bc6.jpg'),
(35087, 2417, 'Na Linha de Frente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127103.mp4', 'http://gstaticontent.com/images/2913b042a079d06dc6b9984304405bc6.jpg'),
(35088, 2417, 'Na Linha de Frente S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127104.mp4', 'http://gstaticontent.com/images/2913b042a079d06dc6b9984304405bc6.jpg'),
(35089, 2417, 'Na Linha de Frente S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127105.mp4', 'http://gstaticontent.com/images/2913b042a079d06dc6b9984304405bc6.jpg'),
(35090, 2417, 'Na Linha de Frente S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127106.mp4', 'http://gstaticontent.com/images/2913b042a079d06dc6b9984304405bc6.jpg'),
(35091, 2417, 'Na Linha de Frente S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127107.mp4', 'http://gstaticontent.com/images/2913b042a079d06dc6b9984304405bc6.jpg'),
(35092, 2417, 'Na Linha de Frente S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127108.mp4', 'http://gstaticontent.com/images/2913b042a079d06dc6b9984304405bc6.jpg'),
(35093, 2417, 'Na Linha de Frente S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127109.mp4', 'http://gstaticontent.com/images/2913b042a079d06dc6b9984304405bc6.jpg'),
(35094, 2417, 'Na Linha de Frente S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127110.mp4', 'http://gstaticontent.com/images/2913b042a079d06dc6b9984304405bc6.jpg'),
(35095, 2418, 'Rita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/122996.mp4', 'http://timg.bdta.pro/images/ff5efcf6bc38e4ce74dcb9fd860dd947.jpg'),
(35096, 2418, 'Rita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/122997.mp4', 'http://timg.bdta.pro/images/b112d5507cfe64032d2ffdb1d0457891.jpg'),
(35097, 2418, 'Rita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/122998.mp4', 'http://timg.bdta.pro/images/9d46577a2ab48b621487800d371d54a8.jpg'),
(35098, 2418, 'Rita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/122999.mp4', 'http://timg.bdta.pro/images/b714e265d93f16b51344bef29127d34a.jpg'),
(35099, 2418, 'Rita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123000.mp4', 'http://timg.bdta.pro/images/cb8f98a0dbc130c694cfd704acd39819.jpg'),
(35100, 2418, 'Rita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123001.mp4', 'http://timg.bdta.pro/images/6ac2fc28c0f3b1b4801303526859565d.jpg'),
(35101, 2418, 'Rita S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123002.mp4', 'http://timg.bdta.pro/images/6e267f8fed01876ed179be127f06012d.jpg'),
(35102, 2418, 'Rita S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123003.mp4', 'http://timg.bdta.pro/images/e60a024a7657bb37eb9c0f72fe07af39.jpg'),
(35103, 2419, 'Rita S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123004.mp4', 'http://timg.bdta.pro/images/0245ec91f3370682be3c3d0cfac9236e.jpg'),
(35104, 2419, 'Rita S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123005.mp4', 'http://timg.bdta.pro/images/2c8bf2a3cbb2d53c375821ff9e4d8233.jpg'),
(35105, 2419, 'Rita S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123006.mp4', 'http://timg.bdta.pro/images/fd17ea8c85a2e79babd85fa8a5af9d21.jpg'),
(35106, 2419, 'Rita S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123007.mp4', 'http://timg.bdta.pro/images/edfa1a422923377ee260fe9918ce122d.jpg'),
(35107, 2419, 'Rita S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123008.mp4', 'http://timg.bdta.pro/images/7725834a08d14c055ab039501965f89d.jpg'),
(35108, 2419, 'Rita S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123009.mp4', 'http://timg.bdta.pro/images/780c718d2d09613b94f41d090ade3aa0.jpg'),
(35109, 2419, 'Rita S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123010.mp4', 'http://timg.bdta.pro/images/227139251476a56ae81864a461604a8e.jpg'),
(35110, 2419, 'Rita S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123011.mp4', 'http://timg.bdta.pro/images/6bfc3418868bfe4e4be41904df8d4fff.jpg'),
(35111, 2420, 'Rita S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123012.mp4', 'http://timg.bdta.pro/images/a93d6bad457fa3c804cdc191d3a35c5b.jpg'),
(35112, 2420, 'Rita S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123013.mp4', 'http://timg.bdta.pro/images/de822dfff0679f79bcb1c117f0153b48.jpg'),
(35113, 2420, 'Rita S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123014.mp4', 'http://timg.bdta.pro/images/b60575d553c46041f55a070447a2e1ac.jpg'),
(35114, 2420, 'Rita S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123015.mp4', 'http://timg.bdta.pro/images/b642783c552706022f4e0635c0baed32.jpg'),
(35115, 2420, 'Rita S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123016.mp4', 'http://timg.bdta.pro/images/e8899e810df9b0a16f89672fe372f2a7.jpg'),
(35116, 2420, 'Rita S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123017.mp4', 'http://timg.bdta.pro/images/f049cd5b013096a75dd4b8605863df94.jpg'),
(35117, 2420, 'Rita S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123018.mp4', 'http://timg.bdta.pro/images/3dc9fcd8eb72b6b070807e5975623fd0.jpg'),
(35118, 2420, 'Rita S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123019.mp4', 'http://timg.bdta.pro/images/e1ba3d2f556ad9156bb19f5754fc35bc.jpg'),
(35119, 2421, 'Rita S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123020.mp4', 'http://timg.bdta.pro/images/945649a33df578aca659d843668c1d4f.jpg'),
(35120, 2421, 'Rita S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123021.mp4', 'http://timg.bdta.pro/images/42b45bdcb65c24c634b50a2437dce9bb.jpg'),
(35121, 2421, 'Rita S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123022.mp4', 'http://timg.bdta.pro/images/c6279809f2bacb59d6e26f969426ead8.jpg'),
(35122, 2421, 'Rita S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123023.mp4', 'http://timg.bdta.pro/images/0155754c391bb4f3423df835801bc4c6.jpg'),
(35123, 2421, 'Rita S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123024.mp4', 'http://timg.bdta.pro/images/565ddd68432319614b7fbd26ac17a2ad.jpg'),
(35124, 2421, 'Rita S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123025.mp4', 'http://timg.bdta.pro/images/e82bb1ace7a5b572375c9f38c99b9738.jpg'),
(35125, 2421, 'Rita S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123026.mp4', 'http://timg.bdta.pro/images/c6c3f07cac3b3f18bec6e762741aef11.jpg'),
(35126, 2421, 'Rita S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123027.mp4', 'http://timg.bdta.pro/images/b037c3e857c16431b52c912ec1941b2d.jpg'),
(35127, 2422, 'Silêncio na Floresta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123028.mp4', 'http://timg.bdta.pro/images/e84b652dd23b3455717b94501810a1fc.jpg'),
(35128, 2422, 'Silêncio na Floresta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123029.mp4', 'http://timg.bdta.pro/images/afe6a180c460a0c448627933e61b8117.jpg'),
(35129, 2422, 'Silêncio na Floresta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123030.mp4', 'http://timg.bdta.pro/images/c8dbb2e89e3d18f677a3b08c33a8115b.jpg'),
(35130, 2422, 'Silêncio na Floresta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123031.mp4', 'http://timg.bdta.pro/images/5c26417e5f99825ee4d651748cde3414.jpg'),
(35131, 2422, 'Silêncio na Floresta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123032.mp4', 'http://timg.bdta.pro/images/0b23f64986eef3500622b15d839c9745.jpg'),
(35132, 2422, 'Silêncio na Floresta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123033.mp4', 'http://timg.bdta.pro/images/634c1298b27a4c76b7b191176a752a98.jpg'),
(35133, 2423, 'SS GB S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123034.mp4', 'http://gstaticontent.com/images/sqybrp68wbUD6tyUz5IJhii00DL_big.jpg'),
(35134, 2423, 'SS GB S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123035.mp4', 'http://gstaticontent.com/images/sqybrp68wbUD6tyUz5IJhii00DL_big.jpg'),
(35135, 2423, 'SS GB S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123036.mp4', 'http://gstaticontent.com/images/sqybrp68wbUD6tyUz5IJhii00DL_big.jpg'),
(35136, 2423, 'SS GB S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123037.mp4', 'http://gstaticontent.com/images/sqybrp68wbUD6tyUz5IJhii00DL_big.jpg'),
(35137, 2423, 'SS GB S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123038.mp4', 'http://gstaticontent.com/images/sqybrp68wbUD6tyUz5IJhii00DL_big.jpg'),
(35138, 2423, 'SS GB S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123039.mp4', 'http://gstaticontent.com/images/sqybrp68wbUD6tyUz5IJhii00DL_big.jpg'),
(35139, 2424, 'Superstore: Uma Loja de Inconveniências S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169580.mp4', 'http://timg.bdta.pro/images/ed4f3946ca101616b775d6bb2f277677.jpg'),
(35140, 2424, 'Superstore: Uma Loja de Inconveniências S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169581.mp4', 'http://timg.bdta.pro/images/0878b7811194eadf6f588a7f8b61eecb.jpg'),
(35141, 2424, 'Superstore: Uma Loja de Inconveniências S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169582.mp4', 'http://timg.bdta.pro/images/929c07f2a184562a36101cfa41e7f464.jpg'),
(35142, 2424, 'Superstore: Uma Loja de Inconveniências S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169583.mp4', 'http://timg.bdta.pro/images/b72f0bc15dc6bb2c23314d3741996869.jpg'),
(35143, 2424, 'Superstore: Uma Loja de Inconveniências S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169584.mp4', 'http://timg.bdta.pro/images/c17c175b365ea4d00ffb629ac3ed1928.jpg'),
(35144, 2424, 'Superstore: Uma Loja de Inconveniências S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169585.mp4', 'http://timg.bdta.pro/images/be56696afe921c6dc1d401430cdadd7f.jpg'),
(35145, 2424, 'Superstore: Uma Loja de Inconveniências S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169586.mp4', 'http://timg.bdta.pro/images/ceee71da112f78ce61e4f1d9ea2bb28f.jpg'),
(35146, 2424, 'Superstore: Uma Loja de Inconveniências S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169587.mp4', 'http://timg.bdta.pro/images/032ceb7cb51a55972947deb42d9409af.jpg'),
(35147, 2424, 'Superstore: Uma Loja de Inconveniências S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169588.mp4', 'http://timg.bdta.pro/images/8240a1f7378346e86a0fb4c575b95a71.jpg'),
(35148, 2424, 'Superstore: Uma Loja de Inconveniências S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169589.mp4', 'http://timg.bdta.pro/images/1a2bca01e8788dfa1c12cbb2513e34d8.jpg'),
(35149, 2424, 'Superstore: Uma Loja de Inconveniências S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/169590.mp4', 'http://timg.bdta.pro/images/c1ff52c8bf6ec617945138504814fa2b.jpg'),
(35150, 2425, 'Superstore: Uma Loja de Inconveniências S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169591.mp4', 'http://timg.bdta.pro/images/4ea0ba72dc573cd3ba56a94c4440a888.jpg'),
(35151, 2425, 'Superstore: Uma Loja de Inconveniências S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169592.mp4', 'http://timg.bdta.pro/images/688534c3abfe1f61e104a08465fe2129.jpg'),
(35152, 2425, 'Superstore: Uma Loja de Inconveniências S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169593.mp4', 'http://timg.bdta.pro/images/8aecac37c678bad01861327c679ecba4.jpg'),
(35153, 2425, 'Superstore: Uma Loja de Inconveniências S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169594.mp4', 'http://timg.bdta.pro/images/eb0f656d7111cafee268c935cb2992a2.jpg'),
(35154, 2425, 'Superstore: Uma Loja de Inconveniências S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169595.mp4', 'http://timg.bdta.pro/images/abfb50519f00299d2cd8fe1d3bf32070.jpg'),
(35155, 2425, 'Superstore: Uma Loja de Inconveniências S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169596.mp4', 'http://timg.bdta.pro/images/07cf9cd00fb9c24d6e2ee74260e0d489.jpg'),
(35156, 2425, 'Superstore: Uma Loja de Inconveniências S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169597.mp4', 'http://timg.bdta.pro/images/b849f507de84763bf02db8ec64a13a2b.jpg'),
(35157, 2425, 'Superstore: Uma Loja de Inconveniências S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169598.mp4', 'http://timg.bdta.pro/images/3111805373b386cf2ac05aa634957210.jpg'),
(35158, 2425, 'Superstore: Uma Loja de Inconveniências S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169599.mp4', 'http://timg.bdta.pro/images/5c92c94bd033548d6b2d93b7a518ea7f.jpg'),
(35159, 2425, 'Superstore: Uma Loja de Inconveniências S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169600.mp4', 'http://timg.bdta.pro/images/8b0a2b8f17e462f433181d59ac5681cf.jpg'),
(35160, 2425, 'Superstore: Uma Loja de Inconveniências S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/169601.mp4', 'http://timg.bdta.pro/images/c6d52c4c8f6d4681009a229e07a108fd.jpg'),
(35161, 2425, 'Superstore: Uma Loja de Inconveniências S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/169602.mp4', 'http://timg.bdta.pro/images/bcfbc6a48eb0a2f6b0d0902acbe1495c.jpg'),
(35162, 2425, 'Superstore: Uma Loja de Inconveniências S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/169603.mp4', 'http://timg.bdta.pro/images/504b582e2cb4c9398c008a004a262eae.jpg'),
(35163, 2425, 'Superstore: Uma Loja de Inconveniências S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/169604.mp4', 'http://timg.bdta.pro/images/ed2bb8434cd30c20eceed7e93afda326.jpg'),
(35164, 2425, 'Superstore: Uma Loja de Inconveniências S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/169605.mp4', 'http://timg.bdta.pro/images/d382ebc4045fecb2e7adf9c6c459ff83.jpg'),
(35165, 2425, 'Superstore: Uma Loja de Inconveniências S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/169606.mp4', 'http://timg.bdta.pro/images/fcc29266de3c4bf80be4ccb8cc89862b.jpg'),
(35166, 2425, 'Superstore: Uma Loja de Inconveniências S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/169607.mp4', 'http://timg.bdta.pro/images/152673e2d0866e73605dc909c20fcb25.jpg'),
(35167, 2425, 'Superstore: Uma Loja de Inconveniências S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/169608.mp4', 'http://timg.bdta.pro/images/ddea3aea64f44bda1d1bb7bfdd44bebe.jpg'),
(35168, 2425, 'Superstore: Uma Loja de Inconveniências S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/169609.mp4', 'http://timg.bdta.pro/images/b7439b78698e374b6e1b4ca8fa599b2f.jpg'),
(35169, 2425, 'Superstore: Uma Loja de Inconveniências S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/169610.mp4', 'http://timg.bdta.pro/images/a26d91b50936d4ee9f5cedd66f799bcc.jpg'),
(35170, 2425, 'Superstore: Uma Loja de Inconveniências S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/169611.mp4', 'http://timg.bdta.pro/images/ccb616f62636941695d80f2cfa4ed0e1.jpg'),
(35171, 2425, 'Superstore: Uma Loja de Inconveniências S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/169612.mp4', 'http://timg.bdta.pro/images/318720aa408c90af813b1a72ffb25221.jpg'),
(35172, 2426, 'Superstore: Uma Loja de Inconveniências S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169613.mp4', 'http://timg.bdta.pro/images/bbcf56bdaf4dfd4f0d57d180d1626155.jpg'),
(35173, 2426, 'Superstore: Uma Loja de Inconveniências S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169614.mp4', 'http://timg.bdta.pro/images/7843061be68de027621f64e12707b769.jpg'),
(35174, 2426, 'Superstore: Uma Loja de Inconveniências S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169615.mp4', 'http://timg.bdta.pro/images/8ed89031fde844d44999adc1f0295508.jpg'),
(35175, 2426, 'Superstore: Uma Loja de Inconveniências S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169616.mp4', 'http://timg.bdta.pro/images/2c9efcf09d3eea4bdd731e07bb859b95.jpg'),
(35176, 2426, 'Superstore: Uma Loja de Inconveniências S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169617.mp4', 'http://timg.bdta.pro/images/1709a88f64af6d9ebd599cbbd64cda15.jpg'),
(35177, 2426, 'Superstore: Uma Loja de Inconveniências S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169618.mp4', 'http://timg.bdta.pro/images/333a0ba85904034a0b4195c6487f0b9c.jpg'),
(35178, 2426, 'Superstore: Uma Loja de Inconveniências S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169619.mp4', 'http://timg.bdta.pro/images/cb1eff79f277a77b2ea0d34fe4396195.jpg'),
(35179, 2426, 'Superstore: Uma Loja de Inconveniências S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169620.mp4', 'http://timg.bdta.pro/images/6e3a04ad9665c97cbb407a43f04b7485.jpg'),
(35180, 2426, 'Superstore: Uma Loja de Inconveniências S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169621.mp4', 'http://timg.bdta.pro/images/6558eed9ea10ae7d3db3cea0e404ca6a.jpg'),
(35181, 2426, 'Superstore: Uma Loja de Inconveniências S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169622.mp4', 'http://timg.bdta.pro/images/6b115e5a1b2877b2f8014cd74248b704.jpg'),
(35182, 2426, 'Superstore: Uma Loja de Inconveniências S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/169623.mp4', 'http://timg.bdta.pro/images/275d54817c1b9399f1bbda3a96ba6df3.jpg'),
(35183, 2426, 'Superstore: Uma Loja de Inconveniências S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/169624.mp4', 'http://timg.bdta.pro/images/4d7b545aec4624e26d275d45587f233f.jpg'),
(35184, 2426, 'Superstore: Uma Loja de Inconveniências S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/169625.mp4', 'http://timg.bdta.pro/images/ed18c5661a405c01e1c6890a581fc845.jpg'),
(35185, 2426, 'Superstore: Uma Loja de Inconveniências S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/169626.mp4', 'http://timg.bdta.pro/images/71e5cae2674825550371ecfaeb39c3a0.jpg'),
(35186, 2426, 'Superstore: Uma Loja de Inconveniências S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/169627.mp4', 'http://timg.bdta.pro/images/5d7d8293fe561cebc139797464665d00.jpg'),
(35187, 2426, 'Superstore: Uma Loja de Inconveniências S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/169628.mp4', 'http://timg.bdta.pro/images/ce74c2aa00be4dac86c5c42f368c0a51.jpg'),
(35188, 2426, 'Superstore: Uma Loja de Inconveniências S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/169629.mp4', 'http://timg.bdta.pro/images/fa933e6c1ab8202f7c717ef80a6844f1.jpg'),
(35189, 2426, 'Superstore: Uma Loja de Inconveniências S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/169630.mp4', 'http://timg.bdta.pro/images/4a58443784383dbe6f45cf959349732f.jpg'),
(35190, 2426, 'Superstore: Uma Loja de Inconveniências S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/169631.mp4', 'http://timg.bdta.pro/images/da249f88b92d38bf956c2a97c23d7875.jpg'),
(35191, 2426, 'Superstore: Uma Loja de Inconveniências S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/169632.mp4', 'http://timg.bdta.pro/images/3eab54bf5cf47228d87c121506c0d15a.jpg'),
(35192, 2426, 'Superstore: Uma Loja de Inconveniências S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/169633.mp4', 'http://timg.bdta.pro/images/c9a25328013cb08181e307bb4100dbd1.jpg'),
(35193, 2426, 'Superstore: Uma Loja de Inconveniências S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/169634.mp4', 'http://timg.bdta.pro/images/b004b87f3da2d891ffd06a9a280dfc41.jpg'),
(35194, 2427, 'Superstore: Uma Loja de Inconveniências S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169635.mp4', 'http://timg.bdta.pro/images/035eb6ac361132cfd3ff80357987d7a4.jpg'),
(35195, 2427, 'Superstore: Uma Loja de Inconveniências S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169636.mp4', 'http://timg.bdta.pro/images/555c1050597a217f7ba6d619ff34f8cf.jpg'),
(35196, 2427, 'Superstore: Uma Loja de Inconveniências S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169637.mp4', 'http://timg.bdta.pro/images/a1196aff769112e56df98bdad237539a.jpg'),
(35197, 2427, 'Superstore: Uma Loja de Inconveniências S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169638.mp4', 'http://timg.bdta.pro/images/e6a938a7f3f56fd22c2a53f10b2bda90.jpg'),
(35198, 2427, 'Superstore: Uma Loja de Inconveniências S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169639.mp4', 'http://timg.bdta.pro/images/eaae1ae6179dc8c0988ad8feea392c7d.jpg'),
(35199, 2427, 'Superstore: Uma Loja de Inconveniências S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169640.mp4', 'http://timg.bdta.pro/images/ea9d7cd7d5ad31476202eb9faa737703.jpg'),
(35200, 2427, 'Superstore: Uma Loja de Inconveniências S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169641.mp4', 'http://timg.bdta.pro/images/2b9080f1a7412e32901777ac2854409f.jpg'),
(35201, 2427, 'Superstore: Uma Loja de Inconveniências S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169642.mp4', 'http://timg.bdta.pro/images/6c2465d37fc964463d740c663694bda7.jpg'),
(35202, 2427, 'Superstore: Uma Loja de Inconveniências S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169643.mp4', 'http://timg.bdta.pro/images/fef8963cb325664dab7f0b5c3bff437c.jpg'),
(35203, 2427, 'Superstore: Uma Loja de Inconveniências S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169644.mp4', 'http://timg.bdta.pro/images/889678e7bd8e086f9c7bdc1837ab8bc9.jpg'),
(35204, 2427, 'Superstore: Uma Loja de Inconveniências S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/169645.mp4', 'http://timg.bdta.pro/images/e7320f2818d534638632747cae2baa90.jpg'),
(35205, 2427, 'Superstore: Uma Loja de Inconveniências S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/169646.mp4', 'http://timg.bdta.pro/images/ef6db4ad98f52596c9d50a7052ad1b1d.jpg'),
(35206, 2427, 'Superstore: Uma Loja de Inconveniências S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/169647.mp4', 'http://timg.bdta.pro/images/191613d30624e7a0788a931c3f11a4f9.jpg'),
(35207, 2427, 'Superstore: Uma Loja de Inconveniências S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/169648.mp4', 'http://timg.bdta.pro/images/c7236cbbb1c703dc510451ed7baa2f80.jpg'),
(35208, 2427, 'Superstore: Uma Loja de Inconveniências S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/169649.mp4', 'http://timg.bdta.pro/images/025d9e4d4aca9551c33079f202b1b8d0.jpg'),
(35209, 2427, 'Superstore: Uma Loja de Inconveniências S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/169650.mp4', 'http://timg.bdta.pro/images/ded22506526fbb54198345d63b777275.jpg'),
(35210, 2427, 'Superstore: Uma Loja de Inconveniências S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/169651.mp4', 'http://timg.bdta.pro/images/fc9a828277a693100be6fd915e79856c.jpg'),
(35211, 2427, 'Superstore: Uma Loja de Inconveniências S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/169652.mp4', 'http://timg.bdta.pro/images/1a0e5aefcc86d0e2cd7a2924e71c306e.jpg'),
(35212, 2427, 'Superstore: Uma Loja de Inconveniências S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/169653.mp4', 'http://timg.bdta.pro/images/fae28a6386aa54d3a08d400cddffa998.jpg'),
(35213, 2427, 'Superstore: Uma Loja de Inconveniências S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/169654.mp4', 'http://timg.bdta.pro/images/647941a1bd893c675cd4956d2bca067c.jpg'),
(35214, 2427, 'Superstore: Uma Loja de Inconveniências S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/169655.mp4', 'http://timg.bdta.pro/images/c4ee6de16f1488370ebf41191d1d227c.jpg'),
(35215, 2427, 'Superstore: Uma Loja de Inconveniências S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/169656.mp4', 'http://timg.bdta.pro/images/80144c82cb8b6cd7c058f8ea637610d0.jpg'),
(35216, 2428, 'Superstore: Uma Loja de Inconveniências S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169657.mp4', 'http://timg.bdta.pro/images/8e9454ed4634989ec9f7b638d451055c.jpg'),
(35217, 2428, 'Superstore: Uma Loja de Inconveniências S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169658.mp4', 'http://timg.bdta.pro/images/4a275917a578ff5142bf2408f5754315.jpg'),
(35218, 2428, 'Superstore: Uma Loja de Inconveniências S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169659.mp4', 'http://timg.bdta.pro/images/9db70d5c3bf1b067f507b97cb67acc89.jpg'),
(35219, 2428, 'Superstore: Uma Loja de Inconveniências S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169660.mp4', 'http://timg.bdta.pro/images/e8627fdb59b961fcb2b762614cfbf6a2.jpg'),
(35220, 2428, 'Superstore: Uma Loja de Inconveniências S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169661.mp4', 'http://timg.bdta.pro/images/6d541be71e3582337acbe31d8c486436.jpg'),
(35221, 2428, 'Superstore: Uma Loja de Inconveniências S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169662.mp4', 'http://timg.bdta.pro/images/77b7d8f54053fead40dbf4e60fb0e72e.jpg'),
(35222, 2428, 'Superstore: Uma Loja de Inconveniências S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169663.mp4', 'http://timg.bdta.pro/images/ce31fdb5e41ac31a9d704b9c02dd933b.jpg'),
(35223, 2428, 'Superstore: Uma Loja de Inconveniências S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169664.mp4', 'http://timg.bdta.pro/images/d3536c4adc215d1ff7d0f27c0600f237.jpg'),
(35224, 2428, 'Superstore: Uma Loja de Inconveniências S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169665.mp4', 'http://timg.bdta.pro/images/88f80393f6310c9f50f93db4f46631b4.jpg'),
(35225, 2428, 'Superstore: Uma Loja de Inconveniências S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169666.mp4', 'http://timg.bdta.pro/images/cc6bb8963eb8fe2ba9e796b178db23ad.jpg'),
(35226, 2428, 'Superstore: Uma Loja de Inconveniências S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/169667.mp4', 'http://timg.bdta.pro/images/b92234298df4203a12d0cd88a1bac4cf.jpg'),
(35227, 2428, 'Superstore: Uma Loja de Inconveniências S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/169668.mp4', 'http://timg.bdta.pro/images/861a3adfaf63ee052d0cde89146bc2e4.jpg'),
(35228, 2428, 'Superstore: Uma Loja de Inconveniências S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/169669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5UTkRTE9ABzmbHPmHVzN7UJMLoI.jpg'),
(35229, 2428, 'Superstore: Uma Loja de Inconveniências S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/169670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2MvNRAVQjNRy3XK5refaoj7nWgK.jpg'),
(35230, 2428, 'Superstore: Uma Loja de Inconveniências S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/169671.mp4', 'http://gstaticontent.com/images/fMycr8Q4BZEkDq2fVVxatWR9Yid_big.jpg'),
(35231, 2428, 'Superstore: Uma Loja de Inconveniências S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/169672.mp4', 'http://gstaticontent.com/images/fMycr8Q4BZEkDq2fVVxatWR9Yid_big.jpg'),
(35232, 2428, 'Superstore: Uma Loja de Inconveniências S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/169673.mp4', 'http://gstaticontent.com/images/fMycr8Q4BZEkDq2fVVxatWR9Yid_big.jpg'),
(35233, 2428, 'Superstore: Uma Loja de Inconveniências S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/169674.mp4', 'http://gstaticontent.com/images/fMycr8Q4BZEkDq2fVVxatWR9Yid_big.jpg'),
(35234, 2428, 'Superstore: Uma Loja de Inconveniências S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/169675.mp4', 'http://gstaticontent.com/images/fMycr8Q4BZEkDq2fVVxatWR9Yid_big.jpg'),
(35235, 2428, 'Superstore: Uma Loja de Inconveniências S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/169676.mp4', 'http://gstaticontent.com/images/fMycr8Q4BZEkDq2fVVxatWR9Yid_big.jpg'),
(35236, 2428, 'Superstore: Uma Loja de Inconveniências S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/169677.mp4', 'http://gstaticontent.com/images/fMycr8Q4BZEkDq2fVVxatWR9Yid_big.jpg'),
(35237, 2429, 'Superstore: Uma Loja de Inconveniências S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mVu0Z0fvn6qyuk6wUc2w2Lz5mAG.jpg'),
(35238, 2429, 'Superstore: Uma Loja de Inconveniências S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zF38GCnhP1yu588FHU2Cz5mfvqN.jpg'),
(35239, 2429, 'Superstore: Uma Loja de Inconveniências S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qp94x3O1LeddKxjIgnql1Hop9vu.jpg'),
(35240, 2429, 'Superstore: Uma Loja de Inconveniências S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169681.mp4', 'http://image.tmdb.org/t/p/w1280/pGvQQqYKsEyAwHorGwYt6wwUZQS.jpg'),
(35241, 2429, 'Superstore: Uma Loja de Inconveniências S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169682.mp4', 'http://image.tmdb.org/t/p/w1280/vZWBME42iqDkFYxKgSKMA8KFxMH.jpg'),
(35242, 2429, 'Superstore: Uma Loja de Inconveniências S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ssTONGegi9dQ6LUSrqBq1x9QqdZ.jpg'),
(35243, 2429, 'Superstore: Uma Loja de Inconveniências S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7IN1HQUbzdAlemM57eDMXuLPbdW.jpg'),
(35244, 2429, 'Superstore: Uma Loja de Inconveniências S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9rkxllFgY4UPxDLEVp3ivgYvFjB.jpg'),
(35245, 2429, 'Superstore: Uma Loja de Inconveniências S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169686.mp4', 'http://image.tmdb.org/t/p/w1280/4iSPgBpZxv14Hzzsa1WfBYvJsgo.jpg'),
(35246, 2429, 'Superstore: Uma Loja de Inconveniências S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x0dI1rrHBnwNZ4vTOC6qOil0gj4.jpg'),
(35247, 2429, 'Superstore: Uma Loja de Inconveniências S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/169688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9n1WCX0pZygOw69VTAawa7MovmS.jpg'),
(35248, 2429, 'Superstore: Uma Loja de Inconveniências S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/169689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zPTZRYigZRBA7gaq1VREGcqkkY6.jpg'),
(35249, 2429, 'Superstore: Uma Loja de Inconveniências S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/169690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/un7RFZYiTpplFJ1kxzZ8oVxGevv.jpg'),
(35250, 2429, 'Superstore: Uma Loja de Inconveniências S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/169691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/neDxmCz9BZDfLuIN34GMXiMfA1B.jpg'),
(35251, 2429, 'Superstore: Uma Loja de Inconveniências S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/169692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m7JAVHDWKG3dGLlM8k2wQocbfu8.jpg'),
(35252, 2430, 'Ted Lasso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216885.mp4', 'http://timg.bdta.pro/images/4d8d0357fc723994b8e0867d18ecba49.jpg'),
(35253, 2430, 'Ted Lasso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216886.mp4', 'http://timg.bdta.pro/images/487081fa699a1e2f5e2948486d4cd3de.jpg'),
(35254, 2430, 'Ted Lasso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216887.mp4', 'http://timg.bdta.pro/images/9ab8e2898b43561238bf90b3beb729db.jpg'),
(35255, 2430, 'Ted Lasso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216888.mp4', 'http://timg.bdta.pro/images/704bf1b3c7d9c2dac70afffb9e580cca.jpg'),
(35256, 2430, 'Ted Lasso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216889.mp4', 'http://timg.bdta.pro/images/0c5ffdb5ea1a651ba7771e4f89fd9c11.jpg'),
(35257, 2430, 'Ted Lasso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216890.mp4', 'http://timg.bdta.pro/images/f2bbb24fb4d15205e6dba4d4587803a5.jpg'),
(35258, 2430, 'Ted Lasso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216891.mp4', 'http://timg.bdta.pro/images/5bb6d87ef7f404c387819f1940af57c2.jpg'),
(35259, 2430, 'Ted Lasso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216892.mp4', 'http://timg.bdta.pro/images/dbbb3c2cc1fa1d1767f5260d7e84b1ae.jpg'),
(35260, 2430, 'Ted Lasso S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216893.mp4', 'http://timg.bdta.pro/images/f404cd30505bf82f204e873a6ea5c8df.jpg'),
(35261, 2430, 'Ted Lasso S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216894.mp4', 'http://timg.bdta.pro/images/64497f670b800373c07f26bc9ed84464.jpg'),
(35262, 2431, 'Ted Lasso S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216895.mp4', 'http://timg.bdta.pro/images/c4d2757ce7493c4f87966bd00c1d1004.jpg'),
(35263, 2431, 'Ted Lasso S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216896.mp4', 'http://timg.bdta.pro/images/80aab772326295e588bdfebefa791a14.jpg'),
(35264, 2431, 'Ted Lasso S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216897.mp4', 'http://timg.bdta.pro/images/cd244bb39ca91753dfbd57b0a648ef57.jpg'),
(35265, 2431, 'Ted Lasso S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216898.mp4', 'http://timg.bdta.pro/images/ff2fc4302ccf78955206ca2f9dc5b5b6.jpg'),
(35266, 2431, 'Ted Lasso S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216899.mp4', 'http://timg.bdta.pro/images/b7666dab2c2cbe3b47050167efe817bb.jpg'),
(35267, 2431, 'Ted Lasso S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216900.mp4', 'http://timg.bdta.pro/images/bc2141ef733c553dd1a5bd591aab3249.jpg'),
(35268, 2431, 'Ted Lasso S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216901.mp4', 'http://timg.bdta.pro/images/bf40dd5f009c2663c656b0f255ed2640.jpg'),
(35269, 2431, 'Ted Lasso S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216902.mp4', 'http://timg.bdta.pro/images/68b812da10652e146dcb64e4c66d9f3f.jpg'),
(35270, 2431, 'Ted Lasso S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216903.mp4', 'http://timg.bdta.pro/images/dffe186640751618ba2462c8bd1747b1.jpg'),
(35271, 2431, 'Ted Lasso S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216904.mp4', 'http://image.tmdb.org/t/p/w1280/1ViXiMxiKH7WYYB6OfQzkoegdK9.jpg'),
(35272, 2431, 'Ted Lasso S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216905.mp4', 'http://image.tmdb.org/t/p/w1280/clp0O56bsvz707xQAI44KfSMOft.jpg'),
(35273, 2431, 'Ted Lasso S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216906.mp4', 'http://image.tmdb.org/t/p/w1280/rc1YAVoHcTexCtVL8RGqdorzVUP.jpg'),
(35274, 2432, 'Ted Lasso S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216907.mp4', 'http://image.tmdb.org/t/p/w1280/hXSVyhVjhSbhGJFHB4rBP7bgqrB.jpg'),
(35275, 2432, 'Ted Lasso S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216908.mp4', 'http://image.tmdb.org/t/p/w1280/wpcIswewy5vpcyLQokIUSlVZZaf.jpg'),
(35276, 2432, 'Ted Lasso S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216909.mp4', 'http://image.tmdb.org/t/p/w1280/AtfVkDAULlQs7paOg29l8GdyOJx.jpg'),
(35277, 2432, 'Ted Lasso S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216910.mp4', 'http://image.tmdb.org/t/p/w1280/3D4PRphUaWTkMm6sBDSLcYdTpX2.jpg'),
(35278, 2432, 'Ted Lasso S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216911.mp4', 'http://image.tmdb.org/t/p/w1280/vpeqM8IlIUfujtCARPyn06dBrBn.jpg'),
(35279, 2432, 'Ted Lasso S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216912.mp4', 'http://image.tmdb.org/t/p/w1280/dCzd2x3CLkuQHjfBUH0cPlUS1ok.jpg'),
(35280, 2432, 'Ted Lasso S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216913.mp4', 'http://image.tmdb.org/t/p/w1280/sgQ3LVQIpUIGdbmh6cCLpKaLu9i.jpg'),
(35281, 2432, 'Ted Lasso S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216914.mp4', 'http://image.tmdb.org/t/p/w1280/8sOFpkpEACy4xF64S1ZKtUy2iAb.jpg'),
(35282, 2432, 'Ted Lasso S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216915.mp4', 'http://image.tmdb.org/t/p/w1280/q7XTLOBtk7NN8f98LPDJzobyPVZ.jpg'),
(35283, 2432, 'Ted Lasso S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216916.mp4', 'http://image.tmdb.org/t/p/w1280/nwwJ7vefKslxMRnpKImalnaa3Hy.jpg'),
(35284, 2432, 'Ted Lasso S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216917.mp4', 'http://image.tmdb.org/t/p/w1280/nAWyJ1tTL8pngx8fNva3yGrwMTI.jpg'),
(35285, 2432, 'Ted Lasso S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216918.mp4', 'http://image.tmdb.org/t/p/w1280/20wtnBwy5nRQHgWU89GTCAtTuyc.jpg'),
(35286, 2433, 'The Romeo Section S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123040.mp4', 'http://timg.bdta.pro/images/c3284b982d855f10f6a489372892cf12.jpg'),
(35287, 2433, 'The Romeo Section S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123041.mp4', 'http://timg.bdta.pro/images/c3f523965926a055b03fc34bddf8f6ec.jpg'),
(35288, 2433, 'The Romeo Section S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123042.mp4', 'http://timg.bdta.pro/images/99b17be3b03e60954e73245216e62e52.jpg'),
(35289, 2433, 'The Romeo Section S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123043.mp4', 'http://timg.bdta.pro/images/43b78950342e8e8894135057913dc059.jpg'),
(35290, 2433, 'The Romeo Section S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123044.mp4', 'http://timg.bdta.pro/images/ca006f2e5847d67c67a79672bc6818ee.jpg'),
(35291, 2433, 'The Romeo Section S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123045.mp4', 'http://timg.bdta.pro/images/64f6f44720df6675d7534e3448be3c42.jpg'),
(35292, 2433, 'The Romeo Section S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123046.mp4', 'http://timg.bdta.pro/images/fb82c68220896884e7ac05225351df88.jpg'),
(35293, 2433, 'The Romeo Section S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123047.mp4', 'http://timg.bdta.pro/images/8337f3b0a989e5ab077287472e83c595.jpg'),
(35294, 2433, 'The Romeo Section S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123048.mp4', 'http://timg.bdta.pro/images/4f67021219cdfee0c21e301786f9c939.jpg'),
(35295, 2433, 'The Romeo Section S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123049.mp4', 'http://timg.bdta.pro/images/8f143629b71b5632177aea989bb9e4a1.jpg'),
(35296, 2434, 'Traficantes Invisiveis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123050.mp4', 'http://gstaticontent.com/images/rSanIa9rfV7jzQjbFICMVdbqMUp_big.jpg'),
(35297, 2434, 'Traficantes Invisiveis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123051.mp4', 'http://gstaticontent.com/images/rSanIa9rfV7jzQjbFICMVdbqMUp_big.jpg'),
(35298, 2435, 'Tudo Bem Nao Ser Normal [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123052.mp4', 'http://timg.bdta.pro/images/ceede1bd66db68b96b0408061a6d993a.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(35299, 2435, 'Tudo Bem Nao Ser Normal [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123053.mp4', 'http://timg.bdta.pro/images/6036e015db66c765549cd04233f54880.jpg'),
(35300, 2435, 'Tudo Bem Nao Ser Normal [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123054.mp4', 'http://timg.bdta.pro/images/2859d32b195097698f3467678dff6e89.jpg'),
(35301, 2435, 'Tudo Bem Nao Ser Normal [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123055.mp4', 'http://timg.bdta.pro/images/a72026f3975e02715dc460d0e65c8f1f.jpg'),
(35302, 2435, 'Tudo Bem Nao Ser Normal [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123056.mp4', 'http://timg.bdta.pro/images/5ce17b27cbb793948a343ca0b269a26f.jpg'),
(35303, 2435, 'Tudo Bem Nao Ser Normal [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123057.mp4', 'http://timg.bdta.pro/images/b2bc6b3a9861d015f5096eae5ea3f83a.jpg'),
(35304, 2435, 'Tudo Bem Nao Ser Normal [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123058.mp4', 'http://timg.bdta.pro/images/a40346a4047c7eb413e5ebffe8e18062.jpg'),
(35305, 2435, 'Tudo Bem Nao Ser Normal [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123059.mp4', 'http://timg.bdta.pro/images/76cfdc0762b62f76c96c46da32dae810.jpg'),
(35306, 2435, 'Tudo Bem Nao Ser Normal [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123060.mp4', 'http://timg.bdta.pro/images/59cba452bdebecf53477a2606f9067c4.jpg'),
(35307, 2435, 'Tudo Bem Nao Ser Normal [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123061.mp4', 'http://timg.bdta.pro/images/60ea0e9fa461a07c99544e6879069178.jpg'),
(35308, 2435, 'Tudo Bem Nao Ser Normal [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/123062.mp4', 'http://timg.bdta.pro/images/e44fc739b8b63b28696cee9e7f889d54.jpg'),
(35309, 2435, 'Tudo Bem Nao Ser Normal [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/123063.mp4', 'http://timg.bdta.pro/images/3f65f9830e54d36f5fb703452dcc92e7.jpg'),
(35310, 2435, 'Tudo Bem Nao Ser Normal [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/123064.mp4', 'http://timg.bdta.pro/images/803438306b5107889125e61a25184778.jpg'),
(35311, 2435, 'Tudo Bem Nao Ser Normal [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/123065.mp4', 'http://timg.bdta.pro/images/4ec5cd5066823b3e4cdff429484da093.jpg'),
(35312, 2435, 'Tudo Bem Nao Ser Normal [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/123066.mp4', 'http://timg.bdta.pro/images/2c535134491e8dee4d0dbf14fcdbe784.jpg'),
(35313, 2435, 'Tudo Bem Nao Ser Normal [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/123067.mp4', 'http://timg.bdta.pro/images/4a129eca3a3836156be1b59f0a917a0b.jpg'),
(35314, 2436, 'Unbreakable Kimmy Schmidt S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123068.mp4', 'http://timg.bdta.pro/images/0b0c823f65bfadb5304638053fab2bcf.jpg'),
(35315, 2436, 'Unbreakable Kimmy Schmidt S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123069.mp4', 'http://timg.bdta.pro/images/47e494c5c322b4e5c070bf5c311a5aa9.jpg'),
(35316, 2436, 'Unbreakable Kimmy Schmidt S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123070.mp4', 'http://timg.bdta.pro/images/a0998dc8f462e46b9b252e4d0087b333.jpg'),
(35317, 2436, 'Unbreakable Kimmy Schmidt S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123071.mp4', 'http://timg.bdta.pro/images/d3072f304671b840c63e778b6651d77a.jpg'),
(35318, 2436, 'Unbreakable Kimmy Schmidt S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123072.mp4', 'http://timg.bdta.pro/images/2ea28ed40cf291bcba8c35847cb8aac6.jpg'),
(35319, 2436, 'Unbreakable Kimmy Schmidt S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123073.mp4', 'http://timg.bdta.pro/images/5e3fe66aef6176444676bd01956d1e2c.jpg'),
(35320, 2436, 'Unbreakable Kimmy Schmidt S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123074.mp4', 'http://timg.bdta.pro/images/72a0a1ea7089949496186c39e859eec9.jpg'),
(35321, 2436, 'Unbreakable Kimmy Schmidt S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123075.mp4', 'http://timg.bdta.pro/images/eff0f3b6107da169dd99925001c1c944.jpg'),
(35322, 2436, 'Unbreakable Kimmy Schmidt S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123076.mp4', 'http://timg.bdta.pro/images/d01ccd0efbef9610aca1bc39e724a04a.jpg'),
(35323, 2436, 'Unbreakable Kimmy Schmidt S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123077.mp4', 'http://timg.bdta.pro/images/7faafa799d327b408956d236d1f33c6d.jpg'),
(35324, 2436, 'Unbreakable Kimmy Schmidt S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/123078.mp4', 'http://timg.bdta.pro/images/aaa6609a10657fd5b2c48d230167b890.jpg'),
(35325, 2436, 'Unbreakable Kimmy Schmidt S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/123079.mp4', 'http://timg.bdta.pro/images/9409524d72628cce57f72ed234efb0d6.jpg'),
(35326, 2436, 'Unbreakable Kimmy Schmidt S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/123080.mp4', 'http://timg.bdta.pro/images/27170dfb64d1fd6fcab373543f7fd246.jpg'),
(35327, 2437, 'Unbreakable Kimmy Schmidt S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123081.mp4', 'http://timg.bdta.pro/images/afe502732252ff5ada6cbb85bdea2aed.jpg'),
(35328, 2437, 'Unbreakable Kimmy Schmidt S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123082.mp4', 'http://timg.bdta.pro/images/56070826d31d6325e5f9dab9f666b103.jpg'),
(35329, 2437, 'Unbreakable Kimmy Schmidt S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123083.mp4', 'http://timg.bdta.pro/images/187f1e66e8b4e7f195771a3f121278ab.jpg'),
(35330, 2437, 'Unbreakable Kimmy Schmidt S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123084.mp4', 'http://timg.bdta.pro/images/39522c426937e9541c0dead6c5baf116.jpg'),
(35331, 2437, 'Unbreakable Kimmy Schmidt S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123085.mp4', 'http://timg.bdta.pro/images/7d77e656dc1c5817eb3041d26d8129bd.jpg'),
(35332, 2437, 'Unbreakable Kimmy Schmidt S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123086.mp4', 'http://timg.bdta.pro/images/8984dcff02f8e9638cbd37f3207fb4c2.jpg'),
(35333, 2437, 'Unbreakable Kimmy Schmidt S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123087.mp4', 'http://timg.bdta.pro/images/b1e6bd91092aa94a3bfb78385c9c3505.jpg'),
(35334, 2437, 'Unbreakable Kimmy Schmidt S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123088.mp4', 'http://timg.bdta.pro/images/7cfaa77adb7e72fde013f3477058863e.jpg'),
(35335, 2437, 'Unbreakable Kimmy Schmidt S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123089.mp4', 'http://timg.bdta.pro/images/42f44f855aa58592a5fd2c4c616bd0ff.jpg'),
(35336, 2437, 'Unbreakable Kimmy Schmidt S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123090.mp4', 'http://timg.bdta.pro/images/55d076edeed3d6a5b70331b12b10e069.jpg'),
(35337, 2437, 'Unbreakable Kimmy Schmidt S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/123091.mp4', 'http://timg.bdta.pro/images/c48ec40b6ddcab28f827f1b6f380942b.jpg'),
(35338, 2437, 'Unbreakable Kimmy Schmidt S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/123092.mp4', 'http://timg.bdta.pro/images/44bc7de7cd2b1bed8a172f41cecef902.jpg'),
(35339, 2437, 'Unbreakable Kimmy Schmidt S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/123093.mp4', 'http://timg.bdta.pro/images/683d04b1bfd2f7c344329fc515b1c3f2.jpg'),
(35340, 2438, 'Unbreakable Kimmy Schmidt S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123094.mp4', 'http://timg.bdta.pro/images/50b389f3e35e8ae6442902a8a7c5cfbf.jpg'),
(35341, 2438, 'Unbreakable Kimmy Schmidt S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123095.mp4', 'http://timg.bdta.pro/images/a8d11305326bd7855ad63234140495ee.jpg'),
(35342, 2438, 'Unbreakable Kimmy Schmidt S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123096.mp4', 'http://timg.bdta.pro/images/e20d0a3307710ded5cee72703d554005.jpg'),
(35343, 2438, 'Unbreakable Kimmy Schmidt S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123097.mp4', 'http://timg.bdta.pro/images/885b79a490000824c6a779c4c459cdd6.jpg'),
(35344, 2438, 'Unbreakable Kimmy Schmidt S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123098.mp4', 'http://timg.bdta.pro/images/61f1c147d57038b0cb2e4ab61175b477.jpg'),
(35345, 2438, 'Unbreakable Kimmy Schmidt S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123099.mp4', 'http://timg.bdta.pro/images/044679a37a6db783eb821603499ba1bf.jpg'),
(35346, 2438, 'Unbreakable Kimmy Schmidt S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123100.mp4', 'http://timg.bdta.pro/images/78850e732037076d1b84635158d81a93.jpg'),
(35347, 2438, 'Unbreakable Kimmy Schmidt S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123101.mp4', 'http://timg.bdta.pro/images/e47bee095f7f9761fc4fe17fd81d244d.jpg'),
(35348, 2438, 'Unbreakable Kimmy Schmidt S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123102.mp4', 'http://timg.bdta.pro/images/e7e7b4680ed23c67ab3eb944099dab8c.jpg'),
(35349, 2438, 'Unbreakable Kimmy Schmidt S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123103.mp4', 'http://timg.bdta.pro/images/a7a3b634d5d797499684129392df1fe0.jpg'),
(35350, 2438, 'Unbreakable Kimmy Schmidt S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/123104.mp4', 'http://timg.bdta.pro/images/ab14ef4d328788edbfc8e2fb646a6537.jpg'),
(35351, 2438, 'Unbreakable Kimmy Schmidt S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/123105.mp4', 'http://timg.bdta.pro/images/5a1ecfb673350f9e2d5dfd851fd846be.jpg'),
(35352, 2438, 'Unbreakable Kimmy Schmidt S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/123106.mp4', 'http://timg.bdta.pro/images/fe619fba35fc542481a96d6d602f4377.jpg'),
(35353, 2439, 'Unbreakable Kimmy Schmidt S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123107.mp4', 'http://timg.bdta.pro/images/615f7f80d489684d708dcacd735a7a65.jpg'),
(35354, 2439, 'Unbreakable Kimmy Schmidt S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123108.mp4', 'http://timg.bdta.pro/images/2a68df0c6232dd8e9356ea838efae5c7.jpg'),
(35355, 2439, 'Unbreakable Kimmy Schmidt S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123109.mp4', 'http://timg.bdta.pro/images/cf821e575363ed3083852cee68a185af.jpg'),
(35356, 2439, 'Unbreakable Kimmy Schmidt S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123110.mp4', 'http://timg.bdta.pro/images/d98a0d88bace5f1712e0371045fccfa9.jpg'),
(35357, 2439, 'Unbreakable Kimmy Schmidt S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123111.mp4', 'http://timg.bdta.pro/images/9de0c5b0ce97aafd3f1b2727512420ac.jpg'),
(35358, 2439, 'Unbreakable Kimmy Schmidt S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123112.mp4', 'http://timg.bdta.pro/images/dbdbc55fd2d67e9816ec80cc1c34a461.jpg'),
(35359, 2439, 'Unbreakable Kimmy Schmidt S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123113.mp4', 'http://timg.bdta.pro/images/f6272f9acd27736b675730239976390f.jpg'),
(35360, 2439, 'Unbreakable Kimmy Schmidt S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123114.mp4', 'http://timg.bdta.pro/images/597e48a7b23d9c8c218b38bb7474f684.jpg'),
(35361, 2439, 'Unbreakable Kimmy Schmidt S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123115.mp4', 'http://timg.bdta.pro/images/c2a4bbf1732ea717fb46b54e10cd8865.jpg'),
(35362, 2439, 'Unbreakable Kimmy Schmidt S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123116.mp4', 'http://timg.bdta.pro/images/2ccafa0852fe9a4103ff74a402cc7d28.jpg'),
(35363, 2439, 'Unbreakable Kimmy Schmidt S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/123117.mp4', 'http://timg.bdta.pro/images/e94a4f44921131f47b580101338d29eb.jpg'),
(35364, 2439, 'Unbreakable Kimmy Schmidt S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/123118.mp4', 'http://timg.bdta.pro/images/0629ce0820da2a2ebe1f3580fdb4f60b.jpg'),
(35365, 2440, 'Wynonna Earp S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251527.mp4', 'http://timg.bdta.pro/images/838fa240790082212957ffd82e590609.jpg'),
(35366, 2440, 'Wynonna Earp S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251528.mp4', 'http://timg.bdta.pro/images/678262741f8c4baa912e9c3a456f5aac.jpg'),
(35367, 2440, 'Wynonna Earp S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251529.mp4', 'http://timg.bdta.pro/images/cf73777c42d0efe015d6f482849e9048.jpg'),
(35368, 2440, 'Wynonna Earp S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251530.mp4', 'http://timg.bdta.pro/images/6b4cecd45d590df1816a5a3c8b5cdbdb.jpg'),
(35369, 2440, 'Wynonna Earp S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251531.mp4', 'http://timg.bdta.pro/images/27d48ec3daee8a4e9254570f2ef62015.jpg'),
(35370, 2440, 'Wynonna Earp S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251532.mp4', 'http://timg.bdta.pro/images/049ebeb2d73fc76acbb66d68183bffc2.jpg'),
(35371, 2440, 'Wynonna Earp S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251533.mp4', 'http://timg.bdta.pro/images/a4c9bceb8da8c42ad0e7a188a99e7c5f.jpg'),
(35372, 2440, 'Wynonna Earp S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251534.mp4', 'http://timg.bdta.pro/images/4f70658c2cf97f2a48997959dfb31a58.jpg'),
(35373, 2440, 'Wynonna Earp S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251535.mp4', 'http://timg.bdta.pro/images/e431df5861b354186887ad3e8437d833.jpg'),
(35374, 2440, 'Wynonna Earp S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251536.mp4', 'http://timg.bdta.pro/images/9ec1dcac6f1aa7d77e3d0d1b3b0b1266.jpg'),
(35375, 2440, 'Wynonna Earp S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251537.mp4', 'http://timg.bdta.pro/images/37867b99c92ff86f2524e1192f46c6a0.jpg'),
(35376, 2440, 'Wynonna Earp S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251538.mp4', 'http://timg.bdta.pro/images/db4dfbae99661be2308b197d79f6c6ce.jpg'),
(35377, 2440, 'Wynonna Earp S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251539.mp4', 'http://timg.bdta.pro/images/d1722b11cb53bf19abc4f2cf5989e85e.jpg'),
(35378, 2441, 'Wynonna Earp S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251540.mp4', 'http://timg.bdta.pro/images/d601de63afdcb5145cfea5a31bd7dc0c.jpg'),
(35379, 2441, 'Wynonna Earp S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251541.mp4', 'http://timg.bdta.pro/images/f48916db35dec7283ebdf5c03d17a96f.jpg'),
(35380, 2441, 'Wynonna Earp S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251542.mp4', 'http://timg.bdta.pro/images/dc7b2c5df472e8a6b1ab53ae44f2a7e5.jpg'),
(35381, 2441, 'Wynonna Earp S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251543.mp4', 'http://timg.bdta.pro/images/a294389d0ef06179acc36f966f6e866d.jpg'),
(35382, 2441, 'Wynonna Earp S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251544.mp4', 'http://timg.bdta.pro/images/dbebcaaaa9dca8882991b11974c18c3f.jpg'),
(35383, 2441, 'Wynonna Earp S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251545.mp4', 'http://timg.bdta.pro/images/b3d7ef177a2344ddf9b89f5749141a8e.jpg'),
(35384, 2441, 'Wynonna Earp S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251546.mp4', 'http://timg.bdta.pro/images/8c96bdbceb6435ace0f575a2d66fd23d.jpg'),
(35385, 2441, 'Wynonna Earp S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251547.mp4', 'http://timg.bdta.pro/images/ba604ea31783a78bd2fd17fce35e145f.jpg'),
(35386, 2441, 'Wynonna Earp S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251548.mp4', 'http://timg.bdta.pro/images/4f73e39a3a1a088a66ff7a85ddecda3e.jpg'),
(35387, 2441, 'Wynonna Earp S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251549.mp4', 'http://timg.bdta.pro/images/a31d6ad7dee29577d13cc59447238f71.jpg'),
(35388, 2441, 'Wynonna Earp S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251550.mp4', 'http://timg.bdta.pro/images/c5c6940b83a82f3eda496110e133b7e6.jpg'),
(35389, 2441, 'Wynonna Earp S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251551.mp4', 'http://timg.bdta.pro/images/4b9f50d175a083ca57037a007db2b593.jpg'),
(35390, 2442, 'Wynonna Earp S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vWdWVdf9tUvq0B0ckZD2RrImjpQ.jpg'),
(35391, 2442, 'Wynonna Earp S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k6jFx7EYBE3Pa2DIHPN1qY1aYoC.jpg'),
(35392, 2442, 'Wynonna Earp S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mHFHLWHokkscsW4pC4WHcZMoqMn.jpg'),
(35393, 2442, 'Wynonna Earp S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sxIfNy4nYTTg9adN0akye7UPKWF.jpg'),
(35394, 2442, 'Wynonna Earp S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rUTiHoE9gSR62EJc4SxBAbuyqUi.jpg'),
(35395, 2442, 'Wynonna Earp S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oGV6ienoURgSVPIA4UIDyCgxFDK.jpg'),
(35396, 2442, 'Wynonna Earp S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zRS4fbsT9W41c7MwnMwsMumGtO9.jpg'),
(35397, 2442, 'Wynonna Earp S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2kW9C939NwAOitqEPpJ9AT1QjtA.jpg'),
(35398, 2442, 'Wynonna Earp S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ka49UmNRfeyCRjrwRnIFBy4Qxw.jpg'),
(35399, 2442, 'Wynonna Earp S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fBFcVeUMuGyL5hmD6J0jvguivkm.jpg'),
(35400, 2442, 'Wynonna Earp S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v1mNV97A93AXMaDuHrNyzxX1zv5.jpg'),
(35401, 2442, 'Wynonna Earp S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o1lqppopdUvdAfGMQptxmFnLXuJ.jpg'),
(35402, 2443, 'XIII: The Series S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123119.mp4', 'http://timg.bdta.pro/images/beaafacd49259ff34a512e2b4cc47efe.jpg'),
(35403, 2443, 'XIII: The Series S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123120.mp4', 'http://timg.bdta.pro/images/fd9b2d103d620b8767b3bbe807491ecb.jpg'),
(35404, 2443, 'XIII: The Series S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123121.mp4', 'http://timg.bdta.pro/images/fb6396dae50911cfd5d309213dbe6561.jpg'),
(35405, 2443, 'XIII: The Series S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123122.mp4', 'http://timg.bdta.pro/images/6956db7282c0082ed29dfab76a2793d4.jpg'),
(35406, 2443, 'XIII: The Series S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123123.mp4', 'http://gstaticontent.com/images/hw8O2D0uWxX8GOOARALcynYNNwu_big.jpg'),
(35407, 2443, 'XIII: The Series S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123124.mp4', 'http://timg.bdta.pro/images/fd7725923d4d3a14701954fef909463e.jpg'),
(35408, 2443, 'XIII: The Series S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123125.mp4', 'http://timg.bdta.pro/images/9e4f0d2ee79c36c6f3fd607feff317b1.jpg'),
(35409, 2443, 'XIII: The Series S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123126.mp4', 'http://timg.bdta.pro/images/a0ab0e330c96db472bd8c8bc6a372b18.jpg'),
(35410, 2443, 'XIII: The Series S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123127.mp4', 'http://timg.bdta.pro/images/cb17ec7f4d8cca0aa3331dae98856bf2.jpg'),
(35411, 2443, 'XIII: The Series S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123128.mp4', 'http://timg.bdta.pro/images/370c4d85a9f68114618e24a3bdd0f6b9.jpg'),
(35412, 2443, 'XIII: The Series S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/123129.mp4', 'http://timg.bdta.pro/images/af2ca1d8b34ec27989c798c52609e32a.jpg'),
(35413, 2443, 'XIII: The Series S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/123130.mp4', 'http://timg.bdta.pro/images/7ac90446cf189f42ba65741a2ada0243.jpg'),
(35414, 2443, 'XIII: The Series S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/123131.mp4', 'http://timg.bdta.pro/images/8367b1296f7a737fb8940fab2c6b7c91.jpg'),
(35415, 2444, 'XIII: The Series S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/123132.mp4', 'http://timg.bdta.pro/images/914a8198c39fa27aeab2bc676f31cb39.jpg'),
(35416, 2444, 'XIII: The Series S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/123133.mp4', 'http://timg.bdta.pro/images/4e540c15e92a3aad9c91297c62be6cc5.jpg'),
(35417, 2444, 'XIII: The Series S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/123134.mp4', 'http://timg.bdta.pro/images/99e3d4c1fd6dd36cc060004204c5b5fd.jpg'),
(35418, 2444, 'XIII: The Series S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/123135.mp4', 'http://timg.bdta.pro/images/d8b43e3bda23fa68dc4bdab0b0e3c2a2.jpg'),
(35419, 2444, 'XIII: The Series S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/123136.mp4', 'http://timg.bdta.pro/images/9e1ab77a55c2fa5ed005a4e08cfdb52d.jpg'),
(35420, 2444, 'XIII: The Series S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/123137.mp4', 'http://timg.bdta.pro/images/3c7dac2101a3d2b667dc05d001867cbd.jpg'),
(35421, 2444, 'XIII: The Series S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/123138.mp4', 'http://timg.bdta.pro/images/04e7d6ac0f04aca767e9811c7d2f4800.jpg'),
(35422, 2444, 'XIII: The Series S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/123139.mp4', 'http://timg.bdta.pro/images/baaff500c9ecc3bc1b69a1d1ba7c8085.jpg'),
(35423, 2444, 'XIII: The Series S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/123140.mp4', 'http://timg.bdta.pro/images/5b7a9f553634b05302694830fe1be6a5.jpg'),
(35424, 2444, 'XIII: The Series S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/123141.mp4', 'http://timg.bdta.pro/images/01164dc5cda3a7eabd41ceebddc282a6.jpg'),
(35425, 2444, 'XIII: The Series S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/123142.mp4', 'http://timg.bdta.pro/images/6384415e332caaa1ca43adbc981ab7ec.jpg'),
(35426, 2444, 'XIII: The Series S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/123143.mp4', 'http://timg.bdta.pro/images/2852d0cd727feae6457dda4ca19d80a8.jpg'),
(35427, 2444, 'XIII: The Series S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/123144.mp4', 'http://timg.bdta.pro/images/4b9393cfdf640bfd357052bbb2e8dff5.jpg'),
(35428, 2445, 'Dont Look Deeper [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129859.mp4', 'http://timg.bdta.pro/images/d4e59b82473b171462a4fec064271afe.jpg'),
(35429, 2445, 'Dont Look Deeper [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129860.mp4', 'http://timg.bdta.pro/images/b1197d8fde8597ea3253d24ee859fb0b.jpg'),
(35430, 2445, 'Dont Look Deeper [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129861.mp4', 'http://timg.bdta.pro/images/92948fb8cfd21a4d49fd93f1ce297774.jpg'),
(35431, 2445, 'Dont Look Deeper [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129862.mp4', 'http://timg.bdta.pro/images/c70d680e67450511e20eeac348208dee.jpg'),
(35432, 2445, 'Dont Look Deeper [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129863.mp4', 'http://timg.bdta.pro/images/32f967a1ef8a0126f5ebc3ec327eaafa.jpg'),
(35433, 2445, 'Dont Look Deeper [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129864.mp4', 'http://timg.bdta.pro/images/d5c6596688b9a8a543b12bb8acbc2398.jpg'),
(35434, 2445, 'Dont Look Deeper [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129865.mp4', 'http://timg.bdta.pro/images/0fb84a6b028e6d7be96ee1af64e7d819.jpg'),
(35435, 2445, 'Dont Look Deeper [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129866.mp4', 'http://timg.bdta.pro/images/32bff4dc893c681c271376d116d63331.jpg'),
(35436, 2445, 'Dont Look Deeper [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129867.mp4', 'http://timg.bdta.pro/images/418f0c5dc25bdfa539e1b2ff5219dd8d.jpg'),
(35437, 2445, 'Dont Look Deeper [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129868.mp4', 'http://timg.bdta.pro/images/4d89029cdb4d0a5f4e5dcdea28b02ca1.jpg'),
(35438, 2445, 'Dont Look Deeper [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129869.mp4', 'http://timg.bdta.pro/images/d60a11e333c63c2fa52a9334ccca7fe5.jpg'),
(35439, 2445, 'Dont Look Deeper [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129870.mp4', 'http://timg.bdta.pro/images/0a4c44533ab23b722b4256f718be320e.jpg'),
(35440, 2445, 'Dont Look Deeper [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129871.mp4', 'http://timg.bdta.pro/images/19274a17fde2f588a0e62cc7c0e05dd4.jpg'),
(35441, 2445, 'Dont Look Deeper [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129872.mp4', 'http://timg.bdta.pro/images/880d01b466bd043dda25747bf3876622.jpg'),
(35442, 2446, 'Legendary [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175693.mp4', 'http://timg.bdta.pro/images/8030213396f0f767f018588b72e63829.jpg'),
(35443, 2446, 'Legendary [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175694.mp4', 'http://timg.bdta.pro/images/f601d61a286e93711b95c01f6b9c86cc.jpg'),
(35444, 2446, 'Legendary [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175695.mp4', 'http://timg.bdta.pro/images/eeaaeb9c06b904f7a3ad61f14a70c222.jpg'),
(35445, 2446, 'Legendary [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175696.mp4', 'http://timg.bdta.pro/images/7ff466d8ae26d2e770ee5b14d2f2de22.jpg'),
(35446, 2446, 'Legendary [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175697.mp4', 'http://timg.bdta.pro/images/ace1343982bc807e0e12d326d143ffbd.jpg'),
(35447, 2446, 'Legendary [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175698.mp4', 'http://timg.bdta.pro/images/bffb1b5f0cb25844a00bab90f5956c2d.jpg'),
(35448, 2446, 'Legendary [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175699.mp4', 'http://timg.bdta.pro/images/36a589d48b3377128f626354f8d22cd3.jpg'),
(35449, 2446, 'Legendary [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175700.mp4', 'http://timg.bdta.pro/images/05ad65c056c35f1a4eb064113a6c8e8f.jpg'),
(35450, 2446, 'Legendary [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/175701.mp4', 'http://timg.bdta.pro/images/6a16c62183752985a72dda84c8e5305d.jpg'),
(35451, 2447, 'Legendary [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175702.mp4', 'http://timg.bdta.pro/images/922ec6b3656cf7578c4d19769a9b4ff3.jpg'),
(35452, 2447, 'Legendary [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175703.mp4', 'http://timg.bdta.pro/images/0c4359e2a9fcac8112ad55c3a76e721f.jpg'),
(35453, 2447, 'Legendary [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175704.mp4', 'http://timg.bdta.pro/images/01e1dcc4ccc82a80b19a1ea9fd197d41.jpg'),
(35454, 2447, 'Legendary [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175705.mp4', 'http://timg.bdta.pro/images/e95d0de38e93e73c41b1d072ea24227a.jpg'),
(35455, 2447, 'Legendary [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175706.mp4', 'http://timg.bdta.pro/images/b675588cb905fe77fdca9c2ed8056e65.jpg'),
(35456, 2447, 'Legendary [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175707.mp4', 'http://timg.bdta.pro/images/36e733579ffd1c3f21d23ed7f2316273.jpg'),
(35457, 2447, 'Legendary [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175708.mp4', 'http://timg.bdta.pro/images/508ad19eb1c223afc0378a2c9e065751.jpg'),
(35458, 2447, 'Legendary [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175709.mp4', 'http://timg.bdta.pro/images/136dedf9c1232e8e362325e53b827e30.jpg'),
(35459, 2447, 'Legendary [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/175710.mp4', 'http://timg.bdta.pro/images/6f1ad37d951fa651a7bb93b8e154ff1c.jpg'),
(35460, 2447, 'Legendary [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/175711.mp4', 'http://timg.bdta.pro/images/6e3d554b57216bc8bade53969c1cca2a.jpg'),
(35461, 2448, 'Barrados no Baile Nova Geracao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129745.mp4', 'http://timg.bdta.pro/images/037a0a21288b07b6c33bdcad0e631280.jpg'),
(35462, 2448, 'Barrados no Baile Nova Geracao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129746.mp4', 'http://timg.bdta.pro/images/78109b7f52914b972e8aa221630e6b48.jpg'),
(35463, 2448, 'Barrados no Baile Nova Geracao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129747.mp4', 'http://timg.bdta.pro/images/506ab127746eeb97f59abf9c29c4f2a9.jpg'),
(35464, 2448, 'Barrados no Baile Nova Geracao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129748.mp4', 'http://timg.bdta.pro/images/1e7c1019f0341a99f54125e2639b0b09.jpg'),
(35465, 2448, 'Barrados no Baile Nova Geracao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129749.mp4', 'http://timg.bdta.pro/images/8afbd5686ecaac0c5467575c34b82284.jpg'),
(35466, 2448, 'Barrados no Baile Nova Geracao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129750.mp4', 'http://timg.bdta.pro/images/d33857ed1f3bfbedb54817200f3c42bf.jpg'),
(35467, 2448, 'Barrados no Baile Nova Geracao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129751.mp4', 'http://timg.bdta.pro/images/c55594c5c3de1ed2e935caab080b1305.jpg'),
(35468, 2448, 'Barrados no Baile Nova Geracao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129752.mp4', 'http://timg.bdta.pro/images/035f5d728e20fdbb370f0971f185e951.jpg'),
(35469, 2448, 'Barrados no Baile Nova Geracao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129753.mp4', 'http://timg.bdta.pro/images/5610ddb4f529c8dec853adb091e2d9fa.jpg'),
(35470, 2448, 'Barrados no Baile Nova Geracao S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129754.mp4', 'http://timg.bdta.pro/images/e8301f125261c22ffb6c6834f8683075.jpg'),
(35471, 2448, 'Barrados no Baile Nova Geracao S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129755.mp4', 'http://timg.bdta.pro/images/5881190e4c054512a571cbdab3693f6d.jpg'),
(35472, 2448, 'Barrados no Baile Nova Geracao S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129756.mp4', 'http://timg.bdta.pro/images/a8eff7e2a73defde0fcbce83da61d2a8.jpg'),
(35473, 2448, 'Barrados no Baile Nova Geracao S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129757.mp4', 'http://timg.bdta.pro/images/c6ca9fcc6606c849cce8b176c6a6a54c.jpg'),
(35474, 2448, 'Barrados no Baile Nova Geracao S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129758.mp4', 'http://timg.bdta.pro/images/bea6a4a097aaee2a456a7f765563430e.jpg'),
(35475, 2448, 'Barrados no Baile Nova Geracao S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129759.mp4', 'http://timg.bdta.pro/images/4b9940f42f8de7d15289e54b0406641d.jpg'),
(35476, 2448, 'Barrados no Baile Nova Geracao S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129760.mp4', 'http://timg.bdta.pro/images/73ee24fbb69c9fc13f5c416f43e0bba5.jpg'),
(35477, 2448, 'Barrados no Baile Nova Geracao S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129761.mp4', 'http://timg.bdta.pro/images/d2a550ab08be05d1fb341d4a104107e5.jpg'),
(35478, 2448, 'Barrados no Baile Nova Geracao S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129762.mp4', 'http://timg.bdta.pro/images/dc866484164212c4cdb7ca36c05c2b07.jpg'),
(35479, 2448, 'Barrados no Baile Nova Geracao S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129763.mp4', 'http://timg.bdta.pro/images/fbb9f44bb76f10cb39cf3c3a7933af59.jpg'),
(35480, 2448, 'Barrados no Baile Nova Geracao S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129764.mp4', 'http://timg.bdta.pro/images/70c3eb8677b968d34f5215234d83f1bc.jpg'),
(35481, 2448, 'Barrados no Baile Nova Geracao S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129765.mp4', 'http://timg.bdta.pro/images/872b16bd9c88430abf93de1cf1a2258f.jpg'),
(35482, 2448, 'Barrados no Baile Nova Geracao S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129766.mp4', 'http://timg.bdta.pro/images/d45a4ed9444176bd8e0056c34d722a2d.jpg'),
(35483, 2448, 'Barrados no Baile Nova Geracao S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/129767.mp4', 'http://timg.bdta.pro/images/9468ed9fa485460d21ca90603226f456.jpg'),
(35484, 2448, 'Barrados no Baile Nova Geracao S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/129768.mp4', 'http://timg.bdta.pro/images/acc4cf5ea8bcc5ca63f417ce7f84040d.jpg'),
(35485, 2449, 'Barrados no Baile Nova Geracao S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129769.mp4', 'http://timg.bdta.pro/images/d278a3e6628f1cdc50352d230c8a514a.jpg'),
(35486, 2449, 'Barrados no Baile Nova Geracao S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129770.mp4', 'http://timg.bdta.pro/images/d0829237c6cb052bb2c73340691bd49c.jpg'),
(35487, 2449, 'Barrados no Baile Nova Geracao S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129771.mp4', 'http://timg.bdta.pro/images/6e90f827547ff3447075f13fd51090f1.jpg'),
(35488, 2449, 'Barrados no Baile Nova Geracao S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129772.mp4', 'http://timg.bdta.pro/images/8349b55afe6fe651acc4ed67f06f60e4.jpg'),
(35489, 2449, 'Barrados no Baile Nova Geracao S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129773.mp4', 'http://timg.bdta.pro/images/40bf70ea6a980095211e3867381c9d03.jpg'),
(35490, 2449, 'Barrados no Baile Nova Geracao S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129774.mp4', 'http://timg.bdta.pro/images/360b46a298537a07df8d5bf7820ed39d.jpg'),
(35491, 2449, 'Barrados no Baile Nova Geracao S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129775.mp4', 'http://timg.bdta.pro/images/5acf0025210681a145b4fe9a6fdc5d25.jpg'),
(35492, 2449, 'Barrados no Baile Nova Geracao S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129776.mp4', 'http://timg.bdta.pro/images/f974dc47bda52f5e8056146291aa8534.jpg'),
(35493, 2449, 'Barrados no Baile Nova Geracao S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129777.mp4', 'http://timg.bdta.pro/images/c792800a202ab9945acfcde0433fee1b.jpg'),
(35494, 2449, 'Barrados no Baile Nova Geracao S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129778.mp4', 'http://timg.bdta.pro/images/7b78191689217af63dea9401f6234a8c.jpg'),
(35495, 2449, 'Barrados no Baile Nova Geracao S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129779.mp4', 'http://timg.bdta.pro/images/245cb2f6fb8e412c3fd4f1c19b474fb6.jpg'),
(35496, 2449, 'Barrados no Baile Nova Geracao S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129780.mp4', 'http://timg.bdta.pro/images/ae9358d8d4e2690a93db98aa286c4512.jpg'),
(35497, 2449, 'Barrados no Baile Nova Geracao S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129781.mp4', 'http://timg.bdta.pro/images/aa3d44a7e16989fd7f3f27d7469b3c31.jpg'),
(35498, 2449, 'Barrados no Baile Nova Geracao S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129782.mp4', 'http://timg.bdta.pro/images/35ec900ec74417dbbfcd305ca1d387cd.jpg'),
(35499, 2449, 'Barrados no Baile Nova Geracao S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129783.mp4', 'http://timg.bdta.pro/images/5f754a85d317a27429f71e18833cb246.jpg'),
(35500, 2449, 'Barrados no Baile Nova Geracao S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129784.mp4', 'http://timg.bdta.pro/images/c7af187947dbb0e6fe50cf5ce497465c.jpg'),
(35501, 2449, 'Barrados no Baile Nova Geracao S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129785.mp4', 'http://timg.bdta.pro/images/50033271cc7a7d2c2459cf2f54a82f58.jpg'),
(35502, 2449, 'Barrados no Baile Nova Geracao S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129786.mp4', 'http://timg.bdta.pro/images/d98419d09d42ae288d7aa7794621d98d.jpg'),
(35503, 2449, 'Barrados no Baile Nova Geracao S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129787.mp4', 'http://timg.bdta.pro/images/7fb5fe76d374ead93a25f9b5e879650a.jpg'),
(35504, 2449, 'Barrados no Baile Nova Geracao S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129788.mp4', 'http://timg.bdta.pro/images/3f28b17e7cc391cc749d6d0d912b9d19.jpg'),
(35505, 2449, 'Barrados no Baile Nova Geracao S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129789.mp4', 'http://timg.bdta.pro/images/63bc5bb55c9e57081834d6d44ac45c3d.jpg'),
(35506, 2449, 'Barrados no Baile Nova Geracao S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129790.mp4', 'http://timg.bdta.pro/images/3dbc5334c7b9c21a756a4b9e7d113b1c.jpg'),
(35507, 2450, 'Barrados no Baile Nova Geracao S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129791.mp4', 'http://timg.bdta.pro/images/da337d3da77c329b8faf15e5abcb5ffd.jpg'),
(35508, 2450, 'Barrados no Baile Nova Geracao S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129792.mp4', 'http://timg.bdta.pro/images/d187af102bc1e1f46332ef612c14a367.jpg'),
(35509, 2450, 'Barrados no Baile Nova Geracao S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129793.mp4', 'http://timg.bdta.pro/images/939fad4627e1006fefcc0229e48bf4fe.jpg'),
(35510, 2450, 'Barrados no Baile Nova Geracao S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129794.mp4', 'http://timg.bdta.pro/images/a146f24e2edc65a2248af6e68a0211c9.jpg'),
(35511, 2450, 'Barrados no Baile Nova Geracao S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129795.mp4', 'http://timg.bdta.pro/images/67299667f04f64d6fcc69793f5e818b2.jpg'),
(35512, 2450, 'Barrados no Baile Nova Geracao S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129796.mp4', 'http://timg.bdta.pro/images/809ca6d24f81bd2950967e8efac6d8dd.jpg'),
(35513, 2450, 'Barrados no Baile Nova Geracao S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129797.mp4', 'http://timg.bdta.pro/images/44830165f9e92e2e5013ed74c2b0739c.jpg'),
(35514, 2450, 'Barrados no Baile Nova Geracao S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129798.mp4', 'http://timg.bdta.pro/images/5de1e43fcf764b3e3b85937dfd19430d.jpg'),
(35515, 2450, 'Barrados no Baile Nova Geracao S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129799.mp4', 'http://timg.bdta.pro/images/5e58c27e1b780adfc67cfaaf98292d92.jpg'),
(35516, 2450, 'Barrados no Baile Nova Geracao S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129800.mp4', 'http://timg.bdta.pro/images/964626d57b457f3f6d038e0e839fdedc.jpg'),
(35517, 2450, 'Barrados no Baile Nova Geracao S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129801.mp4', 'http://timg.bdta.pro/images/1e385a8f4e1f0b885e9a24e589d8ed88.jpg'),
(35518, 2450, 'Barrados no Baile Nova Geracao S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129802.mp4', 'http://timg.bdta.pro/images/b0ae7535dc3eec6944aeafde49e222d8.jpg'),
(35519, 2450, 'Barrados no Baile Nova Geracao S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129803.mp4', 'http://timg.bdta.pro/images/069669455b7599daaeb0bca979c8cf9c.jpg'),
(35520, 2450, 'Barrados no Baile Nova Geracao S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129804.mp4', 'http://timg.bdta.pro/images/fc83e151fe5c21a0afa97ce703625c21.jpg'),
(35521, 2450, 'Barrados no Baile Nova Geracao S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129805.mp4', 'http://timg.bdta.pro/images/19c881147941dd27f87a6476ff8e5fd9.jpg'),
(35522, 2450, 'Barrados no Baile Nova Geracao S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129806.mp4', 'http://timg.bdta.pro/images/b6e095bcfd1b110ad457aa5603009b1d.jpg'),
(35523, 2450, 'Barrados no Baile Nova Geracao S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129807.mp4', 'http://timg.bdta.pro/images/7700ddbe5d02b26858b5abe6279006c6.jpg'),
(35524, 2450, 'Barrados no Baile Nova Geracao S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129808.mp4', 'http://timg.bdta.pro/images/7f7cb7d5cdd1d6e6ac8c864718f6c204.jpg'),
(35525, 2450, 'Barrados no Baile Nova Geracao S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129809.mp4', 'http://timg.bdta.pro/images/f50b25a46efe11ab29ed0af56cf295b3.jpg'),
(35526, 2450, 'Barrados no Baile Nova Geracao S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129810.mp4', 'http://timg.bdta.pro/images/af7f1cac376c106ba74cd8acf68e31a4.jpg'),
(35527, 2450, 'Barrados no Baile Nova Geracao S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129811.mp4', 'http://timg.bdta.pro/images/7ca82a048fd3c45c9b2ebc679b5358eb.jpg'),
(35528, 2450, 'Barrados no Baile Nova Geracao S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129812.mp4', 'http://timg.bdta.pro/images/549ec19a4a71867a38918e9ea0d831ed.jpg'),
(35529, 2451, 'Barrados no Baile Nova Geracao S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129813.mp4', 'http://timg.bdta.pro/images/9d8d36ee5663a0a49dc0eea297d43494.jpg'),
(35530, 2451, 'Barrados no Baile Nova Geracao S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129814.mp4', 'http://timg.bdta.pro/images/7329df261b46f869513760c03cc11bd3.jpg'),
(35531, 2451, 'Barrados no Baile Nova Geracao S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129815.mp4', 'http://timg.bdta.pro/images/d38bfe7ff92754e9202f90d54f925e8f.jpg'),
(35532, 2451, 'Barrados no Baile Nova Geracao S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129816.mp4', 'http://timg.bdta.pro/images/5e743ed8fb0520685a743767705db52b.jpg'),
(35533, 2451, 'Barrados no Baile Nova Geracao S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129817.mp4', 'http://timg.bdta.pro/images/5c4b70e0da23bd59f71f03d993037943.jpg'),
(35534, 2451, 'Barrados no Baile Nova Geracao S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129818.mp4', 'http://timg.bdta.pro/images/87ddb9778c66dfbd580af3a5866e50ed.jpg'),
(35535, 2451, 'Barrados no Baile Nova Geracao S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129819.mp4', 'http://timg.bdta.pro/images/9fa18fda9306c8193c5036997c2f503c.jpg'),
(35536, 2451, 'Barrados no Baile Nova Geracao S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129820.mp4', 'http://timg.bdta.pro/images/bb3734b90e5c0f70344ee17143ef060f.jpg'),
(35537, 2451, 'Barrados no Baile Nova Geracao S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129821.mp4', 'http://timg.bdta.pro/images/9b4eeae22a605e3a02215d90eb119a0e.jpg'),
(35538, 2451, 'Barrados no Baile Nova Geracao S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129822.mp4', 'http://timg.bdta.pro/images/465042ab657728f7a957cdad5b0e588d.jpg'),
(35539, 2451, 'Barrados no Baile Nova Geracao S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129823.mp4', 'http://timg.bdta.pro/images/e36c1bc75b4f34824a9cc645194d440f.jpg'),
(35540, 2451, 'Barrados no Baile Nova Geracao S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129824.mp4', 'http://timg.bdta.pro/images/5e0f1d198362984bfdd3b6b5a40153f6.jpg'),
(35541, 2451, 'Barrados no Baile Nova Geracao S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129825.mp4', 'http://timg.bdta.pro/images/f79c592d2f92010394a426d34216b11c.jpg'),
(35542, 2451, 'Barrados no Baile Nova Geracao S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129826.mp4', 'http://timg.bdta.pro/images/1eda418e1af5a9e6b31f08a3942d7cdf.jpg'),
(35543, 2451, 'Barrados no Baile Nova Geracao S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129827.mp4', 'http://timg.bdta.pro/images/60f6ee9859b61d1f5a8122648887c900.jpg'),
(35544, 2451, 'Barrados no Baile Nova Geracao S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129828.mp4', 'http://timg.bdta.pro/images/2cef6978a68acaef69e9c8764ca7e0e5.jpg'),
(35545, 2451, 'Barrados no Baile Nova Geracao S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129829.mp4', 'http://timg.bdta.pro/images/dc04eef4c62fea64e269dbc890af5638.jpg'),
(35546, 2451, 'Barrados no Baile Nova Geracao S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129830.mp4', 'http://timg.bdta.pro/images/220954874864ac66be36520731b757f2.jpg'),
(35547, 2451, 'Barrados no Baile Nova Geracao S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129831.mp4', 'http://timg.bdta.pro/images/5caa8b4d0f3b63034977743fcfc731c0.jpg'),
(35548, 2451, 'Barrados no Baile Nova Geracao S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129832.mp4', 'http://timg.bdta.pro/images/01b18d7deae7aa0d50bd18d77702fad4.jpg'),
(35549, 2451, 'Barrados no Baile Nova Geracao S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129833.mp4', 'http://timg.bdta.pro/images/e38b80d82dec62806c5075352b658822.jpg'),
(35550, 2451, 'Barrados no Baile Nova Geracao S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129834.mp4', 'http://timg.bdta.pro/images/ae6554e9cbecdf2132769cfb8d6727dd.jpg'),
(35551, 2451, 'Barrados no Baile Nova Geracao S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/129835.mp4', 'http://timg.bdta.pro/images/88d6ad26e91b238a87a1edc13d1f4c88.jpg'),
(35552, 2451, 'Barrados no Baile Nova Geracao S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/129836.mp4', 'http://timg.bdta.pro/images/4288ab6cb3052ca03827e621ab594bec.jpg'),
(35553, 2452, 'Barrados no Baile Nova Geracao S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129837.mp4', 'http://timg.bdta.pro/images/3046c942810f9f5027a1654104477c1b.jpg'),
(35554, 2452, 'Barrados no Baile Nova Geracao S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129838.mp4', 'http://timg.bdta.pro/images/b85d83f7b6e06bffe001e8de2bc24b4d.jpg'),
(35555, 2452, 'Barrados no Baile Nova Geracao S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129839.mp4', 'http://timg.bdta.pro/images/79bd86d0bd33b250792c5ff9fecc5dfb.jpg'),
(35556, 2452, 'Barrados no Baile Nova Geracao S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129840.mp4', 'http://timg.bdta.pro/images/9618c341c9939fd189e4029aff0dbeb5.jpg'),
(35557, 2452, 'Barrados no Baile Nova Geracao S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129841.mp4', 'http://timg.bdta.pro/images/119ce1c762643123642ae7ca7f90062e.jpg'),
(35558, 2452, 'Barrados no Baile Nova Geracao S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129842.mp4', 'http://timg.bdta.pro/images/4a43b865469cd1781ced78541fb7a8d4.jpg'),
(35559, 2452, 'Barrados no Baile Nova Geracao S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129843.mp4', 'http://timg.bdta.pro/images/70d1194bbacf273d9217f6ededc8f352.jpg'),
(35560, 2452, 'Barrados no Baile Nova Geracao S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129844.mp4', 'http://timg.bdta.pro/images/2ef9585e38d3a1a65c4c1a50adc35e69.jpg'),
(35561, 2452, 'Barrados no Baile Nova Geracao S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129845.mp4', 'http://timg.bdta.pro/images/536f3f64eddae74259d707b1c78a139c.jpg'),
(35562, 2452, 'Barrados no Baile Nova Geracao S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129846.mp4', 'http://timg.bdta.pro/images/a795ad3b29dda6c346e991bcb95df49b.jpg'),
(35563, 2452, 'Barrados no Baile Nova Geracao S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129847.mp4', 'http://timg.bdta.pro/images/1c2b547f60899770cd9ddb6ce3cbb74e.jpg'),
(35564, 2452, 'Barrados no Baile Nova Geracao S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129848.mp4', 'http://timg.bdta.pro/images/38e5aa4357216323417a22fe0954cd88.jpg'),
(35565, 2452, 'Barrados no Baile Nova Geracao S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129849.mp4', 'http://timg.bdta.pro/images/92bd94ee6432d4d737dd146f5bc45532.jpg'),
(35566, 2452, 'Barrados no Baile Nova Geracao S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129850.mp4', 'http://timg.bdta.pro/images/89e742e47b248c654e2c7b755402554a.jpg'),
(35567, 2452, 'Barrados no Baile Nova Geracao S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129851.mp4', 'http://timg.bdta.pro/images/fb95d693d6256e886bea4553b2ed4ce1.jpg'),
(35568, 2452, 'Barrados no Baile Nova Geracao S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129852.mp4', 'http://timg.bdta.pro/images/cbeb4713f73e11577ec52c632afc34bd.jpg'),
(35569, 2452, 'Barrados no Baile Nova Geracao S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129853.mp4', 'http://timg.bdta.pro/images/e82fc06c495b2737cd1704aefe4213be.jpg'),
(35570, 2452, 'Barrados no Baile Nova Geracao S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129854.mp4', 'http://timg.bdta.pro/images/3c3fecb525ad1c62c247c90813fcce8f.jpg'),
(35571, 2452, 'Barrados no Baile Nova Geracao S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129855.mp4', 'http://timg.bdta.pro/images/97edb1f5b1f51d67291c9df262c3c7e5.jpg'),
(35572, 2452, 'Barrados no Baile Nova Geracao S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129856.mp4', 'http://timg.bdta.pro/images/77ecec5bb26440ceceecfc0f7db60167.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(35573, 2452, 'Barrados no Baile Nova Geracao S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129857.mp4', 'http://timg.bdta.pro/images/26769e1a0a8f99f09cd273c4fa680518.jpg'),
(35574, 2452, 'Barrados no Baile Nova Geracao S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129858.mp4', 'http://timg.bdta.pro/images/7ca69367f0b390ca7b8923f372bd2a64.jpg'),
(35575, 2453, 'Biohackers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152189.mp4', 'http://timg.bdta.pro/images/93178e48a10364431ca4d172a6ef522f.jpg'),
(35576, 2453, 'Biohackers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152190.mp4', 'http://timg.bdta.pro/images/ec83d1c6487afb8aaa523c9de9be007c.jpg'),
(35577, 2453, 'Biohackers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152191.mp4', 'http://timg.bdta.pro/images/60f99dc80813fc1e2ee678f995a5696b.jpg'),
(35578, 2453, 'Biohackers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152192.mp4', 'http://timg.bdta.pro/images/2afb9834d5fd0976f12506f1487f0f11.jpg'),
(35579, 2453, 'Biohackers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152193.mp4', 'http://timg.bdta.pro/images/ca661813f73e63f95719e67d25771280.jpg'),
(35580, 2453, 'Biohackers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152194.mp4', 'http://timg.bdta.pro/images/0cc1ab24cb25f4e93b44459b8a042749.jpg'),
(35581, 2454, 'Biohackers S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152195.mp4', 'http://timg.bdta.pro/images/de9d34f686d1a1cf25839933ea86dfcc.jpg'),
(35582, 2454, 'Biohackers S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152196.mp4', 'http://timg.bdta.pro/images/22d4ef0b9bc2f3bf332b7ac5ce1a2b8d.jpg'),
(35583, 2454, 'Biohackers S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152197.mp4', 'http://timg.bdta.pro/images/21d222f7e660792852fad572e68681d3.jpg'),
(35584, 2454, 'Biohackers S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152198.mp4', 'http://timg.bdta.pro/images/72a1dc991f9bb28cd30c892a6e016120.jpg'),
(35585, 2454, 'Biohackers S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152199.mp4', 'http://timg.bdta.pro/images/d32a3c61fddf22a9b52ba9c54894019e.jpg'),
(35586, 2454, 'Biohackers S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152200.mp4', 'http://timg.bdta.pro/images/4ae704387219575a06d43a96141edeee.jpg'),
(35587, 2455, 'Get Shorty: A Máfia do Cinema S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129718.mp4', 'http://timg.bdta.pro/images/14322b99c70651e43bb1f12549bc2e68.jpg'),
(35588, 2455, 'Get Shorty: A Máfia do Cinema S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129719.mp4', 'http://timg.bdta.pro/images/c7364198368e537446db8158d24dfd58.jpg'),
(35589, 2455, 'Get Shorty: A Máfia do Cinema S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129720.mp4', 'http://timg.bdta.pro/images/f5f4147f08bf185af5f11ebc2889bfc3.jpg'),
(35590, 2455, 'Get Shorty: A Máfia do Cinema S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129721.mp4', 'http://timg.bdta.pro/images/51844683023faf8f123a7b1418f089c0.jpg'),
(35591, 2455, 'Get Shorty: A Máfia do Cinema S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129722.mp4', 'http://timg.bdta.pro/images/c145ad3d615acca0aa15817ece33b222.jpg'),
(35592, 2455, 'Get Shorty: A Máfia do Cinema S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129723.mp4', 'http://timg.bdta.pro/images/ecb08d24669995cea384441c85fe0ee4.jpg'),
(35593, 2455, 'Get Shorty: A Máfia do Cinema S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129724.mp4', 'http://timg.bdta.pro/images/0874f1f250f0276ad01e1ecf7a58e0fb.jpg'),
(35594, 2455, 'Get Shorty: A Máfia do Cinema S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129725.mp4', 'http://timg.bdta.pro/images/86acaf1bfcfbaec1fb7ea567029d601e.jpg'),
(35595, 2455, 'Get Shorty: A Máfia do Cinema S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129726.mp4', 'http://timg.bdta.pro/images/13e8ec8ed88c6c4632f48ecc490de620.jpg'),
(35596, 2455, 'Get Shorty: A Máfia do Cinema S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129727.mp4', 'http://timg.bdta.pro/images/a9ad5cd3a0d740052747eae7c358b56a.jpg'),
(35597, 2456, 'Get Shorty: A Máfia do Cinema S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129728.mp4', 'http://timg.bdta.pro/images/0315b827489e3dcaa98b92f40c86899b.jpg'),
(35598, 2456, 'Get Shorty: A Máfia do Cinema S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129729.mp4', 'http://timg.bdta.pro/images/1865df7eec16fd5bd84c61904dcca6bc.jpg'),
(35599, 2456, 'Get Shorty: A Máfia do Cinema S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129730.mp4', 'http://timg.bdta.pro/images/4f99bd324097a1d95603d43abc65f51e.jpg'),
(35600, 2456, 'Get Shorty: A Máfia do Cinema S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129731.mp4', 'http://timg.bdta.pro/images/cb36931e10d9c58e1dcd75e089f932ec.jpg'),
(35601, 2456, 'Get Shorty: A Máfia do Cinema S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129732.mp4', 'http://timg.bdta.pro/images/0cf1394e6baafd9837d7ac5e44be53a9.jpg'),
(35602, 2456, 'Get Shorty: A Máfia do Cinema S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129733.mp4', 'http://timg.bdta.pro/images/758660a2d90f057ec808062fd5dbdca6.jpg'),
(35603, 2456, 'Get Shorty: A Máfia do Cinema S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129734.mp4', 'http://timg.bdta.pro/images/cefc233f0cbe84aa6e99c0327251e7c5.jpg'),
(35604, 2456, 'Get Shorty: A Máfia do Cinema S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129735.mp4', 'http://timg.bdta.pro/images/362cf7632167afe49074107203b6af8e.jpg'),
(35605, 2456, 'Get Shorty: A Máfia do Cinema S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129736.mp4', 'http://timg.bdta.pro/images/638f34171d0977daedc1d742ea483d1e.jpg'),
(35606, 2456, 'Get Shorty: A Máfia do Cinema S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129737.mp4', 'http://timg.bdta.pro/images/702568437749727384f29e1dc0575505.jpg'),
(35607, 2457, 'Get Shorty: A Máfia do Cinema S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129738.mp4', 'http://timg.bdta.pro/images/bb429e681b9b102f4744e9cb56335dce.jpg'),
(35608, 2457, 'Get Shorty: A Máfia do Cinema S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129739.mp4', 'http://timg.bdta.pro/images/b00548af26e0f3fdb432f68bf44723fd.jpg'),
(35609, 2457, 'Get Shorty: A Máfia do Cinema S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129740.mp4', 'http://timg.bdta.pro/images/5b992b454eddd03f452d8f562190971a.jpg'),
(35610, 2457, 'Get Shorty: A Máfia do Cinema S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129741.mp4', 'http://timg.bdta.pro/images/e28b6a106df196ba3aa62a5968f8605e.jpg'),
(35611, 2457, 'Get Shorty: A Máfia do Cinema S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129742.mp4', 'http://timg.bdta.pro/images/938c240813f33d31eadb05f7de1d5e91.jpg'),
(35612, 2457, 'Get Shorty: A Máfia do Cinema S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129743.mp4', 'http://timg.bdta.pro/images/fb23f69a57741f23c47a8bb381b8c609.jpg'),
(35613, 2457, 'Get Shorty: A Máfia do Cinema S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129744.mp4', 'http://timg.bdta.pro/images/34a0519b672243f9be2517ef8727b65a.jpg'),
(35614, 2458, 'Nip Tuck S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129631.mp4', 'http://timg.bdta.pro/images/181e865e0bde02df682401fe6101590f.jpg'),
(35615, 2458, 'Nip Tuck S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129632.mp4', 'http://timg.bdta.pro/images/d165838d318c050b0ef3df6ae1fd5790.jpg'),
(35616, 2458, 'Nip Tuck S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129633.mp4', 'http://timg.bdta.pro/images/ba0da6e3af9f96c87b565bd1902f9a1f.jpg'),
(35617, 2458, 'Nip Tuck S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129634.mp4', 'http://timg.bdta.pro/images/2444cf35771470fcc9f4cb4ecf22c17e.jpg'),
(35618, 2458, 'Nip Tuck S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129635.mp4', 'http://timg.bdta.pro/images/9722f51f2f8f16442b6e2ee143a5c627.jpg'),
(35619, 2458, 'Nip Tuck S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129636.mp4', 'http://timg.bdta.pro/images/a122d599d8ee3b45a44ccfba59d33dd2.jpg'),
(35620, 2458, 'Nip Tuck S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129637.mp4', 'http://timg.bdta.pro/images/62eb4433f66f3d9a317be086339338a3.jpg'),
(35621, 2458, 'Nip Tuck S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129638.mp4', 'http://timg.bdta.pro/images/b2b587cde4019ff6237ad4ecc8042383.jpg'),
(35622, 2458, 'Nip Tuck S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129639.mp4', 'http://timg.bdta.pro/images/882898398c2bcc547c5cf71480ee5ee2.jpg'),
(35623, 2458, 'Nip Tuck S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129640.mp4', 'http://timg.bdta.pro/images/8ccef9ec661196988aa4717487d0e7e1.jpg'),
(35624, 2458, 'Nip Tuck S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129641.mp4', 'http://timg.bdta.pro/images/c47b5b1e3ebcef10f96c9a44f1948a59.jpg'),
(35625, 2458, 'Nip Tuck S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129642.mp4', 'http://timg.bdta.pro/images/ffd4645037fe2bf72f46a3e067e8e545.jpg'),
(35626, 2458, 'Nip Tuck S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129643.mp4', 'http://timg.bdta.pro/images/f8282fcfb43bf70a5a0ca26a4dbd1871.jpg'),
(35627, 2459, 'Nip Tuck S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129644.mp4', 'http://timg.bdta.pro/images/37b56c95203299e7638f14d6c5dab5e6.jpg'),
(35628, 2459, 'Nip Tuck S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129645.mp4', 'http://timg.bdta.pro/images/e4148538ac416cbbb9e30ffa6a30dad5.jpg'),
(35629, 2459, 'Nip Tuck S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129646.mp4', 'http://timg.bdta.pro/images/6e19699bb39cfcf18f97c3bc30a84e07.jpg'),
(35630, 2459, 'Nip Tuck S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129647.mp4', 'http://timg.bdta.pro/images/910e3712937bb2dde26a599455c6e300.jpg'),
(35631, 2459, 'Nip Tuck S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129648.mp4', 'http://timg.bdta.pro/images/26606dae0fbf57d11a231f3df30b421f.jpg'),
(35632, 2459, 'Nip Tuck S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129649.mp4', 'http://image.tmdb.org/t/p/w300/nvykSzsOHGF6nPfLN7CtPO6jn4p.jpg'),
(35633, 2459, 'Nip Tuck S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129650.mp4', 'http://image.tmdb.org/t/p/w300/vd4esKGQQExI94zw5XKT94ykQLr.jpg'),
(35634, 2459, 'Nip Tuck S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129651.mp4', 'http://image.tmdb.org/t/p/w300/wwt5WxClJC9ghyRGFg3z0pxHonC.jpg'),
(35635, 2459, 'Nip Tuck S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129652.mp4', 'http://image.tmdb.org/t/p/w300/3y51vjBSsSeyQ6W2ramI5a2O9ks.jpg'),
(35636, 2459, 'Nip Tuck S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129653.mp4', 'http://timg.bdta.pro/images/9f842c950db5469642135cc282e980b2.jpg'),
(35637, 2459, 'Nip Tuck S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129654.mp4', 'http://timg.bdta.pro/images/0fe9e16bd6f96548c30b5270e5a46e2b.jpg'),
(35638, 2459, 'Nip Tuck S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129655.mp4', 'http://timg.bdta.pro/images/8f1d0fb2d15906dc01096af740b2500b.jpg'),
(35639, 2459, 'Nip Tuck S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129656.mp4', 'http://timg.bdta.pro/images/32a67d649e6da09b6fb024eb1383d63a.jpg'),
(35640, 2459, 'Nip Tuck S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129657.mp4', 'http://timg.bdta.pro/images/c315ecbe77d4951d8bd51272f84c94df.jpg'),
(35641, 2459, 'Nip Tuck S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129658.mp4', 'http://timg.bdta.pro/images/a96c7b4c30cc6a27256039002f4844d0.jpg'),
(35642, 2459, 'Nip Tuck S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129659.mp4', 'http://timg.bdta.pro/images/ede79987841f082619f06696613eca1e.jpg'),
(35643, 2460, 'Nip Tuck S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129660.mp4', 'http://timg.bdta.pro/images/1550e89eb15c8898358b096ebbc7d5f3.jpg'),
(35644, 2460, 'Nip Tuck S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129661.mp4', 'http://timg.bdta.pro/images/23fc42e982ccb6bb9f7ce511c8ed6427.jpg'),
(35645, 2460, 'Nip Tuck S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129662.mp4', 'http://timg.bdta.pro/images/9329d59b2c145a4d4c7d01b1acce71e4.jpg'),
(35646, 2460, 'Nip Tuck S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129663.mp4', 'http://timg.bdta.pro/images/784783549158eb2fb137f8fab6358abb.jpg'),
(35647, 2460, 'Nip Tuck S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129664.mp4', 'http://timg.bdta.pro/images/79aa0aaa9fc2b44f40e73b4a3be0ed14.jpg'),
(35648, 2460, 'Nip Tuck S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129665.mp4', 'http://timg.bdta.pro/images/d9f97d2a5e6036692eb8fd0e7c2e9e31.jpg'),
(35649, 2460, 'Nip Tuck S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129666.mp4', 'http://timg.bdta.pro/images/732521132fadfc107adbc1649cd230b0.jpg'),
(35650, 2460, 'Nip Tuck S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129667.mp4', 'http://timg.bdta.pro/images/55949d7fa45d19d6639778ee88b57b51.jpg'),
(35651, 2460, 'Nip Tuck S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129668.mp4', 'http://timg.bdta.pro/images/c4b7826da19a4c60e3988e684fef7e5a.jpg'),
(35652, 2460, 'Nip Tuck S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129669.mp4', 'http://timg.bdta.pro/images/1d68d3143e32afaecf0d783a396552fa.jpg'),
(35653, 2460, 'Nip Tuck S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129670.mp4', 'http://timg.bdta.pro/images/1b4474ccff820d72d2b8441cbec6e136.jpg'),
(35654, 2460, 'Nip Tuck S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129671.mp4', 'http://timg.bdta.pro/images/9f194c8c3bf6226ce74e344c2c667410.jpg'),
(35655, 2461, 'Nip Tuck S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129672.mp4', 'http://timg.bdta.pro/images/c0eeb7b24fd733c32f6551ce626c5806.jpg'),
(35656, 2461, 'Nip Tuck S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129673.mp4', 'http://timg.bdta.pro/images/56d3f8dfe1946e4f66e3b051b4e2fd71.jpg'),
(35657, 2461, 'Nip Tuck S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129674.mp4', 'http://timg.bdta.pro/images/7770a0a3f2fdceeed6818de744b5c7f9.jpg'),
(35658, 2461, 'Nip Tuck S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129675.mp4', 'http://timg.bdta.pro/images/f9f3837fec13de3d82e23cec779ba927.jpg'),
(35659, 2461, 'Nip Tuck S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129676.mp4', 'http://timg.bdta.pro/images/c4e4a07a85f3afce162441bc6f8afdab.jpg'),
(35660, 2461, 'Nip Tuck S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129677.mp4', 'http://timg.bdta.pro/images/a1c9493dc917a22de8ccc3d95c18f2d0.jpg'),
(35661, 2461, 'Nip Tuck S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129678.mp4', 'http://timg.bdta.pro/images/9c0b545769f86059cd5826aa79ef3f1a.jpg'),
(35662, 2461, 'Nip Tuck S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129679.mp4', 'http://timg.bdta.pro/images/a2f1fcfd73d86a4cb87847e820c48c13.jpg'),
(35663, 2461, 'Nip Tuck S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129680.mp4', 'http://timg.bdta.pro/images/b4703357ec578425a16a462d80bcd5a6.jpg'),
(35664, 2461, 'Nip Tuck S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129681.mp4', 'http://timg.bdta.pro/images/4b5b94f217187335090a340d3164a4f1.jpg'),
(35665, 2461, 'Nip Tuck S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129682.mp4', 'http://timg.bdta.pro/images/fc1670aef81cd64bb8c81c6163bc82e8.jpg'),
(35666, 2461, 'Nip Tuck S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129683.mp4', 'http://timg.bdta.pro/images/dc1cf348d1c25bf2384419a59ff1858b.jpg'),
(35667, 2461, 'Nip Tuck S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129684.mp4', 'http://timg.bdta.pro/images/e40e24a45f15b17f48de4cef3a6d48e8.jpg'),
(35668, 2461, 'Nip Tuck S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129685.mp4', 'http://timg.bdta.pro/images/55ae99cd5926cff82feea7e07c3012bb.jpg'),
(35669, 2461, 'Nip Tuck S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129686.mp4', 'http://timg.bdta.pro/images/330a6c6c80d0f2c93eb9c40e2b4c6f96.jpg'),
(35670, 2462, 'Nip Tuck S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129687.mp4', 'http://timg.bdta.pro/images/417f06180fb0fafc8cf671ca6c171341.jpg'),
(35671, 2462, 'Nip Tuck S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129688.mp4', 'http://timg.bdta.pro/images/8832c3b5c811953a76b97f47602cb8c9.jpg'),
(35672, 2462, 'Nip Tuck S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129689.mp4', 'http://timg.bdta.pro/images/2e7b6db027cd9029029e1dd1b7b8881e.jpg'),
(35673, 2462, 'Nip Tuck S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129690.mp4', 'http://timg.bdta.pro/images/a0b023bda56676432abb334fc60c3acf.jpg'),
(35674, 2462, 'Nip Tuck S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129691.mp4', 'http://timg.bdta.pro/images/e6f3a001b84c9dbae9cb0d7c9766563c.jpg'),
(35675, 2462, 'Nip Tuck S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129692.mp4', 'http://timg.bdta.pro/images/b998ffd1f9afc0210f0fb060132e3a90.jpg'),
(35676, 2462, 'Nip Tuck S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129693.mp4', 'http://timg.bdta.pro/images/a2c4536b723fd031e78fa80e1546a3e5.jpg'),
(35677, 2462, 'Nip Tuck S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129694.mp4', 'http://timg.bdta.pro/images/b11edbc2525c5db3f6252c997e399d7c.jpg'),
(35678, 2462, 'Nip Tuck S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129695.mp4', 'http://timg.bdta.pro/images/15455d8b31b49557f8ef89f11b0eb1c2.jpg'),
(35679, 2462, 'Nip Tuck S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129696.mp4', 'http://timg.bdta.pro/images/e2c898a1640626774742dcfa85551066.jpg'),
(35680, 2462, 'Nip Tuck S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129697.mp4', 'http://timg.bdta.pro/images/f3bd1f8c43fd4bad3ee7c2ac429aa710.jpg'),
(35681, 2462, 'Nip Tuck S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129698.mp4', 'http://timg.bdta.pro/images/cbf1436bb0005868121d008caa1c9798.jpg'),
(35682, 2462, 'Nip Tuck S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129699.mp4', 'http://timg.bdta.pro/images/cd6c875e36aa6c842c2a4b7b8bbf892b.jpg'),
(35683, 2462, 'Nip Tuck S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129700.mp4', 'http://timg.bdta.pro/images/63a7742c6569b6803dcb894356635024.jpg'),
(35684, 2462, 'Nip Tuck S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129701.mp4', 'http://timg.bdta.pro/images/3cd4c7d16f286473b761227028fda5f4.jpg'),
(35685, 2462, 'Nip Tuck S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129702.mp4', 'http://timg.bdta.pro/images/4b1403cf4d03bf7b06816d009f4f0489.jpg'),
(35686, 2462, 'Nip Tuck S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129703.mp4', 'http://timg.bdta.pro/images/8ab7c24b6817055bc3edcc0bb16bd855.jpg'),
(35687, 2462, 'Nip Tuck S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129704.mp4', 'http://timg.bdta.pro/images/247ccbf9ecd69ff6d3597b7e9acf03ba.jpg'),
(35688, 2462, 'Nip Tuck S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129705.mp4', 'http://timg.bdta.pro/images/4d29fa955a5db8d7b51565a006a4e362.jpg'),
(35689, 2462, 'Nip Tuck S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129706.mp4', 'http://timg.bdta.pro/images/65e0577eba3d6c0918fda31cde81251a.jpg'),
(35690, 2462, 'Nip Tuck S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129707.mp4', 'http://timg.bdta.pro/images/38cdba8f78817254be7e76c0c2fceef5.jpg'),
(35691, 2463, 'Nip Tuck S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129708.mp4', 'http://timg.bdta.pro/images/1b827e2a9d9811cbcfbc94d829e03131.jpg'),
(35692, 2463, 'Nip Tuck S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129709.mp4', 'http://timg.bdta.pro/images/ae25d6f7fcd73f1ea53fc528339952d2.jpg'),
(35693, 2463, 'Nip Tuck S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129710.mp4', 'http://timg.bdta.pro/images/0acd93f193802d3fa8859eb61685d506.jpg'),
(35694, 2463, 'Nip Tuck S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129711.mp4', 'http://timg.bdta.pro/images/3df80cffa2b2c9b74075ed4f911b0ee1.jpg'),
(35695, 2463, 'Nip Tuck S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129712.mp4', 'http://timg.bdta.pro/images/176f1f32930ff1b565cab55675861a82.jpg'),
(35696, 2463, 'Nip Tuck S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129713.mp4', 'http://timg.bdta.pro/images/877d1828d7e557cabb0ba7bf15eae857.jpg'),
(35697, 2463, 'Nip Tuck S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129714.mp4', 'http://timg.bdta.pro/images/4e41fddb45f7909014ae1e5f39fb02a3.jpg'),
(35698, 2463, 'Nip Tuck S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129715.mp4', 'http://timg.bdta.pro/images/70cf11cd8d179ad0e23eed8a485093de.jpg'),
(35699, 2463, 'Nip Tuck S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129716.mp4', 'http://timg.bdta.pro/images/74bd43d40449cf735585b4966bd994df.jpg'),
(35700, 2463, 'Nip Tuck S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129717.mp4', 'http://timg.bdta.pro/images/f3143c65da51419266123d77eab6910b.jpg'),
(35701, 2464, 'Rocky & Hudson: Os Cowboys Gays S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129619.mp4', 'http://gstaticontent.com/images/51dab5b990446ea00e2f15a88a494ee0.jpg'),
(35702, 2464, 'Rocky & Hudson: Os Cowboys Gays S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129620.mp4', 'http://gstaticontent.com/images/51dab5b990446ea00e2f15a88a494ee0.jpg'),
(35703, 2464, 'Rocky & Hudson: Os Cowboys Gays S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129621.mp4', 'http://gstaticontent.com/images/51dab5b990446ea00e2f15a88a494ee0.jpg'),
(35704, 2464, 'Rocky & Hudson: Os Cowboys Gays S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129622.mp4', 'http://gstaticontent.com/images/51dab5b990446ea00e2f15a88a494ee0.jpg'),
(35705, 2464, 'Rocky & Hudson: Os Cowboys Gays S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129623.mp4', 'http://gstaticontent.com/images/51dab5b990446ea00e2f15a88a494ee0.jpg'),
(35706, 2464, 'Rocky & Hudson: Os Cowboys Gays S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129624.mp4', 'http://gstaticontent.com/images/51dab5b990446ea00e2f15a88a494ee0.jpg'),
(35707, 2464, 'Rocky & Hudson: Os Cowboys Gays S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129625.mp4', 'http://gstaticontent.com/images/51dab5b990446ea00e2f15a88a494ee0.jpg'),
(35708, 2464, 'Rocky & Hudson: Os Cowboys Gays S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129626.mp4', 'http://gstaticontent.com/images/51dab5b990446ea00e2f15a88a494ee0.jpg'),
(35709, 2464, 'Rocky & Hudson: Os Cowboys Gays S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129627.mp4', 'http://gstaticontent.com/images/51dab5b990446ea00e2f15a88a494ee0.jpg'),
(35710, 2464, 'Rocky & Hudson: Os Cowboys Gays S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129628.mp4', 'http://gstaticontent.com/images/51dab5b990446ea00e2f15a88a494ee0.jpg'),
(35711, 2464, 'Rocky & Hudson: Os Cowboys Gays S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129629.mp4', 'http://gstaticontent.com/images/51dab5b990446ea00e2f15a88a494ee0.jpg'),
(35712, 2464, 'Rocky & Hudson: Os Cowboys Gays S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129630.mp4', 'http://gstaticontent.com/images/51dab5b990446ea00e2f15a88a494ee0.jpg'),
(35713, 2465, 'Sugar Rush S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129599.mp4', 'http://timg.bdta.pro/images/f25c187c8210f475139248cb8f679ef5.jpg'),
(35714, 2465, 'Sugar Rush S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129600.mp4', 'http://timg.bdta.pro/images/f23d1f3d4a5e958ef6b75a43d3b2781b.jpg'),
(35715, 2465, 'Sugar Rush S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129601.mp4', 'http://timg.bdta.pro/images/dc6cb068b5e770d87636a535d4a79283.jpg'),
(35716, 2465, 'Sugar Rush S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129602.mp4', 'http://timg.bdta.pro/images/43d6c63db9869bf4ea4d5c1c3ab4617a.jpg'),
(35717, 2465, 'Sugar Rush S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129603.mp4', 'http://timg.bdta.pro/images/e19fdf3a1336384138a9b49ca8c71cfe.jpg'),
(35718, 2465, 'Sugar Rush S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129604.mp4', 'http://timg.bdta.pro/images/0eb236e37e497dec7bcb125c706ff319.jpg'),
(35719, 2465, 'Sugar Rush S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129605.mp4', 'http://timg.bdta.pro/images/4802d70073953504193d88878afb28de.jpg'),
(35720, 2465, 'Sugar Rush S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129606.mp4', 'http://gstaticontent.com/images/ymL4S6c0nnm91zC1kgUDMTMD27E_big.jpg'),
(35721, 2466, 'Sugar Rush S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129607.mp4', 'http://timg.bdta.pro/images/0d3231eeb7799af3a5df5d8a67dccfee.jpg'),
(35722, 2466, 'Sugar Rush S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129608.mp4', 'http://timg.bdta.pro/images/e197fc2d55f901511c13e8172da9c7d2.jpg'),
(35723, 2466, 'Sugar Rush S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129609.mp4', 'http://timg.bdta.pro/images/73cc3ea32d450a1d99843d378e1e9ff9.jpg'),
(35724, 2466, 'Sugar Rush S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129610.mp4', 'http://timg.bdta.pro/images/9857bb88ee4b5b628f7658e3441cf95f.jpg'),
(35725, 2466, 'Sugar Rush S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129611.mp4', 'http://timg.bdta.pro/images/95c8b0fe6e6cd93fcadbe5f2c3adb309.jpg'),
(35726, 2466, 'Sugar Rush S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129612.mp4', 'http://timg.bdta.pro/images/753cd6d3ba7510a6d2c8b47097d460f7.jpg'),
(35727, 2467, 'Sugar Rush S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129613.mp4', 'http://timg.bdta.pro/images/753cd6d3ba7510a6d2c8b47097d460f7.jpg'),
(35728, 2467, 'Sugar Rush S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129614.mp4', 'http://timg.bdta.pro/images/753cd6d3ba7510a6d2c8b47097d460f7.jpg'),
(35729, 2467, 'Sugar Rush S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129615.mp4', 'http://timg.bdta.pro/images/753cd6d3ba7510a6d2c8b47097d460f7.jpg'),
(35730, 2467, 'Sugar Rush S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129616.mp4', 'http://timg.bdta.pro/images/753cd6d3ba7510a6d2c8b47097d460f7.jpg'),
(35731, 2467, 'Sugar Rush S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129617.mp4', 'http://timg.bdta.pro/images/753cd6d3ba7510a6d2c8b47097d460f7.jpg'),
(35732, 2467, 'Sugar Rush S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129618.mp4', 'http://timg.bdta.pro/images/753cd6d3ba7510a6d2c8b47097d460f7.jpg'),
(35733, 2468, 'We Hunt Together [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129593.mp4', 'http://timg.bdta.pro/images/f56065932a3be9f1894b4bfe571674b7.jpg'),
(35734, 2468, 'We Hunt Together [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129594.mp4', 'http://timg.bdta.pro/images/94938786e3d93bf1ee22cba8240b449b.jpg'),
(35735, 2468, 'We Hunt Together [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129595.mp4', 'http://gstaticontent.com/images/pRveqWHqLUxLiXsMus9I8pGLQDX_big.jpg'),
(35736, 2468, 'We Hunt Together [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129596.mp4', 'http://gstaticontent.com/images/pRveqWHqLUxLiXsMus9I8pGLQDX_big.jpg'),
(35737, 2468, 'We Hunt Together [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129597.mp4', 'http://gstaticontent.com/images/pRveqWHqLUxLiXsMus9I8pGLQDX_big.jpg'),
(35738, 2468, 'We Hunt Together [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129598.mp4', 'http://gstaticontent.com/images/pRveqWHqLUxLiXsMus9I8pGLQDX_big.jpg'),
(35739, 2469, 'Hey Arnold! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129493.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35740, 2469, 'Hey Arnold! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129494.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35741, 2469, 'Hey Arnold! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129495.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35742, 2469, 'Hey Arnold! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129496.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35743, 2469, 'Hey Arnold! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129497.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35744, 2469, 'Hey Arnold! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129498.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35745, 2469, 'Hey Arnold! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129499.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35746, 2469, 'Hey Arnold! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129500.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35747, 2469, 'Hey Arnold! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129501.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35748, 2469, 'Hey Arnold! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129502.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35749, 2469, 'Hey Arnold! S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129503.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35750, 2469, 'Hey Arnold! S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129504.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35751, 2469, 'Hey Arnold! S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129505.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35752, 2469, 'Hey Arnold! S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129506.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35753, 2469, 'Hey Arnold! S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129507.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35754, 2469, 'Hey Arnold! S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129508.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35755, 2469, 'Hey Arnold! S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129509.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35756, 2469, 'Hey Arnold! S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129510.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35757, 2469, 'Hey Arnold! S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129511.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35758, 2469, 'Hey Arnold! S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129512.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35759, 2470, 'Hey Arnold! S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129513.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35760, 2470, 'Hey Arnold! S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129514.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35761, 2470, 'Hey Arnold! S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129515.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35762, 2470, 'Hey Arnold! S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129516.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35763, 2470, 'Hey Arnold! S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129517.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35764, 2470, 'Hey Arnold! S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129518.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35765, 2470, 'Hey Arnold! S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129519.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35766, 2470, 'Hey Arnold! S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129520.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35767, 2470, 'Hey Arnold! S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129521.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35768, 2470, 'Hey Arnold! S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129522.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35769, 2470, 'Hey Arnold! S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129523.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35770, 2470, 'Hey Arnold! S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129524.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35771, 2470, 'Hey Arnold! S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129525.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35772, 2470, 'Hey Arnold! S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129526.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35773, 2470, 'Hey Arnold! S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129527.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35774, 2470, 'Hey Arnold! S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129528.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35775, 2470, 'Hey Arnold! S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129529.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35776, 2470, 'Hey Arnold! S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129530.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35777, 2470, 'Hey Arnold! S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129531.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35778, 2471, 'Hey Arnold! S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129532.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35779, 2471, 'Hey Arnold! S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129533.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35780, 2471, 'Hey Arnold! S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129534.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35781, 2471, 'Hey Arnold! S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129535.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35782, 2471, 'Hey Arnold! S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129536.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35783, 2471, 'Hey Arnold! S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129537.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35784, 2471, 'Hey Arnold! S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129538.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35785, 2471, 'Hey Arnold! S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129539.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35786, 2471, 'Hey Arnold! S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129540.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35787, 2471, 'Hey Arnold! S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129541.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35788, 2471, 'Hey Arnold! S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129542.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35789, 2471, 'Hey Arnold! S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129543.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35790, 2471, 'Hey Arnold! S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129544.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35791, 2471, 'Hey Arnold! S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129545.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35792, 2471, 'Hey Arnold! S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129546.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35793, 2471, 'Hey Arnold! S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129547.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35794, 2471, 'Hey Arnold! S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129548.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35795, 2471, 'Hey Arnold! S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129549.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35796, 2471, 'Hey Arnold! S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129550.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35797, 2471, 'Hey Arnold! S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129551.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35798, 2472, 'Hey Arnold! S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129552.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35799, 2472, 'Hey Arnold! S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129553.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35800, 2472, 'Hey Arnold! S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129554.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35801, 2472, 'Hey Arnold! S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129555.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35802, 2472, 'Hey Arnold! S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129556.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35803, 2472, 'Hey Arnold! S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129557.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35804, 2472, 'Hey Arnold! S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129558.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35805, 2472, 'Hey Arnold! S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129559.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35806, 2472, 'Hey Arnold! S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129560.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35807, 2472, 'Hey Arnold! S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129561.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35808, 2472, 'Hey Arnold! S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129562.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35809, 2472, 'Hey Arnold! S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129563.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35810, 2472, 'Hey Arnold! S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129564.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35811, 2472, 'Hey Arnold! S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129565.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35812, 2472, 'Hey Arnold! S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129566.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35813, 2472, 'Hey Arnold! S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129567.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35814, 2472, 'Hey Arnold! S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129568.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35815, 2473, 'Hey Arnold! S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129569.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35816, 2473, 'Hey Arnold! S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129570.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35817, 2473, 'Hey Arnold! S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129571.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35818, 2473, 'Hey Arnold! S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129572.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35819, 2473, 'Hey Arnold! S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129573.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35820, 2473, 'Hey Arnold! S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129574.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35821, 2473, 'Hey Arnold! S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129575.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35822, 2473, 'Hey Arnold! S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129576.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35823, 2473, 'Hey Arnold! S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129577.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35824, 2473, 'Hey Arnold! S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129578.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35825, 2473, 'Hey Arnold! S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129579.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35826, 2473, 'Hey Arnold! S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129580.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35827, 2473, 'Hey Arnold! S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129581.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35828, 2473, 'Hey Arnold! S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129582.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35829, 2473, 'Hey Arnold! S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129583.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35830, 2473, 'Hey Arnold! S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129584.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35831, 2473, 'Hey Arnold! S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129585.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35832, 2473, 'Hey Arnold! S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129586.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35833, 2473, 'Hey Arnold! S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129587.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35834, 2473, 'Hey Arnold! S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129588.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35835, 2473, 'Hey Arnold! S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/129589.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35836, 2473, 'Hey Arnold! S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/129590.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35837, 2473, 'Hey Arnold! S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/129591.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35838, 2473, 'Hey Arnold! S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/129592.mp4', 'http://gstaticontent.com/images/lmoYPc7pXjliXWMLqwN6tuJQc8b_big.jpg'),
(35839, 2474, 'Masaba Masaba [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129487.mp4', 'http://timg.bdta.pro/images/5ed01518f0aaf45c5892970ac17f4538.jpg'),
(35840, 2474, 'Masaba Masaba [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129488.mp4', 'http://timg.bdta.pro/images/d20866001eb9a1a54c33cd8ce8a750ad.jpg'),
(35841, 2474, 'Masaba Masaba [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129489.mp4', 'http://timg.bdta.pro/images/66f61feb3f9f35d20bddd729bf27d0b3.jpg'),
(35842, 2474, 'Masaba Masaba [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129490.mp4', 'http://timg.bdta.pro/images/f04a1b3d3da3a07b9daa5c85ecb95288.jpg'),
(35843, 2474, 'Masaba Masaba [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129491.mp4', 'http://timg.bdta.pro/images/14340cd3bc2c9623386f4b6067c84ef2.jpg'),
(35844, 2474, 'Masaba Masaba [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129492.mp4', 'http://timg.bdta.pro/images/b35ca0e1457608f912d86feb72375255.jpg'),
(35845, 2475, 'Punky a Levada da Breca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129467.mp4', 'http://timg.bdta.pro/images/d673fee030c2dc1ce8bed7e197aac757.jpg'),
(35846, 2475, 'Punky a Levada da Breca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129468.mp4', 'http://timg.bdta.pro/images/f1ba59c90567d04fa20fa8fbb88711b3.jpg'),
(35847, 2475, 'Punky a Levada da Breca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129469.mp4', 'http://timg.bdta.pro/images/4bfaab809b12f6674ad62525a0bc9ec0.jpg'),
(35848, 2475, 'Punky a Levada da Breca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129470.mp4', 'http://gstaticontent.com/images/a3a0704feb03c3199f7a5c664e61b95a.jpg'),
(35849, 2475, 'Punky a Levada da Breca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129471.mp4', 'http://timg.bdta.pro/images/0ece31d2aa65fb7285414537f54c113f.jpg'),
(35850, 2475, 'Punky a Levada da Breca S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129472.mp4', 'http://timg.bdta.pro/images/257fc45dca7f31c084847b8ee09a268e.jpg'),
(35851, 2475, 'Punky a Levada da Breca S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129473.mp4', 'http://gstaticontent.com/images/a3a0704feb03c3199f7a5c664e61b95a.jpg'),
(35852, 2475, 'Punky a Levada da Breca S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129474.mp4', 'http://timg.bdta.pro/images/45dc6dbcbc4a965fea631739ae1efc24.jpg'),
(35853, 2475, 'Punky a Levada da Breca S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129475.mp4', 'http://timg.bdta.pro/images/35dba462722bf973bcd166233a56ec2e.jpg'),
(35854, 2475, 'Punky a Levada da Breca S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129476.mp4', 'http://gstaticontent.com/images/a3a0704feb03c3199f7a5c664e61b95a.jpg'),
(35855, 2475, 'Punky a Levada da Breca S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/129477.mp4', 'http://timg.bdta.pro/images/93820e81f7c6d8d86500a7e4a068dd94.jpg'),
(35856, 2475, 'Punky a Levada da Breca S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/129478.mp4', 'http://timg.bdta.pro/images/0606c349f4653e2657df10cea47d3f18.jpg'),
(35857, 2475, 'Punky a Levada da Breca S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/129479.mp4', 'http://timg.bdta.pro/images/9260dabee1a4e55e010b35e55e8da8f2.jpg'),
(35858, 2475, 'Punky a Levada da Breca S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/129480.mp4', 'http://timg.bdta.pro/images/b9a061993e5bdcd70286197db2371e83.jpg'),
(35859, 2475, 'Punky a Levada da Breca S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/129481.mp4', 'http://timg.bdta.pro/images/466042606c41c9cdb6f451ff42ed1bf2.jpg'),
(35860, 2475, 'Punky a Levada da Breca S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/129482.mp4', 'http://timg.bdta.pro/images/7a489949df49097502f7fbda82fe707b.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(35861, 2475, 'Punky a Levada da Breca S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/129483.mp4', 'http://timg.bdta.pro/images/1e4a774ef27be646a3f92f91ed0080ff.jpg'),
(35862, 2475, 'Punky a Levada da Breca S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/129484.mp4', 'http://timg.bdta.pro/images/7d102a4452de4eb628709b43f04960bb.jpg'),
(35863, 2475, 'Punky a Levada da Breca S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/129485.mp4', 'http://timg.bdta.pro/images/3bb275c99f5750180f3bc48ee7df2c1c.jpg'),
(35864, 2475, 'Punky a Levada da Breca S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/129486.mp4', 'http://timg.bdta.pro/images/d0771c95edea7f920acf9c520034fbfa.jpg'),
(35865, 2476, 'Dupla Identidade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136392.mp4', 'http://gstaticontent.com/images/eo1miDpvXy9i1Ga3LCbRacFHjlZ_big.jpg'),
(35866, 2476, 'Dupla Identidade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136393.mp4', 'http://gstaticontent.com/images/eo1miDpvXy9i1Ga3LCbRacFHjlZ_big.jpg'),
(35867, 2476, 'Dupla Identidade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136394.mp4', 'http://gstaticontent.com/images/eo1miDpvXy9i1Ga3LCbRacFHjlZ_big.jpg'),
(35868, 2476, 'Dupla Identidade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136395.mp4', 'http://gstaticontent.com/images/eo1miDpvXy9i1Ga3LCbRacFHjlZ_big.jpg'),
(35869, 2476, 'Dupla Identidade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136396.mp4', 'http://gstaticontent.com/images/eo1miDpvXy9i1Ga3LCbRacFHjlZ_big.jpg'),
(35870, 2476, 'Dupla Identidade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136397.mp4', 'http://gstaticontent.com/images/eo1miDpvXy9i1Ga3LCbRacFHjlZ_big.jpg'),
(35871, 2476, 'Dupla Identidade S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136398.mp4', 'http://gstaticontent.com/images/eo1miDpvXy9i1Ga3LCbRacFHjlZ_big.jpg'),
(35872, 2476, 'Dupla Identidade S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136399.mp4', 'http://gstaticontent.com/images/eo1miDpvXy9i1Ga3LCbRacFHjlZ_big.jpg'),
(35873, 2476, 'Dupla Identidade S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136400.mp4', 'http://gstaticontent.com/images/eo1miDpvXy9i1Ga3LCbRacFHjlZ_big.jpg'),
(35874, 2476, 'Dupla Identidade S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136401.mp4', 'http://gstaticontent.com/images/eo1miDpvXy9i1Ga3LCbRacFHjlZ_big.jpg'),
(35875, 2476, 'Dupla Identidade S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136402.mp4', 'http://gstaticontent.com/images/eo1miDpvXy9i1Ga3LCbRacFHjlZ_big.jpg'),
(35876, 2476, 'Dupla Identidade S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136403.mp4', 'http://gstaticontent.com/images/eo1miDpvXy9i1Ga3LCbRacFHjlZ_big.jpg'),
(35877, 2476, 'Dupla Identidade S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136404.mp4', 'http://gstaticontent.com/images/eo1miDpvXy9i1Ga3LCbRacFHjlZ_big.jpg'),
(35878, 2477, 'Cobra Kai S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194092.mp4', 'http://timg.bdta.pro/images/411f97ebdfcdf73649352ee9f69bce9d.jpg'),
(35879, 2477, 'Cobra Kai S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194093.mp4', 'http://timg.bdta.pro/images/0fc80c5e80b18d408c0eedb43be6344a.jpg'),
(35880, 2477, 'Cobra Kai S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194094.mp4', 'http://timg.bdta.pro/images/0f6495f8d37fb93d767ba6a15a60c2aa.jpg'),
(35881, 2477, 'Cobra Kai S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194095.mp4', 'http://timg.bdta.pro/images/d526b6ad1682512cdf13e7b6e91c46df.jpg'),
(35882, 2477, 'Cobra Kai S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194096.mp4', 'http://timg.bdta.pro/images/5735440ea53702e9b8b830877497c36f.jpg'),
(35883, 2477, 'Cobra Kai S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194097.mp4', 'http://timg.bdta.pro/images/668bf953a5da67135861165b36dcf1ea.jpg'),
(35884, 2477, 'Cobra Kai S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194098.mp4', 'http://timg.bdta.pro/images/c6f7dca5642b616cc0aefbb61e981f93.jpg'),
(35885, 2477, 'Cobra Kai S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194099.mp4', 'http://timg.bdta.pro/images/778018ebc005956f57b9a489a428984c.jpg'),
(35886, 2477, 'Cobra Kai S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194100.mp4', 'http://timg.bdta.pro/images/0206a72f51d91f88236cb6a6111f8e25.jpg'),
(35887, 2477, 'Cobra Kai S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194101.mp4', 'http://timg.bdta.pro/images/1c54dbdf1aba58d8fa21a376de49aade.jpg'),
(35888, 2478, 'Cobra Kai S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194102.mp4', 'http://timg.bdta.pro/images/321fcfa24fa2916b0d9d96f967d7c7f1.jpg'),
(35889, 2478, 'Cobra Kai S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194103.mp4', 'http://timg.bdta.pro/images/b00ba4576b84f84af17d762faa677e55.jpg'),
(35890, 2478, 'Cobra Kai S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194104.mp4', 'http://timg.bdta.pro/images/eea1690c5d81d0b20ed8a1a473c64b3e.jpg'),
(35891, 2478, 'Cobra Kai S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194105.mp4', 'http://timg.bdta.pro/images/87e86ff82e83850b93a09ad1cc367f37.jpg'),
(35892, 2478, 'Cobra Kai S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194106.mp4', 'http://timg.bdta.pro/images/263d14c68b37dc69767ee0bc8505e719.jpg'),
(35893, 2478, 'Cobra Kai S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194107.mp4', 'http://timg.bdta.pro/images/cbff08dc7ccabc3312a0845ccb2c1a1e.jpg'),
(35894, 2478, 'Cobra Kai S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194108.mp4', 'http://timg.bdta.pro/images/9d395ab97f18895dada03492ad82eb5a.jpg'),
(35895, 2478, 'Cobra Kai S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194109.mp4', 'http://timg.bdta.pro/images/daa9912b1d5a216a5402318517084192.jpg'),
(35896, 2478, 'Cobra Kai S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194110.mp4', 'http://timg.bdta.pro/images/f4427297dfc820a05503cbb81a9eb1a9.jpg'),
(35897, 2478, 'Cobra Kai S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194111.mp4', 'http://timg.bdta.pro/images/b673adf4dd74f0265fea471d21a217e8.jpg'),
(35898, 2479, 'Cobra Kai S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194112.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35899, 2479, 'Cobra Kai S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194113.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35900, 2479, 'Cobra Kai S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194114.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35901, 2479, 'Cobra Kai S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194115.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35902, 2479, 'Cobra Kai S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194116.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35903, 2479, 'Cobra Kai S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194117.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35904, 2479, 'Cobra Kai S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194118.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35905, 2479, 'Cobra Kai S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194119.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35906, 2479, 'Cobra Kai S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194120.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35907, 2479, 'Cobra Kai S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194121.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35908, 2480, 'Cobra Kai S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194122.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35909, 2480, 'Cobra Kai S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194123.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35910, 2480, 'Cobra Kai S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194124.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35911, 2480, 'Cobra Kai S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194125.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35912, 2480, 'Cobra Kai S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194126.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35913, 2480, 'Cobra Kai S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194127.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35914, 2480, 'Cobra Kai S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194128.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35915, 2480, 'Cobra Kai S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194129.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35916, 2480, 'Cobra Kai S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194130.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35917, 2480, 'Cobra Kai S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194131.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35918, 2481, 'Cobra Kai S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194132.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35919, 2481, 'Cobra Kai S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194133.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35920, 2481, 'Cobra Kai S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194134.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35921, 2481, 'Cobra Kai S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194135.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35922, 2481, 'Cobra Kai S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194136.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35923, 2481, 'Cobra Kai S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194137.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35924, 2481, 'Cobra Kai S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194138.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35925, 2481, 'Cobra Kai S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194139.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35926, 2481, 'Cobra Kai S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194140.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35927, 2481, 'Cobra Kai S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194141.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35928, 2482, 'Cobra Kai S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/412965.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35929, 2482, 'Cobra Kai S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/412966.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35930, 2482, 'Cobra Kai S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/412967.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35931, 2482, 'Cobra Kai S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/412968.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35932, 2482, 'Cobra Kai S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/412969.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35933, 2482, 'Cobra Kai S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/506311.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35934, 2482, 'Cobra Kai S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/506312.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35935, 2482, 'Cobra Kai S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/506313.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35936, 2482, 'Cobra Kai S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/506314.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35937, 2482, 'Cobra Kai S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/506315.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35938, 2482, 'Cobra Kai S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/696262.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35939, 2482, 'Cobra Kai S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/696263.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35940, 2482, 'Cobra Kai S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/696264.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35941, 2482, 'Cobra Kai S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/696265.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35942, 2482, 'Cobra Kai S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/696266.mp4', 'http://gstaticontent.com/images/83be7f7958c813ad32ad0f2f7d151866.jpg'),
(35943, 2483, 'Dix Pour Cent S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129449.mp4', 'http://timg.bdta.pro/images/2b4a1bbb5fc78f61b509cb0a85c28d3d.jpg'),
(35944, 2483, 'Dix Pour Cent S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129450.mp4', 'http://timg.bdta.pro/images/de6d12e521039e79a6699c75778c6038.jpg'),
(35945, 2483, 'Dix Pour Cent S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129451.mp4', 'http://timg.bdta.pro/images/f5522e511f8fbeff696f8bfb8eba5113.jpg'),
(35946, 2483, 'Dix Pour Cent S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129452.mp4', 'http://timg.bdta.pro/images/757c26aae578931b79de4d16bcdf7112.jpg'),
(35947, 2483, 'Dix Pour Cent S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129453.mp4', 'http://timg.bdta.pro/images/b4bd598f7a3f2cccfa8eaa4e7cdef644.jpg'),
(35948, 2483, 'Dix Pour Cent S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129454.mp4', 'http://timg.bdta.pro/images/f257621df904451f17f8b937ac8951e7.jpg'),
(35949, 2484, 'Dix Pour Cent S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129455.mp4', 'http://timg.bdta.pro/images/cfce25d885e4aefedf25a89f8e67860c.jpg'),
(35950, 2484, 'Dix Pour Cent S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129456.mp4', 'http://timg.bdta.pro/images/8ea0d843e6cf1860b18b49424b6aef10.jpg'),
(35951, 2484, 'Dix Pour Cent S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129457.mp4', 'http://timg.bdta.pro/images/f73a01261240d0f385b939b09750e57d.jpg'),
(35952, 2484, 'Dix Pour Cent S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129458.mp4', 'http://timg.bdta.pro/images/82b2c9a6f2cf0ea46e31f8240786ed3c.jpg'),
(35953, 2484, 'Dix Pour Cent S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129459.mp4', 'http://timg.bdta.pro/images/340082b1f260a0200cb3c0ad0b33158f.jpg'),
(35954, 2484, 'Dix Pour Cent S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129460.mp4', 'http://timg.bdta.pro/images/158cc26a5816d1542f436110755e7861.jpg'),
(35955, 2485, 'Dix Pour Cent S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129461.mp4', 'http://timg.bdta.pro/images/08afc50474c29520ef595614f1de413b.jpg'),
(35956, 2485, 'Dix Pour Cent S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129462.mp4', 'http://timg.bdta.pro/images/a739117aa8779d85716f78dc10fdfea8.jpg'),
(35957, 2485, 'Dix Pour Cent S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129463.mp4', 'http://timg.bdta.pro/images/166a438654a8cc7d9b909cb4c5e37510.jpg'),
(35958, 2485, 'Dix Pour Cent S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129464.mp4', 'http://timg.bdta.pro/images/fcd95d1438e5a6b7f3993fdf2407001d.jpg'),
(35959, 2485, 'Dix Pour Cent S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129465.mp4', 'http://timg.bdta.pro/images/5c0d8689dbc3016935f1b8f5c36d825a.jpg'),
(35960, 2485, 'Dix Pour Cent S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129466.mp4', 'http://timg.bdta.pro/images/c9a9ca10c5aa648ac0281438b71911dc.jpg'),
(35961, 2486, 'Bluff City Law S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129439.mp4', 'http://timg.bdta.pro/images/f4a59c9c81816f31d7717793e7fbcf3b.jpg'),
(35962, 2486, 'Bluff City Law S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129440.mp4', 'http://timg.bdta.pro/images/1091613335eef16f08b0dee9ecef6006.jpg'),
(35963, 2486, 'Bluff City Law S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129441.mp4', 'http://timg.bdta.pro/images/fe60227615f151a88492703c83da202e.jpg'),
(35964, 2486, 'Bluff City Law S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/129442.mp4', 'http://timg.bdta.pro/images/4c0ee01cdfb2cd65ca7de21afc89387a.jpg'),
(35965, 2486, 'Bluff City Law S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/129443.mp4', 'http://timg.bdta.pro/images/45f1893f6c779dba2502cf9ef368cc64.jpg'),
(35966, 2486, 'Bluff City Law S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/129444.mp4', 'http://gstaticontent.com/images/c4kMxeRENGn7YQVvllqNxIXtaK3_big.jpg'),
(35967, 2486, 'Bluff City Law S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/129445.mp4', 'http://gstaticontent.com/images/c4kMxeRENGn7YQVvllqNxIXtaK3_big.jpg'),
(35968, 2486, 'Bluff City Law S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/129446.mp4', 'http://gstaticontent.com/images/c4kMxeRENGn7YQVvllqNxIXtaK3_big.jpg'),
(35969, 2486, 'Bluff City Law S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/129447.mp4', 'http://gstaticontent.com/images/c4kMxeRENGn7YQVvllqNxIXtaK3_big.jpg'),
(35970, 2486, 'Bluff City Law S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/129448.mp4', 'http://gstaticontent.com/images/c4kMxeRENGn7YQVvllqNxIXtaK3_big.jpg'),
(35971, 2487, 'Sou um Assassino Em Liberdade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/129436.mp4', 'http://timg.bdta.pro/images/a14d10164f54a5a7c484891f887db280.jpg'),
(35972, 2487, 'Sou um Assassino Em Liberdade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/129437.mp4', 'http://timg.bdta.pro/images/5d7a29886c66f6886a8d5f663d0c47cb.jpg'),
(35973, 2487, 'Sou um Assassino Em Liberdade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/129438.mp4', 'http://timg.bdta.pro/images/59c3b6bfedc0e1e10eae656150a5b209.jpg'),
(35974, 2488, 'Borgen S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128839.mp4', 'http://timg.bdta.pro/images/47185f3cecef460f8d8da74e84a2b78b.jpg'),
(35975, 2488, 'Borgen S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128840.mp4', 'http://timg.bdta.pro/images/9eb92e83ce88b1988a201ff94f60dba0.jpg'),
(35976, 2488, 'Borgen S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128841.mp4', 'http://timg.bdta.pro/images/0fffeb2728a0cad79f22db592ef21ce1.jpg'),
(35977, 2488, 'Borgen S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128842.mp4', 'http://timg.bdta.pro/images/fc10dd372fbd5ceafe2eae4150c7eade.jpg'),
(35978, 2488, 'Borgen S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128843.mp4', 'http://timg.bdta.pro/images/9084e4f3584824721145b4b8dcba4171.jpg'),
(35979, 2488, 'Borgen S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128844.mp4', 'http://timg.bdta.pro/images/783e57ede33f950c2335b5c0e8118f3f.jpg'),
(35980, 2488, 'Borgen S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128845.mp4', 'http://timg.bdta.pro/images/54368dc4fc2034a0b30ed0441f11f9cb.jpg'),
(35981, 2488, 'Borgen S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128846.mp4', 'http://timg.bdta.pro/images/11fa444ef721d9e213cac378ce9baab1.jpg'),
(35982, 2488, 'Borgen S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128847.mp4', 'http://timg.bdta.pro/images/9e6edf33bb24ccc25589a2295b7c5a6b.jpg'),
(35983, 2488, 'Borgen S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128848.mp4', 'http://timg.bdta.pro/images/d39b7dd77039dced609de80739a15929.jpg'),
(35984, 2489, 'Borgen S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128849.mp4', 'http://timg.bdta.pro/images/15ef72f5ccd8c6dbdd507a7d76b98692.jpg'),
(35985, 2489, 'Borgen S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128850.mp4', 'http://timg.bdta.pro/images/7761c166356c8c14add3943955a2aed1.jpg'),
(35986, 2489, 'Borgen S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128851.mp4', 'http://timg.bdta.pro/images/d974ed68751240549c987e77672642e2.jpg'),
(35987, 2489, 'Borgen S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128852.mp4', 'http://timg.bdta.pro/images/eb172094abc9694d6e817a96aa593657.jpg'),
(35988, 2489, 'Borgen S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128853.mp4', 'http://timg.bdta.pro/images/fecd3ba14f74b38f9c4c6e1c39c5fd14.jpg'),
(35989, 2489, 'Borgen S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128854.mp4', 'http://timg.bdta.pro/images/5283b8eda112d4001d65af278cd4373d.jpg'),
(35990, 2489, 'Borgen S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128855.mp4', 'http://timg.bdta.pro/images/fc7dd6f21f1ea99bd64310fcd6201518.jpg'),
(35991, 2489, 'Borgen S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128856.mp4', 'http://timg.bdta.pro/images/0e4688e1405e3a5f68d577c2d03ea2f8.jpg'),
(35992, 2489, 'Borgen S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128857.mp4', 'http://timg.bdta.pro/images/d007e837d78890fd848b9ef2fe333191.jpg'),
(35993, 2489, 'Borgen S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128858.mp4', 'http://timg.bdta.pro/images/9a2a6a2fb9b553d069e4765793ab67b2.jpg'),
(35994, 2490, 'Borgen S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128859.mp4', 'http://timg.bdta.pro/images/cc58d76cc9e785a9558775b783c1f5a0.jpg'),
(35995, 2490, 'Borgen S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128860.mp4', 'http://timg.bdta.pro/images/1fba7565f679e46391697d434e0d5e75.jpg'),
(35996, 2490, 'Borgen S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128861.mp4', 'http://timg.bdta.pro/images/a71228f2febcd5da31a939d70f6e8e58.jpg'),
(35997, 2490, 'Borgen S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128862.mp4', 'http://timg.bdta.pro/images/c8a3a041178b412d26b43c0c3e3f6fcb.jpg'),
(35998, 2490, 'Borgen S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128863.mp4', 'http://timg.bdta.pro/images/442599815c551b8d950d92a4b8d03f9b.jpg'),
(35999, 2490, 'Borgen S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128864.mp4', 'http://timg.bdta.pro/images/32d62ff9e2b233b947e7a9c09c632e8d.jpg'),
(36000, 2490, 'Borgen S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128865.mp4', 'http://timg.bdta.pro/images/d27294b231ac85a5cf72445b361ce3e4.jpg'),
(36001, 2490, 'Borgen S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128866.mp4', 'http://timg.bdta.pro/images/5fad6bf3af6ed0f620aedf3c19b08655.jpg'),
(36002, 2490, 'Borgen S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128867.mp4', 'http://timg.bdta.pro/images/720f71dcd7f5a94aa427607bab82535c.jpg'),
(36003, 2490, 'Borgen S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128868.mp4', 'http://timg.bdta.pro/images/db4151d41feabc355560bd4538f3a181.jpg'),
(36004, 2491, 'A Very English Scandal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128669.mp4', 'http://timg.bdta.pro/images/623a664b6d5994e0bc047b9088c5738d.jpg'),
(36005, 2491, 'A Very English Scandal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128670.mp4', 'http://timg.bdta.pro/images/460a25c866d3e5eac9a286e04a31443e.jpg'),
(36006, 2491, 'A Very English Scandal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128671.mp4', 'http://timg.bdta.pro/images/4e64526277b38cda46e57c61d2695dc2.jpg'),
(36007, 2492, 'As Novas Aventuras do Macaco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128649.mp4', 'http://timg.bdta.pro/images/9c5449eba644ea188be2cdf29384e27e.jpg'),
(36008, 2492, 'As Novas Aventuras do Macaco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128650.mp4', 'http://timg.bdta.pro/images/7848256ecdcd26db25b112a1a5bc3c11.jpg'),
(36009, 2492, 'As Novas Aventuras do Macaco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128651.mp4', 'http://timg.bdta.pro/images/b9d1a85c6de6344ce0bf5c7f149a9f70.jpg'),
(36010, 2492, 'As Novas Aventuras do Macaco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128652.mp4', 'http://timg.bdta.pro/images/3c6cd16c75353fef7c680765266e1c82.jpg'),
(36011, 2492, 'As Novas Aventuras do Macaco S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128653.mp4', 'http://timg.bdta.pro/images/eb2e8440e227c31ec43fc2518d72b3ba.jpg'),
(36012, 2492, 'As Novas Aventuras do Macaco S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128654.mp4', 'http://timg.bdta.pro/images/1a8355d33ce35bef6623a156a73ed54b.jpg'),
(36013, 2492, 'As Novas Aventuras do Macaco S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128655.mp4', 'http://timg.bdta.pro/images/3e7e80d5bb8653fee9e21911bfa3fc90.jpg'),
(36014, 2492, 'As Novas Aventuras do Macaco S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128656.mp4', 'http://timg.bdta.pro/images/230939b57b40fa45f87e613b7c1f87be.jpg'),
(36015, 2492, 'As Novas Aventuras do Macaco S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128657.mp4', 'http://timg.bdta.pro/images/286874dd52a9df1863978bb9b637eb9d.jpg'),
(36016, 2492, 'As Novas Aventuras do Macaco S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128658.mp4', 'http://timg.bdta.pro/images/31633da4873b80e104f767652b44cef4.jpg'),
(36017, 2493, 'As Novas Aventuras do Macaco S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128659.mp4', 'http://timg.bdta.pro/images/382c321958c5825c4b02c1a62d3d89f5.jpg'),
(36018, 2493, 'As Novas Aventuras do Macaco S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128660.mp4', 'http://timg.bdta.pro/images/aef8e046a516ec9242eff36e5d8f1dfa.jpg'),
(36019, 2493, 'As Novas Aventuras do Macaco S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128661.mp4', 'http://timg.bdta.pro/images/c959f042b9f423727356c003c7c7c77c.jpg'),
(36020, 2493, 'As Novas Aventuras do Macaco S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128662.mp4', 'http://timg.bdta.pro/images/21de1cacf4ef2eeea0abe9fdeba590a2.jpg'),
(36021, 2493, 'As Novas Aventuras do Macaco S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128663.mp4', 'http://timg.bdta.pro/images/4c59aab4a2cab2f3ed980ed757a73235.jpg'),
(36022, 2493, 'As Novas Aventuras do Macaco S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128664.mp4', 'http://timg.bdta.pro/images/ee78e29fb4c30178a9a81a87aacbf796.jpg'),
(36023, 2493, 'As Novas Aventuras do Macaco S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128665.mp4', 'http://timg.bdta.pro/images/184d05412a27c734d5953c6725d8929d.jpg'),
(36024, 2493, 'As Novas Aventuras do Macaco S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128666.mp4', 'http://timg.bdta.pro/images/0d863ed5c6553161d5b71becb0f9f6fc.jpg'),
(36025, 2493, 'As Novas Aventuras do Macaco S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128667.mp4', 'http://timg.bdta.pro/images/13ad04d26225b0c24b90c4a9cceb1acb.jpg'),
(36026, 2493, 'As Novas Aventuras do Macaco S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128668.mp4', 'http://timg.bdta.pro/images/866532c2e0cb6b5627a2acb00aa09470.jpg'),
(36027, 2494, 'Away S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128639.mp4', 'http://timg.bdta.pro/images/63c6d3d5a0d28687953a49b3a07add46.jpg'),
(36028, 2494, 'Away S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128640.mp4', 'http://timg.bdta.pro/images/3d3ea4de6fc8d1589305b2851626c0cc.jpg'),
(36029, 2494, 'Away S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128641.mp4', 'http://timg.bdta.pro/images/efda9e65f90b2f384da46efcaadd0701.jpg'),
(36030, 2494, 'Away S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128642.mp4', 'http://timg.bdta.pro/images/9344780830f9b821e7d486edfd345bc7.jpg'),
(36031, 2494, 'Away S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128643.mp4', 'http://timg.bdta.pro/images/4bd35bc412c52c3c1d3e66796ada2323.jpg'),
(36032, 2494, 'Away S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128644.mp4', 'http://timg.bdta.pro/images/95861430d36702af5587aa4cfe743f72.jpg'),
(36033, 2494, 'Away S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128645.mp4', 'http://timg.bdta.pro/images/7129bfc94e35e2c6a7dcbdde5542969d.jpg'),
(36034, 2494, 'Away S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128646.mp4', 'http://timg.bdta.pro/images/35f765b4450c8aedd1f55ac4bf7500ba.jpg'),
(36035, 2494, 'Away S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128647.mp4', 'http://timg.bdta.pro/images/9edcd3bfd85d2bebd407fde0b5766540.jpg'),
(36036, 2494, 'Away S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128648.mp4', 'http://timg.bdta.pro/images/518e37f9430e752531ff41c4aff5021d.jpg'),
(36037, 2495, 'Como Se Tornar Uma Divindade na Flórida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128629.mp4', 'http://timg.bdta.pro/images/c1af84c0e4c2183c510eaf78910271d3.jpg'),
(36038, 2495, 'Como Se Tornar Uma Divindade na Flórida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128630.mp4', 'http://timg.bdta.pro/images/92f879125405f8ae378af06c09383712.jpg'),
(36039, 2495, 'Como Se Tornar Uma Divindade na Flórida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128631.mp4', 'http://timg.bdta.pro/images/5d86217d41b443c80dee1521ef071e84.jpg'),
(36040, 2495, 'Como Se Tornar Uma Divindade na Flórida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128632.mp4', 'http://timg.bdta.pro/images/e7e4ce352dd2caf6a17dbd983b69a758.jpg'),
(36041, 2495, 'Como Se Tornar Uma Divindade na Flórida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128633.mp4', 'http://timg.bdta.pro/images/33eb5edc16ca953d27c22ce3385c7da7.jpg'),
(36042, 2495, 'Como Se Tornar Uma Divindade na Flórida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128634.mp4', 'http://timg.bdta.pro/images/c68ec358d42d0dea8877f2adeebc011a.jpg'),
(36043, 2495, 'Como Se Tornar Uma Divindade na Flórida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128635.mp4', 'http://timg.bdta.pro/images/df444014c5099555816d68549f43966b.jpg'),
(36044, 2495, 'Como Se Tornar Uma Divindade na Flórida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128636.mp4', 'http://timg.bdta.pro/images/efcc21a28c5caf778624b56e6bd094f1.jpg'),
(36045, 2495, 'Como Se Tornar Uma Divindade na Flórida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128637.mp4', 'http://timg.bdta.pro/images/b2c27ed1af28b74eb91743a434b80c5f.jpg'),
(36046, 2495, 'Como Se Tornar Uma Divindade na Flórida S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128638.mp4', 'http://timg.bdta.pro/images/1017cbf65e20520e57b12d9374907800.jpg'),
(36047, 2496, 'Flaked S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128615.mp4', 'http://timg.bdta.pro/images/5c3cf705347dcaa7b07134ea92634c40.jpg'),
(36048, 2496, 'Flaked S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128616.mp4', 'http://timg.bdta.pro/images/be348d6f5a344d9cf92037543ae6373b.jpg'),
(36049, 2496, 'Flaked S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128617.mp4', 'http://timg.bdta.pro/images/2236e9497209cd7155a23df1e18bd6e7.jpg'),
(36050, 2496, 'Flaked S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128618.mp4', 'http://timg.bdta.pro/images/3b4a8d74cfcecb99296aa22694dc9a38.jpg'),
(36051, 2496, 'Flaked S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128619.mp4', 'http://timg.bdta.pro/images/ff591da4f0c3a7bf34737da0548b35d7.jpg'),
(36052, 2496, 'Flaked S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128620.mp4', 'http://timg.bdta.pro/images/467905309fa86deb3812768fd8c2868c.jpg'),
(36053, 2496, 'Flaked S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128621.mp4', 'http://timg.bdta.pro/images/10c8d1d6fd50fcb2c13a76cea16ac33a.jpg'),
(36054, 2496, 'Flaked S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128622.mp4', 'http://timg.bdta.pro/images/e377c3420882f34bbd450ec53a23e2ef.jpg'),
(36055, 2497, 'Flaked S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128623.mp4', 'http://timg.bdta.pro/images/a07e402fa4e4de1e6e59b6323edd0bcc.jpg'),
(36056, 2497, 'Flaked S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128624.mp4', 'http://timg.bdta.pro/images/6f949507b697eb7bf0a6533e8055d15f.jpg'),
(36057, 2497, 'Flaked S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128625.mp4', 'http://timg.bdta.pro/images/5b72e8f6b5ebb91362c8ee744263633c.jpg'),
(36058, 2497, 'Flaked S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128626.mp4', 'http://timg.bdta.pro/images/66cb2421a45f8eea950778e74a1787fd.jpg'),
(36059, 2497, 'Flaked S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128627.mp4', 'http://timg.bdta.pro/images/bf2ac4b8b01908932acb35da85d9a051.jpg'),
(36060, 2497, 'Flaked S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128628.mp4', 'http://timg.bdta.pro/images/99e59a6d7075bb4946bfb96dec96a8b8.jpg'),
(36061, 2498, 'Flint Town S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128607.mp4', 'http://timg.bdta.pro/images/cf96a4676f810da6291719ae81ca5ff1.jpg'),
(36062, 2498, 'Flint Town S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128608.mp4', 'http://timg.bdta.pro/images/4cc67b6ea99ab5bbdcfc7e50021dacf3.jpg'),
(36063, 2498, 'Flint Town S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128609.mp4', 'http://timg.bdta.pro/images/87fbff06a8d1c166c6c66baaaa1b9dc8.jpg'),
(36064, 2498, 'Flint Town S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128610.mp4', 'http://timg.bdta.pro/images/fd1b784069f561d55f16437d35eca255.jpg'),
(36065, 2498, 'Flint Town S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128611.mp4', 'http://timg.bdta.pro/images/a3e45996d0d859abc95f7074b9af1371.jpg'),
(36066, 2498, 'Flint Town S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128612.mp4', 'http://timg.bdta.pro/images/3c8718c9e6dcb409685d0591ec836263.jpg'),
(36067, 2498, 'Flint Town S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128613.mp4', 'http://timg.bdta.pro/images/221ab4b84ccfe8496113b98ebc813a24.jpg'),
(36068, 2498, 'Flint Town S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128614.mp4', 'http://timg.bdta.pro/images/0ae77985bf29b023a9061235045459da.jpg'),
(36069, 2499, 'Gêmeos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128599.mp4', 'http://timg.bdta.pro/images/0ef314c564a818ac276a0a9e4813d096.jpg'),
(36070, 2499, 'Gêmeos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128600.mp4', 'http://gstaticontent.com/images/3iFKuVpStPgZ6ImRriVeJ712scC_big.jpg'),
(36071, 2499, 'Gêmeos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128601.mp4', 'http://gstaticontent.com/images/3iFKuVpStPgZ6ImRriVeJ712scC_big.jpg'),
(36072, 2499, 'Gêmeos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128602.mp4', 'http://gstaticontent.com/images/3iFKuVpStPgZ6ImRriVeJ712scC_big.jpg'),
(36073, 2499, 'Gêmeos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128603.mp4', 'http://gstaticontent.com/images/3iFKuVpStPgZ6ImRriVeJ712scC_big.jpg'),
(36074, 2499, 'Gêmeos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128604.mp4', 'http://gstaticontent.com/images/3iFKuVpStPgZ6ImRriVeJ712scC_big.jpg'),
(36075, 2499, 'Gêmeos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128605.mp4', 'http://gstaticontent.com/images/3iFKuVpStPgZ6ImRriVeJ712scC_big.jpg'),
(36076, 2499, 'Gêmeos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128606.mp4', 'http://gstaticontent.com/images/3iFKuVpStPgZ6ImRriVeJ712scC_big.jpg'),
(36077, 2500, 'I May Destroy You S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128587.mp4', 'http://timg.bdta.pro/images/896c85937f257d9a1e2d89d2b27d6c93.jpg'),
(36078, 2500, 'I May Destroy You S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128588.mp4', 'http://timg.bdta.pro/images/b4722f03e8bb8d3113ec9fb4913971a3.jpg'),
(36079, 2500, 'I May Destroy You S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128589.mp4', 'http://timg.bdta.pro/images/6d208bb29229a2b7d1591fd868223b62.jpg'),
(36080, 2500, 'I May Destroy You S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128590.mp4', 'http://timg.bdta.pro/images/63b64057d1ce0567ac8c08e6b8e352ac.jpg'),
(36081, 2500, 'I May Destroy You S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128591.mp4', 'http://timg.bdta.pro/images/3570027d43b88e782d549daf68529b21.jpg'),
(36082, 2500, 'I May Destroy You S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128592.mp4', 'http://timg.bdta.pro/images/b596c1c8d548672ff219aacf8e7b8e6a.jpg'),
(36083, 2500, 'I May Destroy You S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128593.mp4', 'http://timg.bdta.pro/images/015f3df9453982f3abbe4d6eab6a9bdb.jpg'),
(36084, 2500, 'I May Destroy You S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128594.mp4', 'http://timg.bdta.pro/images/15397f9abdeb5d99ee95c841f9eac578.jpg'),
(36085, 2500, 'I May Destroy You S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128595.mp4', 'http://timg.bdta.pro/images/6935ea8e8b2b2d450f66630c4d7d63eb.jpg'),
(36086, 2500, 'I May Destroy You S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128596.mp4', 'http://timg.bdta.pro/images/d8d7c9bf04c92af59280d104dc6dbab6.jpg'),
(36087, 2500, 'I May Destroy You S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/128597.mp4', 'http://timg.bdta.pro/images/47fbe745fb4fce50268a9c87051a7908.jpg'),
(36088, 2500, 'I May Destroy You S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/128598.mp4', 'http://timg.bdta.pro/images/bbcaa87fb945ebd85fbdd64faf875fa2.jpg'),
(36089, 2501, 'Julie and the Phantoms S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128578.mp4', 'http://timg.bdta.pro/images/bce7a323af5616bf95fb2e7d2fc0c630.jpg'),
(36090, 2501, 'Julie and the Phantoms S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128579.mp4', 'http://timg.bdta.pro/images/97f8797cf8f99a929433b24d4b96be53.jpg'),
(36091, 2501, 'Julie and the Phantoms S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128580.mp4', 'http://timg.bdta.pro/images/93d72d5b5ee3454c8e07b38fb4789045.jpg'),
(36092, 2501, 'Julie and the Phantoms S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128581.mp4', 'http://timg.bdta.pro/images/1452ef23baf2adaf0b2402e9f312f658.jpg'),
(36093, 2501, 'Julie and the Phantoms S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128582.mp4', 'http://timg.bdta.pro/images/cbfab8309445a758cd95dd63579ad1e8.jpg'),
(36094, 2501, 'Julie and the Phantoms S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128583.mp4', 'http://timg.bdta.pro/images/a509d6f4da21fec1393a34ea59905a3b.jpg'),
(36095, 2501, 'Julie and the Phantoms S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128584.mp4', 'http://timg.bdta.pro/images/33b2f65750768be3385f18541e0eae62.jpg'),
(36096, 2501, 'Julie and the Phantoms S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128585.mp4', 'http://timg.bdta.pro/images/0ee631dc5b1594db76064f615ee06a1c.jpg'),
(36097, 2501, 'Julie and the Phantoms S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128586.mp4', 'http://timg.bdta.pro/images/817b98d35802f2e1c9e9855d05bf1173.jpg'),
(36098, 2502, 'Longe de Você S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128568.mp4', 'http://gstaticontent.com/images/cDWMvkimPF42RvjJ5yLR467bt2v_big.jpg'),
(36099, 2502, 'Longe de Você S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128569.mp4', 'http://gstaticontent.com/images/cDWMvkimPF42RvjJ5yLR467bt2v_big.jpg'),
(36100, 2502, 'Longe de Você S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128570.mp4', 'http://gstaticontent.com/images/cDWMvkimPF42RvjJ5yLR467bt2v_big.jpg'),
(36101, 2502, 'Longe de Você S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128571.mp4', 'http://gstaticontent.com/images/cDWMvkimPF42RvjJ5yLR467bt2v_big.jpg'),
(36102, 2502, 'Longe de Você S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128572.mp4', 'http://gstaticontent.com/images/cDWMvkimPF42RvjJ5yLR467bt2v_big.jpg'),
(36103, 2502, 'Longe de Você S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128573.mp4', 'http://gstaticontent.com/images/cDWMvkimPF42RvjJ5yLR467bt2v_big.jpg'),
(36104, 2502, 'Longe de Você S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128574.mp4', 'http://gstaticontent.com/images/cDWMvkimPF42RvjJ5yLR467bt2v_big.jpg'),
(36105, 2502, 'Longe de Você S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128575.mp4', 'http://gstaticontent.com/images/cDWMvkimPF42RvjJ5yLR467bt2v_big.jpg'),
(36106, 2502, 'Longe de Você S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128576.mp4', 'http://gstaticontent.com/images/cDWMvkimPF42RvjJ5yLR467bt2v_big.jpg'),
(36107, 2502, 'Longe de Você S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128577.mp4', 'http://gstaticontent.com/images/cDWMvkimPF42RvjJ5yLR467bt2v_big.jpg'),
(36108, 2503, 'Memórias de Idhún S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128563.mp4', 'http://timg.bdta.pro/images/1a7ce9fbe4d3d61d188e01d2a653fa70.jpg'),
(36109, 2503, 'Memórias de Idhún S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128564.mp4', 'http://timg.bdta.pro/images/4de400bb8782aaf2eb246c7a46751a91.jpg'),
(36110, 2503, 'Memórias de Idhún S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128565.mp4', 'http://timg.bdta.pro/images/cb7576ef6947ac9da19c08e6f84662a7.jpg'),
(36111, 2503, 'Memórias de Idhún S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128566.mp4', 'http://timg.bdta.pro/images/2e9da10a08e5e8e4f1d069a6f36f169e.jpg'),
(36112, 2503, 'Memórias de Idhún S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128567.mp4', 'http://timg.bdta.pro/images/b1c63d13e977d8a30aa1b51d62b9a0e0.jpg'),
(36113, 2504, 'Mulher Arte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128553.mp4', 'http://gstaticontent.com/images/91fcbbe46dfaae648ae8ae4c9d1cfe14.jpg'),
(36114, 2504, 'Mulher Arte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128554.mp4', 'http://gstaticontent.com/images/91fcbbe46dfaae648ae8ae4c9d1cfe14.jpg'),
(36115, 2504, 'Mulher Arte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128555.mp4', 'http://gstaticontent.com/images/91fcbbe46dfaae648ae8ae4c9d1cfe14.jpg'),
(36116, 2504, 'Mulher Arte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128556.mp4', 'http://gstaticontent.com/images/91fcbbe46dfaae648ae8ae4c9d1cfe14.jpg'),
(36117, 2504, 'Mulher Arte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128557.mp4', 'http://gstaticontent.com/images/91fcbbe46dfaae648ae8ae4c9d1cfe14.jpg'),
(36118, 2504, 'Mulher Arte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128558.mp4', 'http://gstaticontent.com/images/91fcbbe46dfaae648ae8ae4c9d1cfe14.jpg'),
(36119, 2504, 'Mulher Arte S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128559.mp4', 'http://gstaticontent.com/images/91fcbbe46dfaae648ae8ae4c9d1cfe14.jpg'),
(36120, 2504, 'Mulher Arte S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128560.mp4', 'http://gstaticontent.com/images/91fcbbe46dfaae648ae8ae4c9d1cfe14.jpg'),
(36121, 2504, 'Mulher Arte S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128561.mp4', 'http://gstaticontent.com/images/91fcbbe46dfaae648ae8ae4c9d1cfe14.jpg'),
(36122, 2504, 'Mulher Arte S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128562.mp4', 'http://gstaticontent.com/images/91fcbbe46dfaae648ae8ae4c9d1cfe14.jpg'),
(36123, 2505, 'O Jovem Wallander S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174718.mp4', 'http://timg.bdta.pro/images/90ad0ce96c8ebc0c71641a8641cd990d.jpg'),
(36124, 2505, 'O Jovem Wallander S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174719.mp4', 'http://timg.bdta.pro/images/ed0ff3ffd7ab19386fb2b1bb13e9d993.jpg'),
(36125, 2505, 'O Jovem Wallander S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174720.mp4', 'http://timg.bdta.pro/images/a4c88d0188a18f5a31770bcc95791fe1.jpg'),
(36126, 2505, 'O Jovem Wallander S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174721.mp4', 'http://timg.bdta.pro/images/3f4e8083552926cc06e78eea092d7df2.jpg'),
(36127, 2505, 'O Jovem Wallander S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174722.mp4', 'http://timg.bdta.pro/images/65167d55e117a9f2e4c2c02cc6789df8.jpg'),
(36128, 2505, 'O Jovem Wallander S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174723.mp4', 'http://timg.bdta.pro/images/079530fead87b7067d337488a7a5d59c.jpg'),
(36129, 2506, 'O Jovem Wallander S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174724.mp4', 'http://timg.bdta.pro/images/21b77b9eb757d3cd2899c19bc1c74343.jpg'),
(36130, 2506, 'O Jovem Wallander S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174725.mp4', 'http://timg.bdta.pro/images/bcbb8782c7baf43aecc529f8f25033b4.jpg'),
(36131, 2506, 'O Jovem Wallander S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174726.mp4', 'http://timg.bdta.pro/images/ba0355f49ad4d484f27ea3c8b32ea343.jpg'),
(36132, 2506, 'O Jovem Wallander S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174727.mp4', 'http://timg.bdta.pro/images/ada3c439dcfe9d60a2813f940c53f4b8.jpg'),
(36133, 2506, 'O Jovem Wallander S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174728.mp4', 'http://timg.bdta.pro/images/5755eeec916998c60ac8b8749dd9ab0b.jpg'),
(36134, 2506, 'O Jovem Wallander S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174729.mp4', 'http://timg.bdta.pro/images/73525c2994aceb267729cfd50f4bd0dc.jpg'),
(36135, 2507, 'Operacao Big Hero S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128507.mp4', 'http://timg.bdta.pro/images/5cc85e79c6b52a1dd6aa925d4ce525df.jpg'),
(36136, 2507, 'Operacao Big Hero S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128508.mp4', 'http://timg.bdta.pro/images/8fbfd0c93dae44079a77213213c2ca80.jpg'),
(36137, 2507, 'Operacao Big Hero S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128509.mp4', 'http://timg.bdta.pro/images/b0c90874f34a9cf515544a2ce65f8209.jpg'),
(36138, 2507, 'Operacao Big Hero S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128510.mp4', 'http://timg.bdta.pro/images/6c561d22e9c5ba894c2b273c5c5d5891.jpg'),
(36139, 2507, 'Operacao Big Hero S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128511.mp4', 'http://timg.bdta.pro/images/6a4e78b407c0ee62c0d10318adb247e4.jpg'),
(36140, 2507, 'Operacao Big Hero S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128512.mp4', 'http://timg.bdta.pro/images/09b4575db3612efb835d758a7bc2da85.jpg'),
(36141, 2507, 'Operacao Big Hero S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128513.mp4', 'http://timg.bdta.pro/images/8eead5b9fb6063b5b334b92c6b400fd5.jpg'),
(36142, 2507, 'Operacao Big Hero S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128514.mp4', 'http://timg.bdta.pro/images/ff5d44eb3f2b0f9ef5a9ba11f11e7e1b.jpg'),
(36143, 2507, 'Operacao Big Hero S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128515.mp4', 'http://timg.bdta.pro/images/ffe0e729618591a43a053b875be2d0ba.jpg'),
(36144, 2507, 'Operacao Big Hero S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128516.mp4', 'http://timg.bdta.pro/images/883aa0464694a432dd6f0842c42af126.jpg'),
(36145, 2507, 'Operacao Big Hero S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/128517.mp4', 'http://timg.bdta.pro/images/5ff804c1f8dddf2d9f992c29b378494b.jpg'),
(36146, 2507, 'Operacao Big Hero S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/128518.mp4', 'http://timg.bdta.pro/images/b00e6e37de1ee9de2aa4158a3c9ec415.jpg'),
(36147, 2507, 'Operacao Big Hero S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/128519.mp4', 'http://timg.bdta.pro/images/55de2244115b833aedb1df898b665e38.jpg'),
(36148, 2507, 'Operacao Big Hero S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/128520.mp4', 'http://timg.bdta.pro/images/84dfb2f90f2cd7a792ad31db6725a96b.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(36149, 2507, 'Operacao Big Hero S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/128521.mp4', 'http://timg.bdta.pro/images/6339ce6377738aca9629394a3a30578a.jpg'),
(36150, 2507, 'Operacao Big Hero S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/128522.mp4', 'http://timg.bdta.pro/images/92d264b4de8b5ae4521fb8a6cb23e7b2.jpg'),
(36151, 2507, 'Operacao Big Hero S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/128523.mp4', 'http://timg.bdta.pro/images/d5add0a7e99553752ada1b24c6529985.jpg'),
(36152, 2507, 'Operacao Big Hero S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/128524.mp4', 'http://timg.bdta.pro/images/036313d516a55f5a7984ec5feeeceaa1.jpg'),
(36153, 2507, 'Operacao Big Hero S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/128525.mp4', 'http://timg.bdta.pro/images/c724920bc71504f11331c9984ffb4bcd.jpg'),
(36154, 2507, 'Operacao Big Hero S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/128526.mp4', 'http://timg.bdta.pro/images/339549950b69ebd3437bea95df364b07.jpg'),
(36155, 2507, 'Operacao Big Hero S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/128527.mp4', 'http://timg.bdta.pro/images/4ee00ad1bf3ef4bbafbdb22a08b22d84.jpg'),
(36156, 2507, 'Operacao Big Hero S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/128528.mp4', 'http://timg.bdta.pro/images/d7a62d00c78f7be8f69ffc8b05ae51bf.jpg'),
(36157, 2508, 'Operacao Big Hero S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128529.mp4', 'http://timg.bdta.pro/images/3b7f536f8e5e14b5b65623040a23bdea.jpg'),
(36158, 2508, 'Operacao Big Hero S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128530.mp4', 'http://timg.bdta.pro/images/937bef8c6ac7b55fd829604d8d6cbbb0.jpg'),
(36159, 2508, 'Operacao Big Hero S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128531.mp4', 'http://timg.bdta.pro/images/f01878af8d98c4591fa50944ee554d53.jpg'),
(36160, 2508, 'Operacao Big Hero S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128532.mp4', 'http://timg.bdta.pro/images/7e64f8e25838aaaf980c1ea0bee37da4.jpg'),
(36161, 2508, 'Operacao Big Hero S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128533.mp4', 'http://timg.bdta.pro/images/4a762d09f5e892852b06eeb552062175.jpg'),
(36162, 2508, 'Operacao Big Hero S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128534.mp4', 'http://timg.bdta.pro/images/55134faf1c7f9c5277dbbd176dd3b836.jpg'),
(36163, 2508, 'Operacao Big Hero S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128535.mp4', 'http://timg.bdta.pro/images/c85f98c984d9af7b3fb6b195abb35828.jpg'),
(36164, 2508, 'Operacao Big Hero S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128536.mp4', 'http://timg.bdta.pro/images/021722bb8262379f814a0d6bd2adc572.jpg'),
(36165, 2508, 'Operacao Big Hero S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128537.mp4', 'http://timg.bdta.pro/images/f47ea3a0dfdf65bbdae8ae9aec43941f.jpg'),
(36166, 2508, 'Operacao Big Hero S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128538.mp4', 'http://timg.bdta.pro/images/5d5556b413a0526300f07bce02e25f17.jpg'),
(36167, 2508, 'Operacao Big Hero S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/128539.mp4', 'http://timg.bdta.pro/images/8d03b850f38fe29013c5a913175a7e04.jpg'),
(36168, 2508, 'Operacao Big Hero S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/128540.mp4', 'http://timg.bdta.pro/images/74d743fca54f9a295bd70a8b03554042.jpg'),
(36169, 2508, 'Operacao Big Hero S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/128541.mp4', 'http://timg.bdta.pro/images/050c66e3c2ad5179d6a3715b6b1f0a60.jpg'),
(36170, 2508, 'Operacao Big Hero S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/128542.mp4', 'http://timg.bdta.pro/images/36f2fd77ed943b68ab0223e08ae3e1cf.jpg'),
(36171, 2508, 'Operacao Big Hero S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/128543.mp4', 'http://timg.bdta.pro/images/ec7960fca0f617bbd6f4a9238c449179.jpg'),
(36172, 2508, 'Operacao Big Hero S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/128544.mp4', 'http://timg.bdta.pro/images/4ded293bca8d690fd69ba94f5ae9da1b.jpg'),
(36173, 2508, 'Operacao Big Hero S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/128545.mp4', 'http://timg.bdta.pro/images/d297348d4d10dee03856810c0e05c9f7.jpg'),
(36174, 2508, 'Operacao Big Hero S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/128546.mp4', 'http://timg.bdta.pro/images/dc5433136ed7cdacfeea38f6531aa5e3.jpg'),
(36175, 2508, 'Operacao Big Hero S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/128547.mp4', 'http://timg.bdta.pro/images/a16f991f777614a34e2a7a566f981da0.jpg'),
(36176, 2508, 'Operacao Big Hero S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/128548.mp4', 'http://timg.bdta.pro/images/a16f991f777614a34e2a7a566f981da0.jpg'),
(36177, 2508, 'Operacao Big Hero S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/128549.mp4', 'http://timg.bdta.pro/images/a16f991f777614a34e2a7a566f981da0.jpg'),
(36178, 2508, 'Operacao Big Hero S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/128550.mp4', 'http://timg.bdta.pro/images/a16f991f777614a34e2a7a566f981da0.jpg'),
(36179, 2508, 'Operacao Big Hero S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/128551.mp4', 'http://timg.bdta.pro/images/0cb94f74afa9fafe4a01ebf30c774293.jpg'),
(36180, 2508, 'Operacao Big Hero S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/128552.mp4', 'http://timg.bdta.pro/images/ee6120153d1b4875b3d50a8727c8afff.jpg'),
(36181, 2509, 'Rua Dálmatas 101 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128482.mp4', 'http://timg.bdta.pro/images/1db2d96e8d8aa2ad79ae38501947c936.jpg'),
(36182, 2509, 'Rua Dálmatas 101 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128483.mp4', 'http://timg.bdta.pro/images/5ebc893769e9073f60aa45331f90444f.jpg'),
(36183, 2509, 'Rua Dálmatas 101 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128484.mp4', 'http://timg.bdta.pro/images/0c1949e19a855fea9c21c7bd3f6c5e30.jpg'),
(36184, 2509, 'Rua Dálmatas 101 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128485.mp4', 'http://timg.bdta.pro/images/c3709a80dc24cc305509580d0ca00470.jpg'),
(36185, 2509, 'Rua Dálmatas 101 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128486.mp4', 'http://timg.bdta.pro/images/7832353a0e7fddfb593c9bc57cd0ce1e.jpg'),
(36186, 2509, 'Rua Dálmatas 101 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128487.mp4', 'http://gstaticontent.com/images/hEevWtGNwCzjFzPAzAjelDaoiMG_big.jpg'),
(36187, 2509, 'Rua Dálmatas 101 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128488.mp4', 'http://gstaticontent.com/images/hEevWtGNwCzjFzPAzAjelDaoiMG_big.jpg'),
(36188, 2509, 'Rua Dálmatas 101 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128489.mp4', 'http://gstaticontent.com/images/hEevWtGNwCzjFzPAzAjelDaoiMG_big.jpg'),
(36189, 2509, 'Rua Dálmatas 101 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128490.mp4', 'http://gstaticontent.com/images/hEevWtGNwCzjFzPAzAjelDaoiMG_big.jpg'),
(36190, 2509, 'Rua Dálmatas 101 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128491.mp4', 'http://gstaticontent.com/images/hEevWtGNwCzjFzPAzAjelDaoiMG_big.jpg'),
(36191, 2509, 'Rua Dálmatas 101 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/128492.mp4', 'http://gstaticontent.com/images/hEevWtGNwCzjFzPAzAjelDaoiMG_big.jpg'),
(36192, 2509, 'Rua Dálmatas 101 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/128493.mp4', 'http://gstaticontent.com/images/hEevWtGNwCzjFzPAzAjelDaoiMG_big.jpg'),
(36193, 2509, 'Rua Dálmatas 101 S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/128494.mp4', 'http://gstaticontent.com/images/hEevWtGNwCzjFzPAzAjelDaoiMG_big.jpg'),
(36194, 2509, 'Rua Dálmatas 101 S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/128495.mp4', 'http://gstaticontent.com/images/hEevWtGNwCzjFzPAzAjelDaoiMG_big.jpg'),
(36195, 2509, 'Rua Dálmatas 101 S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/128496.mp4', 'http://gstaticontent.com/images/hEevWtGNwCzjFzPAzAjelDaoiMG_big.jpg'),
(36196, 2509, 'Rua Dálmatas 101 S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/128497.mp4', 'http://gstaticontent.com/images/hEevWtGNwCzjFzPAzAjelDaoiMG_big.jpg'),
(36197, 2509, 'Rua Dálmatas 101 S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/128498.mp4', 'http://gstaticontent.com/images/hEevWtGNwCzjFzPAzAjelDaoiMG_big.jpg'),
(36198, 2509, 'Rua Dálmatas 101 S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/128499.mp4', 'http://gstaticontent.com/images/hEevWtGNwCzjFzPAzAjelDaoiMG_big.jpg'),
(36199, 2509, 'Rua Dálmatas 101 S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/128500.mp4', 'http://gstaticontent.com/images/hEevWtGNwCzjFzPAzAjelDaoiMG_big.jpg'),
(36200, 2509, 'Rua Dálmatas 101 S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/128501.mp4', 'http://gstaticontent.com/images/hEevWtGNwCzjFzPAzAjelDaoiMG_big.jpg'),
(36201, 2509, 'Rua Dálmatas 101 S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/128502.mp4', 'http://gstaticontent.com/images/hEevWtGNwCzjFzPAzAjelDaoiMG_big.jpg'),
(36202, 2509, 'Rua Dálmatas 101 S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/128503.mp4', 'http://gstaticontent.com/images/hEevWtGNwCzjFzPAzAjelDaoiMG_big.jpg'),
(36203, 2509, 'Rua Dálmatas 101 S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/128504.mp4', 'http://gstaticontent.com/images/hEevWtGNwCzjFzPAzAjelDaoiMG_big.jpg'),
(36204, 2509, 'Rua Dálmatas 101 S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/128505.mp4', 'http://gstaticontent.com/images/hEevWtGNwCzjFzPAzAjelDaoiMG_big.jpg'),
(36205, 2509, 'Rua Dálmatas 101 S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/128506.mp4', 'http://gstaticontent.com/images/hEevWtGNwCzjFzPAzAjelDaoiMG_big.jpg'),
(36206, 2510, 'Street Food: América Latina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128476.mp4', 'http://timg.bdta.pro/images/90ac2fcba2fc82f548489d9346779968.jpg'),
(36207, 2510, 'Street Food: América Latina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128477.mp4', 'http://timg.bdta.pro/images/b73e81475e43b2921b73993b230c84cc.jpg'),
(36208, 2510, 'Street Food: América Latina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128478.mp4', 'http://timg.bdta.pro/images/20ad0885235a3472ad2b0d9903cdc5d4.jpg'),
(36209, 2510, 'Street Food: América Latina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128479.mp4', 'http://timg.bdta.pro/images/d04beda833d709786df4ad2e3364f0ea.jpg'),
(36210, 2510, 'Street Food: América Latina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128480.mp4', 'http://timg.bdta.pro/images/08ca4352738a2f8e9c91781e00eed2be.jpg'),
(36211, 2510, 'Street Food: América Latina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128481.mp4', 'http://timg.bdta.pro/images/a4e8a444b46439d4b4d52eedb112da02.jpg'),
(36212, 2511, 'Trailer Park Boys The Animated Series S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128456.mp4', 'http://timg.bdta.pro/images/607f766e54626ddc2001047e5e11c493.jpg'),
(36213, 2511, 'Trailer Park Boys The Animated Series S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128457.mp4', 'http://timg.bdta.pro/images/2b783d34ebdfc9dbda63dfd646103fac.jpg'),
(36214, 2511, 'Trailer Park Boys The Animated Series S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128458.mp4', 'http://timg.bdta.pro/images/b2bde6ecf9b6a4b16c5bb5c393718813.jpg'),
(36215, 2511, 'Trailer Park Boys The Animated Series S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128459.mp4', 'http://timg.bdta.pro/images/9eb12eae84de7af8bf17d4bcb4cbc55a.jpg'),
(36216, 2511, 'Trailer Park Boys The Animated Series S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128460.mp4', 'http://timg.bdta.pro/images/bd6288b6894d18fedcc6ab8c82ebd675.jpg'),
(36217, 2511, 'Trailer Park Boys The Animated Series S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128461.mp4', 'http://timg.bdta.pro/images/2b2c8974711d980cdd449e73b28c894e.jpg'),
(36218, 2511, 'Trailer Park Boys The Animated Series S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128462.mp4', 'http://timg.bdta.pro/images/fa600ae5742d739913078e7d58c48252.jpg'),
(36219, 2511, 'Trailer Park Boys The Animated Series S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128463.mp4', 'http://timg.bdta.pro/images/102ad1606eda97343ab78261abb9386f.jpg'),
(36220, 2511, 'Trailer Park Boys The Animated Series S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128464.mp4', 'http://timg.bdta.pro/images/6df8cab78cfe1f4ee5ab7da9ec6c40ac.jpg'),
(36221, 2511, 'Trailer Park Boys The Animated Series S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128465.mp4', 'http://timg.bdta.pro/images/eedd6535aeeaaf089151940d74c46c36.jpg'),
(36222, 2512, 'Trailer Park Boys The Animated Series S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128466.mp4', 'http://timg.bdta.pro/images/71a7b7a166f74d6d89e1bebe933dd21f.jpg'),
(36223, 2512, 'Trailer Park Boys The Animated Series S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128467.mp4', 'http://timg.bdta.pro/images/b4a58ad5b779cef0bebdf4289e2a2a09.jpg'),
(36224, 2512, 'Trailer Park Boys The Animated Series S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128468.mp4', 'http://timg.bdta.pro/images/d70485acab71f6ea045227aa2c2eefcf.jpg'),
(36225, 2512, 'Trailer Park Boys The Animated Series S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128469.mp4', 'http://timg.bdta.pro/images/366bf8fac5d59047e06e11c79f48a876.jpg'),
(36226, 2512, 'Trailer Park Boys The Animated Series S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128470.mp4', 'http://timg.bdta.pro/images/265ec869394dfeac5a9a449b1da1c345.jpg'),
(36227, 2512, 'Trailer Park Boys The Animated Series S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128471.mp4', 'http://timg.bdta.pro/images/96d75ba9ddf0f9684c04676d15024063.jpg'),
(36228, 2512, 'Trailer Park Boys The Animated Series S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128472.mp4', 'http://timg.bdta.pro/images/1f57beaf1e99cf20ce224d90baaff89c.jpg'),
(36229, 2512, 'Trailer Park Boys The Animated Series S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128473.mp4', 'http://timg.bdta.pro/images/a35a5b3cef331121e936321677294ce0.jpg'),
(36230, 2512, 'Trailer Park Boys The Animated Series S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128474.mp4', 'http://timg.bdta.pro/images/776fab8b1f7cd2dd3e54056dee6ac2ed.jpg'),
(36231, 2512, 'Trailer Park Boys The Animated Series S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128475.mp4', 'http://timg.bdta.pro/images/71ba2cb119a2008417b10505b6bd19e4.jpg'),
(36232, 2513, 'Vintage Voltage [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128446.mp4', 'http://gstaticontent.com/images/kzE2aDvLbHW3Juc4uxdSmsnqpwi_big.jpg'),
(36233, 2513, 'Vintage Voltage [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128447.mp4', 'http://gstaticontent.com/images/kzE2aDvLbHW3Juc4uxdSmsnqpwi_big.jpg'),
(36234, 2513, 'Vintage Voltage [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128448.mp4', 'http://gstaticontent.com/images/kzE2aDvLbHW3Juc4uxdSmsnqpwi_big.jpg'),
(36235, 2513, 'Vintage Voltage [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128449.mp4', 'http://gstaticontent.com/images/kzE2aDvLbHW3Juc4uxdSmsnqpwi_big.jpg'),
(36236, 2513, 'Vintage Voltage [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128450.mp4', 'http://gstaticontent.com/images/kzE2aDvLbHW3Juc4uxdSmsnqpwi_big.jpg'),
(36237, 2513, 'Vintage Voltage [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128451.mp4', 'http://gstaticontent.com/images/kzE2aDvLbHW3Juc4uxdSmsnqpwi_big.jpg'),
(36238, 2513, 'Vintage Voltage [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128452.mp4', 'http://gstaticontent.com/images/kzE2aDvLbHW3Juc4uxdSmsnqpwi_big.jpg'),
(36239, 2513, 'Vintage Voltage [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128453.mp4', 'http://gstaticontent.com/images/kzE2aDvLbHW3Juc4uxdSmsnqpwi_big.jpg'),
(36240, 2513, 'Vintage Voltage [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128454.mp4', 'http://gstaticontent.com/images/kzE2aDvLbHW3Juc4uxdSmsnqpwi_big.jpg'),
(36241, 2513, 'Vintage Voltage [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128455.mp4', 'http://gstaticontent.com/images/kzE2aDvLbHW3Juc4uxdSmsnqpwi_big.jpg'),
(36242, 2514, 'Was It Love [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128430.mp4', 'http://timg.bdta.pro/images/8985ab9c5e6c877345c5554c80ec5e3d.jpg'),
(36243, 2514, 'Was It Love [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128431.mp4', 'http://timg.bdta.pro/images/bf81ec7bcfe6292dd803942d796e8e97.jpg'),
(36244, 2514, 'Was It Love [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128432.mp4', 'http://timg.bdta.pro/images/b1d40f276fa303d8c475f380feddbf14.jpg'),
(36245, 2514, 'Was It Love [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128433.mp4', 'http://timg.bdta.pro/images/a0cbb9e29bef9dfbc21bc6286d70bfe6.jpg'),
(36246, 2514, 'Was It Love [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128434.mp4', 'http://timg.bdta.pro/images/c7531b214d2dc764a951d62deb0fbc35.jpg'),
(36247, 2514, 'Was It Love [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128435.mp4', 'http://timg.bdta.pro/images/b1bf68676029ec037f7e3eef61090c3d.jpg'),
(36248, 2514, 'Was It Love [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128436.mp4', 'http://timg.bdta.pro/images/01f72e467d2333d4aa582633234142bf.jpg'),
(36249, 2514, 'Was It Love [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128437.mp4', 'http://timg.bdta.pro/images/f148362e0416914f79f7adcb92200b2e.jpg'),
(36250, 2514, 'Was It Love [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/128438.mp4', 'http://timg.bdta.pro/images/a8c1e38ccddb00f85bcc7db682f7e8a1.jpg'),
(36251, 2514, 'Was It Love [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/128439.mp4', 'http://timg.bdta.pro/images/b47b2e7ce68c80f69c59574af5d590a3.jpg'),
(36252, 2514, 'Was It Love [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/128440.mp4', 'http://timg.bdta.pro/images/ff85d29329224082a5cd182cd630b871.jpg'),
(36253, 2514, 'Was It Love [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/128441.mp4', 'http://timg.bdta.pro/images/245b6534a199f7b7888081354e7242f9.jpg'),
(36254, 2514, 'Was It Love [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/128442.mp4', 'http://timg.bdta.pro/images/039a6ab0215256ca02a99e7a4580ca87.jpg'),
(36255, 2514, 'Was It Love [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/128443.mp4', 'http://timg.bdta.pro/images/ff01d46f3e2b28886305544b48a73770.jpg'),
(36256, 2514, 'Was It Love [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/128444.mp4', 'http://timg.bdta.pro/images/f56338cbd0fc41391bcf28b789c38e67.jpg'),
(36257, 2514, 'Was It Love [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/128445.mp4', 'http://timg.bdta.pro/images/f624d15d56b7ae18d285a60b7e533b3a.jpg'),
(36258, 2515, 'A Penúltima Palavra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128215.mp4', 'http://timg.bdta.pro/images/c44b37ed0d8e35080e34df7f8eb0690e.jpg'),
(36259, 2515, 'A Penúltima Palavra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128216.mp4', 'http://timg.bdta.pro/images/4b7c1061573edb72f86b9a003ccb76de.jpg'),
(36260, 2515, 'A Penúltima Palavra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128217.mp4', 'http://timg.bdta.pro/images/09cbb00ac34b7d9a04fc235a4e0d64d5.jpg'),
(36261, 2515, 'A Penúltima Palavra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128218.mp4', 'http://timg.bdta.pro/images/47b1f8ef36b5834ccacad7ffb38b32d3.jpg'),
(36262, 2515, 'A Penúltima Palavra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128219.mp4', 'http://timg.bdta.pro/images/46dc5e33cbe3751bacf633f5a1acc80c.jpg'),
(36263, 2515, 'A Penúltima Palavra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128220.mp4', 'http://timg.bdta.pro/images/fbf1cf1381463a50e5bcb48662e32160.jpg'),
(36264, 2516, 'Amor e Sorte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127080.mp4', 'http://gstaticontent.com/images/k2unBo5OcrHVaUBYndaWdPcQ461_big.jpg'),
(36265, 2516, 'Amor e Sorte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127081.mp4', 'http://gstaticontent.com/images/k2unBo5OcrHVaUBYndaWdPcQ461_big.jpg'),
(36266, 2516, 'Amor e Sorte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127082.mp4', 'http://gstaticontent.com/images/k2unBo5OcrHVaUBYndaWdPcQ461_big.jpg'),
(36267, 2516, 'Amor e Sorte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127083.mp4', 'http://gstaticontent.com/images/k2unBo5OcrHVaUBYndaWdPcQ461_big.jpg'),
(36268, 2517, 'Challenger: Voo Final S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128211.mp4', 'http://timg.bdta.pro/images/8a8706f1ad295a039524aed622fdf3aa.jpg'),
(36269, 2517, 'Challenger: Voo Final S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128212.mp4', 'http://timg.bdta.pro/images/f155e729b7e0cf5b55ba25a13549239a.jpg'),
(36270, 2517, 'Challenger: Voo Final S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128213.mp4', 'http://timg.bdta.pro/images/ac0dba6be5ef80c6f20c5efca4ff70ac.jpg'),
(36271, 2517, 'Challenger: Voo Final S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128214.mp4', 'http://timg.bdta.pro/images/745513791fa3d684226e8aa96c3c5065.jpg'),
(36272, 2518, 'Dragon\'s Dogma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128204.mp4', 'http://timg.bdta.pro/images/25d715b04075d8e6f64e0b3254e81ec5.jpg'),
(36273, 2518, 'Dragon\'s Dogma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128205.mp4', 'http://timg.bdta.pro/images/007e004bd082e9b8ec877d45d5edd53f.jpg'),
(36274, 2518, 'Dragon\'s Dogma S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128206.mp4', 'http://timg.bdta.pro/images/b7e87751221b14aaadc30d67aea5c7bc.jpg'),
(36275, 2518, 'Dragon\'s Dogma S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128207.mp4', 'http://timg.bdta.pro/images/5d3fd12b3ecc2536e0e892307ed016cb.jpg'),
(36276, 2518, 'Dragon\'s Dogma S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128208.mp4', 'http://timg.bdta.pro/images/c7cd4dcd2d82e440b3526b2c8325017f.jpg'),
(36277, 2518, 'Dragon\'s Dogma S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128209.mp4', 'http://timg.bdta.pro/images/d1213f2eae74eebb3beb8de7ffc643a9.jpg'),
(36278, 2518, 'Dragon\'s Dogma S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128210.mp4', 'http://timg.bdta.pro/images/cf0694dd5eee1d169438f6404a5dcb34.jpg'),
(36279, 2519, 'High Fidelity S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131340.mp4', 'http://timg.bdta.pro/images/21bf7ef1b550786a3c8a828ac614ee91.jpg'),
(36280, 2519, 'High Fidelity S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131341.mp4', 'http://timg.bdta.pro/images/d5fff5f76c533f68d867b2ff2846d1f7.jpg'),
(36281, 2519, 'High Fidelity S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131342.mp4', 'http://timg.bdta.pro/images/696b5b822a18e2beb325a0910e12b0cb.jpg'),
(36282, 2519, 'High Fidelity S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131343.mp4', 'http://timg.bdta.pro/images/05c2a395b1cd4ba67076680d96b69c98.jpg'),
(36283, 2519, 'High Fidelity S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131344.mp4', 'http://timg.bdta.pro/images/1fe190f34987598722062713b98e1322.jpg'),
(36284, 2519, 'High Fidelity S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131345.mp4', 'http://timg.bdta.pro/images/4ede4f09e5e95f6c690872c85a1d6cc6.jpg'),
(36285, 2519, 'High Fidelity S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131346.mp4', 'http://timg.bdta.pro/images/b8081e9a59c1a56732e8ec456676d342.jpg'),
(36286, 2519, 'High Fidelity S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h3FrWwcK72Mf5cUZ5haxVnJUzoL.jpg'),
(36287, 2519, 'High Fidelity S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gDf8uOQntrLlyjTFfUAlHMXhld.jpg'),
(36288, 2519, 'High Fidelity S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131349.mp4', 'http://gstaticontent.com/images/tKtx6QEq9kjPeTzWTTpJ4QCqcVy_big.jpg'),
(36289, 2520, 'Jurassic World: Acampamento Jurássico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191889.mp4', 'http://timg.bdta.pro/images/8a77758ba4241c1b12da0250d880d825.jpg'),
(36290, 2520, 'Jurassic World: Acampamento Jurássico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191890.mp4', 'http://timg.bdta.pro/images/b1fc9e2eacb98f5ae407d34559220d5a.jpg'),
(36291, 2520, 'Jurassic World: Acampamento Jurássico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191891.mp4', 'http://timg.bdta.pro/images/ffb7c1d001c7dffe2dc429f8e2ea45d4.jpg'),
(36292, 2520, 'Jurassic World: Acampamento Jurássico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191892.mp4', 'http://timg.bdta.pro/images/2a502edfb24aaa4c0d13f2b9b99f8833.jpg'),
(36293, 2520, 'Jurassic World: Acampamento Jurássico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191893.mp4', 'http://timg.bdta.pro/images/f012cc16de89380dc9edaa8e15d7db63.jpg'),
(36294, 2520, 'Jurassic World: Acampamento Jurássico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191894.mp4', 'http://timg.bdta.pro/images/0e29443da26c7cac3a67ba2bca49d9ff.jpg'),
(36295, 2520, 'Jurassic World: Acampamento Jurássico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191895.mp4', 'http://timg.bdta.pro/images/ccca6f156f0bcd4a870aba634851f77f.jpg'),
(36296, 2520, 'Jurassic World: Acampamento Jurássico S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191896.mp4', 'http://timg.bdta.pro/images/844e1e7728e4708450a714471840942f.jpg'),
(36297, 2521, 'Jurassic World: Acampamento Jurássico S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191897.mp4', 'http://gstaticontent.com/images/y58BCVq1DDpKANjmpBrjpNTPzgm_big.jpg'),
(36298, 2521, 'Jurassic World: Acampamento Jurássico S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191898.mp4', 'http://gstaticontent.com/images/y58BCVq1DDpKANjmpBrjpNTPzgm_big.jpg'),
(36299, 2521, 'Jurassic World: Acampamento Jurássico S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191899.mp4', 'http://gstaticontent.com/images/y58BCVq1DDpKANjmpBrjpNTPzgm_big.jpg'),
(36300, 2521, 'Jurassic World: Acampamento Jurássico S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191900.mp4', 'http://gstaticontent.com/images/y58BCVq1DDpKANjmpBrjpNTPzgm_big.jpg'),
(36301, 2521, 'Jurassic World: Acampamento Jurássico S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191901.mp4', 'http://gstaticontent.com/images/y58BCVq1DDpKANjmpBrjpNTPzgm_big.jpg'),
(36302, 2521, 'Jurassic World: Acampamento Jurássico S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191902.mp4', 'http://gstaticontent.com/images/y58BCVq1DDpKANjmpBrjpNTPzgm_big.jpg'),
(36303, 2521, 'Jurassic World: Acampamento Jurássico S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191903.mp4', 'http://gstaticontent.com/images/y58BCVq1DDpKANjmpBrjpNTPzgm_big.jpg'),
(36304, 2521, 'Jurassic World: Acampamento Jurássico S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191904.mp4', 'http://gstaticontent.com/images/y58BCVq1DDpKANjmpBrjpNTPzgm_big.jpg'),
(36305, 2522, 'Jurassic World: Acampamento Jurássico S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191905.mp4', 'http://gstaticontent.com/images/y58BCVq1DDpKANjmpBrjpNTPzgm_big.jpg'),
(36306, 2522, 'Jurassic World: Acampamento Jurássico S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191906.mp4', 'http://gstaticontent.com/images/y58BCVq1DDpKANjmpBrjpNTPzgm_big.jpg'),
(36307, 2522, 'Jurassic World: Acampamento Jurássico S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191907.mp4', 'http://gstaticontent.com/images/y58BCVq1DDpKANjmpBrjpNTPzgm_big.jpg'),
(36308, 2522, 'Jurassic World: Acampamento Jurássico S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191908.mp4', 'http://gstaticontent.com/images/y58BCVq1DDpKANjmpBrjpNTPzgm_big.jpg'),
(36309, 2522, 'Jurassic World: Acampamento Jurássico S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191909.mp4', 'http://gstaticontent.com/images/y58BCVq1DDpKANjmpBrjpNTPzgm_big.jpg'),
(36310, 2522, 'Jurassic World: Acampamento Jurássico S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191910.mp4', 'http://gstaticontent.com/images/y58BCVq1DDpKANjmpBrjpNTPzgm_big.jpg'),
(36311, 2522, 'Jurassic World: Acampamento Jurássico S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191911.mp4', 'http://gstaticontent.com/images/y58BCVq1DDpKANjmpBrjpNTPzgm_big.jpg'),
(36312, 2522, 'Jurassic World: Acampamento Jurássico S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191912.mp4', 'http://gstaticontent.com/images/y58BCVq1DDpKANjmpBrjpNTPzgm_big.jpg'),
(36313, 2522, 'Jurassic World: Acampamento Jurássico S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191913.mp4', 'http://gstaticontent.com/images/y58BCVq1DDpKANjmpBrjpNTPzgm_big.jpg'),
(36314, 2522, 'Jurassic World: Acampamento Jurássico S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191914.mp4', 'http://gstaticontent.com/images/y58BCVq1DDpKANjmpBrjpNTPzgm_big.jpg'),
(36315, 2523, 'Jurassic World: Acampamento Jurássico S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h6U70rlnodqrpTBPucKGbSFqSqp.jpg'),
(36316, 2523, 'Jurassic World: Acampamento Jurássico S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ikXNfDDRUj0YYWBPhvvOg1OZYeZ.jpg'),
(36317, 2523, 'Jurassic World: Acampamento Jurássico S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/P1cEyfT8H5Y0IS3gF6kpI93Dka.jpg'),
(36318, 2523, 'Jurassic World: Acampamento Jurássico S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fpuSI14g7KD8NsuQimxwAKxVJ5.jpg'),
(36319, 2523, 'Jurassic World: Acampamento Jurássico S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7zgiNWpmqZVzKVS2j1ruTX4GzTn.jpg'),
(36320, 2523, 'Jurassic World: Acampamento Jurássico S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hV1YRyz7cuPAQO6Xjx83RqEssmP.jpg'),
(36321, 2523, 'Jurassic World: Acampamento Jurássico S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hBq8gR6eMoLtixwS8xjGI8rCi4Z.jpg'),
(36322, 2523, 'Jurassic World: Acampamento Jurássico S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rsDbBzDyOQ23MieAFUWUZYvEJE.jpg'),
(36323, 2523, 'Jurassic World: Acampamento Jurássico S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ypNGK8zruzxeOnTTeaLnhh88tYi.jpg'),
(36324, 2523, 'Jurassic World: Acampamento Jurássico S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9H2r3KaSOBQOptWJfSnGHcQ1YEk.jpg'),
(36325, 2523, 'Jurassic World: Acampamento Jurássico S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o5hMgw9FfeVzAn0wyvD4bviPLfO.jpg'),
(36326, 2524, 'Jurassic World: Acampamento Jurássico S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191926.mp4', 'http://timg.bdta.pro/images/893792b5d5cea59f0b14d32159fe3c3f.jpg'),
(36327, 2524, 'Jurassic World: Acampamento Jurássico S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191927.mp4', 'http://timg.bdta.pro/images/07e7475f256ba27cda6a325e43cb9aa4.jpg'),
(36328, 2524, 'Jurassic World: Acampamento Jurássico S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191928.mp4', 'http://timg.bdta.pro/images/29be3672bba69ec23ea062790432ec6e.jpg'),
(36329, 2524, 'Jurassic World: Acampamento Jurássico S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191929.mp4', 'http://timg.bdta.pro/images/05ae15226319d16358f9b105d8127bdd.jpg'),
(36330, 2524, 'Jurassic World: Acampamento Jurássico S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191930.mp4', 'http://timg.bdta.pro/images/8f0832725d3791e3a93a4e0bdf96129a.jpg'),
(36331, 2524, 'Jurassic World: Acampamento Jurássico S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191931.mp4', 'http://timg.bdta.pro/images/09eb98f4fd0b19e0f5ecf7b28d773d14.jpg'),
(36332, 2524, 'Jurassic World: Acampamento Jurássico S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191933.mp4', 'http://timg.bdta.pro/images/60e2498fbea083cb556aa48f48cfae78.jpg'),
(36333, 2524, 'Jurassic World: Acampamento Jurássico S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191934.mp4', 'http://timg.bdta.pro/images/d37a02e70b6d0d89612c8a4ec49c0d63.jpg'),
(36334, 2524, 'Jurassic World: Acampamento Jurássico S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191935.mp4', 'http://timg.bdta.pro/images/a7a8a7b2dc5abc39818367261dd201de.jpg'),
(36335, 2524, 'Jurassic World: Acampamento Jurássico S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191936.mp4', 'http://timg.bdta.pro/images/867a705993c1b9be7ed267b067ce8d72.jpg'),
(36336, 2524, 'Jurassic World: Acampamento Jurássico S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191937.mp4', 'http://timg.bdta.pro/images/d4da6737f7ca14d44f14957031b89885.jpg'),
(36337, 2525, 'Sem Maturidade Para Isso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128196.mp4', 'http://timg.bdta.pro/images/3c2f069901db50c90be8da1dc1a22c1f.jpg'),
(36338, 2525, 'Sem Maturidade Para Isso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128197.mp4', 'http://timg.bdta.pro/images/daad92b76b26733843fefb50a90fa557.jpg'),
(36339, 2525, 'Sem Maturidade Para Isso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128198.mp4', 'http://timg.bdta.pro/images/ebc35bbee584155fdc282ae1fd7da44e.jpg'),
(36340, 2525, 'Sem Maturidade Para Isso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128199.mp4', 'http://timg.bdta.pro/images/218970abd2596e9f96d75e57b12c4945.jpg'),
(36341, 2525, 'Sem Maturidade Para Isso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128200.mp4', 'http://timg.bdta.pro/images/d6a560f62e14e877bdb0cfb0739998ba.jpg'),
(36342, 2525, 'Sem Maturidade Para Isso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128201.mp4', 'http://timg.bdta.pro/images/c323f6f27a3daecf7dadb67c7e561a6c.jpg'),
(36343, 2525, 'Sem Maturidade Para Isso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128202.mp4', 'http://timg.bdta.pro/images/9a98db01ee33ffc83e6befe147ba5331.jpg'),
(36344, 2525, 'Sem Maturidade Para Isso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128203.mp4', 'http://timg.bdta.pro/images/61208dd2c4f59d3858af38f9914f9710.jpg'),
(36345, 2526, 'The Third Day S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132849.mp4', 'http://timg.bdta.pro/images/36c89a8c4bf14f13787ebbee18af4264.jpg'),
(36346, 2526, 'The Third Day S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132850.mp4', 'http://timg.bdta.pro/images/41df5452d48449a3167cea5568d86a42.jpg'),
(36347, 2526, 'The Third Day S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132851.mp4', 'http://timg.bdta.pro/images/597edb4a771a5aaf98ccc1bb5a9164a1.jpg'),
(36348, 2526, 'The Third Day S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132852.mp4', 'http://timg.bdta.pro/images/06cf8dc16d00b2a92b91d2c003c7174b.jpg'),
(36349, 2526, 'The Third Day S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132853.mp4', 'http://timg.bdta.pro/images/2e25cbcd1ed36f718faa14711a830113.jpg'),
(36350, 2526, 'The Third Day S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132854.mp4', 'http://timg.bdta.pro/images/89e5d559bbadf75a1e7f0632de930af5.jpg'),
(36351, 2527, 'Viagem A Qualquer Custo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128190.mp4', 'http://gstaticontent.com/images/4158d77e66acbabb74c48e5e13130441.jpg'),
(36352, 2527, 'Viagem A Qualquer Custo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128191.mp4', 'http://gstaticontent.com/images/4158d77e66acbabb74c48e5e13130441.jpg'),
(36353, 2527, 'Viagem A Qualquer Custo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128192.mp4', 'http://gstaticontent.com/images/4158d77e66acbabb74c48e5e13130441.jpg'),
(36354, 2527, 'Viagem A Qualquer Custo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128193.mp4', 'http://gstaticontent.com/images/4158d77e66acbabb74c48e5e13130441.jpg'),
(36355, 2527, 'Viagem A Qualquer Custo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128194.mp4', 'http://gstaticontent.com/images/4158d77e66acbabb74c48e5e13130441.jpg'),
(36356, 2527, 'Viagem A Qualquer Custo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128195.mp4', 'http://gstaticontent.com/images/4158d77e66acbabb74c48e5e13130441.jpg'),
(36357, 2528, 'Zona de Separação S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130566.mp4', 'http://timg.bdta.pro/images/64b0991e1e92893900a7ae5949e527ba.jpg'),
(36358, 2528, 'Zona de Separação S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130567.mp4', 'http://timg.bdta.pro/images/1596efba6cb813d7652214d3774884ea.jpg'),
(36359, 2528, 'Zona de Separação S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130568.mp4', 'http://timg.bdta.pro/images/1ca8fa454a02e2a6541a7bd292ea48cd.jpg'),
(36360, 2528, 'Zona de Separação S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130569.mp4', 'http://timg.bdta.pro/images/ddd36e2c0c3b7833ad7ea0585b2cdb3b.jpg'),
(36361, 2528, 'Zona de Separação S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130570.mp4', 'http://timg.bdta.pro/images/5b521dfda19f71c51f56e3fb93573ad6.jpg'),
(36362, 2528, 'Zona de Separação S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130571.mp4', 'http://timg.bdta.pro/images/a11dbba44856b174b3b7c30f9dab6a57.jpg'),
(36363, 2528, 'Zona de Separação S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130572.mp4', 'http://timg.bdta.pro/images/28f3ca751d3ec1ccc4a947e24f713adb.jpg'),
(36364, 2528, 'Zona de Separação S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkuT54GdVsGg3YLjU4l3ME3S9WD.jpg'),
(36365, 2528, 'Zona de Separação S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/esVeVqLEX8T0xDEzP0xHSbMHncJ.jpg'),
(36366, 2528, 'Zona de Separação S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uWPwfol437N7MvHcCLIMHbFl6Jb.jpg'),
(36367, 2528, 'Zona de Separação S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/130576.mp4', 'http://gstaticontent.com/images/4SqKIHz3jn4TmOV13tINbTrVMEF_big.jpg'),
(36368, 2528, 'Zona de Separação S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/130577.mp4', 'http://gstaticontent.com/images/4SqKIHz3jn4TmOV13tINbTrVMEF_big.jpg'),
(36369, 2528, 'Zona de Separação S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/130578.mp4', 'http://gstaticontent.com/images/4SqKIHz3jn4TmOV13tINbTrVMEF_big.jpg'),
(36370, 2529, 'Família Moderna S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137565.mp4', 'http://timg.bdta.pro/images/544efc084279f1dd5010adc80ee1ca40.jpg'),
(36371, 2529, 'Família Moderna S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137566.mp4', 'http://timg.bdta.pro/images/37998fc530ff8add73eb003fa20fdad0.jpg'),
(36372, 2529, 'Família Moderna S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137567.mp4', 'http://timg.bdta.pro/images/cc742a8a45caafa821c3aca9de124902.jpg'),
(36373, 2529, 'Família Moderna S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137568.mp4', 'http://timg.bdta.pro/images/9f574cfe80825d8de22f67b241b1713c.jpg'),
(36374, 2529, 'Família Moderna S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137569.mp4', 'http://timg.bdta.pro/images/2a4fc9573e8be4d5ae570264bc6c7c48.jpg'),
(36375, 2529, 'Família Moderna S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137570.mp4', 'http://timg.bdta.pro/images/f5d9437477666bc6e87feb15b7539524.jpg'),
(36376, 2529, 'Família Moderna S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137571.mp4', 'http://timg.bdta.pro/images/1d3029749cec8c923d2ef5e30b4411a2.jpg'),
(36377, 2529, 'Família Moderna S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137572.mp4', 'http://timg.bdta.pro/images/42012643f81d6cfcf055547e5f79ea61.jpg'),
(36378, 2529, 'Família Moderna S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137573.mp4', 'http://timg.bdta.pro/images/08559ce9a0d6a9c1b6f040c21ac4fb80.jpg'),
(36379, 2529, 'Família Moderna S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137574.mp4', 'http://timg.bdta.pro/images/fc749be4edf8def8453d9dfb1cbcfa8a.jpg'),
(36380, 2529, 'Família Moderna S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137575.mp4', 'http://timg.bdta.pro/images/f8ab57baccccc5d6c936cfe8a536376f.jpg'),
(36381, 2529, 'Família Moderna S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137576.mp4', 'http://timg.bdta.pro/images/5cb387fb73e18b5d005230a4d16dc310.jpg'),
(36382, 2529, 'Família Moderna S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137577.mp4', 'http://timg.bdta.pro/images/f08c29731010b37dbd46bfdbd51820da.jpg'),
(36383, 2529, 'Família Moderna S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137578.mp4', 'http://timg.bdta.pro/images/ff0cdd8178a864da2525f5c377255151.jpg'),
(36384, 2529, 'Família Moderna S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137579.mp4', 'http://timg.bdta.pro/images/17a5c78b648c2cdf189e45627d73d31d.jpg'),
(36385, 2529, 'Família Moderna S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137580.mp4', 'http://timg.bdta.pro/images/be195c9583ad325fcbe0f7bc5a7b6060.jpg'),
(36386, 2529, 'Família Moderna S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137581.mp4', 'http://timg.bdta.pro/images/9e1d228482040c4088ea4a2497f1e081.jpg'),
(36387, 2529, 'Família Moderna S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137582.mp4', 'http://timg.bdta.pro/images/df7c63c070ec877a200c1a9a06124961.jpg'),
(36388, 2529, 'Família Moderna S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137583.mp4', 'http://timg.bdta.pro/images/1403eb8f6b8667b0e208d2668d963376.jpg'),
(36389, 2529, 'Família Moderna S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137584.mp4', 'http://timg.bdta.pro/images/c354763b85480d08fc0cd19cbcf2080d.jpg'),
(36390, 2529, 'Família Moderna S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/137585.mp4', 'http://timg.bdta.pro/images/45ca90f2bd739564100b417abe917e35.jpg'),
(36391, 2529, 'Família Moderna S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/137586.mp4', 'http://timg.bdta.pro/images/f36ca2149bb70d0cebebfb43414bc18f.jpg'),
(36392, 2529, 'Família Moderna S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/137587.mp4', 'http://timg.bdta.pro/images/fa1a4af2649ed5af2ef239207fb9506e.jpg'),
(36393, 2529, 'Família Moderna S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/137588.mp4', 'http://timg.bdta.pro/images/07503fd3087d260a06eb012afefaa8a7.jpg'),
(36394, 2530, 'Família Moderna S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137589.mp4', 'http://timg.bdta.pro/images/0fe7b8865f405ca6e3864654eb458f52.jpg'),
(36395, 2530, 'Família Moderna S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137590.mp4', 'http://timg.bdta.pro/images/45349bb0e776f2c95189fabd2f95654b.jpg'),
(36396, 2530, 'Família Moderna S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137591.mp4', 'http://timg.bdta.pro/images/dd07c4e145d23f30333eea825b156c69.jpg'),
(36397, 2530, 'Família Moderna S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137592.mp4', 'http://timg.bdta.pro/images/13cf27bfba8b0dc334b6edb44b46a33b.jpg'),
(36398, 2530, 'Família Moderna S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137593.mp4', 'http://timg.bdta.pro/images/178fb2b3b000ae6c0800bb6dca3ed71b.jpg'),
(36399, 2530, 'Família Moderna S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137594.mp4', 'http://timg.bdta.pro/images/edad44dbdfc461545bc0510fa112223a.jpg'),
(36400, 2530, 'Família Moderna S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137595.mp4', 'http://timg.bdta.pro/images/262aa48f4a42f90f93de1fff519f5dec.jpg'),
(36401, 2530, 'Família Moderna S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137596.mp4', 'http://timg.bdta.pro/images/8c0bebc0814fa178ad5c6a85b0490ad6.jpg'),
(36402, 2530, 'Família Moderna S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137597.mp4', 'http://timg.bdta.pro/images/e73a596e5685c1f4f34845365c69b35d.jpg'),
(36403, 2530, 'Família Moderna S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137598.mp4', 'http://timg.bdta.pro/images/a24615a89f513ba9e42a301479a7bd5e.jpg'),
(36404, 2530, 'Família Moderna S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137599.mp4', 'http://timg.bdta.pro/images/8f6de288efa2264cdbaea95f89d1251b.jpg'),
(36405, 2530, 'Família Moderna S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137600.mp4', 'http://timg.bdta.pro/images/c510949ecb27dd6dd2dbff7c20746f65.jpg'),
(36406, 2530, 'Família Moderna S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137601.mp4', 'http://timg.bdta.pro/images/d9a6db46c6a3519dd86ee8e264a9c502.jpg'),
(36407, 2530, 'Família Moderna S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137602.mp4', 'http://timg.bdta.pro/images/d144f93c239c707581af66875f938b5e.jpg'),
(36408, 2530, 'Família Moderna S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137603.mp4', 'http://timg.bdta.pro/images/0fd16784e438faace8143eec4651cc48.jpg'),
(36409, 2530, 'Família Moderna S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137604.mp4', 'http://timg.bdta.pro/images/581c82588a02ad908caaffc94052be57.jpg'),
(36410, 2530, 'Família Moderna S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137605.mp4', 'http://timg.bdta.pro/images/0cfc8c32e90d05cddfcd1a9ea62067bf.jpg'),
(36411, 2530, 'Família Moderna S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137606.mp4', 'http://timg.bdta.pro/images/c5e80c5ca4121c3dacb12a77743c8855.jpg'),
(36412, 2530, 'Família Moderna S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137607.mp4', 'http://timg.bdta.pro/images/f80f78f6b766c5dbd19989303caadb66.jpg'),
(36413, 2530, 'Família Moderna S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137608.mp4', 'http://timg.bdta.pro/images/808b8b7a4f1a7062c5e9caea49ca61e0.jpg'),
(36414, 2530, 'Família Moderna S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/137609.mp4', 'http://timg.bdta.pro/images/b797a53d3e33d0bd747881c41f73411f.jpg'),
(36415, 2530, 'Família Moderna S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/137610.mp4', 'http://timg.bdta.pro/images/b37fb5fdc3f9b6607c8f588fc404fe59.jpg'),
(36416, 2530, 'Família Moderna S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/137611.mp4', 'http://timg.bdta.pro/images/7a29f33e7f25f7bdf23133277be36da0.jpg'),
(36417, 2530, 'Família Moderna S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/137612.mp4', 'http://timg.bdta.pro/images/76786eb2d0c6b6d9b51df918cfaa86e4.jpg'),
(36418, 2531, 'Família Moderna S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137613.mp4', 'http://timg.bdta.pro/images/e92c85ea2690f656ad41742f501e4fd0.jpg'),
(36419, 2531, 'Família Moderna S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137614.mp4', 'http://timg.bdta.pro/images/7b3434f37fdee6a97acf6ee6ebd81779.jpg'),
(36420, 2531, 'Família Moderna S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137615.mp4', 'http://timg.bdta.pro/images/5b15b6b6d9994328d42d36931af55ec5.jpg'),
(36421, 2531, 'Família Moderna S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137616.mp4', 'http://timg.bdta.pro/images/acae2cad98f7240b69a3493d9271be7a.jpg'),
(36422, 2531, 'Família Moderna S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137617.mp4', 'http://timg.bdta.pro/images/f65bb6f3df783c6ac113a3a1d1c2f881.jpg'),
(36423, 2531, 'Família Moderna S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137618.mp4', 'http://timg.bdta.pro/images/a4f4ed8fce3fd8ce1005c516f4f28b2d.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(36424, 2531, 'Família Moderna S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137619.mp4', 'http://timg.bdta.pro/images/2e5e01028fc8ce035f9bf5722e69d1f0.jpg'),
(36425, 2531, 'Família Moderna S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137620.mp4', 'http://timg.bdta.pro/images/f45285d41c0a6426feed31962f7e102d.jpg'),
(36426, 2531, 'Família Moderna S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137621.mp4', 'http://timg.bdta.pro/images/afd78abb04fcebe6e97f39c58cf7dbfc.jpg'),
(36427, 2531, 'Família Moderna S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137622.mp4', 'http://timg.bdta.pro/images/004218f626e499b997b6178ca8ebdf6a.jpg'),
(36428, 2531, 'Família Moderna S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137623.mp4', 'http://timg.bdta.pro/images/18fdaddfbf8cdba8cd4b10bf30028775.jpg'),
(36429, 2531, 'Família Moderna S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137624.mp4', 'http://timg.bdta.pro/images/b6986150c38a1e435f584813b274a2f0.jpg'),
(36430, 2531, 'Família Moderna S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137625.mp4', 'http://timg.bdta.pro/images/2f5320e268ee117305b71a5e2ad92dc6.jpg'),
(36431, 2531, 'Família Moderna S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137626.mp4', 'http://timg.bdta.pro/images/0fd8bb53fbabfc568abad5ffcf484768.jpg'),
(36432, 2531, 'Família Moderna S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137627.mp4', 'http://timg.bdta.pro/images/e9dd0ad047437976157b076cba10b492.jpg'),
(36433, 2531, 'Família Moderna S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137628.mp4', 'http://timg.bdta.pro/images/558036897a46ad0ce42876ef5593b9c5.jpg'),
(36434, 2531, 'Família Moderna S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137629.mp4', 'http://timg.bdta.pro/images/1223aaae24d753fd4e3698e28a2213e8.jpg'),
(36435, 2531, 'Família Moderna S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137630.mp4', 'http://timg.bdta.pro/images/07996c2607fc4172aef428e5e45fd054.jpg'),
(36436, 2531, 'Família Moderna S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137631.mp4', 'http://timg.bdta.pro/images/8d64b4c822248de6162ec6e3666aa50d.jpg'),
(36437, 2531, 'Família Moderna S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137632.mp4', 'http://timg.bdta.pro/images/5c47096e9cfebbfb209ac5aad2a34b1c.jpg'),
(36438, 2531, 'Família Moderna S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/137633.mp4', 'http://timg.bdta.pro/images/1e5b34e00cb10af2c49e590d310b5a74.jpg'),
(36439, 2531, 'Família Moderna S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/137634.mp4', 'http://timg.bdta.pro/images/f07ffcbbd9e0f002c017c81056d0057c.jpg'),
(36440, 2531, 'Família Moderna S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/137635.mp4', 'http://timg.bdta.pro/images/7f597eb9b1da5ba4ad43378bf438c8f4.jpg'),
(36441, 2531, 'Família Moderna S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/137636.mp4', 'http://timg.bdta.pro/images/6c773012ebd5dc3a908b637b7da17298.jpg'),
(36442, 2532, 'Família Moderna S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137637.mp4', 'http://timg.bdta.pro/images/47fa1303d9060d9748a6765e10953c53.jpg'),
(36443, 2532, 'Família Moderna S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137638.mp4', 'http://timg.bdta.pro/images/9bc870da411fb61b187be509cc6f059e.jpg'),
(36444, 2532, 'Família Moderna S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137639.mp4', 'http://timg.bdta.pro/images/0850a560c455cfe41d07f5beb47676a0.jpg'),
(36445, 2532, 'Família Moderna S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137640.mp4', 'http://timg.bdta.pro/images/41c3152f8f868e43d4731f2a65331d5b.jpg'),
(36446, 2532, 'Família Moderna S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137641.mp4', 'http://timg.bdta.pro/images/6d19c0dd45622bc8abc9409acfe678d5.jpg'),
(36447, 2532, 'Família Moderna S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137642.mp4', 'http://timg.bdta.pro/images/3a95e237367acfdf4d2921eab98f0a51.jpg'),
(36448, 2532, 'Família Moderna S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137643.mp4', 'http://timg.bdta.pro/images/61314f87b370c8a8ef18819297f942d9.jpg'),
(36449, 2532, 'Família Moderna S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137644.mp4', 'http://timg.bdta.pro/images/e9c7568a612f19768c2939900b1a72db.jpg'),
(36450, 2532, 'Família Moderna S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137645.mp4', 'http://timg.bdta.pro/images/5d5f3a8358a012612f0f0307e8f53103.jpg'),
(36451, 2532, 'Família Moderna S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137646.mp4', 'http://timg.bdta.pro/images/0ca39c6dbb234992bebbc088d3044230.jpg'),
(36452, 2532, 'Família Moderna S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137647.mp4', 'http://timg.bdta.pro/images/2e5605ec1eee7ff9093166e5e1f2ebf4.jpg'),
(36453, 2532, 'Família Moderna S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137648.mp4', 'http://timg.bdta.pro/images/d104910d22109afc5e5b644cf16a0316.jpg'),
(36454, 2532, 'Família Moderna S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137649.mp4', 'http://timg.bdta.pro/images/3290d5f6d6a1333dedf45abf79df59cb.jpg'),
(36455, 2532, 'Família Moderna S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137650.mp4', 'http://timg.bdta.pro/images/36df3550c411fc0bf6a447757a897d09.jpg'),
(36456, 2532, 'Família Moderna S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137651.mp4', 'http://timg.bdta.pro/images/17466746edaa4bcfeb0bf5a5828f76c4.jpg'),
(36457, 2532, 'Família Moderna S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137652.mp4', 'http://timg.bdta.pro/images/83d9112220208d78d4e90b4c15806354.jpg'),
(36458, 2532, 'Família Moderna S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137653.mp4', 'http://timg.bdta.pro/images/d5e0d39fd6a6b9ebfd37bfe503d4a3dd.jpg'),
(36459, 2532, 'Família Moderna S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137654.mp4', 'http://timg.bdta.pro/images/527bbc859107a3876ea44fe6c6929674.jpg'),
(36460, 2532, 'Família Moderna S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137655.mp4', 'http://timg.bdta.pro/images/81470624f2eb874fc766791fcce2e70f.jpg'),
(36461, 2532, 'Família Moderna S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137656.mp4', 'http://timg.bdta.pro/images/6afc92f2ca4496334ffd64562bc5d85f.jpg'),
(36462, 2532, 'Família Moderna S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/137657.mp4', 'http://timg.bdta.pro/images/37ef7742ab9a75b32e5b0a78e5bf145a.jpg'),
(36463, 2532, 'Família Moderna S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/137658.mp4', 'http://timg.bdta.pro/images/f2b281cde005662236e089981deeeef7.jpg'),
(36464, 2532, 'Família Moderna S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/137659.mp4', 'http://timg.bdta.pro/images/ae09ccc7fd1fde7ec1579c4ab8f00c0f.jpg'),
(36465, 2532, 'Família Moderna S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/137660.mp4', 'http://timg.bdta.pro/images/baea7c0b0e85fc9c786369d8662295b2.jpg'),
(36466, 2533, 'Família Moderna S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137661.mp4', 'http://timg.bdta.pro/images/2597833647747ad94d85305b9a3539a6.jpg'),
(36467, 2533, 'Família Moderna S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137662.mp4', 'http://timg.bdta.pro/images/20e7b9dd7c93b94875dcf3f3118c3789.jpg'),
(36468, 2533, 'Família Moderna S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137663.mp4', 'http://timg.bdta.pro/images/d0fe93f7910f1b616483c7577b53541f.jpg'),
(36469, 2533, 'Família Moderna S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137664.mp4', 'http://timg.bdta.pro/images/8e4764329a9a9b675dd553ab31b96dc0.jpg'),
(36470, 2533, 'Família Moderna S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137665.mp4', 'http://timg.bdta.pro/images/f5d238d2c40fd9f6099d0e1e36f757b1.jpg'),
(36471, 2533, 'Família Moderna S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137666.mp4', 'http://timg.bdta.pro/images/713333f3e7997cfe07cf7ec0b630d95a.jpg'),
(36472, 2533, 'Família Moderna S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137667.mp4', 'http://timg.bdta.pro/images/469aaf01e29c2a596f9887989543362e.jpg'),
(36473, 2533, 'Família Moderna S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137668.mp4', 'http://timg.bdta.pro/images/fa74533ed48d61c39aeb3131c74faf19.jpg'),
(36474, 2533, 'Família Moderna S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137669.mp4', 'http://timg.bdta.pro/images/6166fd5dc62e91be3927e520055be6a2.jpg'),
(36475, 2533, 'Família Moderna S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137670.mp4', 'http://timg.bdta.pro/images/86ee1e2b60d2cedcb2f74b44ef4bed64.jpg'),
(36476, 2533, 'Família Moderna S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137671.mp4', 'http://timg.bdta.pro/images/b3da5fe459cfc92da636bdf05b6d5eca.jpg'),
(36477, 2533, 'Família Moderna S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137672.mp4', 'http://timg.bdta.pro/images/1ebafe9e71c28786cb60a336b0d80336.jpg'),
(36478, 2533, 'Família Moderna S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137673.mp4', 'http://timg.bdta.pro/images/750da9c2ac071e3b844b43ae1389b331.jpg'),
(36479, 2533, 'Família Moderna S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137674.mp4', 'http://timg.bdta.pro/images/c0d164100b174312e58fb0852d0bdeed.jpg'),
(36480, 2533, 'Família Moderna S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137675.mp4', 'http://timg.bdta.pro/images/5b7c50dc2401e039835a86efcfc3d497.jpg'),
(36481, 2533, 'Família Moderna S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137676.mp4', 'http://timg.bdta.pro/images/7d599bd162970e3f979702c8ffd6eb90.jpg'),
(36482, 2533, 'Família Moderna S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137677.mp4', 'http://timg.bdta.pro/images/51dd0ac7ba6f46f820c6d3f8bb4212d0.jpg'),
(36483, 2533, 'Família Moderna S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137678.mp4', 'http://timg.bdta.pro/images/2356f8744bd4b60ae5aa96ec38903fd5.jpg'),
(36484, 2533, 'Família Moderna S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137679.mp4', 'http://timg.bdta.pro/images/bb776570dc607e90c6e096ef080da45d.jpg'),
(36485, 2533, 'Família Moderna S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137680.mp4', 'http://timg.bdta.pro/images/15374ed2007ec5e36ad311fbb2f8f43e.jpg'),
(36486, 2533, 'Família Moderna S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/137681.mp4', 'http://timg.bdta.pro/images/4f568d8fdcfd01bdee6ea512565eb89a.jpg'),
(36487, 2533, 'Família Moderna S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/137682.mp4', 'http://timg.bdta.pro/images/2ee1a0f3baad607d56da4fdd3c808461.jpg'),
(36488, 2533, 'Família Moderna S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/137683.mp4', 'http://timg.bdta.pro/images/1bfca49429c09786522811d5eb8aec78.jpg'),
(36489, 2533, 'Família Moderna S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/137684.mp4', 'http://timg.bdta.pro/images/acb200dd162b520f1f4300fa0d16e9dc.jpg'),
(36490, 2534, 'Família Moderna S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137685.mp4', 'http://timg.bdta.pro/images/41b01dc354cc0201f91df8bb601b292d.jpg'),
(36491, 2534, 'Família Moderna S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137686.mp4', 'http://timg.bdta.pro/images/67a9d7def078fe8f0936426bfc21549f.jpg'),
(36492, 2534, 'Família Moderna S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137687.mp4', 'http://timg.bdta.pro/images/c3b94b7a3eb5ed04ff3658f834b08b61.jpg'),
(36493, 2534, 'Família Moderna S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137688.mp4', 'http://timg.bdta.pro/images/262612e55a6d059a9f20da804dfe57b6.jpg'),
(36494, 2534, 'Família Moderna S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137689.mp4', 'http://timg.bdta.pro/images/cc6dabe3dc47bc6eda9e1755af09a8ce.jpg'),
(36495, 2534, 'Família Moderna S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137690.mp4', 'http://timg.bdta.pro/images/4cae8ab374902deb66d492f010457f89.jpg'),
(36496, 2534, 'Família Moderna S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137691.mp4', 'http://timg.bdta.pro/images/7736d45e7667c25e3294edc6f60d14f2.jpg'),
(36497, 2534, 'Família Moderna S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137692.mp4', 'http://timg.bdta.pro/images/ac4e0cbc56b8c0f7fad9ae3a787331be.jpg'),
(36498, 2534, 'Família Moderna S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137693.mp4', 'http://timg.bdta.pro/images/3691c8fa86175302ca8559bbdb632d60.jpg'),
(36499, 2534, 'Família Moderna S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137694.mp4', 'http://timg.bdta.pro/images/11cc0f8e90f3df222c23dd665a2c342f.jpg'),
(36500, 2534, 'Família Moderna S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137695.mp4', 'http://timg.bdta.pro/images/270f7266ef7f8778a2ea6a57c9864814.jpg'),
(36501, 2534, 'Família Moderna S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137696.mp4', 'http://timg.bdta.pro/images/c84b77142b33d4d9b130d28db557e3f5.jpg'),
(36502, 2534, 'Família Moderna S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137697.mp4', 'http://timg.bdta.pro/images/992ca733fa568bae3b93d19ed3c1c3e0.jpg'),
(36503, 2534, 'Família Moderna S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137698.mp4', 'http://timg.bdta.pro/images/50a0b548349a1f38ca1e3cd5c14ac2ae.jpg'),
(36504, 2534, 'Família Moderna S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137699.mp4', 'http://timg.bdta.pro/images/3f00a53abcdd08b5372e78269c6e7c9b.jpg'),
(36505, 2534, 'Família Moderna S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137700.mp4', 'http://timg.bdta.pro/images/1cc025cbf83aebf406693a8a5dfcf0ec.jpg'),
(36506, 2534, 'Família Moderna S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137701.mp4', 'http://timg.bdta.pro/images/bd1b0ae0de8590b96b4063d1e22301a6.jpg'),
(36507, 2534, 'Família Moderna S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137702.mp4', 'http://timg.bdta.pro/images/9d083591234c653b9bbb9f5964c6641c.jpg'),
(36508, 2534, 'Família Moderna S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137703.mp4', 'http://timg.bdta.pro/images/f78259c7d85b1cfc0c9cbc6ecc6a3a1e.jpg'),
(36509, 2534, 'Família Moderna S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137704.mp4', 'http://timg.bdta.pro/images/8d5127c4e974ce281551936cca5c4405.jpg'),
(36510, 2534, 'Família Moderna S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/137705.mp4', 'http://timg.bdta.pro/images/21930160bb1bef5937d709bb78631419.jpg'),
(36511, 2534, 'Família Moderna S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/137706.mp4', 'http://timg.bdta.pro/images/bcfcac194a9fcf3513d0eeae6856dd8c.jpg'),
(36512, 2534, 'Família Moderna S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/137707.mp4', 'http://timg.bdta.pro/images/35cc2fee4a45eeebee17ed13b5fe4773.jpg'),
(36513, 2534, 'Família Moderna S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/137708.mp4', 'http://timg.bdta.pro/images/a535df82dd676c5bc0e96259e3662a7f.jpg'),
(36514, 2535, 'Família Moderna S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137709.mp4', 'http://timg.bdta.pro/images/bf5851aaf6ccb57c5a9ce174299c9ba9.jpg'),
(36515, 2535, 'Família Moderna S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137710.mp4', 'http://timg.bdta.pro/images/2af43f12d96c6c828a2fbdbe1502baaa.jpg'),
(36516, 2535, 'Família Moderna S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137711.mp4', 'http://timg.bdta.pro/images/3b318e6867475cfcf4039dda815da27c.jpg'),
(36517, 2535, 'Família Moderna S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137712.mp4', 'http://timg.bdta.pro/images/4d80667dd3fe75d967ca5315d692ff03.jpg'),
(36518, 2535, 'Família Moderna S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137713.mp4', 'http://timg.bdta.pro/images/9f77e3f97c1179b94758f69513e8b6ad.jpg'),
(36519, 2535, 'Família Moderna S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137714.mp4', 'http://timg.bdta.pro/images/9838a2fb2b7e158867d3b34797dfcd5b.jpg'),
(36520, 2535, 'Família Moderna S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137715.mp4', 'http://timg.bdta.pro/images/ffe58a979e0bb8fa8ecddb3a89a5c117.jpg'),
(36521, 2535, 'Família Moderna S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137716.mp4', 'http://timg.bdta.pro/images/c8622c18deeb489453669ed736fc3865.jpg'),
(36522, 2535, 'Família Moderna S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137717.mp4', 'http://timg.bdta.pro/images/f8ff6ca585a31b6b4c736b845fa7d2b9.jpg'),
(36523, 2535, 'Família Moderna S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137718.mp4', 'http://timg.bdta.pro/images/5de22904baaa8112932629b1db49aad7.jpg'),
(36524, 2535, 'Família Moderna S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137719.mp4', 'http://timg.bdta.pro/images/af378f2d3e34f21063a1ece56d37a305.jpg'),
(36525, 2535, 'Família Moderna S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137720.mp4', 'http://timg.bdta.pro/images/6aa8ff95145631881ec70a7b15c7acdc.jpg'),
(36526, 2535, 'Família Moderna S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137721.mp4', 'http://timg.bdta.pro/images/d63b31053893d28022101562ecf50a3b.jpg'),
(36527, 2535, 'Família Moderna S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137722.mp4', 'http://timg.bdta.pro/images/053ba9ddabdeef4de2256b91101ea7af.jpg'),
(36528, 2535, 'Família Moderna S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137723.mp4', 'http://timg.bdta.pro/images/9c49aaa3a2ecd0509202090ae65a2497.jpg'),
(36529, 2535, 'Família Moderna S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137724.mp4', 'http://timg.bdta.pro/images/26766c8f3fa753b480d50f1d249f9e7f.jpg'),
(36530, 2535, 'Família Moderna S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137725.mp4', 'http://timg.bdta.pro/images/790d954f832d196be5071693bf558ffe.jpg'),
(36531, 2535, 'Família Moderna S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137726.mp4', 'http://timg.bdta.pro/images/15d874bac4256cbdd90a7bce8376ae19.jpg'),
(36532, 2535, 'Família Moderna S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137727.mp4', 'http://timg.bdta.pro/images/da8355132d87b4fe91c5ed66ac154333.jpg'),
(36533, 2535, 'Família Moderna S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137728.mp4', 'http://timg.bdta.pro/images/d8020bd3d7bc0e134bb3933f32398b73.jpg'),
(36534, 2535, 'Família Moderna S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/137729.mp4', 'http://timg.bdta.pro/images/618907390411659b91e67dc29148c335.jpg'),
(36535, 2535, 'Família Moderna S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/137730.mp4', 'http://timg.bdta.pro/images/496d5d8b85ea521dd583362de4d8345b.jpg'),
(36536, 2536, 'Família Moderna S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137731.mp4', 'http://timg.bdta.pro/images/5319b03b29a8d2721ac13ea31dee4173.jpg'),
(36537, 2536, 'Família Moderna S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137732.mp4', 'http://timg.bdta.pro/images/76d6305466e431b8f7cf6281d9777425.jpg'),
(36538, 2536, 'Família Moderna S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137733.mp4', 'http://timg.bdta.pro/images/5f415269afd2bbdcf177f75ec0a4f454.jpg'),
(36539, 2536, 'Família Moderna S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137734.mp4', 'http://timg.bdta.pro/images/a4ab8feb58d9975b9b9ddc770b141eaa.jpg'),
(36540, 2536, 'Família Moderna S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137735.mp4', 'http://timg.bdta.pro/images/6336c965b769d1e7c99a6349751a2862.jpg'),
(36541, 2536, 'Família Moderna S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137736.mp4', 'http://timg.bdta.pro/images/988d93b884f9e026f33357e38bc4558f.jpg'),
(36542, 2536, 'Família Moderna S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137737.mp4', 'http://timg.bdta.pro/images/82434b376483e01365340d40e0b83b5c.jpg'),
(36543, 2536, 'Família Moderna S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137738.mp4', 'http://timg.bdta.pro/images/8c58eed281e54c5fdec2bdf2772c2418.jpg'),
(36544, 2536, 'Família Moderna S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137739.mp4', 'http://timg.bdta.pro/images/4b7b680e14bec12bcdbac42542c4e2e0.jpg'),
(36545, 2536, 'Família Moderna S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137740.mp4', 'http://timg.bdta.pro/images/703e3376734ccae6c6d7583a207ada6f.jpg'),
(36546, 2536, 'Família Moderna S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137741.mp4', 'http://timg.bdta.pro/images/6b801898980719016b37186e85dadd5c.jpg'),
(36547, 2536, 'Família Moderna S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137742.mp4', 'http://timg.bdta.pro/images/96f4caa98fe5bb53f3f5799f5fc3cf3e.jpg'),
(36548, 2536, 'Família Moderna S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137743.mp4', 'http://timg.bdta.pro/images/637d4eb3417297c21a6c78a7a498ba72.jpg'),
(36549, 2536, 'Família Moderna S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137744.mp4', 'http://timg.bdta.pro/images/7b1132cb7b88c4c65f377060e2e0884e.jpg'),
(36550, 2536, 'Família Moderna S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137745.mp4', 'http://timg.bdta.pro/images/60ec3a8c41c69f17eeed05b396e2e256.jpg'),
(36551, 2536, 'Família Moderna S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137746.mp4', 'http://timg.bdta.pro/images/5ee6db535e73031d96b3199898450b82.jpg'),
(36552, 2536, 'Família Moderna S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137747.mp4', 'http://timg.bdta.pro/images/0bcb3ecf3e0524195d24c2938f459bf5.jpg'),
(36553, 2536, 'Família Moderna S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137748.mp4', 'http://timg.bdta.pro/images/fb3ffff122320f568d9bb4d4f379583c.jpg'),
(36554, 2536, 'Família Moderna S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137749.mp4', 'http://timg.bdta.pro/images/9a6cee22536f7118762a98d9b6f58f93.jpg'),
(36555, 2536, 'Família Moderna S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137750.mp4', 'http://timg.bdta.pro/images/263a39b985e017402f20875bbbc7ee4b.jpg'),
(36556, 2536, 'Família Moderna S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/137751.mp4', 'http://timg.bdta.pro/images/f15e9b35e654f8cfd21c116cd597f864.jpg'),
(36557, 2536, 'Família Moderna S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/137752.mp4', 'http://timg.bdta.pro/images/cda982683ec218ab2982df6b1f21e6e9.jpg'),
(36558, 2537, 'Família Moderna S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137753.mp4', 'http://timg.bdta.pro/images/f9c5db1169ede94926e59b1e8a35514f.jpg'),
(36559, 2537, 'Família Moderna S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137754.mp4', 'http://timg.bdta.pro/images/c87712bea44905b1afa34cc8a498c13b.jpg'),
(36560, 2537, 'Família Moderna S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137755.mp4', 'http://timg.bdta.pro/images/bbeb268b9468343ba983b5af77ab63a3.jpg'),
(36561, 2537, 'Família Moderna S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137756.mp4', 'http://timg.bdta.pro/images/0904fa654568f8210ca1f2df114c445b.jpg'),
(36562, 2537, 'Família Moderna S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137757.mp4', 'http://timg.bdta.pro/images/1a198f692214b873b55f20ba650f5a56.jpg'),
(36563, 2537, 'Família Moderna S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137758.mp4', 'http://timg.bdta.pro/images/f9162ee71ccca366c2273c9d584c136c.jpg'),
(36564, 2537, 'Família Moderna S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137759.mp4', 'http://timg.bdta.pro/images/45d75055ddf42eea48561b736bd92545.jpg'),
(36565, 2537, 'Família Moderna S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137760.mp4', 'http://timg.bdta.pro/images/11d844691fb622e17c2b276c7de32497.jpg'),
(36566, 2537, 'Família Moderna S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137761.mp4', 'http://timg.bdta.pro/images/f5022fe5acab6b747c34d610b209cfee.jpg'),
(36567, 2537, 'Família Moderna S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137762.mp4', 'http://timg.bdta.pro/images/d6bbe89af9158352420f1f8cbcde8113.jpg'),
(36568, 2537, 'Família Moderna S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137763.mp4', 'http://timg.bdta.pro/images/57afd5009f13fc2d0609252096987277.jpg'),
(36569, 2537, 'Família Moderna S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137764.mp4', 'http://timg.bdta.pro/images/74bdde7c0841348e99da5df8e557699f.jpg'),
(36570, 2537, 'Família Moderna S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137765.mp4', 'http://timg.bdta.pro/images/bb7f0348c3b82c63bfe8fed4d57d8348.jpg'),
(36571, 2537, 'Família Moderna S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137766.mp4', 'http://timg.bdta.pro/images/2c2b1876d16ed67b3b6d4dd7a22bdee3.jpg'),
(36572, 2537, 'Família Moderna S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137767.mp4', 'http://timg.bdta.pro/images/4a8e05bb1c50b3964b97bd8f8d6e8d78.jpg'),
(36573, 2537, 'Família Moderna S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137768.mp4', 'http://timg.bdta.pro/images/9d6caf586d482f530ffd7d6b24660e74.jpg'),
(36574, 2537, 'Família Moderna S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137769.mp4', 'http://timg.bdta.pro/images/c49403ec1543dc2a0f3df3d43f025e7b.jpg'),
(36575, 2537, 'Família Moderna S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137770.mp4', 'http://timg.bdta.pro/images/5b5da1be56118b12c9ed0f7dcf73befe.jpg'),
(36576, 2537, 'Família Moderna S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137771.mp4', 'http://timg.bdta.pro/images/1595b9c9251ab3a0540dee5b7fc7bb27.jpg'),
(36577, 2537, 'Família Moderna S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137772.mp4', 'http://timg.bdta.pro/images/3522855e28fd5525c2b95c5d91f61ee5.jpg'),
(36578, 2537, 'Família Moderna S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/137773.mp4', 'http://timg.bdta.pro/images/a7f7beaa4036d59e379835cead949779.jpg'),
(36579, 2537, 'Família Moderna S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/137774.mp4', 'http://timg.bdta.pro/images/eae8f6386562fbf4ce4bea5858c01f93.jpg'),
(36580, 2538, 'Família Moderna S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137775.mp4', 'http://timg.bdta.pro/images/b2147540c0207bb57bea9c1e5de828d8.jpg'),
(36581, 2538, 'Família Moderna S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137776.mp4', 'http://timg.bdta.pro/images/4af9a0202c6d0a4df7e594881f725436.jpg'),
(36582, 2538, 'Família Moderna S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137777.mp4', 'http://timg.bdta.pro/images/f998bff446d11287df43afef8af8ad4b.jpg'),
(36583, 2538, 'Família Moderna S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137778.mp4', 'http://timg.bdta.pro/images/3fd318192027c159d1824c6c44b1c2c3.jpg'),
(36584, 2538, 'Família Moderna S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137779.mp4', 'http://timg.bdta.pro/images/31ade815cad409388509f07a1307360e.jpg'),
(36585, 2538, 'Família Moderna S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137780.mp4', 'http://timg.bdta.pro/images/c438ad792e3cd7e91ff0722976d23b40.jpg'),
(36586, 2538, 'Família Moderna S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137781.mp4', 'http://timg.bdta.pro/images/30ed9295abac5d2d12dd00fe012fce52.jpg'),
(36587, 2538, 'Família Moderna S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137782.mp4', 'http://timg.bdta.pro/images/70143a00c274d788f12c3bbf0c4dd4bb.jpg'),
(36588, 2538, 'Família Moderna S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137783.mp4', 'http://timg.bdta.pro/images/fa553cc5f67a5548c1b72039c10c2fbe.jpg'),
(36589, 2538, 'Família Moderna S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137784.mp4', 'http://timg.bdta.pro/images/5341831c09493f48cfedcf4e682356dc.jpg'),
(36590, 2538, 'Família Moderna S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137785.mp4', 'http://timg.bdta.pro/images/ba4b92a59fe9db36d65af1b9cec617ed.jpg'),
(36591, 2538, 'Família Moderna S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137786.mp4', 'http://timg.bdta.pro/images/c887c460574a2ae152385dfa6a09752c.jpg'),
(36592, 2538, 'Família Moderna S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137787.mp4', 'http://timg.bdta.pro/images/80649238bf875e27efef66cce1d8eb5a.jpg'),
(36593, 2538, 'Família Moderna S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137788.mp4', 'http://timg.bdta.pro/images/e9d9ad613a296a36a4ce34ca6221adb7.jpg'),
(36594, 2538, 'Família Moderna S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137789.mp4', 'http://timg.bdta.pro/images/bd2ee04a2ab7c16406ba92d3bf657ed3.jpg'),
(36595, 2538, 'Família Moderna S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137790.mp4', 'http://timg.bdta.pro/images/54a648d71aac76ea95eed2f782adf5ac.jpg'),
(36596, 2538, 'Família Moderna S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137791.mp4', 'http://timg.bdta.pro/images/4873aa7145c8a51d5217496b45165e5d.jpg'),
(36597, 2538, 'Família Moderna S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137792.mp4', 'http://timg.bdta.pro/images/e3d6352abb4324bd57b9d4f3aca94a60.jpg'),
(36598, 2538, 'Família Moderna S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137793.mp4', 'http://timg.bdta.pro/images/980fd96de312962f37e33d5eaac9faea.jpg'),
(36599, 2538, 'Família Moderna S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137794.mp4', 'http://timg.bdta.pro/images/29517493053d19897dffa93720605fa0.jpg'),
(36600, 2538, 'Família Moderna S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/137795.mp4', 'http://timg.bdta.pro/images/f654585df6eb39883c73c95eee314d78.jpg'),
(36601, 2538, 'Família Moderna S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/137796.mp4', 'http://timg.bdta.pro/images/149c19ce8338115eea82be992068e0b8.jpg'),
(36602, 2539, 'Família Moderna S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137797.mp4', 'http://timg.bdta.pro/images/ad9af15e9b2451ad36c9baeba0f6008f.jpg'),
(36603, 2539, 'Família Moderna S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137798.mp4', 'http://timg.bdta.pro/images/496b4d189721beb7af3547b5cd862a0c.jpg'),
(36604, 2539, 'Família Moderna S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137799.mp4', 'http://timg.bdta.pro/images/8c4ceaee4d04801ac5a0c16ad5da1b94.jpg'),
(36605, 2539, 'Família Moderna S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137800.mp4', 'http://timg.bdta.pro/images/acf38a9abfa071f2ab913c4e6da02858.jpg'),
(36606, 2539, 'Família Moderna S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137801.mp4', 'http://timg.bdta.pro/images/07e4755c95b994e3825a441b5c27f9de.jpg'),
(36607, 2539, 'Família Moderna S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137802.mp4', 'http://timg.bdta.pro/images/2e0811ea4898deb93717b0ba6aa1b943.jpg'),
(36608, 2539, 'Família Moderna S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137803.mp4', 'http://timg.bdta.pro/images/d3c76aaf28842f5a1c7330e0859d9056.jpg'),
(36609, 2539, 'Família Moderna S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137804.mp4', 'http://timg.bdta.pro/images/eacd8ab369c500dffb1ed5eb5bd1cc02.jpg'),
(36610, 2539, 'Família Moderna S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yATEJatDOGtv1vPiysiAxvFzoZy.jpg'),
(36611, 2539, 'Família Moderna S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rwhQCrxpmV43iiFwqZ8uhGND3r4.jpg'),
(36612, 2539, 'Família Moderna S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137807.mp4', 'http://gstaticontent.com/images/gGOZeGx3ggP5O9qvswRPN7PRVWn_big.jpg'),
(36613, 2539, 'Família Moderna S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137808.mp4', 'http://gstaticontent.com/images/gGOZeGx3ggP5O9qvswRPN7PRVWn_big.jpg'),
(36614, 2539, 'Família Moderna S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137809.mp4', 'http://gstaticontent.com/images/gGOZeGx3ggP5O9qvswRPN7PRVWn_big.jpg'),
(36615, 2539, 'Família Moderna S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137810.mp4', 'http://gstaticontent.com/images/gGOZeGx3ggP5O9qvswRPN7PRVWn_big.jpg'),
(36616, 2539, 'Família Moderna S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137811.mp4', 'http://gstaticontent.com/images/gGOZeGx3ggP5O9qvswRPN7PRVWn_big.jpg'),
(36617, 2539, 'Família Moderna S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137812.mp4', 'http://gstaticontent.com/images/gGOZeGx3ggP5O9qvswRPN7PRVWn_big.jpg'),
(36618, 2539, 'Família Moderna S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137813.mp4', 'http://gstaticontent.com/images/gGOZeGx3ggP5O9qvswRPN7PRVWn_big.jpg'),
(36619, 2540, 'The Playbook S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128114.mp4', 'http://gstaticontent.com/images/5uF9KDU5oxcWdAw2x4k2QGMPyQm_big.jpg'),
(36620, 2540, 'The Playbook S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128115.mp4', 'http://gstaticontent.com/images/5uF9KDU5oxcWdAw2x4k2QGMPyQm_big.jpg'),
(36621, 2540, 'The Playbook S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128116.mp4', 'http://gstaticontent.com/images/5uF9KDU5oxcWdAw2x4k2QGMPyQm_big.jpg'),
(36622, 2540, 'The Playbook S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128117.mp4', 'http://gstaticontent.com/images/5uF9KDU5oxcWdAw2x4k2QGMPyQm_big.jpg'),
(36623, 2540, 'The Playbook S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128118.mp4', 'http://gstaticontent.com/images/5uF9KDU5oxcWdAw2x4k2QGMPyQm_big.jpg'),
(36624, 2541, 'Operação Ecstasy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170972.mp4', 'http://timg.bdta.pro/images/e8e50ee62d9abd0c9191b70acbe06992.jpg'),
(36625, 2541, 'Operação Ecstasy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170973.mp4', 'http://timg.bdta.pro/images/00cf66ad7a9043670a7ea49e7bb7ebcc.jpg'),
(36626, 2541, 'Operação Ecstasy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170974.mp4', 'http://timg.bdta.pro/images/e7940608465be941d915d1899c505408.jpg'),
(36627, 2541, 'Operação Ecstasy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170975.mp4', 'http://timg.bdta.pro/images/49ffd0328aa29bde6456e2f88ef3ef65.jpg'),
(36628, 2541, 'Operação Ecstasy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170976.mp4', 'http://timg.bdta.pro/images/10d148ae99bc86f24e3defad38de16c4.jpg'),
(36629, 2541, 'Operação Ecstasy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170977.mp4', 'http://timg.bdta.pro/images/4bc7ded1bbc6d8ae4c63d15e7eeab8de.jpg'),
(36630, 2541, 'Operação Ecstasy S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170978.mp4', 'http://timg.bdta.pro/images/f990c5079e9e75a663508aaf8e3b0217.jpg'),
(36631, 2541, 'Operação Ecstasy S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170979.mp4', 'http://timg.bdta.pro/images/7456f4eae012af3aa339abc05561f8a8.jpg'),
(36632, 2541, 'Operação Ecstasy S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170980.mp4', 'http://timg.bdta.pro/images/667b00e06f7a2b4ea1ece40469417f77.jpg'),
(36633, 2541, 'Operação Ecstasy S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170981.mp4', 'http://timg.bdta.pro/images/af88c0a3ee8c53dc0744aa82df40bcb1.jpg'),
(36634, 2542, 'Operação Ecstasy S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170982.mp4', 'http://timg.bdta.pro/images/544dec301dcac32840452c701006e05b.jpg'),
(36635, 2542, 'Operação Ecstasy S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170983.mp4', 'http://timg.bdta.pro/images/3e683ea9d71fc59241d3ac96a2b5ddf0.jpg'),
(36636, 2542, 'Operação Ecstasy S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170984.mp4', 'http://timg.bdta.pro/images/c55ffe682c0a47681a6775aa035d96e8.jpg'),
(36637, 2542, 'Operação Ecstasy S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170985.mp4', 'http://timg.bdta.pro/images/b559deb0be44654a997affe15e2214c9.jpg'),
(36638, 2542, 'Operação Ecstasy S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170986.mp4', 'http://timg.bdta.pro/images/d16bfd046b4c8b4da82e3a7c1dcecbac.jpg'),
(36639, 2542, 'Operação Ecstasy S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170987.mp4', 'http://timg.bdta.pro/images/4b6bd840ed19ec52950fb382b64152b4.jpg'),
(36640, 2542, 'Operação Ecstasy S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170988.mp4', 'http://timg.bdta.pro/images/0c42d926297fd63b0f5fc4e048d198d1.jpg'),
(36641, 2542, 'Operação Ecstasy S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170989.mp4', 'http://timg.bdta.pro/images/604afd06b2556447adcbfbf78bf3f49b.jpg'),
(36642, 2542, 'Operação Ecstasy S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/26COkeEbRy0EuZ3eqPW2Ndiao0L.jpg'),
(36643, 2542, 'Operação Ecstasy S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b6vHFY3lGiGHpxaKXob6dMfG7rH.jpg'),
(36644, 2543, 'Operação Ecstasy S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/znkVJJFT7rVSwGh6bygq6NvRICQ.jpg'),
(36645, 2543, 'Operação Ecstasy S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v52EciLH9HwsrIEipu0P9jin2f5.jpg'),
(36646, 2543, 'Operação Ecstasy S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g9PecwRHOk4BmKTD59PEf7gvaVA.jpg'),
(36647, 2543, 'Operação Ecstasy S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ahox1Qx3r4mOggzGINZinoOpliy.jpg'),
(36648, 2543, 'Operação Ecstasy S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hcOp1sdeboZKwvUgLuepmF6VHOF.jpg'),
(36649, 2543, 'Operação Ecstasy S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ft4WXnjfqO4nMoQ8uPGrCvgaZob.jpg'),
(36650, 2543, 'Operação Ecstasy S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/70x0ixCJQLMkUbjx8RSNb2Dvv6y.jpg'),
(36651, 2543, 'Operação Ecstasy S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2GkKOfhjevSZhdyzWG3zrmONESJ.jpg'),
(36652, 2544, 'Ratched S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/128106.mp4', 'http://timg.bdta.pro/images/94826638d5e68da29930ec6a297bf38e.jpg'),
(36653, 2544, 'Ratched S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/128107.mp4', 'http://timg.bdta.pro/images/4671703e7b38606ce8d966dfdc14061d.jpg'),
(36654, 2544, 'Ratched S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/128108.mp4', 'http://timg.bdta.pro/images/8469318d0b42ae8a140009d047c881fe.jpg'),
(36655, 2544, 'Ratched S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/128109.mp4', 'http://timg.bdta.pro/images/dde26ac876f4140a01de9813a8b9019b.jpg'),
(36656, 2544, 'Ratched S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/128110.mp4', 'http://timg.bdta.pro/images/d0dd097c309d1f1fc39e2ccaa064eabc.jpg'),
(36657, 2544, 'Ratched S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/128111.mp4', 'http://timg.bdta.pro/images/b367ab9c804ca16f39ed6b0f04df618a.jpg'),
(36658, 2544, 'Ratched S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/128112.mp4', 'http://timg.bdta.pro/images/acecb2c91041e52d27cc9a3961731e99.jpg'),
(36659, 2544, 'Ratched S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/128113.mp4', 'http://timg.bdta.pro/images/7fd0cf9b6daeefce8118553cbaeea480.jpg'),
(36660, 2545, 'NCIS: Investigação Naval S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190650.mp4', 'http://timg.bdta.pro/images/cb8e399394e62576286ec91aa8f6cea0.jpg'),
(36661, 2545, 'NCIS: Investigação Naval S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190651.mp4', 'http://timg.bdta.pro/images/42ca0d7ff96f9d3fc6de0d8700147589.jpg'),
(36662, 2545, 'NCIS: Investigação Naval S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190652.mp4', 'http://timg.bdta.pro/images/73b007033f3a7ce02e64f926071b5d7e.jpg'),
(36663, 2545, 'NCIS: Investigação Naval S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190653.mp4', 'http://timg.bdta.pro/images/da6271a32f0f36605cad7d431f08d3fb.jpg'),
(36664, 2545, 'NCIS: Investigação Naval S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190654.mp4', 'http://timg.bdta.pro/images/5069dc55baef4103876feb342689f5ca.jpg'),
(36665, 2545, 'NCIS: Investigação Naval S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190655.mp4', 'http://timg.bdta.pro/images/23c6cdfd53b9ddb855eefc2892e6241b.jpg'),
(36666, 2545, 'NCIS: Investigação Naval S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190656.mp4', 'http://timg.bdta.pro/images/b1a06b86b85bf65e449edb4a23d9d261.jpg'),
(36667, 2545, 'NCIS: Investigação Naval S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190657.mp4', 'http://timg.bdta.pro/images/959f8880176cd70dad20ef2696b7cc6f.jpg'),
(36668, 2545, 'NCIS: Investigação Naval S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190658.mp4', 'http://timg.bdta.pro/images/402708400be457259b5a5247372f44f1.jpg'),
(36669, 2545, 'NCIS: Investigação Naval S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190659.mp4', 'http://timg.bdta.pro/images/329dd66d5dddd931e45908dd95d2e43b.jpg'),
(36670, 2545, 'NCIS: Investigação Naval S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190660.mp4', 'http://timg.bdta.pro/images/243e4121151e23cb2c4d7b2ff06ab378.jpg'),
(36671, 2545, 'NCIS: Investigação Naval S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190661.mp4', 'http://timg.bdta.pro/images/be16c93129ec8a63f683150b8ee3ff08.jpg'),
(36672, 2545, 'NCIS: Investigação Naval S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190662.mp4', 'http://timg.bdta.pro/images/e0c889c049f78cb2e515c12245566042.jpg'),
(36673, 2545, 'NCIS: Investigação Naval S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190663.mp4', 'http://timg.bdta.pro/images/7631c6dc5443c4a1e3bb53084df8366f.jpg'),
(36674, 2545, 'NCIS: Investigação Naval S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190664.mp4', 'http://timg.bdta.pro/images/4902d5b81a5539a49f3e87cfa1eaec0e.jpg'),
(36675, 2545, 'NCIS: Investigação Naval S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190665.mp4', 'http://timg.bdta.pro/images/850f70ae9bc044b1900596ff2f4d6647.jpg'),
(36676, 2545, 'NCIS: Investigação Naval S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190666.mp4', 'http://timg.bdta.pro/images/505e956ecc529b5a9544896e1f9f99d2.jpg'),
(36677, 2545, 'NCIS: Investigação Naval S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190667.mp4', 'http://timg.bdta.pro/images/24374b36bd22d9026407e258c58142f6.jpg'),
(36678, 2545, 'NCIS: Investigação Naval S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/190668.mp4', 'http://timg.bdta.pro/images/080e1cdde4c2596a5938080a4e743d2d.jpg'),
(36679, 2545, 'NCIS: Investigação Naval S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/190669.mp4', 'http://timg.bdta.pro/images/fe1f8b8ed0424a4d386b411554b531a9.jpg'),
(36680, 2545, 'NCIS: Investigação Naval S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/190670.mp4', 'http://timg.bdta.pro/images/a5b033bf21460b0a00d6ee7af75d9c5a.jpg'),
(36681, 2545, 'NCIS: Investigação Naval S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/190671.mp4', 'http://timg.bdta.pro/images/45044cf068e295eec313ee7edae0dec2.jpg'),
(36682, 2545, 'NCIS: Investigação Naval S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/190672.mp4', 'http://timg.bdta.pro/images/fd0bc33d312eef3fe80ca79b96663aa3.jpg'),
(36683, 2546, 'NCIS: Investigação Naval S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190673.mp4', 'http://timg.bdta.pro/images/0665c0dc9442267447588dfe346a3a0e.jpg'),
(36684, 2546, 'NCIS: Investigação Naval S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190674.mp4', 'http://timg.bdta.pro/images/925d22d3675ed3e7654d3f7ce2f36bff.jpg'),
(36685, 2546, 'NCIS: Investigação Naval S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190675.mp4', 'http://timg.bdta.pro/images/d75dcd79d32f0b96ad2136cb0aa066e8.jpg'),
(36686, 2546, 'NCIS: Investigação Naval S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190676.mp4', 'http://timg.bdta.pro/images/5856ae4f7274008ca1bb0a4454dfea55.jpg'),
(36687, 2546, 'NCIS: Investigação Naval S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190677.mp4', 'http://timg.bdta.pro/images/315ca4cb7b36464bdd0917954e7909c2.jpg'),
(36688, 2546, 'NCIS: Investigação Naval S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190678.mp4', 'http://timg.bdta.pro/images/95e3dd61e5f56041d3699d98563e8f7a.jpg'),
(36689, 2546, 'NCIS: Investigação Naval S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190679.mp4', 'http://timg.bdta.pro/images/92acf20f17cf425a6ea46e59cb04ea11.jpg'),
(36690, 2546, 'NCIS: Investigação Naval S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190680.mp4', 'http://timg.bdta.pro/images/a4134c5d0c961aae47d288792bbb304a.jpg'),
(36691, 2546, 'NCIS: Investigação Naval S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190681.mp4', 'http://timg.bdta.pro/images/0d716e6210c17512bd62d9f5e8d1f4d3.jpg'),
(36692, 2546, 'NCIS: Investigação Naval S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190682.mp4', 'http://timg.bdta.pro/images/e1d78180ed70993ab6370c3e4d3cbb64.jpg'),
(36693, 2546, 'NCIS: Investigação Naval S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190683.mp4', 'http://timg.bdta.pro/images/c27d7066587449d182377935349523db.jpg'),
(36694, 2546, 'NCIS: Investigação Naval S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190684.mp4', 'http://timg.bdta.pro/images/506c674e4f3e7c74e08577ce3a4b8c78.jpg'),
(36695, 2546, 'NCIS: Investigação Naval S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190685.mp4', 'http://timg.bdta.pro/images/c4133ee1aff81d464c81971c8cf67240.jpg'),
(36696, 2546, 'NCIS: Investigação Naval S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190686.mp4', 'http://timg.bdta.pro/images/23291cfcf4bc085ad11ff17cd894822f.jpg'),
(36697, 2546, 'NCIS: Investigação Naval S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190687.mp4', 'http://timg.bdta.pro/images/50e742687428844bc457e02d00fef4ee.jpg'),
(36698, 2546, 'NCIS: Investigação Naval S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190688.mp4', 'http://timg.bdta.pro/images/c0ad847f17d7506766ade8f8cd1aaa93.jpg'),
(36699, 2546, 'NCIS: Investigação Naval S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190689.mp4', 'http://timg.bdta.pro/images/f4c8eb81ac6579e327d258ce76ed9b7f.jpg'),
(36700, 2546, 'NCIS: Investigação Naval S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190690.mp4', 'http://timg.bdta.pro/images/e8b32e90ad8e7a1447010ab3253b32ab.jpg'),
(36701, 2546, 'NCIS: Investigação Naval S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/190691.mp4', 'http://timg.bdta.pro/images/e21c84273475977a5e0e01e10569ef27.jpg'),
(36702, 2546, 'NCIS: Investigação Naval S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/190692.mp4', 'http://timg.bdta.pro/images/bd7a02ad701f6a2392b24834584d6367.jpg'),
(36703, 2546, 'NCIS: Investigação Naval S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/190693.mp4', 'http://timg.bdta.pro/images/aaf62e3e02b24b6c674ae6d2fae44bab.jpg'),
(36704, 2546, 'NCIS: Investigação Naval S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/190694.mp4', 'http://timg.bdta.pro/images/f40e9af5f7e16f5fc60e44a3d007ad6c.jpg'),
(36705, 2546, 'NCIS: Investigação Naval S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/190695.mp4', 'http://timg.bdta.pro/images/3714182dc36c440eef109505b39f2b99.jpg'),
(36706, 2547, 'NCIS: Investigação Naval S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190696.mp4', 'http://timg.bdta.pro/images/2cf2c7df26f53ab8d4b74aa34456755f.jpg'),
(36707, 2547, 'NCIS: Investigação Naval S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190697.mp4', 'http://timg.bdta.pro/images/7dda1a792b1b1f48620eb0858f968a12.jpg'),
(36708, 2547, 'NCIS: Investigação Naval S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190698.mp4', 'http://timg.bdta.pro/images/8e9e409e9a77046ef48737806519547c.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(36709, 2547, 'NCIS: Investigação Naval S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190699.mp4', 'http://timg.bdta.pro/images/17593fce3aba3a5e13cf45bd53661438.jpg'),
(36710, 2547, 'NCIS: Investigação Naval S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190700.mp4', 'http://timg.bdta.pro/images/d7b81b09236d65013e1acd9ab109490c.jpg'),
(36711, 2547, 'NCIS: Investigação Naval S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190701.mp4', 'http://timg.bdta.pro/images/b4ee1b30b1a392b750ebddccf948549f.jpg'),
(36712, 2547, 'NCIS: Investigação Naval S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190702.mp4', 'http://timg.bdta.pro/images/794e4b7445d2fea6f36a4e5bdf6e379e.jpg'),
(36713, 2547, 'NCIS: Investigação Naval S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190703.mp4', 'http://timg.bdta.pro/images/9e6fd85da683b469a17cf8ae36fe5b8f.jpg'),
(36714, 2547, 'NCIS: Investigação Naval S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190704.mp4', 'http://timg.bdta.pro/images/46f1625ce31e6e2a7682290ed0433e11.jpg'),
(36715, 2547, 'NCIS: Investigação Naval S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190705.mp4', 'http://timg.bdta.pro/images/230c902d830ecaa54a22447ffb9e2e65.jpg'),
(36716, 2547, 'NCIS: Investigação Naval S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190706.mp4', 'http://timg.bdta.pro/images/22e2ccbc762fd8767acbd64d28bf35ee.jpg'),
(36717, 2547, 'NCIS: Investigação Naval S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190707.mp4', 'http://timg.bdta.pro/images/d641b4c0e46691ad93e80bb6db2232d6.jpg'),
(36718, 2547, 'NCIS: Investigação Naval S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190708.mp4', 'http://timg.bdta.pro/images/4dbdf8c3062331b4bea767c79c9da53f.jpg'),
(36719, 2547, 'NCIS: Investigação Naval S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190709.mp4', 'http://timg.bdta.pro/images/44876b35dd2a6c8df7bedd31c945cb7b.jpg'),
(36720, 2547, 'NCIS: Investigação Naval S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190710.mp4', 'http://timg.bdta.pro/images/7839e140ca51b23636ef5593f1259421.jpg'),
(36721, 2547, 'NCIS: Investigação Naval S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190711.mp4', 'http://timg.bdta.pro/images/e593edee91afdc7de746905a1b1505f0.jpg'),
(36722, 2547, 'NCIS: Investigação Naval S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190712.mp4', 'http://timg.bdta.pro/images/b01a3d43fa6e542f8ae0ee6dfab09fd9.jpg'),
(36723, 2547, 'NCIS: Investigação Naval S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190713.mp4', 'http://timg.bdta.pro/images/38f4c6d7939c05643d197f80d03671ea.jpg'),
(36724, 2547, 'NCIS: Investigação Naval S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/190714.mp4', 'http://timg.bdta.pro/images/d3a4ee954f046a5b56500d42d0ca74c3.jpg'),
(36725, 2547, 'NCIS: Investigação Naval S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/190715.mp4', 'http://timg.bdta.pro/images/4c13049849137e5e8e42b2a8f7f2b9c7.jpg'),
(36726, 2547, 'NCIS: Investigação Naval S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/190716.mp4', 'http://timg.bdta.pro/images/8c4046ed4d0c3b05001249e8d52e0133.jpg'),
(36727, 2547, 'NCIS: Investigação Naval S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/190717.mp4', 'http://timg.bdta.pro/images/04b77c1785300dc6bb48ae2e22b7fd06.jpg'),
(36728, 2547, 'NCIS: Investigação Naval S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/190718.mp4', 'http://timg.bdta.pro/images/bcab7cbcfee428718ebfae6d512f88c4.jpg'),
(36729, 2547, 'NCIS: Investigação Naval S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/190719.mp4', 'http://timg.bdta.pro/images/9aff984f7f80dcf23d66477ecdb53d0e.jpg'),
(36730, 2548, 'NCIS: Investigação Naval S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190720.mp4', 'http://timg.bdta.pro/images/6a0dfb39e7c74743bb29bdd0ac678913.jpg'),
(36731, 2548, 'NCIS: Investigação Naval S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190721.mp4', 'http://timg.bdta.pro/images/40a2927062a03616eb73e1bf5cac4ada.jpg'),
(36732, 2548, 'NCIS: Investigação Naval S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190722.mp4', 'http://timg.bdta.pro/images/f2c7e0a455c048af339d89c497f5c2bd.jpg'),
(36733, 2548, 'NCIS: Investigação Naval S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190723.mp4', 'http://timg.bdta.pro/images/cd71072c330bb1d18fa7202b7101cff0.jpg'),
(36734, 2548, 'NCIS: Investigação Naval S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190724.mp4', 'http://timg.bdta.pro/images/6f3cdfeebef7744a107e71f5346d8824.jpg'),
(36735, 2548, 'NCIS: Investigação Naval S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190725.mp4', 'http://timg.bdta.pro/images/a59f6aa0963e233856791a4d4cd13d6f.jpg'),
(36736, 2548, 'NCIS: Investigação Naval S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190726.mp4', 'http://timg.bdta.pro/images/9171dcf0ce96859d743aa5a85e3187f5.jpg'),
(36737, 2548, 'NCIS: Investigação Naval S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190727.mp4', 'http://timg.bdta.pro/images/73b7a36840e9acdd8044db0f343413cc.jpg'),
(36738, 2548, 'NCIS: Investigação Naval S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190728.mp4', 'http://timg.bdta.pro/images/9a803f002d60cd64dd79af5e9e46c80d.jpg'),
(36739, 2548, 'NCIS: Investigação Naval S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190729.mp4', 'http://timg.bdta.pro/images/6d6a7e9e704a1e03652113f0357293c8.jpg'),
(36740, 2548, 'NCIS: Investigação Naval S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190730.mp4', 'http://timg.bdta.pro/images/254ff2891008486975510ecc3dbcb728.jpg'),
(36741, 2548, 'NCIS: Investigação Naval S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190731.mp4', 'http://timg.bdta.pro/images/9282b221cadd508859e74292e499807d.jpg'),
(36742, 2548, 'NCIS: Investigação Naval S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190732.mp4', 'http://timg.bdta.pro/images/133d3a0d1afd9e8270283d19c6cf728c.jpg'),
(36743, 2548, 'NCIS: Investigação Naval S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190733.mp4', 'http://timg.bdta.pro/images/756d273dad448a7c9d2a66de229f35be.jpg'),
(36744, 2548, 'NCIS: Investigação Naval S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190734.mp4', 'http://timg.bdta.pro/images/1a1e21e3937b1ce29992c19930315c19.jpg'),
(36745, 2548, 'NCIS: Investigação Naval S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190735.mp4', 'http://timg.bdta.pro/images/be673ef62b9f8ddcad22cecebbe3d46d.jpg'),
(36746, 2548, 'NCIS: Investigação Naval S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190736.mp4', 'http://timg.bdta.pro/images/71f3424c35979267734041c1cfafd860.jpg'),
(36747, 2548, 'NCIS: Investigação Naval S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190737.mp4', 'http://timg.bdta.pro/images/3248d1c192aed49f35840b1eaeea7945.jpg'),
(36748, 2548, 'NCIS: Investigação Naval S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/190738.mp4', 'http://timg.bdta.pro/images/65db652a43d3c5657786dc6df9aed56b.jpg'),
(36749, 2548, 'NCIS: Investigação Naval S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/190739.mp4', 'http://timg.bdta.pro/images/fc18edd8256e01819bd7f4df6b369730.jpg'),
(36750, 2548, 'NCIS: Investigação Naval S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/190740.mp4', 'http://timg.bdta.pro/images/bd4a5ace603c0f9dbd1f6629158ec657.jpg'),
(36751, 2548, 'NCIS: Investigação Naval S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/190741.mp4', 'http://timg.bdta.pro/images/885d4825b1e5d06d3137e9def8a14ed1.jpg'),
(36752, 2548, 'NCIS: Investigação Naval S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/190742.mp4', 'http://timg.bdta.pro/images/7ceadf698e6b4b76a7f14f57e53e5762.jpg'),
(36753, 2548, 'NCIS: Investigação Naval S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/190743.mp4', 'http://timg.bdta.pro/images/6749ef632706e5e596e97fe5ba7bf2fa.jpg'),
(36754, 2549, 'NCIS: Investigação Naval S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190744.mp4', 'http://timg.bdta.pro/images/2c663f3b9587817070b4f2ea282a8f8d.jpg'),
(36755, 2549, 'NCIS: Investigação Naval S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190745.mp4', 'http://timg.bdta.pro/images/c7b870f37b656f3821646e106444a1bf.jpg'),
(36756, 2549, 'NCIS: Investigação Naval S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190746.mp4', 'http://timg.bdta.pro/images/6afa3d566cdae6a0865d30f5d63cc10e.jpg'),
(36757, 2549, 'NCIS: Investigação Naval S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190747.mp4', 'http://timg.bdta.pro/images/1cbbf3f97cac081e874f18a2b94ad8dd.jpg'),
(36758, 2549, 'NCIS: Investigação Naval S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190748.mp4', 'http://timg.bdta.pro/images/a656d639c91b1a7fe046208cf66daa1b.jpg'),
(36759, 2549, 'NCIS: Investigação Naval S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190749.mp4', 'http://timg.bdta.pro/images/75c476295757f64308eb1314700498f3.jpg'),
(36760, 2549, 'NCIS: Investigação Naval S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190750.mp4', 'http://timg.bdta.pro/images/bec404bce338ab0dcf6835b51da525c6.jpg'),
(36761, 2549, 'NCIS: Investigação Naval S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190751.mp4', 'http://timg.bdta.pro/images/d3a3777f00d3225b4a1652c222ccc6a8.jpg'),
(36762, 2549, 'NCIS: Investigação Naval S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190752.mp4', 'http://timg.bdta.pro/images/83c857446f47f1500c8071f7effa0338.jpg'),
(36763, 2549, 'NCIS: Investigação Naval S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190753.mp4', 'http://timg.bdta.pro/images/2e2024511a8f9cacb43660bfdd5fa09e.jpg'),
(36764, 2549, 'NCIS: Investigação Naval S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190754.mp4', 'http://timg.bdta.pro/images/c26ca098c7239d1278ec2378005db5b9.jpg'),
(36765, 2549, 'NCIS: Investigação Naval S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190755.mp4', 'http://timg.bdta.pro/images/ae7ba5e3d18b702ada20e5ecd999e0f6.jpg'),
(36766, 2549, 'NCIS: Investigação Naval S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190756.mp4', 'http://timg.bdta.pro/images/6d534d02de3af19faf3a661797ad91f5.jpg'),
(36767, 2549, 'NCIS: Investigação Naval S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190757.mp4', 'http://timg.bdta.pro/images/eac3d24fb0390bf60cef8fe623b85566.jpg'),
(36768, 2549, 'NCIS: Investigação Naval S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190758.mp4', 'http://timg.bdta.pro/images/6b20824e9b049a13baaf56e556d110f1.jpg'),
(36769, 2549, 'NCIS: Investigação Naval S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190759.mp4', 'http://timg.bdta.pro/images/665d9e343b200171b46aaeaf8065dbbf.jpg'),
(36770, 2549, 'NCIS: Investigação Naval S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190760.mp4', 'http://timg.bdta.pro/images/6386b10ad703f871a3ebce5f7fa92ca1.jpg'),
(36771, 2549, 'NCIS: Investigação Naval S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190761.mp4', 'http://timg.bdta.pro/images/b4cc778399d16110406bd3972487cd3e.jpg'),
(36772, 2550, 'NCIS: Investigação Naval S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190762.mp4', 'http://timg.bdta.pro/images/2bf02c20a928699cb15649d45013a39a.jpg'),
(36773, 2550, 'NCIS: Investigação Naval S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190763.mp4', 'http://timg.bdta.pro/images/4c3281939ab522f0cb3eb6a877bb1ea5.jpg'),
(36774, 2550, 'NCIS: Investigação Naval S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190764.mp4', 'http://timg.bdta.pro/images/cf8b451b35d6afc26eb3cdc82ecceb66.jpg'),
(36775, 2550, 'NCIS: Investigação Naval S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190765.mp4', 'http://timg.bdta.pro/images/5940835bdd1605f7bc6b829b345f4381.jpg'),
(36776, 2550, 'NCIS: Investigação Naval S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190766.mp4', 'http://timg.bdta.pro/images/bf9634694c5ebbaa344f66fcfdca20af.jpg'),
(36777, 2550, 'NCIS: Investigação Naval S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190767.mp4', 'http://timg.bdta.pro/images/edaba4a235ad77ac082aecfd634c0cd6.jpg'),
(36778, 2550, 'NCIS: Investigação Naval S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190768.mp4', 'http://timg.bdta.pro/images/7d33a3e637eccc133d920fae6c017c87.jpg'),
(36779, 2550, 'NCIS: Investigação Naval S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190769.mp4', 'http://timg.bdta.pro/images/643c461babfee382d4f1cf4498adf49c.jpg'),
(36780, 2550, 'NCIS: Investigação Naval S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190770.mp4', 'http://timg.bdta.pro/images/fa73e3ad5107ea528a6a3a15317b0771.jpg'),
(36781, 2550, 'NCIS: Investigação Naval S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190771.mp4', 'http://timg.bdta.pro/images/b1a7819965d7c1a5e34923db0616bf94.jpg'),
(36782, 2550, 'NCIS: Investigação Naval S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190772.mp4', 'http://timg.bdta.pro/images/9d8745a81e3f5129a02c737afee00687.jpg'),
(36783, 2550, 'NCIS: Investigação Naval S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190773.mp4', 'http://timg.bdta.pro/images/b696b970302539c224f3b336094d20df.jpg'),
(36784, 2550, 'NCIS: Investigação Naval S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190774.mp4', 'http://timg.bdta.pro/images/ab109f6a9ae8fb3907972326e03f4acb.jpg'),
(36785, 2550, 'NCIS: Investigação Naval S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190775.mp4', 'http://timg.bdta.pro/images/71737fbd11dbf9734306649b2d3e9811.jpg'),
(36786, 2550, 'NCIS: Investigação Naval S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190776.mp4', 'http://timg.bdta.pro/images/e9de5425f1407d82d18b9e9292bf9d85.jpg'),
(36787, 2550, 'NCIS: Investigação Naval S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190777.mp4', 'http://timg.bdta.pro/images/635d369e90a61d9e5408ba578a020095.jpg'),
(36788, 2550, 'NCIS: Investigação Naval S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190778.mp4', 'http://timg.bdta.pro/images/b1854ea70f250b9888f1c93773e788ab.jpg'),
(36789, 2550, 'NCIS: Investigação Naval S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190779.mp4', 'http://timg.bdta.pro/images/dacb9303bd5bd936ca85a9b4a48c947e.jpg'),
(36790, 2550, 'NCIS: Investigação Naval S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/190780.mp4', 'http://timg.bdta.pro/images/e7d1f07e0683a93d98703cad829b277e.jpg'),
(36791, 2550, 'NCIS: Investigação Naval S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/190781.mp4', 'http://timg.bdta.pro/images/e1fa7beca48139d03d6a5971c880e1c9.jpg'),
(36792, 2550, 'NCIS: Investigação Naval S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/190782.mp4', 'http://timg.bdta.pro/images/662a857fe4df0d787fb9ad1d4839aca1.jpg'),
(36793, 2550, 'NCIS: Investigação Naval S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/190783.mp4', 'http://timg.bdta.pro/images/98bbe1e1495155722494b101a2bd52e2.jpg'),
(36794, 2550, 'NCIS: Investigação Naval S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/190784.mp4', 'http://timg.bdta.pro/images/a70d76fd6f80da1d4321052eab7e4a00.jpg'),
(36795, 2550, 'NCIS: Investigação Naval S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/190785.mp4', 'http://timg.bdta.pro/images/35017737ec313273076a4ce93021dd20.jpg'),
(36796, 2550, 'NCIS: Investigação Naval S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/190786.mp4', 'http://timg.bdta.pro/images/5f3926683556505bd5f5cdd826b48ecb.jpg'),
(36797, 2551, 'NCIS: Investigação Naval S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190787.mp4', 'http://timg.bdta.pro/images/cb3491588765f7d0e9908f32d249624f.jpg'),
(36798, 2551, 'NCIS: Investigação Naval S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190788.mp4', 'http://timg.bdta.pro/images/68dcb4c68ce2a8c27a001743a3d92512.jpg'),
(36799, 2551, 'NCIS: Investigação Naval S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190789.mp4', 'http://timg.bdta.pro/images/bebc7b4012339ce3c2ca55270021abeb.jpg'),
(36800, 2551, 'NCIS: Investigação Naval S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190790.mp4', 'http://timg.bdta.pro/images/930d73ea0b29df3fa745b0848de0eb15.jpg'),
(36801, 2551, 'NCIS: Investigação Naval S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190791.mp4', 'http://timg.bdta.pro/images/fdcd56a4b83684efb407a4bba310e973.jpg'),
(36802, 2551, 'NCIS: Investigação Naval S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190792.mp4', 'http://timg.bdta.pro/images/4ac0be90d27e09636ca58631d4f35d82.jpg'),
(36803, 2551, 'NCIS: Investigação Naval S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190793.mp4', 'http://timg.bdta.pro/images/1b515ea2bab1084f20ebd5e5dc9461f8.jpg'),
(36804, 2551, 'NCIS: Investigação Naval S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190794.mp4', 'http://timg.bdta.pro/images/38350ac22ad76880c05d9d2b99df8e9e.jpg'),
(36805, 2551, 'NCIS: Investigação Naval S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190795.mp4', 'http://timg.bdta.pro/images/560890a0959587b2383ed146fff65bae.jpg'),
(36806, 2551, 'NCIS: Investigação Naval S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190796.mp4', 'http://timg.bdta.pro/images/adeae41afa5c5d8f92fa9f1e036abbc6.jpg'),
(36807, 2551, 'NCIS: Investigação Naval S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190797.mp4', 'http://timg.bdta.pro/images/445d2f5ff147750f7dac6c40db7eb2ae.jpg'),
(36808, 2551, 'NCIS: Investigação Naval S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190798.mp4', 'http://timg.bdta.pro/images/fac1f22b9f8e9ff3b8cfd7f16b33587e.jpg'),
(36809, 2551, 'NCIS: Investigação Naval S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190799.mp4', 'http://timg.bdta.pro/images/8492717be8bb56d2a6a88cd484df2681.jpg'),
(36810, 2551, 'NCIS: Investigação Naval S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190800.mp4', 'http://timg.bdta.pro/images/1ab4e5d771788e6b44ce1eaa4b55c0fd.jpg'),
(36811, 2551, 'NCIS: Investigação Naval S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190801.mp4', 'http://timg.bdta.pro/images/45a67ae17a076ba90660a50df516d740.jpg'),
(36812, 2551, 'NCIS: Investigação Naval S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190802.mp4', 'http://timg.bdta.pro/images/0f2137e399df6f5e9e1ab97f85c0477c.jpg'),
(36813, 2551, 'NCIS: Investigação Naval S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190803.mp4', 'http://timg.bdta.pro/images/d2570f588e25eed41de050bd96712d71.jpg'),
(36814, 2551, 'NCIS: Investigação Naval S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190804.mp4', 'http://timg.bdta.pro/images/d43e663deb63dbd90bcaa43a27b575d8.jpg'),
(36815, 2551, 'NCIS: Investigação Naval S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/190805.mp4', 'http://timg.bdta.pro/images/82dbb123d415cebdfb4d9d8ecf2d79de.jpg'),
(36816, 2551, 'NCIS: Investigação Naval S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/190806.mp4', 'http://timg.bdta.pro/images/4b9712577d7ad6d8c196d5b60627029e.jpg'),
(36817, 2551, 'NCIS: Investigação Naval S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/190807.mp4', 'http://timg.bdta.pro/images/21b66cfa6e5aa16864e857d59e5e9eff.jpg'),
(36818, 2551, 'NCIS: Investigação Naval S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/190808.mp4', 'http://timg.bdta.pro/images/a46f3192818627211738ed194b068fad.jpg'),
(36819, 2551, 'NCIS: Investigação Naval S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/190809.mp4', 'http://timg.bdta.pro/images/65f2028d64849cc40b9dc483e78176c2.jpg'),
(36820, 2551, 'NCIS: Investigação Naval S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/190810.mp4', 'http://timg.bdta.pro/images/3ff3ee418e5a9663102827dd658b28a2.jpg'),
(36821, 2552, 'NCIS: Investigação Naval S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190811.mp4', 'http://timg.bdta.pro/images/e36970920fc7d5315aaf71de56b6384f.jpg'),
(36822, 2552, 'NCIS: Investigação Naval S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190812.mp4', 'http://timg.bdta.pro/images/17b94dda2d353f5b574146ea6cfb2218.jpg'),
(36823, 2552, 'NCIS: Investigação Naval S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190813.mp4', 'http://timg.bdta.pro/images/60e8c9535f5cfcf0321f158c0984ac8a.jpg'),
(36824, 2552, 'NCIS: Investigação Naval S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190814.mp4', 'http://timg.bdta.pro/images/69e7bdb1ce967686c3e97cd4aa9b2cd0.jpg'),
(36825, 2552, 'NCIS: Investigação Naval S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190815.mp4', 'http://timg.bdta.pro/images/0d4aacddad49f771fbf465d3a3aa0f0c.jpg'),
(36826, 2552, 'NCIS: Investigação Naval S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190816.mp4', 'http://timg.bdta.pro/images/38d8f9acf0c2f688459a94512148a1a5.jpg'),
(36827, 2552, 'NCIS: Investigação Naval S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190817.mp4', 'http://timg.bdta.pro/images/d2c1066f05c942f3949567e45bdd5483.jpg'),
(36828, 2552, 'NCIS: Investigação Naval S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190818.mp4', 'http://timg.bdta.pro/images/e7406fedcbb3df2d34a6c50e6ea678e0.jpg'),
(36829, 2552, 'NCIS: Investigação Naval S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190819.mp4', 'http://timg.bdta.pro/images/361b6edf28be332588f6093c7cfda27f.jpg'),
(36830, 2552, 'NCIS: Investigação Naval S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190820.mp4', 'http://timg.bdta.pro/images/b7edcc58fad0d7888363cb4630c6b916.jpg'),
(36831, 2552, 'NCIS: Investigação Naval S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190821.mp4', 'http://timg.bdta.pro/images/7b686bb39d045428d4414421395c3c07.jpg'),
(36832, 2552, 'NCIS: Investigação Naval S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190822.mp4', 'http://timg.bdta.pro/images/a65aa6b294310e657ca6e1f1142f2abb.jpg'),
(36833, 2552, 'NCIS: Investigação Naval S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190823.mp4', 'http://timg.bdta.pro/images/53a42af442f6961f704baea114283389.jpg'),
(36834, 2552, 'NCIS: Investigação Naval S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190824.mp4', 'http://timg.bdta.pro/images/1c0aa9ae289025dc060735c2f9c19f8f.jpg'),
(36835, 2552, 'NCIS: Investigação Naval S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190825.mp4', 'http://timg.bdta.pro/images/65ae07b2bc5e76453ea72e9d16467d6f.jpg'),
(36836, 2552, 'NCIS: Investigação Naval S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190826.mp4', 'http://timg.bdta.pro/images/b9d19833817be58f61c4437f71457133.jpg'),
(36837, 2552, 'NCIS: Investigação Naval S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190827.mp4', 'http://timg.bdta.pro/images/e22e6b8aa8c7536084ad6c365d1b5545.jpg'),
(36838, 2552, 'NCIS: Investigação Naval S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190828.mp4', 'http://timg.bdta.pro/images/efd02ce02de27505919530bf6ddb94c9.jpg'),
(36839, 2552, 'NCIS: Investigação Naval S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/190829.mp4', 'http://timg.bdta.pro/images/e5aabf9c5a59fc9e1430f716cd8ee784.jpg'),
(36840, 2552, 'NCIS: Investigação Naval S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/190830.mp4', 'http://timg.bdta.pro/images/a8f9f2451f2e3673209f78f6e75ae81f.jpg'),
(36841, 2552, 'NCIS: Investigação Naval S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/190831.mp4', 'http://timg.bdta.pro/images/48eadc304912cec8e1311c1a417234a8.jpg'),
(36842, 2552, 'NCIS: Investigação Naval S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/190832.mp4', 'http://timg.bdta.pro/images/46bf42e529a8b6a52a879e0a38e70f8b.jpg'),
(36843, 2552, 'NCIS: Investigação Naval S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/190833.mp4', 'http://timg.bdta.pro/images/135a8b7c8d258b68f466b2e2da159c46.jpg'),
(36844, 2552, 'NCIS: Investigação Naval S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/190834.mp4', 'http://timg.bdta.pro/images/3f71081b142723f8fe14afc788c399e3.jpg'),
(36845, 2553, 'NCIS: Investigação Naval S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190835.mp4', 'http://timg.bdta.pro/images/b7a7c5e8292aad6de87fa8b1ddf0ac77.jpg'),
(36846, 2553, 'NCIS: Investigação Naval S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190836.mp4', 'http://timg.bdta.pro/images/74c460412921325789ba625aaf23bf8f.jpg'),
(36847, 2553, 'NCIS: Investigação Naval S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190837.mp4', 'http://timg.bdta.pro/images/55839d3cedee5cd0fdacf343689e3d50.jpg'),
(36848, 2553, 'NCIS: Investigação Naval S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190838.mp4', 'http://timg.bdta.pro/images/f83fd3f6c59431e318973d713dd7cd3d.jpg'),
(36849, 2553, 'NCIS: Investigação Naval S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190839.mp4', 'http://timg.bdta.pro/images/9b6730319c960ee202e07d410bdc4985.jpg'),
(36850, 2553, 'NCIS: Investigação Naval S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190840.mp4', 'http://timg.bdta.pro/images/27391ec6334d6909f482eaf778b5dc38.jpg'),
(36851, 2553, 'NCIS: Investigação Naval S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190841.mp4', 'http://timg.bdta.pro/images/15893f6b2726738c3cc8104cf54713e1.jpg'),
(36852, 2553, 'NCIS: Investigação Naval S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190842.mp4', 'http://timg.bdta.pro/images/1d44667456c940ae6d6991ee718a7d6e.jpg'),
(36853, 2553, 'NCIS: Investigação Naval S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190843.mp4', 'http://timg.bdta.pro/images/8729f2278def5c984340ca9c7fc1547d.jpg'),
(36854, 2553, 'NCIS: Investigação Naval S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190844.mp4', 'http://timg.bdta.pro/images/d659c3f021a4d7184ab7a26bc53b668c.jpg'),
(36855, 2553, 'NCIS: Investigação Naval S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190845.mp4', 'http://timg.bdta.pro/images/2a75743d7a5e7328ed576f525d5dca4f.jpg'),
(36856, 2553, 'NCIS: Investigação Naval S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190846.mp4', 'http://timg.bdta.pro/images/6ddfd080d22279f24cd6490ef21c65a0.jpg'),
(36857, 2553, 'NCIS: Investigação Naval S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190847.mp4', 'http://timg.bdta.pro/images/5cac2f78c5acd3755ca57b4e141ae6cc.jpg'),
(36858, 2553, 'NCIS: Investigação Naval S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190848.mp4', 'http://timg.bdta.pro/images/a486f777b7a6541819d47d6373a94adb.jpg'),
(36859, 2553, 'NCIS: Investigação Naval S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190849.mp4', 'http://timg.bdta.pro/images/9b1f0e822956462f11f1d0b8222bd631.jpg'),
(36860, 2553, 'NCIS: Investigação Naval S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190850.mp4', 'http://timg.bdta.pro/images/d6ae521a1338afdebabfa29623a13411.jpg'),
(36861, 2553, 'NCIS: Investigação Naval S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190851.mp4', 'http://timg.bdta.pro/images/1df6ffdc4f9f32f20203e25eb110a23f.jpg'),
(36862, 2553, 'NCIS: Investigação Naval S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190852.mp4', 'http://timg.bdta.pro/images/4212e3265dd7772e1a955a9eea8336c2.jpg'),
(36863, 2553, 'NCIS: Investigação Naval S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/190853.mp4', 'http://timg.bdta.pro/images/52331b6e7e0dfc31f5d06ff82fdf4a62.jpg'),
(36864, 2553, 'NCIS: Investigação Naval S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/190854.mp4', 'http://timg.bdta.pro/images/cbd9341382bc4da10571252372063a6a.jpg'),
(36865, 2553, 'NCIS: Investigação Naval S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/190855.mp4', 'http://timg.bdta.pro/images/74ac93f0357dc6e05375137b8a971890.jpg'),
(36866, 2553, 'NCIS: Investigação Naval S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/190856.mp4', 'http://timg.bdta.pro/images/17accccb634aebb91429abae8a8aeb42.jpg'),
(36867, 2553, 'NCIS: Investigação Naval S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/190857.mp4', 'http://timg.bdta.pro/images/6e83f68cfebe23e409c2002dec325484.jpg'),
(36868, 2553, 'NCIS: Investigação Naval S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/190858.mp4', 'http://timg.bdta.pro/images/3d5790f579c0e4adc59972b997955cce.jpg'),
(36869, 2554, 'NCIS: Investigação Naval S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190859.mp4', 'http://timg.bdta.pro/images/39b37e06f09403304f0903aa889c9857.jpg'),
(36870, 2554, 'NCIS: Investigação Naval S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190860.mp4', 'http://timg.bdta.pro/images/f6d3b8ae12bfad8387ef2f62119acaad.jpg'),
(36871, 2554, 'NCIS: Investigação Naval S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190861.mp4', 'http://timg.bdta.pro/images/84d9221c336ec8e34b208e064c94bbef.jpg'),
(36872, 2554, 'NCIS: Investigação Naval S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190862.mp4', 'http://timg.bdta.pro/images/14355ef791bf9241ff1290f4268fb6da.jpg'),
(36873, 2554, 'NCIS: Investigação Naval S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190863.mp4', 'http://timg.bdta.pro/images/213958824e0b1c447eae62fe0207a5f6.jpg'),
(36874, 2554, 'NCIS: Investigação Naval S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190864.mp4', 'http://timg.bdta.pro/images/214be03455b6bad4adf7dcd0a22eaa52.jpg'),
(36875, 2554, 'NCIS: Investigação Naval S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190865.mp4', 'http://timg.bdta.pro/images/aeda2fae41074c426a7bf988c16aed74.jpg'),
(36876, 2554, 'NCIS: Investigação Naval S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190866.mp4', 'http://timg.bdta.pro/images/93bb0121eadec214e54127cfa3fcae4a.jpg'),
(36877, 2554, 'NCIS: Investigação Naval S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190867.mp4', 'http://timg.bdta.pro/images/7013f69d70ec66312f1a9b976aafb081.jpg'),
(36878, 2554, 'NCIS: Investigação Naval S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190868.mp4', 'http://timg.bdta.pro/images/517e59663da73fe7df3567f3ee8f9044.jpg'),
(36879, 2554, 'NCIS: Investigação Naval S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190869.mp4', 'http://timg.bdta.pro/images/589c2b64fc0d35f64c2a97371ddedd87.jpg'),
(36880, 2554, 'NCIS: Investigação Naval S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190870.mp4', 'http://timg.bdta.pro/images/131407c918a18a2f53fb603e8797c975.jpg'),
(36881, 2554, 'NCIS: Investigação Naval S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190871.mp4', 'http://timg.bdta.pro/images/b3a4ee40a5ca0fa433a113132d9cd59e.jpg'),
(36882, 2554, 'NCIS: Investigação Naval S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190872.mp4', 'http://timg.bdta.pro/images/5d5aee07dce732257b4956ba6688f0a4.jpg'),
(36883, 2554, 'NCIS: Investigação Naval S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190873.mp4', 'http://timg.bdta.pro/images/e99095df04d062ee5adffce9d6e1e7f8.jpg'),
(36884, 2554, 'NCIS: Investigação Naval S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190874.mp4', 'http://timg.bdta.pro/images/f5d94b20fd131754125af40032c8be65.jpg'),
(36885, 2554, 'NCIS: Investigação Naval S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190875.mp4', 'http://timg.bdta.pro/images/57c6f5e069a112c3267d0ebd1703247c.jpg'),
(36886, 2554, 'NCIS: Investigação Naval S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190876.mp4', 'http://timg.bdta.pro/images/acc0c5d2963c6a8b3fedb8bd6182ef86.jpg'),
(36887, 2554, 'NCIS: Investigação Naval S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/190877.mp4', 'http://timg.bdta.pro/images/a089db9c850e3a65d6334ec491be0c3d.jpg'),
(36888, 2554, 'NCIS: Investigação Naval S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/190878.mp4', 'http://timg.bdta.pro/images/b389f84a3a217459519d89883eef8086.jpg'),
(36889, 2554, 'NCIS: Investigação Naval S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/190879.mp4', 'http://timg.bdta.pro/images/f5374fc4ad8be8a764c7d78d703f7629.jpg'),
(36890, 2554, 'NCIS: Investigação Naval S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/190880.mp4', 'http://timg.bdta.pro/images/5b9ead50a20bdaeaca8d9d455fa18b19.jpg'),
(36891, 2554, 'NCIS: Investigação Naval S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/190881.mp4', 'http://timg.bdta.pro/images/ca8146d495f7782067c83f3985196758.jpg'),
(36892, 2554, 'NCIS: Investigação Naval S10 E24', 'http://sinalprivado.info:80/series/1533784/1533784/190882.mp4', 'http://timg.bdta.pro/images/931dbc0ccaae01f80a089b73cc1016d0.jpg'),
(36893, 2555, 'NCIS: Investigação Naval S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190883.mp4', 'http://timg.bdta.pro/images/7f8aadc1b7df4991b93117cc0e567044.jpg'),
(36894, 2555, 'NCIS: Investigação Naval S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190884.mp4', 'http://timg.bdta.pro/images/3260b694539f220bc20b724438492825.jpg'),
(36895, 2555, 'NCIS: Investigação Naval S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190885.mp4', 'http://timg.bdta.pro/images/ecfbebdb1bf426ede35b56b64185867d.jpg'),
(36896, 2555, 'NCIS: Investigação Naval S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190886.mp4', 'http://timg.bdta.pro/images/7246ffddf769ea9e72422a27a04e938e.jpg'),
(36897, 2555, 'NCIS: Investigação Naval S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190887.mp4', 'http://timg.bdta.pro/images/d58e7b66d07616244e659f7dfdd86319.jpg'),
(36898, 2555, 'NCIS: Investigação Naval S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190888.mp4', 'http://timg.bdta.pro/images/6e9df56f9570be437157046b67b57ebc.jpg'),
(36899, 2555, 'NCIS: Investigação Naval S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190889.mp4', 'http://timg.bdta.pro/images/0593cd1d37a44a01995fb7656c491025.jpg'),
(36900, 2555, 'NCIS: Investigação Naval S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190890.mp4', 'http://timg.bdta.pro/images/4d95d7ba3e362bca882ed6910561b219.jpg'),
(36901, 2555, 'NCIS: Investigação Naval S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190891.mp4', 'http://timg.bdta.pro/images/58f4bcb3059258677b774758713ae7da.jpg'),
(36902, 2555, 'NCIS: Investigação Naval S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190892.mp4', 'http://timg.bdta.pro/images/8376b775ba88499393bec42db395a840.jpg'),
(36903, 2555, 'NCIS: Investigação Naval S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190893.mp4', 'http://timg.bdta.pro/images/667d5bbc0e03c49908e0c76527668fdb.jpg'),
(36904, 2555, 'NCIS: Investigação Naval S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190894.mp4', 'http://timg.bdta.pro/images/13652b1d7fa4f6852b049c80d343b80e.jpg'),
(36905, 2555, 'NCIS: Investigação Naval S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190895.mp4', 'http://timg.bdta.pro/images/aa93027dacc274a65b48239fdd67c7d1.jpg'),
(36906, 2555, 'NCIS: Investigação Naval S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190896.mp4', 'http://timg.bdta.pro/images/19d6ba8218d39f3a73127dd222885d4b.jpg'),
(36907, 2555, 'NCIS: Investigação Naval S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190897.mp4', 'http://timg.bdta.pro/images/c4a76086cd5df4670eae67088613b4bf.jpg'),
(36908, 2555, 'NCIS: Investigação Naval S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190898.mp4', 'http://timg.bdta.pro/images/1b233ecacf47485b0327adeb27a847e1.jpg'),
(36909, 2555, 'NCIS: Investigação Naval S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190899.mp4', 'http://timg.bdta.pro/images/d01213cf0fb1c0839740b456c852ec78.jpg'),
(36910, 2555, 'NCIS: Investigação Naval S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190900.mp4', 'http://timg.bdta.pro/images/0e68b6b3bd744103a5a08649217b1a06.jpg'),
(36911, 2555, 'NCIS: Investigação Naval S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/190901.mp4', 'http://timg.bdta.pro/images/d9c58602083329dd80a987729b3b1159.jpg'),
(36912, 2555, 'NCIS: Investigação Naval S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/190902.mp4', 'http://timg.bdta.pro/images/f8ec73b036b4911cad732fa6c4bd4c10.jpg'),
(36913, 2555, 'NCIS: Investigação Naval S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/190903.mp4', 'http://timg.bdta.pro/images/7a54fd719e60b52f58ca878ca792e145.jpg'),
(36914, 2555, 'NCIS: Investigação Naval S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/190904.mp4', 'http://timg.bdta.pro/images/7ba24f4947a7f53653cff2a36dbd5d0c.jpg'),
(36915, 2555, 'NCIS: Investigação Naval S11 E23', 'http://sinalprivado.info:80/series/1533784/1533784/190905.mp4', 'http://timg.bdta.pro/images/1547853754b5173573a470552395e2bf.jpg'),
(36916, 2555, 'NCIS: Investigação Naval S11 E24', 'http://sinalprivado.info:80/series/1533784/1533784/190906.mp4', 'http://timg.bdta.pro/images/ccda0a95e28087ec47fe86ce5978e325.jpg'),
(36917, 2556, 'NCIS: Investigação Naval S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190907.mp4', 'http://timg.bdta.pro/images/638659ab0a81261a86562eba51d64659.jpg'),
(36918, 2556, 'NCIS: Investigação Naval S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190908.mp4', 'http://timg.bdta.pro/images/32a5a61a6ee6857d6c98e70605b7707f.jpg'),
(36919, 2556, 'NCIS: Investigação Naval S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190909.mp4', 'http://timg.bdta.pro/images/a7dcf4f6b0ac898c61a9703ee7b555cd.jpg'),
(36920, 2556, 'NCIS: Investigação Naval S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190910.mp4', 'http://timg.bdta.pro/images/d8c156b04c027e679182c995d92f04bf.jpg'),
(36921, 2556, 'NCIS: Investigação Naval S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190911.mp4', 'http://timg.bdta.pro/images/ccad2cfbce27d14671e72c9d98013059.jpg'),
(36922, 2556, 'NCIS: Investigação Naval S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190912.mp4', 'http://timg.bdta.pro/images/b946618ffe4b717d45c481cb8ba2ad3a.jpg'),
(36923, 2556, 'NCIS: Investigação Naval S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190913.mp4', 'http://timg.bdta.pro/images/f17bc2a2b89a5785fac0d2ff808b09e3.jpg'),
(36924, 2556, 'NCIS: Investigação Naval S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190914.mp4', 'http://timg.bdta.pro/images/8d7e20db5b43cd3019af3048dbe78713.jpg'),
(36925, 2556, 'NCIS: Investigação Naval S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190915.mp4', 'http://timg.bdta.pro/images/097809c595c4af421f0f7a948c45a5e2.jpg'),
(36926, 2556, 'NCIS: Investigação Naval S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190916.mp4', 'http://timg.bdta.pro/images/dd79890684715289f742a7d7dab866ec.jpg'),
(36927, 2556, 'NCIS: Investigação Naval S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190917.mp4', 'http://timg.bdta.pro/images/6679168d04134a86d6d200dba42cf328.jpg'),
(36928, 2556, 'NCIS: Investigação Naval S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190918.mp4', 'http://timg.bdta.pro/images/754e008f08e52edf8e14f3245315faed.jpg'),
(36929, 2556, 'NCIS: Investigação Naval S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190919.mp4', 'http://timg.bdta.pro/images/aacbead9ac15586dc89687441dbfbc2c.jpg'),
(36930, 2556, 'NCIS: Investigação Naval S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190920.mp4', 'http://timg.bdta.pro/images/64710602f3ed3bb3bdc3bb15340ef454.jpg'),
(36931, 2556, 'NCIS: Investigação Naval S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190921.mp4', 'http://timg.bdta.pro/images/11c0e7999bb41c2332e57c0d62784a99.jpg'),
(36932, 2556, 'NCIS: Investigação Naval S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190922.mp4', 'http://timg.bdta.pro/images/9716acf393326be67287dd955c183d8e.jpg'),
(36933, 2556, 'NCIS: Investigação Naval S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190923.mp4', 'http://timg.bdta.pro/images/10297f4685e8ccda62b6f1330ee9ec9a.jpg'),
(36934, 2556, 'NCIS: Investigação Naval S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190924.mp4', 'http://timg.bdta.pro/images/31d4851a56ebdd48797ab35a9146d715.jpg'),
(36935, 2556, 'NCIS: Investigação Naval S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/190925.mp4', 'http://timg.bdta.pro/images/ac768ff64772ea3a5988e8d09f965480.jpg'),
(36936, 2556, 'NCIS: Investigação Naval S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/190926.mp4', 'http://timg.bdta.pro/images/444bed339eef9d74927395756229c26f.jpg'),
(36937, 2556, 'NCIS: Investigação Naval S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/190927.mp4', 'http://timg.bdta.pro/images/3cff85484c651992e6a42d25d948f96f.jpg'),
(36938, 2556, 'NCIS: Investigação Naval S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/190928.mp4', 'http://timg.bdta.pro/images/b54f5f1ff9c84ce5bb8c3aa5498dd05d.jpg'),
(36939, 2556, 'NCIS: Investigação Naval S12 E23', 'http://sinalprivado.info:80/series/1533784/1533784/190929.mp4', 'http://timg.bdta.pro/images/db4d1dbd2aaee91ec6f7d86f8f4f5951.jpg'),
(36940, 2556, 'NCIS: Investigação Naval S12 E24', 'http://sinalprivado.info:80/series/1533784/1533784/190930.mp4', 'http://timg.bdta.pro/images/64cdfffed64fcd352074371a44503e5f.jpg'),
(36941, 2557, 'NCIS: Investigação Naval S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190931.mp4', 'http://timg.bdta.pro/images/856607d1cced6049609746bd471182d0.jpg'),
(36942, 2557, 'NCIS: Investigação Naval S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190932.mp4', 'http://timg.bdta.pro/images/df5c232cfe10c55b04a7ff5fcecb2b60.jpg'),
(36943, 2557, 'NCIS: Investigação Naval S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190933.mp4', 'http://timg.bdta.pro/images/f9df3d816093697e93691a6269e7adbf.jpg'),
(36944, 2557, 'NCIS: Investigação Naval S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190934.mp4', 'http://timg.bdta.pro/images/f2884d8fe003d7435491e3eb0ae523df.jpg'),
(36945, 2557, 'NCIS: Investigação Naval S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190935.mp4', 'http://timg.bdta.pro/images/ed4861cf1569a0430c76a53b40ac7e10.jpg'),
(36946, 2557, 'NCIS: Investigação Naval S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190936.mp4', 'http://timg.bdta.pro/images/7b03d748828cb7e9b21c782fbdf10d3f.jpg'),
(36947, 2557, 'NCIS: Investigação Naval S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190937.mp4', 'http://timg.bdta.pro/images/017b6398ab14f052f18d9533cecefccf.jpg'),
(36948, 2557, 'NCIS: Investigação Naval S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190938.mp4', 'http://timg.bdta.pro/images/3fe8ea88f52ecdae0583ac321d9ae927.jpg'),
(36949, 2557, 'NCIS: Investigação Naval S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190939.mp4', 'http://timg.bdta.pro/images/3f700749aae2b9a06b7d3b3b2c6bff07.jpg'),
(36950, 2557, 'NCIS: Investigação Naval S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190940.mp4', 'http://timg.bdta.pro/images/9d54c156cebaf3b4027c75d79b31195a.jpg'),
(36951, 2557, 'NCIS: Investigação Naval S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190941.mp4', 'http://timg.bdta.pro/images/248a5122c0b1609681de1742d857c0a8.jpg'),
(36952, 2557, 'NCIS: Investigação Naval S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190942.mp4', 'http://timg.bdta.pro/images/897a6bde543c42d6190a2e31f831d608.jpg'),
(36953, 2557, 'NCIS: Investigação Naval S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190943.mp4', 'http://timg.bdta.pro/images/2f735c4b616291a0a41fef5933e9ce07.jpg'),
(36954, 2557, 'NCIS: Investigação Naval S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190944.mp4', 'http://timg.bdta.pro/images/561a022a80a794ff6a5f9695f0c058d3.jpg'),
(36955, 2557, 'NCIS: Investigação Naval S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190945.mp4', 'http://timg.bdta.pro/images/059e3c127a4a226299c641b88f39a29e.jpg'),
(36956, 2557, 'NCIS: Investigação Naval S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190946.mp4', 'http://timg.bdta.pro/images/ab722b2f63a7330f051700acc00af69e.jpg'),
(36957, 2557, 'NCIS: Investigação Naval S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190947.mp4', 'http://timg.bdta.pro/images/4e31b37e2ef20ac1d2614ea151e08ec1.jpg'),
(36958, 2557, 'NCIS: Investigação Naval S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190948.mp4', 'http://timg.bdta.pro/images/df731faa01e6d35853f3cccc6e5ad9b2.jpg'),
(36959, 2557, 'NCIS: Investigação Naval S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/190949.mp4', 'http://timg.bdta.pro/images/66ceb57ae4eee8e337fd1e4844f5a88e.jpg'),
(36960, 2557, 'NCIS: Investigação Naval S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/190950.mp4', 'http://timg.bdta.pro/images/e49f16e7b3745e07e78a7ea960f7a078.jpg'),
(36961, 2557, 'NCIS: Investigação Naval S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/190951.mp4', 'http://timg.bdta.pro/images/8a71d08e804fca449ad114d6479eb48b.jpg'),
(36962, 2557, 'NCIS: Investigação Naval S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/190952.mp4', 'http://timg.bdta.pro/images/0570e7ed0afdf375a929baa45f5696ef.jpg'),
(36963, 2557, 'NCIS: Investigação Naval S13 E23', 'http://sinalprivado.info:80/series/1533784/1533784/190953.mp4', 'http://timg.bdta.pro/images/a47643de9b82d157b28b8a462df2cd9f.jpg'),
(36964, 2557, 'NCIS: Investigação Naval S13 E24', 'http://sinalprivado.info:80/series/1533784/1533784/190954.mp4', 'http://timg.bdta.pro/images/0bcef3eaf2f7f13e92346289e5368020.jpg'),
(36965, 2558, 'NCIS: Investigação Naval S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190955.mp4', 'http://timg.bdta.pro/images/724b0655c6db6f2ea4ed208521f74a10.jpg'),
(36966, 2558, 'NCIS: Investigação Naval S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190956.mp4', 'http://timg.bdta.pro/images/13ba4eb5c2aface5eb13049eb38c01ba.jpg'),
(36967, 2558, 'NCIS: Investigação Naval S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190957.mp4', 'http://timg.bdta.pro/images/2891e8a97587b60acdcbf101353cf95d.jpg'),
(36968, 2558, 'NCIS: Investigação Naval S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190958.mp4', 'http://timg.bdta.pro/images/6d9cf953992512c9ba5cb082d8c42220.jpg'),
(36969, 2558, 'NCIS: Investigação Naval S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190959.mp4', 'http://timg.bdta.pro/images/5fab9d2d9851a24c26daadaef1ebbc98.jpg'),
(36970, 2558, 'NCIS: Investigação Naval S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190960.mp4', 'http://timg.bdta.pro/images/7ef9d32582fd0edd73f6fe92bf7e0eed.jpg'),
(36971, 2558, 'NCIS: Investigação Naval S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190961.mp4', 'http://timg.bdta.pro/images/af545a95a745f2483208969bcd58dc4b.jpg'),
(36972, 2558, 'NCIS: Investigação Naval S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190962.mp4', 'http://timg.bdta.pro/images/2eeaeef4e49ba74215955fe77141328b.jpg'),
(36973, 2558, 'NCIS: Investigação Naval S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190963.mp4', 'http://timg.bdta.pro/images/ff324ffd26dc57a4bb88cda73f39d136.jpg'),
(36974, 2558, 'NCIS: Investigação Naval S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190964.mp4', 'http://timg.bdta.pro/images/eb6d9da23286e2089d482443108f0ccd.jpg'),
(36975, 2558, 'NCIS: Investigação Naval S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190965.mp4', 'http://timg.bdta.pro/images/e29a3ac6ffced1226bd8bca09eebc1e2.jpg'),
(36976, 2558, 'NCIS: Investigação Naval S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190966.mp4', 'http://timg.bdta.pro/images/b7b9b86aaed0f48e77120074e52b6dd9.jpg'),
(36977, 2558, 'NCIS: Investigação Naval S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190967.mp4', 'http://timg.bdta.pro/images/e6b1c303bbc3424550ffe1e16ddba8e7.jpg'),
(36978, 2558, 'NCIS: Investigação Naval S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190968.mp4', 'http://timg.bdta.pro/images/36a1b9eff15e4ae9d7bfe07e2fa670a2.jpg'),
(36979, 2558, 'NCIS: Investigação Naval S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190969.mp4', 'http://timg.bdta.pro/images/310858eee07d1782a88193ae97bb4778.jpg'),
(36980, 2558, 'NCIS: Investigação Naval S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190970.mp4', 'http://timg.bdta.pro/images/83868a89ffeb0122eea482a6939f5ae0.jpg'),
(36981, 2558, 'NCIS: Investigação Naval S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190971.mp4', 'http://timg.bdta.pro/images/54a51752ab4587816ddd5b601f2da974.jpg'),
(36982, 2558, 'NCIS: Investigação Naval S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190972.mp4', 'http://timg.bdta.pro/images/946dab1d8724bf3d48e82a7dc1177421.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(36983, 2558, 'NCIS: Investigação Naval S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/190973.mp4', 'http://timg.bdta.pro/images/63549bf6065fc7195408a67d137a1dee.jpg'),
(36984, 2558, 'NCIS: Investigação Naval S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/190974.mp4', 'http://timg.bdta.pro/images/f796d3723aedf24566ce156733ec274a.jpg'),
(36985, 2558, 'NCIS: Investigação Naval S14 E21', 'http://sinalprivado.info:80/series/1533784/1533784/190975.mp4', 'http://timg.bdta.pro/images/3d7d595ba3fafdb25b57933a244e1d92.jpg'),
(36986, 2558, 'NCIS: Investigação Naval S14 E22', 'http://sinalprivado.info:80/series/1533784/1533784/190976.mp4', 'http://timg.bdta.pro/images/60e28d7d2673325cb293519abec8ee90.jpg'),
(36987, 2558, 'NCIS: Investigação Naval S14 E23', 'http://sinalprivado.info:80/series/1533784/1533784/190977.mp4', 'http://timg.bdta.pro/images/20a4b79396331aa20894d76b76c831ec.jpg'),
(36988, 2559, 'NCIS: Investigação Naval S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190978.mp4', 'http://timg.bdta.pro/images/0fe2ea4b5aa71f7153e6a27fd4ffad74.jpg'),
(36989, 2559, 'NCIS: Investigação Naval S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190979.mp4', 'http://timg.bdta.pro/images/362524f2a1d4e2f39266b053cfd4321b.jpg'),
(36990, 2559, 'NCIS: Investigação Naval S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190980.mp4', 'http://timg.bdta.pro/images/7cdd7a3f1af871a98a69a268729fda82.jpg'),
(36991, 2559, 'NCIS: Investigação Naval S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190981.mp4', 'http://timg.bdta.pro/images/245a2c2ecfba5627c15857c407ee0be4.jpg'),
(36992, 2559, 'NCIS: Investigação Naval S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190982.mp4', 'http://timg.bdta.pro/images/16e974160c5337dca21824bd80e8be6c.jpg'),
(36993, 2559, 'NCIS: Investigação Naval S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190983.mp4', 'http://timg.bdta.pro/images/f3fd982a55e2236ed097855d1a9f9ca6.jpg'),
(36994, 2559, 'NCIS: Investigação Naval S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190984.mp4', 'http://timg.bdta.pro/images/32f5a576cb63a860126beb2c3b795b6c.jpg'),
(36995, 2559, 'NCIS: Investigação Naval S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190985.mp4', 'http://timg.bdta.pro/images/fa9c0cd6f8ddb74cec69caaabb3ee538.jpg'),
(36996, 2559, 'NCIS: Investigação Naval S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190986.mp4', 'http://timg.bdta.pro/images/01403726c5cd694476ffcd9bb134bab5.jpg'),
(36997, 2559, 'NCIS: Investigação Naval S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190987.mp4', 'http://timg.bdta.pro/images/9e771fa2441fcaf687b2bb4e0137711d.jpg'),
(36998, 2559, 'NCIS: Investigação Naval S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190988.mp4', 'http://timg.bdta.pro/images/954e251931bc5343273b15754f20a2cc.jpg'),
(36999, 2559, 'NCIS: Investigação Naval S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190989.mp4', 'http://timg.bdta.pro/images/b4c7e489f7d76fded16d7f26ece16fd8.jpg'),
(37000, 2559, 'NCIS: Investigação Naval S15 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190990.mp4', 'http://timg.bdta.pro/images/82eecb8b1f2ce254fb1654459a47f451.jpg'),
(37001, 2559, 'NCIS: Investigação Naval S15 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190991.mp4', 'http://timg.bdta.pro/images/8b3732f55906225e7b136cacb018c7a4.jpg'),
(37002, 2559, 'NCIS: Investigação Naval S15 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190992.mp4', 'http://timg.bdta.pro/images/eac5805f6b5cdb243b322789138a781a.jpg'),
(37003, 2559, 'NCIS: Investigação Naval S15 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190993.mp4', 'http://timg.bdta.pro/images/dec6798f536ccaab7b68be002ba3dea7.jpg'),
(37004, 2559, 'NCIS: Investigação Naval S15 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190994.mp4', 'http://timg.bdta.pro/images/947149b9d943d0452c0ad3d2d0828ac5.jpg'),
(37005, 2559, 'NCIS: Investigação Naval S15 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190995.mp4', 'http://timg.bdta.pro/images/71fcb8d28e9003402dbb9650d09be418.jpg'),
(37006, 2559, 'NCIS: Investigação Naval S15 E19', 'http://sinalprivado.info:80/series/1533784/1533784/190996.mp4', 'http://timg.bdta.pro/images/1ba1199d7bcf38b07a5524f03822a927.jpg'),
(37007, 2559, 'NCIS: Investigação Naval S15 E20', 'http://sinalprivado.info:80/series/1533784/1533784/190997.mp4', 'http://timg.bdta.pro/images/cd649971a4ecdd95de45405dc3680b6b.jpg'),
(37008, 2559, 'NCIS: Investigação Naval S15 E21', 'http://sinalprivado.info:80/series/1533784/1533784/190998.mp4', 'http://timg.bdta.pro/images/0b565da2c2f779cf18de2b1228702d91.jpg'),
(37009, 2559, 'NCIS: Investigação Naval S15 E22', 'http://sinalprivado.info:80/series/1533784/1533784/190999.mp4', 'http://timg.bdta.pro/images/7ee1320686332ba52d1f2a067a15c2f9.jpg'),
(37010, 2559, 'NCIS: Investigação Naval S15 E23', 'http://sinalprivado.info:80/series/1533784/1533784/191000.mp4', 'http://timg.bdta.pro/images/42eb4a200ca0b5a9d82ab557c3423d22.jpg'),
(37011, 2559, 'NCIS: Investigação Naval S15 E24', 'http://sinalprivado.info:80/series/1533784/1533784/191001.mp4', 'http://timg.bdta.pro/images/af51e5c2c901018b3d902f0626be1726.jpg'),
(37012, 2560, 'NCIS: Investigação Naval S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191002.mp4', 'http://timg.bdta.pro/images/4ca4468b65add2072f52729c8204d420.jpg'),
(37013, 2560, 'NCIS: Investigação Naval S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191003.mp4', 'http://timg.bdta.pro/images/5cf91ebaaeb4ed99f2128e0a7ef7676c.jpg'),
(37014, 2560, 'NCIS: Investigação Naval S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191004.mp4', 'http://timg.bdta.pro/images/96d43af23ed1a102ee36897e342dcbae.jpg'),
(37015, 2560, 'NCIS: Investigação Naval S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191005.mp4', 'http://timg.bdta.pro/images/0fe25c85192a6472b3dedc74a85ac63c.jpg'),
(37016, 2560, 'NCIS: Investigação Naval S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191006.mp4', 'http://timg.bdta.pro/images/b464a6a744d5720be1a94d6c8083eae0.jpg'),
(37017, 2560, 'NCIS: Investigação Naval S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191007.mp4', 'http://timg.bdta.pro/images/e527141d183f3a06eb865ed6a06052d5.jpg'),
(37018, 2560, 'NCIS: Investigação Naval S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191008.mp4', 'http://timg.bdta.pro/images/1bf07d480468238a22ee33932d0e6a5d.jpg'),
(37019, 2560, 'NCIS: Investigação Naval S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191009.mp4', 'http://timg.bdta.pro/images/7c46a501dea5c07641b65e13579176ba.jpg'),
(37020, 2560, 'NCIS: Investigação Naval S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191010.mp4', 'http://timg.bdta.pro/images/a7921d379ce31e23a80f7022b74a62ea.jpg'),
(37021, 2560, 'NCIS: Investigação Naval S16 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191011.mp4', 'http://timg.bdta.pro/images/961cfa5f61867e666adc9be2fbddf22a.jpg'),
(37022, 2560, 'NCIS: Investigação Naval S16 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191012.mp4', 'http://timg.bdta.pro/images/9f3442b1202d50ce7734a748ee8aaca3.jpg'),
(37023, 2560, 'NCIS: Investigação Naval S16 E12', 'http://sinalprivado.info:80/series/1533784/1533784/191013.mp4', 'http://timg.bdta.pro/images/d8cade6e12f168528ded10ede270aa3d.jpg'),
(37024, 2560, 'NCIS: Investigação Naval S16 E13', 'http://sinalprivado.info:80/series/1533784/1533784/191014.mp4', 'http://timg.bdta.pro/images/582ee92624f0557eeb021a99d4cd2c95.jpg'),
(37025, 2560, 'NCIS: Investigação Naval S16 E14', 'http://sinalprivado.info:80/series/1533784/1533784/191015.mp4', 'http://timg.bdta.pro/images/f05e275c8ae253aa6114bca0e1a08cef.jpg'),
(37026, 2560, 'NCIS: Investigação Naval S16 E15', 'http://sinalprivado.info:80/series/1533784/1533784/191016.mp4', 'http://timg.bdta.pro/images/d92cbd89449c06d1e911310684a5aa93.jpg'),
(37027, 2560, 'NCIS: Investigação Naval S16 E16', 'http://sinalprivado.info:80/series/1533784/1533784/191017.mp4', 'http://timg.bdta.pro/images/6652aea26a941dc3a3796c827970bc01.jpg'),
(37028, 2560, 'NCIS: Investigação Naval S16 E17', 'http://sinalprivado.info:80/series/1533784/1533784/191018.mp4', 'http://timg.bdta.pro/images/64a43f7e0711cbe85ca175e9a14aeaef.jpg'),
(37029, 2560, 'NCIS: Investigação Naval S16 E18', 'http://sinalprivado.info:80/series/1533784/1533784/191019.mp4', 'http://timg.bdta.pro/images/7d7f038a48226f95c04a342426e2fe71.jpg'),
(37030, 2560, 'NCIS: Investigação Naval S16 E19', 'http://sinalprivado.info:80/series/1533784/1533784/191020.mp4', 'http://timg.bdta.pro/images/79b06feac4bacd41c99aaf467622f856.jpg'),
(37031, 2560, 'NCIS: Investigação Naval S16 E20', 'http://sinalprivado.info:80/series/1533784/1533784/191021.mp4', 'http://timg.bdta.pro/images/ac23352496e580066278ed1080a4d57b.jpg'),
(37032, 2560, 'NCIS: Investigação Naval S16 E21', 'http://sinalprivado.info:80/series/1533784/1533784/191022.mp4', 'http://timg.bdta.pro/images/d19161e3ec8b7873423deeea789998ed.jpg'),
(37033, 2560, 'NCIS: Investigação Naval S16 E22', 'http://sinalprivado.info:80/series/1533784/1533784/191023.mp4', 'http://timg.bdta.pro/images/f843f6fc47c400f2d7fa536e3e8a3c32.jpg'),
(37034, 2560, 'NCIS: Investigação Naval S16 E23', 'http://sinalprivado.info:80/series/1533784/1533784/191024.mp4', 'http://timg.bdta.pro/images/d65d449ec9a6267c6d66474f5712da29.jpg'),
(37035, 2560, 'NCIS: Investigação Naval S16 E24', 'http://sinalprivado.info:80/series/1533784/1533784/191025.mp4', 'http://timg.bdta.pro/images/0ec0738cd78ddb96e5ce1671f6ade734.jpg'),
(37036, 2561, 'NCIS: Investigação Naval S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191026.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37037, 2561, 'NCIS: Investigação Naval S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191027.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37038, 2561, 'NCIS: Investigação Naval S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191028.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37039, 2561, 'NCIS: Investigação Naval S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191029.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37040, 2561, 'NCIS: Investigação Naval S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191030.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37041, 2561, 'NCIS: Investigação Naval S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191031.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37042, 2561, 'NCIS: Investigação Naval S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191032.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37043, 2561, 'NCIS: Investigação Naval S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191033.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37044, 2561, 'NCIS: Investigação Naval S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191034.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37045, 2561, 'NCIS: Investigação Naval S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191035.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37046, 2561, 'NCIS: Investigação Naval S17 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191036.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37047, 2561, 'NCIS: Investigação Naval S17 E12', 'http://sinalprivado.info:80/series/1533784/1533784/191037.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37048, 2561, 'NCIS: Investigação Naval S17 E13', 'http://sinalprivado.info:80/series/1533784/1533784/191038.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37049, 2561, 'NCIS: Investigação Naval S17 E14', 'http://sinalprivado.info:80/series/1533784/1533784/191039.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37050, 2561, 'NCIS: Investigação Naval S17 E15', 'http://sinalprivado.info:80/series/1533784/1533784/191040.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37051, 2561, 'NCIS: Investigação Naval S17 E16', 'http://sinalprivado.info:80/series/1533784/1533784/191041.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37052, 2561, 'NCIS: Investigação Naval S17 E17', 'http://sinalprivado.info:80/series/1533784/1533784/191042.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37053, 2561, 'NCIS: Investigação Naval S17 E18', 'http://sinalprivado.info:80/series/1533784/1533784/191043.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37054, 2561, 'NCIS: Investigação Naval S17 E19', 'http://sinalprivado.info:80/series/1533784/1533784/191044.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37055, 2561, 'NCIS: Investigação Naval S17 E20', 'http://sinalprivado.info:80/series/1533784/1533784/191045.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37056, 2562, 'NCIS: Investigação Naval S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191046.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37057, 2562, 'NCIS: Investigação Naval S18 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191047.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37058, 2562, 'NCIS: Investigação Naval S18 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191048.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37059, 2562, 'NCIS: Investigação Naval S18 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191049.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37060, 2562, 'NCIS: Investigação Naval S18 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191050.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37061, 2562, 'NCIS: Investigação Naval S18 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191051.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37062, 2562, 'NCIS: Investigação Naval S18 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191052.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37063, 2562, 'NCIS: Investigação Naval S18 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191053.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37064, 2562, 'NCIS: Investigação Naval S18 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191054.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37065, 2562, 'NCIS: Investigação Naval S18 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191055.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37066, 2562, 'NCIS: Investigação Naval S18 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191056.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37067, 2562, 'NCIS: Investigação Naval S18 E12', 'http://sinalprivado.info:80/series/1533784/1533784/191057.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37068, 2562, 'NCIS: Investigação Naval S18 E13', 'http://sinalprivado.info:80/series/1533784/1533784/191058.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37069, 2562, 'NCIS: Investigação Naval S18 E14', 'http://sinalprivado.info:80/series/1533784/1533784/191059.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37070, 2562, 'NCIS: Investigação Naval S18 E15', 'http://sinalprivado.info:80/series/1533784/1533784/191060.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37071, 2562, 'NCIS: Investigação Naval S18 E16', 'http://sinalprivado.info:80/series/1533784/1533784/191061.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37072, 2563, 'NCIS: Investigação Naval S19 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191062.mp4', 'http://image.tmdb.org/t/p/w1280/mMobF6gFLTSj0XoVHam70imCt7w.jpg'),
(37073, 2563, 'NCIS: Investigação Naval S19 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191063.mp4', 'http://image.tmdb.org/t/p/w1280/txdEWLibheWMEb00P8pYoNch4gz.jpg'),
(37074, 2563, 'NCIS: Investigação Naval S19 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191064.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37075, 2563, 'NCIS: Investigação Naval S19 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191065.mp4', 'http://image.tmdb.org/t/p/w1280/eGWeW0ZChX43G0YSTtGik2jIcDi.jpg'),
(37076, 2563, 'NCIS: Investigação Naval S19 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191066.mp4', 'http://image.tmdb.org/t/p/w1280/iWM780infuavHASgUW0SvZk8ptt.jpg'),
(37077, 2563, 'NCIS: Investigação Naval S19 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191067.mp4', 'http://timg.bdta.pro/images/790b8031b65bb04810440255ca9c6525.jpg'),
(37078, 2563, 'NCIS: Investigação Naval S19 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191068.mp4', 'http://timg.bdta.pro/images/17081ea4c0d1fb37e065b89af1f7e965.jpg'),
(37079, 2563, 'NCIS: Investigação Naval S19 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191069.mp4', 'http://timg.bdta.pro/images/c7426e16020e6764c8e62de05ac53a27.jpg'),
(37080, 2563, 'NCIS: Investigação Naval S19 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191070.mp4', 'http://timg.bdta.pro/images/4959f72c2320c3bb9817d3e527ec2b0e.jpg'),
(37081, 2563, 'NCIS: Investigação Naval S19 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191071.mp4', 'http://timg.bdta.pro/images/cd887ceeafd779ebbe72722ed3fbaedf.jpg'),
(37082, 2563, 'NCIS: Investigação Naval S19 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191072.mp4', 'http://timg.bdta.pro/images/b70e722326d67db01951706fff0a4b08.jpg'),
(37083, 2563, 'NCIS: Investigação Naval S19 E12', 'http://sinalprivado.info:80/series/1533784/1533784/191073.mp4', 'http://timg.bdta.pro/images/369e3369e676761e1cdd1db44776aa77.jpg'),
(37084, 2563, 'NCIS: Investigação Naval S19 E13', 'http://sinalprivado.info:80/series/1533784/1533784/191074.mp4', 'http://timg.bdta.pro/images/57fed567d4ee4a8c8df62a38c897f7b4.jpg'),
(37085, 2563, 'NCIS: Investigação Naval S19 E14', 'http://sinalprivado.info:80/series/1533784/1533784/191075.mp4', 'http://timg.bdta.pro/images/a4ac96072926c0834ad5fddf6b0ec825.jpg'),
(37086, 2563, 'NCIS: Investigação Naval S19 E15', 'http://sinalprivado.info:80/series/1533784/1533784/191076.mp4', 'http://timg.bdta.pro/images/ead18090a38207c4d0a8c122e2ecd732.jpg'),
(37087, 2563, 'NCIS: Investigação Naval S19 E16', 'http://sinalprivado.info:80/series/1533784/1533784/191077.mp4', 'http://timg.bdta.pro/images/4d06280108169ea40fa409c1dc7e2932.jpg'),
(37088, 2563, 'NCIS: Investigação Naval S19 E17', 'http://sinalprivado.info:80/series/1533784/1533784/191078.mp4', 'http://timg.bdta.pro/images/8e3f21e287c8ba098db1ecd60b9beedb.jpg'),
(37089, 2563, 'NCIS: Investigação Naval S19 E18', 'http://sinalprivado.info:80/series/1533784/1533784/191079.mp4', 'http://timg.bdta.pro/images/e9e32a74d46e2ff378d7b16cdafc5be8.jpg'),
(37090, 2563, 'NCIS: Investigação Naval S19 E19', 'http://sinalprivado.info:80/series/1533784/1533784/191080.mp4', 'http://timg.bdta.pro/images/37f3ffe85c7fd3db8b1a6f2e75d66f94.jpg'),
(37091, 2563, 'NCIS: Investigação Naval S19 E20', 'http://sinalprivado.info:80/series/1533784/1533784/191081.mp4', 'http://timg.bdta.pro/images/cf5bc35c9d51b915a373fd9ca3d62384.jpg'),
(37092, 2563, 'NCIS: Investigação Naval S19 E21', 'http://sinalprivado.info:80/series/1533784/1533784/191082.mp4', 'http://timg.bdta.pro/images/a3864b27e7d02a470a4cc23d4361ee38.jpg'),
(37093, 2564, 'NCIS: Investigação Naval S20 E01', 'http://sinalprivado.info:80/series/1533784/1533784/352049.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37094, 2564, 'NCIS: Investigação Naval S20 E02', 'http://sinalprivado.info:80/series/1533784/1533784/352050.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37095, 2564, 'NCIS: Investigação Naval S20 E03', 'http://sinalprivado.info:80/series/1533784/1533784/352051.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37096, 2564, 'NCIS: Investigação Naval S20 E04', 'http://sinalprivado.info:80/series/1533784/1533784/352052.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37097, 2564, 'NCIS: Investigação Naval S20 E05', 'http://sinalprivado.info:80/series/1533784/1533784/352053.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37098, 2564, 'NCIS: Investigação Naval S20 E06', 'http://sinalprivado.info:80/series/1533784/1533784/352054.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37099, 2564, 'NCIS: Investigação Naval S20 E07', 'http://sinalprivado.info:80/series/1533784/1533784/352055.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37100, 2564, 'NCIS: Investigação Naval S20 E08', 'http://sinalprivado.info:80/series/1533784/1533784/352056.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37101, 2564, 'NCIS: Investigação Naval S20 E09', 'http://sinalprivado.info:80/series/1533784/1533784/352057.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37102, 2564, 'NCIS: Investigação Naval S20 E10', 'http://sinalprivado.info:80/series/1533784/1533784/352058.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37103, 2564, 'NCIS: Investigação Naval S20 E11', 'http://sinalprivado.info:80/series/1533784/1533784/352059.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37104, 2564, 'NCIS: Investigação Naval S20 E12', 'http://sinalprivado.info:80/series/1533784/1533784/352060.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37105, 2564, 'NCIS: Investigação Naval S20 E13', 'http://sinalprivado.info:80/series/1533784/1533784/352061.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37106, 2564, 'NCIS: Investigação Naval S20 E14', 'http://sinalprivado.info:80/series/1533784/1533784/352062.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37107, 2564, 'NCIS: Investigação Naval S20 E15', 'http://sinalprivado.info:80/series/1533784/1533784/352063.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37108, 2564, 'NCIS: Investigação Naval S20 E16', 'http://sinalprivado.info:80/series/1533784/1533784/352064.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37109, 2564, 'NCIS: Investigação Naval S20 E17', 'http://sinalprivado.info:80/series/1533784/1533784/352065.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37110, 2564, 'NCIS: Investigação Naval S20 E18', 'http://sinalprivado.info:80/series/1533784/1533784/352066.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37111, 2564, 'NCIS: Investigação Naval S20 E19', 'http://sinalprivado.info:80/series/1533784/1533784/352067.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37112, 2564, 'NCIS: Investigação Naval S20 E20', 'http://sinalprivado.info:80/series/1533784/1533784/352068.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37113, 2564, 'NCIS: Investigação Naval S20 E21', 'http://sinalprivado.info:80/series/1533784/1533784/352069.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37114, 2564, 'NCIS: Investigação Naval S20 E22', 'http://sinalprivado.info:80/series/1533784/1533784/352070.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37115, 2565, 'NCIS: Investigação Naval S21 E01', 'http://sinalprivado.info:80/series/1533784/1533784/352071.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37116, 2565, 'NCIS: Investigação Naval S21 E02', 'http://sinalprivado.info:80/series/1533784/1533784/352072.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37117, 2565, 'NCIS: Investigação Naval S21 E03', 'http://sinalprivado.info:80/series/1533784/1533784/359388.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37118, 2565, 'NCIS: Investigação Naval S21 E04', 'http://sinalprivado.info:80/series/1533784/1533784/367954.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37119, 2565, 'NCIS: Investigação Naval S21 E05', 'http://sinalprivado.info:80/series/1533784/1533784/373935.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37120, 2565, 'NCIS: Investigação Naval S21 E06', 'http://sinalprivado.info:80/series/1533784/1533784/382481.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37121, 2565, 'NCIS: Investigação Naval S21 E07', 'http://sinalprivado.info:80/series/1533784/1533784/389482.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37122, 2565, 'NCIS: Investigação Naval S21 E08', 'http://sinalprivado.info:80/series/1533784/1533784/396400.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37123, 2565, 'NCIS: Investigação Naval S21 E09', 'http://sinalprivado.info:80/series/1533784/1533784/400963.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37124, 2565, 'NCIS: Investigação Naval S21 E10', 'http://sinalprivado.info:80/series/1533784/1533784/404869.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37125, 2566, 'NCIS: Investigação Naval S22 E01', 'http://sinalprivado.info:80/series/1533784/1533784/675407.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37126, 2566, 'NCIS: Investigação Naval S22 E02', 'http://sinalprivado.info:80/series/1533784/1533784/682563.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37127, 2566, 'NCIS: Investigação Naval S22 E03', 'http://sinalprivado.info:80/series/1533784/1533784/689765.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37128, 2566, 'NCIS: Investigação Naval S22 E04', 'http://sinalprivado.info:80/series/1533784/1533784/700064.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37129, 2566, 'NCIS: Investigação Naval S22 E05', 'http://sinalprivado.info:80/series/1533784/1533784/705007.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37130, 2566, 'NCIS: Investigação Naval S22 E06', 'http://sinalprivado.info:80/series/1533784/1533784/716557.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37131, 2566, 'NCIS: Investigação Naval S22 E07', 'http://sinalprivado.info:80/series/1533784/1533784/720604.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37132, 2566, 'NCIS: Investigação Naval S22 E08', 'http://sinalprivado.info:80/series/1533784/1533784/729074.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37133, 2566, 'NCIS: Investigação Naval S22 E09', 'http://sinalprivado.info:80/series/1533784/1533784/738497.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37134, 2566, 'NCIS: Investigação Naval S22 E10', 'http://sinalprivado.info:80/series/1533784/1533784/751548.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37135, 2566, 'NCIS: Investigação Naval S22 E11', 'http://sinalprivado.info:80/series/1533784/1533784/774504.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37136, 2566, 'NCIS: Investigação Naval S22 E12', 'http://sinalprivado.info:80/series/1533784/1533784/794358.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37137, 2566, 'NCIS: Investigação Naval S22 E13', 'http://sinalprivado.info:80/series/1533784/1533784/794359.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37138, 2566, 'NCIS: Investigação Naval S22 E14', 'http://sinalprivado.info:80/series/1533784/1533784/800181.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37139, 2566, 'NCIS: Investigação Naval S22 E15', 'http://sinalprivado.info:80/series/1533784/1533784/809678.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37140, 2566, 'NCIS: Investigação Naval S22 E16', 'http://sinalprivado.info:80/series/1533784/1533784/809679.mp4', 'http://gstaticontent.com/images/6b68fd3p0OpRXJZfZGLQ9Gs7kzl_big.jpg'),
(37141, 2567, 'As Novas Aventuras de Christine S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127111.mp4', 'http://timg.bdta.pro/images/dd6517276a71c9a7db4cddc72c7dc88c.jpg'),
(37142, 2567, 'As Novas Aventuras de Christine S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127112.mp4', 'http://timg.bdta.pro/images/acd7b37ea0e31d1b2c25880b0888bef5.jpg'),
(37143, 2567, 'As Novas Aventuras de Christine S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127113.mp4', 'http://timg.bdta.pro/images/dc4762d469cc386b6bab060dd7a7324e.jpg'),
(37144, 2567, 'As Novas Aventuras de Christine S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127114.mp4', 'http://timg.bdta.pro/images/4727a8b83f463dc77885f45f77f21c2e.jpg'),
(37145, 2567, 'As Novas Aventuras de Christine S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127115.mp4', 'http://timg.bdta.pro/images/8320886d08d0a1542160684fcbc1d0d5.jpg'),
(37146, 2567, 'As Novas Aventuras de Christine S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127116.mp4', 'http://timg.bdta.pro/images/ab98a577da941238252a5750112b2d2d.jpg'),
(37147, 2567, 'As Novas Aventuras de Christine S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127117.mp4', 'http://timg.bdta.pro/images/65396c84327b67ab0a093cda301171b8.jpg'),
(37148, 2567, 'As Novas Aventuras de Christine S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127118.mp4', 'http://timg.bdta.pro/images/5684ee6434afa0b149b8f6474d1128e8.jpg'),
(37149, 2567, 'As Novas Aventuras de Christine S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127119.mp4', 'http://timg.bdta.pro/images/356a4c73876b37347fb240192693a9fd.jpg'),
(37150, 2567, 'As Novas Aventuras de Christine S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127120.mp4', 'http://timg.bdta.pro/images/b079734b144389e65bcaa782a85c5dc7.jpg'),
(37151, 2567, 'As Novas Aventuras de Christine S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127121.mp4', 'http://timg.bdta.pro/images/6634faa326b8d9ef79ee2db1e6e8d1b1.jpg'),
(37152, 2567, 'As Novas Aventuras de Christine S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127122.mp4', 'http://timg.bdta.pro/images/b52dde1e844e4c9bbaa80f8b2555482d.jpg'),
(37153, 2567, 'As Novas Aventuras de Christine S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127123.mp4', 'http://timg.bdta.pro/images/5cbe39b45ca0fcff8c04ec8e712ba3be.jpg'),
(37154, 2568, 'As Novas Aventuras de Christine S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127124.mp4', 'http://timg.bdta.pro/images/aeb6e9cebde7b4956bb92e7c7164dbe9.jpg'),
(37155, 2568, 'As Novas Aventuras de Christine S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127125.mp4', 'http://timg.bdta.pro/images/7e217d9c126add4a7d52b4974170ae64.jpg'),
(37156, 2568, 'As Novas Aventuras de Christine S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127126.mp4', 'http://timg.bdta.pro/images/5b36e143ce153667a3fcc39931633e34.jpg'),
(37157, 2568, 'As Novas Aventuras de Christine S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127127.mp4', 'http://timg.bdta.pro/images/075d6e4d2ab7a901a4696742c5178104.jpg'),
(37158, 2568, 'As Novas Aventuras de Christine S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127128.mp4', 'http://timg.bdta.pro/images/3fc43a80d43dfb5a6571b9e25844699e.jpg'),
(37159, 2568, 'As Novas Aventuras de Christine S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127129.mp4', 'http://timg.bdta.pro/images/1855a7d8a8b85e810ceaf6a5cea86a72.jpg'),
(37160, 2568, 'As Novas Aventuras de Christine S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127130.mp4', 'http://timg.bdta.pro/images/3c7279c3527be86736bbfd6bbec9430b.jpg'),
(37161, 2568, 'As Novas Aventuras de Christine S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127131.mp4', 'http://timg.bdta.pro/images/f26defcbdd125f8688631905da9bdcf4.jpg'),
(37162, 2568, 'As Novas Aventuras de Christine S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127132.mp4', 'http://timg.bdta.pro/images/fe5f8338ab93ab4bfc16e1fbe78c8e34.jpg'),
(37163, 2568, 'As Novas Aventuras de Christine S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127133.mp4', 'http://timg.bdta.pro/images/aa8ec49d3776451e52f9a07cd085c772.jpg'),
(37164, 2568, 'As Novas Aventuras de Christine S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127134.mp4', 'http://timg.bdta.pro/images/8c49426f88ecc72ca4c0eab153092fe1.jpg'),
(37165, 2568, 'As Novas Aventuras de Christine S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127135.mp4', 'http://timg.bdta.pro/images/c46e23ccebf85a992014f04e7bb8beb4.jpg'),
(37166, 2568, 'As Novas Aventuras de Christine S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127136.mp4', 'http://timg.bdta.pro/images/40441f3bcb0840ba9a2c99c444ac88e6.jpg'),
(37167, 2568, 'As Novas Aventuras de Christine S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127137.mp4', 'http://timg.bdta.pro/images/aee69b86f6ee44799bed6aa2fce5ab43.jpg'),
(37168, 2568, 'As Novas Aventuras de Christine S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127138.mp4', 'http://timg.bdta.pro/images/fe5dd3af1d65c48e6d581a3e9e39738c.jpg'),
(37169, 2568, 'As Novas Aventuras de Christine S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127139.mp4', 'http://timg.bdta.pro/images/083bbdf5d237beba1f48e166cdfd25af.jpg'),
(37170, 2568, 'As Novas Aventuras de Christine S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127140.mp4', 'http://timg.bdta.pro/images/b82a4306b6e11e4d556fe60924ff84b6.jpg'),
(37171, 2568, 'As Novas Aventuras de Christine S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127141.mp4', 'http://timg.bdta.pro/images/3f8d04aeb3c760bfb93ab60a9a3dfab6.jpg'),
(37172, 2568, 'As Novas Aventuras de Christine S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127142.mp4', 'http://timg.bdta.pro/images/a7e3ab502d11882b28d3c652e5de5be3.jpg'),
(37173, 2568, 'As Novas Aventuras de Christine S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127143.mp4', 'http://timg.bdta.pro/images/856bb259a72eea60fa07544f0e41acf0.jpg'),
(37174, 2568, 'As Novas Aventuras de Christine S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127144.mp4', 'http://timg.bdta.pro/images/2d86bd7b732ad0ccc040e4c5f8c1d6f0.jpg'),
(37175, 2568, 'As Novas Aventuras de Christine S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/127145.mp4', 'http://timg.bdta.pro/images/34b4e4f95dee39af56501a16954f2ae9.jpg'),
(37176, 2569, 'As Novas Aventuras de Christine S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127146.mp4', 'http://timg.bdta.pro/images/b9900b4396e9b4cf2a1cb5acea364cdc.jpg'),
(37177, 2569, 'As Novas Aventuras de Christine S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127147.mp4', 'http://timg.bdta.pro/images/60acc6ecfd78e211a6e4f08d0b7b2d9a.jpg'),
(37178, 2569, 'As Novas Aventuras de Christine S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127148.mp4', 'http://timg.bdta.pro/images/45863516b357114efd6cee22e4e1e008.jpg'),
(37179, 2569, 'As Novas Aventuras de Christine S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127149.mp4', 'http://timg.bdta.pro/images/1605eff1537203b558fddb24c8ef69f6.jpg'),
(37180, 2569, 'As Novas Aventuras de Christine S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127150.mp4', 'http://timg.bdta.pro/images/63b25fcffabf274bb170040e4a703ce5.jpg'),
(37181, 2569, 'As Novas Aventuras de Christine S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127151.mp4', 'http://timg.bdta.pro/images/afe3a661ada0aa2086bdbbd7ded89f41.jpg'),
(37182, 2569, 'As Novas Aventuras de Christine S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127152.mp4', 'http://timg.bdta.pro/images/a9cdeec0c19b27f39c3df81127311821.jpg'),
(37183, 2569, 'As Novas Aventuras de Christine S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127153.mp4', 'http://timg.bdta.pro/images/d2398e2cba3710639f617f7b64b05ba7.jpg'),
(37184, 2569, 'As Novas Aventuras de Christine S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127154.mp4', 'http://timg.bdta.pro/images/c33d0fbb516e040119ee826b76af3242.jpg'),
(37185, 2569, 'As Novas Aventuras de Christine S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127155.mp4', 'http://timg.bdta.pro/images/21d24c315e036dfd46eeaffcaafb313d.jpg'),
(37186, 2570, 'As Novas Aventuras de Christine S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127156.mp4', 'http://timg.bdta.pro/images/86c8144614c67bbbcf18ac49f9d19722.jpg'),
(37187, 2570, 'As Novas Aventuras de Christine S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127157.mp4', 'http://timg.bdta.pro/images/bdcbb26c9f924108140e02d8d5640cdf.jpg'),
(37188, 2570, 'As Novas Aventuras de Christine S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127158.mp4', 'http://timg.bdta.pro/images/f8983eb393d6a74008a36b3b5c352e57.jpg'),
(37189, 2570, 'As Novas Aventuras de Christine S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127159.mp4', 'http://timg.bdta.pro/images/08032f275e0cb70d486622d4c818aa6b.jpg'),
(37190, 2570, 'As Novas Aventuras de Christine S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127160.mp4', 'http://timg.bdta.pro/images/f9c4cc73a56a3de366dbd23e77b975c9.jpg'),
(37191, 2570, 'As Novas Aventuras de Christine S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127161.mp4', 'http://timg.bdta.pro/images/f03d25bf13de4d6949fd11977660d971.jpg'),
(37192, 2570, 'As Novas Aventuras de Christine S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127162.mp4', 'http://timg.bdta.pro/images/7262ec9b4b519b4cc1338f8edf1c6a86.jpg'),
(37193, 2570, 'As Novas Aventuras de Christine S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127163.mp4', 'http://timg.bdta.pro/images/049bfc801cd65d7e40e684014e2810c2.jpg'),
(37194, 2570, 'As Novas Aventuras de Christine S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127164.mp4', 'http://timg.bdta.pro/images/8eaa372cb899f8e027574a97b6777d15.jpg'),
(37195, 2570, 'As Novas Aventuras de Christine S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127165.mp4', 'http://timg.bdta.pro/images/c46ff711ab1c0f95842f36841dd086f6.jpg'),
(37196, 2570, 'As Novas Aventuras de Christine S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127166.mp4', 'http://timg.bdta.pro/images/8972027834f6656aed5c6e05453b6c7a.jpg'),
(37197, 2570, 'As Novas Aventuras de Christine S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127167.mp4', 'http://timg.bdta.pro/images/b3a844f63ed58842ab4de4f13eee5743.jpg'),
(37198, 2570, 'As Novas Aventuras de Christine S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127168.mp4', 'http://timg.bdta.pro/images/54a317295752a7a24e408c9f8c143a06.jpg'),
(37199, 2570, 'As Novas Aventuras de Christine S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127169.mp4', 'http://timg.bdta.pro/images/9e2ad11b82bacd790d394f75d9631423.jpg'),
(37200, 2570, 'As Novas Aventuras de Christine S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127170.mp4', 'http://timg.bdta.pro/images/fdcce135b745c4cf0aa7066467b557fe.jpg'),
(37201, 2570, 'As Novas Aventuras de Christine S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127171.mp4', 'http://timg.bdta.pro/images/3f72db422b8e68ca2d259fadc168ad56.jpg'),
(37202, 2570, 'As Novas Aventuras de Christine S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127172.mp4', 'http://timg.bdta.pro/images/9e972d50d67fae36c015f1315fb0237a.jpg'),
(37203, 2570, 'As Novas Aventuras de Christine S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127173.mp4', 'http://timg.bdta.pro/images/ec56c14af5b2bb1221312193d705e30f.jpg'),
(37204, 2570, 'As Novas Aventuras de Christine S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127174.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37205, 2570, 'As Novas Aventuras de Christine S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127175.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37206, 2570, 'As Novas Aventuras de Christine S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127176.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37207, 2570, 'As Novas Aventuras de Christine S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/127177.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37208, 2571, 'As Novas Aventuras de Christine S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127178.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37209, 2571, 'As Novas Aventuras de Christine S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127179.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37210, 2571, 'As Novas Aventuras de Christine S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127180.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37211, 2571, 'As Novas Aventuras de Christine S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127181.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37212, 2571, 'As Novas Aventuras de Christine S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127182.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37213, 2571, 'As Novas Aventuras de Christine S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127183.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37214, 2571, 'As Novas Aventuras de Christine S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127184.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37215, 2571, 'As Novas Aventuras de Christine S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127185.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37216, 2571, 'As Novas Aventuras de Christine S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127186.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37217, 2571, 'As Novas Aventuras de Christine S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127187.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37218, 2571, 'As Novas Aventuras de Christine S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/127188.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37219, 2571, 'As Novas Aventuras de Christine S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/127189.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37220, 2571, 'As Novas Aventuras de Christine S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/127190.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37221, 2571, 'As Novas Aventuras de Christine S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/127191.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37222, 2571, 'As Novas Aventuras de Christine S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/127192.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37223, 2571, 'As Novas Aventuras de Christine S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/127193.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37224, 2571, 'As Novas Aventuras de Christine S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/127194.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37225, 2571, 'As Novas Aventuras de Christine S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/127195.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37226, 2571, 'As Novas Aventuras de Christine S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/127196.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37227, 2571, 'As Novas Aventuras de Christine S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/127197.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37228, 2571, 'As Novas Aventuras de Christine S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/127198.mp4', 'http://timg.bdta.pro/images/94de67876679f039207fe4e75b64aa48.jpg'),
(37229, 2572, 'Borges S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127088.mp4', 'http://gstaticontent.com/images/A4ny080cAW789NvZrpmezCSer1K_big.jpg'),
(37230, 2572, 'Borges S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127089.mp4', 'http://gstaticontent.com/images/A4ny080cAW789NvZrpmezCSer1K_big.jpg'),
(37231, 2572, 'Borges S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127090.mp4', 'http://gstaticontent.com/images/A4ny080cAW789NvZrpmezCSer1K_big.jpg'),
(37232, 2572, 'Borges S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127091.mp4', 'http://gstaticontent.com/images/A4ny080cAW789NvZrpmezCSer1K_big.jpg'),
(37233, 2572, 'Borges S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/127092.mp4', 'http://gstaticontent.com/images/A4ny080cAW789NvZrpmezCSer1K_big.jpg'),
(37234, 2572, 'Borges S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/127093.mp4', 'http://gstaticontent.com/images/A4ny080cAW789NvZrpmezCSer1K_big.jpg'),
(37235, 2572, 'Borges S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/127094.mp4', 'http://gstaticontent.com/images/A4ny080cAW789NvZrpmezCSer1K_big.jpg'),
(37236, 2572, 'Borges S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/127095.mp4', 'http://gstaticontent.com/images/A4ny080cAW789NvZrpmezCSer1K_big.jpg'),
(37237, 2572, 'Borges S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/127096.mp4', 'http://gstaticontent.com/images/A4ny080cAW789NvZrpmezCSer1K_big.jpg'),
(37238, 2572, 'Borges S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/127097.mp4', 'http://gstaticontent.com/images/A4ny080cAW789NvZrpmezCSer1K_big.jpg'),
(37239, 2573, 'Uma Morte em Vermelho S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/127084.mp4', 'http://gstaticontent.com/images/xKfMOhklUhBhciznvi3BZMaHYR6_big.jpg'),
(37240, 2573, 'Uma Morte em Vermelho S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/127085.mp4', 'http://gstaticontent.com/images/xKfMOhklUhBhciznvi3BZMaHYR6_big.jpg'),
(37241, 2573, 'Uma Morte em Vermelho S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/127086.mp4', 'http://gstaticontent.com/images/xKfMOhklUhBhciznvi3BZMaHYR6_big.jpg'),
(37242, 2573, 'Uma Morte em Vermelho S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/127087.mp4', 'http://gstaticontent.com/images/xKfMOhklUhBhciznvi3BZMaHYR6_big.jpg'),
(37243, 2574, 'Yellowstone S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204380.mp4', 'http://timg.bdta.pro/images/b9e6c6ee6930ab67e26504f39a06e22a.jpg'),
(37244, 2574, 'Yellowstone S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204381.mp4', 'http://timg.bdta.pro/images/494b5a467ad716f2fb7741346b0555f9.jpg'),
(37245, 2574, 'Yellowstone S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204382.mp4', 'http://timg.bdta.pro/images/25d7da2d725c86fba210a5505874e1b2.jpg'),
(37246, 2574, 'Yellowstone S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204383.mp4', 'http://timg.bdta.pro/images/97fee4bacffc54bee0ca6b8e3097558e.jpg'),
(37247, 2574, 'Yellowstone S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204384.mp4', 'http://timg.bdta.pro/images/e5d89f0d667992a7fc4fbaba5421f541.jpg'),
(37248, 2574, 'Yellowstone S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204385.mp4', 'http://timg.bdta.pro/images/4494181cf3d274e0fd6f0a022fd68bfc.jpg'),
(37249, 2574, 'Yellowstone S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204386.mp4', 'http://timg.bdta.pro/images/1b38828c955b5b903c6333132ac3f37e.jpg'),
(37250, 2574, 'Yellowstone S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204387.mp4', 'http://timg.bdta.pro/images/7bf88dff522e50b1d77a9fd1846e651b.jpg'),
(37251, 2574, 'Yellowstone S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204388.mp4', 'http://timg.bdta.pro/images/29233f30814e42bd9848d2572d0bf5f2.jpg'),
(37252, 2575, 'Yellowstone S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204389.mp4', 'http://timg.bdta.pro/images/8645e120da869b67ecd485c3cd97d9a9.jpg'),
(37253, 2575, 'Yellowstone S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204390.mp4', 'http://timg.bdta.pro/images/d533be6ec5ffa8d67a809f59d5aab4a8.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(37254, 2575, 'Yellowstone S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204391.mp4', 'http://timg.bdta.pro/images/d2d78842c2ff976071bf4833319d3b69.jpg'),
(37255, 2575, 'Yellowstone S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204392.mp4', 'http://timg.bdta.pro/images/55ea63af2b3884ffd6cc8b6746c4107b.jpg'),
(37256, 2575, 'Yellowstone S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204393.mp4', 'http://timg.bdta.pro/images/95bd10380b5df2f963720fdae2ecedc8.jpg'),
(37257, 2575, 'Yellowstone S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204394.mp4', 'http://timg.bdta.pro/images/378c4633b6d2ed65c285301b103350ee.jpg'),
(37258, 2575, 'Yellowstone S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204395.mp4', 'http://timg.bdta.pro/images/c1d8d0356f58be328658121f01627eca.jpg'),
(37259, 2575, 'Yellowstone S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204396.mp4', 'http://timg.bdta.pro/images/46da5890918cceca78498c0c347fb5b3.jpg'),
(37260, 2575, 'Yellowstone S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204397.mp4', 'http://timg.bdta.pro/images/1691c8a0b943c8e2bd9fb7ff8f224341.jpg'),
(37261, 2575, 'Yellowstone S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204398.mp4', 'http://timg.bdta.pro/images/1acfc010ffd625869fd70b6a86940051.jpg'),
(37262, 2576, 'Yellowstone S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37263, 2576, 'Yellowstone S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37264, 2576, 'Yellowstone S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37265, 2576, 'Yellowstone S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37266, 2576, 'Yellowstone S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37267, 2576, 'Yellowstone S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37268, 2576, 'Yellowstone S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37269, 2576, 'Yellowstone S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37270, 2576, 'Yellowstone S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37271, 2576, 'Yellowstone S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37272, 2577, 'Yellowstone S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37273, 2577, 'Yellowstone S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37274, 2577, 'Yellowstone S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37275, 2577, 'Yellowstone S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37276, 2577, 'Yellowstone S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37277, 2577, 'Yellowstone S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37278, 2577, 'Yellowstone S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37279, 2577, 'Yellowstone S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37280, 2577, 'Yellowstone S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37281, 2577, 'Yellowstone S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37282, 2578, 'Yellowstone S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204419.mp4', 'http://image.tmdb.org/t/p/w1280/pLHvzY7Q7TFDtvvRuEu6I80m410.jpg'),
(37283, 2578, 'Yellowstone S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204420.mp4', 'http://image.tmdb.org/t/p/w1280/gAVvcD1NbX2iZJHHYWQNAF9Gucb.jpg'),
(37284, 2578, 'Yellowstone S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/VAQmK1Fr6NKkPwLSsWkCzDsEeS.jpg'),
(37285, 2578, 'Yellowstone S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xrda67clIjyw4ERpy72uZ9DmVm0.jpg'),
(37286, 2578, 'Yellowstone S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204423.mp4', 'http://image.tmdb.org/t/p/w1280/odbPcT8N6dE4lBAGfBe0LS99b6K.jpg'),
(37287, 2578, 'Yellowstone S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204424.mp4', 'http://image.tmdb.org/t/p/w1280/pQcc293HZgojsbMPPKG4AytXRAX.jpg'),
(37288, 2578, 'Yellowstone S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204425.mp4', 'http://image.tmdb.org/t/p/w1280/l8JNrPjb6DztDGS9LHSdLPPx5zA.jpg'),
(37289, 2578, 'Yellowstone S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204426.mp4', 'http://image.tmdb.org/t/p/w1280/7qj1VJD1TzUQLk4dAptq3Lqtsoi.jpg'),
(37290, 2578, 'Yellowstone S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37291, 2578, 'Yellowstone S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/506966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37292, 2578, 'Yellowstone S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/510946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37293, 2578, 'Yellowstone S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/513431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37294, 2578, 'Yellowstone S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/638728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37295, 2578, 'Yellowstone S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/638729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/peNC0eyc3TQJa6x4TdKcBPNP4t0.jpg'),
(37296, 2579, 'Verônica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190331.mp4', 'http://timg.bdta.pro/images/7a4f117feb1d92e8e5622a43d5a96f49.jpg'),
(37297, 2579, 'Verônica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190332.mp4', 'http://timg.bdta.pro/images/662dd86ae966edac36c0e7e6729a66d4.jpg'),
(37298, 2579, 'Verônica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190333.mp4', 'http://timg.bdta.pro/images/e9f7b4f5adf026cbe24c92e0498c02e2.jpg'),
(37299, 2579, 'Verônica S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190334.mp4', 'http://timg.bdta.pro/images/25e67dc212fc8746be86affff04b3f6b.jpg'),
(37300, 2579, 'Verônica S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190335.mp4', 'http://timg.bdta.pro/images/d84213390b38e3cd835fbb7fc964e0f6.jpg'),
(37301, 2579, 'Verônica S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190336.mp4', 'http://timg.bdta.pro/images/18a2906b606a273e4dc904cc710b60fd.jpg'),
(37302, 2579, 'Verônica S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190337.mp4', 'http://timg.bdta.pro/images/9a5dd71e4323df6847a436d8b2abc59a.jpg'),
(37303, 2579, 'Verônica S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190338.mp4', 'http://timg.bdta.pro/images/9fcb2ae22d8272738431499e849ed895.jpg'),
(37304, 2580, 'Verônica S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190339.mp4', 'http://timg.bdta.pro/images/015f2ff187895970ae34460161853dde.jpg'),
(37305, 2580, 'Verônica S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190340.mp4', 'http://timg.bdta.pro/images/6b46de9c471431a482fee2c2f9a126a7.jpg'),
(37306, 2580, 'Verônica S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190341.mp4', 'http://timg.bdta.pro/images/a8cc3880f0a9705b14151807bfcb45fa.jpg'),
(37307, 2580, 'Verônica S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190342.mp4', 'http://timg.bdta.pro/images/4a25980e5edc93014fae825b32151fd1.jpg'),
(37308, 2580, 'Verônica S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190343.mp4', 'http://timg.bdta.pro/images/7da503786da7eeef189376ffadfed108.jpg'),
(37309, 2580, 'Verônica S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190344.mp4', 'http://timg.bdta.pro/images/3f040f18926a112fa7f2f548f08a8e22.jpg'),
(37310, 2581, 'Verônica S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274804.mp4', 'http://gstaticontent.com/images/kbyZ84DuLJGgxdMnC7bjHlcjJ3e_big.jpg'),
(37311, 2581, 'Verônica S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274805.mp4', 'http://gstaticontent.com/images/kbyZ84DuLJGgxdMnC7bjHlcjJ3e_big.jpg'),
(37312, 2581, 'Verônica S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274806.mp4', 'http://gstaticontent.com/images/kbyZ84DuLJGgxdMnC7bjHlcjJ3e_big.jpg'),
(37313, 2582, 'A Bênção S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126976.mp4', 'http://gstaticontent.com/images/mqBYQdi8Dx2h9XqCl62gbrDs3oy_big.jpg'),
(37314, 2582, 'A Bênção S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126977.mp4', 'http://gstaticontent.com/images/mqBYQdi8Dx2h9XqCl62gbrDs3oy_big.jpg'),
(37315, 2582, 'A Bênção S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126978.mp4', 'http://gstaticontent.com/images/mqBYQdi8Dx2h9XqCl62gbrDs3oy_big.jpg'),
(37316, 2582, 'A Bênção S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126979.mp4', 'http://gstaticontent.com/images/mqBYQdi8Dx2h9XqCl62gbrDs3oy_big.jpg'),
(37317, 2582, 'A Bênção S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126980.mp4', 'http://gstaticontent.com/images/mqBYQdi8Dx2h9XqCl62gbrDs3oy_big.jpg'),
(37318, 2582, 'A Bênção S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126981.mp4', 'http://gstaticontent.com/images/mqBYQdi8Dx2h9XqCl62gbrDs3oy_big.jpg'),
(37319, 2582, 'A Bênção S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126982.mp4', 'http://gstaticontent.com/images/mqBYQdi8Dx2h9XqCl62gbrDs3oy_big.jpg'),
(37320, 2582, 'A Bênção S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126983.mp4', 'http://gstaticontent.com/images/mqBYQdi8Dx2h9XqCl62gbrDs3oy_big.jpg'),
(37321, 2583, 'A Morte do Patriarca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126968.mp4', 'http://timg.bdta.pro/images/8433c653d6211621261edbb609327905.jpg'),
(37322, 2583, 'A Morte do Patriarca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126969.mp4', 'http://timg.bdta.pro/images/304fb1661af3ce158dd5cfb22e6877e7.jpg'),
(37323, 2583, 'A Morte do Patriarca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126970.mp4', 'http://timg.bdta.pro/images/56308d849c9650568c20cd3b2bded525.jpg'),
(37324, 2583, 'A Morte do Patriarca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126971.mp4', 'http://timg.bdta.pro/images/40aa5b53daf5fc706c6086c17bf4260e.jpg'),
(37325, 2583, 'A Morte do Patriarca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126972.mp4', 'http://timg.bdta.pro/images/7252d01dd348d7b09a04307071043c2e.jpg'),
(37326, 2583, 'A Morte do Patriarca S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126973.mp4', 'http://timg.bdta.pro/images/b744a0741be25a0a9840f6d079857b09.jpg'),
(37327, 2583, 'A Morte do Patriarca S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126974.mp4', 'http://timg.bdta.pro/images/6c859736822c3ac679d13d1624097688.jpg'),
(37328, 2583, 'A Morte do Patriarca S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126975.mp4', 'http://timg.bdta.pro/images/c1934fbe0b2b31ecb1b6e2c4d409642a.jpg'),
(37329, 2584, 'Animal Kingdom S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219267.mp4', 'http://timg.bdta.pro/images/5cfec4886ee56d6fe3829a1b8351babe.jpg'),
(37330, 2584, 'Animal Kingdom S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219268.mp4', 'http://timg.bdta.pro/images/e0ed66d78ad61513257e88f5a5ac2ddd.jpg'),
(37331, 2584, 'Animal Kingdom S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219269.mp4', 'http://timg.bdta.pro/images/b8ad8547d41fe0fbde86986b15556503.jpg'),
(37332, 2584, 'Animal Kingdom S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219270.mp4', 'http://timg.bdta.pro/images/1de8cd80e002a61abac89351d69688e9.jpg'),
(37333, 2584, 'Animal Kingdom S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219271.mp4', 'http://timg.bdta.pro/images/160d2b63936ba39ce616fa046c3b82dd.jpg'),
(37334, 2584, 'Animal Kingdom S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219272.mp4', 'http://timg.bdta.pro/images/925f1e0f45c430ec3eb671104d95501c.jpg'),
(37335, 2584, 'Animal Kingdom S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219273.mp4', 'http://timg.bdta.pro/images/4a3247c342007aac78ff01e8e56c8fe7.jpg'),
(37336, 2584, 'Animal Kingdom S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219274.mp4', 'http://timg.bdta.pro/images/0a3480b3ca4ad6cd04b41eb8fdaca2c6.jpg'),
(37337, 2584, 'Animal Kingdom S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219275.mp4', 'http://timg.bdta.pro/images/9a026bc76aae5ea1b4e6c0deba13b94a.jpg'),
(37338, 2584, 'Animal Kingdom S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219276.mp4', 'http://timg.bdta.pro/images/34d928ccb3cbfee24e4ce26a69e6fd29.jpg'),
(37339, 2585, 'Animal Kingdom S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219277.mp4', 'http://timg.bdta.pro/images/1038e1f31de78c7476375865d8114690.jpg'),
(37340, 2585, 'Animal Kingdom S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219278.mp4', 'http://timg.bdta.pro/images/1179b12fb8cd956418b9a55732b57b1f.jpg'),
(37341, 2585, 'Animal Kingdom S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219279.mp4', 'http://timg.bdta.pro/images/a865defb2242c06d5c8b07968dec4dc9.jpg'),
(37342, 2585, 'Animal Kingdom S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219280.mp4', 'http://timg.bdta.pro/images/7afa9862c1168b536cd172ba49b58389.jpg'),
(37343, 2585, 'Animal Kingdom S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219281.mp4', 'http://timg.bdta.pro/images/776436aeb931764647948a09e5fd5b59.jpg'),
(37344, 2585, 'Animal Kingdom S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219282.mp4', 'http://timg.bdta.pro/images/389b3ec558ff1f0d39e4c09cce93098b.jpg'),
(37345, 2585, 'Animal Kingdom S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219283.mp4', 'http://timg.bdta.pro/images/92ae6c3ccda659a9ada50847ad28dd99.jpg'),
(37346, 2585, 'Animal Kingdom S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219284.mp4', 'http://timg.bdta.pro/images/155c92d99d6a2e0abfe24977d1e2ab8a.jpg'),
(37347, 2585, 'Animal Kingdom S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219285.mp4', 'http://timg.bdta.pro/images/3fe13c415b02515de364c928e3353fad.jpg'),
(37348, 2585, 'Animal Kingdom S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219286.mp4', 'http://timg.bdta.pro/images/d296d515d066f94632dd0e06f60dac36.jpg'),
(37349, 2585, 'Animal Kingdom S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219287.mp4', 'http://timg.bdta.pro/images/c7635adb04aeb3c0a1357cf3585ce1ab.jpg'),
(37350, 2585, 'Animal Kingdom S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219288.mp4', 'http://timg.bdta.pro/images/b6427cb103130227f5323e3aded915e6.jpg'),
(37351, 2585, 'Animal Kingdom S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219289.mp4', 'http://timg.bdta.pro/images/e2c06b52a1418e4edd83bdaab0115415.jpg'),
(37352, 2586, 'Animal Kingdom S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219290.mp4', 'http://timg.bdta.pro/images/6508484f8523dd6c90dcb439e9e3ef70.jpg'),
(37353, 2586, 'Animal Kingdom S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219291.mp4', 'http://timg.bdta.pro/images/7e461d5eae7a7dfa2515709933f3341a.jpg'),
(37354, 2586, 'Animal Kingdom S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219292.mp4', 'http://timg.bdta.pro/images/dc8b212e898fe3daa43a772e65bf552a.jpg'),
(37355, 2586, 'Animal Kingdom S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219293.mp4', 'http://timg.bdta.pro/images/b4cdb86d894ff3b4d41d9f0dd950d8f4.jpg'),
(37356, 2586, 'Animal Kingdom S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219294.mp4', 'http://timg.bdta.pro/images/bbd0b62ca086b9f1c6a377f7b593aa15.jpg'),
(37357, 2586, 'Animal Kingdom S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219295.mp4', 'http://timg.bdta.pro/images/5253e7de58ae75daf76df7ed13e44c30.jpg'),
(37358, 2586, 'Animal Kingdom S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219296.mp4', 'http://timg.bdta.pro/images/dc9f2ec71b13101f000b445b73f6f59d.jpg'),
(37359, 2586, 'Animal Kingdom S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219297.mp4', 'http://timg.bdta.pro/images/6dbacfd5e77139002d45ca6f703dcd87.jpg'),
(37360, 2586, 'Animal Kingdom S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219298.mp4', 'http://timg.bdta.pro/images/803ec7156b1ef3aec56ffe62c751e6b1.jpg'),
(37361, 2586, 'Animal Kingdom S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219299.mp4', 'http://timg.bdta.pro/images/d3c25a4b1f9711fb8c2e3f8af9708f1e.jpg'),
(37362, 2586, 'Animal Kingdom S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219300.mp4', 'http://timg.bdta.pro/images/c190938763eeb475b838baaa3ba6a079.jpg'),
(37363, 2586, 'Animal Kingdom S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219301.mp4', 'http://timg.bdta.pro/images/fcc421cb27fab85d105127e4d014f43a.jpg'),
(37364, 2586, 'Animal Kingdom S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219302.mp4', 'http://timg.bdta.pro/images/3af6f04ef6ccd4b1fb85762673a1a8bd.jpg'),
(37365, 2587, 'Animal Kingdom S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219303.mp4', 'http://gstaticontent.com/images/tpnHrx2UuBF0lQiZsGP40t4P9ml_big.jpg'),
(37366, 2587, 'Animal Kingdom S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219304.mp4', 'http://gstaticontent.com/images/tpnHrx2UuBF0lQiZsGP40t4P9ml_big.jpg'),
(37367, 2587, 'Animal Kingdom S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219305.mp4', 'http://gstaticontent.com/images/tpnHrx2UuBF0lQiZsGP40t4P9ml_big.jpg'),
(37368, 2587, 'Animal Kingdom S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219306.mp4', 'http://gstaticontent.com/images/tpnHrx2UuBF0lQiZsGP40t4P9ml_big.jpg'),
(37369, 2587, 'Animal Kingdom S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219307.mp4', 'http://gstaticontent.com/images/tpnHrx2UuBF0lQiZsGP40t4P9ml_big.jpg'),
(37370, 2587, 'Animal Kingdom S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219308.mp4', 'http://gstaticontent.com/images/tpnHrx2UuBF0lQiZsGP40t4P9ml_big.jpg'),
(37371, 2587, 'Animal Kingdom S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219309.mp4', 'http://gstaticontent.com/images/tpnHrx2UuBF0lQiZsGP40t4P9ml_big.jpg'),
(37372, 2587, 'Animal Kingdom S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219310.mp4', 'http://gstaticontent.com/images/tpnHrx2UuBF0lQiZsGP40t4P9ml_big.jpg'),
(37373, 2587, 'Animal Kingdom S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219311.mp4', 'http://gstaticontent.com/images/tpnHrx2UuBF0lQiZsGP40t4P9ml_big.jpg'),
(37374, 2587, 'Animal Kingdom S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219312.mp4', 'http://gstaticontent.com/images/tpnHrx2UuBF0lQiZsGP40t4P9ml_big.jpg'),
(37375, 2587, 'Animal Kingdom S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219313.mp4', 'http://gstaticontent.com/images/tpnHrx2UuBF0lQiZsGP40t4P9ml_big.jpg'),
(37376, 2587, 'Animal Kingdom S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219314.mp4', 'http://gstaticontent.com/images/tpnHrx2UuBF0lQiZsGP40t4P9ml_big.jpg'),
(37377, 2587, 'Animal Kingdom S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219315.mp4', 'http://gstaticontent.com/images/tpnHrx2UuBF0lQiZsGP40t4P9ml_big.jpg'),
(37378, 2588, 'Animal Kingdom S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219316.mp4', 'http://timg.bdta.pro/images/8301a491788da03e31b7ea8a7e4d948e.jpg'),
(37379, 2588, 'Animal Kingdom S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219317.mp4', 'http://timg.bdta.pro/images/dba349ac50f6186cb817470e739facf0.jpg'),
(37380, 2588, 'Animal Kingdom S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219318.mp4', 'http://timg.bdta.pro/images/af6f3c28c92fcc29143687cd10a2ab29.jpg'),
(37381, 2588, 'Animal Kingdom S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219319.mp4', 'http://timg.bdta.pro/images/0cefe103bd89454fb1fd30eb79b08920.jpg'),
(37382, 2588, 'Animal Kingdom S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219320.mp4', 'http://timg.bdta.pro/images/5b2127fe210f473b0a7b67528d5ad567.jpg'),
(37383, 2588, 'Animal Kingdom S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219321.mp4', 'http://timg.bdta.pro/images/e495d9978485da778ade3b49014dcc8b.jpg'),
(37384, 2588, 'Animal Kingdom S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219322.mp4', 'http://timg.bdta.pro/images/39cea8cfb6dbada8c8dfc1645d032c03.jpg'),
(37385, 2588, 'Animal Kingdom S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219323.mp4', 'http://timg.bdta.pro/images/36a2d142ec790457984d4ef91d470f75.jpg'),
(37386, 2588, 'Animal Kingdom S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219324.mp4', 'http://timg.bdta.pro/images/1a3027e48a5867eee9771ee6d4f44250.jpg'),
(37387, 2588, 'Animal Kingdom S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219325.mp4', 'http://timg.bdta.pro/images/d897bdbd63d96bc1a3e66147ae39d643.jpg'),
(37388, 2588, 'Animal Kingdom S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219326.mp4', 'http://timg.bdta.pro/images/ae868ac86ed6ff60b5fc194cb36f9a7a.jpg'),
(37389, 2588, 'Animal Kingdom S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219327.mp4', 'http://timg.bdta.pro/images/e3859f0075996c4b3509cbeff0b0b122.jpg'),
(37390, 2588, 'Animal Kingdom S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219328.mp4', 'http://timg.bdta.pro/images/0cd90952f7edfa0f46be310b3dc0d26e.jpg'),
(37391, 2589, 'Animal Kingdom S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219329.mp4', 'http://timg.bdta.pro/images/ed9b4b6302ac9ffbe5cd4b6c09593319.jpg'),
(37392, 2589, 'Animal Kingdom S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219330.mp4', 'http://timg.bdta.pro/images/00a54ec97b82b11c11deea1a55fe4c00.jpg'),
(37393, 2589, 'Animal Kingdom S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219331.mp4', 'http://timg.bdta.pro/images/3d3a228059544a33de9ff65ab8b4edd8.jpg'),
(37394, 2589, 'Animal Kingdom S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219332.mp4', 'http://timg.bdta.pro/images/78307d24e9fe4fd09e4b5d89a060b5b9.jpg'),
(37395, 2589, 'Animal Kingdom S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219333.mp4', 'http://timg.bdta.pro/images/2dd0563d9ab276d88f188f9e62ae20c7.jpg'),
(37396, 2589, 'Animal Kingdom S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219334.mp4', 'http://timg.bdta.pro/images/f23e8c27c8a00a64591d8ac8bfc98008.jpg'),
(37397, 2589, 'Animal Kingdom S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219335.mp4', 'http://timg.bdta.pro/images/ab660709c537f5eeccabeda536124624.jpg'),
(37398, 2589, 'Animal Kingdom S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219336.mp4', 'http://timg.bdta.pro/images/3d2a5c8bc46dc396c68e1f9bf3ee24f7.jpg'),
(37399, 2589, 'Animal Kingdom S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f8tBGwbTwhT9sPbnjfYMZTiZqYS.jpg'),
(37400, 2589, 'Animal Kingdom S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xtS0XZPMumCRyR238osmqH0Vet5.jpg'),
(37401, 2589, 'Animal Kingdom S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3zXJkqg90RvPVQsJPLFtXRFKFfZ.jpg'),
(37402, 2589, 'Animal Kingdom S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tN4aeYrtVGfMNIE9JqCa06cxzo2.jpg'),
(37403, 2589, 'Animal Kingdom S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aX7KS5NAferBAi4LFdxCseUQ8IH.jpg'),
(37404, 2590, 'Carmen Sandiego S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136405.mp4', 'http://timg.bdta.pro/images/3509dc9152fc30ed0ab9af05d5053271.jpg'),
(37405, 2590, 'Carmen Sandiego S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136406.mp4', 'http://timg.bdta.pro/images/7906b46a807151c01b4988610e6358d4.jpg'),
(37406, 2590, 'Carmen Sandiego S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136407.mp4', 'http://timg.bdta.pro/images/8b139390a0caf170dd4bfc5370e416d1.jpg'),
(37407, 2590, 'Carmen Sandiego S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136408.mp4', 'http://timg.bdta.pro/images/576595531e34fffcf553f08c8835e0c6.jpg'),
(37408, 2590, 'Carmen Sandiego S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136409.mp4', 'http://timg.bdta.pro/images/e9bb586a86c06c9aa2373dd5ae321ba8.jpg'),
(37409, 2590, 'Carmen Sandiego S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136410.mp4', 'http://timg.bdta.pro/images/790963d5bb11daabeeb7994bc5d8654d.jpg'),
(37410, 2590, 'Carmen Sandiego S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136411.mp4', 'http://timg.bdta.pro/images/2a6ea0068b45f38d4bbfa2182201aafb.jpg'),
(37411, 2590, 'Carmen Sandiego S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136412.mp4', 'http://timg.bdta.pro/images/192d7935a2a17512f6ba0004bf7026b2.jpg'),
(37412, 2590, 'Carmen Sandiego S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136413.mp4', 'http://timg.bdta.pro/images/c97e14d380111e43e29a1b040c79caaf.jpg'),
(37413, 2591, 'Carmen Sandiego S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136414.mp4', 'http://timg.bdta.pro/images/4f076461dfd1df0c725c1c2b2617cbaa.jpg'),
(37414, 2591, 'Carmen Sandiego S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136415.mp4', 'http://timg.bdta.pro/images/13210bb18134e8bcee7b973d625908a6.jpg'),
(37415, 2591, 'Carmen Sandiego S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136416.mp4', 'http://timg.bdta.pro/images/0f02ba40dd9d2824c26ff6c288070049.jpg'),
(37416, 2591, 'Carmen Sandiego S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136417.mp4', 'http://timg.bdta.pro/images/b1439869368f7ef75b6ce058e44888a4.jpg'),
(37417, 2591, 'Carmen Sandiego S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136418.mp4', 'http://timg.bdta.pro/images/b980f675bc48b066a6a6b85291f508d7.jpg'),
(37418, 2591, 'Carmen Sandiego S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136419.mp4', 'http://timg.bdta.pro/images/5aac34e53d0396b98779fabe28e34ab2.jpg'),
(37419, 2591, 'Carmen Sandiego S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136420.mp4', 'http://timg.bdta.pro/images/333c2aa510c7fc3a38a6448c9361e89a.jpg'),
(37420, 2591, 'Carmen Sandiego S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136421.mp4', 'http://timg.bdta.pro/images/8a0793440e5b34b8a5e55ce58a8147e7.jpg'),
(37421, 2591, 'Carmen Sandiego S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136422.mp4', 'http://timg.bdta.pro/images/02b447a287a3248e6e528b489f0d0a16.jpg'),
(37422, 2591, 'Carmen Sandiego S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136423.mp4', 'http://timg.bdta.pro/images/22085e3b7d8d328e38692bc2d453b0dd.jpg'),
(37423, 2592, 'Carmen Sandiego S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136424.mp4', 'http://timg.bdta.pro/images/b79b5c3447db8c88da3c8d153f2a2274.jpg'),
(37424, 2592, 'Carmen Sandiego S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136425.mp4', 'http://timg.bdta.pro/images/5bf097a764c242252b284245dbff758f.jpg'),
(37425, 2592, 'Carmen Sandiego S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136426.mp4', 'http://timg.bdta.pro/images/12072ceda704e3b2480718664fa512db.jpg'),
(37426, 2592, 'Carmen Sandiego S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136427.mp4', 'http://timg.bdta.pro/images/b04a8974d37366ab9be8567c2583c257.jpg'),
(37427, 2592, 'Carmen Sandiego S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136428.mp4', 'http://timg.bdta.pro/images/c36856ceffca99f3d56251f611e626c4.jpg'),
(37428, 2593, 'Carmen Sandiego S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136429.mp4', 'http://gstaticontent.com/images/lGSOOzYtg3fqdzjlXKwPa0vH9mp_big.jpg'),
(37429, 2593, 'Carmen Sandiego S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136430.mp4', 'http://gstaticontent.com/images/lGSOOzYtg3fqdzjlXKwPa0vH9mp_big.jpg'),
(37430, 2593, 'Carmen Sandiego S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136431.mp4', 'http://gstaticontent.com/images/lGSOOzYtg3fqdzjlXKwPa0vH9mp_big.jpg'),
(37431, 2593, 'Carmen Sandiego S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136432.mp4', 'http://gstaticontent.com/images/lGSOOzYtg3fqdzjlXKwPa0vH9mp_big.jpg'),
(37432, 2593, 'Carmen Sandiego S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136433.mp4', 'http://gstaticontent.com/images/lGSOOzYtg3fqdzjlXKwPa0vH9mp_big.jpg'),
(37433, 2593, 'Carmen Sandiego S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136434.mp4', 'http://gstaticontent.com/images/lGSOOzYtg3fqdzjlXKwPa0vH9mp_big.jpg'),
(37434, 2593, 'Carmen Sandiego S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136435.mp4', 'http://gstaticontent.com/images/lGSOOzYtg3fqdzjlXKwPa0vH9mp_big.jpg'),
(37435, 2593, 'Carmen Sandiego S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136436.mp4', 'http://gstaticontent.com/images/lGSOOzYtg3fqdzjlXKwPa0vH9mp_big.jpg'),
(37436, 2594, 'Devils S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233309.mp4', 'http://timg.bdta.pro/images/b40848baf513f7af8575ac8c2954fa5d.jpg'),
(37437, 2594, 'Devils S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233310.mp4', 'http://timg.bdta.pro/images/676e50185d8deef7ba33125b91ab4a3f.jpg'),
(37438, 2594, 'Devils S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233311.mp4', 'http://timg.bdta.pro/images/9f9eec850d224dc4230b06be3a45e3bd.jpg'),
(37439, 2594, 'Devils S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233312.mp4', 'http://timg.bdta.pro/images/bdebc754c84f2e0c6b53aa829ea13408.jpg'),
(37440, 2594, 'Devils S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/SfRduSBZvcwoWrNp8DGpgW3MRv.jpg'),
(37441, 2594, 'Devils S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uwWGqNxguAluVjpnwvfjXuksIg7.jpg'),
(37442, 2594, 'Devils S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233315.mp4', 'http://gstaticontent.com/images/l4Pl7APWpRANULCirWTrcMPfdIl_big.jpg'),
(37443, 2594, 'Devils S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233316.mp4', 'http://gstaticontent.com/images/l4Pl7APWpRANULCirWTrcMPfdIl_big.jpg'),
(37444, 2594, 'Devils S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233317.mp4', 'http://gstaticontent.com/images/l4Pl7APWpRANULCirWTrcMPfdIl_big.jpg'),
(37445, 2594, 'Devils S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233318.mp4', 'http://gstaticontent.com/images/l4Pl7APWpRANULCirWTrcMPfdIl_big.jpg'),
(37446, 2595, 'Devils S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233319.mp4', 'http://image.tmdb.org/t/p/w1280/kaerjP0n90vxkIR49ZWGvoDfTsz.jpg'),
(37447, 2595, 'Devils S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233320.mp4', 'http://image.tmdb.org/t/p/w1280/tMyszBXVVsNgzVU1ejOTylloQTM.jpg'),
(37448, 2595, 'Devils S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233321.mp4', 'http://image.tmdb.org/t/p/w1280/tSH6TwOZ5F7eJAs2IbIPo5HGDOo.jpg'),
(37449, 2595, 'Devils S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233322.mp4', 'http://image.tmdb.org/t/p/w1280/pFKEpAEpcEZqe9PlgIN9muwTlZP.jpg'),
(37450, 2595, 'Devils S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233323.mp4', 'http://image.tmdb.org/t/p/w1280/gTCemnba0pTQm86BCWnhONUQSSG.jpg'),
(37451, 2595, 'Devils S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233324.mp4', 'http://image.tmdb.org/t/p/w1280/5SATwerPVLYWWH1ez31u01GaH4n.jpg'),
(37452, 2595, 'Devils S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233325.mp4', 'http://image.tmdb.org/t/p/w1280/fR4JdRTMOOo45uo3w3wDMIG2CMq.jpg'),
(37453, 2595, 'Devils S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233326.mp4', 'http://image.tmdb.org/t/p/w1280/kLFtTxfvGHBrk20XFHs2KsEBAZG.jpg'),
(37454, 2596, 'El Chapo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126934.mp4', 'http://timg.bdta.pro/images/63bd5eec7371826b8f7f31a38d06b0f5.jpg'),
(37455, 2596, 'El Chapo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126935.mp4', 'http://timg.bdta.pro/images/c004c47e2459c8e200e9b5a4135ed3eb.jpg'),
(37456, 2596, 'El Chapo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126936.mp4', 'http://timg.bdta.pro/images/1d1cc7de197e1819b58d608dff418251.jpg'),
(37457, 2596, 'El Chapo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126937.mp4', 'http://timg.bdta.pro/images/c246972361830d12ac290b9a896bc83d.jpg'),
(37458, 2596, 'El Chapo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126938.mp4', 'http://timg.bdta.pro/images/4cce98c3ca6537037336c559b05dc6df.jpg'),
(37459, 2596, 'El Chapo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126939.mp4', 'http://timg.bdta.pro/images/3325b826c4f4a823ac6737c510dfda24.jpg'),
(37460, 2596, 'El Chapo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126940.mp4', 'http://timg.bdta.pro/images/67d1352f5f5b9194d0d73afdba4702dc.jpg'),
(37461, 2596, 'El Chapo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126941.mp4', 'http://timg.bdta.pro/images/4f0152099bbccb16638e7d08f72094b8.jpg'),
(37462, 2596, 'El Chapo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126942.mp4', 'http://gstaticontent.com/images/4yCyZ03Zc0LrJnl27q6vlhKc9iy_big.jpg'),
(37463, 2597, 'El Chapo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126943.mp4', 'http://timg.bdta.pro/images/ad56f79ca2ce4c87cebcbe73eb055fd5.jpg'),
(37464, 2597, 'El Chapo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126944.mp4', 'http://timg.bdta.pro/images/1ad9e5d5017274b129de5f8ce36b8321.jpg'),
(37465, 2597, 'El Chapo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126945.mp4', 'http://timg.bdta.pro/images/9cabfcc0882dd06c8aa19e8f4612b75c.jpg'),
(37466, 2597, 'El Chapo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126946.mp4', 'http://timg.bdta.pro/images/cc3964e9cda640d07b0535dabc26eb06.jpg'),
(37467, 2597, 'El Chapo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126947.mp4', 'http://timg.bdta.pro/images/570e6575dfb773d99ed1188136e0d69d.jpg'),
(37468, 2597, 'El Chapo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126948.mp4', 'http://timg.bdta.pro/images/98c07a379331bebdc74780852308018b.jpg'),
(37469, 2597, 'El Chapo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126949.mp4', 'http://timg.bdta.pro/images/d963e1b452cfc949f231c1a528519e05.jpg'),
(37470, 2597, 'El Chapo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126950.mp4', 'http://timg.bdta.pro/images/1453574af78941093d9655607d45af79.jpg'),
(37471, 2597, 'El Chapo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126951.mp4', 'http://timg.bdta.pro/images/c48597544bac88a07259b3c04e73d704.jpg'),
(37472, 2597, 'El Chapo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126952.mp4', 'http://timg.bdta.pro/images/bd54edf5fc681637f6258366d43b2249.jpg'),
(37473, 2597, 'El Chapo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/126953.mp4', 'http://timg.bdta.pro/images/a47e3138ee2534e5f45ffa00c55f634b.jpg'),
(37474, 2597, 'El Chapo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/126954.mp4', 'http://timg.bdta.pro/images/a0def7afe9de7dc1c073ad39136afbf1.jpg'),
(37475, 2598, 'El Chapo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126955.mp4', 'http://timg.bdta.pro/images/1812c96509569d8b1b93b950e3d02ca1.jpg'),
(37476, 2598, 'El Chapo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126956.mp4', 'http://timg.bdta.pro/images/09e6e566d41dff8eaae0674c253d490f.jpg'),
(37477, 2598, 'El Chapo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126957.mp4', 'http://timg.bdta.pro/images/f7a05ed796a35b6ac2a769e2846b17b6.jpg'),
(37478, 2598, 'El Chapo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126958.mp4', 'http://timg.bdta.pro/images/5d0feb353e0b26cbce398fe0192a3f7d.jpg'),
(37479, 2598, 'El Chapo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126959.mp4', 'http://timg.bdta.pro/images/638c3d75944712f213c795eced7586eb.jpg'),
(37480, 2598, 'El Chapo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126960.mp4', 'http://timg.bdta.pro/images/e278f2b80de3cec36c3373cbbc2f2b98.jpg'),
(37481, 2598, 'El Chapo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126961.mp4', 'http://timg.bdta.pro/images/e6a11f3d30152d091e2da3c2cdade70b.jpg'),
(37482, 2598, 'El Chapo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126962.mp4', 'http://timg.bdta.pro/images/0daaf298415686031f6f6d6b3a5108c1.jpg'),
(37483, 2598, 'El Chapo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126963.mp4', 'http://timg.bdta.pro/images/ad194f5105e1db6cd92be43d39b071e6.jpg'),
(37484, 2598, 'El Chapo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126964.mp4', 'http://timg.bdta.pro/images/71f838c0d8d4a57f74b8a13f19d1ed63.jpg'),
(37485, 2598, 'El Chapo S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/126965.mp4', 'http://timg.bdta.pro/images/783e97a985d594587bb63e0aa49b889f.jpg'),
(37486, 2598, 'El Chapo S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/126966.mp4', 'http://timg.bdta.pro/images/f51b5b64b41b8050c83e334707586471.jpg'),
(37487, 2598, 'El Chapo S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/126967.mp4', 'http://timg.bdta.pro/images/aa1642e8b0cf6957a146b9bbc1f49ac1.jpg'),
(37488, 2599, 'Emily em Paris S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202967.mp4', 'http://timg.bdta.pro/images/62a16a71dcb3c1d193d4a107b25b534b.jpg'),
(37489, 2599, 'Emily em Paris S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202968.mp4', 'http://timg.bdta.pro/images/365c40af0999467889fb9ac4cb52d901.jpg'),
(37490, 2599, 'Emily em Paris S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202969.mp4', 'http://timg.bdta.pro/images/0af6394140ab1791a24e48ee94ccf70f.jpg'),
(37491, 2599, 'Emily em Paris S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202970.mp4', 'http://timg.bdta.pro/images/d6db6ca34152489c4944746ef1106537.jpg'),
(37492, 2599, 'Emily em Paris S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202971.mp4', 'http://timg.bdta.pro/images/29620fe4f6574bdcb3f2ec52a4d54deb.jpg'),
(37493, 2599, 'Emily em Paris S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202972.mp4', 'http://timg.bdta.pro/images/87f907d2bfe035d74d39125178ed0331.jpg'),
(37494, 2599, 'Emily em Paris S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202973.mp4', 'http://timg.bdta.pro/images/e7766d4286d03f24607dd843b629c677.jpg'),
(37495, 2599, 'Emily em Paris S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202974.mp4', 'http://timg.bdta.pro/images/5a08e51861655bc018f6471097dc0421.jpg'),
(37496, 2599, 'Emily em Paris S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202975.mp4', 'http://timg.bdta.pro/images/506f8092f22066021a10bcff8dc4ffbc.jpg'),
(37497, 2599, 'Emily em Paris S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202976.mp4', 'http://timg.bdta.pro/images/1b12e18780b58c7a8ded03c02526f62a.jpg'),
(37498, 2600, 'Emily em Paris S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cs9hmdG9w6w5OkvcFKVOj5AiAZ9.jpg'),
(37499, 2600, 'Emily em Paris S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iZEPz9MBEy9Zoc11NvNCWuElvVC.jpg'),
(37500, 2600, 'Emily em Paris S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ojOKp4wZhFU2Qv4eV5HvAboqzs.jpg'),
(37501, 2600, 'Emily em Paris S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yK7niDJXEdr6AKLimgV8ZpdWQvy.jpg'),
(37502, 2600, 'Emily em Paris S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c6lRYTvJR3o6oU0DabE38EBSUIu.jpg'),
(37503, 2600, 'Emily em Paris S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ykomsIPlGq3uhvadIpY0eoToa0J.jpg'),
(37504, 2600, 'Emily em Paris S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qxumKipIFtni0AYgg4B2uu9nkHB.jpg'),
(37505, 2600, 'Emily em Paris S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tKU7Okh2g7XrS7rBMoOy67N3sWn.jpg'),
(37506, 2600, 'Emily em Paris S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ZZs4WRSoYV7i8OrDk6Vsjk9Anc.jpg'),
(37507, 2600, 'Emily em Paris S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Z2SajfuraGexYgXkPOhC9MGuKV.jpg'),
(37508, 2601, 'Emily em Paris S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uq5OSDjAKZqsp8E1EP50CE2iDw.jpg'),
(37509, 2601, 'Emily em Paris S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pk9qJ0XtCKdkJGJRCf4MCAhl1yM.jpg'),
(37510, 2601, 'Emily em Paris S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dzNWeSwTxegJCdUPFGxipymOO6p.jpg'),
(37511, 2601, 'Emily em Paris S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jP8Z4B07otjQMrOhHd1Vk76UdUA.jpg'),
(37512, 2601, 'Emily em Paris S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y4XugPik9TilZB6rTcpEQY4YVtU.jpg'),
(37513, 2601, 'Emily em Paris S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f3v76o82i7qohy1mayHTQJP40G5.jpg'),
(37514, 2601, 'Emily em Paris S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nnxvV06DniyWu3MiAdAXPmPNA2W.jpg'),
(37515, 2601, 'Emily em Paris S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7BA86LVUXcWCNIKjCtR5lEeAMsB.jpg'),
(37516, 2601, 'Emily em Paris S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lEbEdQoYyYlPhM7bYVYKjyK6Hbr.jpg'),
(37517, 2601, 'Emily em Paris S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/21clMQDwZigbQT994qASshzMjAq.jpg'),
(37518, 2602, 'Emily em Paris S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/429861.mp4', 'http://gstaticontent.com/images/2QeSY4fkl3tKRAg3HEiTHxSJg8j_big.jpg'),
(37519, 2602, 'Emily em Paris S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/429862.mp4', 'http://gstaticontent.com/images/2QeSY4fkl3tKRAg3HEiTHxSJg8j_big.jpg'),
(37520, 2602, 'Emily em Paris S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/429863.mp4', 'http://gstaticontent.com/images/2QeSY4fkl3tKRAg3HEiTHxSJg8j_big.jpg'),
(37521, 2602, 'Emily em Paris S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/429864.mp4', 'http://gstaticontent.com/images/2QeSY4fkl3tKRAg3HEiTHxSJg8j_big.jpg'),
(37522, 2602, 'Emily em Paris S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/429865.mp4', 'http://gstaticontent.com/images/2QeSY4fkl3tKRAg3HEiTHxSJg8j_big.jpg'),
(37523, 2602, 'Emily em Paris S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/452704.mp4', 'http://gstaticontent.com/images/2QeSY4fkl3tKRAg3HEiTHxSJg8j_big.jpg'),
(37524, 2602, 'Emily em Paris S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/452705.mp4', 'http://gstaticontent.com/images/2QeSY4fkl3tKRAg3HEiTHxSJg8j_big.jpg'),
(37525, 2602, 'Emily em Paris S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/452706.mp4', 'http://gstaticontent.com/images/2QeSY4fkl3tKRAg3HEiTHxSJg8j_big.jpg'),
(37526, 2602, 'Emily em Paris S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/452707.mp4', 'http://gstaticontent.com/images/2QeSY4fkl3tKRAg3HEiTHxSJg8j_big.jpg'),
(37527, 2602, 'Emily em Paris S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/452708.mp4', 'http://gstaticontent.com/images/2QeSY4fkl3tKRAg3HEiTHxSJg8j_big.jpg'),
(37528, 2603, 'Emily em Paris S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/896323.mp4', 'http://gstaticontent.com/images/2QeSY4fkl3tKRAg3HEiTHxSJg8j_big.jpg'),
(37529, 2603, 'Emily em Paris S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/896324.mp4', 'http://gstaticontent.com/images/2QeSY4fkl3tKRAg3HEiTHxSJg8j_big.jpg'),
(37530, 2603, 'Emily em Paris S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/896325.mp4', 'http://gstaticontent.com/images/2QeSY4fkl3tKRAg3HEiTHxSJg8j_big.jpg'),
(37531, 2603, 'Emily em Paris S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/896326.mp4', 'http://gstaticontent.com/images/2QeSY4fkl3tKRAg3HEiTHxSJg8j_big.jpg'),
(37532, 2603, 'Emily em Paris S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/896327.mp4', 'http://gstaticontent.com/images/2QeSY4fkl3tKRAg3HEiTHxSJg8j_big.jpg'),
(37533, 2603, 'Emily em Paris S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/896328.mp4', 'http://gstaticontent.com/images/2QeSY4fkl3tKRAg3HEiTHxSJg8j_big.jpg'),
(37534, 2603, 'Emily em Paris S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/896329.mp4', 'http://gstaticontent.com/images/2QeSY4fkl3tKRAg3HEiTHxSJg8j_big.jpg'),
(37535, 2603, 'Emily em Paris S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/896330.mp4', 'http://gstaticontent.com/images/2QeSY4fkl3tKRAg3HEiTHxSJg8j_big.jpg'),
(37536, 2603, 'Emily em Paris S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/896331.mp4', 'http://gstaticontent.com/images/2QeSY4fkl3tKRAg3HEiTHxSJg8j_big.jpg'),
(37537, 2603, 'Emily em Paris S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/896332.mp4', 'http://gstaticontent.com/images/2QeSY4fkl3tKRAg3HEiTHxSJg8j_big.jpg'),
(37538, 2604, 'Fuller House S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126860.mp4', 'http://timg.bdta.pro/images/41d6ff2e80e3fbb743d1550800632e08.jpg'),
(37539, 2604, 'Fuller House S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126861.mp4', 'http://timg.bdta.pro/images/489f620ff0cffe6a20a66452d476027c.jpg'),
(37540, 2604, 'Fuller House S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126862.mp4', 'http://timg.bdta.pro/images/6dba3f7debee34ebe13d2eba3e84ba34.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(37541, 2604, 'Fuller House S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126863.mp4', 'http://timg.bdta.pro/images/b5cc63bf55de9c1963b7c6c2e64c104b.jpg'),
(37542, 2604, 'Fuller House S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126864.mp4', 'http://timg.bdta.pro/images/75a125daf98f099a9d6b1cba8735d733.jpg'),
(37543, 2604, 'Fuller House S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126865.mp4', 'http://timg.bdta.pro/images/ce8c52ec66e9d0415e19b1e56e2c52d4.jpg'),
(37544, 2604, 'Fuller House S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126866.mp4', 'http://timg.bdta.pro/images/8fc6ec316fe4b0e9305c7eb2b7ad0794.jpg'),
(37545, 2604, 'Fuller House S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126867.mp4', 'http://timg.bdta.pro/images/c4dd6b5907d13f554abf379f54846634.jpg'),
(37546, 2604, 'Fuller House S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126868.mp4', 'http://timg.bdta.pro/images/f5c381498b3b4133cf2dbd5d0003cf8d.jpg'),
(37547, 2604, 'Fuller House S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126869.mp4', 'http://timg.bdta.pro/images/e0c0f5abe579ee23132315d357c3a686.jpg'),
(37548, 2604, 'Fuller House S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/126870.mp4', 'http://timg.bdta.pro/images/2c47135e447b3586019135fed4ba6813.jpg'),
(37549, 2604, 'Fuller House S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/126871.mp4', 'http://timg.bdta.pro/images/7cfd6868182da49cd3611bdc5cd1035e.jpg'),
(37550, 2604, 'Fuller House S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/126872.mp4', 'http://timg.bdta.pro/images/65ed91920efeaa5fa7ca88e5a3f0f236.jpg'),
(37551, 2605, 'Fuller House S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126873.mp4', 'http://timg.bdta.pro/images/bb0bbe3013c9250c047b07fc55ef2902.jpg'),
(37552, 2605, 'Fuller House S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126874.mp4', 'http://timg.bdta.pro/images/68b6fcc94a7aed824367cc88d9487344.jpg'),
(37553, 2605, 'Fuller House S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126875.mp4', 'http://timg.bdta.pro/images/185d7eb366cefc407a6b5d5d145d0624.jpg'),
(37554, 2605, 'Fuller House S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126876.mp4', 'http://timg.bdta.pro/images/cb34dea65701bff8a499ecacad672839.jpg'),
(37555, 2605, 'Fuller House S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126877.mp4', 'http://timg.bdta.pro/images/b422d3a1e08abde31e161a675e6aa202.jpg'),
(37556, 2605, 'Fuller House S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126878.mp4', 'http://timg.bdta.pro/images/6cd57e56b19fd623987db34dd3ff7acc.jpg'),
(37557, 2605, 'Fuller House S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126879.mp4', 'http://timg.bdta.pro/images/80b96c1b20f7f9f4093a22befb57d7b2.jpg'),
(37558, 2605, 'Fuller House S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126880.mp4', 'http://timg.bdta.pro/images/524a51501ce71caad2f7b97c0d9a2acc.jpg'),
(37559, 2605, 'Fuller House S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126881.mp4', 'http://timg.bdta.pro/images/c996f73a408672b14c2363de51f79f05.jpg'),
(37560, 2605, 'Fuller House S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126882.mp4', 'http://timg.bdta.pro/images/fe790ac30a0333a1115032e210d5b66d.jpg'),
(37561, 2605, 'Fuller House S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/126883.mp4', 'http://timg.bdta.pro/images/61cbcc4427cdb2f5c7a8eaa31de5bdeb.jpg'),
(37562, 2605, 'Fuller House S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/126884.mp4', 'http://timg.bdta.pro/images/f349cf38078af81ceb23896ca336eb1c.jpg'),
(37563, 2605, 'Fuller House S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/126885.mp4', 'http://timg.bdta.pro/images/6914f86adf2b474cae5e0e39bd17a574.jpg'),
(37564, 2606, 'Fuller House S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126886.mp4', 'http://timg.bdta.pro/images/bebcf47d9f430cd660fe21e9d31f9dde.jpg'),
(37565, 2606, 'Fuller House S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126887.mp4', 'http://timg.bdta.pro/images/9e1db6303433a2c6c76c65e08e1dfab6.jpg'),
(37566, 2606, 'Fuller House S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126888.mp4', 'http://timg.bdta.pro/images/6561441967c606af3c9707e0300b5128.jpg'),
(37567, 2606, 'Fuller House S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126889.mp4', 'http://timg.bdta.pro/images/78ef1bbbf6e0b1346749f7777ce0fe89.jpg'),
(37568, 2606, 'Fuller House S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126890.mp4', 'http://timg.bdta.pro/images/019e67b4ced59c528e97045818d530ec.jpg'),
(37569, 2606, 'Fuller House S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126891.mp4', 'http://timg.bdta.pro/images/c4659932b379caacd69177af51011fc4.jpg'),
(37570, 2606, 'Fuller House S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126892.mp4', 'http://timg.bdta.pro/images/e1abe99f74319b969fe90714dcd36c0d.jpg'),
(37571, 2606, 'Fuller House S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126893.mp4', 'http://timg.bdta.pro/images/44b9adf4a91f914ac0966a7b99b62291.jpg'),
(37572, 2606, 'Fuller House S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126894.mp4', 'http://timg.bdta.pro/images/d5e50ba4638a4fe3059a168d8f389ee8.jpg'),
(37573, 2606, 'Fuller House S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126895.mp4', 'http://timg.bdta.pro/images/4b049a290d71ac779b62e6c4fd1ac56a.jpg'),
(37574, 2606, 'Fuller House S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/126896.mp4', 'http://timg.bdta.pro/images/6fdcb31aca3c1479473d2df8b5abb9cb.jpg'),
(37575, 2606, 'Fuller House S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/126897.mp4', 'http://timg.bdta.pro/images/90eb1752c419642d8c58638e7eedf33a.jpg'),
(37576, 2606, 'Fuller House S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/126898.mp4', 'http://timg.bdta.pro/images/2839c0973cf0d96ce597cc5543c75ff2.jpg'),
(37577, 2606, 'Fuller House S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/126899.mp4', 'http://timg.bdta.pro/images/2208fbf4bed8dc2d86e5609c7d0b7ea9.jpg'),
(37578, 2606, 'Fuller House S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/126900.mp4', 'http://timg.bdta.pro/images/bd75f4839655f0c1054197b1bd61485f.jpg'),
(37579, 2606, 'Fuller House S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/126901.mp4', 'http://timg.bdta.pro/images/da7db9129385552be8250780495d4c68.jpg'),
(37580, 2606, 'Fuller House S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/126902.mp4', 'http://timg.bdta.pro/images/f00f1279c8459f1b27409539ef9931b0.jpg'),
(37581, 2606, 'Fuller House S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/126903.mp4', 'http://timg.bdta.pro/images/f22d557b9b05e5588618b702fd3d7e38.jpg'),
(37582, 2607, 'Fuller House S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126904.mp4', 'http://timg.bdta.pro/images/04d93a3d0578331588c49b333092eed7.jpg'),
(37583, 2607, 'Fuller House S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126905.mp4', 'http://timg.bdta.pro/images/b12c36233de53b3b338d8c30d3d42d3a.jpg'),
(37584, 2607, 'Fuller House S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126906.mp4', 'http://timg.bdta.pro/images/eccf9b426d73122b73d7987fbbbfefd3.jpg'),
(37585, 2607, 'Fuller House S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126907.mp4', 'http://timg.bdta.pro/images/3a52b97de18126f83c4951e7d183fc2a.jpg'),
(37586, 2607, 'Fuller House S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126908.mp4', 'http://timg.bdta.pro/images/e87110d3dca6c533536399416cea3014.jpg'),
(37587, 2607, 'Fuller House S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126909.mp4', 'http://timg.bdta.pro/images/99aff947c6539b5ac10f43ea30dce356.jpg'),
(37588, 2607, 'Fuller House S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126910.mp4', 'http://timg.bdta.pro/images/43855e8e7328374f63d0cdd1b27939bc.jpg'),
(37589, 2607, 'Fuller House S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126911.mp4', 'http://timg.bdta.pro/images/d7eff8b9d0cff348c325e4f14f565e24.jpg'),
(37590, 2607, 'Fuller House S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126912.mp4', 'http://timg.bdta.pro/images/302ca6b2fd526d6d1e12845eecdf8941.jpg'),
(37591, 2607, 'Fuller House S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126913.mp4', 'http://timg.bdta.pro/images/0438ed54cd9702862bacd865325ff35d.jpg'),
(37592, 2607, 'Fuller House S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/126914.mp4', 'http://timg.bdta.pro/images/f888661d3ddfdcfd26418b5e70e255a9.jpg'),
(37593, 2607, 'Fuller House S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/126915.mp4', 'http://timg.bdta.pro/images/3d668e4a2540e3f579c605732fc2c5bd.jpg'),
(37594, 2608, 'Fuller House S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126916.mp4', 'http://timg.bdta.pro/images/25c27860d494f29c807a318a112801db.jpg'),
(37595, 2608, 'Fuller House S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126917.mp4', 'http://timg.bdta.pro/images/769e37faefad94f501180e04c55f5756.jpg'),
(37596, 2608, 'Fuller House S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126918.mp4', 'http://timg.bdta.pro/images/53afc82293c7c61dd7bb4c8a839251f2.jpg'),
(37597, 2608, 'Fuller House S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126919.mp4', 'http://timg.bdta.pro/images/4a05362abf61748f7bd77e94ea3ddd22.jpg'),
(37598, 2608, 'Fuller House S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126920.mp4', 'http://timg.bdta.pro/images/2916112f86054c2ce1a2246a41966292.jpg'),
(37599, 2608, 'Fuller House S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126921.mp4', 'http://timg.bdta.pro/images/6a1ad1ec7659661568ab9daba65b0d7c.jpg'),
(37600, 2608, 'Fuller House S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126922.mp4', 'http://timg.bdta.pro/images/d5932eaa616daeb4a26565d57ba10dfd.jpg'),
(37601, 2608, 'Fuller House S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126923.mp4', 'http://timg.bdta.pro/images/5ea16a852249466e5ac7dd9ee94b3424.jpg'),
(37602, 2608, 'Fuller House S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126924.mp4', 'http://timg.bdta.pro/images/b970fa528e63daa204157270be5b0b9f.jpg'),
(37603, 2608, 'Fuller House S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126925.mp4', 'http://timg.bdta.pro/images/1cb51f6b30cd5ab9e75285f4723cbd1a.jpg'),
(37604, 2608, 'Fuller House S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/126926.mp4', 'http://timg.bdta.pro/images/5228fdab02352f915ff7e38f6c3fc559.jpg'),
(37605, 2608, 'Fuller House S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/126927.mp4', 'http://timg.bdta.pro/images/5c4c86fbecb79a5dd9d17e8c26d68d86.jpg'),
(37606, 2608, 'Fuller House S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/126928.mp4', 'http://timg.bdta.pro/images/31bce07f4ebcbaf4c2a2d492dfd86a1c.jpg'),
(37607, 2608, 'Fuller House S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/126929.mp4', 'http://timg.bdta.pro/images/c75c1d8e2494e085ac5f546726ba4dd7.jpg'),
(37608, 2608, 'Fuller House S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/126930.mp4', 'http://timg.bdta.pro/images/0321bdf670e42c4a1470d957f08ab521.jpg'),
(37609, 2608, 'Fuller House S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/126931.mp4', 'http://timg.bdta.pro/images/cf4f39f0c088829434216491e7d0a359.jpg'),
(37610, 2608, 'Fuller House S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/126932.mp4', 'http://timg.bdta.pro/images/c1b4641afd1241d1a61724866ce7ee9b.jpg'),
(37611, 2608, 'Fuller House S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/126933.mp4', 'http://timg.bdta.pro/images/0cb29c4b7c224cd11d4750a9c01a108e.jpg'),
(37612, 2609, 'Hospital Playlist [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126848.mp4', 'http://timg.bdta.pro/images/76e43aab46762addadf436e3fb77bea4.jpg'),
(37613, 2609, 'Hospital Playlist [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126849.mp4', 'http://timg.bdta.pro/images/30968c659137156688a6aca702754a08.jpg'),
(37614, 2609, 'Hospital Playlist [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126850.mp4', 'http://timg.bdta.pro/images/cfdfdfc857b20d1945528e554671bf5c.jpg'),
(37615, 2609, 'Hospital Playlist [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126851.mp4', 'http://timg.bdta.pro/images/d61b5efd7596d01c7ca7b27e304f292b.jpg'),
(37616, 2609, 'Hospital Playlist [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126852.mp4', 'http://timg.bdta.pro/images/aa0d9193b5257669feecddce99e390d1.jpg'),
(37617, 2609, 'Hospital Playlist [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126853.mp4', 'http://timg.bdta.pro/images/25de80bfa96761176b7100ae35889283.jpg'),
(37618, 2609, 'Hospital Playlist [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126854.mp4', 'http://timg.bdta.pro/images/7b2a9d877ddcdbf8c70017d88df066ab.jpg'),
(37619, 2609, 'Hospital Playlist [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126855.mp4', 'http://timg.bdta.pro/images/6237553fdcb652caffda5ad43caf0451.jpg'),
(37620, 2609, 'Hospital Playlist [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126856.mp4', 'http://timg.bdta.pro/images/08f5d5a5a33ac8fef08c1e20200c5f96.jpg'),
(37621, 2609, 'Hospital Playlist [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126857.mp4', 'http://timg.bdta.pro/images/7d3f35efa4d0e28fc127da918ab5e510.jpg'),
(37622, 2609, 'Hospital Playlist [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/126858.mp4', 'http://timg.bdta.pro/images/0faacac5b700eb2f4a23220417eff844.jpg'),
(37623, 2609, 'Hospital Playlist [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/126859.mp4', 'http://timg.bdta.pro/images/bf05dc88e9f12fe49a6831412f1495f8.jpg'),
(37624, 2610, 'Justified S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126770.mp4', 'http://timg.bdta.pro/images/5b52e3be94b647488fef77b99973a8c1.jpg'),
(37625, 2610, 'Justified S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126771.mp4', 'http://timg.bdta.pro/images/06592de5fd33db38910361c0905fe743.jpg'),
(37626, 2610, 'Justified S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126772.mp4', 'http://timg.bdta.pro/images/39857dee06407e156c40ae6f944dd338.jpg'),
(37627, 2610, 'Justified S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126773.mp4', 'http://timg.bdta.pro/images/41491cb9eb6fe9e01bc6d8ad8d5c5807.jpg'),
(37628, 2610, 'Justified S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126774.mp4', 'http://timg.bdta.pro/images/99bf4853eb31e69d8c1dbba54a5bfc46.jpg'),
(37629, 2610, 'Justified S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126775.mp4', 'http://timg.bdta.pro/images/e41d1d6b9726dfcb81e091abd3e0116e.jpg'),
(37630, 2610, 'Justified S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126776.mp4', 'http://timg.bdta.pro/images/83551fea22fd0ab43b4949486af9976a.jpg'),
(37631, 2610, 'Justified S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126777.mp4', 'http://timg.bdta.pro/images/057cc8a2afe1734f909897e39489ba79.jpg'),
(37632, 2610, 'Justified S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126778.mp4', 'http://timg.bdta.pro/images/83adb291abae7f3db8be798f09a8b5ab.jpg'),
(37633, 2610, 'Justified S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126779.mp4', 'http://timg.bdta.pro/images/d1b5db9df2cf5f5085dd5b43bcacef0b.jpg'),
(37634, 2610, 'Justified S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/126780.mp4', 'http://timg.bdta.pro/images/b270c7ddc2f09ee23be8f8151eb06ceb.jpg'),
(37635, 2610, 'Justified S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/126781.mp4', 'http://timg.bdta.pro/images/7cdba3e5bac41b5aae88c78dc98ef9e0.jpg'),
(37636, 2610, 'Justified S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/126782.mp4', 'http://timg.bdta.pro/images/a75af278c9f3ec766f2cc8010e4e7cf8.jpg'),
(37637, 2611, 'Justified S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126783.mp4', 'http://timg.bdta.pro/images/066880986e4624f696b4ceecbdf9d9b0.jpg'),
(37638, 2611, 'Justified S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126784.mp4', 'http://timg.bdta.pro/images/94444d6ccf57b8a0450b3a00ed5001f4.jpg'),
(37639, 2611, 'Justified S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126785.mp4', 'http://timg.bdta.pro/images/84b33821b56d666d975de65e56996c55.jpg'),
(37640, 2611, 'Justified S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126786.mp4', 'http://timg.bdta.pro/images/eaeb48479d7ab0c3620923c0799b4e5c.jpg'),
(37641, 2611, 'Justified S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126787.mp4', 'http://timg.bdta.pro/images/83690776898e0ed64f989c7452bdfe31.jpg'),
(37642, 2611, 'Justified S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126788.mp4', 'http://timg.bdta.pro/images/001d810ed6bcbf0fbb964f2905ae89fb.jpg'),
(37643, 2611, 'Justified S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126789.mp4', 'http://timg.bdta.pro/images/e293db674ce56977e4cc045205df4d0e.jpg'),
(37644, 2611, 'Justified S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126790.mp4', 'http://timg.bdta.pro/images/6c868832ef801249c5ef28c3e3030926.jpg'),
(37645, 2611, 'Justified S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126791.mp4', 'http://timg.bdta.pro/images/ce1a64c3fa56b4d3476f14e02ca16061.jpg'),
(37646, 2611, 'Justified S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126792.mp4', 'http://timg.bdta.pro/images/dd70b94f5d4d201fdabbf50eafa87286.jpg'),
(37647, 2611, 'Justified S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/126793.mp4', 'http://timg.bdta.pro/images/65caf27d7f08e4560e751df9820c6238.jpg'),
(37648, 2611, 'Justified S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/126794.mp4', 'http://timg.bdta.pro/images/8d501190ce3a9fdfd9759ea85a3ef9a6.jpg'),
(37649, 2611, 'Justified S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/126795.mp4', 'http://timg.bdta.pro/images/4090f4b59027319de1c54610a09a13d6.jpg'),
(37650, 2612, 'Justified S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126796.mp4', 'http://timg.bdta.pro/images/b61d5bc2e3143a28c407aef8a325cbf6.jpg'),
(37651, 2612, 'Justified S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126797.mp4', 'http://timg.bdta.pro/images/bbe0d30b1262296ec7815f2c2c837c71.jpg'),
(37652, 2612, 'Justified S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126798.mp4', 'http://timg.bdta.pro/images/0034119c5cbbd06005e83ab8bc80cc38.jpg'),
(37653, 2612, 'Justified S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126799.mp4', 'http://timg.bdta.pro/images/3ca88b6b708b878ac9ceffe0113b7c2c.jpg'),
(37654, 2612, 'Justified S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126800.mp4', 'http://timg.bdta.pro/images/e1196017a441e913109e74b08c966480.jpg'),
(37655, 2612, 'Justified S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126801.mp4', 'http://timg.bdta.pro/images/c4fb6b6b0a7df477f868d5f777980159.jpg'),
(37656, 2612, 'Justified S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126802.mp4', 'http://timg.bdta.pro/images/08b75c52e8c6321c59fc735236460199.jpg'),
(37657, 2612, 'Justified S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126803.mp4', 'http://timg.bdta.pro/images/54c20f7cb7f80a90118692de1526641a.jpg'),
(37658, 2612, 'Justified S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126804.mp4', 'http://timg.bdta.pro/images/a6aa9c3551c38558a306f5e49b412797.jpg'),
(37659, 2612, 'Justified S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126805.mp4', 'http://timg.bdta.pro/images/7a6b14e90784d538ca6f0edb5baa2ce9.jpg'),
(37660, 2612, 'Justified S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/126806.mp4', 'http://timg.bdta.pro/images/c9e33ddafd43c6160aee7abae16b2c9e.jpg'),
(37661, 2612, 'Justified S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/126807.mp4', 'http://timg.bdta.pro/images/6ddc3771ddaf383731a7b7897b1408be.jpg'),
(37662, 2612, 'Justified S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/126808.mp4', 'http://timg.bdta.pro/images/5b7560e0a67e99c311d1ea9f34804258.jpg'),
(37663, 2613, 'Justified S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126809.mp4', 'http://timg.bdta.pro/images/75ca5b0d3a55a188212110783aeef8d7.jpg'),
(37664, 2613, 'Justified S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126810.mp4', 'http://timg.bdta.pro/images/2fe6ba3339d1ca4fd0cf0e3f4ba748a0.jpg'),
(37665, 2613, 'Justified S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126811.mp4', 'http://timg.bdta.pro/images/810dca624ccc90c3ef3d0ce018cc7c69.jpg'),
(37666, 2613, 'Justified S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126812.mp4', 'http://timg.bdta.pro/images/638314a43cde757c3175dddae6b1daaf.jpg'),
(37667, 2613, 'Justified S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126813.mp4', 'http://timg.bdta.pro/images/d46dce4b1d6d687039a4141648677731.jpg'),
(37668, 2613, 'Justified S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126814.mp4', 'http://timg.bdta.pro/images/732e531cb59259036be59a9cd8ce1262.jpg'),
(37669, 2613, 'Justified S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126815.mp4', 'http://timg.bdta.pro/images/5c15d161c0d3eac960dc3c9c29e7692a.jpg'),
(37670, 2613, 'Justified S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126816.mp4', 'http://timg.bdta.pro/images/b32441f2e50ca592ca477c76e39c372f.jpg'),
(37671, 2613, 'Justified S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126817.mp4', 'http://timg.bdta.pro/images/c8487cc84e8ae52b127a8063302a2316.jpg'),
(37672, 2613, 'Justified S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126818.mp4', 'http://timg.bdta.pro/images/b3aa5f551ffe78538e69853e2046c94f.jpg'),
(37673, 2613, 'Justified S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/126819.mp4', 'http://timg.bdta.pro/images/e960ca5519765308e9fd13807f201f1f.jpg'),
(37674, 2613, 'Justified S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/126820.mp4', 'http://timg.bdta.pro/images/62abe9db0978f54391a6880d9a480eda.jpg'),
(37675, 2613, 'Justified S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/126821.mp4', 'http://timg.bdta.pro/images/2bbea2e26fd62223953e4d86a7a89785.jpg'),
(37676, 2614, 'Justified S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126822.mp4', 'http://timg.bdta.pro/images/85a216c600352f262af806a75f50129c.jpg'),
(37677, 2614, 'Justified S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126823.mp4', 'http://timg.bdta.pro/images/f6b71856e9eb5df10f595684643599e0.jpg'),
(37678, 2614, 'Justified S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126824.mp4', 'http://timg.bdta.pro/images/951efd9afeeee2883b7f419ba43523af.jpg'),
(37679, 2614, 'Justified S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126825.mp4', 'http://timg.bdta.pro/images/7ee91949f395290aa2289474572d6ad9.jpg'),
(37680, 2614, 'Justified S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126826.mp4', 'http://timg.bdta.pro/images/91249a33e121d81de3cc262d01958d08.jpg'),
(37681, 2614, 'Justified S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126827.mp4', 'http://timg.bdta.pro/images/4a5e8ed94de107b34f1c1942aa129913.jpg'),
(37682, 2614, 'Justified S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126828.mp4', 'http://timg.bdta.pro/images/3ce11f0b4b58a59d9268d900ed72b354.jpg'),
(37683, 2614, 'Justified S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126829.mp4', 'http://timg.bdta.pro/images/1efa7344f2f024a5e29787392146f206.jpg'),
(37684, 2614, 'Justified S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126830.mp4', 'http://timg.bdta.pro/images/a0c05c12a444ab195fc54b2e2fdcc859.jpg'),
(37685, 2614, 'Justified S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126831.mp4', 'http://timg.bdta.pro/images/cbff7985d3758c5eb4d20eeec8eb0207.jpg'),
(37686, 2614, 'Justified S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/126832.mp4', 'http://timg.bdta.pro/images/1d75b6bbd67290743c1d2d97de302e2a.jpg'),
(37687, 2614, 'Justified S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/126833.mp4', 'http://timg.bdta.pro/images/b26b6513c9cf9bb369fc71bb00b8d83b.jpg'),
(37688, 2614, 'Justified S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/126834.mp4', 'http://timg.bdta.pro/images/9ceced240726f865f51d493025e78bf3.jpg'),
(37689, 2615, 'Justified S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126835.mp4', 'http://timg.bdta.pro/images/a10fc9b11e7573d978985fd3fb920d5a.jpg'),
(37690, 2615, 'Justified S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126836.mp4', 'http://timg.bdta.pro/images/2d349c3afe9095c02b7854c88557ff7d.jpg'),
(37691, 2615, 'Justified S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126837.mp4', 'http://timg.bdta.pro/images/053ef1e083aceb2430ea10e365c4ec1c.jpg'),
(37692, 2615, 'Justified S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126838.mp4', 'http://timg.bdta.pro/images/25522c50434c8200c176643f7505b05c.jpg'),
(37693, 2615, 'Justified S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126839.mp4', 'http://timg.bdta.pro/images/447511c98839ad9cf07c020618ef3ca1.jpg'),
(37694, 2615, 'Justified S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126840.mp4', 'http://timg.bdta.pro/images/5a1372f2c50b0514f3fb0f36735d510b.jpg'),
(37695, 2615, 'Justified S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126841.mp4', 'http://timg.bdta.pro/images/aba7d9191b44512c98b650cea57151cf.jpg'),
(37696, 2615, 'Justified S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126842.mp4', 'http://timg.bdta.pro/images/93fe43056848c92331c6d16a2be4763d.jpg'),
(37697, 2615, 'Justified S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126843.mp4', 'http://timg.bdta.pro/images/c66f8422be1d0cd411cd2ed9499d1c82.jpg'),
(37698, 2615, 'Justified S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126844.mp4', 'http://timg.bdta.pro/images/fdc0c673a627c75cf7eedf35c1c6b646.jpg'),
(37699, 2615, 'Justified S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/126845.mp4', 'http://timg.bdta.pro/images/f192ec5466bd4a467e4b834a9c7e1797.jpg'),
(37700, 2615, 'Justified S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/126846.mp4', 'http://timg.bdta.pro/images/6920bb74617ad2b7919b320859126334.jpg'),
(37701, 2615, 'Justified S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/126847.mp4', 'http://timg.bdta.pro/images/b630e720fc8ee81d1bf3851ccca169be.jpg'),
(37702, 2616, 'Me Conte Uma História S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126750.mp4', 'http://timg.bdta.pro/images/2da81e20e6d8f27c7a47fa05e5dcd85e.jpg'),
(37703, 2616, 'Me Conte Uma História S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126751.mp4', 'http://timg.bdta.pro/images/4a9d7a6fba43b982d73c7130d85cc0d9.jpg'),
(37704, 2616, 'Me Conte Uma História S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126752.mp4', 'http://timg.bdta.pro/images/6deafae10dbbbd589566f45a537d9d12.jpg'),
(37705, 2616, 'Me Conte Uma História S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126753.mp4', 'http://timg.bdta.pro/images/5d3909ade524c5dc64a1eb49b93f8edb.jpg'),
(37706, 2616, 'Me Conte Uma História S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126754.mp4', 'http://timg.bdta.pro/images/165afca4da5c5e0ece029e94079c33df.jpg'),
(37707, 2616, 'Me Conte Uma História S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126755.mp4', 'http://timg.bdta.pro/images/8579d914bf9470380a4ddc73a4a1ab98.jpg'),
(37708, 2616, 'Me Conte Uma História S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126756.mp4', 'http://timg.bdta.pro/images/ffea0ddeb9449206d5b0cd7472d02f85.jpg'),
(37709, 2616, 'Me Conte Uma História S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126757.mp4', 'http://timg.bdta.pro/images/39e76947f8dc55b08644f4b3310cc921.jpg'),
(37710, 2616, 'Me Conte Uma História S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126758.mp4', 'http://timg.bdta.pro/images/1b78737e37a8756c4ce9374909e7ed77.jpg'),
(37711, 2616, 'Me Conte Uma História S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126759.mp4', 'http://timg.bdta.pro/images/109b915242dbb363294c01144df91d3e.jpg'),
(37712, 2617, 'Me Conte Uma História S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126760.mp4', 'http://timg.bdta.pro/images/e23f78f52eda0049cc607cf6b8358031.jpg'),
(37713, 2617, 'Me Conte Uma História S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126761.mp4', 'http://timg.bdta.pro/images/68f2941caacf755a37169e4337a14cca.jpg'),
(37714, 2617, 'Me Conte Uma História S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126762.mp4', 'http://timg.bdta.pro/images/2f67834f4ebe46e655d92a3b817882cb.jpg'),
(37715, 2617, 'Me Conte Uma História S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126763.mp4', 'http://timg.bdta.pro/images/345b937f8924b1f714f3df3d15d6e6f0.jpg'),
(37716, 2617, 'Me Conte Uma História S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126764.mp4', 'http://timg.bdta.pro/images/6e6be2c41f09c3449dbf8bfb286283df.jpg'),
(37717, 2617, 'Me Conte Uma História S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126765.mp4', 'http://timg.bdta.pro/images/f3a2910d82bd0b8f1129672f8860b34d.jpg'),
(37718, 2617, 'Me Conte Uma História S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126766.mp4', 'http://timg.bdta.pro/images/8dcad47d0596b021ee4f70ff5c28790e.jpg'),
(37719, 2617, 'Me Conte Uma História S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126767.mp4', 'http://timg.bdta.pro/images/f0b077e0a42904acb4c3db3ed2e8d82c.jpg'),
(37720, 2617, 'Me Conte Uma História S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126768.mp4', 'http://timg.bdta.pro/images/46f058ef304df23a3103510d4de0bf08.jpg'),
(37721, 2617, 'Me Conte Uma História S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126769.mp4', 'http://timg.bdta.pro/images/00f873b191c22014ce25265969a7668d.jpg'),
(37722, 2618, 'O Novo Papa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126741.mp4', 'http://timg.bdta.pro/images/db8729d9f5ee9c71cd038812bd6666ba.jpg'),
(37723, 2618, 'O Novo Papa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126742.mp4', 'http://timg.bdta.pro/images/6e77d161cfa2b6536002e9c4e887a623.jpg'),
(37724, 2618, 'O Novo Papa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126743.mp4', 'http://timg.bdta.pro/images/e765169b4ef6ee4936c49a3469f95d7e.jpg'),
(37725, 2618, 'O Novo Papa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126744.mp4', 'http://timg.bdta.pro/images/497d193c5b23b7d5c76856e93d8dedaa.jpg'),
(37726, 2618, 'O Novo Papa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126745.mp4', 'http://timg.bdta.pro/images/45aec239c266bf794c6381a6f327913a.jpg'),
(37727, 2618, 'O Novo Papa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126746.mp4', 'http://timg.bdta.pro/images/349b6b06bd2e61ac447124b9096c487e.jpg'),
(37728, 2618, 'O Novo Papa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126747.mp4', 'http://timg.bdta.pro/images/ca5bffd23f3b4387fe75d260a657a222.jpg'),
(37729, 2618, 'O Novo Papa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126748.mp4', 'http://timg.bdta.pro/images/fe5aac3d3436372268ee093e67bbb37b.jpg'),
(37730, 2618, 'O Novo Papa S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126749.mp4', 'http://timg.bdta.pro/images/3e3071447510f6b6496fe2796ec793a8.jpg'),
(37731, 2619, 'O Segredo do Rancho Skinwalker S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262557.mp4', 'http://timg.bdta.pro/images/5b592910ca6273ba3f7da32ad79fed69.jpg'),
(37732, 2619, 'O Segredo do Rancho Skinwalker S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262558.mp4', 'http://timg.bdta.pro/images/88ec80778bac664a4d5ed0bcd65ff70e.jpg'),
(37733, 2619, 'O Segredo do Rancho Skinwalker S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262559.mp4', 'http://timg.bdta.pro/images/777ac075c7dd3321ece666f12cc11e60.jpg'),
(37734, 2619, 'O Segredo do Rancho Skinwalker S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262560.mp4', 'http://timg.bdta.pro/images/c2b6103dbea7ef053f12f8874f73ad79.jpg'),
(37735, 2619, 'O Segredo do Rancho Skinwalker S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262561.mp4', 'http://timg.bdta.pro/images/cb231672da72ec150772fffc485de0eb.jpg'),
(37736, 2619, 'O Segredo do Rancho Skinwalker S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262562.mp4', 'http://timg.bdta.pro/images/300099095ba262c3d5b06ef38902d8a2.jpg'),
(37737, 2619, 'O Segredo do Rancho Skinwalker S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262563.mp4', 'http://timg.bdta.pro/images/b3af0d2807c4eaf6c76c83452fdeb0aa.jpg'),
(37738, 2619, 'O Segredo do Rancho Skinwalker S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262564.mp4', 'http://timg.bdta.pro/images/2990bf19f5eb0b0259d7196d0148b1bf.jpg'),
(37739, 2620, 'O Segredo do Rancho Skinwalker S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262565.mp4', 'http://timg.bdta.pro/images/1439f6cc82f09d27ea80133959549a69.jpg'),
(37740, 2620, 'O Segredo do Rancho Skinwalker S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262566.mp4', 'http://timg.bdta.pro/images/afc7861d14d70715b410347000900981.jpg'),
(37741, 2620, 'O Segredo do Rancho Skinwalker S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262567.mp4', 'http://timg.bdta.pro/images/2dae898682283283ff9baabb495db750.jpg'),
(37742, 2620, 'O Segredo do Rancho Skinwalker S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262568.mp4', 'http://timg.bdta.pro/images/80db04cc2455587b812142ae571cefd6.jpg'),
(37743, 2620, 'O Segredo do Rancho Skinwalker S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262569.mp4', 'http://timg.bdta.pro/images/9796274bb7e390d7f9cc9f1e37e598d2.jpg'),
(37744, 2620, 'O Segredo do Rancho Skinwalker S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262570.mp4', 'http://timg.bdta.pro/images/af620e46f3ac4b2064fffdb1b959a030.jpg'),
(37745, 2620, 'O Segredo do Rancho Skinwalker S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262571.mp4', 'http://timg.bdta.pro/images/3a75f956e30ac47f947b6f6b4809c693.jpg'),
(37746, 2620, 'O Segredo do Rancho Skinwalker S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262572.mp4', 'http://timg.bdta.pro/images/82de53da541e4c6ee55ce974b58e0cb5.jpg'),
(37747, 2620, 'O Segredo do Rancho Skinwalker S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/262573.mp4', 'http://timg.bdta.pro/images/ad0de7abbf0f05a4c5dfb9b39c214586.jpg'),
(37748, 2620, 'O Segredo do Rancho Skinwalker S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/262574.mp4', 'http://timg.bdta.pro/images/cfa5f9fbcfa929ad00ec7a0518ff23e8.jpg'),
(37749, 2621, 'O Segredo do Rancho Skinwalker S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262575.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37750, 2621, 'O Segredo do Rancho Skinwalker S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262576.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37751, 2621, 'O Segredo do Rancho Skinwalker S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262577.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37752, 2621, 'O Segredo do Rancho Skinwalker S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262578.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37753, 2621, 'O Segredo do Rancho Skinwalker S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262579.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37754, 2621, 'O Segredo do Rancho Skinwalker S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262580.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37755, 2621, 'O Segredo do Rancho Skinwalker S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262581.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37756, 2621, 'O Segredo do Rancho Skinwalker S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262582.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37757, 2621, 'O Segredo do Rancho Skinwalker S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/262583.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37758, 2621, 'O Segredo do Rancho Skinwalker S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/262584.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37759, 2621, 'O Segredo do Rancho Skinwalker S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/262585.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37760, 2622, 'O Segredo do Rancho Skinwalker S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262586.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37761, 2622, 'O Segredo do Rancho Skinwalker S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262587.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37762, 2622, 'O Segredo do Rancho Skinwalker S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262588.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37763, 2622, 'O Segredo do Rancho Skinwalker S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262589.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37764, 2622, 'O Segredo do Rancho Skinwalker S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262590.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37765, 2622, 'O Segredo do Rancho Skinwalker S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262591.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37766, 2622, 'O Segredo do Rancho Skinwalker S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262592.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37767, 2622, 'O Segredo do Rancho Skinwalker S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262593.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37768, 2622, 'O Segredo do Rancho Skinwalker S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/262594.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37769, 2622, 'O Segredo do Rancho Skinwalker S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/262595.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37770, 2622, 'O Segredo do Rancho Skinwalker S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/262596.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37771, 2622, 'O Segredo do Rancho Skinwalker S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/262597.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37772, 2622, 'O Segredo do Rancho Skinwalker S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/262598.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37773, 2622, 'O Segredo do Rancho Skinwalker S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/262599.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37774, 2622, 'O Segredo do Rancho Skinwalker S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/262600.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37775, 2623, 'O Segredo do Rancho Skinwalker S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/460602.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37776, 2623, 'O Segredo do Rancho Skinwalker S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/460603.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37777, 2623, 'O Segredo do Rancho Skinwalker S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/636928.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37778, 2623, 'O Segredo do Rancho Skinwalker S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/636929.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37779, 2623, 'O Segredo do Rancho Skinwalker S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/636930.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37780, 2623, 'O Segredo do Rancho Skinwalker S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/636931.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37781, 2623, 'O Segredo do Rancho Skinwalker S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/636932.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37782, 2623, 'O Segredo do Rancho Skinwalker S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/636933.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37783, 2623, 'O Segredo do Rancho Skinwalker S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/636934.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37784, 2623, 'O Segredo do Rancho Skinwalker S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/636935.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37785, 2623, 'O Segredo do Rancho Skinwalker S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/636936.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37786, 2623, 'O Segredo do Rancho Skinwalker S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/636937.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37787, 2623, 'O Segredo do Rancho Skinwalker S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/636938.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37788, 2623, 'O Segredo do Rancho Skinwalker S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/636939.mp4', 'http://gstaticontent.com/images/uG5qIdxLuvzSXV6x60j2y2Mfsl2_big.jpg'),
(37789, 2624, 'Oktoberfest: Sangue e Cerveja S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126735.mp4', 'http://timg.bdta.pro/images/686cd6aa55b632584db627f88cdbc467.jpg'),
(37790, 2624, 'Oktoberfest: Sangue e Cerveja S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126736.mp4', 'http://timg.bdta.pro/images/e512fa5721e73d05cd0de0c24c979fff.jpg'),
(37791, 2624, 'Oktoberfest: Sangue e Cerveja S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126737.mp4', 'http://timg.bdta.pro/images/98d22ec717f31c8e3c1f18ec097ab4d6.jpg'),
(37792, 2624, 'Oktoberfest: Sangue e Cerveja S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126738.mp4', 'http://timg.bdta.pro/images/717f4cd06d342a8c19465be038b63c86.jpg'),
(37793, 2624, 'Oktoberfest: Sangue e Cerveja S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126739.mp4', 'http://timg.bdta.pro/images/5e6bfa1179d310c4651b44b3515a54d5.jpg'),
(37794, 2624, 'Oktoberfest: Sangue e Cerveja S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126740.mp4', 'http://timg.bdta.pro/images/6ef97bc8e67de85c6b12be93462ec18e.jpg'),
(37795, 2625, 'Os Borgias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126706.mp4', 'http://timg.bdta.pro/images/42c372c34c70aa89ec583d4bd70e274e.jpg'),
(37796, 2625, 'Os Borgias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126707.mp4', 'http://timg.bdta.pro/images/a9d8b99961690d4ef316a13358dcfd3b.jpg'),
(37797, 2625, 'Os Borgias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126708.mp4', 'http://timg.bdta.pro/images/8a5f2436a8dff2513b483f52a30f2708.jpg'),
(37798, 2625, 'Os Borgias S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126709.mp4', 'http://timg.bdta.pro/images/f83be7cef17299645fc2ae520bff9831.jpg'),
(37799, 2625, 'Os Borgias S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126710.mp4', 'http://timg.bdta.pro/images/9c3aebf1ddfe7a81566866fdc287a056.jpg'),
(37800, 2625, 'Os Borgias S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126711.mp4', 'http://timg.bdta.pro/images/047a7302ea9696d12f92d82619be5efd.jpg'),
(37801, 2625, 'Os Borgias S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126712.mp4', 'http://timg.bdta.pro/images/17d23a9fc391df01c185d80ef0558b4d.jpg'),
(37802, 2625, 'Os Borgias S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126713.mp4', 'http://timg.bdta.pro/images/dd7f1096bbfe1713b02bfd960884f882.jpg'),
(37803, 2625, 'Os Borgias S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126714.mp4', 'http://timg.bdta.pro/images/309b2030ab4daa5496d5f66bd5ff7d0c.jpg'),
(37804, 2626, 'Os Borgias S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126715.mp4', 'http://timg.bdta.pro/images/7e28502883b08aaea433197c934432db.jpg'),
(37805, 2626, 'Os Borgias S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126716.mp4', 'http://timg.bdta.pro/images/2e65f449228213898ae35826404dfb3a.jpg'),
(37806, 2626, 'Os Borgias S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126717.mp4', 'http://timg.bdta.pro/images/83001c4f8884e3cf574ca9b4c6281a08.jpg'),
(37807, 2626, 'Os Borgias S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126718.mp4', 'http://timg.bdta.pro/images/687f110a3a9dfa2b3601c5012aecbabb.jpg'),
(37808, 2626, 'Os Borgias S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126719.mp4', 'http://timg.bdta.pro/images/7e1602f3445eead12fde6073896b504d.jpg'),
(37809, 2626, 'Os Borgias S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126720.mp4', 'http://timg.bdta.pro/images/3b66bc3ad109e4facc54159f171a4e8b.jpg'),
(37810, 2626, 'Os Borgias S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126721.mp4', 'http://timg.bdta.pro/images/e6dbd609a8452d28f142c84252d03a6d.jpg'),
(37811, 2626, 'Os Borgias S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126722.mp4', 'http://timg.bdta.pro/images/0c904ab285aa9556c94211ec21404f44.jpg'),
(37812, 2626, 'Os Borgias S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126723.mp4', 'http://timg.bdta.pro/images/e873de9ef173476f3ff9ada963fd50dc.jpg'),
(37813, 2626, 'Os Borgias S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126724.mp4', 'http://timg.bdta.pro/images/3af2e84df131248af53938c8b2ee3c6e.jpg'),
(37814, 2627, 'Os Borgias S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126725.mp4', 'http://timg.bdta.pro/images/2e15cbebe3a36d2169aa66e367b20072.jpg'),
(37815, 2627, 'Os Borgias S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126726.mp4', 'http://timg.bdta.pro/images/7c6bde8b5ed280d406dddca5a5ec1f23.jpg'),
(37816, 2627, 'Os Borgias S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126727.mp4', 'http://timg.bdta.pro/images/4ed4aab713115bb75cdbd7c63cb9165c.jpg'),
(37817, 2627, 'Os Borgias S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126728.mp4', 'http://timg.bdta.pro/images/2b15bfb780deb66c0d5b5bb2a8d79767.jpg'),
(37818, 2627, 'Os Borgias S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126729.mp4', 'http://timg.bdta.pro/images/5c4ad66d16b0516894047f2a2a96a85e.jpg'),
(37819, 2627, 'Os Borgias S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126730.mp4', 'http://timg.bdta.pro/images/79609d28acdf7c81013072849bb8d9af.jpg'),
(37820, 2627, 'Os Borgias S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126731.mp4', 'http://timg.bdta.pro/images/52a02b7219c9763c26cca63179a94986.jpg'),
(37821, 2627, 'Os Borgias S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126732.mp4', 'http://timg.bdta.pro/images/47de24321a019b236215f224106cfd55.jpg'),
(37822, 2627, 'Os Borgias S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126733.mp4', 'http://timg.bdta.pro/images/afa82652fe13855dcdb32cbebd346fcd.jpg'),
(37823, 2627, 'Os Borgias S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126734.mp4', 'http://timg.bdta.pro/images/50ec0bbf7d103302bfe7af9fa64a60cf.jpg'),
(37824, 2628, 'Santo Forte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126669.mp4', 'http://gstaticontent.com/images/0a9e129c8de4b845e87d769f776a9892.jpg'),
(37825, 2628, 'Santo Forte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126670.mp4', 'http://gstaticontent.com/images/0a9e129c8de4b845e87d769f776a9892.jpg'),
(37826, 2628, 'Santo Forte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126671.mp4', 'http://gstaticontent.com/images/0a9e129c8de4b845e87d769f776a9892.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(37827, 2628, 'Santo Forte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126672.mp4', 'http://gstaticontent.com/images/0a9e129c8de4b845e87d769f776a9892.jpg'),
(37828, 2628, 'Santo Forte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126673.mp4', 'http://gstaticontent.com/images/0a9e129c8de4b845e87d769f776a9892.jpg'),
(37829, 2628, 'Santo Forte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126674.mp4', 'http://gstaticontent.com/images/0a9e129c8de4b845e87d769f776a9892.jpg'),
(37830, 2628, 'Santo Forte S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126675.mp4', 'http://gstaticontent.com/images/0a9e129c8de4b845e87d769f776a9892.jpg'),
(37831, 2628, 'Santo Forte S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126676.mp4', 'http://gstaticontent.com/images/0a9e129c8de4b845e87d769f776a9892.jpg'),
(37832, 2628, 'Santo Forte S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126677.mp4', 'http://gstaticontent.com/images/0a9e129c8de4b845e87d769f776a9892.jpg'),
(37833, 2628, 'Santo Forte S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126678.mp4', 'http://gstaticontent.com/images/0a9e129c8de4b845e87d769f776a9892.jpg'),
(37834, 2628, 'Santo Forte S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/126679.mp4', 'http://gstaticontent.com/images/0a9e129c8de4b845e87d769f776a9892.jpg'),
(37835, 2628, 'Santo Forte S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/126680.mp4', 'http://gstaticontent.com/images/0a9e129c8de4b845e87d769f776a9892.jpg'),
(37836, 2628, 'Santo Forte S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/126681.mp4', 'http://gstaticontent.com/images/0a9e129c8de4b845e87d769f776a9892.jpg'),
(37837, 2629, 'The Walking Dead: Um Novo Universo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170542.mp4', 'http://timg.bdta.pro/images/551c9feb363cfc2826f1795c9c72a82e.jpg'),
(37838, 2629, 'The Walking Dead: Um Novo Universo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170543.mp4', 'http://timg.bdta.pro/images/5445c9572460a5c8e302ffa564bbbfde.jpg'),
(37839, 2629, 'The Walking Dead: Um Novo Universo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170544.mp4', 'http://timg.bdta.pro/images/2ac2350e5508c458c228cebf5182448b.jpg'),
(37840, 2629, 'The Walking Dead: Um Novo Universo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170545.mp4', 'http://timg.bdta.pro/images/930d046be019557cda82378206e8b69e.jpg'),
(37841, 2629, 'The Walking Dead: Um Novo Universo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/epVHqo24YhbmBAwmqPjdIgjZe5E.jpg'),
(37842, 2629, 'The Walking Dead: Um Novo Universo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lOUWGxlQNIw23TWUmh6q4q5VjFp.jpg'),
(37843, 2629, 'The Walking Dead: Um Novo Universo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170548.mp4', 'http://gstaticontent.com/images/uDmAoKh5pdoDof9CNIqBtWcLZJd_big.jpg'),
(37844, 2629, 'The Walking Dead: Um Novo Universo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170549.mp4', 'http://gstaticontent.com/images/uDmAoKh5pdoDof9CNIqBtWcLZJd_big.jpg'),
(37845, 2629, 'The Walking Dead: Um Novo Universo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170550.mp4', 'http://gstaticontent.com/images/uDmAoKh5pdoDof9CNIqBtWcLZJd_big.jpg'),
(37846, 2629, 'The Walking Dead: Um Novo Universo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170551.mp4', 'http://gstaticontent.com/images/uDmAoKh5pdoDof9CNIqBtWcLZJd_big.jpg'),
(37847, 2630, 'The Walking Dead: Um Novo Universo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170552.mp4', 'http://image.tmdb.org/t/p/w1280/cDoGJzF695CtcegtWNy9aiUjuKy.jpg'),
(37848, 2630, 'The Walking Dead: Um Novo Universo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170553.mp4', 'http://image.tmdb.org/t/p/w1280/t7sMnOBAGJ8MHL2mjtDvchN1jUL.jpg'),
(37849, 2630, 'The Walking Dead: Um Novo Universo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qfCmXctM5Wy7sUcl957QWrNuHy5.jpg'),
(37850, 2630, 'The Walking Dead: Um Novo Universo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ic5dXVebiCFWQEcpLno0crcRnIz.jpg'),
(37851, 2630, 'The Walking Dead: Um Novo Universo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170556.mp4', 'http://image.tmdb.org/t/p/w1280/wqnn6NeiumwQUJHWZxnialuL4rN.jpg'),
(37852, 2630, 'The Walking Dead: Um Novo Universo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170557.mp4', 'http://image.tmdb.org/t/p/w1280/1TEJVSOlpopJzPVONgo2NfGrfg5.jpg'),
(37853, 2630, 'The Walking Dead: Um Novo Universo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJIv0Lb8ARAJosRWDdrq3IO9gDo.jpg'),
(37854, 2630, 'The Walking Dead: Um Novo Universo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s3ZqxTzAvWI5xSvgay67GJyJ4Ag.jpg'),
(37855, 2630, 'The Walking Dead: Um Novo Universo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZeGbOy158qKEDndDxdj2sV85ZV.jpg'),
(37856, 2630, 'The Walking Dead: Um Novo Universo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qN5QA6BHuRuUBGoyXIUmPIt026o.jpg'),
(37857, 2631, 'Tsugu Tsugumomo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126657.mp4', 'http://timg.bdta.pro/images/c7a6593ab6fc976471548d8bae07b029.jpg'),
(37858, 2631, 'Tsugu Tsugumomo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126658.mp4', 'http://timg.bdta.pro/images/a87b22fed65747a728ef22fa49d249d4.jpg'),
(37859, 2631, 'Tsugu Tsugumomo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126659.mp4', 'http://timg.bdta.pro/images/c305e235f60642806e71b2f2abef46dd.jpg'),
(37860, 2631, 'Tsugu Tsugumomo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126660.mp4', 'http://timg.bdta.pro/images/5b2fe2ec2fbf6fa727b510e7cf1794e3.jpg'),
(37861, 2631, 'Tsugu Tsugumomo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126661.mp4', 'http://timg.bdta.pro/images/43c1643aec40592f37177ffdae59a6c0.jpg'),
(37862, 2631, 'Tsugu Tsugumomo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126662.mp4', 'http://timg.bdta.pro/images/da93a860cf48c08204e1ef63455293a6.jpg'),
(37863, 2631, 'Tsugu Tsugumomo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126663.mp4', 'http://timg.bdta.pro/images/0e50c63bce278c4c24285918ecc542dc.jpg'),
(37864, 2631, 'Tsugu Tsugumomo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126664.mp4', 'http://timg.bdta.pro/images/e063223bac2fa6d71429fc2af13d378d.jpg'),
(37865, 2631, 'Tsugu Tsugumomo [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126665.mp4', 'http://timg.bdta.pro/images/805f85534d39cafdc85881717de6d9fc.jpg'),
(37866, 2631, 'Tsugu Tsugumomo [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126666.mp4', 'http://timg.bdta.pro/images/a6f9661e13a38c9dc3b68735bd72d5c3.jpg'),
(37867, 2631, 'Tsugu Tsugumomo [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/126667.mp4', 'http://timg.bdta.pro/images/586accf252ba953346ac93a5f8e5a368.jpg'),
(37868, 2631, 'Tsugu Tsugumomo [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/126668.mp4', 'http://timg.bdta.pro/images/91d52a05f692595f25279a50710cda62.jpg'),
(37869, 2632, 'Bad Boys e Bilionários: Índia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126634.mp4', 'http://timg.bdta.pro/images/d49f963dee0220fff4485bc875de7f61.jpg'),
(37870, 2632, 'Bad Boys e Bilionários: Índia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126635.mp4', 'http://timg.bdta.pro/images/17546bf27301ac1a73d6ccaa192e5afb.jpg'),
(37871, 2632, 'Bad Boys e Bilionários: Índia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126636.mp4', 'http://timg.bdta.pro/images/49ab27aa8051ccc14fbfcaddd0d9e753.jpg'),
(37872, 2633, 'Cidade dos Mortos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126626.mp4', 'http://gstaticontent.com/images/AbKwJKeitPkOb7iAE1P1dEkVCP1_big.jpg'),
(37873, 2633, 'Cidade dos Mortos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126627.mp4', 'http://gstaticontent.com/images/AbKwJKeitPkOb7iAE1P1dEkVCP1_big.jpg'),
(37874, 2633, 'Cidade dos Mortos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126628.mp4', 'http://gstaticontent.com/images/AbKwJKeitPkOb7iAE1P1dEkVCP1_big.jpg'),
(37875, 2633, 'Cidade dos Mortos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126629.mp4', 'http://gstaticontent.com/images/AbKwJKeitPkOb7iAE1P1dEkVCP1_big.jpg'),
(37876, 2633, 'Cidade dos Mortos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126630.mp4', 'http://gstaticontent.com/images/AbKwJKeitPkOb7iAE1P1dEkVCP1_big.jpg'),
(37877, 2633, 'Cidade dos Mortos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126631.mp4', 'http://gstaticontent.com/images/AbKwJKeitPkOb7iAE1P1dEkVCP1_big.jpg'),
(37878, 2633, 'Cidade dos Mortos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126632.mp4', 'http://gstaticontent.com/images/AbKwJKeitPkOb7iAE1P1dEkVCP1_big.jpg'),
(37879, 2633, 'Cidade dos Mortos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126633.mp4', 'http://gstaticontent.com/images/AbKwJKeitPkOb7iAE1P1dEkVCP1_big.jpg'),
(37880, 2634, 'The Fall S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182670.mp4', 'http://timg.bdta.pro/images/8e4bb3f456578db72f2d0aa650cd0e8c.jpg'),
(37881, 2634, 'The Fall S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182671.mp4', 'http://timg.bdta.pro/images/7c4c985f4074d9ba1e12cb6b22784382.jpg'),
(37882, 2634, 'The Fall S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182672.mp4', 'http://timg.bdta.pro/images/e36d98026903e277120379181e38998a.jpg'),
(37883, 2634, 'The Fall S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182673.mp4', 'http://timg.bdta.pro/images/7d12b9eb0c89faae3b33d998c88cc645.jpg'),
(37884, 2634, 'The Fall S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182674.mp4', 'http://timg.bdta.pro/images/6d314c790c0894863d6b4b98b927bcdb.jpg'),
(37885, 2635, 'The Fall S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182675.mp4', 'http://timg.bdta.pro/images/8f713ff0fa3a638d2384dffe885e9caf.jpg'),
(37886, 2635, 'The Fall S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182676.mp4', 'http://timg.bdta.pro/images/10309c5ff5972deec9f9e4a79846e7d9.jpg'),
(37887, 2635, 'The Fall S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182677.mp4', 'http://timg.bdta.pro/images/2a51259a901d2db937fcffa260088eed.jpg'),
(37888, 2635, 'The Fall S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182678.mp4', 'http://timg.bdta.pro/images/65743009e35c0dbf93cc4375353ae631.jpg'),
(37889, 2635, 'The Fall S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182679.mp4', 'http://timg.bdta.pro/images/8efb4d607c1ce0ca96d26323796b5789.jpg'),
(37890, 2635, 'The Fall S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182680.mp4', 'http://timg.bdta.pro/images/ce9a91ca0bcd45e48a31215807f7973d.jpg'),
(37891, 2636, 'The Fall S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182681.mp4', 'http://timg.bdta.pro/images/afc3939ef0b7304b750fcf8529140838.jpg'),
(37892, 2636, 'The Fall S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182682.mp4', 'http://timg.bdta.pro/images/6bd4329361325c1c25e177a047c76091.jpg'),
(37893, 2636, 'The Fall S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182683.mp4', 'http://timg.bdta.pro/images/7f48f964b0e5f821f53d2879be2f3398.jpg'),
(37894, 2636, 'The Fall S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182684.mp4', 'http://timg.bdta.pro/images/939244634a53dc591e91890e67654563.jpg'),
(37895, 2636, 'The Fall S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182685.mp4', 'http://timg.bdta.pro/images/19fdd627a47ec2fdcd08c2bf08ded634.jpg'),
(37896, 2636, 'The Fall S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182686.mp4', 'http://timg.bdta.pro/images/9dce499ce74e92a3b0bcac0e7e32bc01.jpg'),
(37897, 2637, 'Sob Pressao Plantao COVID S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/133947.mp4', 'http://timg.bdta.pro/images/695ccae1f804cfb6cf03b0e3f5665581.jpg'),
(37898, 2637, 'Sob Pressao Plantao COVID S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/133948.mp4', 'http://timg.bdta.pro/images/8fb6a2872cdf7213edfc66bc47b701b5.jpg'),
(37899, 2638, 'Menu Selvagem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126620.mp4', 'http://gstaticontent.com/images/Ao9If5oIF6Dts9LIfKbQhUK8j7X_big.jpg'),
(37900, 2638, 'Menu Selvagem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126621.mp4', 'http://gstaticontent.com/images/Ao9If5oIF6Dts9LIfKbQhUK8j7X_big.jpg'),
(37901, 2638, 'Menu Selvagem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126622.mp4', 'http://gstaticontent.com/images/Ao9If5oIF6Dts9LIfKbQhUK8j7X_big.jpg'),
(37902, 2638, 'Menu Selvagem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126623.mp4', 'http://gstaticontent.com/images/Ao9If5oIF6Dts9LIfKbQhUK8j7X_big.jpg'),
(37903, 2638, 'Menu Selvagem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126624.mp4', 'http://gstaticontent.com/images/Ao9If5oIF6Dts9LIfKbQhUK8j7X_big.jpg'),
(37904, 2638, 'Menu Selvagem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126625.mp4', 'http://gstaticontent.com/images/Ao9If5oIF6Dts9LIfKbQhUK8j7X_big.jpg'),
(37905, 2639, 'Rainha da Cocada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126591.mp4', 'http://gstaticontent.com/images/zCTVleTrsYuyG2SUyNNrq1EdW8l_big.jpg'),
(37906, 2639, 'Rainha da Cocada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126592.mp4', 'http://gstaticontent.com/images/zCTVleTrsYuyG2SUyNNrq1EdW8l_big.jpg'),
(37907, 2639, 'Rainha da Cocada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126593.mp4', 'http://gstaticontent.com/images/zCTVleTrsYuyG2SUyNNrq1EdW8l_big.jpg'),
(37908, 2639, 'Rainha da Cocada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126594.mp4', 'http://gstaticontent.com/images/zCTVleTrsYuyG2SUyNNrq1EdW8l_big.jpg'),
(37909, 2639, 'Rainha da Cocada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/126595.mp4', 'http://gstaticontent.com/images/zCTVleTrsYuyG2SUyNNrq1EdW8l_big.jpg'),
(37910, 2639, 'Rainha da Cocada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/126596.mp4', 'http://gstaticontent.com/images/zCTVleTrsYuyG2SUyNNrq1EdW8l_big.jpg'),
(37911, 2639, 'Rainha da Cocada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/126597.mp4', 'http://gstaticontent.com/images/zCTVleTrsYuyG2SUyNNrq1EdW8l_big.jpg'),
(37912, 2639, 'Rainha da Cocada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/126598.mp4', 'http://gstaticontent.com/images/zCTVleTrsYuyG2SUyNNrq1EdW8l_big.jpg'),
(37913, 2639, 'Rainha da Cocada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/126599.mp4', 'http://gstaticontent.com/images/zCTVleTrsYuyG2SUyNNrq1EdW8l_big.jpg'),
(37914, 2639, 'Rainha da Cocada S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/126600.mp4', 'http://gstaticontent.com/images/zCTVleTrsYuyG2SUyNNrq1EdW8l_big.jpg'),
(37915, 2639, 'Rainha da Cocada S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/126601.mp4', 'http://gstaticontent.com/images/zCTVleTrsYuyG2SUyNNrq1EdW8l_big.jpg'),
(37916, 2639, 'Rainha da Cocada S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/126602.mp4', 'http://gstaticontent.com/images/zCTVleTrsYuyG2SUyNNrq1EdW8l_big.jpg'),
(37917, 2639, 'Rainha da Cocada S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/126603.mp4', 'http://gstaticontent.com/images/zCTVleTrsYuyG2SUyNNrq1EdW8l_big.jpg'),
(37918, 2639, 'Rainha da Cocada S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/126604.mp4', 'http://gstaticontent.com/images/zCTVleTrsYuyG2SUyNNrq1EdW8l_big.jpg'),
(37919, 2639, 'Rainha da Cocada S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/126605.mp4', 'http://gstaticontent.com/images/zCTVleTrsYuyG2SUyNNrq1EdW8l_big.jpg'),
(37920, 2639, 'Rainha da Cocada S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/126606.mp4', 'http://gstaticontent.com/images/zCTVleTrsYuyG2SUyNNrq1EdW8l_big.jpg'),
(37921, 2639, 'Rainha da Cocada S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/126607.mp4', 'http://gstaticontent.com/images/zCTVleTrsYuyG2SUyNNrq1EdW8l_big.jpg'),
(37922, 2639, 'Rainha da Cocada S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/126608.mp4', 'http://gstaticontent.com/images/zCTVleTrsYuyG2SUyNNrq1EdW8l_big.jpg'),
(37923, 2639, 'Rainha da Cocada S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/126609.mp4', 'http://gstaticontent.com/images/zCTVleTrsYuyG2SUyNNrq1EdW8l_big.jpg'),
(37924, 2639, 'Rainha da Cocada S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/126610.mp4', 'http://gstaticontent.com/images/zCTVleTrsYuyG2SUyNNrq1EdW8l_big.jpg'),
(37925, 2640, 'O Que Querem As Mulheres S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126587.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(37926, 2640, 'O Que Querem As Mulheres S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126588.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(37927, 2640, 'O Que Querem As Mulheres S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126589.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(37928, 2640, 'O Que Querem As Mulheres S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126590.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(37929, 2641, 'Bancroft [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126580.mp4', 'http://timg.bdta.pro/images/6256b7a5e238ba13e547d168d6787591.jpg'),
(37930, 2641, 'Bancroft [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126581.mp4', 'http://timg.bdta.pro/images/85db127b78c179c6199042925059b489.jpg'),
(37931, 2641, 'Bancroft [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126582.mp4', 'http://timg.bdta.pro/images/6728ba7e791facbfacbaee3376bbefd7.jpg'),
(37932, 2641, 'Bancroft [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/126583.mp4', 'http://timg.bdta.pro/images/bc8f33c94d53e5abc7e2fd55f6875fef.jpg'),
(37933, 2642, 'Bancroft [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/126584.mp4', 'http://timg.bdta.pro/images/445b0d7f5113c6dfc91028ed1197e305.jpg'),
(37934, 2642, 'Bancroft [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/126585.mp4', 'http://timg.bdta.pro/images/6b30305ed0f5d1ef0c618fe43862a27b.jpg'),
(37935, 2642, 'Bancroft [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/126586.mp4', 'http://timg.bdta.pro/images/77697d2cdd179202526f1e93b7223e44.jpg'),
(37936, 2643, 'Woke [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134802.mp4', 'http://timg.bdta.pro/images/c2aac947c6e0c17d6696424a33d5ba3b.jpg'),
(37937, 2643, 'Woke [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134803.mp4', 'http://timg.bdta.pro/images/2907421d000e0db52b5e446764ad01e8.jpg'),
(37938, 2643, 'Woke [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134804.mp4', 'http://timg.bdta.pro/images/d7b06c1b378a4982f4ac065312f00f3f.jpg'),
(37939, 2643, 'Woke [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134805.mp4', 'http://timg.bdta.pro/images/c3e1cc46f80284adb17dd5315151560a.jpg'),
(37940, 2643, 'Woke [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134806.mp4', 'http://gstaticontent.com/images/iYG9jehElgXDEl6aBJpeOyaSErw_big.jpg'),
(37941, 2643, 'Woke [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134807.mp4', 'http://gstaticontent.com/images/iYG9jehElgXDEl6aBJpeOyaSErw_big.jpg'),
(37942, 2643, 'Woke [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134808.mp4', 'http://gstaticontent.com/images/iYG9jehElgXDEl6aBJpeOyaSErw_big.jpg'),
(37943, 2643, 'Woke [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134809.mp4', 'http://timg.bdta.pro/images/1c251c651da2d300da203f66aaca4a5d.jpg'),
(37944, 2644, 'Sailor Moon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134602.mp4', 'http://timg.bdta.pro/images/55deda0a302145cf883ab12c95c3ce48.jpg'),
(37945, 2644, 'Sailor Moon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134603.mp4', 'http://timg.bdta.pro/images/61e5e04b296ad4ee414294507e2f2875.jpg'),
(37946, 2644, 'Sailor Moon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134604.mp4', 'http://timg.bdta.pro/images/c3ed053ba3787c1dab9187fc9b2166cd.jpg'),
(37947, 2644, 'Sailor Moon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134605.mp4', 'http://timg.bdta.pro/images/9b7f57be40198c1e274e33a6c1416c24.jpg'),
(37948, 2644, 'Sailor Moon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134606.mp4', 'http://timg.bdta.pro/images/27cbc94b46ce9f6cbd0414217992d3d5.jpg'),
(37949, 2644, 'Sailor Moon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134607.mp4', 'http://timg.bdta.pro/images/d6ce4721507f3a48b62f1d2196ff896e.jpg'),
(37950, 2644, 'Sailor Moon S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134608.mp4', 'http://timg.bdta.pro/images/12fc9ab6057f98b74f7cb99e4e815ee7.jpg'),
(37951, 2644, 'Sailor Moon S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134609.mp4', 'http://timg.bdta.pro/images/a78933e50bdd713d30d517d3fc75a348.jpg'),
(37952, 2644, 'Sailor Moon S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/134610.mp4', 'http://timg.bdta.pro/images/5a5b86d4f091ab92a1d3b1f3baaf1395.jpg'),
(37953, 2644, 'Sailor Moon S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/134611.mp4', 'http://timg.bdta.pro/images/7e3245e4c581b9be57cb6d6ec4ecd958.jpg'),
(37954, 2644, 'Sailor Moon S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/134612.mp4', 'http://timg.bdta.pro/images/31df143154e0226064513e2960f3c42b.jpg'),
(37955, 2644, 'Sailor Moon S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/134613.mp4', 'http://timg.bdta.pro/images/228fb1d6055fbd2c48fcab59c4ff70ef.jpg'),
(37956, 2644, 'Sailor Moon S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/134614.mp4', 'http://timg.bdta.pro/images/61343fc38a4b81b111b735708bad572c.jpg'),
(37957, 2644, 'Sailor Moon S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/134615.mp4', 'http://timg.bdta.pro/images/0ee023aac2456a05c565e05b18fdfc9a.jpg'),
(37958, 2644, 'Sailor Moon S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/134616.mp4', 'http://timg.bdta.pro/images/59e9baea71b8cd743478fcc297cf1e72.jpg'),
(37959, 2644, 'Sailor Moon S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/134617.mp4', 'http://timg.bdta.pro/images/80f00b1ebb45137ba63f1623330852f4.jpg'),
(37960, 2644, 'Sailor Moon S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/134618.mp4', 'http://timg.bdta.pro/images/faf8072e3758f586bd41cd4d29bf38a0.jpg'),
(37961, 2644, 'Sailor Moon S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/134619.mp4', 'http://timg.bdta.pro/images/a38b06c9287e17fac6420719d552c28c.jpg'),
(37962, 2644, 'Sailor Moon S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/134620.mp4', 'http://timg.bdta.pro/images/9f2cfddddbf7be1bc0b0d29140d886cc.jpg'),
(37963, 2644, 'Sailor Moon S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/134621.mp4', 'http://timg.bdta.pro/images/06324ee31df816b6deb7e9cc6afdaf45.jpg'),
(37964, 2644, 'Sailor Moon S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/134622.mp4', 'http://timg.bdta.pro/images/17a1ccbe1a7de60f8ce52073a9a22110.jpg'),
(37965, 2644, 'Sailor Moon S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/134623.mp4', 'http://timg.bdta.pro/images/a1e830cd6e92326b779810c0bc65b84f.jpg'),
(37966, 2644, 'Sailor Moon S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/134624.mp4', 'http://timg.bdta.pro/images/66680707d494fe2349eeff3091fb3685.jpg'),
(37967, 2644, 'Sailor Moon S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/134625.mp4', 'http://timg.bdta.pro/images/de55e70cd054f1534e5beef8ffcca94e.jpg'),
(37968, 2644, 'Sailor Moon S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/134626.mp4', 'http://timg.bdta.pro/images/987b913fc1d22b545836781854e2c7a1.jpg'),
(37969, 2644, 'Sailor Moon S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/134627.mp4', 'http://timg.bdta.pro/images/a89a206364db656d9a1eaabcf02e8b13.jpg'),
(37970, 2644, 'Sailor Moon S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/134628.mp4', 'http://timg.bdta.pro/images/634b16acd1f31ad94e8e7940e85ea580.jpg'),
(37971, 2644, 'Sailor Moon S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/134629.mp4', 'http://timg.bdta.pro/images/154ab769f2506784664ec72aebdabbac.jpg'),
(37972, 2644, 'Sailor Moon S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/134630.mp4', 'http://timg.bdta.pro/images/0a9fd3d23ca7f659fa2d3d2ee4dc077f.jpg'),
(37973, 2644, 'Sailor Moon S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/134631.mp4', 'http://timg.bdta.pro/images/c8949c71311ed7bd10b09879e1ea8bc2.jpg'),
(37974, 2644, 'Sailor Moon S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/134632.mp4', 'http://timg.bdta.pro/images/82d7b261120aad84080470697cf3c869.jpg'),
(37975, 2644, 'Sailor Moon S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/134633.mp4', 'http://timg.bdta.pro/images/e067ad3ccd019e0c409b564530071bf5.jpg'),
(37976, 2644, 'Sailor Moon S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/134634.mp4', 'http://timg.bdta.pro/images/330fff005e79a66bed46793913b759ac.jpg'),
(37977, 2644, 'Sailor Moon S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/134635.mp4', 'http://timg.bdta.pro/images/dd2b907ccf196509fce406903cee15b2.jpg'),
(37978, 2644, 'Sailor Moon S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/134636.mp4', 'http://timg.bdta.pro/images/176b2945bc3c12b7103855ec9047983d.jpg'),
(37979, 2644, 'Sailor Moon S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/134637.mp4', 'http://timg.bdta.pro/images/23d9d00d0970c190ae7f09be0c4b2c81.jpg'),
(37980, 2644, 'Sailor Moon S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/134638.mp4', 'http://timg.bdta.pro/images/26302cd49218029eeebca450b2b6fbf3.jpg'),
(37981, 2644, 'Sailor Moon S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/134639.mp4', 'http://timg.bdta.pro/images/f6792ec4e615eda39e9742e7e537057a.jpg'),
(37982, 2644, 'Sailor Moon S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/134640.mp4', 'http://timg.bdta.pro/images/1cfedb6b83e872c8e5ae92e8c7e727c8.jpg'),
(37983, 2644, 'Sailor Moon S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/134641.mp4', 'http://timg.bdta.pro/images/02b72b956f03560fa4b974f4f10df7a1.jpg'),
(37984, 2644, 'Sailor Moon S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/134642.mp4', 'http://timg.bdta.pro/images/98f4feae1d0ab5602b607331f1bd8d46.jpg'),
(37985, 2644, 'Sailor Moon S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/134643.mp4', 'http://timg.bdta.pro/images/5d3b4e83b4f363b7065b4a9cc4243c57.jpg'),
(37986, 2644, 'Sailor Moon S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/134644.mp4', 'http://timg.bdta.pro/images/73587360485f005160d80276be9fc117.jpg'),
(37987, 2644, 'Sailor Moon S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/134645.mp4', 'http://timg.bdta.pro/images/5eebca8cc6d5cd64096b9c731f5b89b6.jpg'),
(37988, 2644, 'Sailor Moon S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/134646.mp4', 'http://timg.bdta.pro/images/036836495cb57c418c34659bfff3f936.jpg'),
(37989, 2644, 'Sailor Moon S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/134647.mp4', 'http://timg.bdta.pro/images/5dba30ad640216d81233fc33e939a381.jpg'),
(37990, 2645, 'Sailor Moon S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134648.mp4', 'http://timg.bdta.pro/images/66c80139cd0eb22ec8309bd4d3a365da.jpg'),
(37991, 2645, 'Sailor Moon S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134649.mp4', 'http://timg.bdta.pro/images/0719810b8a8362854f68e46f6a97d598.jpg'),
(37992, 2645, 'Sailor Moon S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134650.mp4', 'http://timg.bdta.pro/images/8244658144ac8509789cf888983540e5.jpg'),
(37993, 2645, 'Sailor Moon S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134651.mp4', 'http://timg.bdta.pro/images/46770c226e05496b53d90e33a4f71529.jpg'),
(37994, 2645, 'Sailor Moon S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134652.mp4', 'http://timg.bdta.pro/images/7934ad3751e1ba4e96c3fc27c24eb6e7.jpg'),
(37995, 2645, 'Sailor Moon S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134653.mp4', 'http://timg.bdta.pro/images/03926639952a042b33c670dbc86c408b.jpg'),
(37996, 2645, 'Sailor Moon S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134654.mp4', 'http://timg.bdta.pro/images/b21be68febb3971ba9a47191f3cb56cd.jpg'),
(37997, 2645, 'Sailor Moon S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134655.mp4', 'http://timg.bdta.pro/images/a7aea5c9508e026fbb3c774c824e81f4.jpg'),
(37998, 2645, 'Sailor Moon S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/134656.mp4', 'http://timg.bdta.pro/images/8020d24e657cdaa61bfb25c6ea2464a1.jpg'),
(37999, 2645, 'Sailor Moon S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/134657.mp4', 'http://timg.bdta.pro/images/e4eb8f0efbec9d3585682ac902d83a3f.jpg'),
(38000, 2645, 'Sailor Moon S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/134658.mp4', 'http://timg.bdta.pro/images/13718c8e1bdb8292a2a2ed975ea33041.jpg'),
(38001, 2645, 'Sailor Moon S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/134659.mp4', 'http://timg.bdta.pro/images/e2ad57db6c83bf3bb56746438d1c3424.jpg'),
(38002, 2645, 'Sailor Moon S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/134660.mp4', 'http://timg.bdta.pro/images/24e436f864f28e0096785c4dd21f9894.jpg'),
(38003, 2645, 'Sailor Moon S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/134661.mp4', 'http://timg.bdta.pro/images/469b68efd8be69304936572693db954d.jpg'),
(38004, 2645, 'Sailor Moon S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/134662.mp4', 'http://timg.bdta.pro/images/1ec8c6a0d67e0ef158c849024b305204.jpg'),
(38005, 2645, 'Sailor Moon S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/134663.mp4', 'http://timg.bdta.pro/images/3d8da788c14b4c54c317fe1527ab69c7.jpg'),
(38006, 2645, 'Sailor Moon S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/134664.mp4', 'http://timg.bdta.pro/images/9d317be945bcaa37bec9a9569a2a0a93.jpg'),
(38007, 2645, 'Sailor Moon S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/134665.mp4', 'http://timg.bdta.pro/images/d3093c216518b718256b460d9c2da5ea.jpg'),
(38008, 2645, 'Sailor Moon S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/134666.mp4', 'http://timg.bdta.pro/images/d4b94f3a6f955106f4d2b40789de6ff5.jpg'),
(38009, 2645, 'Sailor Moon S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/134667.mp4', 'http://timg.bdta.pro/images/e16f603fc5fbd3baf4e323434f8ea06d.jpg'),
(38010, 2645, 'Sailor Moon S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/134668.mp4', 'http://timg.bdta.pro/images/5d5b22754a2e671e05f11bede3e094a9.jpg'),
(38011, 2645, 'Sailor Moon S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/134669.mp4', 'http://timg.bdta.pro/images/2a6f90f919963f3f41c4d16ddb2343fa.jpg'),
(38012, 2645, 'Sailor Moon S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/134670.mp4', 'http://timg.bdta.pro/images/fb9bf8ff5ea39c8b51abe3b6a92b270f.jpg'),
(38013, 2645, 'Sailor Moon S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/134671.mp4', 'http://timg.bdta.pro/images/fe06943e9072e3534f1ffaa434c00ba6.jpg'),
(38014, 2645, 'Sailor Moon S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/134672.mp4', 'http://timg.bdta.pro/images/8eaada34230fc9bbfe81ec6bd32a636d.jpg'),
(38015, 2645, 'Sailor Moon S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/134673.mp4', 'http://timg.bdta.pro/images/7192605a6edf2a9501376dd2b664770e.jpg'),
(38016, 2645, 'Sailor Moon S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/134674.mp4', 'http://timg.bdta.pro/images/75368a0c75eae2871670575dd732edd4.jpg'),
(38017, 2645, 'Sailor Moon S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/134675.mp4', 'http://timg.bdta.pro/images/db1b45fd6648c6e317dc3d866fb62117.jpg'),
(38018, 2645, 'Sailor Moon S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/134676.mp4', 'http://timg.bdta.pro/images/5fe3c5ff0ea98dd00d72fafa0bc3071f.jpg'),
(38019, 2645, 'Sailor Moon S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/134677.mp4', 'http://timg.bdta.pro/images/9037419cbed7d33b72960e3af4123f6a.jpg'),
(38020, 2645, 'Sailor Moon S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/134678.mp4', 'http://timg.bdta.pro/images/fec5c99c6db746821fdf540664808505.jpg'),
(38021, 2645, 'Sailor Moon S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/134679.mp4', 'http://timg.bdta.pro/images/3492d9915fd68d3e8116550ee4113367.jpg'),
(38022, 2645, 'Sailor Moon S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/134680.mp4', 'http://timg.bdta.pro/images/5906c7f1a302cf3081cffef623c377e6.jpg'),
(38023, 2645, 'Sailor Moon S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/134681.mp4', 'http://timg.bdta.pro/images/d90e973d38581a19d15fb83205f3250a.jpg'),
(38024, 2645, 'Sailor Moon S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/134682.mp4', 'http://timg.bdta.pro/images/c15e14a8347d9ef67b3632d28bdd4566.jpg'),
(38025, 2645, 'Sailor Moon S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/134683.mp4', 'http://timg.bdta.pro/images/34427d19ad14860724f589dce0812c7a.jpg'),
(38026, 2645, 'Sailor Moon S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/134684.mp4', 'http://timg.bdta.pro/images/e75704b7039bf084477792dcfa936611.jpg'),
(38027, 2645, 'Sailor Moon S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/134685.mp4', 'http://timg.bdta.pro/images/0f9c8b2c056bd89d73b7cd36e492c2b1.jpg'),
(38028, 2645, 'Sailor Moon S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/134686.mp4', 'http://timg.bdta.pro/images/418d8b8613e880b40042f050119a56d5.jpg'),
(38029, 2645, 'Sailor Moon S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/134687.mp4', 'http://timg.bdta.pro/images/9e9d014a7e0590d751363763ef1f8fd5.jpg'),
(38030, 2645, 'Sailor Moon S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/134688.mp4', 'http://timg.bdta.pro/images/8f7214c27bb921de94dde00c37236af4.jpg'),
(38031, 2645, 'Sailor Moon S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/134689.mp4', 'http://timg.bdta.pro/images/cbd762de873d27d9dcb1d0a43c591655.jpg'),
(38032, 2645, 'Sailor Moon S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/134690.mp4', 'http://timg.bdta.pro/images/89bd3c25b83bc31f7b42da033eac1fe5.jpg'),
(38033, 2646, 'Sailor Moon S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134691.mp4', 'http://timg.bdta.pro/images/6229be4a3136d19233ed3db2c1e53f1b.jpg'),
(38034, 2646, 'Sailor Moon S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134692.mp4', 'http://timg.bdta.pro/images/e65fe8acfe887594b26d153237995299.jpg'),
(38035, 2646, 'Sailor Moon S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134693.mp4', 'http://timg.bdta.pro/images/2b65bcb00ef62f179f47563f86fc8ec7.jpg'),
(38036, 2646, 'Sailor Moon S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134694.mp4', 'http://timg.bdta.pro/images/e8daed130bfd563705b0fde422c7ee41.jpg'),
(38037, 2646, 'Sailor Moon S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134695.mp4', 'http://timg.bdta.pro/images/07220aea30909fc3e2bbf25c8bcf0467.jpg'),
(38038, 2646, 'Sailor Moon S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134696.mp4', 'http://timg.bdta.pro/images/16aa90eebae2d9b6d1f587b742a19972.jpg'),
(38039, 2646, 'Sailor Moon S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134697.mp4', 'http://timg.bdta.pro/images/e963c67f85fd1e33e462953476183fd1.jpg'),
(38040, 2646, 'Sailor Moon S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134698.mp4', 'http://timg.bdta.pro/images/d0fcc10e1d03119c5cfb7a99fd3d9202.jpg'),
(38041, 2646, 'Sailor Moon S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/134699.mp4', 'http://timg.bdta.pro/images/806527aa54469e19a48f875f422b9814.jpg'),
(38042, 2646, 'Sailor Moon S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/134700.mp4', 'http://timg.bdta.pro/images/16b4bdd4bf3dffca23b75a877f2cac8e.jpg'),
(38043, 2646, 'Sailor Moon S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/134701.mp4', 'http://timg.bdta.pro/images/77f48efdff648fe0d1869e54c321a30c.jpg'),
(38044, 2646, 'Sailor Moon S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/134702.mp4', 'http://timg.bdta.pro/images/01b9b56c2d730b403f8261782c2d4a5d.jpg'),
(38045, 2646, 'Sailor Moon S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/134703.mp4', 'http://timg.bdta.pro/images/fb2c1327adfdb6270b96fd2afc913143.jpg'),
(38046, 2646, 'Sailor Moon S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/134704.mp4', 'http://timg.bdta.pro/images/c800565289135217b0b4c1293dbf9b02.jpg'),
(38047, 2646, 'Sailor Moon S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/134705.mp4', 'http://timg.bdta.pro/images/a8f2c03b11bce0bb567ac310e9fdbfdf.jpg'),
(38048, 2646, 'Sailor Moon S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/134706.mp4', 'http://timg.bdta.pro/images/8251336446cbec04e1b96c0559e15a90.jpg'),
(38049, 2646, 'Sailor Moon S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/134707.mp4', 'http://timg.bdta.pro/images/6a1cdd9851547315087e4933ba0a0f89.jpg'),
(38050, 2646, 'Sailor Moon S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/134708.mp4', 'http://timg.bdta.pro/images/27e31ef035d06ebe34f89b42ae338570.jpg'),
(38051, 2646, 'Sailor Moon S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/134709.mp4', 'http://timg.bdta.pro/images/cd7c1d5259301d739729e7a13bd4a5b1.jpg'),
(38052, 2646, 'Sailor Moon S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/134710.mp4', 'http://timg.bdta.pro/images/48968b5008e11ffef6b0df941d93a3dc.jpg'),
(38053, 2646, 'Sailor Moon S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/134711.mp4', 'http://timg.bdta.pro/images/6bc1d2d9fae1d7b5982b3f2e0c19ab93.jpg'),
(38054, 2646, 'Sailor Moon S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/134712.mp4', 'http://timg.bdta.pro/images/a12a7d0d3303c75cde27673be141c539.jpg'),
(38055, 2646, 'Sailor Moon S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/134713.mp4', 'http://timg.bdta.pro/images/95c3213915728f59072f6b4404ce8608.jpg'),
(38056, 2646, 'Sailor Moon S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/134714.mp4', 'http://timg.bdta.pro/images/40b84d92a01478d999b06ad5c185a15f.jpg'),
(38057, 2646, 'Sailor Moon S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/134715.mp4', 'http://timg.bdta.pro/images/ce74ce9c0234ce1d37b3c92e58beb5d5.jpg'),
(38058, 2646, 'Sailor Moon S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/134716.mp4', 'http://timg.bdta.pro/images/55239e0ca6d369f7052e420109ee430d.jpg'),
(38059, 2646, 'Sailor Moon S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/134717.mp4', 'http://timg.bdta.pro/images/2d5289a42ca5dedd0b1da249db045e2a.jpg'),
(38060, 2646, 'Sailor Moon S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/134718.mp4', 'http://timg.bdta.pro/images/8cee34424338d09de696354677452ea4.jpg'),
(38061, 2646, 'Sailor Moon S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/134719.mp4', 'http://timg.bdta.pro/images/eecadf305c992d513c1a0393d70e3e8a.jpg'),
(38062, 2646, 'Sailor Moon S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/134720.mp4', 'http://timg.bdta.pro/images/3c10b1c9a35403605a6feb41c08275eb.jpg'),
(38063, 2646, 'Sailor Moon S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/134721.mp4', 'http://timg.bdta.pro/images/4e9a164b792c5f9e88ed9201ee749625.jpg'),
(38064, 2646, 'Sailor Moon S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/134722.mp4', 'http://timg.bdta.pro/images/187ce08bfeacf03aa9faabda52b2e418.jpg'),
(38065, 2646, 'Sailor Moon S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/134723.mp4', 'http://timg.bdta.pro/images/182f8b89b94c1eb2c6fe5c0ca2d5a783.jpg'),
(38066, 2646, 'Sailor Moon S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/134724.mp4', 'http://timg.bdta.pro/images/fbba362e46e27e9513b31f636f327544.jpg'),
(38067, 2646, 'Sailor Moon S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/134725.mp4', 'http://timg.bdta.pro/images/02e260c5eaa609b9e7e663e32136cc70.jpg'),
(38068, 2646, 'Sailor Moon S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/134726.mp4', 'http://timg.bdta.pro/images/7fa331623f86d67d75bcbab428f33869.jpg'),
(38069, 2646, 'Sailor Moon S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/134727.mp4', 'http://timg.bdta.pro/images/a7e30449364eeabee6991346420366a9.jpg'),
(38070, 2646, 'Sailor Moon S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/134728.mp4', 'http://timg.bdta.pro/images/c363d3538c7c3d052414b01c17ee06e0.jpg'),
(38071, 2647, 'Sailor Moon S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134729.mp4', 'http://timg.bdta.pro/images/a5fce08937d9b8c14e775bb80ed10b0c.jpg'),
(38072, 2647, 'Sailor Moon S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134730.mp4', 'http://timg.bdta.pro/images/ba4c151d960d9965adb6b6854cda1a50.jpg'),
(38073, 2647, 'Sailor Moon S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134731.mp4', 'http://timg.bdta.pro/images/246d8126fe134e05f811bccc81371690.jpg'),
(38074, 2647, 'Sailor Moon S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134732.mp4', 'http://timg.bdta.pro/images/e370b6fef3269cb39b57f0d719027dfa.jpg'),
(38075, 2647, 'Sailor Moon S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134733.mp4', 'http://timg.bdta.pro/images/0049bfe52709661df0efbee6ae021248.jpg'),
(38076, 2647, 'Sailor Moon S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134734.mp4', 'http://timg.bdta.pro/images/2589ce00f9e7d247d25a98058c7bf2f6.jpg'),
(38077, 2647, 'Sailor Moon S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134735.mp4', 'http://timg.bdta.pro/images/4c8b89da36718d588d76e2602cd18883.jpg'),
(38078, 2647, 'Sailor Moon S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134736.mp4', 'http://timg.bdta.pro/images/19d3ae146f5fe3153038601da8710c8f.jpg'),
(38079, 2647, 'Sailor Moon S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/134737.mp4', 'http://timg.bdta.pro/images/c03b01e68395b309fde2004b968b366f.jpg'),
(38080, 2647, 'Sailor Moon S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/134738.mp4', 'http://timg.bdta.pro/images/06c2fbeb0fc762e36ec54b5980dcd385.jpg'),
(38081, 2647, 'Sailor Moon S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/134739.mp4', 'http://timg.bdta.pro/images/683d77768869e80d193a45f38fb2781f.jpg'),
(38082, 2647, 'Sailor Moon S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/134740.mp4', 'http://timg.bdta.pro/images/280016ecb66f6c0ea8fb435de2dd1637.jpg'),
(38083, 2647, 'Sailor Moon S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/134741.mp4', 'http://timg.bdta.pro/images/859e00eda5c4046483c261d3bd86efca.jpg'),
(38084, 2647, 'Sailor Moon S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/134742.mp4', 'http://timg.bdta.pro/images/96c364e5865ce87efca9f7b498c97cfa.jpg'),
(38085, 2647, 'Sailor Moon S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/134743.mp4', 'http://timg.bdta.pro/images/2ab3e4f093cfeae887b490c48ded0f0e.jpg'),
(38086, 2647, 'Sailor Moon S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/134744.mp4', 'http://timg.bdta.pro/images/953707bfeef171ad6310733cfaecf2ff.jpg'),
(38087, 2647, 'Sailor Moon S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/134745.mp4', 'http://timg.bdta.pro/images/ad97fa1438b5bc1a264c0f1c72b58c89.jpg'),
(38088, 2647, 'Sailor Moon S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/134746.mp4', 'http://timg.bdta.pro/images/41aab1bd8e9861c1f610c2e4610b9af6.jpg'),
(38089, 2647, 'Sailor Moon S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/134747.mp4', 'http://timg.bdta.pro/images/4ddd79f24d94edcb1557b55f30cb27dc.jpg'),
(38090, 2647, 'Sailor Moon S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/134748.mp4', 'http://timg.bdta.pro/images/3fa8362f8b0d4a9436c92633bca98c88.jpg'),
(38091, 2647, 'Sailor Moon S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/134749.mp4', 'http://timg.bdta.pro/images/ff4390a7557c1d028bc5c8af1768b19b.jpg'),
(38092, 2647, 'Sailor Moon S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/134750.mp4', 'http://timg.bdta.pro/images/3f729a76ccdecec17665bb570c602f25.jpg'),
(38093, 2647, 'Sailor Moon S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/134751.mp4', 'http://timg.bdta.pro/images/7d27e1ce13bb237f82ecf130b90fd21b.jpg'),
(38094, 2647, 'Sailor Moon S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/134752.mp4', 'http://timg.bdta.pro/images/f8fac35914f56c543485d609045a44b5.jpg'),
(38095, 2647, 'Sailor Moon S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/134753.mp4', 'http://timg.bdta.pro/images/3a041f26763b5d613e22a64b4b1c140a.jpg'),
(38096, 2647, 'Sailor Moon S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/134754.mp4', 'http://timg.bdta.pro/images/03c6e7ecd90b514736624ba31282f399.jpg'),
(38097, 2647, 'Sailor Moon S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/134755.mp4', 'http://timg.bdta.pro/images/93bb9d5a7e01c2d2c390c124044ec182.jpg'),
(38098, 2647, 'Sailor Moon S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/134756.mp4', 'http://timg.bdta.pro/images/4c3037b2358b438830e66d7c726e48ab.jpg'),
(38099, 2647, 'Sailor Moon S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/134757.mp4', 'http://timg.bdta.pro/images/6ca187843d803af73d08e4589a52bddd.jpg'),
(38100, 2647, 'Sailor Moon S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/134758.mp4', 'http://timg.bdta.pro/images/62e01610110ff4fbb1114d671d3a0ca7.jpg'),
(38101, 2647, 'Sailor Moon S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/134759.mp4', 'http://timg.bdta.pro/images/b1c635c9d84872aaac6bac56e40e6595.jpg'),
(38102, 2647, 'Sailor Moon S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/134760.mp4', 'http://timg.bdta.pro/images/41e3d430e988d93f2309e7ffc07a3137.jpg'),
(38103, 2647, 'Sailor Moon S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/134761.mp4', 'http://timg.bdta.pro/images/ac185e506a8424acf5a84f681013de9b.jpg'),
(38104, 2647, 'Sailor Moon S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/134762.mp4', 'http://timg.bdta.pro/images/d03d0cb2195d81e690cc2d534db96700.jpg'),
(38105, 2647, 'Sailor Moon S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/134763.mp4', 'http://timg.bdta.pro/images/f2c49d12cfc75daf350e83a44cb16c65.jpg'),
(38106, 2647, 'Sailor Moon S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/134764.mp4', 'http://timg.bdta.pro/images/772a91477b20cb0765bc64211b1c4c7f.jpg'),
(38107, 2647, 'Sailor Moon S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/134765.mp4', 'http://timg.bdta.pro/images/dc155a07803892aaa9aa146da7dbcca1.jpg'),
(38108, 2647, 'Sailor Moon S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/134766.mp4', 'http://timg.bdta.pro/images/8e42938e84f6736f75352dba1b0d5842.jpg'),
(38109, 2647, 'Sailor Moon S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/134767.mp4', 'http://timg.bdta.pro/images/303ca26af24eed78ecd9167a303d92da.jpg'),
(38110, 2648, 'Sailor Moon S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134768.mp4', 'http://timg.bdta.pro/images/23f31663d5b0602e3d02c178c1c784aa.jpg'),
(38111, 2648, 'Sailor Moon S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134769.mp4', 'http://timg.bdta.pro/images/a982d77bb874f801715da035f809e7b6.jpg'),
(38112, 2648, 'Sailor Moon S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134770.mp4', 'http://timg.bdta.pro/images/23927b85c8c4f61f3f38ca6662d3e75e.jpg'),
(38113, 2648, 'Sailor Moon S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134771.mp4', 'http://timg.bdta.pro/images/131b1850abb2b523bdd99c0991b3ddd4.jpg'),
(38114, 2648, 'Sailor Moon S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134772.mp4', 'http://timg.bdta.pro/images/1c16b540b8ccf4889248d34dc367a3d8.jpg'),
(38115, 2648, 'Sailor Moon S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134773.mp4', 'http://timg.bdta.pro/images/d8040ad9df08cdd9b8f222c45a4154fd.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(38116, 2648, 'Sailor Moon S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134774.mp4', 'http://timg.bdta.pro/images/3216f44b3aa99e93ec826aff271778c7.jpg'),
(38117, 2648, 'Sailor Moon S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134775.mp4', 'http://timg.bdta.pro/images/5fc2138d5d003123aef80142527514a5.jpg'),
(38118, 2648, 'Sailor Moon S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/134776.mp4', 'http://timg.bdta.pro/images/6181088bb796cea5e996932e4a3b54dd.jpg'),
(38119, 2648, 'Sailor Moon S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/134777.mp4', 'http://timg.bdta.pro/images/28131bc67a935826c140f81e2a0132ab.jpg'),
(38120, 2648, 'Sailor Moon S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/134778.mp4', 'http://timg.bdta.pro/images/b63beb8c8ac85f4b0b55c2750af365e7.jpg'),
(38121, 2648, 'Sailor Moon S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/134779.mp4', 'http://timg.bdta.pro/images/152895bc2bd0c471da701534c7830313.jpg'),
(38122, 2648, 'Sailor Moon S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/134780.mp4', 'http://timg.bdta.pro/images/abcae2acda4d2c0d4f161ecf14ab37b5.jpg'),
(38123, 2648, 'Sailor Moon S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/134781.mp4', 'http://timg.bdta.pro/images/d202b847692cce42a1b753c5958236e3.jpg'),
(38124, 2648, 'Sailor Moon S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/134782.mp4', 'http://timg.bdta.pro/images/9d77b7e92ea546ec9b35993167429068.jpg'),
(38125, 2648, 'Sailor Moon S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/134783.mp4', 'http://timg.bdta.pro/images/e970b8cea2880fcade97bfe42428fdd0.jpg'),
(38126, 2648, 'Sailor Moon S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/134784.mp4', 'http://timg.bdta.pro/images/ce4c06b28a365e7964b2e86f68acfbea.jpg'),
(38127, 2648, 'Sailor Moon S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/134785.mp4', 'http://timg.bdta.pro/images/0c720e65e917f302e171510ae1388223.jpg'),
(38128, 2648, 'Sailor Moon S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/134786.mp4', 'http://timg.bdta.pro/images/8155de5c2dc9b2c949a82fd6d1fade0f.jpg'),
(38129, 2648, 'Sailor Moon S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/134787.mp4', 'http://timg.bdta.pro/images/a4e81a3cb2cd14653c8eb2adb7c4e277.jpg'),
(38130, 2648, 'Sailor Moon S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/134788.mp4', 'http://timg.bdta.pro/images/2f8b4391ccad07ccd9d78f6317d0819e.jpg'),
(38131, 2648, 'Sailor Moon S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/134789.mp4', 'http://timg.bdta.pro/images/6be22b2f2c82b5bf2870f913bb766fa6.jpg'),
(38132, 2648, 'Sailor Moon S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/134790.mp4', 'http://timg.bdta.pro/images/55290d38bf09e393a2af1a0c9cbf274e.jpg'),
(38133, 2648, 'Sailor Moon S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/134791.mp4', 'http://timg.bdta.pro/images/57610132657986b52ee0f84c62e22848.jpg'),
(38134, 2648, 'Sailor Moon S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/134792.mp4', 'http://timg.bdta.pro/images/0de88678550485bf7df92a9763b1894d.jpg'),
(38135, 2648, 'Sailor Moon S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/134793.mp4', 'http://timg.bdta.pro/images/be97f720ce852e5ae5325e73ef775987.jpg'),
(38136, 2648, 'Sailor Moon S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/134794.mp4', 'http://timg.bdta.pro/images/07db71e08e07b45651a1ce55789af7cd.jpg'),
(38137, 2648, 'Sailor Moon S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/134795.mp4', 'http://timg.bdta.pro/images/8386ed0ac32834c133c0499df3d9c869.jpg'),
(38138, 2648, 'Sailor Moon S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/134796.mp4', 'http://timg.bdta.pro/images/b965e94a2b63899c4e1d87c0331ec34a.jpg'),
(38139, 2648, 'Sailor Moon S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/134797.mp4', 'http://timg.bdta.pro/images/c4a28ca71957a297a7bae9191b585e7a.jpg'),
(38140, 2648, 'Sailor Moon S05 E31', 'http://sinalprivado.info:80/series/1533784/1533784/134798.mp4', 'http://timg.bdta.pro/images/1722add9ca2378d981ddd837cab9ab9c.jpg'),
(38141, 2648, 'Sailor Moon S05 E32', 'http://sinalprivado.info:80/series/1533784/1533784/134799.mp4', 'http://timg.bdta.pro/images/9ec0b8f295da1a79dfe4fe16cfd3efed.jpg'),
(38142, 2648, 'Sailor Moon S05 E33', 'http://sinalprivado.info:80/series/1533784/1533784/134800.mp4', 'http://timg.bdta.pro/images/68376cd85c6bda01fea40c86f1cb4811.jpg'),
(38143, 2648, 'Sailor Moon S05 E34', 'http://sinalprivado.info:80/series/1533784/1533784/134801.mp4', 'http://timg.bdta.pro/images/11375902c41342cdec1a24c7a978d39b.jpg'),
(38144, 2649, 'Cold Courage [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134594.mp4', 'http://timg.bdta.pro/images/b8d9bde8c73cf92b107402980f8fa53c.jpg'),
(38145, 2649, 'Cold Courage [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134595.mp4', 'http://timg.bdta.pro/images/400053372933f7e8a7996140ba9f2c26.jpg'),
(38146, 2649, 'Cold Courage [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134596.mp4', 'http://timg.bdta.pro/images/d2292773f4100377cd93e49b33b30a38.jpg'),
(38147, 2649, 'Cold Courage [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134597.mp4', 'http://timg.bdta.pro/images/1d4517d9e29c81010dca445efb9f96e6.jpg'),
(38148, 2649, 'Cold Courage [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134598.mp4', 'http://timg.bdta.pro/images/9b9eb4c31b5484b1d0b183939549a759.jpg'),
(38149, 2649, 'Cold Courage [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134599.mp4', 'http://timg.bdta.pro/images/4d08f5a338b354f702f832f4c75e6f5a.jpg'),
(38150, 2649, 'Cold Courage [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134600.mp4', 'http://timg.bdta.pro/images/22efd05e07305f7986600515720199e1.jpg'),
(38151, 2649, 'Cold Courage [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134601.mp4', 'http://timg.bdta.pro/images/8514ac90c87cc8a2fbf506ffc7635d1a.jpg'),
(38152, 2650, 'Code Black [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134547.mp4', 'http://timg.bdta.pro/images/62928a0069fa10532a17fe67025d97fe.jpg'),
(38153, 2650, 'Code Black [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134548.mp4', 'http://timg.bdta.pro/images/c425a1a321c7787f175fdec9015825dc.jpg'),
(38154, 2650, 'Code Black [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134549.mp4', 'http://timg.bdta.pro/images/5c9fbc18478f220ce2b68077bdbc3e3b.jpg'),
(38155, 2650, 'Code Black [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134550.mp4', 'http://timg.bdta.pro/images/6ab76a7c9c718365065ce28d6247d4d7.jpg'),
(38156, 2650, 'Code Black [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134551.mp4', 'http://timg.bdta.pro/images/da17da0b132b681a165a78d03b531c4d.jpg'),
(38157, 2650, 'Code Black [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134552.mp4', 'http://timg.bdta.pro/images/5df4a157321d669f78c08d3112597550.jpg'),
(38158, 2650, 'Code Black [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134553.mp4', 'http://timg.bdta.pro/images/1ebea3163125535f377f31b70478fe5d.jpg'),
(38159, 2650, 'Code Black [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134554.mp4', 'http://timg.bdta.pro/images/1c03ee73fbdd72cdebe434db5b7147e4.jpg'),
(38160, 2650, 'Code Black [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/134555.mp4', 'http://timg.bdta.pro/images/855365d29db7ab4acd6c17eadd2e17e5.jpg'),
(38161, 2650, 'Code Black [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/134556.mp4', 'http://timg.bdta.pro/images/dcab2fd0032cdc5502eccd373f62d793.jpg'),
(38162, 2650, 'Code Black [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/134557.mp4', 'http://timg.bdta.pro/images/1c68522c1551959471a6d15fd3f41d5c.jpg'),
(38163, 2650, 'Code Black [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/134558.mp4', 'http://timg.bdta.pro/images/e6ee311390315b20d17a604a097f7c4e.jpg'),
(38164, 2650, 'Code Black [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/134559.mp4', 'http://timg.bdta.pro/images/3e1c21318d88b4af55b559272ac2d5e1.jpg'),
(38165, 2650, 'Code Black [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/134560.mp4', 'http://timg.bdta.pro/images/236a6be3b1db4d00f47192f59b12d34f.jpg'),
(38166, 2650, 'Code Black [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/134561.mp4', 'http://timg.bdta.pro/images/c5b1a9fe8656e75c6618e323b90fb5ff.jpg'),
(38167, 2650, 'Code Black [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/134562.mp4', 'http://timg.bdta.pro/images/b3c8b1c510f573ab702d558069aaf3ee.jpg'),
(38168, 2650, 'Code Black [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/134563.mp4', 'http://timg.bdta.pro/images/bd5c58a1e8468603121d6553b4088013.jpg'),
(38169, 2650, 'Code Black [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/134564.mp4', 'http://timg.bdta.pro/images/f1e602300e2837ae60224f576a865692.jpg'),
(38170, 2651, 'Code Black [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134565.mp4', 'http://timg.bdta.pro/images/ec927edaada6684c22e9769afb08df52.jpg'),
(38171, 2651, 'Code Black [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134566.mp4', 'http://timg.bdta.pro/images/cf3e342ef19bf901ead802a937a249ff.jpg'),
(38172, 2651, 'Code Black [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134567.mp4', 'http://timg.bdta.pro/images/a355bf7bac0b27c0e7e4d8148e05fa57.jpg'),
(38173, 2651, 'Code Black [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134568.mp4', 'http://timg.bdta.pro/images/9f208fd1d8f74fa40c58b1c8917aab7e.jpg'),
(38174, 2651, 'Code Black [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134569.mp4', 'http://timg.bdta.pro/images/e0d9c12bcac1b175e839266b765e5198.jpg'),
(38175, 2651, 'Code Black [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134570.mp4', 'http://timg.bdta.pro/images/bba89c6d564beb7b8c8b3177a46d0f4a.jpg'),
(38176, 2651, 'Code Black [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134571.mp4', 'http://timg.bdta.pro/images/1e21437db94b2e6d4eabc2b9c1f2a4c4.jpg'),
(38177, 2651, 'Code Black [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134572.mp4', 'http://timg.bdta.pro/images/11f40cd3c719c66b4568f1897859b29a.jpg'),
(38178, 2651, 'Code Black [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/134573.mp4', 'http://timg.bdta.pro/images/091643ac3512cfaa3428864291478745.jpg'),
(38179, 2651, 'Code Black [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/134574.mp4', 'http://timg.bdta.pro/images/07a224e6c6b9073bf069ed4a3811b6b6.jpg'),
(38180, 2651, 'Code Black [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/134575.mp4', 'http://timg.bdta.pro/images/93fc3a4992e8bc8bfdd986cc08a61890.jpg'),
(38181, 2651, 'Code Black [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/134576.mp4', 'http://timg.bdta.pro/images/9ac89c92c38e5ddb5bcaf8c06df6ce23.jpg'),
(38182, 2651, 'Code Black [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/134577.mp4', 'http://timg.bdta.pro/images/ce903ad10a9b3fdfef9885ddb57648e8.jpg'),
(38183, 2651, 'Code Black [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/134578.mp4', 'http://timg.bdta.pro/images/06f87058fdb43d5de4fe1ab29a42e52f.jpg'),
(38184, 2651, 'Code Black [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/134579.mp4', 'http://timg.bdta.pro/images/893bf6dc2e1c547edb1111fa99779ed6.jpg'),
(38185, 2651, 'Code Black [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/134580.mp4', 'http://timg.bdta.pro/images/678ffbb1f565fce7f65f9caa92d27ad5.jpg'),
(38186, 2652, 'Code Black [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134581.mp4', 'http://timg.bdta.pro/images/09bc84e790addd39f79c0f2ce5eda869.jpg'),
(38187, 2652, 'Code Black [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134582.mp4', 'http://timg.bdta.pro/images/38921588130b19cce71833e7e1d07e1c.jpg'),
(38188, 2652, 'Code Black [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134583.mp4', 'http://timg.bdta.pro/images/6562f696ded618353cbd0fb8b4561a1f.jpg'),
(38189, 2652, 'Code Black [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134584.mp4', 'http://timg.bdta.pro/images/eea10d8112d9b00d9bec270148f93bd4.jpg'),
(38190, 2652, 'Code Black [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134585.mp4', 'http://timg.bdta.pro/images/7e39e68b0382c6599d237ad4222cc3e6.jpg'),
(38191, 2652, 'Code Black [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134586.mp4', 'http://timg.bdta.pro/images/f37063b55a181a67ab33f0dc41996277.jpg'),
(38192, 2652, 'Code Black [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134587.mp4', 'http://timg.bdta.pro/images/82662da61a4dd72425c50b9a25fb2cc7.jpg'),
(38193, 2652, 'Code Black [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134588.mp4', 'http://timg.bdta.pro/images/055d36d7dbc031bbdd390b40d1a6e2b6.jpg'),
(38194, 2652, 'Code Black [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/134589.mp4', 'http://timg.bdta.pro/images/0773af0caaf2c46c66bd545f4c564e43.jpg'),
(38195, 2652, 'Code Black [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/134590.mp4', 'http://timg.bdta.pro/images/ff6ff159fe9908bc4048c90984edb616.jpg'),
(38196, 2652, 'Code Black [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/134591.mp4', 'http://timg.bdta.pro/images/108e0f957755fcbbee002b203c897da6.jpg'),
(38197, 2652, 'Code Black [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/134592.mp4', 'http://timg.bdta.pro/images/5e012febb7436ce8f69bf9bdfbe33500.jpg'),
(38198, 2652, 'Code Black [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/134593.mp4', 'http://timg.bdta.pro/images/856be6b2fad25d37cdc2758fe2e00cc0.jpg'),
(38199, 2653, 'Xilindró S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134472.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38200, 2653, 'Xilindró S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134473.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38201, 2653, 'Xilindró S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134474.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38202, 2653, 'Xilindró S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134475.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38203, 2653, 'Xilindró S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134476.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38204, 2653, 'Xilindró S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134477.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38205, 2653, 'Xilindró S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134478.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38206, 2653, 'Xilindró S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134479.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38207, 2653, 'Xilindró S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/134480.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38208, 2653, 'Xilindró S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/134481.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38209, 2653, 'Xilindró S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/134482.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38210, 2653, 'Xilindró S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/134483.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38211, 2653, 'Xilindró S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/134484.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38212, 2653, 'Xilindró S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/134485.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38213, 2653, 'Xilindró S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/134486.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38214, 2653, 'Xilindró S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/134487.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38215, 2653, 'Xilindró S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/134488.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38216, 2653, 'Xilindró S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/134489.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38217, 2653, 'Xilindró S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/134490.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38218, 2653, 'Xilindró S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/134491.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38219, 2654, 'Xilindró S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134492.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38220, 2654, 'Xilindró S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134493.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38221, 2654, 'Xilindró S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134494.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38222, 2654, 'Xilindró S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134495.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38223, 2654, 'Xilindró S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134496.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38224, 2654, 'Xilindró S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134497.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38225, 2654, 'Xilindró S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134498.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38226, 2654, 'Xilindró S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134499.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38227, 2654, 'Xilindró S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/134500.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38228, 2654, 'Xilindró S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/134501.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38229, 2654, 'Xilindró S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/134502.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38230, 2654, 'Xilindró S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/134503.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38231, 2654, 'Xilindró S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/134504.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38232, 2654, 'Xilindró S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/134505.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38233, 2654, 'Xilindró S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/134506.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38234, 2654, 'Xilindró S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/134507.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38235, 2654, 'Xilindró S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/134508.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38236, 2654, 'Xilindró S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/134509.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38237, 2654, 'Xilindró S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/134510.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38238, 2654, 'Xilindró S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/134511.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38239, 2655, 'Xilindró S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134512.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38240, 2655, 'Xilindró S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134513.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38241, 2655, 'Xilindró S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134514.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38242, 2655, 'Xilindró S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134515.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38243, 2655, 'Xilindró S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134516.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38244, 2655, 'Xilindró S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134517.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38245, 2655, 'Xilindró S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134518.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38246, 2655, 'Xilindró S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134519.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38247, 2655, 'Xilindró S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/134520.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38248, 2655, 'Xilindró S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/134521.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38249, 2655, 'Xilindró S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/134522.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38250, 2655, 'Xilindró S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/134523.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38251, 2655, 'Xilindró S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/134524.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38252, 2655, 'Xilindró S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/134525.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38253, 2655, 'Xilindró S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/134526.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38254, 2655, 'Xilindró S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/134527.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38255, 2655, 'Xilindró S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/134528.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38256, 2655, 'Xilindró S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/134529.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38257, 2655, 'Xilindró S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/134530.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38258, 2655, 'Xilindró S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/134531.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38259, 2656, 'Xilindró S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134532.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38260, 2656, 'Xilindró S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134533.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38261, 2656, 'Xilindró S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134534.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38262, 2656, 'Xilindró S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134535.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38263, 2656, 'Xilindró S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134536.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38264, 2656, 'Xilindró S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134537.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38265, 2656, 'Xilindró S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134538.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38266, 2656, 'Xilindró S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134539.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38267, 2656, 'Xilindró S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/134540.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38268, 2656, 'Xilindró S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/134541.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38269, 2656, 'Xilindró S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/134542.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38270, 2656, 'Xilindró S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/134543.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38271, 2656, 'Xilindró S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/134544.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38272, 2656, 'Xilindró S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/134545.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38273, 2656, 'Xilindró S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/134546.mp4', 'http://gstaticontent.com/images/fOZr8UEMI0My6BwopGQnFUVqYl8_big.jpg'),
(38274, 2657, 'Two Weeks to Live [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134466.mp4', 'http://timg.bdta.pro/images/093c764b4971a8e90e88f9b188b834fe.jpg'),
(38275, 2657, 'Two Weeks to Live [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134467.mp4', 'http://timg.bdta.pro/images/31d2069917a690a61ddba254e7195987.jpg'),
(38276, 2657, 'Two Weeks to Live [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134468.mp4', 'http://timg.bdta.pro/images/cfb6e33199cfcce753278e37a7f4c261.jpg'),
(38277, 2657, 'Two Weeks to Live [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134469.mp4', 'http://timg.bdta.pro/images/f216ed36094ed5070427b3f45a10442e.jpg'),
(38278, 2657, 'Two Weeks to Live [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134470.mp4', 'http://timg.bdta.pro/images/77e8b75522936132d55dbad99c2c106f.jpg'),
(38279, 2657, 'Two Weeks to Live [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134471.mp4', 'http://timg.bdta.pro/images/1b8d25c75e66cd648179a4c63c1c6fef.jpg'),
(38280, 2658, '4 Contra o Apocalipse S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244724.mp4', 'http://timg.bdta.pro/images/5ca097ce341a47000771c0262eb5525f.jpg'),
(38281, 2658, '4 Contra o Apocalipse S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244725.mp4', 'http://gstaticontent.com/images/lTpGn2hgB0WGFGp6Q6ArkEWWTsk_big.jpg'),
(38282, 2658, '4 Contra o Apocalipse S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244726.mp4', 'http://gstaticontent.com/images/lTpGn2hgB0WGFGp6Q6ArkEWWTsk_big.jpg'),
(38283, 2658, '4 Contra o Apocalipse S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244727.mp4', 'http://gstaticontent.com/images/lTpGn2hgB0WGFGp6Q6ArkEWWTsk_big.jpg'),
(38284, 2658, '4 Contra o Apocalipse S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244728.mp4', 'http://gstaticontent.com/images/lTpGn2hgB0WGFGp6Q6ArkEWWTsk_big.jpg'),
(38285, 2658, '4 Contra o Apocalipse S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244729.mp4', 'http://gstaticontent.com/images/lTpGn2hgB0WGFGp6Q6ArkEWWTsk_big.jpg'),
(38286, 2658, '4 Contra o Apocalipse S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244730.mp4', 'http://gstaticontent.com/images/lTpGn2hgB0WGFGp6Q6ArkEWWTsk_big.jpg'),
(38287, 2658, '4 Contra o Apocalipse S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244731.mp4', 'http://gstaticontent.com/images/lTpGn2hgB0WGFGp6Q6ArkEWWTsk_big.jpg'),
(38288, 2658, '4 Contra o Apocalipse S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244732.mp4', 'http://gstaticontent.com/images/lTpGn2hgB0WGFGp6Q6ArkEWWTsk_big.jpg'),
(38289, 2658, '4 Contra o Apocalipse S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244733.mp4', 'http://gstaticontent.com/images/lTpGn2hgB0WGFGp6Q6ArkEWWTsk_big.jpg'),
(38290, 2658, '4 Contra o Apocalipse S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244734.mp4', 'http://gstaticontent.com/images/lTpGn2hgB0WGFGp6Q6ArkEWWTsk_big.jpg'),
(38291, 2659, '4 Contra o Apocalipse S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244735.mp4', 'http://timg.bdta.pro/images/f88fee7da02be1edc709025b339a0bcf.jpg'),
(38292, 2659, '4 Contra o Apocalipse S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244736.mp4', 'http://timg.bdta.pro/images/99d1c3f0d1ddd28014e0bdd0f95e1781.jpg'),
(38293, 2659, '4 Contra o Apocalipse S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244737.mp4', 'http://timg.bdta.pro/images/3c4ac2db66ff15bf18c1055f105db596.jpg'),
(38294, 2659, '4 Contra o Apocalipse S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244738.mp4', 'http://timg.bdta.pro/images/ba07a043f5024a6bad727b9d36e75453.jpg'),
(38295, 2659, '4 Contra o Apocalipse S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244739.mp4', 'http://timg.bdta.pro/images/6e3a36acca6b01ae1cf35eb958be1365.jpg'),
(38296, 2659, '4 Contra o Apocalipse S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244740.mp4', 'http://timg.bdta.pro/images/6cbb8a806c3d0567f1fa6cb947c1fb9e.jpg'),
(38297, 2659, '4 Contra o Apocalipse S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244741.mp4', 'http://timg.bdta.pro/images/0d23c51a888ae71b6d88004fbbb6acf9.jpg'),
(38298, 2659, '4 Contra o Apocalipse S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244742.mp4', 'http://timg.bdta.pro/images/f35bd7ee9b1ac43da02c84cd581e4946.jpg'),
(38299, 2659, '4 Contra o Apocalipse S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244743.mp4', 'http://timg.bdta.pro/images/811f4ff405e9bd9c4e5c7f891fd42eb6.jpg'),
(38300, 2659, '4 Contra o Apocalipse S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244744.mp4', 'http://timg.bdta.pro/images/0f1f44ed95c134f59d132dc231573a8f.jpg'),
(38301, 2660, '4 Contra o Apocalipse S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244745.mp4', 'http://gstaticontent.com/images/lTpGn2hgB0WGFGp6Q6ArkEWWTsk_big.jpg'),
(38302, 2660, '4 Contra o Apocalipse S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244746.mp4', 'http://gstaticontent.com/images/lTpGn2hgB0WGFGp6Q6ArkEWWTsk_big.jpg'),
(38303, 2660, '4 Contra o Apocalipse S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244747.mp4', 'http://gstaticontent.com/images/lTpGn2hgB0WGFGp6Q6ArkEWWTsk_big.jpg'),
(38304, 2660, '4 Contra o Apocalipse S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244748.mp4', 'http://gstaticontent.com/images/lTpGn2hgB0WGFGp6Q6ArkEWWTsk_big.jpg'),
(38305, 2660, '4 Contra o Apocalipse S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244749.mp4', 'http://gstaticontent.com/images/lTpGn2hgB0WGFGp6Q6ArkEWWTsk_big.jpg'),
(38306, 2660, '4 Contra o Apocalipse S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244750.mp4', 'http://gstaticontent.com/images/lTpGn2hgB0WGFGp6Q6ArkEWWTsk_big.jpg'),
(38307, 2660, '4 Contra o Apocalipse S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244751.mp4', 'http://gstaticontent.com/images/lTpGn2hgB0WGFGp6Q6ArkEWWTsk_big.jpg'),
(38308, 2660, '4 Contra o Apocalipse S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244752.mp4', 'http://gstaticontent.com/images/lTpGn2hgB0WGFGp6Q6ArkEWWTsk_big.jpg'),
(38309, 2660, '4 Contra o Apocalipse S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244753.mp4', 'http://gstaticontent.com/images/lTpGn2hgB0WGFGp6Q6ArkEWWTsk_big.jpg'),
(38310, 2660, '4 Contra o Apocalipse S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244754.mp4', 'http://gstaticontent.com/images/lTpGn2hgB0WGFGp6Q6ArkEWWTsk_big.jpg'),
(38311, 2661, 'A Maldição da Mansão Bly S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/133938.mp4', 'http://timg.bdta.pro/images/fb2042fa4007633646156ee44c51f942.jpg'),
(38312, 2661, 'A Maldição da Mansão Bly S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/133939.mp4', 'http://timg.bdta.pro/images/36b59462bd9107ba566544fd8f56f66e.jpg'),
(38313, 2661, 'A Maldição da Mansão Bly S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/133940.mp4', 'http://timg.bdta.pro/images/dbb552a0aa273df8e60a13b8627f0c17.jpg'),
(38314, 2661, 'A Maldição da Mansão Bly S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/133941.mp4', 'http://timg.bdta.pro/images/d5b2a71152ef05257066c6dae07e7074.jpg'),
(38315, 2661, 'A Maldição da Mansão Bly S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/133942.mp4', 'http://timg.bdta.pro/images/bfe746e5e2d42a0ca5841a95ef8ab950.jpg'),
(38316, 2661, 'A Maldição da Mansão Bly S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/133943.mp4', 'http://timg.bdta.pro/images/7c01ea847e841b9a839cac6b9b95c89d.jpg'),
(38317, 2661, 'A Maldição da Mansão Bly S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/133944.mp4', 'http://timg.bdta.pro/images/3c4859d6c65dff6c8764fb5aabe5e48d.jpg'),
(38318, 2661, 'A Maldição da Mansão Bly S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/133945.mp4', 'http://timg.bdta.pro/images/3aa5c5e339631efe96ab419c0176e9ae.jpg'),
(38319, 2661, 'A Maldição da Mansão Bly S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/133946.mp4', 'http://timg.bdta.pro/images/8e6ac674b61e71244d127f5e7f46d640.jpg'),
(38320, 2662, 'Dando um Tempo com Bert Kreischer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/133933.mp4', 'http://timg.bdta.pro/images/4302a56d45fae542e7ae20d25c204787.jpg'),
(38321, 2662, 'Dando um Tempo com Bert Kreischer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/133934.mp4', 'http://timg.bdta.pro/images/d481bb0b82a12c39c2fa3ea759fab60b.jpg'),
(38322, 2662, 'Dando um Tempo com Bert Kreischer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/133935.mp4', 'http://timg.bdta.pro/images/8b7b74fc9a0d5948c625f012c3626708.jpg'),
(38323, 2662, 'Dando um Tempo com Bert Kreischer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/133936.mp4', 'http://timg.bdta.pro/images/a778b00b569235c8626623e8edbcc21c.jpg'),
(38324, 2662, 'Dando um Tempo com Bert Kreischer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/133937.mp4', 'http://timg.bdta.pro/images/d46f9d23114b35648e9b7c0d05966f49.jpg'),
(38325, 2663, 'Distanciamento Social S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/133925.mp4', 'http://timg.bdta.pro/images/25c2429f33b07cc4eeaf347f6d079142.jpg'),
(38326, 2663, 'Distanciamento Social S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/133926.mp4', 'http://timg.bdta.pro/images/7aa139e2258c08eb128e0449ca70d2e3.jpg'),
(38327, 2663, 'Distanciamento Social S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/133927.mp4', 'http://timg.bdta.pro/images/96845337c2128f461caa0ad67c1155fd.jpg'),
(38328, 2663, 'Distanciamento Social S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/133928.mp4', 'http://timg.bdta.pro/images/192ac35fcbbf073264db4c9f7a93fab6.jpg'),
(38329, 2663, 'Distanciamento Social S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/133929.mp4', 'http://timg.bdta.pro/images/51ec84c852c1f91fb6d731e6b99dc67e.jpg'),
(38330, 2663, 'Distanciamento Social S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/133930.mp4', 'http://timg.bdta.pro/images/51242ff33b10e46e26a02e8587617271.jpg'),
(38331, 2663, 'Distanciamento Social S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/133931.mp4', 'http://timg.bdta.pro/images/c66bccc01f79834e438730e5bc0395d7.jpg'),
(38332, 2663, 'Distanciamento Social S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/133932.mp4', 'http://timg.bdta.pro/images/dce5ff958c409641ae029c7ef78884d2.jpg'),
(38333, 2664, 'Força Danger S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yuHXGiJuPf6l9sWqkloOCbXvVUI.jpg'),
(38334, 2664, 'Força Danger S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cZYPd1gsDu0B4k7EecF371gIfJq.jpg'),
(38335, 2664, 'Força Danger S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Q0wwWyoJQr2Add4zCicSAFrv8S.jpg'),
(38336, 2664, 'Força Danger S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qq8x2dvxRS9re53lLcLKPkEMnBg.jpg'),
(38337, 2664, 'Força Danger S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2TxNOeoJEI7iirWnHfNx2ivdYC.jpg'),
(38338, 2664, 'Força Danger S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2daGbbXUo5okXTJ8VVVNaTaP7OS.jpg'),
(38339, 2664, 'Força Danger S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dXKVgU5v7N4IUdG42thI8Xx8rad.jpg'),
(38340, 2664, 'Força Danger S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJUuTIFM3m6e1Pxq37Gjmaf0YlE.jpg'),
(38341, 2664, 'Força Danger S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mOGuz7kZDB7qBIQIsSsZhNr6FOU.jpg'),
(38342, 2664, 'Força Danger S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJDqkqKx6AlacAwOpPuaxe3fgYc.jpg'),
(38343, 2664, 'Força Danger S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Adk16KICVsno4IB2CWOfz0w7pp.jpg'),
(38344, 2664, 'Força Danger S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n2D0ttZOdF7rwQLIuaXqbtsd7Ru.jpg'),
(38345, 2664, 'Força Danger S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nUVnEU7P57QqxjgfLhbtPaMxYh1.jpg'),
(38346, 2664, 'Força Danger S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/259059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Q1kM0sjufQ62nFN5jGqueHx4p0.jpg'),
(38347, 2664, 'Força Danger S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/259060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aMCcCEUUnivCCJY9qVApJ2fG6ZY.jpg'),
(38348, 2664, 'Força Danger S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/259061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fzCTNovGAcsrWfHNRSR9XgO2Yun.jpg'),
(38349, 2664, 'Força Danger S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/259062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y2U3ySM0DPsGY81IVyKRH5kDvkb.jpg'),
(38350, 2664, 'Força Danger S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/259063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pEY66Rlw6WrVgu1AsCEKpOAGB5g.jpg'),
(38351, 2664, 'Força Danger S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/259064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7C6PCBjhxJUOBZwFjH8jCuC6PjD.jpg'),
(38352, 2664, 'Força Danger S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/259065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dTSMbuZjRtvXYpx3PHgvlEo8ote.jpg'),
(38353, 2664, 'Força Danger S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/259066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jAdRfIE21nImDeXAquYImJ95VWZ.jpg'),
(38354, 2664, 'Força Danger S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/259067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ld2YvEY5l38pfFIgWlxkxVyRDOp.jpg'),
(38355, 2664, 'Força Danger S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/259068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCuCAXosp7JIXMUrxNcmDd84Ddi.jpg'),
(38356, 2664, 'Força Danger S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/259069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a5LXe4wmsbrVPTHF8I8SzvK8kGh.jpg'),
(38357, 2664, 'Força Danger S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/259070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k12aKcmd34ogEtGAe1aefXnAfPZ.jpg'),
(38358, 2664, 'Força Danger S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/259071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQaToL9AN6P0eOcuLPSIcGxtaS7.jpg'),
(38359, 2665, 'Força Danger S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259072.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38360, 2665, 'Força Danger S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259073.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38361, 2665, 'Força Danger S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259074.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38362, 2665, 'Força Danger S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259075.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38363, 2665, 'Força Danger S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259076.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38364, 2665, 'Força Danger S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259077.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38365, 2665, 'Força Danger S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259078.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38366, 2665, 'Força Danger S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259079.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38367, 2665, 'Força Danger S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259080.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38368, 2665, 'Força Danger S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259081.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38369, 2665, 'Força Danger S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259082.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38370, 2665, 'Força Danger S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259083.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38371, 2665, 'Força Danger S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259084.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38372, 2665, 'Força Danger S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/259085.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38373, 2665, 'Força Danger S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/259086.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38374, 2665, 'Força Danger S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/259087.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38375, 2665, 'Força Danger S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/259088.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38376, 2665, 'Força Danger S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/259089.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38377, 2665, 'Força Danger S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/259090.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38378, 2665, 'Força Danger S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/259091.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38379, 2665, 'Força Danger S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/259092.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38380, 2665, 'Força Danger S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/259093.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38381, 2665, 'Força Danger S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/259094.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38382, 2665, 'Força Danger S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/259095.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38383, 2665, 'Força Danger S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/259096.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38384, 2665, 'Força Danger S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/259097.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38385, 2666, 'Força Danger S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/281149.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38386, 2666, 'Força Danger S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/281150.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38387, 2666, 'Força Danger S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/281151.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38388, 2666, 'Força Danger S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/281152.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38389, 2666, 'Força Danger S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/281153.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38390, 2666, 'Força Danger S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/281154.mp4', 'http://gstaticontent.com/images/xS6CcFRcNDW7zpIQBme201ptoAp_big.jpg'),
(38391, 2667, 'Future Man S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/133891.mp4', 'http://timg.bdta.pro/images/d1106e870cbe2e1f1415c109b274c194.jpg'),
(38392, 2667, 'Future Man S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/133892.mp4', 'http://timg.bdta.pro/images/a0c97e2a4e3d6d26a75a6c16568a189b.jpg'),
(38393, 2667, 'Future Man S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/133893.mp4', 'http://timg.bdta.pro/images/24b5fc419b4aa0ec7dd77e30aa469d2c.jpg'),
(38394, 2667, 'Future Man S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/133894.mp4', 'http://timg.bdta.pro/images/af535c9efd7f6356230214d88d2ce81a.jpg'),
(38395, 2667, 'Future Man S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/133895.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38396, 2667, 'Future Man S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/133896.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38397, 2667, 'Future Man S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/133897.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38398, 2667, 'Future Man S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/133898.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38399, 2667, 'Future Man S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/133899.mp4', 'http://timg.bdta.pro/images/38636317f80b7b9e96cf2d9f49518bfd.jpg'),
(38400, 2667, 'Future Man S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/133900.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38401, 2667, 'Future Man S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/133901.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(38402, 2667, 'Future Man S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/133902.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38403, 2667, 'Future Man S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/133903.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38404, 2668, 'Future Man S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/133904.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38405, 2668, 'Future Man S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/133905.mp4', 'http://timg.bdta.pro/images/61d80711f530e9866f258744cba6a075.jpg'),
(38406, 2668, 'Future Man S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/133906.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38407, 2668, 'Future Man S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/133907.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38408, 2668, 'Future Man S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/133908.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38409, 2668, 'Future Man S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/133909.mp4', 'http://timg.bdta.pro/images/57b4fe6b5cba5253a3d7232e84b500f8.jpg'),
(38410, 2668, 'Future Man S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/133910.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38411, 2668, 'Future Man S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/133911.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38412, 2668, 'Future Man S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/133912.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38413, 2668, 'Future Man S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/133913.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38414, 2668, 'Future Man S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/133914.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38415, 2668, 'Future Man S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/133915.mp4', 'http://timg.bdta.pro/images/247d4488fc9eecaf33a5faa389d7abbd.jpg'),
(38416, 2668, 'Future Man S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/133916.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38417, 2669, 'Future Man S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/133917.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38418, 2669, 'Future Man S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/133918.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38419, 2669, 'Future Man S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/133919.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38420, 2669, 'Future Man S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/133920.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38421, 2669, 'Future Man S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/133921.mp4', 'http://timg.bdta.pro/images/41121260917e6dca1d23d9c8795276e4.jpg'),
(38422, 2669, 'Future Man S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/133922.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38423, 2669, 'Future Man S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/133923.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38424, 2669, 'Future Man S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/133924.mp4', 'http://gstaticontent.com/images/nWOf73kvq363IEjyIUfIMZuc8Dy_big.jpg'),
(38425, 2670, 'Game dos Clones S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137253.mp4', 'http://gstaticontent.com/images/qVJB4EbYfRPB2UsHiGeVCzIZZrj_big.jpg'),
(38426, 2670, 'Game dos Clones S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137254.mp4', 'http://gstaticontent.com/images/qVJB4EbYfRPB2UsHiGeVCzIZZrj_big.jpg'),
(38427, 2670, 'Game dos Clones S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137255.mp4', 'http://gstaticontent.com/images/qVJB4EbYfRPB2UsHiGeVCzIZZrj_big.jpg'),
(38428, 2670, 'Game dos Clones S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137256.mp4', 'http://gstaticontent.com/images/qVJB4EbYfRPB2UsHiGeVCzIZZrj_big.jpg'),
(38429, 2670, 'Game dos Clones S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137257.mp4', 'http://gstaticontent.com/images/qVJB4EbYfRPB2UsHiGeVCzIZZrj_big.jpg'),
(38430, 2670, 'Game dos Clones S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137258.mp4', 'http://gstaticontent.com/images/qVJB4EbYfRPB2UsHiGeVCzIZZrj_big.jpg'),
(38431, 2670, 'Game dos Clones S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137259.mp4', 'http://gstaticontent.com/images/qVJB4EbYfRPB2UsHiGeVCzIZZrj_big.jpg'),
(38432, 2670, 'Game dos Clones S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137260.mp4', 'http://gstaticontent.com/images/qVJB4EbYfRPB2UsHiGeVCzIZZrj_big.jpg'),
(38433, 2670, 'Game dos Clones S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137261.mp4', 'http://gstaticontent.com/images/qVJB4EbYfRPB2UsHiGeVCzIZZrj_big.jpg'),
(38434, 2670, 'Game dos Clones S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137262.mp4', 'http://gstaticontent.com/images/qVJB4EbYfRPB2UsHiGeVCzIZZrj_big.jpg'),
(38435, 2671, 'Grand Army S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/133882.mp4', 'http://timg.bdta.pro/images/9bab2d601eb3d5f2b20d33862cdb6e32.jpg'),
(38436, 2671, 'Grand Army S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/133883.mp4', 'http://timg.bdta.pro/images/97093b7623408bb44d2c068ea983bc4c.jpg'),
(38437, 2671, 'Grand Army S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/133884.mp4', 'http://timg.bdta.pro/images/658dbf54bbb1cea76b6b2e9d9e1bc64a.jpg'),
(38438, 2671, 'Grand Army S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/133885.mp4', 'http://timg.bdta.pro/images/aa0a7aeb936daacaedf2c324e116d69a.jpg'),
(38439, 2671, 'Grand Army S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/133886.mp4', 'http://timg.bdta.pro/images/55c066452cafa65b035f277cb8211370.jpg'),
(38440, 2671, 'Grand Army S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/133887.mp4', 'http://timg.bdta.pro/images/89711d39d94f62aeed271294d8ca8452.jpg'),
(38441, 2671, 'Grand Army S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/133888.mp4', 'http://timg.bdta.pro/images/e834332eefc443f34b79aac46df7a05a.jpg'),
(38442, 2671, 'Grand Army S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/133889.mp4', 'http://timg.bdta.pro/images/81ffd5060c3da01990932c859f685f04.jpg'),
(38443, 2671, 'Grand Army S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/133890.mp4', 'http://timg.bdta.pro/images/be2b3c0e8fbc562baeda720154283756.jpg'),
(38444, 2672, 'La Révolution S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/133874.mp4', 'http://timg.bdta.pro/images/74f46e3aaa48fb70b09ea9d680b65362.jpg'),
(38445, 2672, 'La Révolution S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/133875.mp4', 'http://timg.bdta.pro/images/3aabf18fee3c920d36425249766aa67f.jpg'),
(38446, 2672, 'La Révolution S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/133876.mp4', 'http://timg.bdta.pro/images/a61131404ebbefb4189ff38223555c4f.jpg'),
(38447, 2672, 'La Révolution S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/133877.mp4', 'http://timg.bdta.pro/images/47957ee410a165485d2baf46053e0869.jpg'),
(38448, 2672, 'La Révolution S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/133878.mp4', 'http://timg.bdta.pro/images/2b88672d94a67156c196445710879541.jpg'),
(38449, 2672, 'La Révolution S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/133879.mp4', 'http://timg.bdta.pro/images/668a10dc1c2d11fc41d5dcc9446256ea.jpg'),
(38450, 2672, 'La Révolution S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/133880.mp4', 'http://timg.bdta.pro/images/dd071a40993774233f026c9b4ac331e7.jpg'),
(38451, 2672, 'La Révolution S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/133881.mp4', 'http://timg.bdta.pro/images/fb31fd9daf9ed9ed2da71ba762d1a42e.jpg'),
(38452, 2673, 'Os Eleitos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131332.mp4', 'http://timg.bdta.pro/images/d1025e8f4ad0e6b51c660327db4db64b.jpg'),
(38453, 2673, 'Os Eleitos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131333.mp4', 'http://timg.bdta.pro/images/4cc90254ed4eb5b3f05350057c13c621.jpg'),
(38454, 2673, 'Os Eleitos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131334.mp4', 'http://timg.bdta.pro/images/742ca96e88dd3c3e6784192c0b2ca2c1.jpg'),
(38455, 2673, 'Os Eleitos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/abWqXrk4NtgNrHWkLE6KqkInRaD.jpg'),
(38456, 2673, 'Os Eleitos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sX1fSclepBOoDMj1N2jqrQRaRPu.jpg'),
(38457, 2673, 'Os Eleitos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7JMjWJFUaNn7FOr9wH02VI9GKbA.jpg'),
(38458, 2673, 'Os Eleitos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131338.mp4', 'http://gstaticontent.com/images/dYN0Fkv2mwafqAiYtvIBoOiY3nL_big.jpg'),
(38459, 2673, 'Os Eleitos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131339.mp4', 'http://gstaticontent.com/images/dYN0Fkv2mwafqAiYtvIBoOiY3nL_big.jpg'),
(38460, 2674, 'Patria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131324.mp4', 'http://timg.bdta.pro/images/4ef53fff31fd55699d4fdfb62ebde445.jpg'),
(38461, 2674, 'Patria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131325.mp4', 'http://timg.bdta.pro/images/8f21e4e776426d289b11294cf2eefddc.jpg'),
(38462, 2674, 'Patria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131326.mp4', 'http://timg.bdta.pro/images/b8bf2f2130e52783c4235cf4c7231321.jpg'),
(38463, 2674, 'Patria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131327.mp4', 'http://timg.bdta.pro/images/c62f91fb92d0e57fa4b9c956cbb7f510.jpg'),
(38464, 2674, 'Patria S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131328.mp4', 'http://timg.bdta.pro/images/86d628bef22fcf0ef4ecc6fe18e52ba2.jpg'),
(38465, 2674, 'Patria S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/liIwNo6efzp2R5EVHEXB5FOXdf.jpg'),
(38466, 2674, 'Patria S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gHtwDWZ7PvCIJb8ttg2EY1LoFj8.jpg'),
(38467, 2674, 'Patria S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131331.mp4', 'http://gstaticontent.com/images/0f9ca06b7594bf35d27b7a4f3f25ff4c.jpg'),
(38468, 2675, 'Tardezinha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/133870.mp4', 'http://gstaticontent.com/images/tjRhMBxeMM1QnEyRRvgembtocTz_big.jpg'),
(38469, 2675, 'Tardezinha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/133871.mp4', 'http://gstaticontent.com/images/tjRhMBxeMM1QnEyRRvgembtocTz_big.jpg'),
(38470, 2675, 'Tardezinha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/133872.mp4', 'http://gstaticontent.com/images/tjRhMBxeMM1QnEyRRvgembtocTz_big.jpg'),
(38471, 2675, 'Tardezinha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/133873.mp4', 'http://gstaticontent.com/images/tjRhMBxeMM1QnEyRRvgembtocTz_big.jpg'),
(38472, 2676, 'Teerã S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/184279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/chXGeonteDicWKM9KVM2MZqwBcJ.jpg'),
(38473, 2676, 'Teerã S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/184280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wv6Smma7sts6C4LKBHNaMyVX9Nf.jpg'),
(38474, 2676, 'Teerã S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/184281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tNlEENZmKwakHq4PUPUbgZAUjfm.jpg'),
(38475, 2676, 'Teerã S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/184282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSKQKCZMGD7DsW5Ag3AXB1syMVn.jpg'),
(38476, 2676, 'Teerã S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/184283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hI569JoZu5Mry19dsbzR8YbpcBz.jpg'),
(38477, 2676, 'Teerã S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/184284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1bOQGXNUTWbq1aSQUhngkR0IIkX.jpg'),
(38478, 2676, 'Teerã S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/184285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Z3prFgJ3WKrmYORkDt71ZVnbXl.jpg'),
(38479, 2676, 'Teerã S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/184286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/UqZ75FgyrVD4c8s2HGWvhAfwqb.jpg'),
(38480, 2677, 'Teerã S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/184287.mp4', 'http://timg.bdta.pro/images/138ea63f4c7105d6732c9d9bc3790495.jpg'),
(38481, 2677, 'Teerã S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/184288.mp4', 'http://timg.bdta.pro/images/6251d12ebd08a4f8d99268089d846a84.jpg'),
(38482, 2677, 'Teerã S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/184289.mp4', 'http://timg.bdta.pro/images/c741dd25828bc5302a8811a6f09749d6.jpg'),
(38483, 2677, 'Teerã S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/184290.mp4', 'http://timg.bdta.pro/images/e983e06a8d972a063557a41ae1da07d9.jpg'),
(38484, 2677, 'Teerã S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/184291.mp4', 'http://timg.bdta.pro/images/962009f30954243afecafd8cd75c7f0f.jpg'),
(38485, 2677, 'Teerã S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/184292.mp4', 'http://timg.bdta.pro/images/3fee0254413eebed1581007dcc8b76af.jpg'),
(38486, 2677, 'Teerã S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/184293.mp4', 'http://timg.bdta.pro/images/5a2c4481727b1e02fb03645cfd9e8a70.jpg'),
(38487, 2677, 'Teerã S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/184294.mp4', 'http://timg.bdta.pro/images/455bedf59883fe5b09f1a8de851149e5.jpg'),
(38488, 2678, 'Zoey e Sua Fantástica Playlist S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146198.mp4', 'http://timg.bdta.pro/images/0cd74d11a883208cd5171979e08d6c7e.jpg'),
(38489, 2678, 'Zoey e Sua Fantástica Playlist S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146199.mp4', 'http://timg.bdta.pro/images/02f2c748e9befbea1d95b49a7125060e.jpg'),
(38490, 2678, 'Zoey e Sua Fantástica Playlist S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146200.mp4', 'http://timg.bdta.pro/images/55ca8b94f209234a9b7f81830bf8a2ab.jpg'),
(38491, 2678, 'Zoey e Sua Fantástica Playlist S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146201.mp4', 'http://timg.bdta.pro/images/0035a533b3574fa58a2e16f9d3f6990c.jpg'),
(38492, 2678, 'Zoey e Sua Fantástica Playlist S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146202.mp4', 'http://timg.bdta.pro/images/e7ae52e5c9f2cb0539477e274019ad4d.jpg'),
(38493, 2678, 'Zoey e Sua Fantástica Playlist S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146203.mp4', 'http://timg.bdta.pro/images/ebd16aa24ad6fff67a3b665f4c5faf4c.jpg'),
(38494, 2678, 'Zoey e Sua Fantástica Playlist S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146204.mp4', 'http://timg.bdta.pro/images/b03c4eb3d33e211c89b4ad001054ed47.jpg'),
(38495, 2678, 'Zoey e Sua Fantástica Playlist S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146205.mp4', 'http://timg.bdta.pro/images/ec10af4501bfc7c03d27147ee3128c4a.jpg'),
(38496, 2678, 'Zoey e Sua Fantástica Playlist S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146206.mp4', 'http://timg.bdta.pro/images/6a1c175eb2afd429e3c5af3c06256346.jpg'),
(38497, 2678, 'Zoey e Sua Fantástica Playlist S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146207.mp4', 'http://timg.bdta.pro/images/bee8fd96db72b51d44858c8e221585c8.jpg'),
(38498, 2678, 'Zoey e Sua Fantástica Playlist S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146208.mp4', 'http://timg.bdta.pro/images/3be96229a9110f36ba68d05653515ad5.jpg'),
(38499, 2678, 'Zoey e Sua Fantástica Playlist S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146209.mp4', 'http://timg.bdta.pro/images/48a1156025fb1996bdec96a019ba1292.jpg'),
(38500, 2679, 'Zoey e Sua Fantástica Playlist S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146210.mp4', 'http://gstaticontent.com/images/AlaZjoTFUAYhOL24P9AZor15wgH_big.jpg'),
(38501, 2679, 'Zoey e Sua Fantástica Playlist S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146211.mp4', 'http://gstaticontent.com/images/AlaZjoTFUAYhOL24P9AZor15wgH_big.jpg'),
(38502, 2679, 'Zoey e Sua Fantástica Playlist S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146212.mp4', 'http://gstaticontent.com/images/AlaZjoTFUAYhOL24P9AZor15wgH_big.jpg'),
(38503, 2679, 'Zoey e Sua Fantástica Playlist S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146213.mp4', 'http://gstaticontent.com/images/AlaZjoTFUAYhOL24P9AZor15wgH_big.jpg'),
(38504, 2679, 'Zoey e Sua Fantástica Playlist S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146214.mp4', 'http://gstaticontent.com/images/AlaZjoTFUAYhOL24P9AZor15wgH_big.jpg'),
(38505, 2679, 'Zoey e Sua Fantástica Playlist S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146215.mp4', 'http://gstaticontent.com/images/AlaZjoTFUAYhOL24P9AZor15wgH_big.jpg'),
(38506, 2679, 'Zoey e Sua Fantástica Playlist S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146216.mp4', 'http://gstaticontent.com/images/AlaZjoTFUAYhOL24P9AZor15wgH_big.jpg'),
(38507, 2679, 'Zoey e Sua Fantástica Playlist S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146217.mp4', 'http://gstaticontent.com/images/AlaZjoTFUAYhOL24P9AZor15wgH_big.jpg'),
(38508, 2679, 'Zoey e Sua Fantástica Playlist S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146218.mp4', 'http://gstaticontent.com/images/AlaZjoTFUAYhOL24P9AZor15wgH_big.jpg'),
(38509, 2679, 'Zoey e Sua Fantástica Playlist S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146219.mp4', 'http://gstaticontent.com/images/AlaZjoTFUAYhOL24P9AZor15wgH_big.jpg'),
(38510, 2679, 'Zoey e Sua Fantástica Playlist S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146220.mp4', 'http://gstaticontent.com/images/AlaZjoTFUAYhOL24P9AZor15wgH_big.jpg'),
(38511, 2679, 'Zoey e Sua Fantástica Playlist S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146221.mp4', 'http://gstaticontent.com/images/AlaZjoTFUAYhOL24P9AZor15wgH_big.jpg'),
(38512, 2679, 'Zoey e Sua Fantástica Playlist S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146222.mp4', 'http://gstaticontent.com/images/AlaZjoTFUAYhOL24P9AZor15wgH_big.jpg'),
(38513, 2680, 'Vampirina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132791.mp4', 'http://timg.bdta.pro/images/f4245e0171a6394c952704545430f9d5.jpg'),
(38514, 2680, 'Vampirina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132792.mp4', 'http://timg.bdta.pro/images/3602fdd5f80d1c0f186c56353598e88a.jpg'),
(38515, 2680, 'Vampirina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132793.mp4', 'http://timg.bdta.pro/images/42a7d0a9eb2ba115e0892858c3026548.jpg'),
(38516, 2680, 'Vampirina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132794.mp4', 'http://timg.bdta.pro/images/c8f5a8676166a86505fb922add31bb62.jpg'),
(38517, 2680, 'Vampirina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132795.mp4', 'http://timg.bdta.pro/images/62b03e8184699abd985c9c620db00449.jpg'),
(38518, 2680, 'Vampirina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132796.mp4', 'http://timg.bdta.pro/images/ba609537c563e1efd985ed7b34c1ffe2.jpg'),
(38519, 2680, 'Vampirina S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132797.mp4', 'http://timg.bdta.pro/images/c86317eb54b6fdd9ff463ded90dd0dc5.jpg'),
(38520, 2680, 'Vampirina S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132798.mp4', 'http://timg.bdta.pro/images/62b03e8184699abd985c9c620db00449.jpg'),
(38521, 2680, 'Vampirina S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132799.mp4', 'http://timg.bdta.pro/images/8c62fa8e6fdfd23a7e1ff36e196ba525.jpg'),
(38522, 2680, 'Vampirina S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132800.mp4', 'http://timg.bdta.pro/images/1843068536ccd9dfc83cac59afd1fc93.jpg'),
(38523, 2680, 'Vampirina S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132801.mp4', 'http://timg.bdta.pro/images/11b8949206432cd7d6bf7c4b99fe18fa.jpg'),
(38524, 2680, 'Vampirina S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132802.mp4', 'http://timg.bdta.pro/images/56efa221a42f59fabcc5e0f890faa086.jpg'),
(38525, 2680, 'Vampirina S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132803.mp4', 'http://timg.bdta.pro/images/277155eed0f0465d119fe21bb5328ee6.jpg'),
(38526, 2680, 'Vampirina S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132804.mp4', 'http://timg.bdta.pro/images/f6e23d10eb68b0445ef18924e7dc9d9c.jpg'),
(38527, 2680, 'Vampirina S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132805.mp4', 'http://timg.bdta.pro/images/4bd9d8a50ea6b75c87be16b21a74aa89.jpg'),
(38528, 2680, 'Vampirina S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132806.mp4', 'http://timg.bdta.pro/images/93778a75c8fd59037240fefc5506f531.jpg'),
(38529, 2680, 'Vampirina S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132807.mp4', 'http://timg.bdta.pro/images/2f45d1925818221d016db62cce3af1d3.jpg'),
(38530, 2680, 'Vampirina S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132808.mp4', 'http://timg.bdta.pro/images/b47deff987a683e1e46f18ce7d0011a6.jpg'),
(38531, 2680, 'Vampirina S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132809.mp4', 'http://timg.bdta.pro/images/c7e73a964759ace3a5858a597db44a36.jpg'),
(38532, 2680, 'Vampirina S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132810.mp4', 'http://timg.bdta.pro/images/abe3a661bcb38ce415730266654d4117.jpg'),
(38533, 2680, 'Vampirina S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132811.mp4', 'http://timg.bdta.pro/images/0459cb544eb62200726ae58b8442ce81.jpg'),
(38534, 2680, 'Vampirina S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132812.mp4', 'http://timg.bdta.pro/images/df8f3f5bd6a68a9468659c0ec7f60ee7.jpg'),
(38535, 2680, 'Vampirina S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/132813.mp4', 'http://timg.bdta.pro/images/a947dc8d6583b2c06f8417484117b06f.jpg'),
(38536, 2680, 'Vampirina S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/132814.mp4', 'http://timg.bdta.pro/images/b659fd6ffef3411dae58e860f54fa1f7.jpg'),
(38537, 2680, 'Vampirina S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/132815.mp4', 'http://timg.bdta.pro/images/240b1fceb126df7cfeb5cad6cb782136.jpg'),
(38538, 2681, 'Vampirina S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132816.mp4', 'http://timg.bdta.pro/images/9c03faaf9c81b8b7899afcddeaefc2bb.jpg'),
(38539, 2681, 'Vampirina S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132817.mp4', 'http://timg.bdta.pro/images/09f1b85e934745ae37ab44ffc7cf0cfe.jpg'),
(38540, 2681, 'Vampirina S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132818.mp4', 'http://gstaticontent.com/images/wGlzmtf0ae9vAFIthuU2CLNAUEL_big.jpg'),
(38541, 2681, 'Vampirina S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132819.mp4', 'http://timg.bdta.pro/images/18ac50b19e9fae256f6f25d82324dd2c.jpg'),
(38542, 2681, 'Vampirina S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132820.mp4', 'http://gstaticontent.com/images/wGlzmtf0ae9vAFIthuU2CLNAUEL_big.jpg'),
(38543, 2681, 'Vampirina S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132821.mp4', 'http://timg.bdta.pro/images/8588ae2638dc49c8df1e7759a4d00c05.jpg'),
(38544, 2681, 'Vampirina S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132822.mp4', 'http://gstaticontent.com/images/wGlzmtf0ae9vAFIthuU2CLNAUEL_big.jpg'),
(38545, 2681, 'Vampirina S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132823.mp4', 'http://timg.bdta.pro/images/3a15369470d0b479c053641b4ea1cc4c.jpg'),
(38546, 2681, 'Vampirina S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132824.mp4', 'http://gstaticontent.com/images/wGlzmtf0ae9vAFIthuU2CLNAUEL_big.jpg'),
(38547, 2681, 'Vampirina S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132825.mp4', 'http://timg.bdta.pro/images/eda4f01878d01a3690eaed06ce3ae3d0.jpg'),
(38548, 2681, 'Vampirina S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132826.mp4', 'http://timg.bdta.pro/images/dc7f78ed95a05da3b7947e3d9e287181.jpg'),
(38549, 2681, 'Vampirina S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132827.mp4', 'http://timg.bdta.pro/images/ade125fba7cfae605f1386b9d79c3144.jpg'),
(38550, 2681, 'Vampirina S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132828.mp4', 'http://timg.bdta.pro/images/aefa326f933536bb2e11e49abeff8cc0.jpg'),
(38551, 2681, 'Vampirina S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132829.mp4', 'http://gstaticontent.com/images/wGlzmtf0ae9vAFIthuU2CLNAUEL_big.jpg'),
(38552, 2681, 'Vampirina S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132830.mp4', 'http://timg.bdta.pro/images/d7c9a33786b50be92fe0415c4e346830.jpg'),
(38553, 2681, 'Vampirina S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132831.mp4', 'http://gstaticontent.com/images/wGlzmtf0ae9vAFIthuU2CLNAUEL_big.jpg'),
(38554, 2681, 'Vampirina S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132832.mp4', 'http://timg.bdta.pro/images/d84b0b6884440abe5389f69706113c5f.jpg'),
(38555, 2681, 'Vampirina S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132833.mp4', 'http://gstaticontent.com/images/wGlzmtf0ae9vAFIthuU2CLNAUEL_big.jpg'),
(38556, 2681, 'Vampirina S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132834.mp4', 'http://gstaticontent.com/images/wGlzmtf0ae9vAFIthuU2CLNAUEL_big.jpg'),
(38557, 2681, 'Vampirina S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132835.mp4', 'http://timg.bdta.pro/images/7a4fe439b7c646a16c2c71b5ab9d8f07.jpg'),
(38558, 2681, 'Vampirina S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132836.mp4', 'http://timg.bdta.pro/images/09f5ff0508580fd65ccada6d8b26ca4e.jpg'),
(38559, 2681, 'Vampirina S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132837.mp4', 'http://gstaticontent.com/images/wGlzmtf0ae9vAFIthuU2CLNAUEL_big.jpg'),
(38560, 2681, 'Vampirina S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/132838.mp4', 'http://timg.bdta.pro/images/4f71c6204206c1ca4815f1f4d6b7c1b4.jpg'),
(38561, 2682, 'Helstrom [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132084.mp4', 'http://timg.bdta.pro/images/b9fea5d34059cc9ad6e5f308eb165c52.jpg'),
(38562, 2682, 'Helstrom [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132085.mp4', 'http://timg.bdta.pro/images/61e300669fd6245f0308b5ab0da36757.jpg'),
(38563, 2682, 'Helstrom [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132086.mp4', 'http://timg.bdta.pro/images/155a7cdd3acb4ef259d4f88f154a27de.jpg'),
(38564, 2682, 'Helstrom [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132087.mp4', 'http://timg.bdta.pro/images/38856b56d4e931625809ef92fcd9446a.jpg'),
(38565, 2682, 'Helstrom [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132088.mp4', 'http://timg.bdta.pro/images/45ac5e2c409a83d3d491a6a1dce38883.jpg'),
(38566, 2682, 'Helstrom [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132089.mp4', 'http://timg.bdta.pro/images/a2843857c90c274fd26e9f264faa3c56.jpg'),
(38567, 2682, 'Helstrom [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132090.mp4', 'http://timg.bdta.pro/images/6f474c014f3b2fafbc2f83bfd0f16097.jpg'),
(38568, 2682, 'Helstrom [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132091.mp4', 'http://timg.bdta.pro/images/0554c8fd014cafddcb4db96c51f839ac.jpg'),
(38569, 2682, 'Helstrom [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132092.mp4', 'http://timg.bdta.pro/images/ce39b6a06fabdc5fcb6decbfef942184.jpg'),
(38570, 2682, 'Helstrom [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132093.mp4', 'http://timg.bdta.pro/images/a0199e614d71878864194337647e0185.jpg'),
(38571, 2683, 'Pokemon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192781.mp4', 'http://timg.bdta.pro/images/d7118746ca3c3a691cfcecab0f0ef3f9.jpg'),
(38572, 2683, 'Pokemon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192782.mp4', 'http://timg.bdta.pro/images/f36c2027dd3d732c6c4b2a17e28ce226.jpg'),
(38573, 2683, 'Pokemon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192783.mp4', 'http://timg.bdta.pro/images/3ff1a3a743cc98ebfa826bc90ee55d41.jpg'),
(38574, 2683, 'Pokemon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192784.mp4', 'http://timg.bdta.pro/images/01473acfc9b83b8acc511f963ffa7eac.jpg'),
(38575, 2683, 'Pokemon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192785.mp4', 'http://timg.bdta.pro/images/cb31b9d52de99e156b85ccf568db26bc.jpg'),
(38576, 2683, 'Pokemon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192786.mp4', 'http://timg.bdta.pro/images/169e4383c3a6ee0c3a4004d3859f587c.jpg'),
(38577, 2683, 'Pokemon S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192787.mp4', 'http://timg.bdta.pro/images/9618499ec9ceb5ef1961cea988c63162.jpg'),
(38578, 2683, 'Pokemon S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192788.mp4', 'http://timg.bdta.pro/images/f438bc6317ee7eaea2bd13e649e13c16.jpg'),
(38579, 2683, 'Pokemon S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192789.mp4', 'http://timg.bdta.pro/images/5dd3b2d63ec3ade3b1f0d23ccd3b2259.jpg'),
(38580, 2683, 'Pokemon S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192790.mp4', 'http://timg.bdta.pro/images/9a8d98c34b51314e8d331ee42de65ed3.jpg'),
(38581, 2683, 'Pokemon S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192791.mp4', 'http://timg.bdta.pro/images/5a03b6916fcf520e1337c43d7f218b79.jpg'),
(38582, 2683, 'Pokemon S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192792.mp4', 'http://timg.bdta.pro/images/c62f1feb9e272f57ec851593949a3c99.jpg'),
(38583, 2683, 'Pokemon S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/192793.mp4', 'http://timg.bdta.pro/images/1e43065eb5559ee8ed42675c72af4a5d.jpg'),
(38584, 2683, 'Pokemon S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/192794.mp4', 'http://timg.bdta.pro/images/d489431bd72659d43d06533e570f1cd9.jpg'),
(38585, 2683, 'Pokemon S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/192795.mp4', 'http://timg.bdta.pro/images/6b6c347eb158ad1ca0491e812d226165.jpg'),
(38586, 2683, 'Pokemon S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/192796.mp4', 'http://timg.bdta.pro/images/054e7fe2e7b6e45a9a8456bbda3f6506.jpg'),
(38587, 2683, 'Pokemon S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/192797.mp4', 'http://timg.bdta.pro/images/e0634a79771a1cbf475f122e4e55f657.jpg'),
(38588, 2683, 'Pokemon S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/192798.mp4', 'http://timg.bdta.pro/images/3ac89601704f2c49466768343e2226a1.jpg'),
(38589, 2683, 'Pokemon S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/192799.mp4', 'http://timg.bdta.pro/images/900e86a7e92159cbea1ba0c35f1473bb.jpg'),
(38590, 2683, 'Pokemon S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/192800.mp4', 'http://timg.bdta.pro/images/cdbc545f7b61103bff3ae4e4030b1fc7.jpg'),
(38591, 2683, 'Pokemon S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/192801.mp4', 'http://timg.bdta.pro/images/3abc37884dfcfbcf0d6ea9bfaffbf1ef.jpg'),
(38592, 2683, 'Pokemon S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/192802.mp4', 'http://timg.bdta.pro/images/a53ced7bdea4fbc6b91b2a6af856f8c3.jpg'),
(38593, 2683, 'Pokemon S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/192803.mp4', 'http://timg.bdta.pro/images/4f787560ba9ce4d29c4a1a0b6abdbc4c.jpg'),
(38594, 2683, 'Pokemon S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/192804.mp4', 'http://timg.bdta.pro/images/e3c670bd491e894d790b8e9e980e7314.jpg'),
(38595, 2683, 'Pokemon S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/192805.mp4', 'http://timg.bdta.pro/images/014153489678e8a82576323c7f295689.jpg'),
(38596, 2683, 'Pokemon S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/192806.mp4', 'http://timg.bdta.pro/images/619dfaeed98716df2e0d746e716d6bf1.jpg'),
(38597, 2683, 'Pokemon S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/192807.mp4', 'http://timg.bdta.pro/images/ec02e22487b8fee8341d2ca1ddc61884.jpg'),
(38598, 2683, 'Pokemon S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/192808.mp4', 'http://timg.bdta.pro/images/bb5efd0a8e61e702a2f852054a74cb47.jpg'),
(38599, 2683, 'Pokemon S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/192809.mp4', 'http://timg.bdta.pro/images/8b8f8ba23325f4dc82ab9ec48fcf1eb8.jpg'),
(38600, 2683, 'Pokemon S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/192810.mp4', 'http://timg.bdta.pro/images/e41fb3738edc3da7d54d4de6118ee1e6.jpg'),
(38601, 2683, 'Pokemon S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/192811.mp4', 'http://timg.bdta.pro/images/1d54972c6675c64ee58e1c9715e63aae.jpg'),
(38602, 2683, 'Pokemon S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/192812.mp4', 'http://timg.bdta.pro/images/164fc663acefb0cc11f9a6e0af51a511.jpg'),
(38603, 2683, 'Pokemon S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/192813.mp4', 'http://timg.bdta.pro/images/c5c14c9b618db2bb127e039b58491664.jpg'),
(38604, 2683, 'Pokemon S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/192814.mp4', 'http://timg.bdta.pro/images/b8bfc42ec9e3ac108ae3986bd583f31d.jpg'),
(38605, 2683, 'Pokemon S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/192815.mp4', 'http://timg.bdta.pro/images/d431ac97d0e7b99831fafd5aed3381cc.jpg'),
(38606, 2683, 'Pokemon S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/192816.mp4', 'http://timg.bdta.pro/images/740a2451fdde2668efa757744859a5ea.jpg'),
(38607, 2683, 'Pokemon S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/192817.mp4', 'http://timg.bdta.pro/images/63323960359010e947f419fb2bb0712e.jpg'),
(38608, 2683, 'Pokemon S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/192818.mp4', 'http://timg.bdta.pro/images/7177a480fdff01c9ca6f18234752c1a0.jpg'),
(38609, 2683, 'Pokemon S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/192819.mp4', 'http://timg.bdta.pro/images/2bb8b8c1191b30c1aa581bb8ee3bf70c.jpg'),
(38610, 2683, 'Pokemon S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/192820.mp4', 'http://timg.bdta.pro/images/084e02d3401958afe92023988a7ec686.jpg'),
(38611, 2683, 'Pokemon S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/192821.mp4', 'http://timg.bdta.pro/images/529ba06212f1c115ee466b37c24fb77b.jpg'),
(38612, 2683, 'Pokemon S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/192822.mp4', 'http://timg.bdta.pro/images/57ceb653a700b4c1b917dc3c0017daf0.jpg'),
(38613, 2683, 'Pokemon S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/192823.mp4', 'http://timg.bdta.pro/images/4814f9d051a02f345706ae66c42399bb.jpg'),
(38614, 2683, 'Pokemon S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/192824.mp4', 'http://timg.bdta.pro/images/f82fede2bc4fad230ac1b1e0e53c965f.jpg'),
(38615, 2683, 'Pokemon S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/192825.mp4', 'http://timg.bdta.pro/images/3a7144a060fc30d069a02e75dcb9451c.jpg'),
(38616, 2683, 'Pokemon S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/192826.mp4', 'http://timg.bdta.pro/images/4b61519398795fda9fd384e13533af38.jpg'),
(38617, 2683, 'Pokemon S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/192827.mp4', 'http://timg.bdta.pro/images/361f350cb2748db5c3c77c05b65b484e.jpg'),
(38618, 2683, 'Pokemon S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/192828.mp4', 'http://timg.bdta.pro/images/b97b8498800397189e46d99d06238dd3.jpg'),
(38619, 2683, 'Pokemon S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/192829.mp4', 'http://timg.bdta.pro/images/33cd31ad08537cd2ff64db0e2a519f7f.jpg'),
(38620, 2683, 'Pokemon S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/192830.mp4', 'http://timg.bdta.pro/images/9d0a8872b34ba6aba95e60db795fa379.jpg'),
(38621, 2683, 'Pokemon S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/192831.mp4', 'http://timg.bdta.pro/images/7fd19d16444b822300d15771006aec99.jpg'),
(38622, 2683, 'Pokemon S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/192832.mp4', 'http://timg.bdta.pro/images/6132d3244aefc24eb6842b58a7248fe0.jpg'),
(38623, 2683, 'Pokemon S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/192833.mp4', 'http://timg.bdta.pro/images/15966f4ed130dd07450825a456f3cc98.jpg'),
(38624, 2683, 'Pokemon S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/192834.mp4', 'http://timg.bdta.pro/images/579b64cdadc3f642ebe89b4b8d645b23.jpg'),
(38625, 2683, 'Pokemon S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/192835.mp4', 'http://timg.bdta.pro/images/9d7710ddb5f19364e982919bdb34095b.jpg'),
(38626, 2683, 'Pokemon S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/192836.mp4', 'http://timg.bdta.pro/images/40bb0c7377ee4467683788e78ea164b0.jpg'),
(38627, 2683, 'Pokemon S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/192837.mp4', 'http://timg.bdta.pro/images/3c0e418be998e037fd1343a2e0d4b4a3.jpg'),
(38628, 2683, 'Pokemon S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/192838.mp4', 'http://timg.bdta.pro/images/0bef8f6ee5bd4b24e1c228cdeb52b35f.jpg'),
(38629, 2683, 'Pokemon S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/192839.mp4', 'http://timg.bdta.pro/images/37bcdbbb02b4ccb44ecf54005349ab5b.jpg'),
(38630, 2683, 'Pokemon S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/192840.mp4', 'http://timg.bdta.pro/images/7f610f2ebc9ca4cd3c4097afbe95a843.jpg'),
(38631, 2683, 'Pokemon S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/192841.mp4', 'http://timg.bdta.pro/images/06c62ef3bd449c88937e63a3d86ce4d8.jpg'),
(38632, 2683, 'Pokemon S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/192842.mp4', 'http://timg.bdta.pro/images/9dc77c51d2653e36696e3137d9c78e75.jpg'),
(38633, 2683, 'Pokemon S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/192843.mp4', 'http://timg.bdta.pro/images/7f4650448124c633613b7eea750f055d.jpg'),
(38634, 2683, 'Pokemon S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/192844.mp4', 'http://timg.bdta.pro/images/148f42055e5ef00cb76086bf874b8142.jpg'),
(38635, 2683, 'Pokemon S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/192845.mp4', 'http://timg.bdta.pro/images/a5dcf7f887cfbb17a97838b800dc7df5.jpg'),
(38636, 2683, 'Pokemon S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/192846.mp4', 'http://timg.bdta.pro/images/97272a917511f3cf91bd3896a355a133.jpg'),
(38637, 2683, 'Pokemon S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/192847.mp4', 'http://timg.bdta.pro/images/b52cdb6eebf61a9e7744aa1d60c8a343.jpg'),
(38638, 2683, 'Pokemon S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/192848.mp4', 'http://timg.bdta.pro/images/f7706fc8069fb4591f90f23a1b00a02b.jpg'),
(38639, 2683, 'Pokemon S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/192849.mp4', 'http://timg.bdta.pro/images/96e6967e18d008926f2fb8d5994a23fc.jpg'),
(38640, 2683, 'Pokemon S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/192850.mp4', 'http://timg.bdta.pro/images/fb92345ba352d3cfb296cdac8a4f8763.jpg'),
(38641, 2683, 'Pokemon S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/192851.mp4', 'http://timg.bdta.pro/images/0fb4a51a007c2af9e35bc9e1b7b8b1a8.jpg'),
(38642, 2683, 'Pokemon S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/192852.mp4', 'http://timg.bdta.pro/images/63a617ac23ff41d57b264d323c2d9c06.jpg'),
(38643, 2683, 'Pokemon S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/192853.mp4', 'http://timg.bdta.pro/images/6187cb15489bf917b7e22d4f6e79785d.jpg'),
(38644, 2683, 'Pokemon S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/192854.mp4', 'http://timg.bdta.pro/images/fc9405d20cd514e638e19af224a7af3d.jpg'),
(38645, 2683, 'Pokemon S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/192855.mp4', 'http://timg.bdta.pro/images/4fc843b92ba305f45a01a4e75b34bceb.jpg'),
(38646, 2683, 'Pokemon S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/192856.mp4', 'http://timg.bdta.pro/images/cdcbf00f07ee93aa90f4163c6806d02a.jpg'),
(38647, 2683, 'Pokemon S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/192857.mp4', 'http://timg.bdta.pro/images/f748bc4e0eaed96dcd12bc799b1c3318.jpg'),
(38648, 2683, 'Pokemon S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/192858.mp4', 'http://timg.bdta.pro/images/16671c3389c653d51ce417e8020f80b4.jpg'),
(38649, 2683, 'Pokemon S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/192859.mp4', 'http://timg.bdta.pro/images/093d5250d66c3fe74db671fce04111e7.jpg'),
(38650, 2683, 'Pokemon S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/192860.mp4', 'http://timg.bdta.pro/images/976d68c8c4ad2c5a5d41cfab28050347.jpg'),
(38651, 2683, 'Pokemon S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/192861.mp4', 'http://timg.bdta.pro/images/d76e9cce61b1139a6d5a4da8483320b0.jpg'),
(38652, 2683, 'Pokemon S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/192862.mp4', 'http://timg.bdta.pro/images/ae239edd059ac18e2cd13a016bf2e11a.jpg'),
(38653, 2684, 'Pokemon S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192863.mp4', 'http://timg.bdta.pro/images/5f741096f00f850619021fc37590baf0.jpg'),
(38654, 2684, 'Pokemon S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192864.mp4', 'http://timg.bdta.pro/images/8ea784aaf53da03153e16d054866ac16.jpg'),
(38655, 2684, 'Pokemon S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192865.mp4', 'http://timg.bdta.pro/images/ef5ac47497767625c404463215654eff.jpg'),
(38656, 2684, 'Pokemon S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192866.mp4', 'http://timg.bdta.pro/images/9b8d6fca3c80f5072f093190f15a9831.jpg'),
(38657, 2684, 'Pokemon S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192867.mp4', 'http://timg.bdta.pro/images/8d0d09c61991dc1b991adee6e1690d30.jpg'),
(38658, 2684, 'Pokemon S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192868.mp4', 'http://timg.bdta.pro/images/3ad3f17a043aac7c1663c2415c911204.jpg'),
(38659, 2684, 'Pokemon S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192869.mp4', 'http://timg.bdta.pro/images/e59da699007f6b747e0ec1dd81fb6db5.jpg'),
(38660, 2684, 'Pokemon S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192870.mp4', 'http://timg.bdta.pro/images/e8e2a0848a1cabdd6f3f4640ae4d8a5b.jpg'),
(38661, 2684, 'Pokemon S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192871.mp4', 'http://timg.bdta.pro/images/68f209abb728483ff56e88301b6f6fc1.jpg'),
(38662, 2684, 'Pokemon S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192872.mp4', 'http://timg.bdta.pro/images/27085f5d86d9e2d795ff0bde2c30ae42.jpg'),
(38663, 2684, 'Pokemon S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192873.mp4', 'http://timg.bdta.pro/images/6405e604c96c0c77fb432630a04b4ef6.jpg'),
(38664, 2684, 'Pokemon S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192874.mp4', 'http://timg.bdta.pro/images/4b7c84add0d1ebbc5cd1d5abd4fbd79f.jpg'),
(38665, 2684, 'Pokemon S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/192875.mp4', 'http://timg.bdta.pro/images/c96b8cb4141828afa54bbbee4e8129b1.jpg'),
(38666, 2684, 'Pokemon S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/192876.mp4', 'http://timg.bdta.pro/images/458537f856a873d990a73bf444af4d3d.jpg'),
(38667, 2684, 'Pokemon S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/192877.mp4', 'http://timg.bdta.pro/images/b9a163a764dc538ef42f42487f3f8f62.jpg'),
(38668, 2684, 'Pokemon S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/192878.mp4', 'http://timg.bdta.pro/images/eeec8f403bffd49da8478bb204e8d963.jpg'),
(38669, 2684, 'Pokemon S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/192879.mp4', 'http://timg.bdta.pro/images/14a105c0525cfe9e1ec323ac753682cc.jpg'),
(38670, 2684, 'Pokemon S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/192880.mp4', 'http://timg.bdta.pro/images/5047db9f863a53c74f4fffea9516e0c3.jpg'),
(38671, 2684, 'Pokemon S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/192881.mp4', 'http://timg.bdta.pro/images/0d305000db922dcfeb16091e4555a48b.jpg'),
(38672, 2684, 'Pokemon S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/192882.mp4', 'http://timg.bdta.pro/images/115571453c3e12dd9b7dc60366602056.jpg'),
(38673, 2684, 'Pokemon S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/192883.mp4', 'http://timg.bdta.pro/images/dc46f3fcd2f85131cc50f9e22b36c7b1.jpg'),
(38674, 2684, 'Pokemon S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/192884.mp4', 'http://timg.bdta.pro/images/b802a1359a9c0fb06c933685584baf10.jpg'),
(38675, 2684, 'Pokemon S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/192885.mp4', 'http://timg.bdta.pro/images/c187b29fabbc4a19d1023cda4ccc41cb.jpg'),
(38676, 2684, 'Pokemon S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/192886.mp4', 'http://timg.bdta.pro/images/67107355efe9bfbbe23a84bb409b6766.jpg'),
(38677, 2684, 'Pokemon S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/192887.mp4', 'http://timg.bdta.pro/images/035c886e369bd31844972fd8eb534b43.jpg'),
(38678, 2684, 'Pokemon S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/192888.mp4', 'http://timg.bdta.pro/images/8b06a4fc8a39adf1a404b962e0c90548.jpg'),
(38679, 2684, 'Pokemon S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/192889.mp4', 'http://timg.bdta.pro/images/59367a2e062c29d0d6ef50d7cafe047a.jpg'),
(38680, 2684, 'Pokemon S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/192890.mp4', 'http://timg.bdta.pro/images/ced668fcb0d31e0a8857ceba070d3a3e.jpg'),
(38681, 2684, 'Pokemon S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/192891.mp4', 'http://timg.bdta.pro/images/7c573b505e611abbd233a1f70ab07f80.jpg'),
(38682, 2684, 'Pokemon S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/192892.mp4', 'http://timg.bdta.pro/images/4d4239b736e39a404433ae7735d28b0e.jpg'),
(38683, 2684, 'Pokemon S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/192893.mp4', 'http://timg.bdta.pro/images/06e0f0f918ac22cac6fa75132654e82e.jpg'),
(38684, 2684, 'Pokemon S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/192894.mp4', 'http://timg.bdta.pro/images/48691b4e689e8f04694fc6aae7cce88f.jpg'),
(38685, 2684, 'Pokemon S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/192895.mp4', 'http://timg.bdta.pro/images/7eb202277c73035d587ef7320f28e5cc.jpg'),
(38686, 2684, 'Pokemon S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/192896.mp4', 'http://timg.bdta.pro/images/fedf1a03dac3de40e2d3d90507955569.jpg'),
(38687, 2684, 'Pokemon S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/192897.mp4', 'http://timg.bdta.pro/images/cbdbf4b8c5978c3c49a7b18460475ea3.jpg'),
(38688, 2684, 'Pokemon S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/192898.mp4', 'http://timg.bdta.pro/images/f58bb57dfc27ed1fb4dc1d9890843ba1.jpg'),
(38689, 2685, 'Pokemon S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192899.mp4', 'http://timg.bdta.pro/images/a3065d82ba1b1b5a232bc4aa5e3015f7.jpg'),
(38690, 2685, 'Pokemon S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192900.mp4', 'http://timg.bdta.pro/images/3faea3d43ed2ab7cd20314303b0055db.jpg'),
(38691, 2685, 'Pokemon S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192901.mp4', 'http://timg.bdta.pro/images/864a0045c55382e71cffb45a3e2d0c17.jpg'),
(38692, 2685, 'Pokemon S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192902.mp4', 'http://timg.bdta.pro/images/9df7da45a8c9e5a1acaf703b26bc9f4a.jpg'),
(38693, 2685, 'Pokemon S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192903.mp4', 'http://timg.bdta.pro/images/ef33a60b07f3713c72e6bd7dba594b12.jpg'),
(38694, 2685, 'Pokemon S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192904.mp4', 'http://timg.bdta.pro/images/388c5079f1699ef4931ed2e875f2c16e.jpg'),
(38695, 2685, 'Pokemon S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192905.mp4', 'http://timg.bdta.pro/images/6826c4ca8b52d007823e6d4553993d09.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(38696, 2685, 'Pokemon S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192906.mp4', 'http://timg.bdta.pro/images/97f4b5278846aeae7cbc2e5b657f6e8b.jpg'),
(38697, 2685, 'Pokemon S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192907.mp4', 'http://timg.bdta.pro/images/1a026961f1803d796635ea06a7d2bfad.jpg'),
(38698, 2685, 'Pokemon S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192908.mp4', 'http://timg.bdta.pro/images/848786d2a15b251e63b616a7ab07751a.jpg'),
(38699, 2685, 'Pokemon S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192909.mp4', 'http://timg.bdta.pro/images/f31d88961b6597245b903e0b93bd61c2.jpg'),
(38700, 2685, 'Pokemon S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192910.mp4', 'http://timg.bdta.pro/images/b93d816bc9091340cc142d7f45d89741.jpg'),
(38701, 2685, 'Pokemon S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/192911.mp4', 'http://timg.bdta.pro/images/df589e18a6b05ca6dd1eaf6bdbe0384a.jpg'),
(38702, 2685, 'Pokemon S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/192912.mp4', 'http://timg.bdta.pro/images/d6015941f14180a713f7eed4f376f9c4.jpg'),
(38703, 2685, 'Pokemon S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/192913.mp4', 'http://timg.bdta.pro/images/062b960ca27d46979fc20780ad3acf6a.jpg'),
(38704, 2685, 'Pokemon S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/192914.mp4', 'http://timg.bdta.pro/images/fc6e7f85bd95e4b9713472892fe1ef9e.jpg'),
(38705, 2685, 'Pokemon S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/192915.mp4', 'http://timg.bdta.pro/images/eccde17ea156c37c255918a9801279b1.jpg'),
(38706, 2685, 'Pokemon S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/192916.mp4', 'http://timg.bdta.pro/images/b386722d72a40e3b5e1e3de46e39f59d.jpg'),
(38707, 2685, 'Pokemon S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/192917.mp4', 'http://timg.bdta.pro/images/aab5351ab8e39b8b362029f24892112a.jpg'),
(38708, 2685, 'Pokemon S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/192918.mp4', 'http://timg.bdta.pro/images/d13247a7b8c0ae4f4401298cb1e87b2d.jpg'),
(38709, 2685, 'Pokemon S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/192919.mp4', 'http://timg.bdta.pro/images/e713702a21513b341cd417380ec70736.jpg'),
(38710, 2685, 'Pokemon S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/192920.mp4', 'http://timg.bdta.pro/images/d3335dc0f08af4ef7b424b2d1bd33322.jpg'),
(38711, 2685, 'Pokemon S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/192921.mp4', 'http://timg.bdta.pro/images/32d14eaedc8599ba1d34e7885ea77637.jpg'),
(38712, 2685, 'Pokemon S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/192922.mp4', 'http://timg.bdta.pro/images/c30549f82762bdcaa96be57e9e433ba4.jpg'),
(38713, 2685, 'Pokemon S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/192923.mp4', 'http://timg.bdta.pro/images/4b91e59aebb643d494d416a6063fdd50.jpg'),
(38714, 2685, 'Pokemon S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/192924.mp4', 'http://timg.bdta.pro/images/2a20d57a25fdbe92f0e35a21bca1bb04.jpg'),
(38715, 2685, 'Pokemon S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/192925.mp4', 'http://timg.bdta.pro/images/082c844654cb43d83ce58a04f5c18114.jpg'),
(38716, 2685, 'Pokemon S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/192926.mp4', 'http://timg.bdta.pro/images/661202a1438fbdb665ed7248b9fcc723.jpg'),
(38717, 2685, 'Pokemon S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/192927.mp4', 'http://timg.bdta.pro/images/1200190534bf58c5bb9ca568183f3d86.jpg'),
(38718, 2685, 'Pokemon S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/192928.mp4', 'http://timg.bdta.pro/images/40703adeeb456f8069f1ac1dc5da760b.jpg'),
(38719, 2685, 'Pokemon S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/192929.mp4', 'http://timg.bdta.pro/images/3b8cbfd1626437904b0e5058c207b681.jpg'),
(38720, 2685, 'Pokemon S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/192930.mp4', 'http://timg.bdta.pro/images/680eeb0b0c2726f294efad9357626672.jpg'),
(38721, 2685, 'Pokemon S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/192931.mp4', 'http://timg.bdta.pro/images/53d31266d5458903770d783fd3ef1026.jpg'),
(38722, 2685, 'Pokemon S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/192932.mp4', 'http://timg.bdta.pro/images/f4c6a8f49fa1da1d42dffd55b2c41b59.jpg'),
(38723, 2685, 'Pokemon S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/192933.mp4', 'http://timg.bdta.pro/images/be5a88c011c969a90a09c714ae83f60f.jpg'),
(38724, 2685, 'Pokemon S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/192934.mp4', 'http://timg.bdta.pro/images/69e708c91b3b9117947c68588de3ff82.jpg'),
(38725, 2685, 'Pokemon S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/192935.mp4', 'http://timg.bdta.pro/images/7199e54a783666bfd5962eb34f760b6a.jpg'),
(38726, 2685, 'Pokemon S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/192936.mp4', 'http://timg.bdta.pro/images/28629aa18d77006f684bd4bba9729402.jpg'),
(38727, 2685, 'Pokemon S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/192937.mp4', 'http://timg.bdta.pro/images/3fde57cccd6bae4da939b93486250ee8.jpg'),
(38728, 2685, 'Pokemon S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/192938.mp4', 'http://timg.bdta.pro/images/0282e7a015da4d03d24337170b2f1555.jpg'),
(38729, 2685, 'Pokemon S03 E41', 'http://sinalprivado.info:80/series/1533784/1533784/192939.mp4', 'http://timg.bdta.pro/images/b339bf4c03059afb4ed46df88336b635.jpg'),
(38730, 2686, 'Pokemon S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192940.mp4', 'http://timg.bdta.pro/images/6bf7f0457ab1fe2f23098761669457de.jpg'),
(38731, 2686, 'Pokemon S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192941.mp4', 'http://timg.bdta.pro/images/13a8fca96ba24df2546cd4e90aff6426.jpg'),
(38732, 2686, 'Pokemon S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192942.mp4', 'http://timg.bdta.pro/images/f87157f46ee88b329983917b280b00fe.jpg'),
(38733, 2686, 'Pokemon S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192943.mp4', 'http://timg.bdta.pro/images/a68a16e913c49430fcd3b625fcf5bf7d.jpg'),
(38734, 2686, 'Pokemon S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192944.mp4', 'http://timg.bdta.pro/images/b5cb722d8add98aa0f9eb9e348d6986a.jpg'),
(38735, 2686, 'Pokemon S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192945.mp4', 'http://timg.bdta.pro/images/03e40e93019d67eee6cfc1a58e03def5.jpg'),
(38736, 2686, 'Pokemon S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192946.mp4', 'http://timg.bdta.pro/images/1f785edaeb713610414cb9203caeec02.jpg'),
(38737, 2686, 'Pokemon S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192947.mp4', 'http://timg.bdta.pro/images/2593036b2b54e2e4fa00b6312141e02f.jpg'),
(38738, 2686, 'Pokemon S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192948.mp4', 'http://timg.bdta.pro/images/bc959a948826913c48d0a0518b0ddc41.jpg'),
(38739, 2686, 'Pokemon S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192949.mp4', 'http://timg.bdta.pro/images/054c73c01adb7aa64ffd0d1641d87497.jpg'),
(38740, 2686, 'Pokemon S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192950.mp4', 'http://timg.bdta.pro/images/5669b558e2743b25fdf942e7689dd6db.jpg'),
(38741, 2686, 'Pokemon S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192951.mp4', 'http://timg.bdta.pro/images/3923844b97bc56d15c27110917d00e86.jpg'),
(38742, 2686, 'Pokemon S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/192952.mp4', 'http://timg.bdta.pro/images/b39f17e83c124db38cbe25a8b5c3d166.jpg'),
(38743, 2686, 'Pokemon S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/192953.mp4', 'http://timg.bdta.pro/images/f3ac3c051aeab4abafb7e408aca650d1.jpg'),
(38744, 2686, 'Pokemon S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/192954.mp4', 'http://timg.bdta.pro/images/875b1f0684c6afbbe481a837f9cf63d6.jpg'),
(38745, 2686, 'Pokemon S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/192955.mp4', 'http://timg.bdta.pro/images/03eaa0a7c033a064ef542a8de993f23f.jpg'),
(38746, 2686, 'Pokemon S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/192956.mp4', 'http://timg.bdta.pro/images/3b018c1a19dab34da42bf653966656e0.jpg'),
(38747, 2686, 'Pokemon S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/192957.mp4', 'http://timg.bdta.pro/images/b69dfee6e2bcec90f675d263d0aaff8c.jpg'),
(38748, 2686, 'Pokemon S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/192958.mp4', 'http://timg.bdta.pro/images/319b3840cf5f6d0f76670af81563cbe1.jpg'),
(38749, 2686, 'Pokemon S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/192959.mp4', 'http://timg.bdta.pro/images/0fcb282bcf2ed672748be382f3df276c.jpg'),
(38750, 2686, 'Pokemon S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/192960.mp4', 'http://timg.bdta.pro/images/491f0db0ca349dc58f9f5c75e5aa4504.jpg'),
(38751, 2686, 'Pokemon S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/192961.mp4', 'http://timg.bdta.pro/images/475b295a9e112a3eece34977dd0c1b59.jpg'),
(38752, 2686, 'Pokemon S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/192962.mp4', 'http://timg.bdta.pro/images/a574bb055ff2871a742a1868f259bdff.jpg'),
(38753, 2686, 'Pokemon S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/192963.mp4', 'http://timg.bdta.pro/images/5cf6d74bcdd702060b9d9d74d79fa590.jpg'),
(38754, 2686, 'Pokemon S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/192964.mp4', 'http://timg.bdta.pro/images/233215de31e7fbc64b8227601b60037a.jpg'),
(38755, 2686, 'Pokemon S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/192965.mp4', 'http://timg.bdta.pro/images/28d653b59bb5198d33b88c1ff2d259a8.jpg'),
(38756, 2686, 'Pokemon S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/192966.mp4', 'http://timg.bdta.pro/images/5a6f5ae0c094e3fc62279039bbd40eca.jpg'),
(38757, 2686, 'Pokemon S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/192967.mp4', 'http://timg.bdta.pro/images/a721a6a541be9575cb04f0424fa94d40.jpg'),
(38758, 2686, 'Pokemon S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/192968.mp4', 'http://timg.bdta.pro/images/39d1c7228e177894b1d864c50adfdb41.jpg'),
(38759, 2686, 'Pokemon S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/192969.mp4', 'http://timg.bdta.pro/images/859fc856edc89ee1ea6b7f4e5eab81dd.jpg'),
(38760, 2686, 'Pokemon S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/192970.mp4', 'http://timg.bdta.pro/images/85355ce93d0d11dfcc2d73c7e535cd0a.jpg'),
(38761, 2686, 'Pokemon S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/192971.mp4', 'http://timg.bdta.pro/images/e99f48cd4668efce7e530a5517b01918.jpg'),
(38762, 2686, 'Pokemon S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/192972.mp4', 'http://timg.bdta.pro/images/ca6495198dafa08799a0dc817f06d338.jpg'),
(38763, 2686, 'Pokemon S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/192973.mp4', 'http://timg.bdta.pro/images/1215c9d8f2ee6df6a27873e87e2fbaed.jpg'),
(38764, 2686, 'Pokemon S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/192974.mp4', 'http://timg.bdta.pro/images/459addeca011a3df6e29fd3edbb817dc.jpg'),
(38765, 2686, 'Pokemon S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/192975.mp4', 'http://timg.bdta.pro/images/7ec5eb2f3144a29b73bd31625df2abe0.jpg'),
(38766, 2686, 'Pokemon S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/192976.mp4', 'http://timg.bdta.pro/images/ef1a49606bcd415f40e8e3fdff56790e.jpg'),
(38767, 2686, 'Pokemon S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/192977.mp4', 'http://timg.bdta.pro/images/2633231613a2bfbe2e34cc3f9b97f09a.jpg'),
(38768, 2686, 'Pokemon S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/192978.mp4', 'http://timg.bdta.pro/images/c7cdcab3b3351e0feb37445c0a32e728.jpg'),
(38769, 2686, 'Pokemon S04 E40', 'http://sinalprivado.info:80/series/1533784/1533784/192979.mp4', 'http://timg.bdta.pro/images/f146503c888959e0144bdb0dfab7c25c.jpg'),
(38770, 2686, 'Pokemon S04 E41', 'http://sinalprivado.info:80/series/1533784/1533784/192980.mp4', 'http://timg.bdta.pro/images/56399d5cdb0b116b763b6af4ad777eaf.jpg'),
(38771, 2686, 'Pokemon S04 E42', 'http://sinalprivado.info:80/series/1533784/1533784/192981.mp4', 'http://timg.bdta.pro/images/670fa6aa8bd58157b3236e9e91692a6b.jpg'),
(38772, 2686, 'Pokemon S04 E43', 'http://sinalprivado.info:80/series/1533784/1533784/192982.mp4', 'http://timg.bdta.pro/images/421f66890438cb31e3819df521ea746e.jpg'),
(38773, 2686, 'Pokemon S04 E44', 'http://sinalprivado.info:80/series/1533784/1533784/192983.mp4', 'http://timg.bdta.pro/images/63ffc627b9acc29026d48c3f80604c69.jpg'),
(38774, 2686, 'Pokemon S04 E45', 'http://sinalprivado.info:80/series/1533784/1533784/192984.mp4', 'http://timg.bdta.pro/images/2534fa72d7173dab8643a0936d48e0bf.jpg'),
(38775, 2686, 'Pokemon S04 E46', 'http://sinalprivado.info:80/series/1533784/1533784/192985.mp4', 'http://timg.bdta.pro/images/32c9e99d25ac18d6ec1e0647ea02303b.jpg'),
(38776, 2686, 'Pokemon S04 E47', 'http://sinalprivado.info:80/series/1533784/1533784/192986.mp4', 'http://timg.bdta.pro/images/62dc73465ce8822d21c36e94ecd5b36f.jpg'),
(38777, 2686, 'Pokemon S04 E48', 'http://sinalprivado.info:80/series/1533784/1533784/192987.mp4', 'http://timg.bdta.pro/images/9fd03022ed6637bba433fe959ea8699f.jpg'),
(38778, 2686, 'Pokemon S04 E49', 'http://sinalprivado.info:80/series/1533784/1533784/192988.mp4', 'http://timg.bdta.pro/images/a6db30a3b291a21927ee838766b93b97.jpg'),
(38779, 2686, 'Pokemon S04 E50', 'http://sinalprivado.info:80/series/1533784/1533784/192989.mp4', 'http://timg.bdta.pro/images/4c82e27b199808b847bf7ce593c283e8.jpg'),
(38780, 2686, 'Pokemon S04 E51', 'http://sinalprivado.info:80/series/1533784/1533784/192990.mp4', 'http://timg.bdta.pro/images/b5877d2e0e0b4ef075bb518c275c5680.jpg'),
(38781, 2686, 'Pokemon S04 E52', 'http://sinalprivado.info:80/series/1533784/1533784/192991.mp4', 'http://timg.bdta.pro/images/ad7437a7c199c62e8be5d9dd9a5999f5.jpg'),
(38782, 2687, 'Pokemon S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192992.mp4', 'http://timg.bdta.pro/images/127a9b82097d73dfc42090a611499e04.jpg'),
(38783, 2687, 'Pokemon S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192993.mp4', 'http://timg.bdta.pro/images/1876f54d1f237c39d24bdb9498d0f702.jpg'),
(38784, 2687, 'Pokemon S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192994.mp4', 'http://timg.bdta.pro/images/5c9123320e31f2da188cdac01aaed2a3.jpg'),
(38785, 2687, 'Pokemon S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192995.mp4', 'http://timg.bdta.pro/images/812e9b2a9113fbd0dbc4410d920846e3.jpg'),
(38786, 2687, 'Pokemon S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192996.mp4', 'http://timg.bdta.pro/images/750c5541d166e7eb7f0716b099c3f689.jpg'),
(38787, 2687, 'Pokemon S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192997.mp4', 'http://timg.bdta.pro/images/227e7d1ffa75c6c9b4efed33780253f0.jpg'),
(38788, 2687, 'Pokemon S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192998.mp4', 'http://timg.bdta.pro/images/44dce89bb2635fc8b065258840c163b4.jpg'),
(38789, 2687, 'Pokemon S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192999.mp4', 'http://timg.bdta.pro/images/9ab9a33815aafbf89e77c3cee6767924.jpg'),
(38790, 2687, 'Pokemon S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193000.mp4', 'http://timg.bdta.pro/images/400cf94cd15e9107a7badfa89216d317.jpg'),
(38791, 2687, 'Pokemon S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193001.mp4', 'http://timg.bdta.pro/images/4c9ce3f8ef3dfb00df3fb2e951700077.jpg'),
(38792, 2687, 'Pokemon S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193002.mp4', 'http://timg.bdta.pro/images/8e0ee86495a8f2c55114838b5da14a8e.jpg'),
(38793, 2687, 'Pokemon S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193003.mp4', 'http://timg.bdta.pro/images/1f5546d1280a0986af84b456d5eb6e4c.jpg'),
(38794, 2687, 'Pokemon S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193004.mp4', 'http://timg.bdta.pro/images/a606d7ce7b3121d2fd970e393219f573.jpg'),
(38795, 2687, 'Pokemon S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/193005.mp4', 'http://timg.bdta.pro/images/1532080b5fdf9ffd9e075e785ee6ce2e.jpg'),
(38796, 2687, 'Pokemon S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/193006.mp4', 'http://timg.bdta.pro/images/317b85bc1a352ab03e567eabe56fd0ff.jpg'),
(38797, 2687, 'Pokemon S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/193007.mp4', 'http://timg.bdta.pro/images/40dba04b54adb87a44048e69953bc983.jpg'),
(38798, 2687, 'Pokemon S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/193008.mp4', 'http://timg.bdta.pro/images/59cc4706221037b9dc2d3791c567be7f.jpg'),
(38799, 2687, 'Pokemon S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/193009.mp4', 'http://timg.bdta.pro/images/2ee91e571b55f38dbbc4296880070a4e.jpg'),
(38800, 2687, 'Pokemon S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/193010.mp4', 'http://timg.bdta.pro/images/1667ba88eb42e45a8fa6e43e8f41be4e.jpg'),
(38801, 2687, 'Pokemon S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/193011.mp4', 'http://timg.bdta.pro/images/2bce9c6fc7eac4e5f3f9f08ce1512a61.jpg'),
(38802, 2687, 'Pokemon S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/193012.mp4', 'http://timg.bdta.pro/images/8caa76e702270c253e0530162f488469.jpg'),
(38803, 2687, 'Pokemon S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/193013.mp4', 'http://timg.bdta.pro/images/65514f9bd16f508a889811a5e8f8bb7e.jpg'),
(38804, 2687, 'Pokemon S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/193014.mp4', 'http://timg.bdta.pro/images/c069d3c84511fce3e67a71d247f4faf8.jpg'),
(38805, 2687, 'Pokemon S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/193015.mp4', 'http://timg.bdta.pro/images/9bf894dfd93b96978c27df8716a95da6.jpg'),
(38806, 2687, 'Pokemon S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/193016.mp4', 'http://timg.bdta.pro/images/01ce4cdbb161bf3af03ef1479de04fe1.jpg'),
(38807, 2687, 'Pokemon S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/193017.mp4', 'http://timg.bdta.pro/images/a20c2a23f9d2d46d9b2a7dd1bb2ca8ed.jpg'),
(38808, 2687, 'Pokemon S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/193018.mp4', 'http://timg.bdta.pro/images/5a97f3a4307a518c56d9d05bb3fe160d.jpg'),
(38809, 2687, 'Pokemon S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/193019.mp4', 'http://timg.bdta.pro/images/28338c6fdbc28218ec7020e2fde7be8c.jpg'),
(38810, 2687, 'Pokemon S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/193020.mp4', 'http://timg.bdta.pro/images/54e34e71a05b17b4347016f10d36c999.jpg'),
(38811, 2687, 'Pokemon S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/193021.mp4', 'http://timg.bdta.pro/images/b3d0d440c77658aaa27760e22157a49a.jpg'),
(38812, 2687, 'Pokemon S05 E31', 'http://sinalprivado.info:80/series/1533784/1533784/193022.mp4', 'http://timg.bdta.pro/images/81c9ee267a958374a0327b1e11b81c11.jpg'),
(38813, 2687, 'Pokemon S05 E32', 'http://sinalprivado.info:80/series/1533784/1533784/193023.mp4', 'http://timg.bdta.pro/images/d356763a53cf30caf356046a0b4c0c8e.jpg'),
(38814, 2687, 'Pokemon S05 E33', 'http://sinalprivado.info:80/series/1533784/1533784/193024.mp4', 'http://timg.bdta.pro/images/9028fd60319fb5a7e9d829832dadb8d1.jpg'),
(38815, 2687, 'Pokemon S05 E34', 'http://sinalprivado.info:80/series/1533784/1533784/193025.mp4', 'http://timg.bdta.pro/images/cb2bee08df6041f0d467b0ee3fd13e88.jpg'),
(38816, 2687, 'Pokemon S05 E35', 'http://sinalprivado.info:80/series/1533784/1533784/193026.mp4', 'http://timg.bdta.pro/images/4818a0fcda0e98c6a6580c90b7771b66.jpg'),
(38817, 2687, 'Pokemon S05 E36', 'http://sinalprivado.info:80/series/1533784/1533784/193027.mp4', 'http://timg.bdta.pro/images/7761319d53650e4dfa1e784df97ef61d.jpg'),
(38818, 2687, 'Pokemon S05 E37', 'http://sinalprivado.info:80/series/1533784/1533784/193028.mp4', 'http://timg.bdta.pro/images/399bbe380f4b9410120aa744a5e36678.jpg'),
(38819, 2687, 'Pokemon S05 E38', 'http://sinalprivado.info:80/series/1533784/1533784/193029.mp4', 'http://timg.bdta.pro/images/a7a070ef5cfeabeb6c859abd2ed46e60.jpg'),
(38820, 2687, 'Pokemon S05 E39', 'http://sinalprivado.info:80/series/1533784/1533784/193030.mp4', 'http://timg.bdta.pro/images/f3725e3f9c41c4ab8ac264117fc2984b.jpg'),
(38821, 2687, 'Pokemon S05 E40', 'http://sinalprivado.info:80/series/1533784/1533784/193031.mp4', 'http://timg.bdta.pro/images/12d2b00099290439feee4203137b2876.jpg'),
(38822, 2687, 'Pokemon S05 E41', 'http://sinalprivado.info:80/series/1533784/1533784/193032.mp4', 'http://timg.bdta.pro/images/6480238ad6f874e151e4c28f656a14c4.jpg'),
(38823, 2687, 'Pokemon S05 E42', 'http://sinalprivado.info:80/series/1533784/1533784/193033.mp4', 'http://timg.bdta.pro/images/da6aa859b0935b9304c73c104ee1fb76.jpg'),
(38824, 2687, 'Pokemon S05 E43', 'http://sinalprivado.info:80/series/1533784/1533784/193034.mp4', 'http://timg.bdta.pro/images/1c8533d130574129e9244548150c5f12.jpg'),
(38825, 2687, 'Pokemon S05 E44', 'http://sinalprivado.info:80/series/1533784/1533784/193035.mp4', 'http://timg.bdta.pro/images/5d91b97a52abca4ba081e5836e0be27c.jpg'),
(38826, 2687, 'Pokemon S05 E45', 'http://sinalprivado.info:80/series/1533784/1533784/193036.mp4', 'http://timg.bdta.pro/images/c159445bc1cbcb2cdc989ce9b8a9803d.jpg'),
(38827, 2687, 'Pokemon S05 E46', 'http://sinalprivado.info:80/series/1533784/1533784/193037.mp4', 'http://timg.bdta.pro/images/44b613f94a60def381a017d15985744f.jpg'),
(38828, 2687, 'Pokemon S05 E47', 'http://sinalprivado.info:80/series/1533784/1533784/193038.mp4', 'http://timg.bdta.pro/images/c17b3ddada08efc48a27d7678bcc8255.jpg'),
(38829, 2687, 'Pokemon S05 E48', 'http://sinalprivado.info:80/series/1533784/1533784/193039.mp4', 'http://timg.bdta.pro/images/80afd2687b2c95286cd4e315b950aeda.jpg'),
(38830, 2687, 'Pokemon S05 E49', 'http://sinalprivado.info:80/series/1533784/1533784/193040.mp4', 'http://timg.bdta.pro/images/25d99cde43261230eec53bf2e9c5dd54.jpg'),
(38831, 2687, 'Pokemon S05 E50', 'http://sinalprivado.info:80/series/1533784/1533784/193041.mp4', 'http://timg.bdta.pro/images/cf446f75e528ea84920618e925fb22c7.jpg'),
(38832, 2687, 'Pokemon S05 E51', 'http://sinalprivado.info:80/series/1533784/1533784/193042.mp4', 'http://timg.bdta.pro/images/3178bc8a8bd7538813174628b0131e4f.jpg'),
(38833, 2687, 'Pokemon S05 E52', 'http://sinalprivado.info:80/series/1533784/1533784/193043.mp4', 'http://timg.bdta.pro/images/9305de867e371a040f0a980f7ce29663.jpg'),
(38834, 2687, 'Pokemon S05 E53', 'http://sinalprivado.info:80/series/1533784/1533784/193044.mp4', 'http://timg.bdta.pro/images/8dd1c6d66041ce948d250c8fc7c4c705.jpg'),
(38835, 2687, 'Pokemon S05 E54', 'http://sinalprivado.info:80/series/1533784/1533784/193045.mp4', 'http://timg.bdta.pro/images/77505749c5104d1bd3b0ea7634eb59b7.jpg'),
(38836, 2687, 'Pokemon S05 E55', 'http://sinalprivado.info:80/series/1533784/1533784/193046.mp4', 'http://timg.bdta.pro/images/f28ba35596821c94eb98a7970a5dc096.jpg'),
(38837, 2687, 'Pokemon S05 E56', 'http://sinalprivado.info:80/series/1533784/1533784/193047.mp4', 'http://timg.bdta.pro/images/3b3dbdbac14e82b234b95728b9a6acc6.jpg'),
(38838, 2687, 'Pokemon S05 E57', 'http://sinalprivado.info:80/series/1533784/1533784/193048.mp4', 'http://timg.bdta.pro/images/eb91e85657396928a3835d30c3256d90.jpg'),
(38839, 2687, 'Pokemon S05 E58', 'http://sinalprivado.info:80/series/1533784/1533784/193049.mp4', 'http://timg.bdta.pro/images/5811c70bdad97e7760c33bff7ac88fd7.jpg'),
(38840, 2687, 'Pokemon S05 E59', 'http://sinalprivado.info:80/series/1533784/1533784/193050.mp4', 'http://timg.bdta.pro/images/1116f98059e05e97c8c68c18da02ec65.jpg'),
(38841, 2687, 'Pokemon S05 E60', 'http://sinalprivado.info:80/series/1533784/1533784/193051.mp4', 'http://timg.bdta.pro/images/33346953a708f16a66063811bed89189.jpg'),
(38842, 2687, 'Pokemon S05 E61', 'http://sinalprivado.info:80/series/1533784/1533784/193052.mp4', 'http://timg.bdta.pro/images/18c3fb39a9b9446402edc819537f80ad.jpg'),
(38843, 2687, 'Pokemon S05 E62', 'http://sinalprivado.info:80/series/1533784/1533784/193053.mp4', 'http://timg.bdta.pro/images/d7e7cf73a3c669f94beb033c31889859.jpg'),
(38844, 2687, 'Pokemon S05 E63', 'http://sinalprivado.info:80/series/1533784/1533784/193054.mp4', 'http://timg.bdta.pro/images/f49489a64f9a0e46ecc785adfcb5f6e1.jpg'),
(38845, 2687, 'Pokemon S05 E64', 'http://sinalprivado.info:80/series/1533784/1533784/193055.mp4', 'http://timg.bdta.pro/images/65ac13db9e1d41c103d7c02f315ea5cd.jpg'),
(38846, 2687, 'Pokemon S05 E65', 'http://sinalprivado.info:80/series/1533784/1533784/193056.mp4', 'http://timg.bdta.pro/images/655c46404b3557ebe14fb8bf78248a2d.jpg'),
(38847, 2688, 'Pokemon S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193057.mp4', 'http://timg.bdta.pro/images/38ed69d0b15af07f5fcd28bdd7b0e115.jpg'),
(38848, 2688, 'Pokemon S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193058.mp4', 'http://timg.bdta.pro/images/924f1c022c2188017123a95464a96982.jpg'),
(38849, 2688, 'Pokemon S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193059.mp4', 'http://timg.bdta.pro/images/90029e0397cf7fa27cb895fa0a06f2a8.jpg'),
(38850, 2688, 'Pokemon S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193060.mp4', 'http://timg.bdta.pro/images/27f8938c1fc0695ed19b2bbb0b824eac.jpg'),
(38851, 2688, 'Pokemon S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193061.mp4', 'http://timg.bdta.pro/images/35e866d534fb9ad52fdd26ed73255cd8.jpg'),
(38852, 2688, 'Pokemon S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193062.mp4', 'http://timg.bdta.pro/images/eb97ec63e8eeace5546a67f26013f176.jpg'),
(38853, 2688, 'Pokemon S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193063.mp4', 'http://timg.bdta.pro/images/b2e5eef5f3ae11842f78d169c5d21855.jpg'),
(38854, 2688, 'Pokemon S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193064.mp4', 'http://timg.bdta.pro/images/9ea3b3f1e4b3484a29e283cb79d8bc37.jpg'),
(38855, 2688, 'Pokemon S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193065.mp4', 'http://timg.bdta.pro/images/4da3d69c7c57cebdf8e1d0cdcfa96d76.jpg'),
(38856, 2688, 'Pokemon S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193066.mp4', 'http://timg.bdta.pro/images/8e1e1dbf24c7ea673473b16455e657a2.jpg'),
(38857, 2688, 'Pokemon S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193067.mp4', 'http://timg.bdta.pro/images/a867a2bd6ffef54f1d3d55a03ade739f.jpg'),
(38858, 2688, 'Pokemon S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193068.mp4', 'http://timg.bdta.pro/images/8456b916c85480012bde07de7849d79e.jpg'),
(38859, 2688, 'Pokemon S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193069.mp4', 'http://timg.bdta.pro/images/ee56641196a7393db1c8e91d37811b7f.jpg'),
(38860, 2688, 'Pokemon S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/193070.mp4', 'http://timg.bdta.pro/images/1d5b17a3f92a1807d483775520609f65.jpg'),
(38861, 2688, 'Pokemon S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/193071.mp4', 'http://timg.bdta.pro/images/a5098d27cb441b88d12431ebe85ac8a3.jpg'),
(38862, 2688, 'Pokemon S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/193072.mp4', 'http://timg.bdta.pro/images/a361fd29bdfe895528938e59ba7a3182.jpg'),
(38863, 2688, 'Pokemon S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/193073.mp4', 'http://timg.bdta.pro/images/560eb9e22e05569b3dfc618a70b232d4.jpg'),
(38864, 2688, 'Pokemon S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/193074.mp4', 'http://timg.bdta.pro/images/7c1a9530677b71c1332348a2c7799c66.jpg'),
(38865, 2688, 'Pokemon S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/193075.mp4', 'http://timg.bdta.pro/images/fe9a886001feb1b1aecbb997240fa81f.jpg'),
(38866, 2688, 'Pokemon S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/193076.mp4', 'http://timg.bdta.pro/images/cb829ec09cf1f16256bb36e26f862a66.jpg'),
(38867, 2688, 'Pokemon S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/193077.mp4', 'http://timg.bdta.pro/images/3d7835295aff3c80d57a1a55857cc2d2.jpg'),
(38868, 2688, 'Pokemon S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/193078.mp4', 'http://timg.bdta.pro/images/97f7f46f7f934f9224ce97739997ef37.jpg'),
(38869, 2688, 'Pokemon S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/193079.mp4', 'http://timg.bdta.pro/images/d5b37221cbd88cecbfe44a35c8504b47.jpg'),
(38870, 2688, 'Pokemon S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/193080.mp4', 'http://timg.bdta.pro/images/49c54f2bf193b20cdf136faa1ad143f2.jpg'),
(38871, 2688, 'Pokemon S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/193081.mp4', 'http://timg.bdta.pro/images/cdb20059e0c17eb3c670f2f1744b36a7.jpg'),
(38872, 2688, 'Pokemon S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/193082.mp4', 'http://timg.bdta.pro/images/990243c0becf9ee6f680ae2041f107b0.jpg'),
(38873, 2688, 'Pokemon S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/193083.mp4', 'http://timg.bdta.pro/images/00c2647c5e0c472e89e03aff62248c0d.jpg'),
(38874, 2688, 'Pokemon S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/193084.mp4', 'http://timg.bdta.pro/images/a2c7ddfa9dec9f074e7c458fbbdf6564.jpg'),
(38875, 2688, 'Pokemon S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/193085.mp4', 'http://timg.bdta.pro/images/b0620b0bb328362b1b37cb75f7b2469b.jpg'),
(38876, 2688, 'Pokemon S06 E30', 'http://sinalprivado.info:80/series/1533784/1533784/193086.mp4', 'http://timg.bdta.pro/images/e464ede391b1f6f0cb4c9ebc537f3861.jpg'),
(38877, 2688, 'Pokemon S06 E31', 'http://sinalprivado.info:80/series/1533784/1533784/193087.mp4', 'http://timg.bdta.pro/images/a58d85f2c25ba9bc3c75d49a8d0a616a.jpg'),
(38878, 2688, 'Pokemon S06 E32', 'http://sinalprivado.info:80/series/1533784/1533784/193088.mp4', 'http://timg.bdta.pro/images/831fb7d8e5e65073ab519487a43ee81d.jpg'),
(38879, 2688, 'Pokemon S06 E33', 'http://sinalprivado.info:80/series/1533784/1533784/193089.mp4', 'http://timg.bdta.pro/images/fbd76ee7c48aefe17ba708838f3c7256.jpg'),
(38880, 2688, 'Pokemon S06 E34', 'http://sinalprivado.info:80/series/1533784/1533784/193090.mp4', 'http://timg.bdta.pro/images/37e394e023b1c089bae57d7c96154cda.jpg'),
(38881, 2688, 'Pokemon S06 E35', 'http://sinalprivado.info:80/series/1533784/1533784/193091.mp4', 'http://timg.bdta.pro/images/21f8eca770517fef914ff04cea521145.jpg'),
(38882, 2688, 'Pokemon S06 E36', 'http://sinalprivado.info:80/series/1533784/1533784/193092.mp4', 'http://timg.bdta.pro/images/aa49fa844c4d941370d0739ede2423ab.jpg'),
(38883, 2688, 'Pokemon S06 E37', 'http://sinalprivado.info:80/series/1533784/1533784/193093.mp4', 'http://timg.bdta.pro/images/44ad0e6de9d3db27f5f1d371ebbde524.jpg'),
(38884, 2688, 'Pokemon S06 E38', 'http://sinalprivado.info:80/series/1533784/1533784/193094.mp4', 'http://timg.bdta.pro/images/da5ae86d2dc3d350f3f206d594cc9aad.jpg'),
(38885, 2688, 'Pokemon S06 E39', 'http://sinalprivado.info:80/series/1533784/1533784/193095.mp4', 'http://timg.bdta.pro/images/4b62f2b0171b6e843dc6a0ca477d4e21.jpg'),
(38886, 2688, 'Pokemon S06 E40', 'http://sinalprivado.info:80/series/1533784/1533784/193096.mp4', 'http://timg.bdta.pro/images/93e44376b9c4cfa7efa93ed81c754f18.jpg'),
(38887, 2689, 'Pokemon S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193097.mp4', 'http://timg.bdta.pro/images/1a1f84b5372dcdfa138da8c1b20b214f.jpg'),
(38888, 2689, 'Pokemon S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193098.mp4', 'http://timg.bdta.pro/images/0c2ea0b13a402293bf677cbed479ac02.jpg'),
(38889, 2689, 'Pokemon S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193099.mp4', 'http://timg.bdta.pro/images/c13914c5f8da51bc571ca0f7a31950f0.jpg'),
(38890, 2689, 'Pokemon S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193100.mp4', 'http://timg.bdta.pro/images/a29a151b700a14ed550e33e86289e16f.jpg'),
(38891, 2689, 'Pokemon S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193101.mp4', 'http://timg.bdta.pro/images/66072f158b0406124d0d4ded1a0d9fc9.jpg'),
(38892, 2689, 'Pokemon S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193102.mp4', 'http://timg.bdta.pro/images/ab6a4690f112e2d8f6fb7d039ecd6963.jpg'),
(38893, 2689, 'Pokemon S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193103.mp4', 'http://timg.bdta.pro/images/3d445eb415ed24829c233ce54d071be5.jpg'),
(38894, 2689, 'Pokemon S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193104.mp4', 'http://timg.bdta.pro/images/0a2bde9d0126785c5ab5ea8631783b2f.jpg'),
(38895, 2689, 'Pokemon S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193105.mp4', 'http://timg.bdta.pro/images/fa70ef84d5905d1f1e9abe2f30ca20c7.jpg'),
(38896, 2689, 'Pokemon S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193106.mp4', 'http://timg.bdta.pro/images/7c6100550d82834a2426806ba2653a3f.jpg'),
(38897, 2689, 'Pokemon S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193107.mp4', 'http://timg.bdta.pro/images/aa911f62ed1fe409e67064098b39b8b3.jpg'),
(38898, 2689, 'Pokemon S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193108.mp4', 'http://timg.bdta.pro/images/257f77075fc5ecf3ad632baf94aee240.jpg'),
(38899, 2689, 'Pokemon S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193109.mp4', 'http://timg.bdta.pro/images/fdbffb59a2a4e2a3849ec9b55d8ed4af.jpg'),
(38900, 2689, 'Pokemon S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/193110.mp4', 'http://timg.bdta.pro/images/d457b8e5035727fb7eceb2e7c01c3751.jpg'),
(38901, 2689, 'Pokemon S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/193111.mp4', 'http://timg.bdta.pro/images/a3696bb57dc6865f9f7db4c6778c2f61.jpg'),
(38902, 2689, 'Pokemon S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/193112.mp4', 'http://timg.bdta.pro/images/cd08d5c7000dbf143933a8092020733d.jpg'),
(38903, 2689, 'Pokemon S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/193113.mp4', 'http://timg.bdta.pro/images/830dd07138a61592a2e320cbbf944efc.jpg'),
(38904, 2689, 'Pokemon S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/193114.mp4', 'http://timg.bdta.pro/images/8fbab0abd0ffa50d90513d0e71aef251.jpg'),
(38905, 2689, 'Pokemon S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/193115.mp4', 'http://timg.bdta.pro/images/763a3625ac9f03ec94a8051aa6660e1a.jpg'),
(38906, 2689, 'Pokemon S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/193116.mp4', 'http://timg.bdta.pro/images/0246fb1cbdc887702e19e7776f5e1a28.jpg'),
(38907, 2689, 'Pokemon S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/193117.mp4', 'http://timg.bdta.pro/images/5cb88a4818890d968cc5df0bf29a8daa.jpg'),
(38908, 2689, 'Pokemon S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/193118.mp4', 'http://timg.bdta.pro/images/dbf2e63eb489c8b79a07f1de3f177268.jpg'),
(38909, 2689, 'Pokemon S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/193119.mp4', 'http://timg.bdta.pro/images/f33298d42fc0face5d1a5bb6e1816b61.jpg'),
(38910, 2689, 'Pokemon S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/193120.mp4', 'http://timg.bdta.pro/images/dec31b481eb7ead00f3598af92c91ffe.jpg'),
(38911, 2689, 'Pokemon S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/193121.mp4', 'http://timg.bdta.pro/images/125d5c24d003fe675247560e2b038dce.jpg'),
(38912, 2689, 'Pokemon S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/193122.mp4', 'http://timg.bdta.pro/images/9f094901bc59da0bf9e463a2e08017b1.jpg'),
(38913, 2689, 'Pokemon S07 E27', 'http://sinalprivado.info:80/series/1533784/1533784/193123.mp4', 'http://timg.bdta.pro/images/ed406be4bb3dc01a045a1364cdf472bf.jpg'),
(38914, 2689, 'Pokemon S07 E28', 'http://sinalprivado.info:80/series/1533784/1533784/193124.mp4', 'http://timg.bdta.pro/images/be5704e251429a835ca80c9bd7444da1.jpg'),
(38915, 2689, 'Pokemon S07 E29', 'http://sinalprivado.info:80/series/1533784/1533784/193125.mp4', 'http://timg.bdta.pro/images/f5822891722fbc43b0d9f79149616621.jpg'),
(38916, 2689, 'Pokemon S07 E30', 'http://sinalprivado.info:80/series/1533784/1533784/193126.mp4', 'http://timg.bdta.pro/images/dad1bf5a0fa75d80dec82cb2d4eb118a.jpg'),
(38917, 2689, 'Pokemon S07 E31', 'http://sinalprivado.info:80/series/1533784/1533784/193127.mp4', 'http://timg.bdta.pro/images/edfd0b4ec4380dbe1b24c7ddbe449dc8.jpg'),
(38918, 2689, 'Pokemon S07 E32', 'http://sinalprivado.info:80/series/1533784/1533784/193128.mp4', 'http://timg.bdta.pro/images/30848c78fdf075e7cfa2fb881740231a.jpg'),
(38919, 2689, 'Pokemon S07 E33', 'http://sinalprivado.info:80/series/1533784/1533784/193129.mp4', 'http://timg.bdta.pro/images/7a4ef96678e35448e610be1ffba372e0.jpg'),
(38920, 2689, 'Pokemon S07 E34', 'http://sinalprivado.info:80/series/1533784/1533784/193130.mp4', 'http://timg.bdta.pro/images/bc88a9500708f30e1c48ecae6c43686d.jpg'),
(38921, 2689, 'Pokemon S07 E35', 'http://sinalprivado.info:80/series/1533784/1533784/193131.mp4', 'http://timg.bdta.pro/images/bcab0090ae8b3db40c21654ae9e52fb4.jpg'),
(38922, 2689, 'Pokemon S07 E36', 'http://sinalprivado.info:80/series/1533784/1533784/193132.mp4', 'http://timg.bdta.pro/images/8e0a0b04bfba89f779cd612b44faef7a.jpg'),
(38923, 2689, 'Pokemon S07 E37', 'http://sinalprivado.info:80/series/1533784/1533784/193133.mp4', 'http://timg.bdta.pro/images/be7a41b1047ed4078175a629611ce539.jpg'),
(38924, 2689, 'Pokemon S07 E38', 'http://sinalprivado.info:80/series/1533784/1533784/193134.mp4', 'http://timg.bdta.pro/images/2aff33af6521bb50acbb7fe7ff46f0e6.jpg'),
(38925, 2689, 'Pokemon S07 E39', 'http://sinalprivado.info:80/series/1533784/1533784/193135.mp4', 'http://timg.bdta.pro/images/aa4cea51552a547f1431c2a1d63bc8ee.jpg'),
(38926, 2689, 'Pokemon S07 E40', 'http://sinalprivado.info:80/series/1533784/1533784/193136.mp4', 'http://timg.bdta.pro/images/996abaf47e51892323bd5f8642a69be7.jpg'),
(38927, 2689, 'Pokemon S07 E41', 'http://sinalprivado.info:80/series/1533784/1533784/193137.mp4', 'http://timg.bdta.pro/images/81a7763bcbcd48a5faf81a446cb4a81c.jpg'),
(38928, 2689, 'Pokemon S07 E42', 'http://sinalprivado.info:80/series/1533784/1533784/193138.mp4', 'http://timg.bdta.pro/images/c919b81312ed6c58152f5e3002f025dc.jpg'),
(38929, 2689, 'Pokemon S07 E43', 'http://sinalprivado.info:80/series/1533784/1533784/193139.mp4', 'http://timg.bdta.pro/images/137da966e7855e605a5ccf0f0eedc3a7.jpg'),
(38930, 2689, 'Pokemon S07 E44', 'http://sinalprivado.info:80/series/1533784/1533784/193140.mp4', 'http://timg.bdta.pro/images/6fceaf3d9bda3d62d9220f532105c0e3.jpg'),
(38931, 2689, 'Pokemon S07 E45', 'http://sinalprivado.info:80/series/1533784/1533784/193141.mp4', 'http://timg.bdta.pro/images/bd7db7c3baff556fa94fb1fdf4e06f04.jpg'),
(38932, 2689, 'Pokemon S07 E46', 'http://sinalprivado.info:80/series/1533784/1533784/193142.mp4', 'http://timg.bdta.pro/images/1e8c165379d9f703f6c3b6412c88515a.jpg'),
(38933, 2689, 'Pokemon S07 E47', 'http://sinalprivado.info:80/series/1533784/1533784/193143.mp4', 'http://timg.bdta.pro/images/8f28b7f2a4dd84e3104c0f147a918d6b.jpg'),
(38934, 2689, 'Pokemon S07 E48', 'http://sinalprivado.info:80/series/1533784/1533784/193144.mp4', 'http://timg.bdta.pro/images/df77a01e85da470caabbec4f38e366b5.jpg'),
(38935, 2689, 'Pokemon S07 E49', 'http://sinalprivado.info:80/series/1533784/1533784/193145.mp4', 'http://timg.bdta.pro/images/357c0175aa0aaf49fe8a1cdf7ae71706.jpg'),
(38936, 2689, 'Pokemon S07 E50', 'http://sinalprivado.info:80/series/1533784/1533784/193146.mp4', 'http://timg.bdta.pro/images/3f0f971b185644c05aa8ab9148368356.jpg'),
(38937, 2689, 'Pokemon S07 E51', 'http://sinalprivado.info:80/series/1533784/1533784/193147.mp4', 'http://timg.bdta.pro/images/a15b176e457a44d17ac3174c36e2bb04.jpg'),
(38938, 2689, 'Pokemon S07 E52', 'http://sinalprivado.info:80/series/1533784/1533784/193148.mp4', 'http://timg.bdta.pro/images/1935507ed5223d1a83145b6740e345fa.jpg'),
(38939, 2690, 'Pokemon S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193149.mp4', 'http://timg.bdta.pro/images/8c57e6aef10586ac6e20ea980fadf1dc.jpg'),
(38940, 2690, 'Pokemon S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193150.mp4', 'http://timg.bdta.pro/images/c6ff1e2a774a142c7c603a855db7553e.jpg'),
(38941, 2690, 'Pokemon S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193151.mp4', 'http://timg.bdta.pro/images/cf4b762b661d8ea62e44ec4276c22147.jpg'),
(38942, 2690, 'Pokemon S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193152.mp4', 'http://timg.bdta.pro/images/d141ecd5b927d422436cb7f17807aecd.jpg'),
(38943, 2690, 'Pokemon S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193153.mp4', 'http://timg.bdta.pro/images/612f1da12bac8e2f92a7372ed2610a1e.jpg'),
(38944, 2690, 'Pokemon S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193154.mp4', 'http://timg.bdta.pro/images/6374562c646e75d4999fca0abc8917d9.jpg'),
(38945, 2690, 'Pokemon S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193155.mp4', 'http://timg.bdta.pro/images/26aaf3ea6d9def9ce87e91afb67ca75c.jpg'),
(38946, 2690, 'Pokemon S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193156.mp4', 'http://timg.bdta.pro/images/c89d3e7e91f346d45c456b3636da7cf0.jpg'),
(38947, 2690, 'Pokemon S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193157.mp4', 'http://timg.bdta.pro/images/5223dd67d4daba256a70f8b9d04a1778.jpg'),
(38948, 2690, 'Pokemon S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193158.mp4', 'http://timg.bdta.pro/images/cd1b98709bef090494bd4cd6681e55d2.jpg'),
(38949, 2690, 'Pokemon S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193159.mp4', 'http://timg.bdta.pro/images/bde63b24d0add0d70fe06cb4b22a7faf.jpg'),
(38950, 2690, 'Pokemon S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193160.mp4', 'http://timg.bdta.pro/images/deb45a807433183ff1695c22dbe6d7e8.jpg'),
(38951, 2690, 'Pokemon S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193161.mp4', 'http://timg.bdta.pro/images/93f0b1dc9b9b072f5d61ee4b7f61a919.jpg'),
(38952, 2690, 'Pokemon S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/193162.mp4', 'http://timg.bdta.pro/images/669bd2ccfaa2e8636ee6eac6f0513006.jpg'),
(38953, 2690, 'Pokemon S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/193163.mp4', 'http://timg.bdta.pro/images/063e61dfb9706f637def01d3951d0248.jpg'),
(38954, 2690, 'Pokemon S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/193164.mp4', 'http://timg.bdta.pro/images/a51c3b3082b21008f2d5a23c83bcf2a9.jpg'),
(38955, 2690, 'Pokemon S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/193165.mp4', 'http://timg.bdta.pro/images/5d534b0cab032dadf38e1210a703c6d7.jpg'),
(38956, 2690, 'Pokemon S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/193166.mp4', 'http://timg.bdta.pro/images/f6d6f9c52186053cfb15a1a147e2fc75.jpg'),
(38957, 2690, 'Pokemon S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/193167.mp4', 'http://timg.bdta.pro/images/429cce283ecc37612f23bc2d65454ea5.jpg'),
(38958, 2690, 'Pokemon S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/193168.mp4', 'http://timg.bdta.pro/images/04fb9377d206e0c9762897c42bb3b8b0.jpg'),
(38959, 2690, 'Pokemon S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/193169.mp4', 'http://timg.bdta.pro/images/fab8c72ea6ad6050dd1d91969a4ad590.jpg'),
(38960, 2690, 'Pokemon S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/193170.mp4', 'http://timg.bdta.pro/images/a76ef4830adbca1c0926efb2651d8b73.jpg'),
(38961, 2690, 'Pokemon S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/193171.mp4', 'http://timg.bdta.pro/images/d7773cfbc6e204c330cd3e82b28e543b.jpg'),
(38962, 2690, 'Pokemon S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/193172.mp4', 'http://timg.bdta.pro/images/a97e78ba2a63c94724f1230a5d084333.jpg'),
(38963, 2690, 'Pokemon S08 E25', 'http://sinalprivado.info:80/series/1533784/1533784/193173.mp4', 'http://timg.bdta.pro/images/b5c8f0a6d489874eb05a19a70c25aece.jpg'),
(38964, 2690, 'Pokemon S08 E26', 'http://sinalprivado.info:80/series/1533784/1533784/193174.mp4', 'http://timg.bdta.pro/images/c8bb060e3edc42c34d57631691af0833.jpg'),
(38965, 2690, 'Pokemon S08 E27', 'http://sinalprivado.info:80/series/1533784/1533784/193175.mp4', 'http://timg.bdta.pro/images/6bc0fd2c8b1b79738ab042e10c6dfeca.jpg'),
(38966, 2690, 'Pokemon S08 E28', 'http://sinalprivado.info:80/series/1533784/1533784/193176.mp4', 'http://timg.bdta.pro/images/ed18543bd9290bbc8ff2892f74761559.jpg'),
(38967, 2690, 'Pokemon S08 E29', 'http://sinalprivado.info:80/series/1533784/1533784/193177.mp4', 'http://timg.bdta.pro/images/f994a11482cafc07b05650bf8d7ccc6e.jpg'),
(38968, 2690, 'Pokemon S08 E30', 'http://sinalprivado.info:80/series/1533784/1533784/193178.mp4', 'http://timg.bdta.pro/images/c477e936ca2b0011a9248f35993d5774.jpg'),
(38969, 2690, 'Pokemon S08 E31', 'http://sinalprivado.info:80/series/1533784/1533784/193179.mp4', 'http://timg.bdta.pro/images/9591b28eb2ef80ab9a41010101040282.jpg'),
(38970, 2690, 'Pokemon S08 E32', 'http://sinalprivado.info:80/series/1533784/1533784/193180.mp4', 'http://timg.bdta.pro/images/522a6f9b0fb4b62ed992e0c2dd167336.jpg'),
(38971, 2690, 'Pokemon S08 E33', 'http://sinalprivado.info:80/series/1533784/1533784/193181.mp4', 'http://timg.bdta.pro/images/b4d6e82df07e6a93516ea61774af1e6d.jpg'),
(38972, 2690, 'Pokemon S08 E34', 'http://sinalprivado.info:80/series/1533784/1533784/193182.mp4', 'http://timg.bdta.pro/images/c7d16bfc3f03e9f0f2af45765beb3790.jpg'),
(38973, 2690, 'Pokemon S08 E35', 'http://sinalprivado.info:80/series/1533784/1533784/193183.mp4', 'http://timg.bdta.pro/images/3cfb3b906d4ef6aca916a31348c4a9e1.jpg'),
(38974, 2690, 'Pokemon S08 E36', 'http://sinalprivado.info:80/series/1533784/1533784/193184.mp4', 'http://timg.bdta.pro/images/6be4c25824f581d26dfcfa6fae267485.jpg'),
(38975, 2690, 'Pokemon S08 E37', 'http://sinalprivado.info:80/series/1533784/1533784/193185.mp4', 'http://timg.bdta.pro/images/9c593fce9ca169ad0ce0fb925d085827.jpg'),
(38976, 2690, 'Pokemon S08 E38', 'http://sinalprivado.info:80/series/1533784/1533784/193186.mp4', 'http://timg.bdta.pro/images/38ffeb72a61cf89dbf23bfe8bce561bc.jpg'),
(38977, 2690, 'Pokemon S08 E39', 'http://sinalprivado.info:80/series/1533784/1533784/193187.mp4', 'http://timg.bdta.pro/images/88e360d7e25d90aece29d4cb07d4cfe0.jpg'),
(38978, 2690, 'Pokemon S08 E40', 'http://sinalprivado.info:80/series/1533784/1533784/193188.mp4', 'http://timg.bdta.pro/images/268fe07313d8d6339047e777707e6790.jpg'),
(38979, 2690, 'Pokemon S08 E41', 'http://sinalprivado.info:80/series/1533784/1533784/193189.mp4', 'http://timg.bdta.pro/images/3a6b75e921953de01c29be1165369272.jpg'),
(38980, 2690, 'Pokemon S08 E42', 'http://sinalprivado.info:80/series/1533784/1533784/193190.mp4', 'http://timg.bdta.pro/images/864f389c85ce626f169c484e3ef38da3.jpg'),
(38981, 2690, 'Pokemon S08 E43', 'http://sinalprivado.info:80/series/1533784/1533784/193191.mp4', 'http://timg.bdta.pro/images/5cd5be8b3754a5367556e593252c3e8d.jpg'),
(38982, 2690, 'Pokemon S08 E44', 'http://sinalprivado.info:80/series/1533784/1533784/193192.mp4', 'http://timg.bdta.pro/images/6c26858930df55829c5cfd4a7a484f9d.jpg'),
(38983, 2690, 'Pokemon S08 E45', 'http://sinalprivado.info:80/series/1533784/1533784/193193.mp4', 'http://timg.bdta.pro/images/3d37cb7dac9c632b528d98356a9e0f82.jpg'),
(38984, 2690, 'Pokemon S08 E46', 'http://sinalprivado.info:80/series/1533784/1533784/193194.mp4', 'http://timg.bdta.pro/images/a3cf5c9aa3f15bcc812d240bdd0d5924.jpg'),
(38985, 2690, 'Pokemon S08 E47', 'http://sinalprivado.info:80/series/1533784/1533784/193195.mp4', 'http://timg.bdta.pro/images/c7a57813cebd5b1f70556fa3294c9bc7.jpg'),
(38986, 2690, 'Pokemon S08 E48', 'http://sinalprivado.info:80/series/1533784/1533784/193196.mp4', 'http://timg.bdta.pro/images/df3f126d39318b47c903ca7d7e0439fb.jpg'),
(38987, 2690, 'Pokemon S08 E49', 'http://sinalprivado.info:80/series/1533784/1533784/193197.mp4', 'http://timg.bdta.pro/images/5a017fa58d0984057894fe9b68285619.jpg'),
(38988, 2690, 'Pokemon S08 E50', 'http://sinalprivado.info:80/series/1533784/1533784/193198.mp4', 'http://timg.bdta.pro/images/b6dddc0be01ebcb16d8970af137ed543.jpg'),
(38989, 2690, 'Pokemon S08 E51', 'http://sinalprivado.info:80/series/1533784/1533784/193199.mp4', 'http://timg.bdta.pro/images/0998d1cfb27a7e2c465e89426e279ebe.jpg'),
(38990, 2690, 'Pokemon S08 E52', 'http://sinalprivado.info:80/series/1533784/1533784/193200.mp4', 'http://timg.bdta.pro/images/01f1514ee4339efc7a98edbc5d863c48.jpg'),
(38991, 2690, 'Pokemon S08 E53', 'http://sinalprivado.info:80/series/1533784/1533784/193201.mp4', 'http://timg.bdta.pro/images/e65c57e3f5fd312519645636c5d6ddcb.jpg'),
(38992, 2690, 'Pokemon S08 E54', 'http://sinalprivado.info:80/series/1533784/1533784/193202.mp4', 'http://gstaticontent.com/images/cce5482f122e672ea4457e978496130d.jpg'),
(38993, 2691, 'Pokemon S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193203.mp4', 'http://timg.bdta.pro/images/e0fea55f2bad9e0cb42a5889a383886a.jpg'),
(38994, 2691, 'Pokemon S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193204.mp4', 'http://timg.bdta.pro/images/5d84a574180ebc00278f7b996c6f962d.jpg'),
(38995, 2691, 'Pokemon S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193205.mp4', 'http://timg.bdta.pro/images/02bc6be9d391d6775f5f97a9fa4a48e9.jpg'),
(38996, 2691, 'Pokemon S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193206.mp4', 'http://timg.bdta.pro/images/8612b167cf23ea700839b803336e4a60.jpg'),
(38997, 2691, 'Pokemon S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193207.mp4', 'http://timg.bdta.pro/images/23d00f0d3319df8ec1c8f115af0ffe07.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(38998, 2691, 'Pokemon S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193208.mp4', 'http://timg.bdta.pro/images/497d6c247cc14ec68e4a4a406265347a.jpg'),
(38999, 2691, 'Pokemon S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193209.mp4', 'http://timg.bdta.pro/images/d0fd960c524cbb73d84661481b6a7c6e.jpg'),
(39000, 2691, 'Pokemon S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193210.mp4', 'http://timg.bdta.pro/images/b82bacb0c93a1f1188497279d6b793a3.jpg'),
(39001, 2691, 'Pokemon S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193211.mp4', 'http://timg.bdta.pro/images/f2c8f021f0872d2f49b4e4b145080133.jpg'),
(39002, 2691, 'Pokemon S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193212.mp4', 'http://timg.bdta.pro/images/80c468b9adaf004541a05e4edffb905a.jpg'),
(39003, 2691, 'Pokemon S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193213.mp4', 'http://timg.bdta.pro/images/1e1a0e8dbab19db10dd13a2d78a7dc02.jpg'),
(39004, 2691, 'Pokemon S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193214.mp4', 'http://timg.bdta.pro/images/4b03f306d8fcad8c8d4446d137967f6d.jpg'),
(39005, 2691, 'Pokemon S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193215.mp4', 'http://timg.bdta.pro/images/fb2d0d1910dbde59abe0901469dfa30e.jpg'),
(39006, 2691, 'Pokemon S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/193216.mp4', 'http://timg.bdta.pro/images/24a0e86b249f8ceb67138487f1010049.jpg'),
(39007, 2691, 'Pokemon S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/193217.mp4', 'http://timg.bdta.pro/images/4d92010c81122b5ebec4a8f61a7e58cf.jpg'),
(39008, 2691, 'Pokemon S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/193218.mp4', 'http://timg.bdta.pro/images/16b695daccb26949bdd0611f5f0afdf1.jpg'),
(39009, 2691, 'Pokemon S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/193219.mp4', 'http://timg.bdta.pro/images/f3e7a5ad356c0972f539468d1028ca16.jpg'),
(39010, 2691, 'Pokemon S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/193220.mp4', 'http://timg.bdta.pro/images/7bef5e82fed069e5a614c09dba389ac5.jpg'),
(39011, 2691, 'Pokemon S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/193221.mp4', 'http://timg.bdta.pro/images/051817ee471d200f674e2e4327344abb.jpg'),
(39012, 2691, 'Pokemon S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/193222.mp4', 'http://timg.bdta.pro/images/6b8725a9d20b121160b3efe01e1e5280.jpg'),
(39013, 2691, 'Pokemon S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/193223.mp4', 'http://timg.bdta.pro/images/063e464d72fc4b5c82a4f9bfa911da30.jpg'),
(39014, 2691, 'Pokemon S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/193224.mp4', 'http://timg.bdta.pro/images/6b51236d5f27f8d8aeb5d7f6fd59a249.jpg'),
(39015, 2691, 'Pokemon S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/193225.mp4', 'http://timg.bdta.pro/images/fd3c920b4ab6688aadb1c458eab52066.jpg'),
(39016, 2691, 'Pokemon S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/193226.mp4', 'http://timg.bdta.pro/images/c64dafbe4c4e559693316bcb6899e38e.jpg'),
(39017, 2691, 'Pokemon S09 E25', 'http://sinalprivado.info:80/series/1533784/1533784/193227.mp4', 'http://timg.bdta.pro/images/9b70b86c42855c488fc03d3eb81ae696.jpg'),
(39018, 2691, 'Pokemon S09 E26', 'http://sinalprivado.info:80/series/1533784/1533784/193228.mp4', 'http://timg.bdta.pro/images/97addc8a151aca257042bccc3ae2a9d0.jpg'),
(39019, 2691, 'Pokemon S09 E27', 'http://sinalprivado.info:80/series/1533784/1533784/193229.mp4', 'http://timg.bdta.pro/images/420c0d6d27f1b826924a4709a7d1bd91.jpg'),
(39020, 2691, 'Pokemon S09 E28', 'http://sinalprivado.info:80/series/1533784/1533784/193230.mp4', 'http://timg.bdta.pro/images/cec60c23edbba742908f7b3ead5b76a4.jpg'),
(39021, 2691, 'Pokemon S09 E29', 'http://sinalprivado.info:80/series/1533784/1533784/193231.mp4', 'http://timg.bdta.pro/images/3b0a4383f6fdf78d469f004284eff645.jpg'),
(39022, 2691, 'Pokemon S09 E30', 'http://sinalprivado.info:80/series/1533784/1533784/193232.mp4', 'http://timg.bdta.pro/images/b40a2aad3a5b53c357c5db290fba6560.jpg'),
(39023, 2691, 'Pokemon S09 E31', 'http://sinalprivado.info:80/series/1533784/1533784/193233.mp4', 'http://timg.bdta.pro/images/756c60aa1ad934698a6a256e66f10dc6.jpg'),
(39024, 2691, 'Pokemon S09 E32', 'http://sinalprivado.info:80/series/1533784/1533784/193234.mp4', 'http://timg.bdta.pro/images/e45884d889ca46a44e9594d99aaf7a61.jpg'),
(39025, 2691, 'Pokemon S09 E33', 'http://sinalprivado.info:80/series/1533784/1533784/193235.mp4', 'http://timg.bdta.pro/images/74ea8e89f70ccd83050d921f19ecd81a.jpg'),
(39026, 2691, 'Pokemon S09 E34', 'http://sinalprivado.info:80/series/1533784/1533784/193236.mp4', 'http://timg.bdta.pro/images/0d647bf1f69e06449fb032102ae4c690.jpg'),
(39027, 2691, 'Pokemon S09 E35', 'http://sinalprivado.info:80/series/1533784/1533784/193237.mp4', 'http://timg.bdta.pro/images/6dd430dc8676ce2b728b975ca0f8ce23.jpg'),
(39028, 2691, 'Pokemon S09 E36', 'http://sinalprivado.info:80/series/1533784/1533784/193238.mp4', 'http://timg.bdta.pro/images/f5d6aecfd07b58c90a30f53cf16b310d.jpg'),
(39029, 2691, 'Pokemon S09 E37', 'http://sinalprivado.info:80/series/1533784/1533784/193239.mp4', 'http://timg.bdta.pro/images/ed1aa8f84724e0b66516f39849b703ac.jpg'),
(39030, 2691, 'Pokemon S09 E38', 'http://sinalprivado.info:80/series/1533784/1533784/193240.mp4', 'http://timg.bdta.pro/images/c0f45ea602a3196e9a1056c26dc96ecb.jpg'),
(39031, 2691, 'Pokemon S09 E39', 'http://sinalprivado.info:80/series/1533784/1533784/193241.mp4', 'http://timg.bdta.pro/images/b05466ca967eb172d3ec457c449f5054.jpg'),
(39032, 2691, 'Pokemon S09 E40', 'http://sinalprivado.info:80/series/1533784/1533784/193242.mp4', 'http://timg.bdta.pro/images/cccb7deed0cec508335bcf24ae4a66fa.jpg'),
(39033, 2691, 'Pokemon S09 E41', 'http://sinalprivado.info:80/series/1533784/1533784/193243.mp4', 'http://timg.bdta.pro/images/fd767d3efd757886e56a3c6b3a0547b6.jpg'),
(39034, 2691, 'Pokemon S09 E42', 'http://sinalprivado.info:80/series/1533784/1533784/193244.mp4', 'http://timg.bdta.pro/images/39731d62001c2e7a481e5341695f4a02.jpg'),
(39035, 2691, 'Pokemon S09 E43', 'http://sinalprivado.info:80/series/1533784/1533784/193245.mp4', 'http://timg.bdta.pro/images/759cd3f880403ab23b323b4509b4d0b2.jpg'),
(39036, 2691, 'Pokemon S09 E44', 'http://sinalprivado.info:80/series/1533784/1533784/193246.mp4', 'http://timg.bdta.pro/images/fa160551cd4ce4c036725e351a6df56f.jpg'),
(39037, 2691, 'Pokemon S09 E45', 'http://sinalprivado.info:80/series/1533784/1533784/193247.mp4', 'http://timg.bdta.pro/images/04caa563b9a881fcc9dd02188b418302.jpg'),
(39038, 2691, 'Pokemon S09 E46', 'http://sinalprivado.info:80/series/1533784/1533784/193248.mp4', 'http://gstaticontent.com/images/cce5482f122e672ea4457e978496130d.jpg'),
(39039, 2691, 'Pokemon S09 E47', 'http://sinalprivado.info:80/series/1533784/1533784/193249.mp4', 'http://gstaticontent.com/images/cce5482f122e672ea4457e978496130d.jpg'),
(39040, 2692, 'Pokemon S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193250.mp4', 'http://timg.bdta.pro/images/f5b3b00129e068e49de33bacc20e861b.jpg'),
(39041, 2692, 'Pokemon S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193251.mp4', 'http://timg.bdta.pro/images/8ac036454b7b43570e42b07f5620cb11.jpg'),
(39042, 2692, 'Pokemon S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193252.mp4', 'http://timg.bdta.pro/images/c056ce251727285dae807030ca40efcb.jpg'),
(39043, 2692, 'Pokemon S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193253.mp4', 'http://timg.bdta.pro/images/a938d07ed976b1606d16e2427dfbf876.jpg'),
(39044, 2692, 'Pokemon S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193254.mp4', 'http://timg.bdta.pro/images/83e3694322c7e98bd1314f94e7470a6e.jpg'),
(39045, 2692, 'Pokemon S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193255.mp4', 'http://timg.bdta.pro/images/aee2ffab81426c28b53a1c517b39106f.jpg'),
(39046, 2692, 'Pokemon S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193256.mp4', 'http://timg.bdta.pro/images/7baf5e71db55dbe4bca87cb9f03101db.jpg'),
(39047, 2692, 'Pokemon S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193257.mp4', 'http://timg.bdta.pro/images/8d7a242a31ef40fd07522c8c471682f6.jpg'),
(39048, 2692, 'Pokemon S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193258.mp4', 'http://timg.bdta.pro/images/c2e2bb5c02fec459568de25a814ed78f.jpg'),
(39049, 2692, 'Pokemon S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193259.mp4', 'http://timg.bdta.pro/images/2084d2a83b9774aed46588f89b54a573.jpg'),
(39050, 2692, 'Pokemon S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193260.mp4', 'http://timg.bdta.pro/images/b390916f8296cce7e5450933494d14f2.jpg'),
(39051, 2692, 'Pokemon S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193261.mp4', 'http://timg.bdta.pro/images/852facd66f67ad746ff3a83701ca4165.jpg'),
(39052, 2692, 'Pokemon S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193262.mp4', 'http://timg.bdta.pro/images/8d677a28d112a009984eb9536b467b5e.jpg'),
(39053, 2692, 'Pokemon S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/193263.mp4', 'http://timg.bdta.pro/images/272dc59d61ec79a79a39350be548c8d0.jpg'),
(39054, 2692, 'Pokemon S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/193264.mp4', 'http://timg.bdta.pro/images/aedf92eca02fd2789d3fdac3a43c13db.jpg'),
(39055, 2692, 'Pokemon S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/193265.mp4', 'http://timg.bdta.pro/images/4f9042b02b99bb4b7e5c153471f7a2fc.jpg'),
(39056, 2692, 'Pokemon S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/193266.mp4', 'http://timg.bdta.pro/images/32fb8b312a85d69670f217a3c6341a3f.jpg'),
(39057, 2692, 'Pokemon S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/193267.mp4', 'http://timg.bdta.pro/images/0359c4475c9395403975af5b43bb6f06.jpg'),
(39058, 2692, 'Pokemon S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/193268.mp4', 'http://timg.bdta.pro/images/bb12c4891b33278e7e26210693552678.jpg'),
(39059, 2692, 'Pokemon S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/193269.mp4', 'http://timg.bdta.pro/images/40568eaef15c60f3ebd6e0ba73700d63.jpg'),
(39060, 2692, 'Pokemon S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/193270.mp4', 'http://timg.bdta.pro/images/75172ea5d15d5f079b844e2ace2d21a6.jpg'),
(39061, 2692, 'Pokemon S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/193271.mp4', 'http://timg.bdta.pro/images/6f74fe790d72b09b7f6a23d71923288b.jpg'),
(39062, 2692, 'Pokemon S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/193272.mp4', 'http://timg.bdta.pro/images/9e616e18235975b5e1a87ee5ebe6a8c3.jpg'),
(39063, 2692, 'Pokemon S10 E24', 'http://sinalprivado.info:80/series/1533784/1533784/193273.mp4', 'http://timg.bdta.pro/images/6a5b87b7905d80c4a502d00ffe4604ad.jpg'),
(39064, 2692, 'Pokemon S10 E25', 'http://sinalprivado.info:80/series/1533784/1533784/193274.mp4', 'http://timg.bdta.pro/images/eee1aeec64b22fa56a4df337e96e1f53.jpg'),
(39065, 2692, 'Pokemon S10 E26', 'http://sinalprivado.info:80/series/1533784/1533784/193275.mp4', 'http://timg.bdta.pro/images/8f8f15e81d89529140b0923be654999c.jpg'),
(39066, 2692, 'Pokemon S10 E27', 'http://sinalprivado.info:80/series/1533784/1533784/193276.mp4', 'http://timg.bdta.pro/images/2044e1dc536be67a5d88ac5ae2b4997a.jpg'),
(39067, 2692, 'Pokemon S10 E28', 'http://sinalprivado.info:80/series/1533784/1533784/193277.mp4', 'http://timg.bdta.pro/images/f1a098fa8bbe4040b0e2b9c63ad3a30a.jpg'),
(39068, 2692, 'Pokemon S10 E29', 'http://sinalprivado.info:80/series/1533784/1533784/193278.mp4', 'http://timg.bdta.pro/images/ee00ee68d295fea8533f9d3f545d62f9.jpg'),
(39069, 2692, 'Pokemon S10 E30', 'http://sinalprivado.info:80/series/1533784/1533784/193279.mp4', 'http://timg.bdta.pro/images/8e94694fbe79eb569c6240a390706f4c.jpg'),
(39070, 2692, 'Pokemon S10 E31', 'http://sinalprivado.info:80/series/1533784/1533784/193280.mp4', 'http://timg.bdta.pro/images/58d56f2c5d99e26680e91fa80acf207d.jpg'),
(39071, 2692, 'Pokemon S10 E32', 'http://sinalprivado.info:80/series/1533784/1533784/193281.mp4', 'http://timg.bdta.pro/images/95499fed2c1c3f019b28d1d6e6457302.jpg'),
(39072, 2692, 'Pokemon S10 E33', 'http://sinalprivado.info:80/series/1533784/1533784/193282.mp4', 'http://timg.bdta.pro/images/4abdb6e039a4899ec58ddd6314bc3c1f.jpg'),
(39073, 2692, 'Pokemon S10 E34', 'http://sinalprivado.info:80/series/1533784/1533784/193283.mp4', 'http://timg.bdta.pro/images/c2256875ae3f46f206811e86f2213867.jpg'),
(39074, 2692, 'Pokemon S10 E35', 'http://sinalprivado.info:80/series/1533784/1533784/193284.mp4', 'http://timg.bdta.pro/images/3de1df343ea1528c14267f20e11433f5.jpg'),
(39075, 2692, 'Pokemon S10 E36', 'http://sinalprivado.info:80/series/1533784/1533784/193285.mp4', 'http://timg.bdta.pro/images/3f916b4a7b75463d31ed1393171d4677.jpg'),
(39076, 2692, 'Pokemon S10 E37', 'http://sinalprivado.info:80/series/1533784/1533784/193286.mp4', 'http://timg.bdta.pro/images/412a3bd963b4865bb955a9d12c308d6c.jpg'),
(39077, 2692, 'Pokemon S10 E38', 'http://sinalprivado.info:80/series/1533784/1533784/193287.mp4', 'http://timg.bdta.pro/images/c58ff7ce7c7f2de27fc2be9c90264c92.jpg'),
(39078, 2692, 'Pokemon S10 E39', 'http://sinalprivado.info:80/series/1533784/1533784/193288.mp4', 'http://timg.bdta.pro/images/228080f2e7cdb45e330e1c1bd4a920e5.jpg'),
(39079, 2692, 'Pokemon S10 E40', 'http://sinalprivado.info:80/series/1533784/1533784/193289.mp4', 'http://timg.bdta.pro/images/a835c37bb55576dd733460b9c690f768.jpg'),
(39080, 2692, 'Pokemon S10 E41', 'http://sinalprivado.info:80/series/1533784/1533784/193290.mp4', 'http://timg.bdta.pro/images/46cd618eb648b840194d9ec1cbf33f38.jpg'),
(39081, 2692, 'Pokemon S10 E42', 'http://sinalprivado.info:80/series/1533784/1533784/193291.mp4', 'http://timg.bdta.pro/images/46c4f58db95394ac4bd458e4803df899.jpg'),
(39082, 2692, 'Pokemon S10 E43', 'http://sinalprivado.info:80/series/1533784/1533784/193292.mp4', 'http://timg.bdta.pro/images/d20c897458079415486b3b4137f1bcf0.jpg'),
(39083, 2692, 'Pokemon S10 E44', 'http://sinalprivado.info:80/series/1533784/1533784/193293.mp4', 'http://timg.bdta.pro/images/73c1576fa7241b7368d6abf24c4cff6f.jpg'),
(39084, 2692, 'Pokemon S10 E45', 'http://sinalprivado.info:80/series/1533784/1533784/193294.mp4', 'http://timg.bdta.pro/images/7a030a22e11f79294a9875c83f16c512.jpg'),
(39085, 2692, 'Pokemon S10 E46', 'http://sinalprivado.info:80/series/1533784/1533784/193295.mp4', 'http://timg.bdta.pro/images/f95c0e098174888fe662fe5584ab8424.jpg'),
(39086, 2692, 'Pokemon S10 E47', 'http://sinalprivado.info:80/series/1533784/1533784/193296.mp4', 'http://timg.bdta.pro/images/6a026bfd34fef482d3168c33e40de44e.jpg'),
(39087, 2692, 'Pokemon S10 E48', 'http://sinalprivado.info:80/series/1533784/1533784/193297.mp4', 'http://timg.bdta.pro/images/b94b62157710baf7e4e7271a82993cb8.jpg'),
(39088, 2692, 'Pokemon S10 E49', 'http://sinalprivado.info:80/series/1533784/1533784/193298.mp4', 'http://timg.bdta.pro/images/54d0d15e470f0dc0ae533f2f2eec9380.jpg'),
(39089, 2692, 'Pokemon S10 E50', 'http://sinalprivado.info:80/series/1533784/1533784/193299.mp4', 'http://timg.bdta.pro/images/051b6e5827cfe6d284dbc3997b50d2c6.jpg'),
(39090, 2692, 'Pokemon S10 E51', 'http://sinalprivado.info:80/series/1533784/1533784/193300.mp4', 'http://timg.bdta.pro/images/1ceea89e2b09e37e6416f054415d4e7e.jpg'),
(39091, 2692, 'Pokemon S10 E52', 'http://sinalprivado.info:80/series/1533784/1533784/193301.mp4', 'http://timg.bdta.pro/images/baa4f7593c305d009b7f300cf841f99b.jpg'),
(39092, 2693, 'Pokemon S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193302.mp4', 'http://timg.bdta.pro/images/f3b146d018628cef6aaea496d30d4e46.jpg'),
(39093, 2693, 'Pokemon S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193303.mp4', 'http://timg.bdta.pro/images/8ffb1968bf370a78df3630d3c44c6f85.jpg'),
(39094, 2693, 'Pokemon S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193304.mp4', 'http://timg.bdta.pro/images/ba7b88e9315bbca8bd5ee031db42654c.jpg'),
(39095, 2693, 'Pokemon S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193305.mp4', 'http://timg.bdta.pro/images/ced51c089d4300cdaaf1f9946bac98cc.jpg'),
(39096, 2693, 'Pokemon S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193306.mp4', 'http://timg.bdta.pro/images/d2966c0d63d0cd3d8afbdb10702a1cc3.jpg'),
(39097, 2693, 'Pokemon S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193307.mp4', 'http://timg.bdta.pro/images/91eac7ca111d9e0c10900c476390bc93.jpg'),
(39098, 2693, 'Pokemon S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193308.mp4', 'http://timg.bdta.pro/images/48363cd631ff598e9573963e3428c2dc.jpg'),
(39099, 2693, 'Pokemon S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193309.mp4', 'http://timg.bdta.pro/images/8f3d339c5c6bcf66913921c63ce08f96.jpg'),
(39100, 2693, 'Pokemon S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193310.mp4', 'http://timg.bdta.pro/images/f25b3ada682679d676fcabc16a0a0a7a.jpg'),
(39101, 2693, 'Pokemon S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193311.mp4', 'http://timg.bdta.pro/images/7e240a9c970978b00b893a881e2d917a.jpg'),
(39102, 2693, 'Pokemon S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193312.mp4', 'http://timg.bdta.pro/images/e03b4cc5bf718b31a86c3eb6a3722f69.jpg'),
(39103, 2693, 'Pokemon S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193313.mp4', 'http://timg.bdta.pro/images/0954eb32bef0340584c7f823f0e8e6f6.jpg'),
(39104, 2693, 'Pokemon S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193314.mp4', 'http://timg.bdta.pro/images/e4535ddbe0e90854ba65818c6782cadf.jpg'),
(39105, 2693, 'Pokemon S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/193315.mp4', 'http://timg.bdta.pro/images/c8bd74c2bf0f978d1674e1258675cef3.jpg'),
(39106, 2693, 'Pokemon S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/193316.mp4', 'http://timg.bdta.pro/images/1a04b088af35f98b2e98049b92f78bb4.jpg'),
(39107, 2693, 'Pokemon S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/193317.mp4', 'http://timg.bdta.pro/images/2bd50293647390fee1eb62ddd23ad4d0.jpg'),
(39108, 2693, 'Pokemon S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/193318.mp4', 'http://timg.bdta.pro/images/3efae47158aa9afaae09c93db7a225f5.jpg'),
(39109, 2693, 'Pokemon S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/193319.mp4', 'http://timg.bdta.pro/images/2ec94856b8e6bb6433b4a27652dece69.jpg'),
(39110, 2693, 'Pokemon S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/193320.mp4', 'http://timg.bdta.pro/images/931b152523b7f53ea0649892ec07b260.jpg'),
(39111, 2693, 'Pokemon S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/193321.mp4', 'http://timg.bdta.pro/images/64f0d93a5091c68d2fb892ba6b62747f.jpg'),
(39112, 2693, 'Pokemon S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/193322.mp4', 'http://timg.bdta.pro/images/7cf6d8bcb28e7bc43d6c83f1273f4a18.jpg'),
(39113, 2693, 'Pokemon S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/193323.mp4', 'http://timg.bdta.pro/images/e42e153bc099c0dbfc1e616f215a2993.jpg'),
(39114, 2693, 'Pokemon S11 E23', 'http://sinalprivado.info:80/series/1533784/1533784/193324.mp4', 'http://timg.bdta.pro/images/9b1c852f9cb0ed57cf6307e4d6d616ae.jpg'),
(39115, 2693, 'Pokemon S11 E24', 'http://sinalprivado.info:80/series/1533784/1533784/193325.mp4', 'http://timg.bdta.pro/images/03cfdd85129f77130f2b931dfb6a8dec.jpg'),
(39116, 2693, 'Pokemon S11 E25', 'http://sinalprivado.info:80/series/1533784/1533784/193326.mp4', 'http://timg.bdta.pro/images/cb97069089ce4174e4bc961036bad2bb.jpg'),
(39117, 2693, 'Pokemon S11 E26', 'http://sinalprivado.info:80/series/1533784/1533784/193327.mp4', 'http://timg.bdta.pro/images/562fe7c51e083c7cabbb53ba37c392b1.jpg'),
(39118, 2693, 'Pokemon S11 E27', 'http://sinalprivado.info:80/series/1533784/1533784/193328.mp4', 'http://timg.bdta.pro/images/505bd92e6215bb50001b073fba173655.jpg'),
(39119, 2693, 'Pokemon S11 E28', 'http://sinalprivado.info:80/series/1533784/1533784/193329.mp4', 'http://timg.bdta.pro/images/b0fa00ba7d56eb1bf94e35729e10378d.jpg'),
(39120, 2693, 'Pokemon S11 E29', 'http://sinalprivado.info:80/series/1533784/1533784/193330.mp4', 'http://timg.bdta.pro/images/a5f509393f1b6c6c075256b74a2fd83c.jpg'),
(39121, 2693, 'Pokemon S11 E30', 'http://sinalprivado.info:80/series/1533784/1533784/193331.mp4', 'http://timg.bdta.pro/images/a2be3e5b3dacb6bf16ddda3e15b4b02e.jpg'),
(39122, 2693, 'Pokemon S11 E31', 'http://sinalprivado.info:80/series/1533784/1533784/193332.mp4', 'http://timg.bdta.pro/images/5167c7fec5d5ecbdd27554482d20e024.jpg'),
(39123, 2693, 'Pokemon S11 E32', 'http://sinalprivado.info:80/series/1533784/1533784/193333.mp4', 'http://timg.bdta.pro/images/3e8fa8bdbcc801e47c22e3c0ec5a7bc6.jpg'),
(39124, 2693, 'Pokemon S11 E33', 'http://sinalprivado.info:80/series/1533784/1533784/193334.mp4', 'http://timg.bdta.pro/images/46c45ea83c8d3ab860a62c47c5ec5e19.jpg'),
(39125, 2693, 'Pokemon S11 E34', 'http://sinalprivado.info:80/series/1533784/1533784/193335.mp4', 'http://timg.bdta.pro/images/715d8d3000bcc904d7326026ad1e2a44.jpg'),
(39126, 2693, 'Pokemon S11 E35', 'http://sinalprivado.info:80/series/1533784/1533784/193336.mp4', 'http://timg.bdta.pro/images/f411dc1c2b30212834bd2f9bb36a4bad.jpg'),
(39127, 2693, 'Pokemon S11 E36', 'http://sinalprivado.info:80/series/1533784/1533784/193337.mp4', 'http://timg.bdta.pro/images/0c06f411271d6f219a63753456771c69.jpg'),
(39128, 2693, 'Pokemon S11 E37', 'http://sinalprivado.info:80/series/1533784/1533784/193338.mp4', 'http://timg.bdta.pro/images/3bb6c6f6f94e772c5936f4d40c27cac3.jpg'),
(39129, 2693, 'Pokemon S11 E38', 'http://sinalprivado.info:80/series/1533784/1533784/193339.mp4', 'http://timg.bdta.pro/images/84ee9cb0013a00c42ae111824a31607c.jpg'),
(39130, 2693, 'Pokemon S11 E39', 'http://sinalprivado.info:80/series/1533784/1533784/193340.mp4', 'http://timg.bdta.pro/images/e362aa16510ff0afe35c3a9c6242cd90.jpg'),
(39131, 2693, 'Pokemon S11 E40', 'http://sinalprivado.info:80/series/1533784/1533784/193341.mp4', 'http://timg.bdta.pro/images/1c52452852ed42b6f6a3199ac55114d2.jpg'),
(39132, 2693, 'Pokemon S11 E41', 'http://sinalprivado.info:80/series/1533784/1533784/193342.mp4', 'http://timg.bdta.pro/images/6d0d25a369916c8b441ae878a21b6458.jpg'),
(39133, 2693, 'Pokemon S11 E42', 'http://sinalprivado.info:80/series/1533784/1533784/193343.mp4', 'http://timg.bdta.pro/images/6fec0b1d7c6f8af7a27256a32b8c3513.jpg'),
(39134, 2693, 'Pokemon S11 E43', 'http://sinalprivado.info:80/series/1533784/1533784/193344.mp4', 'http://timg.bdta.pro/images/17753883c0a36a854a7826133ac04466.jpg'),
(39135, 2693, 'Pokemon S11 E44', 'http://sinalprivado.info:80/series/1533784/1533784/193345.mp4', 'http://timg.bdta.pro/images/f8e21148cbbbb1f0834cce77df8e2601.jpg'),
(39136, 2693, 'Pokemon S11 E45', 'http://sinalprivado.info:80/series/1533784/1533784/193346.mp4', 'http://timg.bdta.pro/images/97afb283474236a9fd0939daf0b068d2.jpg'),
(39137, 2693, 'Pokemon S11 E46', 'http://sinalprivado.info:80/series/1533784/1533784/193347.mp4', 'http://timg.bdta.pro/images/f6f224b4182a4cc6c54ea1b45b285a79.jpg'),
(39138, 2693, 'Pokemon S11 E47', 'http://sinalprivado.info:80/series/1533784/1533784/193348.mp4', 'http://timg.bdta.pro/images/599cd0e7f115b6302214309e54674df3.jpg'),
(39139, 2693, 'Pokemon S11 E48', 'http://sinalprivado.info:80/series/1533784/1533784/193349.mp4', 'http://timg.bdta.pro/images/cdee3e4865fabb5b60b5a1c3177c1e5e.jpg'),
(39140, 2693, 'Pokemon S11 E49', 'http://sinalprivado.info:80/series/1533784/1533784/193350.mp4', 'http://timg.bdta.pro/images/c88a2053359e15ec845b9560eff796d5.jpg'),
(39141, 2693, 'Pokemon S11 E50', 'http://sinalprivado.info:80/series/1533784/1533784/193351.mp4', 'http://timg.bdta.pro/images/3edfb85b9d89032942260a41a2697785.jpg'),
(39142, 2693, 'Pokemon S11 E51', 'http://sinalprivado.info:80/series/1533784/1533784/193352.mp4', 'http://timg.bdta.pro/images/12eb78b06a3102973e4ace60858e8fb2.jpg'),
(39143, 2693, 'Pokemon S11 E52', 'http://sinalprivado.info:80/series/1533784/1533784/193353.mp4', 'http://timg.bdta.pro/images/22efe668978275bd0f6897cb8cb48ffe.jpg'),
(39144, 2694, 'Pokemon S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193354.mp4', 'http://timg.bdta.pro/images/1396b5b733445d123b71cd88a8f93acf.jpg'),
(39145, 2694, 'Pokemon S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193355.mp4', 'http://timg.bdta.pro/images/6bc0d36d7cc5f1a8c42ecf95bf4d2f12.jpg'),
(39146, 2694, 'Pokemon S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193356.mp4', 'http://timg.bdta.pro/images/b99a1c65602f1ec1a1ca02bf6cf3c62e.jpg'),
(39147, 2694, 'Pokemon S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193357.mp4', 'http://timg.bdta.pro/images/b20b234c8986c436d6c28fc343f4c783.jpg'),
(39148, 2694, 'Pokemon S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193358.mp4', 'http://timg.bdta.pro/images/2e745c26fcf4c699055b5b7670bb61f0.jpg'),
(39149, 2694, 'Pokemon S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193359.mp4', 'http://timg.bdta.pro/images/724af34afc761ad8836c383fa3ad2955.jpg'),
(39150, 2694, 'Pokemon S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193360.mp4', 'http://timg.bdta.pro/images/3b95f4ade7be58408ec8cc0f276ae43b.jpg'),
(39151, 2694, 'Pokemon S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193361.mp4', 'http://timg.bdta.pro/images/dd9ae0077b0bfe78599aceddf7c3d62b.jpg'),
(39152, 2694, 'Pokemon S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193362.mp4', 'http://timg.bdta.pro/images/cbe49ecd202a689bbcb02f50e661d744.jpg'),
(39153, 2694, 'Pokemon S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193363.mp4', 'http://timg.bdta.pro/images/02d04e2b101d30df68b3ea6b3a652640.jpg'),
(39154, 2694, 'Pokemon S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193364.mp4', 'http://timg.bdta.pro/images/fec902286bc2fddbf708b6ea1bbef800.jpg'),
(39155, 2694, 'Pokemon S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193365.mp4', 'http://timg.bdta.pro/images/c5c800eaf2a2d6b9c4577a40689629f7.jpg'),
(39156, 2694, 'Pokemon S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193366.mp4', 'http://timg.bdta.pro/images/0e8b7199b75c3e9aee2b40a7bfecef40.jpg'),
(39157, 2694, 'Pokemon S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/193367.mp4', 'http://timg.bdta.pro/images/2e9ff19091ed1600bbd804c83d6d4893.jpg'),
(39158, 2694, 'Pokemon S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/193368.mp4', 'http://timg.bdta.pro/images/1d9cdd444707d6e992df87fdc9d56def.jpg'),
(39159, 2694, 'Pokemon S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/193369.mp4', 'http://timg.bdta.pro/images/5a6f59913ca05c5afa522e18c3966eab.jpg'),
(39160, 2694, 'Pokemon S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/193370.mp4', 'http://timg.bdta.pro/images/75d7259bdd709b08db2d53fe29f35c36.jpg'),
(39161, 2694, 'Pokemon S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/193371.mp4', 'http://timg.bdta.pro/images/bd9c46ebcab18538c41855b2a1f5e72b.jpg'),
(39162, 2694, 'Pokemon S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/193372.mp4', 'http://timg.bdta.pro/images/16d087b213572f0ab6e7fef2e3319a51.jpg'),
(39163, 2694, 'Pokemon S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/193373.mp4', 'http://timg.bdta.pro/images/c90c764d7359e372c1e87ee3bd01bcab.jpg'),
(39164, 2694, 'Pokemon S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/193374.mp4', 'http://timg.bdta.pro/images/781915cb00e5dfcc0aa204c3de48b8f5.jpg'),
(39165, 2694, 'Pokemon S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/193375.mp4', 'http://timg.bdta.pro/images/71537b340182f691c090fc8e88d18cfd.jpg'),
(39166, 2694, 'Pokemon S12 E23', 'http://sinalprivado.info:80/series/1533784/1533784/193376.mp4', 'http://timg.bdta.pro/images/a1eb8e4cba4a109c1585ea8c3fb1e43a.jpg'),
(39167, 2694, 'Pokemon S12 E24', 'http://sinalprivado.info:80/series/1533784/1533784/193377.mp4', 'http://timg.bdta.pro/images/a6820e3d44a0e5ceebfd1aeab24b81e3.jpg'),
(39168, 2694, 'Pokemon S12 E25', 'http://sinalprivado.info:80/series/1533784/1533784/193378.mp4', 'http://timg.bdta.pro/images/322996609108bb51fb40eeb75ce07b2e.jpg'),
(39169, 2694, 'Pokemon S12 E26', 'http://sinalprivado.info:80/series/1533784/1533784/193379.mp4', 'http://timg.bdta.pro/images/6584cfe8517385edb40fb0ce899d5b24.jpg'),
(39170, 2694, 'Pokemon S12 E27', 'http://sinalprivado.info:80/series/1533784/1533784/193380.mp4', 'http://timg.bdta.pro/images/3b6ba4b9f6263e0803612f74656f484d.jpg'),
(39171, 2694, 'Pokemon S12 E28', 'http://sinalprivado.info:80/series/1533784/1533784/193381.mp4', 'http://timg.bdta.pro/images/a55eaaf1790d56778adcf7557e59ab21.jpg'),
(39172, 2694, 'Pokemon S12 E29', 'http://sinalprivado.info:80/series/1533784/1533784/193382.mp4', 'http://timg.bdta.pro/images/ace29dbc9259952520cb6eaea8e8f6d2.jpg'),
(39173, 2694, 'Pokemon S12 E30', 'http://sinalprivado.info:80/series/1533784/1533784/193383.mp4', 'http://timg.bdta.pro/images/2e81e093e0d56f6f9fec2b92d62ebc12.jpg'),
(39174, 2694, 'Pokemon S12 E31', 'http://sinalprivado.info:80/series/1533784/1533784/193384.mp4', 'http://timg.bdta.pro/images/1c90905dfdf42c9c5955f21dbb969de7.jpg'),
(39175, 2694, 'Pokemon S12 E32', 'http://sinalprivado.info:80/series/1533784/1533784/193385.mp4', 'http://timg.bdta.pro/images/6758247527fc064524f24beaa453c976.jpg'),
(39176, 2694, 'Pokemon S12 E33', 'http://sinalprivado.info:80/series/1533784/1533784/193386.mp4', 'http://timg.bdta.pro/images/1bbe1bd7b604cd38dad85d5022b18421.jpg'),
(39177, 2694, 'Pokemon S12 E34', 'http://sinalprivado.info:80/series/1533784/1533784/193387.mp4', 'http://timg.bdta.pro/images/ab1bd87d576ad082646269567dd4550f.jpg'),
(39178, 2694, 'Pokemon S12 E35', 'http://sinalprivado.info:80/series/1533784/1533784/193388.mp4', 'http://timg.bdta.pro/images/09ab3bb023b2ff54d6789ee8014efa92.jpg'),
(39179, 2694, 'Pokemon S12 E36', 'http://sinalprivado.info:80/series/1533784/1533784/193389.mp4', 'http://timg.bdta.pro/images/7e723ebbb210d0e6290bc07bfa6f5c5c.jpg'),
(39180, 2694, 'Pokemon S12 E37', 'http://sinalprivado.info:80/series/1533784/1533784/193390.mp4', 'http://timg.bdta.pro/images/7748b88002b9785f91486c34c5849736.jpg'),
(39181, 2694, 'Pokemon S12 E38', 'http://sinalprivado.info:80/series/1533784/1533784/193391.mp4', 'http://timg.bdta.pro/images/0deff58049fbb0f90c8181699c9468bd.jpg'),
(39182, 2694, 'Pokemon S12 E39', 'http://sinalprivado.info:80/series/1533784/1533784/193392.mp4', 'http://timg.bdta.pro/images/8b5f707bea88fd67ae8740e353c355c7.jpg'),
(39183, 2694, 'Pokemon S12 E40', 'http://sinalprivado.info:80/series/1533784/1533784/193393.mp4', 'http://timg.bdta.pro/images/d8ba23dc84c5bd5a9e560b5194a80a5f.jpg'),
(39184, 2694, 'Pokemon S12 E41', 'http://sinalprivado.info:80/series/1533784/1533784/193394.mp4', 'http://timg.bdta.pro/images/b761691975ce67092bf08f56268c7fe2.jpg'),
(39185, 2694, 'Pokemon S12 E42', 'http://sinalprivado.info:80/series/1533784/1533784/193395.mp4', 'http://timg.bdta.pro/images/60bd61fb7ffbd06dd964540a7610c5d7.jpg'),
(39186, 2694, 'Pokemon S12 E43', 'http://sinalprivado.info:80/series/1533784/1533784/193396.mp4', 'http://timg.bdta.pro/images/b9c1ac8347d82b851ddf247de80313ff.jpg'),
(39187, 2694, 'Pokemon S12 E44', 'http://sinalprivado.info:80/series/1533784/1533784/193397.mp4', 'http://timg.bdta.pro/images/9bddc6cbeddf800014f45c765e04926f.jpg'),
(39188, 2694, 'Pokemon S12 E45', 'http://sinalprivado.info:80/series/1533784/1533784/193398.mp4', 'http://timg.bdta.pro/images/13f9a824eaa98aef25f1aa94e9169990.jpg'),
(39189, 2694, 'Pokemon S12 E46', 'http://sinalprivado.info:80/series/1533784/1533784/193399.mp4', 'http://timg.bdta.pro/images/0bef049b3f72c908e54c9460c521537c.jpg'),
(39190, 2694, 'Pokemon S12 E47', 'http://sinalprivado.info:80/series/1533784/1533784/193400.mp4', 'http://timg.bdta.pro/images/42eab52ddc91f2d6410b9ebb44d8efd0.jpg'),
(39191, 2694, 'Pokemon S12 E48', 'http://sinalprivado.info:80/series/1533784/1533784/193401.mp4', 'http://timg.bdta.pro/images/4b32c86ee1dfec0e1795ca4591419ac2.jpg'),
(39192, 2694, 'Pokemon S12 E49', 'http://sinalprivado.info:80/series/1533784/1533784/193402.mp4', 'http://timg.bdta.pro/images/32c093a805bcf7a0ec0ef73f16f32eb3.jpg'),
(39193, 2694, 'Pokemon S12 E50', 'http://sinalprivado.info:80/series/1533784/1533784/193403.mp4', 'http://timg.bdta.pro/images/56043bf6f3624566ae87c0a51e7b92b4.jpg'),
(39194, 2694, 'Pokemon S12 E51', 'http://sinalprivado.info:80/series/1533784/1533784/193404.mp4', 'http://timg.bdta.pro/images/e57bd5a5e5e1ef036ddf3d2bb243fa28.jpg'),
(39195, 2694, 'Pokemon S12 E52', 'http://sinalprivado.info:80/series/1533784/1533784/193405.mp4', 'http://timg.bdta.pro/images/07a36d3e19393ffc355becf8a81cb641.jpg'),
(39196, 2694, 'Pokemon S12 E53', 'http://sinalprivado.info:80/series/1533784/1533784/193406.mp4', 'http://timg.bdta.pro/images/6c5dfa591761302c81fd00f99f56fc4f.jpg'),
(39197, 2695, 'Pokemon S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193407.mp4', 'http://timg.bdta.pro/images/5ee2b6595846bddd13a903e86b8eee54.jpg'),
(39198, 2695, 'Pokemon S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193408.mp4', 'http://timg.bdta.pro/images/bc773546f72baac8a319d175205cd02f.jpg'),
(39199, 2695, 'Pokemon S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193409.mp4', 'http://timg.bdta.pro/images/00686de50167779350e08b32e28c87ce.jpg'),
(39200, 2695, 'Pokemon S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193410.mp4', 'http://timg.bdta.pro/images/d6714593d4b598fd201c8d069dd579e3.jpg'),
(39201, 2695, 'Pokemon S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193411.mp4', 'http://timg.bdta.pro/images/40ddc25c4fac8c817145706daafcd48e.jpg'),
(39202, 2695, 'Pokemon S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193412.mp4', 'http://timg.bdta.pro/images/0293b6be9b16f3b9c68846bddb8649bd.jpg'),
(39203, 2695, 'Pokemon S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193413.mp4', 'http://timg.bdta.pro/images/9f6040216b9ab972aaf561d69b09929e.jpg'),
(39204, 2695, 'Pokemon S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193414.mp4', 'http://timg.bdta.pro/images/258b9cb6b62f44903dd271ca58e89f1b.jpg'),
(39205, 2695, 'Pokemon S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193415.mp4', 'http://timg.bdta.pro/images/bc8ddcb5b0de1b962f36000cd5f69e47.jpg'),
(39206, 2695, 'Pokemon S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193416.mp4', 'http://timg.bdta.pro/images/c0c8d386fabdaa3d1cefb8324dca1a1a.jpg'),
(39207, 2695, 'Pokemon S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193417.mp4', 'http://timg.bdta.pro/images/65130e4a9ecdd731465716d5031549dc.jpg'),
(39208, 2695, 'Pokemon S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193418.mp4', 'http://timg.bdta.pro/images/e9aea2c5a2ec0a90ef7750e46d99ec8b.jpg'),
(39209, 2695, 'Pokemon S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193419.mp4', 'http://timg.bdta.pro/images/140b8f2911bc46bf866a4a3c90e84cc3.jpg'),
(39210, 2695, 'Pokemon S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/193420.mp4', 'http://timg.bdta.pro/images/97f889a1b38e32787ad3e2dfad74682c.jpg'),
(39211, 2695, 'Pokemon S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/193421.mp4', 'http://timg.bdta.pro/images/16b13dd1c16f6e13a07f443fdfa49768.jpg'),
(39212, 2695, 'Pokemon S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/193422.mp4', 'http://timg.bdta.pro/images/1fca1f8e960a01c20a781f32fe212142.jpg'),
(39213, 2695, 'Pokemon S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/193423.mp4', 'http://timg.bdta.pro/images/cd05ce67a7c52f55d9249c6f671f5099.jpg'),
(39214, 2695, 'Pokemon S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/193424.mp4', 'http://timg.bdta.pro/images/d38c8edb98ef27346caeb971862e12eb.jpg'),
(39215, 2695, 'Pokemon S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/193425.mp4', 'http://timg.bdta.pro/images/3426fea670f7d757342d002be53e6374.jpg'),
(39216, 2695, 'Pokemon S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/193426.mp4', 'http://timg.bdta.pro/images/ff19eeed3117e35dfd7234550fdd8340.jpg'),
(39217, 2695, 'Pokemon S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/193427.mp4', 'http://timg.bdta.pro/images/b8ccc6da8af30fca7735573ac0179d43.jpg'),
(39218, 2695, 'Pokemon S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/193428.mp4', 'http://timg.bdta.pro/images/6807ad066c73bc13d8fe5231eaf557dd.jpg'),
(39219, 2695, 'Pokemon S13 E23', 'http://sinalprivado.info:80/series/1533784/1533784/193429.mp4', 'http://timg.bdta.pro/images/231072ceaff62d43abbe94f4e7fd9653.jpg'),
(39220, 2695, 'Pokemon S13 E24', 'http://sinalprivado.info:80/series/1533784/1533784/193430.mp4', 'http://timg.bdta.pro/images/49d2ceb4557079693a45bb13f8c304f8.jpg'),
(39221, 2695, 'Pokemon S13 E25', 'http://sinalprivado.info:80/series/1533784/1533784/193431.mp4', 'http://timg.bdta.pro/images/5ac1022127e826537be6dbceb289479a.jpg'),
(39222, 2695, 'Pokemon S13 E26', 'http://sinalprivado.info:80/series/1533784/1533784/193432.mp4', 'http://timg.bdta.pro/images/b7363faf9f4f100f50f567bc111a82dd.jpg'),
(39223, 2695, 'Pokemon S13 E27', 'http://sinalprivado.info:80/series/1533784/1533784/193433.mp4', 'http://timg.bdta.pro/images/829301cf317531bb5afaf4a72bcfba95.jpg'),
(39224, 2695, 'Pokemon S13 E28', 'http://sinalprivado.info:80/series/1533784/1533784/193434.mp4', 'http://timg.bdta.pro/images/d51054c04788b01145f05ee1942bf8ee.jpg'),
(39225, 2695, 'Pokemon S13 E29', 'http://sinalprivado.info:80/series/1533784/1533784/193435.mp4', 'http://timg.bdta.pro/images/59e820ecb3bcda27c09f557dc7034af0.jpg'),
(39226, 2695, 'Pokemon S13 E30', 'http://sinalprivado.info:80/series/1533784/1533784/193436.mp4', 'http://timg.bdta.pro/images/9dfc679dd76a9d72cc6db58c1d4002df.jpg'),
(39227, 2695, 'Pokemon S13 E31', 'http://sinalprivado.info:80/series/1533784/1533784/193437.mp4', 'http://timg.bdta.pro/images/5011b5091b5a20338fb8c95b1cdc0387.jpg'),
(39228, 2695, 'Pokemon S13 E32', 'http://sinalprivado.info:80/series/1533784/1533784/193438.mp4', 'http://timg.bdta.pro/images/29cd0ab30390f5ff32c583efa0c9a41a.jpg'),
(39229, 2695, 'Pokemon S13 E33', 'http://sinalprivado.info:80/series/1533784/1533784/193439.mp4', 'http://timg.bdta.pro/images/bfe8056b2d730d163656216ff4593624.jpg'),
(39230, 2695, 'Pokemon S13 E34', 'http://sinalprivado.info:80/series/1533784/1533784/193440.mp4', 'http://timg.bdta.pro/images/1ef623fd191d20ca5e984ee3d45e1300.jpg'),
(39231, 2695, 'Pokemon S13 E35', 'http://sinalprivado.info:80/series/1533784/1533784/193441.mp4', 'http://gstaticontent.com/images/cce5482f122e672ea4457e978496130d.jpg'),
(39232, 2695, 'Pokemon S13 E36', 'http://sinalprivado.info:80/series/1533784/1533784/193442.mp4', 'http://gstaticontent.com/images/cce5482f122e672ea4457e978496130d.jpg'),
(39233, 2696, 'Pokemon S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193443.mp4', 'http://timg.bdta.pro/images/a5acaf2ebb3b3ad75eab40445fcbeee5.jpg'),
(39234, 2696, 'Pokemon S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193444.mp4', 'http://timg.bdta.pro/images/205c3e993cacb5440e18a445866a4015.jpg'),
(39235, 2696, 'Pokemon S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193445.mp4', 'http://timg.bdta.pro/images/ef8b3e17f9bde73ced44ae0077e4f22f.jpg'),
(39236, 2696, 'Pokemon S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193446.mp4', 'http://timg.bdta.pro/images/129f192f8af70a6456d6e7cb94a7da15.jpg'),
(39237, 2696, 'Pokemon S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193447.mp4', 'http://timg.bdta.pro/images/52d038cac42a7284511dad82dfbb4f5f.jpg'),
(39238, 2696, 'Pokemon S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193448.mp4', 'http://timg.bdta.pro/images/772a86b61cce186a88b8c29fc15d2b4b.jpg'),
(39239, 2696, 'Pokemon S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193449.mp4', 'http://timg.bdta.pro/images/3b01ec8a6f74cb301b6abf9964d0279d.jpg'),
(39240, 2696, 'Pokemon S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193450.mp4', 'http://timg.bdta.pro/images/d50cb783e16e10e47aca83b51496da5d.jpg'),
(39241, 2696, 'Pokemon S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193451.mp4', 'http://timg.bdta.pro/images/739338998f57c86fac3d8809dfeb1b16.jpg'),
(39242, 2696, 'Pokemon S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193452.mp4', 'http://timg.bdta.pro/images/9bd84127e45d50501241b8c090bec015.jpg'),
(39243, 2696, 'Pokemon S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193453.mp4', 'http://timg.bdta.pro/images/89643b0d536366107cd87923f82bea60.jpg'),
(39244, 2696, 'Pokemon S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193454.mp4', 'http://timg.bdta.pro/images/030914a4a31f312e0a2550befa9841c8.jpg'),
(39245, 2696, 'Pokemon S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193455.mp4', 'http://timg.bdta.pro/images/d143c8c3af18c3d3d008c67deab93696.jpg'),
(39246, 2696, 'Pokemon S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/193456.mp4', 'http://timg.bdta.pro/images/f4d0f607cb9c4050b2065dd275c84466.jpg'),
(39247, 2696, 'Pokemon S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/193457.mp4', 'http://timg.bdta.pro/images/0c3423b5be37c79a1e5e84443ed87d14.jpg'),
(39248, 2696, 'Pokemon S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/193458.mp4', 'http://timg.bdta.pro/images/7c7da604569b1d570f31f441fede7c48.jpg'),
(39249, 2696, 'Pokemon S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/193459.mp4', 'http://timg.bdta.pro/images/efd1dcf34ea4960c5e831f3f8ea2803c.jpg'),
(39250, 2696, 'Pokemon S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/193460.mp4', 'http://timg.bdta.pro/images/619f538059d598d8cfb585479d5423b0.jpg'),
(39251, 2696, 'Pokemon S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/193461.mp4', 'http://timg.bdta.pro/images/37ea44c1589f52858285b4450216d08f.jpg'),
(39252, 2696, 'Pokemon S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/193462.mp4', 'http://timg.bdta.pro/images/c5730c60839ff5eb9a0031d072d0d12f.jpg'),
(39253, 2696, 'Pokemon S14 E21', 'http://sinalprivado.info:80/series/1533784/1533784/193463.mp4', 'http://timg.bdta.pro/images/b6c27687ec550d6523aeda75f1ac555b.jpg'),
(39254, 2696, 'Pokemon S14 E22', 'http://sinalprivado.info:80/series/1533784/1533784/193464.mp4', 'http://timg.bdta.pro/images/8eff5933671439d1d97b9469b51f9edc.jpg'),
(39255, 2696, 'Pokemon S14 E23', 'http://sinalprivado.info:80/series/1533784/1533784/193465.mp4', 'http://timg.bdta.pro/images/18b74a778147e40b6d3b27c96ee1a3a8.jpg'),
(39256, 2696, 'Pokemon S14 E24', 'http://sinalprivado.info:80/series/1533784/1533784/193466.mp4', 'http://timg.bdta.pro/images/262fa8321a449df20c49b9de17930fef.jpg'),
(39257, 2696, 'Pokemon S14 E25', 'http://sinalprivado.info:80/series/1533784/1533784/193467.mp4', 'http://timg.bdta.pro/images/4d6ea03306decaa024af70f11542dba3.jpg'),
(39258, 2696, 'Pokemon S14 E26', 'http://sinalprivado.info:80/series/1533784/1533784/193468.mp4', 'http://timg.bdta.pro/images/301b025a1dde4b84f1951aacbfbfac7f.jpg'),
(39259, 2696, 'Pokemon S14 E27', 'http://sinalprivado.info:80/series/1533784/1533784/193469.mp4', 'http://timg.bdta.pro/images/8df9a1bed3dcd6fd565e1aa8f438f1fc.jpg'),
(39260, 2696, 'Pokemon S14 E28', 'http://sinalprivado.info:80/series/1533784/1533784/193470.mp4', 'http://timg.bdta.pro/images/0d7ff9740d8e37bbd1b555c629f9ee8c.jpg'),
(39261, 2696, 'Pokemon S14 E29', 'http://sinalprivado.info:80/series/1533784/1533784/193471.mp4', 'http://timg.bdta.pro/images/fb97c7245a6b7e547f3bc4e4a8306d5d.jpg'),
(39262, 2696, 'Pokemon S14 E30', 'http://sinalprivado.info:80/series/1533784/1533784/193472.mp4', 'http://timg.bdta.pro/images/595eb03488e321f1bbdf7d9a5229b7d4.jpg'),
(39263, 2696, 'Pokemon S14 E31', 'http://sinalprivado.info:80/series/1533784/1533784/193473.mp4', 'http://timg.bdta.pro/images/b13b5715ccab4e8c49289db3b2d0af45.jpg'),
(39264, 2696, 'Pokemon S14 E32', 'http://sinalprivado.info:80/series/1533784/1533784/193474.mp4', 'http://timg.bdta.pro/images/8b8987847cc0eee2f3ac8f0d73de26fb.jpg'),
(39265, 2696, 'Pokemon S14 E33', 'http://sinalprivado.info:80/series/1533784/1533784/193475.mp4', 'http://timg.bdta.pro/images/6404e5b44bcc6fdbe59be65405b8967a.jpg'),
(39266, 2696, 'Pokemon S14 E34', 'http://sinalprivado.info:80/series/1533784/1533784/193476.mp4', 'http://timg.bdta.pro/images/658803cbc6a4a39ef55dbe7433796528.jpg'),
(39267, 2696, 'Pokemon S14 E35', 'http://sinalprivado.info:80/series/1533784/1533784/193477.mp4', 'http://timg.bdta.pro/images/9e415d7e4e0b1d51abfce9dfd5fc970e.jpg'),
(39268, 2696, 'Pokemon S14 E36', 'http://sinalprivado.info:80/series/1533784/1533784/193478.mp4', 'http://timg.bdta.pro/images/c5b7a1ed5c6d43f02cc0ebcb51a4ab40.jpg'),
(39269, 2696, 'Pokemon S14 E37', 'http://sinalprivado.info:80/series/1533784/1533784/193479.mp4', 'http://timg.bdta.pro/images/fa3bdd54bbb9856cf6cc031e01b10c2f.jpg'),
(39270, 2696, 'Pokemon S14 E38', 'http://sinalprivado.info:80/series/1533784/1533784/193480.mp4', 'http://timg.bdta.pro/images/d2086ac7f5f277972530afc6fbca286b.jpg'),
(39271, 2696, 'Pokemon S14 E39', 'http://sinalprivado.info:80/series/1533784/1533784/193481.mp4', 'http://timg.bdta.pro/images/ed93b72712c41bb1ce467f3ed9e2777b.jpg'),
(39272, 2696, 'Pokemon S14 E40', 'http://sinalprivado.info:80/series/1533784/1533784/193482.mp4', 'http://timg.bdta.pro/images/578ff3e1f421e6408ea170a6a78742a9.jpg'),
(39273, 2696, 'Pokemon S14 E41', 'http://sinalprivado.info:80/series/1533784/1533784/193483.mp4', 'http://timg.bdta.pro/images/d865d72a441ba22b1adc7623e96bbca8.jpg'),
(39274, 2696, 'Pokemon S14 E42', 'http://sinalprivado.info:80/series/1533784/1533784/193484.mp4', 'http://timg.bdta.pro/images/9b8565d89ae8763a3eb0893f3f2d9002.jpg'),
(39275, 2696, 'Pokemon S14 E43', 'http://sinalprivado.info:80/series/1533784/1533784/193485.mp4', 'http://timg.bdta.pro/images/2432e589f0420f94caea7e3b848f5287.jpg'),
(39276, 2696, 'Pokemon S14 E44', 'http://sinalprivado.info:80/series/1533784/1533784/193486.mp4', 'http://timg.bdta.pro/images/304aa8c26718867e5e21519976951eaa.jpg'),
(39277, 2696, 'Pokemon S14 E45', 'http://sinalprivado.info:80/series/1533784/1533784/193487.mp4', 'http://timg.bdta.pro/images/64a625cd6d9f112ab7aecbd95796ccbe.jpg'),
(39278, 2696, 'Pokemon S14 E46', 'http://sinalprivado.info:80/series/1533784/1533784/193488.mp4', 'http://timg.bdta.pro/images/1a7bca458bafddd96f08a59f786ffb08.jpg'),
(39279, 2696, 'Pokemon S14 E47', 'http://sinalprivado.info:80/series/1533784/1533784/193489.mp4', 'http://timg.bdta.pro/images/90100eb25cd73d7b0a3d5b9541a86240.jpg'),
(39280, 2696, 'Pokemon S14 E48', 'http://sinalprivado.info:80/series/1533784/1533784/193490.mp4', 'http://timg.bdta.pro/images/a114e788bfc2a3cbee0db8e2a91c934c.jpg'),
(39281, 2697, 'Pokemon S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193491.mp4', 'http://timg.bdta.pro/images/6c7f2e32970402d331064089b09c3dc7.jpg'),
(39282, 2697, 'Pokemon S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193492.mp4', 'http://timg.bdta.pro/images/05b9c6b29bf8f1342aad946c305a9949.jpg'),
(39283, 2697, 'Pokemon S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193493.mp4', 'http://timg.bdta.pro/images/8f3a32b2144fe39232a3864aabf636b8.jpg'),
(39284, 2697, 'Pokemon S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193494.mp4', 'http://timg.bdta.pro/images/83424a2902b2dc1fe348bb93ad4cbec5.jpg'),
(39285, 2697, 'Pokemon S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193495.mp4', 'http://timg.bdta.pro/images/6834fa6aa9aab72975ef171aacd3001b.jpg'),
(39286, 2697, 'Pokemon S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193496.mp4', 'http://timg.bdta.pro/images/c724a737f0260fc08b5af48a5ab835ca.jpg'),
(39287, 2697, 'Pokemon S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193497.mp4', 'http://timg.bdta.pro/images/a3cbb4b449db57d1dd103e1dea19c2a2.jpg'),
(39288, 2697, 'Pokemon S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193498.mp4', 'http://timg.bdta.pro/images/6d118ee45d086c697df261fe842601d9.jpg'),
(39289, 2697, 'Pokemon S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193499.mp4', 'http://timg.bdta.pro/images/da765e6ce8457bf4b79e55f3b14f2940.jpg'),
(39290, 2697, 'Pokemon S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193500.mp4', 'http://timg.bdta.pro/images/283b16db7e0fcfcc66fda1de6676a64d.jpg'),
(39291, 2697, 'Pokemon S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193501.mp4', 'http://timg.bdta.pro/images/91d8fdfbeae5da2809da245586241eee.jpg'),
(39292, 2697, 'Pokemon S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193502.mp4', 'http://timg.bdta.pro/images/b118b4b250b3dea54abc74bea7987ac8.jpg'),
(39293, 2697, 'Pokemon S15 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193503.mp4', 'http://timg.bdta.pro/images/dba7edf51ca196e3efd3f15f9756b647.jpg'),
(39294, 2697, 'Pokemon S15 E14', 'http://sinalprivado.info:80/series/1533784/1533784/193504.mp4', 'http://timg.bdta.pro/images/6ca364371d157ea70b4344e8846eaac6.jpg'),
(39295, 2697, 'Pokemon S15 E15', 'http://sinalprivado.info:80/series/1533784/1533784/193505.mp4', 'http://timg.bdta.pro/images/45540d378d8c3d0e81b4b8dbc95a4f79.jpg'),
(39296, 2697, 'Pokemon S15 E16', 'http://sinalprivado.info:80/series/1533784/1533784/193506.mp4', 'http://timg.bdta.pro/images/7cbefd6f6085782986d6a0bd9c11de25.jpg'),
(39297, 2697, 'Pokemon S15 E17', 'http://sinalprivado.info:80/series/1533784/1533784/193507.mp4', 'http://timg.bdta.pro/images/c1312503b40593bc06fd3bd0d0faf164.jpg'),
(39298, 2697, 'Pokemon S15 E18', 'http://sinalprivado.info:80/series/1533784/1533784/193508.mp4', 'http://timg.bdta.pro/images/c1f1830d0a06b95f2167cb2cdabddbf9.jpg'),
(39299, 2697, 'Pokemon S15 E19', 'http://sinalprivado.info:80/series/1533784/1533784/193509.mp4', 'http://timg.bdta.pro/images/cf894c401a821e5ae505d3163ac88765.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(39300, 2697, 'Pokemon S15 E20', 'http://sinalprivado.info:80/series/1533784/1533784/193510.mp4', 'http://timg.bdta.pro/images/07f8a5f5a25cf64ef12ca4537a1c772c.jpg'),
(39301, 2697, 'Pokemon S15 E21', 'http://sinalprivado.info:80/series/1533784/1533784/193511.mp4', 'http://timg.bdta.pro/images/4bc5e4a4c2c813a5e3a22f55dafc89b8.jpg'),
(39302, 2697, 'Pokemon S15 E22', 'http://sinalprivado.info:80/series/1533784/1533784/193512.mp4', 'http://timg.bdta.pro/images/f51a5778cb43273704c0d8e25f6c8679.jpg'),
(39303, 2697, 'Pokemon S15 E23', 'http://sinalprivado.info:80/series/1533784/1533784/193513.mp4', 'http://timg.bdta.pro/images/b0d63533ba63216313053b443a299f36.jpg'),
(39304, 2697, 'Pokemon S15 E24', 'http://sinalprivado.info:80/series/1533784/1533784/193514.mp4', 'http://timg.bdta.pro/images/81142e8399948db406ccad6664f1c5a5.jpg'),
(39305, 2697, 'Pokemon S15 E25', 'http://sinalprivado.info:80/series/1533784/1533784/193515.mp4', 'http://timg.bdta.pro/images/bfe1d70fdf7b2e13dee83cf1601463c4.jpg'),
(39306, 2697, 'Pokemon S15 E26', 'http://sinalprivado.info:80/series/1533784/1533784/193516.mp4', 'http://timg.bdta.pro/images/19dcdd47989ce4d07a235d822ef0cd26.jpg'),
(39307, 2697, 'Pokemon S15 E27', 'http://sinalprivado.info:80/series/1533784/1533784/193517.mp4', 'http://timg.bdta.pro/images/bf126bec31f1ec8c2964314b7dc6fb03.jpg'),
(39308, 2697, 'Pokemon S15 E28', 'http://sinalprivado.info:80/series/1533784/1533784/193518.mp4', 'http://timg.bdta.pro/images/01f1f3c832043e033f3c598317cce291.jpg'),
(39309, 2697, 'Pokemon S15 E29', 'http://sinalprivado.info:80/series/1533784/1533784/193519.mp4', 'http://timg.bdta.pro/images/f7ea401914bdea91c409dda970254ace.jpg'),
(39310, 2697, 'Pokemon S15 E30', 'http://sinalprivado.info:80/series/1533784/1533784/193520.mp4', 'http://timg.bdta.pro/images/7d0fb581dcb4714e8e8bd930d602d6ce.jpg'),
(39311, 2697, 'Pokemon S15 E31', 'http://sinalprivado.info:80/series/1533784/1533784/193521.mp4', 'http://timg.bdta.pro/images/1e912e7f2867344d9328e9467a642274.jpg'),
(39312, 2697, 'Pokemon S15 E32', 'http://sinalprivado.info:80/series/1533784/1533784/193522.mp4', 'http://timg.bdta.pro/images/ea8cab63977c3f4506f3acef5a7582e0.jpg'),
(39313, 2697, 'Pokemon S15 E33', 'http://sinalprivado.info:80/series/1533784/1533784/193523.mp4', 'http://timg.bdta.pro/images/41a551aa8b16c0e2fab9c88d2272bb7f.jpg'),
(39314, 2697, 'Pokemon S15 E34', 'http://sinalprivado.info:80/series/1533784/1533784/193524.mp4', 'http://timg.bdta.pro/images/9d93475472f75a358080c6ff983585a7.jpg'),
(39315, 2697, 'Pokemon S15 E35', 'http://sinalprivado.info:80/series/1533784/1533784/193525.mp4', 'http://timg.bdta.pro/images/3d7d35f7516988f99aec08268b7c8644.jpg'),
(39316, 2697, 'Pokemon S15 E36', 'http://sinalprivado.info:80/series/1533784/1533784/193526.mp4', 'http://timg.bdta.pro/images/008fde9470caad680004a456e99e20cf.jpg'),
(39317, 2697, 'Pokemon S15 E37', 'http://sinalprivado.info:80/series/1533784/1533784/193527.mp4', 'http://timg.bdta.pro/images/392e0c3108a5cd212580f9fb41bcb529.jpg'),
(39318, 2697, 'Pokemon S15 E38', 'http://sinalprivado.info:80/series/1533784/1533784/193528.mp4', 'http://timg.bdta.pro/images/4b41088fc1a2568737118fab04b6ed84.jpg'),
(39319, 2697, 'Pokemon S15 E39', 'http://sinalprivado.info:80/series/1533784/1533784/193529.mp4', 'http://timg.bdta.pro/images/6d56fc824eb7ba2b908dc46ed09150b3.jpg'),
(39320, 2697, 'Pokemon S15 E40', 'http://sinalprivado.info:80/series/1533784/1533784/193530.mp4', 'http://timg.bdta.pro/images/f0d86f7418509503627cf9c6334cb28d.jpg'),
(39321, 2697, 'Pokemon S15 E41', 'http://sinalprivado.info:80/series/1533784/1533784/193531.mp4', 'http://timg.bdta.pro/images/80454d51f9478b7517e37b2bf2eb6dd7.jpg'),
(39322, 2697, 'Pokemon S15 E42', 'http://sinalprivado.info:80/series/1533784/1533784/193532.mp4', 'http://timg.bdta.pro/images/1600a77e33f221b7b898d63efb19c5da.jpg'),
(39323, 2697, 'Pokemon S15 E43', 'http://sinalprivado.info:80/series/1533784/1533784/193533.mp4', 'http://timg.bdta.pro/images/4b2b24c7dc99b4999740212cc167f0e9.jpg'),
(39324, 2697, 'Pokemon S15 E44', 'http://sinalprivado.info:80/series/1533784/1533784/193534.mp4', 'http://timg.bdta.pro/images/9eb39840d1c7f3cf358e5e4b4e60a5ec.jpg'),
(39325, 2697, 'Pokemon S15 E45', 'http://sinalprivado.info:80/series/1533784/1533784/193535.mp4', 'http://timg.bdta.pro/images/553aed97255f26cc4e4c5ac4f50f48de.jpg'),
(39326, 2697, 'Pokemon S15 E46', 'http://sinalprivado.info:80/series/1533784/1533784/193536.mp4', 'http://timg.bdta.pro/images/66a162d2a99d28cf151f78975047c306.jpg'),
(39327, 2697, 'Pokemon S15 E47', 'http://sinalprivado.info:80/series/1533784/1533784/193537.mp4', 'http://timg.bdta.pro/images/1a5f47386b82ae3cfd6d3738753f3842.jpg'),
(39328, 2697, 'Pokemon S15 E48', 'http://sinalprivado.info:80/series/1533784/1533784/193538.mp4', 'http://timg.bdta.pro/images/8bba0d9807c318cfaa5fc8fbede6a516.jpg'),
(39329, 2697, 'Pokemon S15 E49', 'http://sinalprivado.info:80/series/1533784/1533784/193539.mp4', 'http://timg.bdta.pro/images/650bfca3cee14f6518a9242b290526d7.jpg'),
(39330, 2698, 'Pokemon S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193540.mp4', 'http://timg.bdta.pro/images/32464f1a3f1fc156eb5685b37e903921.jpg'),
(39331, 2698, 'Pokemon S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193541.mp4', 'http://timg.bdta.pro/images/d12d574312c0ea4845c838b3ec4b8b3a.jpg'),
(39332, 2698, 'Pokemon S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193542.mp4', 'http://timg.bdta.pro/images/0dadb9db350057520a6e7e985ab4688d.jpg'),
(39333, 2698, 'Pokemon S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193543.mp4', 'http://timg.bdta.pro/images/6844468c9e5ba3d466e9a21e2081453a.jpg'),
(39334, 2698, 'Pokemon S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193544.mp4', 'http://timg.bdta.pro/images/f892922dc149c1c570266129d2e022a4.jpg'),
(39335, 2698, 'Pokemon S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193545.mp4', 'http://timg.bdta.pro/images/caea2262e8f713abacafe2b888245a7b.jpg'),
(39336, 2698, 'Pokemon S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193546.mp4', 'http://timg.bdta.pro/images/2d0051224004d58bca4b9cbf7680d00a.jpg'),
(39337, 2698, 'Pokemon S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193547.mp4', 'http://timg.bdta.pro/images/11f91941d60dedd1f9f2739a32f7a412.jpg'),
(39338, 2698, 'Pokemon S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193548.mp4', 'http://timg.bdta.pro/images/3afe7b1890102a7c4338fbd1a8c34c08.jpg'),
(39339, 2698, 'Pokemon S16 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193549.mp4', 'http://timg.bdta.pro/images/52323f7cecf6fe70a93bb1cc1abdc63b.jpg'),
(39340, 2698, 'Pokemon S16 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193550.mp4', 'http://timg.bdta.pro/images/3e1af5da863d30acaf1aacdcc68c7657.jpg'),
(39341, 2698, 'Pokemon S16 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193551.mp4', 'http://timg.bdta.pro/images/4316de4c4da42c1b0f747990959b3298.jpg'),
(39342, 2698, 'Pokemon S16 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193552.mp4', 'http://timg.bdta.pro/images/4457640c302e67c9297bcd4f652713c1.jpg'),
(39343, 2698, 'Pokemon S16 E14', 'http://sinalprivado.info:80/series/1533784/1533784/193553.mp4', 'http://timg.bdta.pro/images/5c2bad5ccf25476017db090711edc55c.jpg'),
(39344, 2698, 'Pokemon S16 E15', 'http://sinalprivado.info:80/series/1533784/1533784/193554.mp4', 'http://timg.bdta.pro/images/c5b08903e9afb89bdc393b739901e984.jpg'),
(39345, 2698, 'Pokemon S16 E16', 'http://sinalprivado.info:80/series/1533784/1533784/193555.mp4', 'http://timg.bdta.pro/images/fb1dc3fdd34e7a1d8fd0a9d831185d11.jpg'),
(39346, 2698, 'Pokemon S16 E17', 'http://sinalprivado.info:80/series/1533784/1533784/193556.mp4', 'http://timg.bdta.pro/images/7d84c332b58a5761faffcec0bab0decb.jpg'),
(39347, 2698, 'Pokemon S16 E18', 'http://sinalprivado.info:80/series/1533784/1533784/193557.mp4', 'http://timg.bdta.pro/images/3098e3f07c08bfbdd395b23f9c19eb83.jpg'),
(39348, 2698, 'Pokemon S16 E19', 'http://sinalprivado.info:80/series/1533784/1533784/193558.mp4', 'http://timg.bdta.pro/images/84863434c27da6026ee11a6711377883.jpg'),
(39349, 2698, 'Pokemon S16 E20', 'http://sinalprivado.info:80/series/1533784/1533784/193559.mp4', 'http://timg.bdta.pro/images/c750620562622440502b3e206538f6c7.jpg'),
(39350, 2698, 'Pokemon S16 E21', 'http://sinalprivado.info:80/series/1533784/1533784/193560.mp4', 'http://timg.bdta.pro/images/ce87491f9286f4155e404e50af6a6b9e.jpg'),
(39351, 2698, 'Pokemon S16 E22', 'http://sinalprivado.info:80/series/1533784/1533784/193561.mp4', 'http://timg.bdta.pro/images/897575adb7e4fde9e4593561d33eaa17.jpg'),
(39352, 2698, 'Pokemon S16 E23', 'http://sinalprivado.info:80/series/1533784/1533784/193562.mp4', 'http://timg.bdta.pro/images/cc8eacbfd67e5b2c3c6161ee44149bff.jpg'),
(39353, 2698, 'Pokemon S16 E24', 'http://sinalprivado.info:80/series/1533784/1533784/193563.mp4', 'http://timg.bdta.pro/images/d329cdc13d6ffc9f2b530fccebfed574.jpg'),
(39354, 2698, 'Pokemon S16 E25', 'http://sinalprivado.info:80/series/1533784/1533784/193564.mp4', 'http://timg.bdta.pro/images/46f169b019e03cbfd75fb5388dee7f4d.jpg'),
(39355, 2698, 'Pokemon S16 E26', 'http://sinalprivado.info:80/series/1533784/1533784/193565.mp4', 'http://timg.bdta.pro/images/0a2d09c46b7a7f56a99a5a4d10215f3e.jpg'),
(39356, 2698, 'Pokemon S16 E27', 'http://sinalprivado.info:80/series/1533784/1533784/193566.mp4', 'http://timg.bdta.pro/images/bac95fc144cd6433a09d3ce208ca8624.jpg'),
(39357, 2698, 'Pokemon S16 E28', 'http://sinalprivado.info:80/series/1533784/1533784/193567.mp4', 'http://timg.bdta.pro/images/dbe49153467d8429eae2ab035bd72208.jpg'),
(39358, 2698, 'Pokemon S16 E29', 'http://sinalprivado.info:80/series/1533784/1533784/193568.mp4', 'http://timg.bdta.pro/images/18f56153b60244cc556704a1e6ce6ca6.jpg'),
(39359, 2698, 'Pokemon S16 E30', 'http://sinalprivado.info:80/series/1533784/1533784/193569.mp4', 'http://timg.bdta.pro/images/63ccea8aa41eb2ca041bedeef50dda50.jpg'),
(39360, 2698, 'Pokemon S16 E31', 'http://sinalprivado.info:80/series/1533784/1533784/193570.mp4', 'http://timg.bdta.pro/images/53ec74330ccf3fbfdaec6b78f4e7b38a.jpg'),
(39361, 2698, 'Pokemon S16 E32', 'http://sinalprivado.info:80/series/1533784/1533784/193571.mp4', 'http://timg.bdta.pro/images/0e3867f3a3cee3f43314b431f58e478b.jpg'),
(39362, 2698, 'Pokemon S16 E33', 'http://sinalprivado.info:80/series/1533784/1533784/193572.mp4', 'http://timg.bdta.pro/images/aa397f1de99e840790d66c412c314229.jpg'),
(39363, 2698, 'Pokemon S16 E34', 'http://sinalprivado.info:80/series/1533784/1533784/193573.mp4', 'http://timg.bdta.pro/images/cbbcd999ccd5989616dc5fdbc625b4d6.jpg'),
(39364, 2698, 'Pokemon S16 E35', 'http://sinalprivado.info:80/series/1533784/1533784/193574.mp4', 'http://timg.bdta.pro/images/f3bb4ed855a3b7ed5e80d039b36fccb6.jpg'),
(39365, 2698, 'Pokemon S16 E36', 'http://sinalprivado.info:80/series/1533784/1533784/193575.mp4', 'http://timg.bdta.pro/images/b2de350c31d59dace02a9ea566534425.jpg'),
(39366, 2698, 'Pokemon S16 E37', 'http://sinalprivado.info:80/series/1533784/1533784/193576.mp4', 'http://timg.bdta.pro/images/2fc9e392f920a4557391ccdd4fda0cff.jpg'),
(39367, 2698, 'Pokemon S16 E38', 'http://sinalprivado.info:80/series/1533784/1533784/193577.mp4', 'http://timg.bdta.pro/images/63f0e26dacfa500b877a117e56f417a1.jpg'),
(39368, 2698, 'Pokemon S16 E39', 'http://sinalprivado.info:80/series/1533784/1533784/193578.mp4', 'http://timg.bdta.pro/images/cd725862055962023c2e9a69b094a6e3.jpg'),
(39369, 2698, 'Pokemon S16 E40', 'http://sinalprivado.info:80/series/1533784/1533784/193579.mp4', 'http://timg.bdta.pro/images/1d2d351922fd5599d5b74d7abab6ce5b.jpg'),
(39370, 2698, 'Pokemon S16 E41', 'http://sinalprivado.info:80/series/1533784/1533784/193580.mp4', 'http://timg.bdta.pro/images/bd3bc96aba8b19ef484a272028ecd764.jpg'),
(39371, 2698, 'Pokemon S16 E42', 'http://sinalprivado.info:80/series/1533784/1533784/193581.mp4', 'http://timg.bdta.pro/images/19cdcfe9dadb571a3ccba7af1f95f7bc.jpg'),
(39372, 2698, 'Pokemon S16 E43', 'http://sinalprivado.info:80/series/1533784/1533784/193582.mp4', 'http://timg.bdta.pro/images/b150ee45e73a14944f1ae0daf7eb809f.jpg'),
(39373, 2698, 'Pokemon S16 E44', 'http://sinalprivado.info:80/series/1533784/1533784/193583.mp4', 'http://timg.bdta.pro/images/e59c91474a785628ee8d9f816a2c0686.jpg'),
(39374, 2698, 'Pokemon S16 E45', 'http://sinalprivado.info:80/series/1533784/1533784/193584.mp4', 'http://timg.bdta.pro/images/cbc53f5cc584b52122d8f7c15c21047b.jpg'),
(39375, 2698, 'Pokemon S16 E46', 'http://sinalprivado.info:80/series/1533784/1533784/193585.mp4', 'http://gstaticontent.com/images/cce5482f122e672ea4457e978496130d.jpg'),
(39376, 2698, 'Pokemon S16 E47', 'http://sinalprivado.info:80/series/1533784/1533784/193586.mp4', 'http://gstaticontent.com/images/cce5482f122e672ea4457e978496130d.jpg'),
(39377, 2699, 'Pokemon S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193587.mp4', 'http://timg.bdta.pro/images/ac88a09d14cc3bfd97f5f207b77bc66d.jpg'),
(39378, 2699, 'Pokemon S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193588.mp4', 'http://timg.bdta.pro/images/0722fcc686ffdddde65d24df92917c9f.jpg'),
(39379, 2699, 'Pokemon S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193589.mp4', 'http://timg.bdta.pro/images/6d88480e1a0393f684f6bcb0e0e7d3a3.jpg'),
(39380, 2699, 'Pokemon S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193590.mp4', 'http://timg.bdta.pro/images/be54a08e226c429b098b7b0711b557fe.jpg'),
(39381, 2699, 'Pokemon S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193591.mp4', 'http://timg.bdta.pro/images/70beb503eb5e19413a310681e9c5f226.jpg'),
(39382, 2699, 'Pokemon S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193592.mp4', 'http://timg.bdta.pro/images/ed63958335f1f616513178dfb23c3044.jpg'),
(39383, 2699, 'Pokemon S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193593.mp4', 'http://timg.bdta.pro/images/d5847a50be12fe18abf37fef607a6ebc.jpg'),
(39384, 2699, 'Pokemon S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193594.mp4', 'http://timg.bdta.pro/images/00db269b9a0613b699d06ca8f0c42a1f.jpg'),
(39385, 2699, 'Pokemon S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193595.mp4', 'http://timg.bdta.pro/images/c6662b4ed4e81a5e697d3d2063df4c23.jpg'),
(39386, 2699, 'Pokemon S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193596.mp4', 'http://timg.bdta.pro/images/3b8bf845152dd05a825995e3e5dbc10d.jpg'),
(39387, 2699, 'Pokemon S17 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193597.mp4', 'http://timg.bdta.pro/images/aeb77e231799cae9818bcb86ff48de3f.jpg'),
(39388, 2699, 'Pokemon S17 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193598.mp4', 'http://timg.bdta.pro/images/4783410e0fa9b874dc320654ebc65b31.jpg'),
(39389, 2699, 'Pokemon S17 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193599.mp4', 'http://timg.bdta.pro/images/d9f5d970086303d4ab96e6ace40d2663.jpg'),
(39390, 2699, 'Pokemon S17 E14', 'http://sinalprivado.info:80/series/1533784/1533784/193600.mp4', 'http://timg.bdta.pro/images/ddafcb94474f11bbac07f41d4db40746.jpg'),
(39391, 2699, 'Pokemon S17 E15', 'http://sinalprivado.info:80/series/1533784/1533784/193601.mp4', 'http://timg.bdta.pro/images/32f47006f1fa328966d70cfb0c1f6b0e.jpg'),
(39392, 2699, 'Pokemon S17 E16', 'http://sinalprivado.info:80/series/1533784/1533784/193602.mp4', 'http://timg.bdta.pro/images/8e3e7ae08acf25cf47829932af2f2423.jpg'),
(39393, 2699, 'Pokemon S17 E17', 'http://sinalprivado.info:80/series/1533784/1533784/193603.mp4', 'http://timg.bdta.pro/images/fd91b6597d0e0d4711af37c47181184c.jpg'),
(39394, 2699, 'Pokemon S17 E18', 'http://sinalprivado.info:80/series/1533784/1533784/193604.mp4', 'http://timg.bdta.pro/images/e0e9276b8a5a5b386f351398064d84fb.jpg'),
(39395, 2699, 'Pokemon S17 E19', 'http://sinalprivado.info:80/series/1533784/1533784/193605.mp4', 'http://timg.bdta.pro/images/ef6c26fb44cc7d2226da520925dadf24.jpg'),
(39396, 2699, 'Pokemon S17 E20', 'http://sinalprivado.info:80/series/1533784/1533784/193606.mp4', 'http://timg.bdta.pro/images/c2e015d77799e47d4267539f28f27210.jpg'),
(39397, 2699, 'Pokemon S17 E21', 'http://sinalprivado.info:80/series/1533784/1533784/193607.mp4', 'http://timg.bdta.pro/images/3986466d0e5c6e04efacb73d1b0386b6.jpg'),
(39398, 2699, 'Pokemon S17 E22', 'http://sinalprivado.info:80/series/1533784/1533784/193608.mp4', 'http://timg.bdta.pro/images/6bcad99952a302e140263534095c8794.jpg'),
(39399, 2699, 'Pokemon S17 E23', 'http://sinalprivado.info:80/series/1533784/1533784/193609.mp4', 'http://timg.bdta.pro/images/6eaa196241743c7ec2048036189293cb.jpg'),
(39400, 2699, 'Pokemon S17 E24', 'http://sinalprivado.info:80/series/1533784/1533784/193610.mp4', 'http://timg.bdta.pro/images/fe5da64111abb22d04896145d1abc7da.jpg'),
(39401, 2699, 'Pokemon S17 E25', 'http://sinalprivado.info:80/series/1533784/1533784/193611.mp4', 'http://timg.bdta.pro/images/840e451f24c0acd0384c533af2f3d3ac.jpg'),
(39402, 2699, 'Pokemon S17 E26', 'http://sinalprivado.info:80/series/1533784/1533784/193612.mp4', 'http://timg.bdta.pro/images/58c360f7467cb2d3940f23779783df38.jpg'),
(39403, 2699, 'Pokemon S17 E27', 'http://sinalprivado.info:80/series/1533784/1533784/193613.mp4', 'http://timg.bdta.pro/images/9e8d3a39633cb0f3c50ab81d14a522b3.jpg'),
(39404, 2699, 'Pokemon S17 E28', 'http://sinalprivado.info:80/series/1533784/1533784/193614.mp4', 'http://timg.bdta.pro/images/bb40f9ff7f9c0fcebf77c4ce0a410864.jpg'),
(39405, 2699, 'Pokemon S17 E29', 'http://sinalprivado.info:80/series/1533784/1533784/193615.mp4', 'http://timg.bdta.pro/images/04f718121c93280d4bc76734d5af23a2.jpg'),
(39406, 2699, 'Pokemon S17 E30', 'http://sinalprivado.info:80/series/1533784/1533784/193616.mp4', 'http://timg.bdta.pro/images/9817fd3c1ebba7ced5867fb3a90b6137.jpg'),
(39407, 2699, 'Pokemon S17 E31', 'http://sinalprivado.info:80/series/1533784/1533784/193617.mp4', 'http://timg.bdta.pro/images/daa9ee1b537bbabce497ca81124345c1.jpg'),
(39408, 2699, 'Pokemon S17 E32', 'http://sinalprivado.info:80/series/1533784/1533784/193618.mp4', 'http://timg.bdta.pro/images/b62b0673bf71f776b1c76655836257db.jpg'),
(39409, 2699, 'Pokemon S17 E33', 'http://sinalprivado.info:80/series/1533784/1533784/193619.mp4', 'http://timg.bdta.pro/images/5136f7e7128dfd59e615dc7fba010a12.jpg'),
(39410, 2699, 'Pokemon S17 E34', 'http://sinalprivado.info:80/series/1533784/1533784/193620.mp4', 'http://timg.bdta.pro/images/0008685932ad74edb9d123e79afbe885.jpg'),
(39411, 2699, 'Pokemon S17 E35', 'http://sinalprivado.info:80/series/1533784/1533784/193621.mp4', 'http://timg.bdta.pro/images/648c1447f1cf0133b0b9173d02571343.jpg'),
(39412, 2699, 'Pokemon S17 E36', 'http://sinalprivado.info:80/series/1533784/1533784/193622.mp4', 'http://timg.bdta.pro/images/b3e7970dbce662bf7c6c4ab31b0db062.jpg'),
(39413, 2699, 'Pokemon S17 E37', 'http://sinalprivado.info:80/series/1533784/1533784/193623.mp4', 'http://timg.bdta.pro/images/4105b8a490985a422c70fddc3c247740.jpg'),
(39414, 2699, 'Pokemon S17 E38', 'http://sinalprivado.info:80/series/1533784/1533784/193624.mp4', 'http://timg.bdta.pro/images/48ce25ffb6399bcbe1e1eb4b7fb8f8b4.jpg'),
(39415, 2699, 'Pokemon S17 E39', 'http://sinalprivado.info:80/series/1533784/1533784/193625.mp4', 'http://timg.bdta.pro/images/0e8415504f48cff61eca3764cf713734.jpg'),
(39416, 2699, 'Pokemon S17 E40', 'http://sinalprivado.info:80/series/1533784/1533784/193626.mp4', 'http://timg.bdta.pro/images/abd452a9506fd4ce7cafe6de42f4758f.jpg'),
(39417, 2699, 'Pokemon S17 E41', 'http://sinalprivado.info:80/series/1533784/1533784/193627.mp4', 'http://timg.bdta.pro/images/9ab676996b0a92c5464ba723ead53bc4.jpg'),
(39418, 2699, 'Pokemon S17 E42', 'http://sinalprivado.info:80/series/1533784/1533784/193628.mp4', 'http://timg.bdta.pro/images/a8562a65fe06c3d245b38edba7c3b259.jpg'),
(39419, 2699, 'Pokemon S17 E43', 'http://sinalprivado.info:80/series/1533784/1533784/193629.mp4', 'http://timg.bdta.pro/images/6ebdcc18d0fc736b503c9232f6b228ef.jpg'),
(39420, 2699, 'Pokemon S17 E44', 'http://sinalprivado.info:80/series/1533784/1533784/193630.mp4', 'http://timg.bdta.pro/images/38a0800ff96498c5b91ea5268a15d8cb.jpg'),
(39421, 2699, 'Pokemon S17 E45', 'http://sinalprivado.info:80/series/1533784/1533784/193631.mp4', 'http://timg.bdta.pro/images/ab5e77389a252d547717aedafa53e450.jpg'),
(39422, 2699, 'Pokemon S17 E46', 'http://sinalprivado.info:80/series/1533784/1533784/193632.mp4', 'http://timg.bdta.pro/images/6adc80b2f62eb0a48154dcc446388fcf.jpg'),
(39423, 2699, 'Pokemon S17 E47', 'http://sinalprivado.info:80/series/1533784/1533784/193633.mp4', 'http://timg.bdta.pro/images/45785b50029e1198a0bc15a54c44df31.jpg'),
(39424, 2699, 'Pokemon S17 E48', 'http://sinalprivado.info:80/series/1533784/1533784/193634.mp4', 'http://timg.bdta.pro/images/e14165dc34c6e079720a97290e660216.jpg'),
(39425, 2699, 'Pokemon S17 E49', 'http://sinalprivado.info:80/series/1533784/1533784/193635.mp4', 'http://gstaticontent.com/images/cce5482f122e672ea4457e978496130d.jpg'),
(39426, 2700, 'Pokemon S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193636.mp4', 'http://timg.bdta.pro/images/2bcce62e05de1381b34cfb799151a7c3.jpg'),
(39427, 2700, 'Pokemon S18 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193637.mp4', 'http://timg.bdta.pro/images/c248b7873137cb779cbdf088c6226ee2.jpg'),
(39428, 2700, 'Pokemon S18 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193638.mp4', 'http://timg.bdta.pro/images/9f5ce21a0a48589b4dad4d7c972fcf75.jpg'),
(39429, 2700, 'Pokemon S18 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193639.mp4', 'http://timg.bdta.pro/images/ec24379f8e54fa9a6f3e516157e0a235.jpg'),
(39430, 2700, 'Pokemon S18 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193640.mp4', 'http://timg.bdta.pro/images/40b92e5069c386496bff1d64c05839ca.jpg'),
(39431, 2700, 'Pokemon S18 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193641.mp4', 'http://timg.bdta.pro/images/6a394fcbe6f5d48f5052488a2c15a36a.jpg'),
(39432, 2700, 'Pokemon S18 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193642.mp4', 'http://timg.bdta.pro/images/2bdd5f150fc0cfe62d23302d9503f809.jpg'),
(39433, 2700, 'Pokemon S18 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193643.mp4', 'http://timg.bdta.pro/images/c30a1a41c1b00f6cc1efa56e3b109eb4.jpg'),
(39434, 2700, 'Pokemon S18 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193644.mp4', 'http://timg.bdta.pro/images/8e042b8b5fc59c7714ad97b7af05094d.jpg'),
(39435, 2700, 'Pokemon S18 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193645.mp4', 'http://timg.bdta.pro/images/919762af67d118218c0976a59513d017.jpg'),
(39436, 2700, 'Pokemon S18 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193646.mp4', 'http://timg.bdta.pro/images/dcda86b712d834f344b6f372c89a5b22.jpg'),
(39437, 2700, 'Pokemon S18 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193647.mp4', 'http://timg.bdta.pro/images/60f23b1165fe8da538048d4d529529cc.jpg'),
(39438, 2700, 'Pokemon S18 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193648.mp4', 'http://timg.bdta.pro/images/15fe764384fdbd886f4f5ff5ca4de2c6.jpg'),
(39439, 2700, 'Pokemon S18 E14', 'http://sinalprivado.info:80/series/1533784/1533784/193649.mp4', 'http://timg.bdta.pro/images/b36262e0bd6097950448147b6c072d08.jpg'),
(39440, 2700, 'Pokemon S18 E15', 'http://sinalprivado.info:80/series/1533784/1533784/193650.mp4', 'http://timg.bdta.pro/images/b7b1ed39413eaa99ded473d8cfd8ffc3.jpg'),
(39441, 2700, 'Pokemon S18 E16', 'http://sinalprivado.info:80/series/1533784/1533784/193651.mp4', 'http://timg.bdta.pro/images/c3be62133c9e91c2a748c53d3cbda372.jpg'),
(39442, 2700, 'Pokemon S18 E17', 'http://sinalprivado.info:80/series/1533784/1533784/193652.mp4', 'http://timg.bdta.pro/images/f2814c9801c81f9984d5297f317cdcee.jpg'),
(39443, 2700, 'Pokemon S18 E18', 'http://sinalprivado.info:80/series/1533784/1533784/193653.mp4', 'http://timg.bdta.pro/images/a6270593985d7462506376b4b0b00d7f.jpg'),
(39444, 2700, 'Pokemon S18 E19', 'http://sinalprivado.info:80/series/1533784/1533784/193654.mp4', 'http://timg.bdta.pro/images/6823630a58d67548e25cb826c0c2e479.jpg'),
(39445, 2700, 'Pokemon S18 E20', 'http://sinalprivado.info:80/series/1533784/1533784/193655.mp4', 'http://timg.bdta.pro/images/1e75520afc4f7eee67042efb582e0a58.jpg'),
(39446, 2700, 'Pokemon S18 E21', 'http://sinalprivado.info:80/series/1533784/1533784/193656.mp4', 'http://timg.bdta.pro/images/73993486fee10007741a85704c627771.jpg'),
(39447, 2700, 'Pokemon S18 E22', 'http://sinalprivado.info:80/series/1533784/1533784/193657.mp4', 'http://timg.bdta.pro/images/12faef4e8ab3a2d99e55d1fc7f31fe51.jpg'),
(39448, 2700, 'Pokemon S18 E23', 'http://sinalprivado.info:80/series/1533784/1533784/193658.mp4', 'http://timg.bdta.pro/images/d27fe7d74d8985062f541d2e8b9d6d9d.jpg'),
(39449, 2700, 'Pokemon S18 E24', 'http://sinalprivado.info:80/series/1533784/1533784/193659.mp4', 'http://timg.bdta.pro/images/0bbb0c707bc9414eb57b100ad9dc0fd2.jpg'),
(39450, 2700, 'Pokemon S18 E25', 'http://sinalprivado.info:80/series/1533784/1533784/193660.mp4', 'http://timg.bdta.pro/images/dc50ffd4576d20dee19668b63d9fde8f.jpg'),
(39451, 2700, 'Pokemon S18 E26', 'http://sinalprivado.info:80/series/1533784/1533784/193661.mp4', 'http://timg.bdta.pro/images/f9328d4a02bc7a4729f6c86aa445175c.jpg'),
(39452, 2700, 'Pokemon S18 E27', 'http://sinalprivado.info:80/series/1533784/1533784/193662.mp4', 'http://timg.bdta.pro/images/37e6b178f34d3f93bdf44ede8a81e0b0.jpg'),
(39453, 2700, 'Pokemon S18 E28', 'http://sinalprivado.info:80/series/1533784/1533784/193663.mp4', 'http://timg.bdta.pro/images/461b3cd51e3a476ce392b3e6e3acd88a.jpg'),
(39454, 2700, 'Pokemon S18 E29', 'http://sinalprivado.info:80/series/1533784/1533784/193664.mp4', 'http://timg.bdta.pro/images/0454d4c65b9d26b0b9fb08a38c88fd22.jpg'),
(39455, 2700, 'Pokemon S18 E30', 'http://sinalprivado.info:80/series/1533784/1533784/193665.mp4', 'http://timg.bdta.pro/images/e01edf9a632ab2924c74e093fa9ef027.jpg'),
(39456, 2700, 'Pokemon S18 E31', 'http://sinalprivado.info:80/series/1533784/1533784/193666.mp4', 'http://timg.bdta.pro/images/faef53df78dce594c8172834114541d2.jpg'),
(39457, 2700, 'Pokemon S18 E32', 'http://sinalprivado.info:80/series/1533784/1533784/193667.mp4', 'http://timg.bdta.pro/images/b9fb9185ffe56473dbbcda860e0631a9.jpg'),
(39458, 2700, 'Pokemon S18 E33', 'http://sinalprivado.info:80/series/1533784/1533784/193668.mp4', 'http://timg.bdta.pro/images/01fd5f45d3198eaa5b74e617b60f0808.jpg'),
(39459, 2700, 'Pokemon S18 E34', 'http://sinalprivado.info:80/series/1533784/1533784/193669.mp4', 'http://timg.bdta.pro/images/ab9181fce738388c51c4679523eed3f9.jpg'),
(39460, 2700, 'Pokemon S18 E35', 'http://sinalprivado.info:80/series/1533784/1533784/193670.mp4', 'http://timg.bdta.pro/images/4bd1d9704263a2c24e9b98f59d49d037.jpg'),
(39461, 2700, 'Pokemon S18 E36', 'http://sinalprivado.info:80/series/1533784/1533784/193671.mp4', 'http://timg.bdta.pro/images/c89029a4c3b4f29e613b3e23c053db0e.jpg'),
(39462, 2700, 'Pokemon S18 E37', 'http://sinalprivado.info:80/series/1533784/1533784/193672.mp4', 'http://timg.bdta.pro/images/145e51e0aff5c3ebe657407ad4f52170.jpg'),
(39463, 2700, 'Pokemon S18 E38', 'http://sinalprivado.info:80/series/1533784/1533784/193673.mp4', 'http://timg.bdta.pro/images/bac530c2f723ecc081cff4a308fa9679.jpg'),
(39464, 2700, 'Pokemon S18 E39', 'http://sinalprivado.info:80/series/1533784/1533784/193674.mp4', 'http://timg.bdta.pro/images/e669ae61c15ea37124ea7dd3ed0fd553.jpg'),
(39465, 2700, 'Pokemon S18 E40', 'http://sinalprivado.info:80/series/1533784/1533784/193675.mp4', 'http://timg.bdta.pro/images/0a370d2a503ba8fb1dd4ba516f5c356e.jpg'),
(39466, 2700, 'Pokemon S18 E41', 'http://sinalprivado.info:80/series/1533784/1533784/193676.mp4', 'http://timg.bdta.pro/images/cffafb1465716aff73bb9c2828cadf54.jpg'),
(39467, 2700, 'Pokemon S18 E42', 'http://sinalprivado.info:80/series/1533784/1533784/193677.mp4', 'http://timg.bdta.pro/images/85ca3b76559803bf51f69764692bbe1f.jpg'),
(39468, 2700, 'Pokemon S18 E43', 'http://sinalprivado.info:80/series/1533784/1533784/193678.mp4', 'http://timg.bdta.pro/images/972c8cfcd8976b67d036a76d5937ef0c.jpg'),
(39469, 2700, 'Pokemon S18 E44', 'http://sinalprivado.info:80/series/1533784/1533784/193679.mp4', 'http://timg.bdta.pro/images/6eb70623b70209fbe93614d0dd53b214.jpg'),
(39470, 2701, 'Pokemon S19 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193680.mp4', 'http://timg.bdta.pro/images/2ae1eae1cef433ef7840b85c441f1e49.jpg'),
(39471, 2701, 'Pokemon S19 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193681.mp4', 'http://timg.bdta.pro/images/d01b9f97fe5a4e1fd01425661829882a.jpg'),
(39472, 2701, 'Pokemon S19 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193682.mp4', 'http://timg.bdta.pro/images/175db9df10059e6754087dd35cb33ef1.jpg'),
(39473, 2701, 'Pokemon S19 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193683.mp4', 'http://timg.bdta.pro/images/af4d1c6d25d0662ee2d5904d15c1efa6.jpg'),
(39474, 2701, 'Pokemon S19 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193684.mp4', 'http://timg.bdta.pro/images/12d0467bd7127eebab0a2dd5b38f0370.jpg'),
(39475, 2701, 'Pokemon S19 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193685.mp4', 'http://timg.bdta.pro/images/79bddba8528bc8f662de4cdc501c8abc.jpg'),
(39476, 2701, 'Pokemon S19 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193686.mp4', 'http://timg.bdta.pro/images/3e77274122253e08d6dfc7d1a9b6e390.jpg'),
(39477, 2701, 'Pokemon S19 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193687.mp4', 'http://timg.bdta.pro/images/a68551b06db41bab433111a6171dcf6a.jpg'),
(39478, 2701, 'Pokemon S19 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193688.mp4', 'http://timg.bdta.pro/images/e56061e24347eb23d0554bd4ee58fc85.jpg'),
(39479, 2701, 'Pokemon S19 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193689.mp4', 'http://timg.bdta.pro/images/262cbfc7f8fbebf4d030e1ecadfec3d8.jpg'),
(39480, 2701, 'Pokemon S19 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193690.mp4', 'http://timg.bdta.pro/images/65b81efdb12c97a2af7915c4b76c687a.jpg'),
(39481, 2701, 'Pokemon S19 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193691.mp4', 'http://timg.bdta.pro/images/b0cd9286b6de0a4e287dde43b25b67ea.jpg'),
(39482, 2701, 'Pokemon S19 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193692.mp4', 'http://timg.bdta.pro/images/1537867353b813ddf2739bbee53d5a23.jpg'),
(39483, 2701, 'Pokemon S19 E14', 'http://sinalprivado.info:80/series/1533784/1533784/193693.mp4', 'http://timg.bdta.pro/images/8b36fd0c03075180293c8ff8f346b687.jpg'),
(39484, 2701, 'Pokemon S19 E15', 'http://sinalprivado.info:80/series/1533784/1533784/193694.mp4', 'http://timg.bdta.pro/images/4e09c2aede865ce9b39df656dfdff83a.jpg'),
(39485, 2701, 'Pokemon S19 E16', 'http://sinalprivado.info:80/series/1533784/1533784/193695.mp4', 'http://timg.bdta.pro/images/97d4daff5ede29bc5c90c62d6457cb4a.jpg'),
(39486, 2701, 'Pokemon S19 E17', 'http://sinalprivado.info:80/series/1533784/1533784/193696.mp4', 'http://timg.bdta.pro/images/43d4359e62dd9f76c7cd49e44f19dc82.jpg'),
(39487, 2701, 'Pokemon S19 E18', 'http://sinalprivado.info:80/series/1533784/1533784/193697.mp4', 'http://timg.bdta.pro/images/d624f48a14e894e7fb0fefb4e975c38b.jpg'),
(39488, 2701, 'Pokemon S19 E19', 'http://sinalprivado.info:80/series/1533784/1533784/193698.mp4', 'http://timg.bdta.pro/images/dc085128af4c15cef7656b0463ba113d.jpg'),
(39489, 2701, 'Pokemon S19 E20', 'http://sinalprivado.info:80/series/1533784/1533784/193699.mp4', 'http://timg.bdta.pro/images/40caa4eb0ae0b2c7a15b3b641adaf9ac.jpg'),
(39490, 2701, 'Pokemon S19 E21', 'http://sinalprivado.info:80/series/1533784/1533784/193700.mp4', 'http://timg.bdta.pro/images/5798aa0719d1bcc55fb19239a7b19945.jpg'),
(39491, 2701, 'Pokemon S19 E22', 'http://sinalprivado.info:80/series/1533784/1533784/193701.mp4', 'http://timg.bdta.pro/images/4aea27caa5ad4e64d4acc58de984e028.jpg'),
(39492, 2701, 'Pokemon S19 E23', 'http://sinalprivado.info:80/series/1533784/1533784/193702.mp4', 'http://timg.bdta.pro/images/f944bd351fa40195eb1007907d9e4522.jpg'),
(39493, 2701, 'Pokemon S19 E24', 'http://sinalprivado.info:80/series/1533784/1533784/193703.mp4', 'http://timg.bdta.pro/images/25080e9aaf5a2485e12997f343b78d1d.jpg'),
(39494, 2701, 'Pokemon S19 E25', 'http://sinalprivado.info:80/series/1533784/1533784/193704.mp4', 'http://timg.bdta.pro/images/fca47867305c1ae4aea5e420190e5df7.jpg'),
(39495, 2701, 'Pokemon S19 E26', 'http://sinalprivado.info:80/series/1533784/1533784/193705.mp4', 'http://timg.bdta.pro/images/c70b7d67ae1eb8d5079cf8b5d6aa2aea.jpg'),
(39496, 2701, 'Pokemon S19 E27', 'http://sinalprivado.info:80/series/1533784/1533784/193706.mp4', 'http://timg.bdta.pro/images/a897627c01b1efcf577ccbb25f23f5ca.jpg'),
(39497, 2701, 'Pokemon S19 E28', 'http://sinalprivado.info:80/series/1533784/1533784/193707.mp4', 'http://timg.bdta.pro/images/a0f24a654d0be1b21e152c9988fd9b17.jpg'),
(39498, 2701, 'Pokemon S19 E29', 'http://sinalprivado.info:80/series/1533784/1533784/193708.mp4', 'http://timg.bdta.pro/images/4bf653f729a132eb486f3bdbcacf83f5.jpg'),
(39499, 2701, 'Pokemon S19 E30', 'http://sinalprivado.info:80/series/1533784/1533784/193709.mp4', 'http://timg.bdta.pro/images/8d7fc01bd0ad958adb98b2059861fc9c.jpg'),
(39500, 2701, 'Pokemon S19 E31', 'http://sinalprivado.info:80/series/1533784/1533784/193710.mp4', 'http://timg.bdta.pro/images/b9fbdd35a84104fc4f44fcbcebea4d60.jpg'),
(39501, 2701, 'Pokemon S19 E32', 'http://sinalprivado.info:80/series/1533784/1533784/193711.mp4', 'http://timg.bdta.pro/images/a44595550e723866a56d4f81ea38af35.jpg'),
(39502, 2701, 'Pokemon S19 E33', 'http://sinalprivado.info:80/series/1533784/1533784/193712.mp4', 'http://timg.bdta.pro/images/700ff538b045a78547e043293339b981.jpg'),
(39503, 2701, 'Pokemon S19 E34', 'http://sinalprivado.info:80/series/1533784/1533784/193713.mp4', 'http://timg.bdta.pro/images/cc549477b3b3ad969c345fb67d93f43c.jpg'),
(39504, 2701, 'Pokemon S19 E35', 'http://sinalprivado.info:80/series/1533784/1533784/193714.mp4', 'http://timg.bdta.pro/images/62c489c5bb59fc3e852035f0aa9b6610.jpg'),
(39505, 2701, 'Pokemon S19 E36', 'http://sinalprivado.info:80/series/1533784/1533784/193715.mp4', 'http://timg.bdta.pro/images/fe25f079ca1c604d4cae641c2fdc500d.jpg'),
(39506, 2701, 'Pokemon S19 E37', 'http://sinalprivado.info:80/series/1533784/1533784/193716.mp4', 'http://timg.bdta.pro/images/ac8cb4d531f942377d0cfb0b452ed90e.jpg'),
(39507, 2701, 'Pokemon S19 E38', 'http://sinalprivado.info:80/series/1533784/1533784/193717.mp4', 'http://timg.bdta.pro/images/25557df585b1c96b95b65127bb158c3d.jpg'),
(39508, 2701, 'Pokemon S19 E39', 'http://sinalprivado.info:80/series/1533784/1533784/193718.mp4', 'http://timg.bdta.pro/images/08918a30812a124c636913651f38759a.jpg'),
(39509, 2701, 'Pokemon S19 E40', 'http://sinalprivado.info:80/series/1533784/1533784/193719.mp4', 'http://timg.bdta.pro/images/dfbdc8cad2d75573991ab40864321a9b.jpg'),
(39510, 2701, 'Pokemon S19 E41', 'http://sinalprivado.info:80/series/1533784/1533784/193720.mp4', 'http://timg.bdta.pro/images/5f2ef95f3bdc7f2f1785ff3ead0b16b8.jpg'),
(39511, 2701, 'Pokemon S19 E42', 'http://sinalprivado.info:80/series/1533784/1533784/193721.mp4', 'http://timg.bdta.pro/images/0cf0896eb43a935ade18e814fa95607c.jpg'),
(39512, 2701, 'Pokemon S19 E43', 'http://sinalprivado.info:80/series/1533784/1533784/193722.mp4', 'http://timg.bdta.pro/images/64ce7eb0628acd4647670aaedf8dae7a.jpg'),
(39513, 2701, 'Pokemon S19 E44', 'http://sinalprivado.info:80/series/1533784/1533784/193723.mp4', 'http://timg.bdta.pro/images/00faa2e75cdecac6fbf32b76144ed440.jpg'),
(39514, 2701, 'Pokemon S19 E45', 'http://sinalprivado.info:80/series/1533784/1533784/193724.mp4', 'http://timg.bdta.pro/images/f5718615b71bfc832ab6c1e52c96a181.jpg'),
(39515, 2701, 'Pokemon S19 E46', 'http://sinalprivado.info:80/series/1533784/1533784/193725.mp4', 'http://timg.bdta.pro/images/31981c01a56ec0b1cfd6abf6303f9ffd.jpg'),
(39516, 2701, 'Pokemon S19 E47', 'http://sinalprivado.info:80/series/1533784/1533784/193726.mp4', 'http://timg.bdta.pro/images/368cdb57ee3544c51ff7b26a640bf266.jpg'),
(39517, 2701, 'Pokemon S19 E48', 'http://sinalprivado.info:80/series/1533784/1533784/193727.mp4', 'http://timg.bdta.pro/images/bc70693b83360d1c37615ea96bdcc3f5.jpg'),
(39518, 2702, 'Pokemon S20 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193728.mp4', 'http://timg.bdta.pro/images/ef282eb982f38dd4586aa6cc02f4e786.jpg'),
(39519, 2702, 'Pokemon S20 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193729.mp4', 'http://timg.bdta.pro/images/a6fe80749f9f8b2d2b40f60b535c4f69.jpg'),
(39520, 2702, 'Pokemon S20 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193730.mp4', 'http://timg.bdta.pro/images/78c811275d8a1aa40f9da54993c1f36a.jpg'),
(39521, 2702, 'Pokemon S20 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193731.mp4', 'http://timg.bdta.pro/images/ce2afd10117d24296ed96d91038f6c44.jpg'),
(39522, 2702, 'Pokemon S20 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193732.mp4', 'http://timg.bdta.pro/images/d8868480750ae640ec06418f22f2cd4c.jpg'),
(39523, 2702, 'Pokemon S20 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193733.mp4', 'http://timg.bdta.pro/images/b196f9bc5db64f3534b1b18a9c47dcf7.jpg'),
(39524, 2702, 'Pokemon S20 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193734.mp4', 'http://timg.bdta.pro/images/87cfe0e35e925ff12e8471627d4b83b3.jpg'),
(39525, 2702, 'Pokemon S20 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193735.mp4', 'http://timg.bdta.pro/images/f31802a2b650ecf8d37713ad59c064ac.jpg'),
(39526, 2702, 'Pokemon S20 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193736.mp4', 'http://timg.bdta.pro/images/3562a1cffcbf189e5a6c2b59ff310653.jpg'),
(39527, 2702, 'Pokemon S20 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193737.mp4', 'http://timg.bdta.pro/images/3f5273c3933644a0d1a2a44ba908e6ff.jpg'),
(39528, 2702, 'Pokemon S20 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193738.mp4', 'http://timg.bdta.pro/images/55960d73033cb4475b0cc77d25130456.jpg'),
(39529, 2702, 'Pokemon S20 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193739.mp4', 'http://timg.bdta.pro/images/0bc038c514189e8882a6d52ac0f03b84.jpg'),
(39530, 2702, 'Pokemon S20 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193740.mp4', 'http://timg.bdta.pro/images/0274e97818d0a274387fa822a4e80391.jpg'),
(39531, 2702, 'Pokemon S20 E14', 'http://sinalprivado.info:80/series/1533784/1533784/193741.mp4', 'http://timg.bdta.pro/images/40271c5467063a3f86878ad46a14d253.jpg'),
(39532, 2702, 'Pokemon S20 E15', 'http://sinalprivado.info:80/series/1533784/1533784/193742.mp4', 'http://timg.bdta.pro/images/f83f8e575583a3158360c0442dfad9e6.jpg'),
(39533, 2702, 'Pokemon S20 E16', 'http://sinalprivado.info:80/series/1533784/1533784/193743.mp4', 'http://timg.bdta.pro/images/fd2d64d1b2e1f0ba07ff157b6c24bfac.jpg'),
(39534, 2702, 'Pokemon S20 E17', 'http://sinalprivado.info:80/series/1533784/1533784/193744.mp4', 'http://timg.bdta.pro/images/177dc8c8bc5516cce46c02aa517c34cc.jpg'),
(39535, 2702, 'Pokemon S20 E18', 'http://sinalprivado.info:80/series/1533784/1533784/193745.mp4', 'http://timg.bdta.pro/images/66578b24360f3040027520489ea3b0ac.jpg'),
(39536, 2702, 'Pokemon S20 E19', 'http://sinalprivado.info:80/series/1533784/1533784/193746.mp4', 'http://timg.bdta.pro/images/9a0683189297245267aa4b5648af1645.jpg'),
(39537, 2702, 'Pokemon S20 E20', 'http://sinalprivado.info:80/series/1533784/1533784/193747.mp4', 'http://timg.bdta.pro/images/761d25ec91a71ce5abf83ffed0ce1a2f.jpg'),
(39538, 2702, 'Pokemon S20 E21', 'http://sinalprivado.info:80/series/1533784/1533784/193748.mp4', 'http://timg.bdta.pro/images/9380d8c6ff2b518a5046c251035f254c.jpg'),
(39539, 2702, 'Pokemon S20 E22', 'http://sinalprivado.info:80/series/1533784/1533784/193749.mp4', 'http://timg.bdta.pro/images/f9630310fd0fd34681ec4e2fe9343ab0.jpg'),
(39540, 2702, 'Pokemon S20 E23', 'http://sinalprivado.info:80/series/1533784/1533784/193750.mp4', 'http://timg.bdta.pro/images/e6fe4d8f41984e1b8bd45cd0850bdbca.jpg'),
(39541, 2702, 'Pokemon S20 E24', 'http://sinalprivado.info:80/series/1533784/1533784/193751.mp4', 'http://timg.bdta.pro/images/8ce48a2d97d481f0a405fbb342dd61a8.jpg'),
(39542, 2702, 'Pokemon S20 E25', 'http://sinalprivado.info:80/series/1533784/1533784/193752.mp4', 'http://timg.bdta.pro/images/33b7f45408cba0f479439a3c86da45f1.jpg'),
(39543, 2702, 'Pokemon S20 E26', 'http://sinalprivado.info:80/series/1533784/1533784/193753.mp4', 'http://timg.bdta.pro/images/1719c7aef4b59e18abe6a90faa6ffa38.jpg'),
(39544, 2702, 'Pokemon S20 E27', 'http://sinalprivado.info:80/series/1533784/1533784/193754.mp4', 'http://timg.bdta.pro/images/885283b7ddd69ab58b9f04429d010f92.jpg'),
(39545, 2702, 'Pokemon S20 E28', 'http://sinalprivado.info:80/series/1533784/1533784/193755.mp4', 'http://timg.bdta.pro/images/86f53bba96f6307111deba5d0d419eb8.jpg'),
(39546, 2702, 'Pokemon S20 E29', 'http://sinalprivado.info:80/series/1533784/1533784/193756.mp4', 'http://timg.bdta.pro/images/c84144adcac4fe3472b66bdc611e4f18.jpg'),
(39547, 2702, 'Pokemon S20 E30', 'http://sinalprivado.info:80/series/1533784/1533784/193757.mp4', 'http://timg.bdta.pro/images/251ade424327bd4a49533a279303af51.jpg'),
(39548, 2702, 'Pokemon S20 E31', 'http://sinalprivado.info:80/series/1533784/1533784/193758.mp4', 'http://timg.bdta.pro/images/33670634df4bda27b8608bdbac65a8b7.jpg'),
(39549, 2702, 'Pokemon S20 E32', 'http://sinalprivado.info:80/series/1533784/1533784/193759.mp4', 'http://timg.bdta.pro/images/14a351e73acb52a80ec1d3c794d33998.jpg'),
(39550, 2702, 'Pokemon S20 E33', 'http://sinalprivado.info:80/series/1533784/1533784/193760.mp4', 'http://timg.bdta.pro/images/6b13f76183501740e1bdac4fb91c052b.jpg'),
(39551, 2702, 'Pokemon S20 E34', 'http://sinalprivado.info:80/series/1533784/1533784/193761.mp4', 'http://timg.bdta.pro/images/0360f8214d1a7d6da0f8377bc86541fa.jpg'),
(39552, 2702, 'Pokemon S20 E35', 'http://sinalprivado.info:80/series/1533784/1533784/193762.mp4', 'http://timg.bdta.pro/images/718594348fa2fcfd87f05fc3abc05699.jpg'),
(39553, 2702, 'Pokemon S20 E36', 'http://sinalprivado.info:80/series/1533784/1533784/193763.mp4', 'http://timg.bdta.pro/images/cda74e4dc4fb4329d280b55f1f861c2d.jpg'),
(39554, 2702, 'Pokemon S20 E37', 'http://sinalprivado.info:80/series/1533784/1533784/193764.mp4', 'http://timg.bdta.pro/images/663467ca015d75482f23d8423c96e305.jpg'),
(39555, 2702, 'Pokemon S20 E38', 'http://sinalprivado.info:80/series/1533784/1533784/193765.mp4', 'http://timg.bdta.pro/images/9141d11b88e529453ab56e838b13001d.jpg'),
(39556, 2702, 'Pokemon S20 E39', 'http://sinalprivado.info:80/series/1533784/1533784/193766.mp4', 'http://timg.bdta.pro/images/3950e92fc30dc6d8670ace9406563345.jpg'),
(39557, 2702, 'Pokemon S20 E40', 'http://sinalprivado.info:80/series/1533784/1533784/193767.mp4', 'http://timg.bdta.pro/images/e1dbf17ee109f857685ad0329eaf609b.jpg'),
(39558, 2702, 'Pokemon S20 E41', 'http://sinalprivado.info:80/series/1533784/1533784/193768.mp4', 'http://timg.bdta.pro/images/811b001a9af28687ed3214a8fe058d03.jpg'),
(39559, 2702, 'Pokemon S20 E42', 'http://sinalprivado.info:80/series/1533784/1533784/193769.mp4', 'http://timg.bdta.pro/images/53a61c2f10369b7c74c923260192492c.jpg'),
(39560, 2702, 'Pokemon S20 E43', 'http://sinalprivado.info:80/series/1533784/1533784/193770.mp4', 'http://timg.bdta.pro/images/81a493b1f3072df24e52e2c074f98b85.jpg'),
(39561, 2703, 'Pokemon S21 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193771.mp4', 'http://timg.bdta.pro/images/831a3012fa886fbed7c75f124225e2f2.jpg'),
(39562, 2703, 'Pokemon S21 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193772.mp4', 'http://timg.bdta.pro/images/a9a070d92dfa05ae183f5880d41de305.jpg'),
(39563, 2703, 'Pokemon S21 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193773.mp4', 'http://timg.bdta.pro/images/c43191cb06391c29f15f75867c6442f3.jpg'),
(39564, 2703, 'Pokemon S21 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193774.mp4', 'http://timg.bdta.pro/images/0a8985168a644317232908cbc09ede2e.jpg'),
(39565, 2703, 'Pokemon S21 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193775.mp4', 'http://timg.bdta.pro/images/77d11e0e40a1c14fba8cc9ba46da3743.jpg'),
(39566, 2703, 'Pokemon S21 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193776.mp4', 'http://timg.bdta.pro/images/fed9667436caa97e71d2ea881e3ff48b.jpg'),
(39567, 2703, 'Pokemon S21 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193777.mp4', 'http://timg.bdta.pro/images/dacbce0b0122da188f26384ac3b48e60.jpg'),
(39568, 2703, 'Pokemon S21 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193778.mp4', 'http://timg.bdta.pro/images/1e8f6f5333f633e75c62a79463afab53.jpg'),
(39569, 2703, 'Pokemon S21 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193779.mp4', 'http://timg.bdta.pro/images/39ea2953ea546e6613136ad0c4178669.jpg'),
(39570, 2703, 'Pokemon S21 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193780.mp4', 'http://timg.bdta.pro/images/26fdad90b6192a19f534791700e3839c.jpg'),
(39571, 2703, 'Pokemon S21 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193781.mp4', 'http://timg.bdta.pro/images/979540afe44159f46a6a3c5391bd3bb8.jpg'),
(39572, 2703, 'Pokemon S21 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193782.mp4', 'http://timg.bdta.pro/images/5eef73382aea2df0b91931872514beaa.jpg'),
(39573, 2703, 'Pokemon S21 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193783.mp4', 'http://timg.bdta.pro/images/736ac8968b0c0c0e97d8a469520d5292.jpg'),
(39574, 2703, 'Pokemon S21 E14', 'http://sinalprivado.info:80/series/1533784/1533784/193784.mp4', 'http://timg.bdta.pro/images/80542d655e3b6d0a61bff9a362cb631e.jpg'),
(39575, 2703, 'Pokemon S21 E15', 'http://sinalprivado.info:80/series/1533784/1533784/193785.mp4', 'http://timg.bdta.pro/images/f619b6ead0db89ca06d8e0e0cab37c67.jpg'),
(39576, 2703, 'Pokemon S21 E16', 'http://sinalprivado.info:80/series/1533784/1533784/193786.mp4', 'http://timg.bdta.pro/images/631a6aeea3ac87b0f5077bc4e5dc0c12.jpg'),
(39577, 2703, 'Pokemon S21 E17', 'http://sinalprivado.info:80/series/1533784/1533784/193787.mp4', 'http://timg.bdta.pro/images/6521574691e4d0a94689ebd7567bd4b6.jpg'),
(39578, 2703, 'Pokemon S21 E18', 'http://sinalprivado.info:80/series/1533784/1533784/193788.mp4', 'http://timg.bdta.pro/images/589a3eef3a0c03a0a68596c8476f808b.jpg'),
(39579, 2703, 'Pokemon S21 E19', 'http://sinalprivado.info:80/series/1533784/1533784/193789.mp4', 'http://timg.bdta.pro/images/a76485a9b993367e52d7159c04f83bf0.jpg'),
(39580, 2703, 'Pokemon S21 E20', 'http://sinalprivado.info:80/series/1533784/1533784/193790.mp4', 'http://timg.bdta.pro/images/3a502aff7c5ff558100b6185ed70f3d0.jpg'),
(39581, 2703, 'Pokemon S21 E21', 'http://sinalprivado.info:80/series/1533784/1533784/193791.mp4', 'http://timg.bdta.pro/images/be5f20deb60a58e2ccc01939f3f1c6ff.jpg'),
(39582, 2703, 'Pokemon S21 E22', 'http://sinalprivado.info:80/series/1533784/1533784/193792.mp4', 'http://timg.bdta.pro/images/357ce604c50fd9b008b41e095d3aa0bd.jpg'),
(39583, 2703, 'Pokemon S21 E23', 'http://sinalprivado.info:80/series/1533784/1533784/193793.mp4', 'http://timg.bdta.pro/images/3c0ee97dd9e47df91a18c176d9941d56.jpg'),
(39584, 2703, 'Pokemon S21 E24', 'http://sinalprivado.info:80/series/1533784/1533784/193794.mp4', 'http://timg.bdta.pro/images/f40f4f5541b2ff89f961db94c141ce09.jpg'),
(39585, 2703, 'Pokemon S21 E25', 'http://sinalprivado.info:80/series/1533784/1533784/193795.mp4', 'http://timg.bdta.pro/images/1767677574bfcb80e4c901d595361c3b.jpg'),
(39586, 2703, 'Pokemon S21 E26', 'http://sinalprivado.info:80/series/1533784/1533784/193796.mp4', 'http://timg.bdta.pro/images/8a0d63bdf9a7536fc1861dbfbbcd0a88.jpg'),
(39587, 2703, 'Pokemon S21 E27', 'http://sinalprivado.info:80/series/1533784/1533784/193797.mp4', 'http://timg.bdta.pro/images/f8edddfae64dd2d603a37ea6e7844226.jpg'),
(39588, 2703, 'Pokemon S21 E28', 'http://sinalprivado.info:80/series/1533784/1533784/193798.mp4', 'http://timg.bdta.pro/images/4eabab50b371563015e844fe1ad8ddf2.jpg'),
(39589, 2703, 'Pokemon S21 E29', 'http://sinalprivado.info:80/series/1533784/1533784/193799.mp4', 'http://timg.bdta.pro/images/eb3b7e40b4352971b0f7c863d4da9916.jpg'),
(39590, 2703, 'Pokemon S21 E30', 'http://sinalprivado.info:80/series/1533784/1533784/193800.mp4', 'http://timg.bdta.pro/images/2f9b7c7279c46d5dccd0b15fe93407db.jpg'),
(39591, 2703, 'Pokemon S21 E31', 'http://sinalprivado.info:80/series/1533784/1533784/193801.mp4', 'http://timg.bdta.pro/images/c0dc80835cdefb614cc740708abe5615.jpg'),
(39592, 2703, 'Pokemon S21 E32', 'http://sinalprivado.info:80/series/1533784/1533784/193802.mp4', 'http://timg.bdta.pro/images/0527f7933d1c033ff6b7e5807f128f60.jpg'),
(39593, 2703, 'Pokemon S21 E33', 'http://sinalprivado.info:80/series/1533784/1533784/193803.mp4', 'http://timg.bdta.pro/images/7d598299613e777fde71ea0386bff1a3.jpg'),
(39594, 2703, 'Pokemon S21 E34', 'http://sinalprivado.info:80/series/1533784/1533784/193804.mp4', 'http://timg.bdta.pro/images/0cbd19aa6c4e8b1220da3a318cfd017d.jpg'),
(39595, 2703, 'Pokemon S21 E35', 'http://sinalprivado.info:80/series/1533784/1533784/193805.mp4', 'http://timg.bdta.pro/images/dc3db4522a5dd934ae33c7806716d972.jpg'),
(39596, 2703, 'Pokemon S21 E36', 'http://sinalprivado.info:80/series/1533784/1533784/193806.mp4', 'http://timg.bdta.pro/images/886dbbe02c14e6834c52893deb4be153.jpg'),
(39597, 2703, 'Pokemon S21 E37', 'http://sinalprivado.info:80/series/1533784/1533784/193807.mp4', 'http://timg.bdta.pro/images/f0afe79471928c4cedbed56cde1e67d8.jpg'),
(39598, 2703, 'Pokemon S21 E38', 'http://sinalprivado.info:80/series/1533784/1533784/193808.mp4', 'http://timg.bdta.pro/images/c003e59dfe6c04943168574f637238dc.jpg'),
(39599, 2703, 'Pokemon S21 E39', 'http://sinalprivado.info:80/series/1533784/1533784/193809.mp4', 'http://timg.bdta.pro/images/588f081d50387429289ec929ac7ef95a.jpg'),
(39600, 2703, 'Pokemon S21 E40', 'http://sinalprivado.info:80/series/1533784/1533784/193810.mp4', 'http://timg.bdta.pro/images/4409f5c0e80497f1a54749c6ff8709dd.jpg'),
(39601, 2703, 'Pokemon S21 E41', 'http://sinalprivado.info:80/series/1533784/1533784/193811.mp4', 'http://timg.bdta.pro/images/b56df14ebb89101f0dfd372ee9e6cf92.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(39602, 2703, 'Pokemon S21 E42', 'http://sinalprivado.info:80/series/1533784/1533784/193812.mp4', 'http://timg.bdta.pro/images/d60c4f9e9be7bc3d9372f3318106104b.jpg'),
(39603, 2703, 'Pokemon S21 E43', 'http://sinalprivado.info:80/series/1533784/1533784/193813.mp4', 'http://timg.bdta.pro/images/34f7bbc7e8c0cfe6bd0617f15a960188.jpg'),
(39604, 2703, 'Pokemon S21 E44', 'http://sinalprivado.info:80/series/1533784/1533784/193814.mp4', 'http://timg.bdta.pro/images/dd31e74a6152c7893a2d8ccbf2b3c6a3.jpg'),
(39605, 2703, 'Pokemon S21 E45', 'http://sinalprivado.info:80/series/1533784/1533784/193815.mp4', 'http://timg.bdta.pro/images/0b289851d462b07418aeb6279f6283e0.jpg'),
(39606, 2703, 'Pokemon S21 E46', 'http://sinalprivado.info:80/series/1533784/1533784/193816.mp4', 'http://timg.bdta.pro/images/788d05cc6dfe89f0a6474a72444df101.jpg'),
(39607, 2703, 'Pokemon S21 E47', 'http://sinalprivado.info:80/series/1533784/1533784/193817.mp4', 'http://timg.bdta.pro/images/b2e41fff5004e75e54d3a886a3a36fdd.jpg'),
(39608, 2703, 'Pokemon S21 E48', 'http://sinalprivado.info:80/series/1533784/1533784/193818.mp4', 'http://timg.bdta.pro/images/f2f13e7b9c6a979dae21f02f9ab73211.jpg'),
(39609, 2703, 'Pokemon S21 E49', 'http://sinalprivado.info:80/series/1533784/1533784/193819.mp4', 'http://timg.bdta.pro/images/dbf2db2b99e0eedce0dd82391a21a81c.jpg'),
(39610, 2704, 'Pokemon S24 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193820.mp4', 'http://timg.bdta.pro/images/368bfc3b0cc6e80e2de200bcfd5e8459.jpg'),
(39611, 2704, 'Pokemon S24 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193821.mp4', 'http://timg.bdta.pro/images/02549a8b384172a91be089aef26c95f2.jpg'),
(39612, 2704, 'Pokemon S24 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193822.mp4', 'http://timg.bdta.pro/images/b7acf73c27ca43f91c49c18e29452268.jpg'),
(39613, 2704, 'Pokemon S24 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193823.mp4', 'http://timg.bdta.pro/images/73a16d6da3901fec5db60590e33b65ea.jpg'),
(39614, 2704, 'Pokemon S24 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193824.mp4', 'http://timg.bdta.pro/images/fad65e9177f33bdeec40a7755597f7d4.jpg'),
(39615, 2704, 'Pokemon S24 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193825.mp4', 'http://timg.bdta.pro/images/e30363377fde86bb86b287d7248d370b.jpg'),
(39616, 2704, 'Pokemon S24 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193826.mp4', 'http://timg.bdta.pro/images/f0ab27f351e1f02692e16548f4e05613.jpg'),
(39617, 2704, 'Pokemon S24 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193827.mp4', 'http://timg.bdta.pro/images/678c9c1edb2dc5fcd183bd4ecdf79a94.jpg'),
(39618, 2704, 'Pokemon S24 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193828.mp4', 'http://timg.bdta.pro/images/b176999250091048e91a635851767700.jpg'),
(39619, 2704, 'Pokemon S24 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193829.mp4', 'http://timg.bdta.pro/images/6ca093dd803b07f007095ea382cc1e96.jpg'),
(39620, 2704, 'Pokemon S24 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193830.mp4', 'http://timg.bdta.pro/images/2246651127164b084feb98d7d20dbd03.jpg'),
(39621, 2704, 'Pokemon S24 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193831.mp4', 'http://timg.bdta.pro/images/c6a2cdec1d2e2d32eb89f9261e968ddb.jpg'),
(39622, 2704, 'Pokemon S24 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193832.mp4', 'http://timg.bdta.pro/images/cadeb282e08b406d5069025c00c95504.jpg'),
(39623, 2704, 'Pokemon S24 E14', 'http://sinalprivado.info:80/series/1533784/1533784/193833.mp4', 'http://timg.bdta.pro/images/3d6e0c90e5f19243ab5f30967f54f7c3.jpg'),
(39624, 2704, 'Pokemon S24 E15', 'http://sinalprivado.info:80/series/1533784/1533784/193834.mp4', 'http://timg.bdta.pro/images/508151d69e551d1f50737e3f3b0f1c1b.jpg'),
(39625, 2704, 'Pokemon S24 E16', 'http://sinalprivado.info:80/series/1533784/1533784/193835.mp4', 'http://timg.bdta.pro/images/3d7e69513a02894728643d4456635f74.jpg'),
(39626, 2704, 'Pokemon S24 E17', 'http://sinalprivado.info:80/series/1533784/1533784/193836.mp4', 'http://timg.bdta.pro/images/a351a442d7eaf747d8e26153dab15296.jpg'),
(39627, 2704, 'Pokemon S24 E18', 'http://sinalprivado.info:80/series/1533784/1533784/193837.mp4', 'http://timg.bdta.pro/images/83cdd3dd0f850ab417ba2747338f6627.jpg'),
(39628, 2704, 'Pokemon S24 E19', 'http://sinalprivado.info:80/series/1533784/1533784/193838.mp4', 'http://timg.bdta.pro/images/1ba590c62a18e83dbe05d82be8de085f.jpg'),
(39629, 2704, 'Pokemon S24 E20', 'http://sinalprivado.info:80/series/1533784/1533784/193839.mp4', 'http://timg.bdta.pro/images/d20c3bf7e38f64292d3d3fad5d04a34a.jpg'),
(39630, 2704, 'Pokemon S24 E21', 'http://sinalprivado.info:80/series/1533784/1533784/193840.mp4', 'http://timg.bdta.pro/images/97624cf90a91eca4fea597d5276a108a.jpg'),
(39631, 2704, 'Pokemon S24 E22', 'http://sinalprivado.info:80/series/1533784/1533784/193841.mp4', 'http://timg.bdta.pro/images/cd8169d425dc9130aba39458bc1b6070.jpg'),
(39632, 2704, 'Pokemon S24 E23', 'http://sinalprivado.info:80/series/1533784/1533784/193842.mp4', 'http://timg.bdta.pro/images/4924d902e6889b0f6a2c936eb93524fe.jpg'),
(39633, 2704, 'Pokemon S24 E24', 'http://sinalprivado.info:80/series/1533784/1533784/193843.mp4', 'http://timg.bdta.pro/images/3ed1990693649589c59fea6f8bdc8735.jpg'),
(39634, 2704, 'Pokemon S24 E25', 'http://sinalprivado.info:80/series/1533784/1533784/193844.mp4', 'http://timg.bdta.pro/images/b17719b03514bfbde1a8b879e391adc3.jpg'),
(39635, 2704, 'Pokemon S24 E26', 'http://sinalprivado.info:80/series/1533784/1533784/193845.mp4', 'http://timg.bdta.pro/images/c56f6a6a285509c8d1ff4b5b5f4c8f4d.jpg'),
(39636, 2704, 'Pokemon S24 E27', 'http://sinalprivado.info:80/series/1533784/1533784/193846.mp4', 'http://timg.bdta.pro/images/d89f6199f2df4d8679ac63d27aff9399.jpg'),
(39637, 2704, 'Pokemon S24 E28', 'http://sinalprivado.info:80/series/1533784/1533784/193847.mp4', 'http://timg.bdta.pro/images/434506bc0128a41dfe9958166ff781ef.jpg'),
(39638, 2704, 'Pokemon S24 E29', 'http://sinalprivado.info:80/series/1533784/1533784/193848.mp4', 'http://timg.bdta.pro/images/e9768c44c5bd897fcabacae1c5b960e2.jpg'),
(39639, 2704, 'Pokemon S24 E30', 'http://sinalprivado.info:80/series/1533784/1533784/193849.mp4', 'http://timg.bdta.pro/images/f23c16259b11659e5b295729c268b086.jpg'),
(39640, 2704, 'Pokemon S24 E31', 'http://sinalprivado.info:80/series/1533784/1533784/193850.mp4', 'http://timg.bdta.pro/images/0717cbe38a74a1c576a4d1d8eb648bcb.jpg'),
(39641, 2704, 'Pokemon S24 E32', 'http://sinalprivado.info:80/series/1533784/1533784/193851.mp4', 'http://timg.bdta.pro/images/86b69d867de296177c8760c4e11853cf.jpg'),
(39642, 2704, 'Pokemon S24 E33', 'http://sinalprivado.info:80/series/1533784/1533784/193852.mp4', 'http://timg.bdta.pro/images/65102ea6798dc36b7eeb2c33d9cd01d6.jpg'),
(39643, 2704, 'Pokemon S24 E34', 'http://sinalprivado.info:80/series/1533784/1533784/193853.mp4', 'http://timg.bdta.pro/images/f5b6ebdd4b6aeb2532c4ed302c4ae5e1.jpg'),
(39644, 2704, 'Pokemon S24 E35', 'http://sinalprivado.info:80/series/1533784/1533784/193854.mp4', 'http://timg.bdta.pro/images/7ef38e975a0d567bc43a0af580f4fc3a.jpg'),
(39645, 2704, 'Pokemon S24 E36', 'http://sinalprivado.info:80/series/1533784/1533784/193855.mp4', 'http://timg.bdta.pro/images/8a7f1fd878575d046f9ccf43353b4321.jpg'),
(39646, 2704, 'Pokemon S24 E37', 'http://sinalprivado.info:80/series/1533784/1533784/193856.mp4', 'http://timg.bdta.pro/images/841378fa55a0a5183668de19d5abeb6e.jpg'),
(39647, 2704, 'Pokemon S24 E38', 'http://sinalprivado.info:80/series/1533784/1533784/193857.mp4', 'http://timg.bdta.pro/images/d4ea59213cc40fe7e1f227952e359563.jpg'),
(39648, 2704, 'Pokemon S24 E39', 'http://sinalprivado.info:80/series/1533784/1533784/193858.mp4', 'http://timg.bdta.pro/images/186486ae9fdaf9e64a835bac5e4298d2.jpg'),
(39649, 2704, 'Pokemon S24 E40', 'http://sinalprivado.info:80/series/1533784/1533784/193859.mp4', 'http://timg.bdta.pro/images/61c103e33acdda1ac9e908b4031bc4fa.jpg'),
(39650, 2704, 'Pokemon S24 E41', 'http://sinalprivado.info:80/series/1533784/1533784/193860.mp4', 'http://timg.bdta.pro/images/24ff6ea564e36f465470260bcda4dc2b.jpg'),
(39651, 2704, 'Pokemon S24 E42', 'http://sinalprivado.info:80/series/1533784/1533784/193861.mp4', 'http://timg.bdta.pro/images/a707213637b29fa5279e2de87fda83ef.jpg'),
(39652, 2705, 'Mistérios sem Solução S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132779.mp4', 'http://timg.bdta.pro/images/1f743290a8a4cb64eaef32625d656ced.jpg'),
(39653, 2705, 'Mistérios sem Solução S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132780.mp4', 'http://timg.bdta.pro/images/a2299fb19319e10a492e72e67bb97ca9.jpg'),
(39654, 2705, 'Mistérios sem Solução S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132781.mp4', 'http://timg.bdta.pro/images/e1134552b64b9a3204bc2b27e1a7c263.jpg'),
(39655, 2705, 'Mistérios sem Solução S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132782.mp4', 'http://timg.bdta.pro/images/c23234bcfdbaa81ad6e4327471dedb12.jpg'),
(39656, 2705, 'Mistérios sem Solução S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132783.mp4', 'http://timg.bdta.pro/images/9d5d029bade1508c0c5fb030a09f75c2.jpg'),
(39657, 2705, 'Mistérios sem Solução S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132784.mp4', 'http://timg.bdta.pro/images/ea442ade0c4da5aba818a9cdd0c9a06b.jpg'),
(39658, 2706, 'Mistérios sem Solução S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132785.mp4', 'http://gstaticontent.com/images/q2NvU1i5kwh1OChflkOuSTlaoc1_big.jpg'),
(39659, 2706, 'Mistérios sem Solução S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132786.mp4', 'http://gstaticontent.com/images/q2NvU1i5kwh1OChflkOuSTlaoc1_big.jpg'),
(39660, 2706, 'Mistérios sem Solução S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132787.mp4', 'http://gstaticontent.com/images/q2NvU1i5kwh1OChflkOuSTlaoc1_big.jpg'),
(39661, 2706, 'Mistérios sem Solução S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132788.mp4', 'http://gstaticontent.com/images/q2NvU1i5kwh1OChflkOuSTlaoc1_big.jpg'),
(39662, 2706, 'Mistérios sem Solução S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132789.mp4', 'http://gstaticontent.com/images/q2NvU1i5kwh1OChflkOuSTlaoc1_big.jpg'),
(39663, 2706, 'Mistérios sem Solução S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132790.mp4', 'http://gstaticontent.com/images/q2NvU1i5kwh1OChflkOuSTlaoc1_big.jpg'),
(39664, 2707, 'Mistérios sem Solução S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/424590.mp4', 'http://gstaticontent.com/images/q2NvU1i5kwh1OChflkOuSTlaoc1_big.jpg'),
(39665, 2707, 'Mistérios sem Solução S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/424591.mp4', 'http://gstaticontent.com/images/q2NvU1i5kwh1OChflkOuSTlaoc1_big.jpg'),
(39666, 2707, 'Mistérios sem Solução S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/424592.mp4', 'http://gstaticontent.com/images/q2NvU1i5kwh1OChflkOuSTlaoc1_big.jpg'),
(39667, 2707, 'Mistérios sem Solução S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/424593.mp4', 'http://gstaticontent.com/images/q2NvU1i5kwh1OChflkOuSTlaoc1_big.jpg'),
(39668, 2707, 'Mistérios sem Solução S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/424594.mp4', 'http://gstaticontent.com/images/q2NvU1i5kwh1OChflkOuSTlaoc1_big.jpg'),
(39669, 2707, 'Mistérios sem Solução S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/424595.mp4', 'http://gstaticontent.com/images/q2NvU1i5kwh1OChflkOuSTlaoc1_big.jpg'),
(39670, 2707, 'Mistérios sem Solução S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/424596.mp4', 'http://gstaticontent.com/images/q2NvU1i5kwh1OChflkOuSTlaoc1_big.jpg'),
(39671, 2707, 'Mistérios sem Solução S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/424597.mp4', 'http://gstaticontent.com/images/q2NvU1i5kwh1OChflkOuSTlaoc1_big.jpg'),
(39672, 2707, 'Mistérios sem Solução S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/424598.mp4', 'http://gstaticontent.com/images/q2NvU1i5kwh1OChflkOuSTlaoc1_big.jpg'),
(39673, 2708, 'Mistérios sem Solução S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/424599.mp4', 'http://gstaticontent.com/images/q2NvU1i5kwh1OChflkOuSTlaoc1_big.jpg'),
(39674, 2708, 'Mistérios sem Solução S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/424600.mp4', 'http://gstaticontent.com/images/q2NvU1i5kwh1OChflkOuSTlaoc1_big.jpg'),
(39675, 2708, 'Mistérios sem Solução S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/424601.mp4', 'http://gstaticontent.com/images/q2NvU1i5kwh1OChflkOuSTlaoc1_big.jpg'),
(39676, 2708, 'Mistérios sem Solução S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/424602.mp4', 'http://gstaticontent.com/images/q2NvU1i5kwh1OChflkOuSTlaoc1_big.jpg'),
(39677, 2708, 'Mistérios sem Solução S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/424603.mp4', 'http://gstaticontent.com/images/q2NvU1i5kwh1OChflkOuSTlaoc1_big.jpg'),
(39678, 2709, 'Pose S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174693.mp4', 'http://timg.bdta.pro/images/9eeae2677b6365648de9f70386e40d42.jpg'),
(39679, 2709, 'Pose S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174694.mp4', 'http://timg.bdta.pro/images/8eb766d5ae9c8929ad9134fd32ffcb4c.jpg'),
(39680, 2709, 'Pose S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174695.mp4', 'http://timg.bdta.pro/images/dabe2848857a3cd5db204ffd57ef4bc2.jpg'),
(39681, 2709, 'Pose S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174696.mp4', 'http://timg.bdta.pro/images/73d19807ffede44eacd465927fd2e954.jpg'),
(39682, 2709, 'Pose S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174697.mp4', 'http://timg.bdta.pro/images/27de32cb1c0baccb255aec17053f5b4f.jpg'),
(39683, 2709, 'Pose S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174698.mp4', 'http://timg.bdta.pro/images/13552ac55c055964fa98d048dd82b00d.jpg'),
(39684, 2709, 'Pose S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174699.mp4', 'http://timg.bdta.pro/images/92c380181b71f20c94f3b7c360c0e211.jpg'),
(39685, 2709, 'Pose S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174700.mp4', 'http://timg.bdta.pro/images/484ec1b30f9063e07f4825372de50f13.jpg'),
(39686, 2710, 'Pose S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174701.mp4', 'http://timg.bdta.pro/images/92faf76a7a18117870be287087ae09c6.jpg'),
(39687, 2710, 'Pose S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174702.mp4', 'http://timg.bdta.pro/images/4cabe1f44daae840383cc22deb291492.jpg'),
(39688, 2710, 'Pose S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174703.mp4', 'http://timg.bdta.pro/images/6122ef74ecd065395b971026322eb925.jpg'),
(39689, 2710, 'Pose S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174704.mp4', 'http://timg.bdta.pro/images/289a32fc9248fa4fa5946f6bd14a810b.jpg'),
(39690, 2710, 'Pose S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174705.mp4', 'http://timg.bdta.pro/images/723ba84218e101adfd8f3fd3f3ef859f.jpg'),
(39691, 2710, 'Pose S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174706.mp4', 'http://timg.bdta.pro/images/d4bcd370a4f80934def98b611449bf0a.jpg'),
(39692, 2710, 'Pose S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174707.mp4', 'http://timg.bdta.pro/images/aaba19fa13f45dd0ddadba78645bedd9.jpg'),
(39693, 2710, 'Pose S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174708.mp4', 'http://timg.bdta.pro/images/5796857cee6a438b764bd2817ead119a.jpg'),
(39694, 2710, 'Pose S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174709.mp4', 'http://timg.bdta.pro/images/bc2b6bc6e1ed1e01175974d991ffc14d.jpg'),
(39695, 2710, 'Pose S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174710.mp4', 'http://timg.bdta.pro/images/3ec0d56f93f2afd1c41c55e5354e52ea.jpg'),
(39696, 2711, 'Pose S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174711.mp4', 'http://timg.bdta.pro/images/16605666fedb6671da0571a7e973afd8.jpg'),
(39697, 2711, 'Pose S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174712.mp4', 'http://timg.bdta.pro/images/f4ba9bd2390bd0b540c8cc73b19746d1.jpg'),
(39698, 2711, 'Pose S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174713.mp4', 'http://timg.bdta.pro/images/e748f7bb1d65ad581560a7146a600eff.jpg'),
(39699, 2711, 'Pose S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174714.mp4', 'http://timg.bdta.pro/images/d71b3555a3dede8bccee6f9d289d7317.jpg'),
(39700, 2711, 'Pose S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174715.mp4', 'http://timg.bdta.pro/images/32bbf793b5eb0d64ab3b3e70038b96b4.jpg'),
(39701, 2711, 'Pose S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174716.mp4', 'http://timg.bdta.pro/images/abc0820ea9e88427a87c06a9f06e8505.jpg'),
(39702, 2711, 'Pose S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174717.mp4', 'http://timg.bdta.pro/images/ae5c9e37a9e4b07b6ccfd61b41182ea4.jpg'),
(39703, 2712, 'Retidos na Fronteira S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132769.mp4', 'http://gstaticontent.com/images/drKZOti2PFAL9R43kJt5WEUp7ZE_big.jpg'),
(39704, 2712, 'Retidos na Fronteira S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132770.mp4', 'http://gstaticontent.com/images/drKZOti2PFAL9R43kJt5WEUp7ZE_big.jpg'),
(39705, 2712, 'Retidos na Fronteira S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132771.mp4', 'http://gstaticontent.com/images/drKZOti2PFAL9R43kJt5WEUp7ZE_big.jpg'),
(39706, 2712, 'Retidos na Fronteira S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132772.mp4', 'http://gstaticontent.com/images/drKZOti2PFAL9R43kJt5WEUp7ZE_big.jpg'),
(39707, 2712, 'Retidos na Fronteira S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132773.mp4', 'http://gstaticontent.com/images/drKZOti2PFAL9R43kJt5WEUp7ZE_big.jpg'),
(39708, 2712, 'Retidos na Fronteira S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132774.mp4', 'http://gstaticontent.com/images/drKZOti2PFAL9R43kJt5WEUp7ZE_big.jpg'),
(39709, 2712, 'Retidos na Fronteira S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132775.mp4', 'http://gstaticontent.com/images/drKZOti2PFAL9R43kJt5WEUp7ZE_big.jpg'),
(39710, 2712, 'Retidos na Fronteira S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132776.mp4', 'http://gstaticontent.com/images/drKZOti2PFAL9R43kJt5WEUp7ZE_big.jpg'),
(39711, 2712, 'Retidos na Fronteira S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132777.mp4', 'http://gstaticontent.com/images/drKZOti2PFAL9R43kJt5WEUp7ZE_big.jpg'),
(39712, 2712, 'Retidos na Fronteira S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132778.mp4', 'http://gstaticontent.com/images/drKZOti2PFAL9R43kJt5WEUp7ZE_big.jpg'),
(39713, 2713, 'Raised by Wolves [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132759.mp4', 'http://timg.bdta.pro/images/85bfe8645cbb66fe2cde6b0d2e525456.jpg'),
(39714, 2713, 'Raised by Wolves [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132760.mp4', 'http://timg.bdta.pro/images/3ebceec0d2fd0bc288e0e0706e8d9024.jpg'),
(39715, 2713, 'Raised by Wolves [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132761.mp4', 'http://timg.bdta.pro/images/5529973c59839bfc91f0fb76a2eededa.jpg'),
(39716, 2713, 'Raised by Wolves [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132762.mp4', 'http://timg.bdta.pro/images/37f6e218e047c0a76e263a70ec740256.jpg'),
(39717, 2713, 'Raised by Wolves [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132763.mp4', 'http://timg.bdta.pro/images/d69055237bcd17540cc157842e176574.jpg'),
(39718, 2713, 'Raised by Wolves [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132764.mp4', 'http://timg.bdta.pro/images/37fb6f3f21d7e71b226558287ed95753.jpg'),
(39719, 2713, 'Raised by Wolves [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132765.mp4', 'http://timg.bdta.pro/images/49df3c7d5e553ab2f469902b1fe3828e.jpg'),
(39720, 2713, 'Raised by Wolves [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132766.mp4', 'http://timg.bdta.pro/images/f8e0260bac6e1985cb87c009bff46a41.jpg'),
(39721, 2713, 'Raised by Wolves [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132767.mp4', 'http://timg.bdta.pro/images/917e8813ef07b3a6080f18147113314d.jpg'),
(39722, 2713, 'Raised by Wolves [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132768.mp4', 'http://timg.bdta.pro/images/13d906971fb9524749aafcd9b9fe40ae.jpg'),
(39723, 2714, 'Desaparecidos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132747.mp4', 'http://timg.bdta.pro/images/9cd14f7534646c94e3074d94fbe5abb4.jpg'),
(39724, 2714, 'Desaparecidos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132748.mp4', 'http://timg.bdta.pro/images/0d112e7d17ecefa9098a873b84d75aae.jpg'),
(39725, 2714, 'Desaparecidos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132749.mp4', 'http://timg.bdta.pro/images/4e7adb353e5ee8b8f30762551d62d847.jpg'),
(39726, 2714, 'Desaparecidos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132750.mp4', 'http://timg.bdta.pro/images/295b189471a72ef4b8b7b24768529ea9.jpg'),
(39727, 2714, 'Desaparecidos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132751.mp4', 'http://timg.bdta.pro/images/e6326e832669fc0acb7fbb7f2e5ad90e.jpg'),
(39728, 2714, 'Desaparecidos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132752.mp4', 'http://timg.bdta.pro/images/fbb189ad084844322b53be61852a479d.jpg'),
(39729, 2714, 'Desaparecidos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132753.mp4', 'http://timg.bdta.pro/images/79e05fc00fee2dd70e131db2b2746cad.jpg'),
(39730, 2714, 'Desaparecidos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132754.mp4', 'http://timg.bdta.pro/images/e63650d0afcda695148b921d5d8e0b62.jpg'),
(39731, 2714, 'Desaparecidos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132755.mp4', 'http://timg.bdta.pro/images/b4bc116c3f44bcec68a370ecee0101ae.jpg'),
(39732, 2714, 'Desaparecidos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132756.mp4', 'http://timg.bdta.pro/images/879e31ef2007f4d0bfdcce719030c822.jpg'),
(39733, 2714, 'Desaparecidos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132757.mp4', 'http://timg.bdta.pro/images/3a055cab86a8b40512e0012fc928c246.jpg'),
(39734, 2714, 'Desaparecidos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132758.mp4', 'http://timg.bdta.pro/images/2acf15db631e6df3fa2d6af68a1f9552.jpg'),
(39735, 2715, 'Alguém tem que morrer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132744.mp4', 'http://timg.bdta.pro/images/8cdf383a748f2577ecbd2886bde21787.jpg'),
(39736, 2715, 'Alguém tem que morrer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132745.mp4', 'http://timg.bdta.pro/images/15986a0bfd6b5ddbd7910b79f7ff6740.jpg'),
(39737, 2715, 'Alguém tem que morrer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132746.mp4', 'http://timg.bdta.pro/images/df556a38c711590fd06fdbcd7723e49d.jpg'),
(39738, 2716, 'Bruce Lee: A Lenda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132694.avi', 'http://timg.bdta.pro/images/9632058a3f9a435f6befc91f9a1952ac.jpg'),
(39739, 2716, 'Bruce Lee: A Lenda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132695.avi', 'http://timg.bdta.pro/images/b91507c4cf3cbf73d4b4fcf87c95a20b.jpg'),
(39740, 2716, 'Bruce Lee: A Lenda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132696.avi', 'http://timg.bdta.pro/images/e39418fc1a6ece8e83f0794c71982eee.jpg'),
(39741, 2716, 'Bruce Lee: A Lenda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132697.avi', 'http://timg.bdta.pro/images/cc337887fc1b2b91dd2bb95e85bfc1aa.jpg'),
(39742, 2716, 'Bruce Lee: A Lenda S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132698.avi', 'http://timg.bdta.pro/images/c6a1d01463d062a0cf897df900d8a536.jpg'),
(39743, 2716, 'Bruce Lee: A Lenda S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132699.avi', 'http://timg.bdta.pro/images/8e019484dab32e990c3d97835b394659.jpg'),
(39744, 2716, 'Bruce Lee: A Lenda S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132700.avi', 'http://timg.bdta.pro/images/13cadd8a1493f028c0afc9ce507aaf4a.jpg'),
(39745, 2716, 'Bruce Lee: A Lenda S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132701.avi', 'http://timg.bdta.pro/images/055c2d29f7a4ff77f8ca4f5244ce99c4.jpg'),
(39746, 2716, 'Bruce Lee: A Lenda S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132702.avi', 'http://timg.bdta.pro/images/21e376b388e2a548653564cbdc29cb29.jpg'),
(39747, 2716, 'Bruce Lee: A Lenda S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132703.avi', 'http://timg.bdta.pro/images/1710a6174774257b321186814b8496ee.jpg'),
(39748, 2716, 'Bruce Lee: A Lenda S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132704.avi', 'http://timg.bdta.pro/images/7995ba16dbdfbcf92e7d93fc34e1db0b.jpg'),
(39749, 2716, 'Bruce Lee: A Lenda S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132705.avi', 'http://timg.bdta.pro/images/3fe121d6650097963dbd26c7b4d16e6e.jpg'),
(39750, 2716, 'Bruce Lee: A Lenda S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132706.avi', 'http://timg.bdta.pro/images/4c56f8b149967ab9e80fee8a8f1f6195.jpg'),
(39751, 2716, 'Bruce Lee: A Lenda S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132707.avi', 'http://timg.bdta.pro/images/f6ba3f4b3d9c1061896ca330a6930d36.jpg'),
(39752, 2716, 'Bruce Lee: A Lenda S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132708.avi', 'http://timg.bdta.pro/images/907d91d60dfb35359a74a1a514618dc3.jpg'),
(39753, 2716, 'Bruce Lee: A Lenda S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132709.avi', 'http://timg.bdta.pro/images/613267086c945f64c8a09bd8e3db3bf7.jpg'),
(39754, 2716, 'Bruce Lee: A Lenda S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132710.avi', 'http://timg.bdta.pro/images/3a7153938620322132d672f5b678d7de.jpg'),
(39755, 2716, 'Bruce Lee: A Lenda S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132711.avi', 'http://timg.bdta.pro/images/89aaed8730b2bf1b1d2e8bc2842132f7.jpg'),
(39756, 2716, 'Bruce Lee: A Lenda S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132712.avi', 'http://timg.bdta.pro/images/ff36330dc85ba5facae3322802846a6d.jpg'),
(39757, 2716, 'Bruce Lee: A Lenda S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132713.avi', 'http://timg.bdta.pro/images/d8ae443694c84752c9e72e0edb931d82.jpg'),
(39758, 2716, 'Bruce Lee: A Lenda S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132714.avi', 'http://timg.bdta.pro/images/54d65e4eb466a78d5bc1474c63c1de64.jpg'),
(39759, 2716, 'Bruce Lee: A Lenda S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132715.avi', 'http://timg.bdta.pro/images/a8165207279e171375d9119ae144c927.jpg'),
(39760, 2716, 'Bruce Lee: A Lenda S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/132716.avi', 'http://timg.bdta.pro/images/b4a6cced70abbfbc18290c06eea198d8.jpg'),
(39761, 2716, 'Bruce Lee: A Lenda S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/132717.avi', 'http://timg.bdta.pro/images/fe6617e30b8fd7498f0d2b84908118a7.jpg'),
(39762, 2716, 'Bruce Lee: A Lenda S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/132718.avi', 'http://timg.bdta.pro/images/3c9e2050fa392953800dec544207213d.jpg'),
(39763, 2716, 'Bruce Lee: A Lenda S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/132719.avi', 'http://timg.bdta.pro/images/a9bd8e4f7c7ff0e8ff203404a26f3e12.jpg'),
(39764, 2716, 'Bruce Lee: A Lenda S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/132720.avi', 'http://timg.bdta.pro/images/c1aea531fbb531e7f2876f8a5c050426.jpg'),
(39765, 2716, 'Bruce Lee: A Lenda S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/132721.avi', 'http://timg.bdta.pro/images/4fd101fc8dc46a75f591a3b9fa28636d.jpg'),
(39766, 2716, 'Bruce Lee: A Lenda S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/132722.avi', 'http://timg.bdta.pro/images/bc68971ef15bd8a009edcbb4a83568d3.jpg'),
(39767, 2716, 'Bruce Lee: A Lenda S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/132723.avi', 'http://timg.bdta.pro/images/01da6fb0bd409d0749eb05e16b74b402.jpg'),
(39768, 2716, 'Bruce Lee: A Lenda S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/132724.avi', 'http://timg.bdta.pro/images/26ed1e7985d45ca57b67885be58e4978.jpg'),
(39769, 2716, 'Bruce Lee: A Lenda S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/132725.avi', 'http://timg.bdta.pro/images/c090f38e1900e7b821d1afe2870eff63.jpg'),
(39770, 2716, 'Bruce Lee: A Lenda S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/132726.avi', 'http://timg.bdta.pro/images/6db83165711b275fc13979feedc27935.jpg'),
(39771, 2716, 'Bruce Lee: A Lenda S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/132727.avi', 'http://timg.bdta.pro/images/e690831204eaf6047258ec1c212d2fe9.jpg'),
(39772, 2716, 'Bruce Lee: A Lenda S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/132728.avi', 'http://timg.bdta.pro/images/8b7a86e097293fd4e4333932b45f1536.jpg'),
(39773, 2716, 'Bruce Lee: A Lenda S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/132729.avi', 'http://timg.bdta.pro/images/74eeb2f6c5afe0ecb4bfeced8ea133c2.jpg'),
(39774, 2716, 'Bruce Lee: A Lenda S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/132730.avi', 'http://timg.bdta.pro/images/301c27aacb1cfc726ceefbe020ed9108.jpg'),
(39775, 2716, 'Bruce Lee: A Lenda S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/132731.avi', 'http://timg.bdta.pro/images/23ccb2637b84f9e6b2459d80a7c4ce14.jpg'),
(39776, 2716, 'Bruce Lee: A Lenda S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/132732.avi', 'http://timg.bdta.pro/images/760f3e76902d5c8131fe3a685e5fe62a.jpg'),
(39777, 2716, 'Bruce Lee: A Lenda S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/132733.avi', 'http://timg.bdta.pro/images/7c1835e555702af158ebf9726ca777c5.jpg'),
(39778, 2716, 'Bruce Lee: A Lenda S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/132734.avi', 'http://timg.bdta.pro/images/ca312a0b6f5e4a81c7e0c0a9520394c1.jpg'),
(39779, 2716, 'Bruce Lee: A Lenda S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/132735.avi', 'http://timg.bdta.pro/images/891fce53f5a204c05487668920aeb7ca.jpg'),
(39780, 2716, 'Bruce Lee: A Lenda S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/132736.avi', 'http://timg.bdta.pro/images/eff3e20a0fa8f148ef2d083ca595438b.jpg'),
(39781, 2716, 'Bruce Lee: A Lenda S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/132737.avi', 'http://timg.bdta.pro/images/82e180422591c7ef96edd26de358a7e5.jpg'),
(39782, 2716, 'Bruce Lee: A Lenda S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/132738.avi', 'http://timg.bdta.pro/images/444a5bf0c083fa958ced68a81e5865ef.jpg'),
(39783, 2716, 'Bruce Lee: A Lenda S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/132739.avi', 'http://timg.bdta.pro/images/b1d2cb03017a5d526ce75dcf99cd1894.jpg'),
(39784, 2716, 'Bruce Lee: A Lenda S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/132740.avi', 'http://timg.bdta.pro/images/f5bf85e2d9badda955450f015ce5b655.jpg'),
(39785, 2716, 'Bruce Lee: A Lenda S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/132741.avi', 'http://timg.bdta.pro/images/7896e180509c6d5c9afdb2b5887ef99c.jpg'),
(39786, 2716, 'Bruce Lee: A Lenda S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/132742.avi', 'http://timg.bdta.pro/images/c622b4fe8d1b95ce729b0cbf4537cb2f.jpg'),
(39787, 2716, 'Bruce Lee: A Lenda S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/132743.avi', 'http://timg.bdta.pro/images/f204e5d4df84f9b04d5d6b0d0f5c3927.jpg'),
(39788, 2717, 'Crônicas de São Francisco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132684.mp4', 'http://timg.bdta.pro/images/bfbb34d01791f5a2242c956e4eba5179.jpg'),
(39789, 2717, 'Crônicas de São Francisco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132685.mp4', 'http://timg.bdta.pro/images/c588c1d64e605520d25553d35866d652.jpg'),
(39790, 2717, 'Crônicas de São Francisco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132686.mp4', 'http://timg.bdta.pro/images/814672ee70a6b7812f1918241dcfc565.jpg'),
(39791, 2717, 'Crônicas de São Francisco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132687.mp4', 'http://timg.bdta.pro/images/97f99dd3c34ebb4a36773f5ad49ea5e6.jpg'),
(39792, 2717, 'Crônicas de São Francisco S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132688.mp4', 'http://timg.bdta.pro/images/8a89795103a499bc6d5456400f6c329c.jpg'),
(39793, 2717, 'Crônicas de São Francisco S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132689.mp4', 'http://timg.bdta.pro/images/d1fb30c9a240f2c8e06e754080672273.jpg'),
(39794, 2717, 'Crônicas de São Francisco S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132690.mp4', 'http://timg.bdta.pro/images/5f40d36961e3289f9d33ec49487f3946.jpg'),
(39795, 2717, 'Crônicas de São Francisco S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132691.mp4', 'http://timg.bdta.pro/images/fc5b91c9a1da93344a7b49588eaa61e6.jpg'),
(39796, 2717, 'Crônicas de São Francisco S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132692.mp4', 'http://timg.bdta.pro/images/c19906446c6d404c2f6f9fd839af6dae.jpg'),
(39797, 2717, 'Crônicas de São Francisco S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132693.mp4', 'http://timg.bdta.pro/images/a52d3d97d52fc34c8867eb19ee673bab.jpg'),
(39798, 2718, 'Digimon Savers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132636.mp4', 'http://timg.bdta.pro/images/8e79ac070f5bcc918e25be2a4960df04.jpg'),
(39799, 2718, 'Digimon Savers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132637.mp4', 'http://timg.bdta.pro/images/b6f3ff0b3fe7d91b3031a9ceb5a91f68.jpg'),
(39800, 2718, 'Digimon Savers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132638.mp4', 'http://timg.bdta.pro/images/beadea580d97c58ae4d3e59a68a5d8cf.jpg'),
(39801, 2718, 'Digimon Savers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132639.mp4', 'http://timg.bdta.pro/images/04b041c4b429e0792448271820630f4e.jpg'),
(39802, 2718, 'Digimon Savers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132640.mp4', 'http://timg.bdta.pro/images/42514d01d332afbc3c226946e808c195.jpg'),
(39803, 2718, 'Digimon Savers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132641.mp4', 'http://timg.bdta.pro/images/b5d3b9188d11c9ec23f89504cbf36e19.jpg'),
(39804, 2718, 'Digimon Savers S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132642.mp4', 'http://timg.bdta.pro/images/0ca7dcd05a721b55dd1ee0c9c2974552.jpg'),
(39805, 2718, 'Digimon Savers S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132643.mp4', 'http://timg.bdta.pro/images/3f25157125716844ef3cca19d72df983.jpg'),
(39806, 2718, 'Digimon Savers S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132644.mp4', 'http://timg.bdta.pro/images/22ceb50f876a23b68d6ccdff95fa9d04.jpg'),
(39807, 2718, 'Digimon Savers S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132645.mp4', 'http://timg.bdta.pro/images/567fb7ff1b115c78636a249f9e2de7be.jpg'),
(39808, 2718, 'Digimon Savers S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132646.mp4', 'http://timg.bdta.pro/images/12e1699dc5d286e7a76aa72cff93adb9.jpg'),
(39809, 2718, 'Digimon Savers S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132647.mp4', 'http://timg.bdta.pro/images/a69529a2646950092eb17e73c2a9767b.jpg'),
(39810, 2718, 'Digimon Savers S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132648.mp4', 'http://timg.bdta.pro/images/d26506d46618a64e1dcfba6bf1203f35.jpg'),
(39811, 2718, 'Digimon Savers S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132649.mp4', 'http://timg.bdta.pro/images/137486addea00f039c8e819c9f021c1a.jpg'),
(39812, 2718, 'Digimon Savers S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132650.mp4', 'http://timg.bdta.pro/images/8ec1a29bef27cab362330198f17b6493.jpg'),
(39813, 2718, 'Digimon Savers S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132651.mp4', 'http://timg.bdta.pro/images/ad63054fb306766704d1c6fae91bb2f3.jpg'),
(39814, 2718, 'Digimon Savers S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132652.mp4', 'http://timg.bdta.pro/images/8701a6cdc9325fa5041f6512f7ab0802.jpg'),
(39815, 2718, 'Digimon Savers S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132653.mp4', 'http://timg.bdta.pro/images/74f7f0f13c870db7ad25a4da8f272168.jpg'),
(39816, 2718, 'Digimon Savers S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132654.mp4', 'http://timg.bdta.pro/images/51f2d158da44fbd3a782f0ee255b4ed2.jpg'),
(39817, 2718, 'Digimon Savers S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132655.mp4', 'http://timg.bdta.pro/images/a38d5bab866f6cea13d118f95d0121bd.jpg'),
(39818, 2718, 'Digimon Savers S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132656.mp4', 'http://timg.bdta.pro/images/185706e8acf226b4e7d3900253e5ace5.jpg'),
(39819, 2718, 'Digimon Savers S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132657.mp4', 'http://timg.bdta.pro/images/d4db459652b4620e61448806116eed66.jpg'),
(39820, 2718, 'Digimon Savers S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/132658.mp4', 'http://timg.bdta.pro/images/1f3cc4e58b4524df31cf46883827715b.jpg'),
(39821, 2718, 'Digimon Savers S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/132659.mp4', 'http://timg.bdta.pro/images/843cadd88e47ac56640c67ec58129199.jpg'),
(39822, 2718, 'Digimon Savers S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/132660.mp4', 'http://timg.bdta.pro/images/76c5983228e219296fb255c8ec9eacc4.jpg'),
(39823, 2718, 'Digimon Savers S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/132661.mp4', 'http://timg.bdta.pro/images/7ee8bc2df1aff0a97ddfa079868b9027.jpg'),
(39824, 2718, 'Digimon Savers S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/132662.mp4', 'http://timg.bdta.pro/images/63b774d435b9b6e94e504bd350dbf5fe.jpg'),
(39825, 2718, 'Digimon Savers S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/132663.mp4', 'http://timg.bdta.pro/images/ac7caae11bcbc139f6437562429939b4.jpg'),
(39826, 2718, 'Digimon Savers S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/132664.mp4', 'http://timg.bdta.pro/images/51862f12a4d10484c5d61b78f40e0db9.jpg'),
(39827, 2718, 'Digimon Savers S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/132665.mp4', 'http://timg.bdta.pro/images/9d18885d6b3f27cd000ea11df29219bc.jpg'),
(39828, 2718, 'Digimon Savers S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/132666.mp4', 'http://timg.bdta.pro/images/4532665eb422ea2b65ee9158244c8936.jpg'),
(39829, 2718, 'Digimon Savers S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/132667.mp4', 'http://timg.bdta.pro/images/3e1572e1b157715d3cbe5bf9936ba1fe.jpg'),
(39830, 2718, 'Digimon Savers S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/132668.mp4', 'http://timg.bdta.pro/images/0626cde1e66e2de850c10691df3e3529.jpg'),
(39831, 2718, 'Digimon Savers S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/132669.mp4', 'http://timg.bdta.pro/images/89f09e6b1b56d6dce5254763e0b70f41.jpg'),
(39832, 2718, 'Digimon Savers S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/132670.mp4', 'http://timg.bdta.pro/images/361aba9a2b86b01714634f56cb334cec.jpg'),
(39833, 2718, 'Digimon Savers S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/132671.mp4', 'http://timg.bdta.pro/images/5581489e072053fd61a353c24a59959d.jpg'),
(39834, 2718, 'Digimon Savers S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/132672.mp4', 'http://timg.bdta.pro/images/7d91ccbde6d358d157b786f72a7f30f8.jpg'),
(39835, 2718, 'Digimon Savers S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/132673.mp4', 'http://timg.bdta.pro/images/89ea45a45bb036c5c17d7330df39be95.jpg'),
(39836, 2718, 'Digimon Savers S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/132674.mp4', 'http://timg.bdta.pro/images/92b22841c20e9e00e3dd46ccecc5dd9c.jpg'),
(39837, 2718, 'Digimon Savers S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/132675.mp4', 'http://timg.bdta.pro/images/32c96189c8f36d5817afbc47b0ed0e68.jpg'),
(39838, 2718, 'Digimon Savers S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/132676.mp4', 'http://timg.bdta.pro/images/abb76ece7bab0f6baf3c0ee7de795cbe.jpg'),
(39839, 2718, 'Digimon Savers S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/132677.mp4', 'http://timg.bdta.pro/images/582022399e007abf92b72a87055b79a0.jpg'),
(39840, 2718, 'Digimon Savers S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/132678.mp4', 'http://timg.bdta.pro/images/4637efd360bd48c9b6f6872d5a288e5d.jpg'),
(39841, 2718, 'Digimon Savers S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/132679.mp4', 'http://timg.bdta.pro/images/8a0a77436b90827acb888461d8c0a621.jpg'),
(39842, 2718, 'Digimon Savers S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/132680.mp4', 'http://timg.bdta.pro/images/e5e5970d4629c0402ca47a1d21d6edb3.jpg'),
(39843, 2718, 'Digimon Savers S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/132681.mp4', 'http://timg.bdta.pro/images/60e6b7390cbd57133310c39673b5e6cb.jpg'),
(39844, 2718, 'Digimon Savers S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/132682.mp4', 'http://timg.bdta.pro/images/464ecba772a68d991693db347ce71e9d.jpg'),
(39845, 2718, 'Digimon Savers S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/132683.mp4', 'http://timg.bdta.pro/images/8b3bda9c082dfad8b25f4008f48062a7.jpg'),
(39846, 2719, 'Desalma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178668.mp4', 'http://gstaticontent.com/images/3g75wyrKEOBiLDcYW8XAV6E5zjC_big.jpg'),
(39847, 2719, 'Desalma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178669.mp4', 'http://gstaticontent.com/images/3g75wyrKEOBiLDcYW8XAV6E5zjC_big.jpg'),
(39848, 2719, 'Desalma S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178670.mp4', 'http://gstaticontent.com/images/3g75wyrKEOBiLDcYW8XAV6E5zjC_big.jpg'),
(39849, 2719, 'Desalma S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178671.mp4', 'http://gstaticontent.com/images/3g75wyrKEOBiLDcYW8XAV6E5zjC_big.jpg'),
(39850, 2719, 'Desalma S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178672.mp4', 'http://gstaticontent.com/images/3g75wyrKEOBiLDcYW8XAV6E5zjC_big.jpg'),
(39851, 2719, 'Desalma S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178673.mp4', 'http://gstaticontent.com/images/3g75wyrKEOBiLDcYW8XAV6E5zjC_big.jpg'),
(39852, 2719, 'Desalma S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178674.mp4', 'http://gstaticontent.com/images/3g75wyrKEOBiLDcYW8XAV6E5zjC_big.jpg'),
(39853, 2719, 'Desalma S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178675.mp4', 'http://gstaticontent.com/images/3g75wyrKEOBiLDcYW8XAV6E5zjC_big.jpg'),
(39854, 2719, 'Desalma S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178676.mp4', 'http://gstaticontent.com/images/3g75wyrKEOBiLDcYW8XAV6E5zjC_big.jpg'),
(39855, 2719, 'Desalma S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178677.mp4', 'http://gstaticontent.com/images/3g75wyrKEOBiLDcYW8XAV6E5zjC_big.jpg'),
(39856, 2720, 'Desalma S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178678.mp4', 'http://timg.bdta.pro/images/8cdf0f7a0d14455601101d31ef43a101.jpg'),
(39857, 2720, 'Desalma S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178679.mp4', 'http://timg.bdta.pro/images/a32b5a16659e485eff792a161dff2c0e.jpg'),
(39858, 2720, 'Desalma S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178680.mp4', 'http://timg.bdta.pro/images/f1f352bfc46e348b036e8f9f5601a760.jpg'),
(39859, 2720, 'Desalma S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178681.mp4', 'http://timg.bdta.pro/images/8664c51ed7c2dddbeea7a96a1ef99c7a.jpg'),
(39860, 2720, 'Desalma S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178682.mp4', 'http://timg.bdta.pro/images/a1f5070decb3876a9a62eb1ad38df99c.jpg'),
(39861, 2720, 'Desalma S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178683.mp4', 'http://timg.bdta.pro/images/af4b3ad22cbe8b61a1e7cd2fa3c20637.jpg'),
(39862, 2720, 'Desalma S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178684.mp4', 'http://timg.bdta.pro/images/cb576d102dec9658b3a695e42b10f70d.jpg'),
(39863, 2720, 'Desalma S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178685.mp4', 'http://timg.bdta.pro/images/048c4b4100af49002bdd74b26169acfa.jpg'),
(39864, 2720, 'Desalma S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178686.mp4', 'http://timg.bdta.pro/images/9e668cb83c4e1879da62b5daf6427799.jpg'),
(39865, 2720, 'Desalma S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178687.mp4', 'http://timg.bdta.pro/images/1793bde1585c1306080edafea334b0df.jpg'),
(39866, 2721, 'Três é Demais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132412.mp4', 'http://timg.bdta.pro/images/53a0c19425536c54a58940719a599a15.jpg'),
(39867, 2721, 'Três é Demais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132413.mp4', 'http://timg.bdta.pro/images/217aff9ee56f127440863e1877162ee9.jpg'),
(39868, 2721, 'Três é Demais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132414.mp4', 'http://timg.bdta.pro/images/b4dd0610ee3afb5293ff9711208e5428.jpg'),
(39869, 2721, 'Três é Demais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132415.mp4', 'http://timg.bdta.pro/images/e05dc390c75c3d245651d26400822176.jpg'),
(39870, 2721, 'Três é Demais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132416.mp4', 'http://timg.bdta.pro/images/3f08506318dd5d3fb5febd30f5938423.jpg'),
(39871, 2721, 'Três é Demais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132417.mp4', 'http://timg.bdta.pro/images/dbfd90558201f60bf7e0a66c40624bfd.jpg'),
(39872, 2721, 'Três é Demais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132418.mp4', 'http://timg.bdta.pro/images/947eec34950abf46863c3f2b82d918cd.jpg'),
(39873, 2721, 'Três é Demais S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132419.mp4', 'http://timg.bdta.pro/images/ce853d049c62628381f73afc9a072a3d.jpg'),
(39874, 2721, 'Três é Demais S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132420.mp4', 'http://timg.bdta.pro/images/064614dc5e3c026f43a26996d5af5e17.jpg'),
(39875, 2721, 'Três é Demais S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132421.mp4', 'http://timg.bdta.pro/images/0de2e48c2968badd0dbcbed3c0b8d161.jpg'),
(39876, 2721, 'Três é Demais S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132422.mp4', 'http://timg.bdta.pro/images/2a18917ed9b30c1e9a7a956b508dfe96.jpg'),
(39877, 2721, 'Três é Demais S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132423.mp4', 'http://timg.bdta.pro/images/37d0b6705abdbeacbb804a906b038c27.jpg'),
(39878, 2721, 'Três é Demais S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132424.mp4', 'http://timg.bdta.pro/images/6675c704c2495acc53e5979d912289c5.jpg'),
(39879, 2721, 'Três é Demais S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132425.mp4', 'http://timg.bdta.pro/images/68f570fb1ef60d62421dd32a5a9f3741.jpg'),
(39880, 2721, 'Três é Demais S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132426.mp4', 'http://timg.bdta.pro/images/89d09112c21736bb96676b9dd223566c.jpg'),
(39881, 2721, 'Três é Demais S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132427.mp4', 'http://timg.bdta.pro/images/7d78d86c99c3b86bbd35583788da4786.jpg'),
(39882, 2721, 'Três é Demais S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132428.mp4', 'http://timg.bdta.pro/images/14c2ef9446cf30f1270df2a6d25dbb82.jpg'),
(39883, 2721, 'Três é Demais S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132429.mp4', 'http://timg.bdta.pro/images/b56badd6dda4236fb2778e954f76c8d1.jpg'),
(39884, 2721, 'Três é Demais S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132430.mp4', 'http://timg.bdta.pro/images/fad432276cdedb3cdd03f1b8bc3c9896.jpg'),
(39885, 2721, 'Três é Demais S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132431.mp4', 'http://timg.bdta.pro/images/5d75bae3390fe1fe18e4504783574805.jpg'),
(39886, 2721, 'Três é Demais S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132432.mp4', 'http://timg.bdta.pro/images/972e02a80dea3c45f316c89174c78a66.jpg'),
(39887, 2721, 'Três é Demais S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132433.mp4', 'http://timg.bdta.pro/images/cbb44934559eb9a8afcb65dc7f1fc3d4.jpg'),
(39888, 2722, 'Três é Demais S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132434.mp4', 'http://timg.bdta.pro/images/c293b91736c3c4a53a3e37a455193c79.jpg'),
(39889, 2722, 'Três é Demais S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132435.mp4', 'http://timg.bdta.pro/images/13776a2854259c881b8252f28f28d282.jpg'),
(39890, 2722, 'Três é Demais S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132436.mp4', 'http://timg.bdta.pro/images/ec75d699f37575311352dc0e7773bbff.jpg'),
(39891, 2722, 'Três é Demais S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132437.mp4', 'http://timg.bdta.pro/images/f5e3aa1907d24310dcf30956b5108159.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(39892, 2722, 'Três é Demais S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132438.mp4', 'http://timg.bdta.pro/images/63ddcc50c2ab1ce01a0f6321dc4e3191.jpg'),
(39893, 2722, 'Três é Demais S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132439.mp4', 'http://timg.bdta.pro/images/c1b60ae94ef96d2866b7035e952336a2.jpg'),
(39894, 2722, 'Três é Demais S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132440.mp4', 'http://timg.bdta.pro/images/a1997ee74825c8e5940caa4cb0aae5c8.jpg'),
(39895, 2722, 'Três é Demais S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132441.mp4', 'http://timg.bdta.pro/images/f548da63145d90b1e5780f8824d97f69.jpg'),
(39896, 2722, 'Três é Demais S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132442.mp4', 'http://timg.bdta.pro/images/3851d72ac5e79b25792d4ecd1971ef28.jpg'),
(39897, 2722, 'Três é Demais S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132443.mp4', 'http://timg.bdta.pro/images/fd6fa2e8de986ae9016fc668b464dbcc.jpg'),
(39898, 2722, 'Três é Demais S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132444.mp4', 'http://timg.bdta.pro/images/b9434848d5430f0a275672cafa374921.jpg'),
(39899, 2722, 'Três é Demais S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132445.mp4', 'http://timg.bdta.pro/images/6b64b1ac43b3e080fe8e65d66b004f05.jpg'),
(39900, 2722, 'Três é Demais S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132446.mp4', 'http://timg.bdta.pro/images/22a293e902428b3361f734c4c624b9b1.jpg'),
(39901, 2722, 'Três é Demais S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132447.mp4', 'http://timg.bdta.pro/images/4310a6cc9e832274f8d7af00af533efd.jpg'),
(39902, 2722, 'Três é Demais S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132448.mp4', 'http://timg.bdta.pro/images/7b66e677e127ec173bd0e8e109fea57a.jpg'),
(39903, 2722, 'Três é Demais S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132449.mp4', 'http://timg.bdta.pro/images/c5084ed7b37350c0a3d182301c93683c.jpg'),
(39904, 2722, 'Três é Demais S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132450.mp4', 'http://timg.bdta.pro/images/cf4daaac81dfb6ed4cd7de4cb22e5502.jpg'),
(39905, 2722, 'Três é Demais S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132451.mp4', 'http://timg.bdta.pro/images/f42da88617f1e67172da561516b2c0c7.jpg'),
(39906, 2722, 'Três é Demais S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132452.mp4', 'http://timg.bdta.pro/images/6ca1ad73d5274908d062305926e5ac41.jpg'),
(39907, 2722, 'Três é Demais S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132453.mp4', 'http://timg.bdta.pro/images/65ea36dae76a4cea94c88490c5ff39a0.jpg'),
(39908, 2722, 'Três é Demais S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132454.mp4', 'http://timg.bdta.pro/images/2a4c73e86a94fbe2551ba2483eab3664.jpg'),
(39909, 2722, 'Três é Demais S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132455.mp4', 'http://timg.bdta.pro/images/eed6605d4403d9073ce246a0de4b270c.jpg'),
(39910, 2723, 'Três é Demais S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132456.mp4', 'http://timg.bdta.pro/images/8868ea861d16b82a2565ae766d3cf720.jpg'),
(39911, 2723, 'Três é Demais S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132457.mp4', 'http://timg.bdta.pro/images/79c2efb2ffdf774f252bc1e3535ee1c4.jpg'),
(39912, 2723, 'Três é Demais S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132458.mp4', 'http://timg.bdta.pro/images/197edbceb4e849cf0d2cd1b22978b555.jpg'),
(39913, 2723, 'Três é Demais S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132459.mp4', 'http://timg.bdta.pro/images/69bd91b65135c99594416659e2537b36.jpg'),
(39914, 2723, 'Três é Demais S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132460.mp4', 'http://timg.bdta.pro/images/8b7a1dbfd56dffbd347a036ccf945f75.jpg'),
(39915, 2723, 'Três é Demais S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132461.mp4', 'http://timg.bdta.pro/images/acbb17e71c04b0ded497fa4e2b380a43.jpg'),
(39916, 2723, 'Três é Demais S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132462.mp4', 'http://timg.bdta.pro/images/116f5c849c9a19ad1058ae4baf10f32d.jpg'),
(39917, 2723, 'Três é Demais S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132463.mp4', 'http://timg.bdta.pro/images/13c58016fc16c11003eaac0bce48d767.jpg'),
(39918, 2723, 'Três é Demais S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132464.mp4', 'http://timg.bdta.pro/images/0c52ca6a9b2598b3175ae4ed98eb42b9.jpg'),
(39919, 2723, 'Três é Demais S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132465.mp4', 'http://timg.bdta.pro/images/7064630da1892273730d83362e3e8465.jpg'),
(39920, 2723, 'Três é Demais S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132466.mp4', 'http://timg.bdta.pro/images/8618c058d321c295207b783e175b897e.jpg'),
(39921, 2723, 'Três é Demais S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132467.mp4', 'http://timg.bdta.pro/images/e9eea9744907176531a5989f0391e340.jpg'),
(39922, 2723, 'Três é Demais S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132468.mp4', 'http://timg.bdta.pro/images/f8857f79fedcd513e8603f24950eac52.jpg'),
(39923, 2723, 'Três é Demais S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132469.mp4', 'http://timg.bdta.pro/images/348b1c8a82aea37290fb3551d8f82378.jpg'),
(39924, 2723, 'Três é Demais S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132470.mp4', 'http://timg.bdta.pro/images/293d6c3aa18bbbc9d984a91d9013a67b.jpg'),
(39925, 2723, 'Três é Demais S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132471.mp4', 'http://timg.bdta.pro/images/9d9758f2e5058934bfc81aebdfcbbc23.jpg'),
(39926, 2723, 'Três é Demais S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132472.mp4', 'http://timg.bdta.pro/images/9aa354d7e544f5d785aa5c7e7150b14a.jpg'),
(39927, 2723, 'Três é Demais S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132473.mp4', 'http://timg.bdta.pro/images/5f2621f4de4a040177fe72e512c1a011.jpg'),
(39928, 2723, 'Três é Demais S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132474.mp4', 'http://timg.bdta.pro/images/08e479a444feb3f2097253becc23438c.jpg'),
(39929, 2723, 'Três é Demais S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132475.mp4', 'http://timg.bdta.pro/images/2212adffadb395808216488441daf1cb.jpg'),
(39930, 2723, 'Três é Demais S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132476.mp4', 'http://timg.bdta.pro/images/300cb575ef102351e79c6cc7be7671e7.jpg'),
(39931, 2723, 'Três é Demais S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132477.mp4', 'http://timg.bdta.pro/images/d8b3aec6db2d34585010733adf5116cb.jpg'),
(39932, 2723, 'Três é Demais S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/132478.mp4', 'http://timg.bdta.pro/images/cbfd109b067e8441e8dcfc53a0ce5c1f.jpg'),
(39933, 2723, 'Três é Demais S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/132479.mp4', 'http://timg.bdta.pro/images/f7e0afe7ba9ae3fe61d0a85a6ab865b9.jpg'),
(39934, 2724, 'Três é Demais S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132480.mp4', 'http://timg.bdta.pro/images/5772e18844089d5974b60fe0c9bb07e3.jpg'),
(39935, 2724, 'Três é Demais S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132481.mp4', 'http://timg.bdta.pro/images/232ba4ce779aa0e889e8ec9bb232f7ea.jpg'),
(39936, 2724, 'Três é Demais S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132482.mp4', 'http://timg.bdta.pro/images/300106dc8aa4b465ec02951b9add0358.jpg'),
(39937, 2724, 'Três é Demais S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132483.mp4', 'http://timg.bdta.pro/images/7f119afa9f54c9803bcd19c9f31f0e7d.jpg'),
(39938, 2724, 'Três é Demais S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132484.mp4', 'http://timg.bdta.pro/images/f78ac0827e0b07c8858461ef08ccb9ff.jpg'),
(39939, 2724, 'Três é Demais S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132485.mp4', 'http://timg.bdta.pro/images/3ffc3ad7aab4e7ce4398b506e1e0de25.jpg'),
(39940, 2724, 'Três é Demais S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132486.mp4', 'http://timg.bdta.pro/images/c5be042c888eb5c4872e6978ab51f331.jpg'),
(39941, 2724, 'Três é Demais S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132487.mp4', 'http://timg.bdta.pro/images/95356ee439fd696736744059cad09a39.jpg'),
(39942, 2724, 'Três é Demais S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132488.mp4', 'http://timg.bdta.pro/images/4a771b2df028b739551aca5a0d3020ef.jpg'),
(39943, 2724, 'Três é Demais S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132489.mp4', 'http://timg.bdta.pro/images/bf5c82382fe0496a447c0de9977d4f9b.jpg'),
(39944, 2724, 'Três é Demais S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132490.mp4', 'http://timg.bdta.pro/images/4d52ca8a3e3181ab5317a3024d531dd7.jpg'),
(39945, 2724, 'Três é Demais S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132491.mp4', 'http://timg.bdta.pro/images/86bc7bcad5c9e960ddf43872ef485b7f.jpg'),
(39946, 2724, 'Três é Demais S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132492.mp4', 'http://timg.bdta.pro/images/4f505ce3c4b38e706438bc4791968844.jpg'),
(39947, 2724, 'Três é Demais S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132493.mp4', 'http://timg.bdta.pro/images/58d7d30479ff589b18c877b4e597b2c6.jpg'),
(39948, 2724, 'Três é Demais S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132494.mp4', 'http://timg.bdta.pro/images/9e40269069bc928c63fea4591ae9211d.jpg'),
(39949, 2724, 'Três é Demais S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132495.mp4', 'http://timg.bdta.pro/images/5f90faf7777e623a358483403a4eb45f.jpg'),
(39950, 2724, 'Três é Demais S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132496.mp4', 'http://timg.bdta.pro/images/5db8d7c9e1b17831eceab9bba271eae7.jpg'),
(39951, 2724, 'Três é Demais S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132497.mp4', 'http://timg.bdta.pro/images/a231f2fa728e4947666436dfd353df98.jpg'),
(39952, 2724, 'Três é Demais S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132498.mp4', 'http://timg.bdta.pro/images/0f4cc3edea2bf5f1e94aa699d7fae120.jpg'),
(39953, 2724, 'Três é Demais S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132499.mp4', 'http://timg.bdta.pro/images/27bc9f9a2cb2389d2b4b4e4e1f4db22a.jpg'),
(39954, 2724, 'Três é Demais S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132500.mp4', 'http://timg.bdta.pro/images/34ef4e7b6833187ff3e18306262990cc.jpg'),
(39955, 2724, 'Três é Demais S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132501.mp4', 'http://timg.bdta.pro/images/261c3f54205e9ab05e36f542a00b8dd6.jpg'),
(39956, 2724, 'Três é Demais S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/132502.mp4', 'http://timg.bdta.pro/images/3743942a56e51dce751431532422affb.jpg'),
(39957, 2724, 'Três é Demais S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/132503.mp4', 'http://timg.bdta.pro/images/511be174f306bc082bc4e3ed505b6ae7.jpg'),
(39958, 2724, 'Três é Demais S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/132504.mp4', 'http://timg.bdta.pro/images/61e7f56471153352a00a731588dc59cb.jpg'),
(39959, 2724, 'Três é Demais S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/132505.mp4', 'http://timg.bdta.pro/images/4f9d4c98663bdb78dd5bce8f0bbb6c63.jpg'),
(39960, 2725, 'Três é Demais S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132506.mp4', 'http://timg.bdta.pro/images/3d43efd017c086e2148a7bd8232a1b4e.jpg'),
(39961, 2725, 'Três é Demais S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132507.mp4', 'http://timg.bdta.pro/images/ef7e07f0572a4f4498740633407d0154.jpg'),
(39962, 2725, 'Três é Demais S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132508.mp4', 'http://timg.bdta.pro/images/985bd2b202ee24072bb1cfe23d683399.jpg'),
(39963, 2725, 'Três é Demais S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132509.mp4', 'http://timg.bdta.pro/images/12b5b00137b98e7c382bdd1d0ad8f346.jpg'),
(39964, 2725, 'Três é Demais S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132510.mp4', 'http://timg.bdta.pro/images/308b1d06eb9f65e0569678da915e361a.jpg'),
(39965, 2725, 'Três é Demais S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132511.mp4', 'http://timg.bdta.pro/images/42f18c07c9c6c9a3a977e58d9c938ea8.jpg'),
(39966, 2725, 'Três é Demais S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132512.mp4', 'http://timg.bdta.pro/images/bb5b5f243b8d1857d09d06b78418a2dd.jpg'),
(39967, 2725, 'Três é Demais S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132513.mp4', 'http://timg.bdta.pro/images/b0877cea7c159f6e458a46abf68a28e1.jpg'),
(39968, 2725, 'Três é Demais S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132514.mp4', 'http://timg.bdta.pro/images/1d789e9e2051bec667f8d200ef65df68.jpg'),
(39969, 2725, 'Três é Demais S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132515.mp4', 'http://timg.bdta.pro/images/d0324c8db93a4e1667d532d89d9c17a3.jpg'),
(39970, 2725, 'Três é Demais S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132516.mp4', 'http://timg.bdta.pro/images/c9a64103cdc0bd9ef920c2d8869177aa.jpg'),
(39971, 2725, 'Três é Demais S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132517.mp4', 'http://timg.bdta.pro/images/dfd562491393612730bbbf3a4ee7ce16.jpg'),
(39972, 2725, 'Três é Demais S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132518.mp4', 'http://timg.bdta.pro/images/ab31ab108ba0eca14d65d5227644613b.jpg'),
(39973, 2725, 'Três é Demais S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132519.mp4', 'http://timg.bdta.pro/images/719d898541544f7c4ca41a15fef2f95c.jpg'),
(39974, 2725, 'Três é Demais S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132520.mp4', 'http://timg.bdta.pro/images/845954cb64d209f2bd1062a8ac70bdaf.jpg'),
(39975, 2725, 'Três é Demais S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132521.mp4', 'http://timg.bdta.pro/images/08474b76ea2bb29070292f1288149223.jpg'),
(39976, 2725, 'Três é Demais S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132522.mp4', 'http://timg.bdta.pro/images/a1eff1b4ea85c89e0ebba149ca205322.jpg'),
(39977, 2725, 'Três é Demais S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132523.mp4', 'http://timg.bdta.pro/images/d203e9d6dd1df2fa76f716a66d2813f8.jpg'),
(39978, 2725, 'Três é Demais S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132524.mp4', 'http://timg.bdta.pro/images/f4af55f46ab8e95967e9701c1340d117.jpg'),
(39979, 2725, 'Três é Demais S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132525.mp4', 'http://timg.bdta.pro/images/9531816e404b5de01516d9df15b173af.jpg'),
(39980, 2725, 'Três é Demais S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132526.mp4', 'http://timg.bdta.pro/images/7a1bf0733914d1177a83df4251a49a9d.jpg'),
(39981, 2725, 'Três é Demais S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132527.mp4', 'http://timg.bdta.pro/images/bf4df3bd78c04b5db7d27a58d23b5ddc.jpg'),
(39982, 2725, 'Três é Demais S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/132528.mp4', 'http://timg.bdta.pro/images/bc987e6b84113c304499b3e1705e3610.jpg'),
(39983, 2725, 'Três é Demais S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/132529.mp4', 'http://timg.bdta.pro/images/46cc6f7ed1acfba2f7cbc77ea1003026.jpg'),
(39984, 2725, 'Três é Demais S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/132530.mp4', 'http://timg.bdta.pro/images/98c357e3e1ac9b95fda45aa4a20e3b8e.jpg'),
(39985, 2725, 'Três é Demais S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/132531.mp4', 'http://timg.bdta.pro/images/113b01a0e17e727b692b9cd0d21e12b1.jpg'),
(39986, 2726, 'Três é Demais S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132532.mp4', 'http://timg.bdta.pro/images/56570165c0b237e7dd98ca6cd53a99e9.jpg'),
(39987, 2726, 'Três é Demais S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132533.mp4', 'http://timg.bdta.pro/images/1c5ba4dc6f01cbcccbdb180bc3cc2e18.jpg'),
(39988, 2726, 'Três é Demais S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132534.mp4', 'http://timg.bdta.pro/images/af1dd1a5b4d5c40cf37be3e97236f44c.jpg'),
(39989, 2726, 'Três é Demais S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132535.mp4', 'http://timg.bdta.pro/images/435bb35ce31659a01089395d3a1e7ae2.jpg'),
(39990, 2726, 'Três é Demais S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132536.mp4', 'http://timg.bdta.pro/images/bfa12e755a7e2fbb9ae1f5dc404be8c7.jpg'),
(39991, 2726, 'Três é Demais S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132537.mp4', 'http://timg.bdta.pro/images/30b513bb3497624d8ed6e8868e23bedc.jpg'),
(39992, 2726, 'Três é Demais S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132538.mp4', 'http://timg.bdta.pro/images/7093c1e3939c847e3b932f6dbec4068e.jpg'),
(39993, 2726, 'Três é Demais S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132539.mp4', 'http://timg.bdta.pro/images/4873063a296554b9d7dcbc5bc3c02217.jpg'),
(39994, 2726, 'Três é Demais S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132540.mp4', 'http://timg.bdta.pro/images/54e4ea0a2469a713bdcb9abd37ab29be.jpg'),
(39995, 2726, 'Três é Demais S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132541.mp4', 'http://timg.bdta.pro/images/72c73496efdc295bd5c968e68770fb42.jpg'),
(39996, 2726, 'Três é Demais S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132542.mp4', 'http://timg.bdta.pro/images/a2ab319c3f7fc9610c13de808ba1626a.jpg'),
(39997, 2726, 'Três é Demais S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132543.mp4', 'http://timg.bdta.pro/images/c25026a7e68f0dbfcd305e5f42e0d3d0.jpg'),
(39998, 2726, 'Três é Demais S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132544.mp4', 'http://timg.bdta.pro/images/b1757b6b57c2c849854c4ba541bd3715.jpg'),
(39999, 2726, 'Três é Demais S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132545.mp4', 'http://timg.bdta.pro/images/04fd6b357026c558d0063ee6a760fffb.jpg'),
(40000, 2726, 'Três é Demais S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/544962.mp4', 'http://gstaticontent.com/images/e98b06d15393b6eea6d590d3db5ee0a2.jpg'),
(40001, 2726, 'Três é Demais S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132547.mp4', 'http://timg.bdta.pro/images/a93b76bcbabb1bf40e3bda381d31afd7.jpg'),
(40002, 2726, 'Três é Demais S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132548.mp4', 'http://timg.bdta.pro/images/9c9d8a999c10cfe5e3d82640746bb0e8.jpg'),
(40003, 2726, 'Três é Demais S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132549.mp4', 'http://timg.bdta.pro/images/6f344e87118a289a2539886a87b20b2c.jpg'),
(40004, 2726, 'Três é Demais S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132550.mp4', 'http://timg.bdta.pro/images/94b17c3d06c604336d2aa0ad19be08da.jpg'),
(40005, 2726, 'Três é Demais S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132551.mp4', 'http://timg.bdta.pro/images/60b38eeb2eeb07270f7128277da2f5c5.jpg'),
(40006, 2726, 'Três é Demais S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132552.mp4', 'http://timg.bdta.pro/images/47a9554a265d9b10c026194741944d2b.jpg'),
(40007, 2726, 'Três é Demais S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132553.mp4', 'http://timg.bdta.pro/images/6523d26e72d674017d3fbac8a5e6432a.jpg'),
(40008, 2726, 'Três é Demais S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/132554.mp4', 'http://timg.bdta.pro/images/b966c231402a702dabc2b82ffb0da71d.jpg'),
(40009, 2726, 'Três é Demais S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/132555.mp4', 'http://timg.bdta.pro/images/e889093ff23f5e783f8f4d6513516887.jpg'),
(40010, 2727, 'Três é Demais S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132556.mp4', 'http://timg.bdta.pro/images/ca35126958a587ece6a70db434957b09.jpg'),
(40011, 2727, 'Três é Demais S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132557.mp4', 'http://timg.bdta.pro/images/06ea6fd3b85c6580dc5383dfbcd9fee4.jpg'),
(40012, 2727, 'Três é Demais S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132558.mp4', 'http://timg.bdta.pro/images/8466854eb26fc39f7cd78942737aeae4.jpg'),
(40013, 2727, 'Três é Demais S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132559.mp4', 'http://timg.bdta.pro/images/500281db75b094d42a7ee8ca8529f38d.jpg'),
(40014, 2727, 'Três é Demais S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132560.mp4', 'http://timg.bdta.pro/images/5279924d2eacc04d1f1509e8569d5260.jpg'),
(40015, 2727, 'Três é Demais S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132561.mp4', 'http://timg.bdta.pro/images/a592ed1c0160b894a67fb3a19bd80b1b.jpg'),
(40016, 2727, 'Três é Demais S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132562.mp4', 'http://timg.bdta.pro/images/110ea633a5f85955e23dac14731abec0.jpg'),
(40017, 2727, 'Três é Demais S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132563.mp4', 'http://timg.bdta.pro/images/d0d6ed7b0184ae06a91e643a40cf56ff.jpg'),
(40018, 2727, 'Três é Demais S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132564.mp4', 'http://timg.bdta.pro/images/fb6d39ae673fc19e4a445678d17ced72.jpg'),
(40019, 2727, 'Três é Demais S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132565.mp4', 'http://timg.bdta.pro/images/a1969807a92f8b4adc3c15d2b24511b4.jpg'),
(40020, 2727, 'Três é Demais S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132566.mp4', 'http://timg.bdta.pro/images/25ebf255e6a70e4cd710be387b804ad2.jpg'),
(40021, 2727, 'Três é Demais S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132567.mp4', 'http://timg.bdta.pro/images/aabf9ce4a5abe2acba2969a963fed136.jpg'),
(40022, 2727, 'Três é Demais S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132568.mp4', 'http://timg.bdta.pro/images/febf7b6ebd6ad80630184f2760b57c87.jpg'),
(40023, 2727, 'Três é Demais S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132569.mp4', 'http://timg.bdta.pro/images/1dfb6d8d42a281f396f5d9954b5a0838.jpg'),
(40024, 2727, 'Três é Demais S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132570.mp4', 'http://timg.bdta.pro/images/fb907c97e24407a18430d7ea8ca3b783.jpg'),
(40025, 2727, 'Três é Demais S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132571.mp4', 'http://timg.bdta.pro/images/2c75ab3353be8df7f61c8e60ae6ce2ba.jpg'),
(40026, 2727, 'Três é Demais S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132572.mp4', 'http://timg.bdta.pro/images/a8763562723dfc806f897fbd7a49f60f.jpg'),
(40027, 2727, 'Três é Demais S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132573.mp4', 'http://timg.bdta.pro/images/7161141499a4739608a516a48cc6b038.jpg'),
(40028, 2727, 'Três é Demais S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132574.mp4', 'http://timg.bdta.pro/images/b827dfb1d85a90c505fe72618f610b34.jpg'),
(40029, 2727, 'Três é Demais S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132575.mp4', 'http://timg.bdta.pro/images/6aef06972cf3a78820b6779e887854cf.jpg'),
(40030, 2727, 'Três é Demais S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132576.mp4', 'http://timg.bdta.pro/images/2d2fb03dd81361bdb48486eb070495db.jpg'),
(40031, 2727, 'Três é Demais S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132577.mp4', 'http://timg.bdta.pro/images/73f7ba87378c65147fad841bd8056c69.jpg'),
(40032, 2727, 'Três é Demais S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/132578.mp4', 'http://timg.bdta.pro/images/1f6a7244b0595b4a62d64fe623fc916e.jpg'),
(40033, 2727, 'Três é Demais S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/132579.mp4', 'http://timg.bdta.pro/images/0ced1dac2079a9e1cf6809a6a447dd4e.jpg'),
(40034, 2728, 'Três é Demais S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132580.mp4', 'http://timg.bdta.pro/images/a0c099ebc68cd78572dae1eb6edab21a.jpg'),
(40035, 2728, 'Três é Demais S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132581.mp4', 'http://timg.bdta.pro/images/a69f8f2aaf1c7c8a0599591a0aa5a6a3.jpg'),
(40036, 2728, 'Três é Demais S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132582.mp4', 'http://timg.bdta.pro/images/39a638b6fd7d69c89e37c65b40368e25.jpg'),
(40037, 2728, 'Três é Demais S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132583.mp4', 'http://timg.bdta.pro/images/d707a8d8f4e5cb6b19f57fe136b57be4.jpg'),
(40038, 2728, 'Três é Demais S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132584.mp4', 'http://timg.bdta.pro/images/95eb0681537093a44262d71c507ddc9a.jpg'),
(40039, 2728, 'Três é Demais S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132585.mp4', 'http://timg.bdta.pro/images/8779392e8c152d24c09f03df638c83f1.jpg'),
(40040, 2728, 'Três é Demais S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132586.mp4', 'http://timg.bdta.pro/images/28e3b12a4e8cbf31f3cefe32dba943c4.jpg'),
(40041, 2728, 'Três é Demais S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132587.mp4', 'http://timg.bdta.pro/images/165432b50af9929859f857a64dbe1364.jpg'),
(40042, 2728, 'Três é Demais S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132588.mp4', 'http://timg.bdta.pro/images/b885c4cc63d4ec2f5999b4ec4fe73322.jpg'),
(40043, 2728, 'Três é Demais S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132589.mp4', 'http://timg.bdta.pro/images/28ee537859e1484aa6c0d5d9814a5e42.jpg'),
(40044, 2728, 'Três é Demais S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132590.mp4', 'http://timg.bdta.pro/images/a0bb4385ac56c0ad65cc6c52e7c0813f.jpg'),
(40045, 2728, 'Três é Demais S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132591.mp4', 'http://timg.bdta.pro/images/ec5044637583191607f73ec8486be75d.jpg'),
(40046, 2728, 'Três é Demais S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132592.mp4', 'http://timg.bdta.pro/images/ce9e38bb08e6f7f0a6fb933c1c93016d.jpg'),
(40047, 2728, 'Três é Demais S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132593.mp4', 'http://timg.bdta.pro/images/0e02892cda927a53c8b025ba375c82ca.jpg'),
(40048, 2728, 'Três é Demais S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132594.mp4', 'http://timg.bdta.pro/images/1e5a748a3de555410476165720e53949.jpg'),
(40049, 2728, 'Três é Demais S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132595.mp4', 'http://timg.bdta.pro/images/853d7bb43913dec4fb40279189dbe444.jpg'),
(40050, 2728, 'Três é Demais S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132596.mp4', 'http://timg.bdta.pro/images/21b17bd2675f16aaaec4f9e5dccd0c0d.jpg'),
(40051, 2728, 'Três é Demais S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132597.mp4', 'http://timg.bdta.pro/images/2b71629845972f4d163738ca3a698253.jpg'),
(40052, 2728, 'Três é Demais S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132598.mp4', 'http://timg.bdta.pro/images/6e967c6c84cff53380946ff0a66f376f.jpg'),
(40053, 2728, 'Três é Demais S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132599.mp4', 'http://timg.bdta.pro/images/971ed195b0be94bc43e04d7b456571c4.jpg'),
(40054, 2728, 'Três é Demais S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132600.mp4', 'http://timg.bdta.pro/images/5297ad909e813915bbc65e367a94d2b9.jpg'),
(40055, 2728, 'Três é Demais S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132601.mp4', 'http://timg.bdta.pro/images/69538bb9fa776ac2e58251c6d5218ea7.jpg'),
(40056, 2728, 'Três é Demais S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/132602.mp4', 'http://timg.bdta.pro/images/f5bdd8b39dcddba767d052afcc35ee28.jpg'),
(40057, 2728, 'Três é Demais S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/132603.mp4', 'http://timg.bdta.pro/images/6434b7b83f303759e8ad987d9e78ae78.jpg'),
(40058, 2729, 'Bárbaros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199643.mp4', 'http://timg.bdta.pro/images/81851b04a7d78efbcfb3aa1ff8e31e80.jpg'),
(40059, 2729, 'Bárbaros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199644.mp4', 'http://timg.bdta.pro/images/8c274074c7624a9dcba22b52107a4b9d.jpg'),
(40060, 2729, 'Bárbaros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199645.mp4', 'http://timg.bdta.pro/images/4581c9c7000b7b203143d46b97d67558.jpg'),
(40061, 2729, 'Bárbaros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199646.mp4', 'http://timg.bdta.pro/images/192903e8b0a6619dd46bb97f42953072.jpg'),
(40062, 2729, 'Bárbaros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199647.mp4', 'http://timg.bdta.pro/images/e7c90b6bbcc7d760cb80811a9ee4f08b.jpg'),
(40063, 2729, 'Bárbaros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199648.mp4', 'http://timg.bdta.pro/images/46f3e92dd8aed5d99e8079064a4aeacb.jpg'),
(40064, 2730, 'Bárbaros S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199649.mp4', 'http://timg.bdta.pro/images/94eaae5041cfd6a6da972e89c4d56165.jpg'),
(40065, 2730, 'Bárbaros S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199650.mp4', 'http://timg.bdta.pro/images/b69b2e2d0b9c1be4c82ea31232b50ebf.jpg'),
(40066, 2730, 'Bárbaros S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199651.mp4', 'http://timg.bdta.pro/images/5e2131b0ce8b33fb97779baa0fb0a449.jpg'),
(40067, 2730, 'Bárbaros S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199652.mp4', 'http://timg.bdta.pro/images/546e75ad1e6a13f2658d00b2b38b8794.jpg'),
(40068, 2730, 'Bárbaros S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199653.mp4', 'http://timg.bdta.pro/images/b0e54719f68ad6e59633f9e613c4f63c.jpg'),
(40069, 2730, 'Bárbaros S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199654.mp4', 'http://timg.bdta.pro/images/34a13e0e3ba32ee81db2b6b4d4d4c2c5.jpg'),
(40070, 2731, 'Black Earth Rising S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132404.mp4', 'http://timg.bdta.pro/images/1d39b042395a84130af18ef18f771f87.jpg'),
(40071, 2731, 'Black Earth Rising S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132405.mp4', 'http://timg.bdta.pro/images/8fdbb8159d25eb3354023725df97ef08.jpg'),
(40072, 2731, 'Black Earth Rising S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132406.mp4', 'http://timg.bdta.pro/images/db99494efcc91d8eb668774b0a3d4630.jpg'),
(40073, 2731, 'Black Earth Rising S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132407.mp4', 'http://timg.bdta.pro/images/5c826406f675fd7e84ea228410469355.jpg'),
(40074, 2731, 'Black Earth Rising S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132408.mp4', 'http://timg.bdta.pro/images/23ceee7d75b1c2fe8cdfe31121ebaaa4.jpg'),
(40075, 2731, 'Black Earth Rising S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132409.mp4', 'http://timg.bdta.pro/images/09340b317517f36fe4e887ccc7ce20ae.jpg'),
(40076, 2731, 'Black Earth Rising S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132410.mp4', 'http://timg.bdta.pro/images/6497979ab76369de00b39a1ae9198071.jpg'),
(40077, 2731, 'Black Earth Rising S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132411.mp4', 'http://timg.bdta.pro/images/3b747e89146d1d93ac8fee05892b5317.jpg'),
(40078, 2732, 'Fargo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132374.mp4', 'http://timg.bdta.pro/images/5ccd06a78388334ae59099f0443d26bb.jpg'),
(40079, 2732, 'Fargo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132375.mp4', 'http://timg.bdta.pro/images/c476c91e8da47ab50dca2a65729a7f1e.jpg'),
(40080, 2732, 'Fargo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132376.mp4', 'http://timg.bdta.pro/images/05a58a48e3f8a88af127a2f76e46c301.jpg'),
(40081, 2732, 'Fargo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132377.mp4', 'http://timg.bdta.pro/images/d0f97200c24d2179fd0253a7788c17ab.jpg'),
(40082, 2732, 'Fargo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132378.mp4', 'http://timg.bdta.pro/images/242b1bf4952b60016e210daa5dcecc95.jpg'),
(40083, 2732, 'Fargo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132379.mp4', 'http://timg.bdta.pro/images/ecad92042026912ef6a00a06fcbb319b.jpg'),
(40084, 2732, 'Fargo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132380.mp4', 'http://timg.bdta.pro/images/46b2a19c32444d1ed43d74976fd31667.jpg'),
(40085, 2732, 'Fargo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132381.mp4', 'http://timg.bdta.pro/images/ab37b37b9775cd7668aefde749c8d50a.jpg'),
(40086, 2732, 'Fargo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132382.mp4', 'http://timg.bdta.pro/images/52ee916870fe1d1e7e0d6f2bd2ad71b5.jpg'),
(40087, 2732, 'Fargo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132383.mp4', 'http://timg.bdta.pro/images/d6f2bcf2e21c9081dc6cae9e864b0163.jpg'),
(40088, 2733, 'Fargo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132384.mp4', 'http://timg.bdta.pro/images/5991d42c3c2feaed1a2bf256f400132b.jpg'),
(40089, 2733, 'Fargo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132385.mp4', 'http://timg.bdta.pro/images/9793d3edfd3cf00e576f58e100893ef0.jpg'),
(40090, 2733, 'Fargo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132386.mp4', 'http://timg.bdta.pro/images/8d9a83464e934c2800cc9c6a9a64de17.jpg'),
(40091, 2733, 'Fargo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132387.mp4', 'http://timg.bdta.pro/images/02178391f889680e8950095dc452e341.jpg'),
(40092, 2733, 'Fargo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132388.mp4', 'http://timg.bdta.pro/images/09b0aa576c254e332dc93291d9e15a3c.jpg'),
(40093, 2733, 'Fargo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132389.mp4', 'http://timg.bdta.pro/images/d10bbf9acffd574524655ae2559129cb.jpg'),
(40094, 2733, 'Fargo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132390.mp4', 'http://timg.bdta.pro/images/538a04ce4a51f1ddebefae1fa7e1a9e8.jpg'),
(40095, 2733, 'Fargo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132391.mp4', 'http://timg.bdta.pro/images/b6bcd455e45b5573fa530d8585f7bd77.jpg'),
(40096, 2733, 'Fargo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132392.mp4', 'http://timg.bdta.pro/images/9540a15f70e3d56c201f490737c281b9.jpg'),
(40097, 2733, 'Fargo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132393.mp4', 'http://timg.bdta.pro/images/d9fd98bd11ab8f33d629fe051cb1ebec.jpg'),
(40098, 2734, 'Fargo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132394.mp4', 'http://timg.bdta.pro/images/adfb9e010f672ca5381f6d090ca30f7a.jpg'),
(40099, 2734, 'Fargo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132395.mp4', 'http://timg.bdta.pro/images/331f4d18e81f0f0a5e285035cb2e5351.jpg'),
(40100, 2734, 'Fargo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132396.mp4', 'http://timg.bdta.pro/images/725e16a3d5842adf945131ea93d4459c.jpg'),
(40101, 2734, 'Fargo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132397.mp4', 'http://timg.bdta.pro/images/f51d48e39fefef4b5acefdc2127b5635.jpg'),
(40102, 2734, 'Fargo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132398.mp4', 'http://timg.bdta.pro/images/d3d05d33a2a54a2361f7e72146cffcba.jpg'),
(40103, 2734, 'Fargo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132399.mp4', 'http://timg.bdta.pro/images/17e5ccf386930229a2598b5ed69bed57.jpg'),
(40104, 2734, 'Fargo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132400.mp4', 'http://timg.bdta.pro/images/457387b3f98aa34ec07a1e4fc7e5269d.jpg'),
(40105, 2734, 'Fargo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132401.mp4', 'http://timg.bdta.pro/images/ebca2a40558559243e29706a96e33a93.jpg'),
(40106, 2734, 'Fargo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132402.mp4', 'http://timg.bdta.pro/images/61d2454918ea4f873e6b5bf7297c4fc0.jpg'),
(40107, 2734, 'Fargo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132403.mp4', 'http://timg.bdta.pro/images/9725f6e60836ddd3bbaa7838fa6b34d3.jpg'),
(40108, 2735, 'Fargo S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/422642.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r8uWDma9ewCfxmdrjOMaXlj0PgI.jpg'),
(40109, 2735, 'Fargo S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/422643.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hxszGz7LKuYLtqeBw6Bou2vwDQh.jpg'),
(40110, 2735, 'Fargo S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/422644.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1qeBLvDESzHxftKKRevZyJwdh5z.jpg'),
(40111, 2735, 'Fargo S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/422645.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y619kj6sRWiai4ZPffUI5UVWHed.jpg'),
(40112, 2735, 'Fargo S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/422646.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g1CcPbyrtn9nqOaZqlC3UbZGXoP.jpg'),
(40113, 2735, 'Fargo S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/422647.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8fGw0TfgZx62wSu7k4pqOsXJX5l.jpg'),
(40114, 2735, 'Fargo S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/422648.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tS81pPH1KJJ60Q1wcmKVv9JNsML.jpg'),
(40115, 2735, 'Fargo S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/422649.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xnGU0KnEzzSazhib0Dnnl7rNAxk.jpg'),
(40116, 2735, 'Fargo S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/440633.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mRWvGbDL4IwniAdX19jKmVN3MM5.jpg'),
(40117, 2735, 'Fargo S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/422650.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xybYWE5yWpODggthaJQ2WaLIZFY.jpg'),
(40118, 2735, 'Fargo S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/422651.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tx1WmVqVUioG67PIkhQWTGyJus9.jpg'),
(40119, 2736, 'Fargo S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/432854.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yt9VPxlZLvyNTjMWtzhdqeXwPsH.jpg'),
(40120, 2736, 'Fargo S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/432855.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sjBOWb7hWC34hvwgz2c3wcpFBO2.jpg'),
(40121, 2736, 'Fargo S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/432856.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bqU69n8bJVzX0GMcVNhqsQ5AN8K.jpg'),
(40122, 2736, 'Fargo S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/432857.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fLBHoSzmqv4k4QTXHk74TLcZXCp.jpg'),
(40123, 2736, 'Fargo S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/432858.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7UgJ8TpVQArpUJgdqH9IrKKTBLZ.jpg'),
(40124, 2736, 'Fargo S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/432859.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/stEwG8xjK9LfrwQK8zSwv97xiVG.jpg'),
(40125, 2736, 'Fargo S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/432860.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o9eKNJimo65sMiRJjw9T6VaGKTb.jpg'),
(40126, 2736, 'Fargo S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/432861.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xdcDvCu4fvVyt4qdGBuJKOSjqKb.jpg'),
(40127, 2736, 'Fargo S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/432862.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/In2jufP9Y4j4hpSeR70dCmAlUI.jpg'),
(40128, 2736, 'Fargo S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/432863.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eH29pckIQbdrV9sOAihry4iJypJ.jpg'),
(40129, 2737, 'Malcolm In The Middle [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132333.mp4', 'http://timg.bdta.pro/images/cba7a7a0c662eafb6b5b0be5750e101b.jpg'),
(40130, 2737, 'Malcolm In The Middle [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132334.mp4', 'http://timg.bdta.pro/images/26c4a4ff83220451ff15cef630c6a586.jpg'),
(40131, 2737, 'Malcolm In The Middle [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132335.mp4', 'http://timg.bdta.pro/images/4908d70c7967e6411a807100c2b20579.jpg'),
(40132, 2737, 'Malcolm In The Middle [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132336.mp4', 'http://timg.bdta.pro/images/605498cbf07773e2baf9d5b50d7b917d.jpg'),
(40133, 2737, 'Malcolm In The Middle [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132337.mp4', 'http://timg.bdta.pro/images/b36faf9c995af6a345234037e048461b.jpg'),
(40134, 2737, 'Malcolm In The Middle [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132338.mp4', 'http://timg.bdta.pro/images/0166c4a98eae4477553d019bd5024a4a.jpg'),
(40135, 2737, 'Malcolm In The Middle [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132339.mp4', 'http://timg.bdta.pro/images/a0cca5991de6bf0e974833baeb457dad.jpg'),
(40136, 2737, 'Malcolm In The Middle [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132340.mp4', 'http://timg.bdta.pro/images/1508a9840c7049fc70270031542674ee.jpg'),
(40137, 2737, 'Malcolm In The Middle [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132341.mp4', 'http://timg.bdta.pro/images/2a8daea07787983a4328a431a76b556c.jpg'),
(40138, 2737, 'Malcolm In The Middle [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132342.mp4', 'http://timg.bdta.pro/images/03a6ef0ee998c9a28686b8029f0dac2d.jpg'),
(40139, 2737, 'Malcolm In The Middle [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132343.mp4', 'http://timg.bdta.pro/images/355b8381a14bf9dd7bcc31b82534650c.jpg'),
(40140, 2737, 'Malcolm In The Middle [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132344.mp4', 'http://timg.bdta.pro/images/b1133a01da92e8ea2531d8fe06925437.jpg'),
(40141, 2737, 'Malcolm In The Middle [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132345.mp4', 'http://timg.bdta.pro/images/42b6c57ffbf962cc7439c98217e67b05.jpg'),
(40142, 2737, 'Malcolm In The Middle [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132346.mp4', 'http://timg.bdta.pro/images/499ea7724d98da8e3f8eb3ea50bde6a4.jpg'),
(40143, 2737, 'Malcolm In The Middle [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132347.mp4', 'http://timg.bdta.pro/images/fbe3b900ed000bbe99e940633ccedcfe.jpg'),
(40144, 2737, 'Malcolm In The Middle [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132348.mp4', 'http://timg.bdta.pro/images/6ebc510b2ed8da0b20c60260db7be7e0.jpg'),
(40145, 2738, 'Malcolm In The Middle [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132349.mp4', 'http://timg.bdta.pro/images/7270a49c9d97c184e123cfee03b5a401.jpg'),
(40146, 2738, 'Malcolm In The Middle [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132350.mp4', 'http://timg.bdta.pro/images/8c3b60f4a4b13d67f70657e1684164af.jpg'),
(40147, 2738, 'Malcolm In The Middle [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132351.mp4', 'http://timg.bdta.pro/images/59ab40d879953825e028cc5dd08c5b78.jpg'),
(40148, 2738, 'Malcolm In The Middle [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132352.mp4', 'http://timg.bdta.pro/images/b1e996f8679cf517aeb524565b4b5348.jpg'),
(40149, 2738, 'Malcolm In The Middle [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132353.mp4', 'http://timg.bdta.pro/images/521823e603bd27b7dbd80f2ee64986dc.jpg'),
(40150, 2738, 'Malcolm In The Middle [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132354.mp4', 'http://timg.bdta.pro/images/f5433f089f4889ba52b4297214a5897f.jpg'),
(40151, 2738, 'Malcolm In The Middle [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132355.mp4', 'http://timg.bdta.pro/images/e59833009d865cfc2db4ffd3e6f2f2da.jpg'),
(40152, 2738, 'Malcolm In The Middle [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132356.mp4', 'http://timg.bdta.pro/images/ff68bcfe16b8562c56817351f6f7878d.jpg'),
(40153, 2738, 'Malcolm In The Middle [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132357.mp4', 'http://timg.bdta.pro/images/8203b99ab97a206b71c509a860943c9f.jpg'),
(40154, 2738, 'Malcolm In The Middle [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132358.mp4', 'http://timg.bdta.pro/images/7f7f8264a96e73770a1085fa329ce7b5.jpg'),
(40155, 2738, 'Malcolm In The Middle [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132359.mp4', 'http://timg.bdta.pro/images/5e12e31cdf1273089577b1869a8bcb4d.jpg'),
(40156, 2738, 'Malcolm In The Middle [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132360.mp4', 'http://timg.bdta.pro/images/85776832f18e57445737fd5597749abf.jpg'),
(40157, 2738, 'Malcolm In The Middle [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132361.mp4', 'http://timg.bdta.pro/images/0a10705f49194d9992cd4b5ae0276234.jpg'),
(40158, 2738, 'Malcolm In The Middle [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132362.mp4', 'http://timg.bdta.pro/images/3578d87a4843ef33febcb3e0c9bfdca3.jpg'),
(40159, 2738, 'Malcolm In The Middle [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132363.mp4', 'http://timg.bdta.pro/images/1f9462542f5b63af174a0042151d3b65.jpg'),
(40160, 2738, 'Malcolm In The Middle [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132364.mp4', 'http://timg.bdta.pro/images/1ea81728bf9a9391df00d4f2856d3d70.jpg'),
(40161, 2738, 'Malcolm In The Middle [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132365.mp4', 'http://timg.bdta.pro/images/a56913d1978232c45523b1f3cf85f861.jpg'),
(40162, 2738, 'Malcolm In The Middle [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132366.mp4', 'http://timg.bdta.pro/images/186f4b0865ea609bef3ba04ddbd8947b.jpg'),
(40163, 2738, 'Malcolm In The Middle [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132367.mp4', 'http://timg.bdta.pro/images/b9d1c972b27435cdbdc454b6c77537b7.jpg'),
(40164, 2738, 'Malcolm In The Middle [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132368.mp4', 'http://timg.bdta.pro/images/572ebb01492a6ee07a195d7559c79d4d.jpg'),
(40165, 2738, 'Malcolm In The Middle [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132369.mp4', 'http://timg.bdta.pro/images/7c4487b29f2ddd9578ba65d73436b7db.jpg'),
(40166, 2738, 'Malcolm In The Middle [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132370.mp4', 'http://timg.bdta.pro/images/b0998faa6994a3dbd11dda5d765daed4.jpg'),
(40167, 2738, 'Malcolm In The Middle [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/132371.mp4', 'http://timg.bdta.pro/images/0cc4d5203c218bb929d2f031ab9dc511.jpg'),
(40168, 2738, 'Malcolm In The Middle [L] S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/132372.mp4', 'http://timg.bdta.pro/images/b700a41b09a8cfcba92fdc7b8aeb20d8.jpg'),
(40169, 2738, 'Malcolm In The Middle [L] S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/132373.mp4', 'http://timg.bdta.pro/images/35978134018bf0a1442e98372d45b05e.jpg'),
(40170, 2739, 'Move [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132328.mp4', 'http://gstaticontent.com/images/mhKG2PQWikMb7IkdNhCaR9AHS2f_big.jpg'),
(40171, 2739, 'Move [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132329.mp4', 'http://gstaticontent.com/images/mhKG2PQWikMb7IkdNhCaR9AHS2f_big.jpg'),
(40172, 2739, 'Move [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132330.mp4', 'http://gstaticontent.com/images/mhKG2PQWikMb7IkdNhCaR9AHS2f_big.jpg'),
(40173, 2739, 'Move [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132331.mp4', 'http://gstaticontent.com/images/mhKG2PQWikMb7IkdNhCaR9AHS2f_big.jpg'),
(40174, 2739, 'Move [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132332.mp4', 'http://gstaticontent.com/images/mhKG2PQWikMb7IkdNhCaR9AHS2f_big.jpg'),
(40175, 2740, 'NCIS: Los Angeles S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222431.mp4', 'http://timg.bdta.pro/images/1e170654b7c0a96a74d5fc16d5ddc647.jpg'),
(40176, 2740, 'NCIS: Los Angeles S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222432.mp4', 'http://timg.bdta.pro/images/a974bcc70154305ec114ecebc36d0240.jpg'),
(40177, 2740, 'NCIS: Los Angeles S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222433.mp4', 'http://timg.bdta.pro/images/d8e9d21bee7cfb412a1c048853f6998d.jpg'),
(40178, 2740, 'NCIS: Los Angeles S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222434.mp4', 'http://timg.bdta.pro/images/ea5eea796166ef98aee237295147761d.jpg'),
(40179, 2740, 'NCIS: Los Angeles S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222435.mp4', 'http://timg.bdta.pro/images/1de75d9c863cebf2f56452327766b0df.jpg'),
(40180, 2740, 'NCIS: Los Angeles S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222436.mp4', 'http://timg.bdta.pro/images/e70508b51b713a003c70ff03fca2d128.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(40181, 2740, 'NCIS: Los Angeles S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222437.mp4', 'http://timg.bdta.pro/images/b63159563930cb31c880a2807126a067.jpg'),
(40182, 2740, 'NCIS: Los Angeles S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222438.mp4', 'http://timg.bdta.pro/images/ca400b481836129839f8a66e9d157b20.jpg'),
(40183, 2740, 'NCIS: Los Angeles S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222439.mp4', 'http://timg.bdta.pro/images/c65b702e98cc44d4f06467fd64aa5002.jpg'),
(40184, 2740, 'NCIS: Los Angeles S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222440.mp4', 'http://timg.bdta.pro/images/d12d0b540440b7b4e4a13b57d0383734.jpg'),
(40185, 2740, 'NCIS: Los Angeles S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222441.mp4', 'http://timg.bdta.pro/images/89e461704fe42056407b2511a03a2b4a.jpg'),
(40186, 2740, 'NCIS: Los Angeles S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222442.mp4', 'http://timg.bdta.pro/images/c5356bef04042f4b51bab3664028a329.jpg'),
(40187, 2740, 'NCIS: Los Angeles S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222443.mp4', 'http://timg.bdta.pro/images/9c62cf220e1896bbb4b586507f906900.jpg'),
(40188, 2740, 'NCIS: Los Angeles S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222444.mp4', 'http://timg.bdta.pro/images/73078b5266cfc0127d014b5d5254760f.jpg'),
(40189, 2740, 'NCIS: Los Angeles S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222445.mp4', 'http://timg.bdta.pro/images/0e7788f7cc73134080b4dee2b028cc8c.jpg'),
(40190, 2740, 'NCIS: Los Angeles S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222446.mp4', 'http://timg.bdta.pro/images/5c0a0c51bb8370f96d99d21dd9ab7ad8.jpg'),
(40191, 2740, 'NCIS: Los Angeles S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222447.mp4', 'http://timg.bdta.pro/images/e9d132efdb0a7b2363eb20cb9d542fbf.jpg'),
(40192, 2740, 'NCIS: Los Angeles S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222448.mp4', 'http://timg.bdta.pro/images/35e80e8ec7dd02a08884e12222bb705d.jpg'),
(40193, 2740, 'NCIS: Los Angeles S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222449.mp4', 'http://timg.bdta.pro/images/69fbc1ab8eaf1d2e264ca196bf8aeee4.jpg'),
(40194, 2740, 'NCIS: Los Angeles S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222450.mp4', 'http://timg.bdta.pro/images/9cf2076f12040de81b5ca2ffc69413ac.jpg'),
(40195, 2740, 'NCIS: Los Angeles S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222451.mp4', 'http://timg.bdta.pro/images/47021534538453bb1655466976513180.jpg'),
(40196, 2740, 'NCIS: Los Angeles S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222452.mp4', 'http://timg.bdta.pro/images/f864a5c2d7869ec051e46f42ef1d040b.jpg'),
(40197, 2740, 'NCIS: Los Angeles S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/222453.mp4', 'http://timg.bdta.pro/images/9a30db4d627b7332f9266b396c187fdc.jpg'),
(40198, 2740, 'NCIS: Los Angeles S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/222454.mp4', 'http://timg.bdta.pro/images/3f3c082e1c11250d4bb4beff21bf4e11.jpg'),
(40199, 2741, 'NCIS: Los Angeles S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222455.mp4', 'http://timg.bdta.pro/images/d1d680f5ddc5ecdf30d8bc79bf51413b.jpg'),
(40200, 2741, 'NCIS: Los Angeles S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222456.mp4', 'http://timg.bdta.pro/images/1834bc7d404da0659fdac6919cc3791a.jpg'),
(40201, 2741, 'NCIS: Los Angeles S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222457.mp4', 'http://timg.bdta.pro/images/f02b02ab220759dfe91d41dfd960bf1a.jpg'),
(40202, 2741, 'NCIS: Los Angeles S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222458.mp4', 'http://timg.bdta.pro/images/89cdf119db0ccf45f4a8c56fc8f0b33f.jpg'),
(40203, 2741, 'NCIS: Los Angeles S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222459.mp4', 'http://timg.bdta.pro/images/9ce96426986dcd88b2bc26398554be50.jpg'),
(40204, 2741, 'NCIS: Los Angeles S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222460.mp4', 'http://timg.bdta.pro/images/5c36580f3a46efde0abadcd27af8322d.jpg'),
(40205, 2741, 'NCIS: Los Angeles S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222461.mp4', 'http://timg.bdta.pro/images/1e2645d1ffc66c8e0e63f7d4373df140.jpg'),
(40206, 2741, 'NCIS: Los Angeles S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222462.mp4', 'http://timg.bdta.pro/images/e761074ff5f40cc21a13d9e15b20c01d.jpg'),
(40207, 2741, 'NCIS: Los Angeles S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222463.mp4', 'http://timg.bdta.pro/images/280d164ec84c8284454267b139f8a646.jpg'),
(40208, 2741, 'NCIS: Los Angeles S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222464.mp4', 'http://timg.bdta.pro/images/80c0f74f653d988f38ca246e526c6943.jpg'),
(40209, 2741, 'NCIS: Los Angeles S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222465.mp4', 'http://timg.bdta.pro/images/32c14c00d9eb16580d9ff95a1395a9d9.jpg'),
(40210, 2741, 'NCIS: Los Angeles S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222466.mp4', 'http://timg.bdta.pro/images/49b87d307aa124a820994a52742756b5.jpg'),
(40211, 2741, 'NCIS: Los Angeles S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222467.mp4', 'http://timg.bdta.pro/images/15cb6050ceb93ce89c2eb8c9a310facd.jpg'),
(40212, 2741, 'NCIS: Los Angeles S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222468.mp4', 'http://timg.bdta.pro/images/3572791c8542c7788dd7e5827c7493b1.jpg'),
(40213, 2741, 'NCIS: Los Angeles S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222469.mp4', 'http://timg.bdta.pro/images/823a5cb822e3f747f7e595cd1a926b72.jpg'),
(40214, 2741, 'NCIS: Los Angeles S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222470.mp4', 'http://timg.bdta.pro/images/1e4877a287d5ed581ab1ec6b1fd1bbf2.jpg'),
(40215, 2741, 'NCIS: Los Angeles S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222471.mp4', 'http://timg.bdta.pro/images/f33e818399c3e6f52ba85d1eb704ccac.jpg'),
(40216, 2741, 'NCIS: Los Angeles S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222472.mp4', 'http://timg.bdta.pro/images/e269b77a9d1fda82275bc982fb5466bf.jpg'),
(40217, 2741, 'NCIS: Los Angeles S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222473.mp4', 'http://timg.bdta.pro/images/5baab60b0176dc4d8c6d289becbb9312.jpg'),
(40218, 2741, 'NCIS: Los Angeles S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222474.mp4', 'http://timg.bdta.pro/images/998ec267c4aab4fb5f109586e2c6b10a.jpg'),
(40219, 2741, 'NCIS: Los Angeles S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222475.mp4', 'http://timg.bdta.pro/images/5b2f0994c44f4e06046d4747b0f17b93.jpg'),
(40220, 2741, 'NCIS: Los Angeles S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222476.mp4', 'http://timg.bdta.pro/images/dab0dfcda2ae0106e3849541c62d8f4b.jpg'),
(40221, 2741, 'NCIS: Los Angeles S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/222477.mp4', 'http://timg.bdta.pro/images/e8a254c7cf6b2874810a8fe681ddd7fd.jpg'),
(40222, 2741, 'NCIS: Los Angeles S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/222478.mp4', 'http://timg.bdta.pro/images/1cdc9000a4205e4c009cf72da339391f.jpg'),
(40223, 2742, 'NCIS: Los Angeles S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222479.mp4', 'http://timg.bdta.pro/images/ab9d4ecbdde5cb9df46007270eae9955.jpg'),
(40224, 2742, 'NCIS: Los Angeles S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222480.mp4', 'http://timg.bdta.pro/images/1a37002cb5c90fc5fd4a46fd334eeffa.jpg'),
(40225, 2742, 'NCIS: Los Angeles S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222481.mp4', 'http://timg.bdta.pro/images/cb40dc09cd4dedad9c1a267c18179d3f.jpg'),
(40226, 2742, 'NCIS: Los Angeles S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222482.mp4', 'http://timg.bdta.pro/images/8c7efdd0c40336b65fce281e1467fdf5.jpg'),
(40227, 2742, 'NCIS: Los Angeles S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222483.mp4', 'http://timg.bdta.pro/images/8ad0d3ec17e975d04564b28cf7f909c3.jpg'),
(40228, 2742, 'NCIS: Los Angeles S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222484.mp4', 'http://timg.bdta.pro/images/180198156c7123212ecccc405f42d1fe.jpg'),
(40229, 2742, 'NCIS: Los Angeles S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222485.mp4', 'http://timg.bdta.pro/images/894fb892fa4b6297369bd9696e161cb1.jpg'),
(40230, 2742, 'NCIS: Los Angeles S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222486.mp4', 'http://timg.bdta.pro/images/ee0811d32dc97b979248a370b4dc7d23.jpg'),
(40231, 2742, 'NCIS: Los Angeles S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222487.mp4', 'http://timg.bdta.pro/images/171d58a3c4bdacc9046b9f5ca9b09886.jpg'),
(40232, 2742, 'NCIS: Los Angeles S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222488.mp4', 'http://timg.bdta.pro/images/e5555f1ad49c10df0afda50f7df0c78a.jpg'),
(40233, 2742, 'NCIS: Los Angeles S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222489.mp4', 'http://timg.bdta.pro/images/6dcb14d0b0320f328eb30ff5c5be8edc.jpg'),
(40234, 2742, 'NCIS: Los Angeles S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222490.mp4', 'http://timg.bdta.pro/images/8798543ca5d7eeb70d0543b0a5a36838.jpg'),
(40235, 2742, 'NCIS: Los Angeles S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222491.mp4', 'http://timg.bdta.pro/images/7bf9ca466c1908094370f17a0bab6aaa.jpg'),
(40236, 2742, 'NCIS: Los Angeles S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222492.mp4', 'http://timg.bdta.pro/images/026a77b6982e8d6b2a85b8b1823342ca.jpg'),
(40237, 2742, 'NCIS: Los Angeles S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222493.mp4', 'http://timg.bdta.pro/images/c0a6b400c68169b752faf40a399c402c.jpg'),
(40238, 2742, 'NCIS: Los Angeles S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222494.mp4', 'http://timg.bdta.pro/images/4c69cb93fbe99c73a80c10e413df061b.jpg'),
(40239, 2742, 'NCIS: Los Angeles S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222495.mp4', 'http://timg.bdta.pro/images/b5f963576d66ddab6bfd4aba8d18b637.jpg'),
(40240, 2742, 'NCIS: Los Angeles S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222496.mp4', 'http://timg.bdta.pro/images/51d8e62bb075da704f23d6ef51eca93f.jpg'),
(40241, 2742, 'NCIS: Los Angeles S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222497.mp4', 'http://timg.bdta.pro/images/977d481ef10efb28eb44e8850bc860d9.jpg'),
(40242, 2742, 'NCIS: Los Angeles S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222498.mp4', 'http://timg.bdta.pro/images/ebeeb40e10245100fb2f569fc22aa61d.jpg'),
(40243, 2742, 'NCIS: Los Angeles S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222499.mp4', 'http://timg.bdta.pro/images/7f5c596bb600328dada068146fb42868.jpg'),
(40244, 2742, 'NCIS: Los Angeles S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222500.mp4', 'http://timg.bdta.pro/images/799f11518f52032a86f91ed53d50cf53.jpg'),
(40245, 2742, 'NCIS: Los Angeles S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/222501.mp4', 'http://timg.bdta.pro/images/06da124bda75a2959f00bd3a238c0fab.jpg'),
(40246, 2742, 'NCIS: Los Angeles S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/222502.mp4', 'http://timg.bdta.pro/images/cd1e86a439834e84d16697eedda05a24.jpg'),
(40247, 2743, 'NCIS: Los Angeles S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222503.mp4', 'http://timg.bdta.pro/images/8a36d9662d03e43ffdd5c24411afb245.jpg'),
(40248, 2743, 'NCIS: Los Angeles S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222504.mp4', 'http://timg.bdta.pro/images/ec3fa20ca9f0c50c1d8debab896f1a85.jpg'),
(40249, 2743, 'NCIS: Los Angeles S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222505.mp4', 'http://timg.bdta.pro/images/e728ce8f4cb64c2c860240562b983237.jpg'),
(40250, 2743, 'NCIS: Los Angeles S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222506.mp4', 'http://timg.bdta.pro/images/6adde60213b91262c501fb4a2ec612c2.jpg'),
(40251, 2743, 'NCIS: Los Angeles S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222507.mp4', 'http://timg.bdta.pro/images/8030b6a9a4a9e3077cd59c578b43a77a.jpg'),
(40252, 2743, 'NCIS: Los Angeles S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222508.mp4', 'http://timg.bdta.pro/images/6e8e3551165f7339ed529efe0f240492.jpg'),
(40253, 2743, 'NCIS: Los Angeles S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222509.mp4', 'http://timg.bdta.pro/images/9716fec0a63fe9e8b0de57a9c6c8ea10.jpg'),
(40254, 2743, 'NCIS: Los Angeles S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222510.mp4', 'http://timg.bdta.pro/images/b9a3391b3972d212e37495ad91ba7b35.jpg'),
(40255, 2743, 'NCIS: Los Angeles S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222511.mp4', 'http://timg.bdta.pro/images/f23f7b8cff959dd8eaac0990294c80bd.jpg'),
(40256, 2743, 'NCIS: Los Angeles S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222512.mp4', 'http://timg.bdta.pro/images/cd43d515de420d4fbb958fac62e27048.jpg'),
(40257, 2743, 'NCIS: Los Angeles S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222513.mp4', 'http://timg.bdta.pro/images/a8c498911a6aa88462d4898a4ec0ad03.jpg'),
(40258, 2743, 'NCIS: Los Angeles S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222514.mp4', 'http://timg.bdta.pro/images/7e32c873c7f322f6ad306de2096c0540.jpg'),
(40259, 2743, 'NCIS: Los Angeles S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222515.mp4', 'http://timg.bdta.pro/images/49c7fb77d8edb6813031e313e66e9660.jpg'),
(40260, 2743, 'NCIS: Los Angeles S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222516.mp4', 'http://timg.bdta.pro/images/ee99dcbd87d700f69b5150be4e2afcdd.jpg'),
(40261, 2743, 'NCIS: Los Angeles S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222517.mp4', 'http://timg.bdta.pro/images/a0da65e445e56e8063e8e287a9716eb5.jpg'),
(40262, 2743, 'NCIS: Los Angeles S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222518.mp4', 'http://timg.bdta.pro/images/23788029505cfbd46f9b5679a65afdba.jpg'),
(40263, 2743, 'NCIS: Los Angeles S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222519.mp4', 'http://timg.bdta.pro/images/9cf374a84a69ac3339cfea36445c5411.jpg'),
(40264, 2743, 'NCIS: Los Angeles S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222520.mp4', 'http://timg.bdta.pro/images/2b822a40e8069aa1b086b8150e2fa29f.jpg'),
(40265, 2743, 'NCIS: Los Angeles S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222521.mp4', 'http://timg.bdta.pro/images/9669d5ec46c2b92a4c5cb57adc280a35.jpg'),
(40266, 2743, 'NCIS: Los Angeles S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222522.mp4', 'http://timg.bdta.pro/images/3e5ae836a0c6c05c7ecf5bbf34cd431d.jpg'),
(40267, 2743, 'NCIS: Los Angeles S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222523.mp4', 'http://timg.bdta.pro/images/8ea8bbf0bf7a5f4d0c20c201ad8cc4bb.jpg'),
(40268, 2743, 'NCIS: Los Angeles S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222524.mp4', 'http://timg.bdta.pro/images/8aec0ec1335be2d439388444fefcae5b.jpg'),
(40269, 2743, 'NCIS: Los Angeles S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/222525.mp4', 'http://timg.bdta.pro/images/d513c7f0ef2e97a4b4be05a60878a116.jpg'),
(40270, 2743, 'NCIS: Los Angeles S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/222526.mp4', 'http://timg.bdta.pro/images/b03f78d53b39fbc9981e6b5424b2e2a1.jpg'),
(40271, 2744, 'NCIS: Los Angeles S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222527.mp4', 'http://timg.bdta.pro/images/eb949a435926f68cd5417b161bcda632.jpg'),
(40272, 2744, 'NCIS: Los Angeles S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222528.mp4', 'http://timg.bdta.pro/images/4668c5864a669112d75793fe803ad00f.jpg'),
(40273, 2744, 'NCIS: Los Angeles S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222529.mp4', 'http://timg.bdta.pro/images/cfc7ca6aeae771ae2ca0050aae7b3cb8.jpg'),
(40274, 2744, 'NCIS: Los Angeles S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222530.mp4', 'http://timg.bdta.pro/images/543d0dd5fc0002163e95a3a2e9519eac.jpg'),
(40275, 2744, 'NCIS: Los Angeles S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222531.mp4', 'http://timg.bdta.pro/images/22b110109e3b50f2805319a5a01db302.jpg'),
(40276, 2744, 'NCIS: Los Angeles S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222532.mp4', 'http://timg.bdta.pro/images/f2d0603fd8194349b0a1f3f404482ef5.jpg'),
(40277, 2744, 'NCIS: Los Angeles S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222533.mp4', 'http://timg.bdta.pro/images/5319a8b39daacd339905cb54a47dbea7.jpg'),
(40278, 2744, 'NCIS: Los Angeles S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222534.mp4', 'http://timg.bdta.pro/images/bc799cde928b83a04c53abdf0b1ff044.jpg'),
(40279, 2744, 'NCIS: Los Angeles S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222535.mp4', 'http://timg.bdta.pro/images/3ebc44c8fe059d2261206a5af5899269.jpg'),
(40280, 2744, 'NCIS: Los Angeles S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222536.mp4', 'http://timg.bdta.pro/images/d783575f3e1734650295098e8202213e.jpg'),
(40281, 2744, 'NCIS: Los Angeles S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222537.mp4', 'http://timg.bdta.pro/images/d783575f3e1734650295098e8202213e.jpg'),
(40282, 2744, 'NCIS: Los Angeles S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222538.mp4', 'http://timg.bdta.pro/images/d783575f3e1734650295098e8202213e.jpg'),
(40283, 2744, 'NCIS: Los Angeles S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222539.mp4', 'http://timg.bdta.pro/images/d783575f3e1734650295098e8202213e.jpg'),
(40284, 2744, 'NCIS: Los Angeles S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222540.mp4', 'http://timg.bdta.pro/images/d783575f3e1734650295098e8202213e.jpg'),
(40285, 2744, 'NCIS: Los Angeles S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222541.mp4', 'http://timg.bdta.pro/images/d783575f3e1734650295098e8202213e.jpg'),
(40286, 2744, 'NCIS: Los Angeles S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222542.mp4', 'http://timg.bdta.pro/images/d783575f3e1734650295098e8202213e.jpg'),
(40287, 2744, 'NCIS: Los Angeles S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222543.mp4', 'http://timg.bdta.pro/images/d783575f3e1734650295098e8202213e.jpg'),
(40288, 2744, 'NCIS: Los Angeles S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222544.mp4', 'http://timg.bdta.pro/images/d783575f3e1734650295098e8202213e.jpg'),
(40289, 2744, 'NCIS: Los Angeles S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222545.mp4', 'http://timg.bdta.pro/images/d783575f3e1734650295098e8202213e.jpg'),
(40290, 2744, 'NCIS: Los Angeles S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222546.mp4', 'http://timg.bdta.pro/images/d783575f3e1734650295098e8202213e.jpg'),
(40291, 2744, 'NCIS: Los Angeles S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222547.mp4', 'http://timg.bdta.pro/images/d783575f3e1734650295098e8202213e.jpg'),
(40292, 2744, 'NCIS: Los Angeles S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222548.mp4', 'http://timg.bdta.pro/images/d783575f3e1734650295098e8202213e.jpg'),
(40293, 2744, 'NCIS: Los Angeles S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/222549.mp4', 'http://timg.bdta.pro/images/d783575f3e1734650295098e8202213e.jpg'),
(40294, 2744, 'NCIS: Los Angeles S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/222550.mp4', 'http://timg.bdta.pro/images/d783575f3e1734650295098e8202213e.jpg'),
(40295, 2745, 'NCIS: Los Angeles S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222551.mp4', 'http://timg.bdta.pro/images/582ca8979e955158eacd1c2b96b9e83b.jpg'),
(40296, 2745, 'NCIS: Los Angeles S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222552.mp4', 'http://timg.bdta.pro/images/60601ceb698a57b427f13af10c397b67.jpg'),
(40297, 2745, 'NCIS: Los Angeles S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222553.mp4', 'http://timg.bdta.pro/images/70fe94e635e669d4a23720e685fff57f.jpg'),
(40298, 2745, 'NCIS: Los Angeles S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222554.mp4', 'http://timg.bdta.pro/images/0365d63f5772fd13521c312233370472.jpg'),
(40299, 2745, 'NCIS: Los Angeles S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222555.mp4', 'http://timg.bdta.pro/images/ac59fdfa378d61d8d4eac071c9c72204.jpg'),
(40300, 2745, 'NCIS: Los Angeles S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222556.mp4', 'http://timg.bdta.pro/images/eecdeefdfece96f46fd2901d39de39b0.jpg'),
(40301, 2745, 'NCIS: Los Angeles S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222557.mp4', 'http://timg.bdta.pro/images/71671c6f3c7564b0ee96dd4ef323cc27.jpg'),
(40302, 2745, 'NCIS: Los Angeles S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222558.mp4', 'http://timg.bdta.pro/images/86405da7940ec3d13f8aad2391c8e2f6.jpg'),
(40303, 2745, 'NCIS: Los Angeles S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222559.mp4', 'http://timg.bdta.pro/images/36ba721ef19a2fa04d313a33be0938bf.jpg'),
(40304, 2745, 'NCIS: Los Angeles S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222560.mp4', 'http://timg.bdta.pro/images/4c08c20170d80340fb8fe1f8b79b0f76.jpg'),
(40305, 2745, 'NCIS: Los Angeles S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222561.mp4', 'http://timg.bdta.pro/images/3fb6145db1e432eeadca438ae18c5833.jpg'),
(40306, 2745, 'NCIS: Los Angeles S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222562.mp4', 'http://timg.bdta.pro/images/2c31d5aa873b6eff1b8995102d4cc55e.jpg'),
(40307, 2745, 'NCIS: Los Angeles S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222563.mp4', 'http://timg.bdta.pro/images/55b53a4ed92fc1c558568757e82ac2a1.jpg'),
(40308, 2745, 'NCIS: Los Angeles S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222564.mp4', 'http://timg.bdta.pro/images/91f8f1cddb53cef23de4c19165a057dc.jpg'),
(40309, 2745, 'NCIS: Los Angeles S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222565.mp4', 'http://timg.bdta.pro/images/88ce43e112c5ed0e719b4ce93b0367f5.jpg'),
(40310, 2745, 'NCIS: Los Angeles S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222566.mp4', 'http://timg.bdta.pro/images/8d1252668f3eea65f2c5e7699b33c059.jpg'),
(40311, 2745, 'NCIS: Los Angeles S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222567.mp4', 'http://timg.bdta.pro/images/57d43f8a2cea984d70e1fcb97a741bd4.jpg'),
(40312, 2745, 'NCIS: Los Angeles S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222568.mp4', 'http://timg.bdta.pro/images/013901b0f7ffa65851382979d544c807.jpg'),
(40313, 2745, 'NCIS: Los Angeles S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222569.mp4', 'http://timg.bdta.pro/images/a1638c1265b0f8f4f680621f6b10115e.jpg'),
(40314, 2745, 'NCIS: Los Angeles S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222570.mp4', 'http://timg.bdta.pro/images/7bb62b99b47ff4b19fe9597b32c0a93c.jpg'),
(40315, 2745, 'NCIS: Los Angeles S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222571.mp4', 'http://timg.bdta.pro/images/cf1c3f7ad1355c6ea11e6589f4162852.jpg'),
(40316, 2745, 'NCIS: Los Angeles S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222572.mp4', 'http://timg.bdta.pro/images/3799b6f0948f93aa893f80fd147ab99c.jpg'),
(40317, 2745, 'NCIS: Los Angeles S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/222573.mp4', 'http://timg.bdta.pro/images/1e561c35b504afecf6ebcd3e2c82a9c2.jpg'),
(40318, 2745, 'NCIS: Los Angeles S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/222574.mp4', 'http://timg.bdta.pro/images/8509b0af6122301c5332fadedb79be99.jpg'),
(40319, 2746, 'NCIS: Los Angeles S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222575.mp4', 'http://timg.bdta.pro/images/bbed3142f271ac4fa9f4d57482ecc5f7.jpg'),
(40320, 2746, 'NCIS: Los Angeles S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222576.mp4', 'http://timg.bdta.pro/images/4d31c0a8d7b5ff17c77c49498eadb9d9.jpg'),
(40321, 2746, 'NCIS: Los Angeles S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222577.mp4', 'http://timg.bdta.pro/images/972c06bfd6b5201509fb9f50bee397a6.jpg'),
(40322, 2746, 'NCIS: Los Angeles S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222578.mp4', 'http://timg.bdta.pro/images/ceed2e85f8047aeed53dc67ce5987d9d.jpg'),
(40323, 2746, 'NCIS: Los Angeles S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222579.mp4', 'http://timg.bdta.pro/images/c35d21bceb4c8e3ce6f6b84b804d0c61.jpg'),
(40324, 2746, 'NCIS: Los Angeles S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222580.mp4', 'http://timg.bdta.pro/images/a889bb363517858e1b7e8d69c13bd356.jpg'),
(40325, 2746, 'NCIS: Los Angeles S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222581.mp4', 'http://timg.bdta.pro/images/cd2acf2e42963fa6667532b90e5e0a1e.jpg'),
(40326, 2746, 'NCIS: Los Angeles S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222582.mp4', 'http://timg.bdta.pro/images/dac887cac488f82697c4052535c2ec9e.jpg'),
(40327, 2746, 'NCIS: Los Angeles S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222583.mp4', 'http://timg.bdta.pro/images/6af7c2f0a03d1a77fd0bf9eb53b05100.jpg'),
(40328, 2746, 'NCIS: Los Angeles S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222584.mp4', 'http://timg.bdta.pro/images/77eb2a15b93efee0c534c4599e49bfdc.jpg'),
(40329, 2746, 'NCIS: Los Angeles S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222585.mp4', 'http://timg.bdta.pro/images/a9a54f5079549d6851afd351d300f746.jpg'),
(40330, 2746, 'NCIS: Los Angeles S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222586.mp4', 'http://timg.bdta.pro/images/362ee286765afdc552a9c30b445e4fd1.jpg'),
(40331, 2746, 'NCIS: Los Angeles S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222587.mp4', 'http://timg.bdta.pro/images/6a74010ef001339c0fd7fd79fb7159cf.jpg'),
(40332, 2746, 'NCIS: Los Angeles S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222588.mp4', 'http://timg.bdta.pro/images/6723f63878f5135da87be40d75885343.jpg'),
(40333, 2746, 'NCIS: Los Angeles S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222589.mp4', 'http://timg.bdta.pro/images/30dcc7e869742f94710c8bf0afc10c21.jpg'),
(40334, 2746, 'NCIS: Los Angeles S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222590.mp4', 'http://timg.bdta.pro/images/5686e6fda6914ae456560dff9b9bc330.jpg'),
(40335, 2746, 'NCIS: Los Angeles S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222591.mp4', 'http://timg.bdta.pro/images/7c6ce22039aabd9b2252f9705c362b4a.jpg'),
(40336, 2746, 'NCIS: Los Angeles S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222592.mp4', 'http://timg.bdta.pro/images/ee6a70fc28833928ba1bbc3480a59f5a.jpg'),
(40337, 2746, 'NCIS: Los Angeles S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222593.mp4', 'http://timg.bdta.pro/images/02275d8ea764b02f0651ac473cc16e7b.jpg'),
(40338, 2746, 'NCIS: Los Angeles S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222594.mp4', 'http://timg.bdta.pro/images/133ecc9c5574fd3959d58d8cba0ddbe2.jpg'),
(40339, 2746, 'NCIS: Los Angeles S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222595.mp4', 'http://timg.bdta.pro/images/f49abaa4e996e88ed8c4255ed6870ae8.jpg'),
(40340, 2746, 'NCIS: Los Angeles S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222596.mp4', 'http://timg.bdta.pro/images/f60e79a573a9b7675b20eac33ab606e8.jpg'),
(40341, 2746, 'NCIS: Los Angeles S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/222597.mp4', 'http://timg.bdta.pro/images/3787951cbbe62b35b8e41f635d8af2c3.jpg'),
(40342, 2746, 'NCIS: Los Angeles S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/222598.mp4', 'http://timg.bdta.pro/images/ddeb50a123da33e1195a8a3c37759e91.jpg'),
(40343, 2747, 'NCIS: Los Angeles S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222599.mp4', 'http://timg.bdta.pro/images/c11725926382064c8ae977d084acf210.jpg'),
(40344, 2747, 'NCIS: Los Angeles S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222600.mp4', 'http://timg.bdta.pro/images/38f0bf05673d55af9cd6133d053853ff.jpg'),
(40345, 2747, 'NCIS: Los Angeles S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222601.mp4', 'http://timg.bdta.pro/images/10a1c04ade81191bc21c96975d0bfa8d.jpg'),
(40346, 2747, 'NCIS: Los Angeles S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222602.mp4', 'http://timg.bdta.pro/images/976bf45f15e738034e1b127fc7c36164.jpg'),
(40347, 2747, 'NCIS: Los Angeles S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222603.mp4', 'http://timg.bdta.pro/images/1662566f3e674a1f18e32d2fa42e8c00.jpg'),
(40348, 2747, 'NCIS: Los Angeles S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222604.mp4', 'http://timg.bdta.pro/images/383ec1232480ab25662d560793efd942.jpg'),
(40349, 2747, 'NCIS: Los Angeles S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222605.mp4', 'http://timg.bdta.pro/images/0a2ee37becff40df4ca824a5ea878e07.jpg'),
(40350, 2747, 'NCIS: Los Angeles S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222606.mp4', 'http://timg.bdta.pro/images/a556ed7d409e1e1af71d47c604ef0ced.jpg'),
(40351, 2747, 'NCIS: Los Angeles S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222607.mp4', 'http://timg.bdta.pro/images/38e680effc9d43c8be78f52bd14c49b5.jpg'),
(40352, 2747, 'NCIS: Los Angeles S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222608.mp4', 'http://timg.bdta.pro/images/0473323a9c4b62d18ef83c0ad17cd860.jpg'),
(40353, 2747, 'NCIS: Los Angeles S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222609.mp4', 'http://timg.bdta.pro/images/849f2d25408f258440b28eff4e2f64d4.jpg'),
(40354, 2747, 'NCIS: Los Angeles S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222610.mp4', 'http://timg.bdta.pro/images/dea420c92f4d3e76abd667a75c9d6ec3.jpg'),
(40355, 2747, 'NCIS: Los Angeles S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222611.mp4', 'http://timg.bdta.pro/images/08380b64395415359e1c8fc118b93576.jpg'),
(40356, 2747, 'NCIS: Los Angeles S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222612.mp4', 'http://timg.bdta.pro/images/fe7cf6488aadb5f36031ff97c826e456.jpg'),
(40357, 2747, 'NCIS: Los Angeles S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222613.mp4', 'http://timg.bdta.pro/images/04e4544840b8ec21aa445e2c7ac5b346.jpg'),
(40358, 2747, 'NCIS: Los Angeles S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222614.mp4', 'http://timg.bdta.pro/images/c907745f8ac6cc9e79834f26a78534fd.jpg'),
(40359, 2747, 'NCIS: Los Angeles S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222615.mp4', 'http://timg.bdta.pro/images/0c6cd45bd34665cd7523a5611b2f54a8.jpg'),
(40360, 2747, 'NCIS: Los Angeles S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222616.mp4', 'http://timg.bdta.pro/images/890861593835c0deb3a5935c7ccc3542.jpg'),
(40361, 2747, 'NCIS: Los Angeles S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222617.mp4', 'http://timg.bdta.pro/images/acef7687192488f5a9e00554c565f5c7.jpg'),
(40362, 2747, 'NCIS: Los Angeles S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222618.mp4', 'http://timg.bdta.pro/images/acef7687192488f5a9e00554c565f5c7.jpg'),
(40363, 2747, 'NCIS: Los Angeles S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222619.mp4', 'http://timg.bdta.pro/images/acef7687192488f5a9e00554c565f5c7.jpg'),
(40364, 2747, 'NCIS: Los Angeles S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222620.mp4', 'http://timg.bdta.pro/images/acef7687192488f5a9e00554c565f5c7.jpg'),
(40365, 2747, 'NCIS: Los Angeles S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/222621.mp4', 'http://timg.bdta.pro/images/acef7687192488f5a9e00554c565f5c7.jpg'),
(40366, 2748, 'NCIS: Los Angeles S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222622.mp4', 'http://timg.bdta.pro/images/3a510e74938a2c97e12112f3a70bbb2b.jpg'),
(40367, 2748, 'NCIS: Los Angeles S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222623.mp4', 'http://timg.bdta.pro/images/a1eebb4566922a03006be7eeb71e62b4.jpg'),
(40368, 2748, 'NCIS: Los Angeles S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222624.mp4', 'http://timg.bdta.pro/images/ae503aff2610624801018640a7fdb181.jpg'),
(40369, 2748, 'NCIS: Los Angeles S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222625.mp4', 'http://timg.bdta.pro/images/09a5abccbb579f2900e8a123b2f99c6a.jpg'),
(40370, 2748, 'NCIS: Los Angeles S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222626.mp4', 'http://timg.bdta.pro/images/1e09e8de222dbe061ee0415eeb622b87.jpg'),
(40371, 2748, 'NCIS: Los Angeles S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222627.mp4', 'http://timg.bdta.pro/images/839880dbb0149990c181f03bc36545b5.jpg'),
(40372, 2748, 'NCIS: Los Angeles S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222628.mp4', 'http://timg.bdta.pro/images/e1b1e129c1309262c28fb3b65a1c9a4a.jpg'),
(40373, 2748, 'NCIS: Los Angeles S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222629.mp4', 'http://timg.bdta.pro/images/74b46a144a936f85e9cd3543fae883e9.jpg'),
(40374, 2748, 'NCIS: Los Angeles S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222630.mp4', 'http://timg.bdta.pro/images/a763de9c87e07ddb436e4d3a39a660c1.jpg'),
(40375, 2748, 'NCIS: Los Angeles S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222631.mp4', 'http://timg.bdta.pro/images/e48a7a29416b24a4f8b55b5f18ddc47f.jpg'),
(40376, 2748, 'NCIS: Los Angeles S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222632.mp4', 'http://timg.bdta.pro/images/35cd2cb7df3ecc997a40a4455b78412a.jpg'),
(40377, 2748, 'NCIS: Los Angeles S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222633.mp4', 'http://timg.bdta.pro/images/ea5e40ed7a49d85a8c8005c1c66c9eba.jpg'),
(40378, 2748, 'NCIS: Los Angeles S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222634.mp4', 'http://timg.bdta.pro/images/a69086b4d6ec2251a356df0ae033ee22.jpg'),
(40379, 2748, 'NCIS: Los Angeles S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222635.mp4', 'http://timg.bdta.pro/images/42d7773e7b33c5bfa0f2b187de79be71.jpg'),
(40380, 2748, 'NCIS: Los Angeles S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222636.mp4', 'http://timg.bdta.pro/images/005e0587a8f207ddaa29a13979d3092b.jpg'),
(40381, 2748, 'NCIS: Los Angeles S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222637.mp4', 'http://timg.bdta.pro/images/65433711a95bd7db9b1277f530f50c25.jpg'),
(40382, 2748, 'NCIS: Los Angeles S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222638.mp4', 'http://timg.bdta.pro/images/e7c160b1367e4b8490040283dfc3119d.jpg'),
(40383, 2748, 'NCIS: Los Angeles S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222639.mp4', 'http://timg.bdta.pro/images/5cf720eca5c89d47d435fe982e007e7d.jpg'),
(40384, 2748, 'NCIS: Los Angeles S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222640.mp4', 'http://timg.bdta.pro/images/5cf720eca5c89d47d435fe982e007e7d.jpg'),
(40385, 2748, 'NCIS: Los Angeles S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222641.mp4', 'http://timg.bdta.pro/images/5cf720eca5c89d47d435fe982e007e7d.jpg'),
(40386, 2748, 'NCIS: Los Angeles S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222642.mp4', 'http://timg.bdta.pro/images/5cf720eca5c89d47d435fe982e007e7d.jpg'),
(40387, 2748, 'NCIS: Los Angeles S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222643.mp4', 'http://timg.bdta.pro/images/5cf720eca5c89d47d435fe982e007e7d.jpg'),
(40388, 2748, 'NCIS: Los Angeles S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/222644.mp4', 'http://timg.bdta.pro/images/5cf720eca5c89d47d435fe982e007e7d.jpg'),
(40389, 2749, 'NCIS: Los Angeles S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222645.mp4', 'http://timg.bdta.pro/images/1bf9af28da7f9381ce40d0dae9f7aa2c.jpg'),
(40390, 2749, 'NCIS: Los Angeles S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222646.mp4', 'http://timg.bdta.pro/images/0c9206858fd672600c99c7cc52a00dfc.jpg'),
(40391, 2749, 'NCIS: Los Angeles S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222647.mp4', 'http://timg.bdta.pro/images/9e7605b6889e8797a14970a3a970f350.jpg'),
(40392, 2749, 'NCIS: Los Angeles S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222648.mp4', 'http://timg.bdta.pro/images/b1f5c2823ec6d40397d266c1d28cd269.jpg'),
(40393, 2749, 'NCIS: Los Angeles S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222649.mp4', 'http://timg.bdta.pro/images/84857fb22ef30222d8378b43503c856c.jpg'),
(40394, 2749, 'NCIS: Los Angeles S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222650.mp4', 'http://timg.bdta.pro/images/eba824a4a4c93e2326e641053e36d83a.jpg'),
(40395, 2749, 'NCIS: Los Angeles S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222651.mp4', 'http://timg.bdta.pro/images/0a33ffe7eabda88fc01234bced6c959b.jpg'),
(40396, 2749, 'NCIS: Los Angeles S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222652.mp4', 'http://timg.bdta.pro/images/facf43b07890b64adae7ad13ba34ab24.jpg'),
(40397, 2749, 'NCIS: Los Angeles S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222653.mp4', 'http://timg.bdta.pro/images/b125b130ea6c76a6fb080a18ac8a62e1.jpg'),
(40398, 2749, 'NCIS: Los Angeles S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222654.mp4', 'http://timg.bdta.pro/images/3c48ad237b4cf8299e8387b680132c50.jpg'),
(40399, 2749, 'NCIS: Los Angeles S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222655.mp4', 'http://timg.bdta.pro/images/9c56d280e9ee4776dbce359a7b5f8ef4.jpg'),
(40400, 2749, 'NCIS: Los Angeles S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222656.mp4', 'http://timg.bdta.pro/images/55fdb67b67c03db9d45f9737946c4bff.jpg'),
(40401, 2749, 'NCIS: Los Angeles S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222657.mp4', 'http://timg.bdta.pro/images/de09fe43e75fff78ddaf53c1272a4774.jpg'),
(40402, 2749, 'NCIS: Los Angeles S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222658.mp4', 'http://timg.bdta.pro/images/c15d6858963b1b44ca094fbf1d42b89f.jpg'),
(40403, 2749, 'NCIS: Los Angeles S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222659.mp4', 'http://timg.bdta.pro/images/8384a48ba03459ff728d961deeac28df.jpg'),
(40404, 2749, 'NCIS: Los Angeles S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222660.mp4', 'http://timg.bdta.pro/images/fd9c8af8c692454e72053110db139738.jpg'),
(40405, 2749, 'NCIS: Los Angeles S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222661.mp4', 'http://timg.bdta.pro/images/aa025a8043b4b1187b92077b09769ad9.jpg'),
(40406, 2749, 'NCIS: Los Angeles S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222662.mp4', 'http://timg.bdta.pro/images/b5c2844f10ab5eae5158430b8d4ad43d.jpg'),
(40407, 2749, 'NCIS: Los Angeles S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222663.mp4', 'http://timg.bdta.pro/images/822fecd57f6f63cec92ab9f0c2822fce.jpg'),
(40408, 2749, 'NCIS: Los Angeles S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222664.mp4', 'http://timg.bdta.pro/images/7968705aded554845036d86fedc3cbec.jpg'),
(40409, 2749, 'NCIS: Los Angeles S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222665.mp4', 'http://timg.bdta.pro/images/387112af9e43238b5bad2c96af9cf789.jpg'),
(40410, 2749, 'NCIS: Los Angeles S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222666.mp4', 'http://timg.bdta.pro/images/b4c7eaea57abff033b97afc000c1b6e7.jpg'),
(40411, 2749, 'NCIS: Los Angeles S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/222667.mp4', 'http://timg.bdta.pro/images/e5c596a64f371ea1d03236061e3dabc0.jpg'),
(40412, 2749, 'NCIS: Los Angeles S10 E24', 'http://sinalprivado.info:80/series/1533784/1533784/222668.mp4', 'http://timg.bdta.pro/images/8b520ce9c8c794bb4c2937fed7f178e2.jpg'),
(40413, 2750, 'NCIS: Los Angeles S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222669.mp4', 'http://timg.bdta.pro/images/0fd91199ea41d705fbb725b37d971e27.jpg'),
(40414, 2750, 'NCIS: Los Angeles S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222670.mp4', 'http://timg.bdta.pro/images/17f3fdc7297c76531270b9b2adede53c.jpg'),
(40415, 2750, 'NCIS: Los Angeles S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222671.mp4', 'http://timg.bdta.pro/images/1ae9e15510eb1d808d9d30968ed8bce5.jpg'),
(40416, 2750, 'NCIS: Los Angeles S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222672.mp4', 'http://timg.bdta.pro/images/2668f18d3350bcb1d9d2d28fa1e6aa59.jpg'),
(40417, 2750, 'NCIS: Los Angeles S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222673.mp4', 'http://timg.bdta.pro/images/5fc6c5ccaca0043ee74a0acd5a35c0ab.jpg'),
(40418, 2750, 'NCIS: Los Angeles S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222674.mp4', 'http://timg.bdta.pro/images/ed4ba874b16f2b23f4ac30eaadbb1b2b.jpg'),
(40419, 2750, 'NCIS: Los Angeles S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222675.mp4', 'http://timg.bdta.pro/images/4b0c8fc5694fa74452f0df28dd821aba.jpg'),
(40420, 2750, 'NCIS: Los Angeles S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222676.mp4', 'http://timg.bdta.pro/images/a4b7fb4817b437809bcf6f87059044ff.jpg'),
(40421, 2750, 'NCIS: Los Angeles S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222677.mp4', 'http://timg.bdta.pro/images/0940f4a8d2947e78b9732af3a7be6793.jpg'),
(40422, 2750, 'NCIS: Los Angeles S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222678.mp4', 'http://timg.bdta.pro/images/a4e18f4afe85592f8f9dd4f6eba5fe7e.jpg'),
(40423, 2750, 'NCIS: Los Angeles S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222679.mp4', 'http://timg.bdta.pro/images/852b8f9529fd5e1922cdb63c30dedcbb.jpg'),
(40424, 2750, 'NCIS: Los Angeles S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222680.mp4', 'http://timg.bdta.pro/images/940193b9d31a16152e96a26c2a835b95.jpg'),
(40425, 2750, 'NCIS: Los Angeles S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222681.mp4', 'http://timg.bdta.pro/images/832483c8e893c468e5e799b3d860c922.jpg'),
(40426, 2750, 'NCIS: Los Angeles S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222682.mp4', 'http://timg.bdta.pro/images/fe700f8cc0dfeaa508766a875cbbf76b.jpg'),
(40427, 2750, 'NCIS: Los Angeles S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222683.mp4', 'http://timg.bdta.pro/images/2355c9f00993b4c49ee767da2c58a4d9.jpg'),
(40428, 2750, 'NCIS: Los Angeles S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222684.mp4', 'http://timg.bdta.pro/images/5279a9a1ad85b0fffc98d034dc8d021a.jpg'),
(40429, 2750, 'NCIS: Los Angeles S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222685.mp4', 'http://timg.bdta.pro/images/891942a51dd48665a4f72a2800b0fef6.jpg'),
(40430, 2750, 'NCIS: Los Angeles S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222686.mp4', 'http://timg.bdta.pro/images/e8b437d2e335076d53d8d2a7b917dd07.jpg'),
(40431, 2750, 'NCIS: Los Angeles S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222687.mp4', 'http://timg.bdta.pro/images/b3e3fccc8d812282f3a96ec48c51d3a3.jpg'),
(40432, 2750, 'NCIS: Los Angeles S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222688.mp4', 'http://timg.bdta.pro/images/31b346484330b17872c9802c7ded7f7f.jpg'),
(40433, 2750, 'NCIS: Los Angeles S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222689.mp4', 'http://timg.bdta.pro/images/081bc2d2ec00dde0fc9d6a02afdca611.jpg'),
(40434, 2750, 'NCIS: Los Angeles S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222690.mp4', 'http://timg.bdta.pro/images/3dc580df279a0238213bc38f8f9e018f.jpg'),
(40435, 2751, 'NCIS: Los Angeles S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222691.mp4', 'http://timg.bdta.pro/images/26841f9ca42256cea4e2490c71770259.jpg'),
(40436, 2751, 'NCIS: Los Angeles S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222692.mp4', 'http://timg.bdta.pro/images/c256f11afc10fd5e4ae4908cc6b00b69.jpg'),
(40437, 2751, 'NCIS: Los Angeles S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222693.mp4', 'http://timg.bdta.pro/images/027ec274510acd15df39bf7add216dc4.jpg'),
(40438, 2751, 'NCIS: Los Angeles S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222694.mp4', 'http://timg.bdta.pro/images/f5dacc33cf3084f4bc19b5fa61d37e55.jpg'),
(40439, 2751, 'NCIS: Los Angeles S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222695.mp4', 'http://timg.bdta.pro/images/85afcd8c578d718c2ecb6b781ced3d32.jpg'),
(40440, 2751, 'NCIS: Los Angeles S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222696.mp4', 'http://timg.bdta.pro/images/a4a9116d5a991de19188491ef6b7beef.jpg'),
(40441, 2751, 'NCIS: Los Angeles S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222697.mp4', 'http://timg.bdta.pro/images/b2c59cb9be4e3beaadb1e34561b39cd7.jpg'),
(40442, 2751, 'NCIS: Los Angeles S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222698.mp4', 'http://timg.bdta.pro/images/bfb6e487af18288fd5e6eccfa8ff7436.jpg'),
(40443, 2751, 'NCIS: Los Angeles S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222699.mp4', 'http://timg.bdta.pro/images/2144fb81451fbc8ba92336c46562a209.jpg'),
(40444, 2751, 'NCIS: Los Angeles S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222700.mp4', 'http://timg.bdta.pro/images/ecf3c113f2a6a2bbd4c905a084182f22.jpg'),
(40445, 2751, 'NCIS: Los Angeles S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222701.mp4', 'http://timg.bdta.pro/images/3fc4646a7ae6e796ccaa1b21880b332e.jpg'),
(40446, 2751, 'NCIS: Los Angeles S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222702.mp4', 'http://timg.bdta.pro/images/692c69e4935698def611e9ca6b7b80ad.jpg'),
(40447, 2751, 'NCIS: Los Angeles S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222703.mp4', 'http://timg.bdta.pro/images/6b8de60f196618469b9e9db03a9da21e.jpg'),
(40448, 2751, 'NCIS: Los Angeles S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222704.mp4', 'http://timg.bdta.pro/images/4529cf678b903c359d9ee91068480c76.jpg'),
(40449, 2751, 'NCIS: Los Angeles S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222705.mp4', 'http://timg.bdta.pro/images/7eb725e958d86f906a357a6863ca9d5f.jpg'),
(40450, 2751, 'NCIS: Los Angeles S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222706.mp4', 'http://timg.bdta.pro/images/04e556f24f71dfe52717acb7239c693e.jpg'),
(40451, 2751, 'NCIS: Los Angeles S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222707.mp4', 'http://timg.bdta.pro/images/d2d8b993cc159d01d881e6dd61235ef7.jpg'),
(40452, 2751, 'NCIS: Los Angeles S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222708.mp4', 'http://timg.bdta.pro/images/a9dd2e44d90c1bedc39e6af2d1634dd4.jpg'),
(40453, 2752, 'NCIS: Los Angeles S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222709.mp4', 'http://timg.bdta.pro/images/b5c4d3bbee7cc8d25287852d31da20a2.jpg'),
(40454, 2752, 'NCIS: Los Angeles S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222710.mp4', 'http://timg.bdta.pro/images/5a04a7bdbb3b887f39feed3de65e42c6.jpg'),
(40455, 2752, 'NCIS: Los Angeles S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222711.mp4', 'http://timg.bdta.pro/images/32f01b721677565469c408079842c4b8.jpg'),
(40456, 2752, 'NCIS: Los Angeles S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222712.mp4', 'http://timg.bdta.pro/images/528ee2419222f6e437370a8407e6a810.jpg'),
(40457, 2752, 'NCIS: Los Angeles S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222713.mp4', 'http://timg.bdta.pro/images/040c8f739d38cdceba492c1e1190f465.jpg'),
(40458, 2752, 'NCIS: Los Angeles S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222714.mp4', 'http://timg.bdta.pro/images/6ec38f8bd581bd8077b74faa357a8b6b.jpg'),
(40459, 2752, 'NCIS: Los Angeles S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222715.mp4', 'http://timg.bdta.pro/images/7e28282528f6971880d85dbf8847d4a9.jpg'),
(40460, 2752, 'NCIS: Los Angeles S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222716.mp4', 'http://timg.bdta.pro/images/7a47472e7405f4e745212ecdbbdfc286.jpg'),
(40461, 2752, 'NCIS: Los Angeles S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222717.mp4', 'http://timg.bdta.pro/images/5063398b96670ee575937eda117c73f9.jpg'),
(40462, 2752, 'NCIS: Los Angeles S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222718.mp4', 'http://timg.bdta.pro/images/3732546c45d52a3e571f908093b506b2.jpg'),
(40463, 2752, 'NCIS: Los Angeles S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222719.mp4', 'http://timg.bdta.pro/images/e7ec9e11d6b8dcc68d4cb1ae62a2b285.jpg'),
(40464, 2752, 'NCIS: Los Angeles S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222720.mp4', 'http://timg.bdta.pro/images/66e8787d5c6769ba473170c2b1cd3f76.jpg'),
(40465, 2752, 'NCIS: Los Angeles S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222721.mp4', 'http://timg.bdta.pro/images/7b1b05cbe2d31539037fce95b2306f86.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(40466, 2752, 'NCIS: Los Angeles S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222722.mp4', 'http://timg.bdta.pro/images/76ba71940f8796f0173f40a0109fc8cf.jpg'),
(40467, 2752, 'NCIS: Los Angeles S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222723.mp4', 'http://timg.bdta.pro/images/2a5c3f86b5d277fb99d1e89f08e6034c.jpg'),
(40468, 2752, 'NCIS: Los Angeles S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222724.mp4', 'http://timg.bdta.pro/images/3b87c09b7d5657d23fd9371ae97cfc0b.jpg'),
(40469, 2752, 'NCIS: Los Angeles S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222725.mp4', 'http://timg.bdta.pro/images/99d8720ab3a1d5671fcce8bf587954a6.jpg'),
(40470, 2752, 'NCIS: Los Angeles S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222726.mp4', 'http://timg.bdta.pro/images/3da7e5888c28d5939078d231dd1d3152.jpg'),
(40471, 2752, 'NCIS: Los Angeles S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222727.mp4', 'http://timg.bdta.pro/images/ccb40cfbec15d74beecbf785dd56e96a.jpg'),
(40472, 2752, 'NCIS: Los Angeles S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222728.mp4', 'http://timg.bdta.pro/images/4523829ab16d344816963317e6255226.jpg'),
(40473, 2752, 'NCIS: Los Angeles S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222729.mp4', 'http://timg.bdta.pro/images/ffc6ea1bc7e02ff6a7667caa9c40769e.jpg'),
(40474, 2752, 'NCIS: Los Angeles S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222730.mp4', 'http://timg.bdta.pro/images/3558389bff8ea3209cd399fbb2f94081.jpg'),
(40475, 2753, 'NCIS: Los Angeles S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m6xBJaOXis9OIRyb52ZbzeMn32f.jpg'),
(40476, 2753, 'NCIS: Los Angeles S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fEFgNNQfdawYR3dwtoFpdnqGWFL.jpg'),
(40477, 2753, 'NCIS: Los Angeles S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eovvb1nw0uhLykcBZUD1uPS52uC.jpg'),
(40478, 2753, 'NCIS: Los Angeles S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lSYz8PkfJz9VlIfQU9CzpdvhAhE.jpg'),
(40479, 2753, 'NCIS: Los Angeles S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oWe4H6H3AZW97qEpufMYNJSi872.jpg'),
(40480, 2753, 'NCIS: Los Angeles S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDmkJdItswCIqcijxIOdfVzQCvq.jpg'),
(40481, 2753, 'NCIS: Los Angeles S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ngSH5QHvfprgY8HwtzAH5wyZQ3k.jpg'),
(40482, 2753, 'NCIS: Los Angeles S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mnFeSYABDzcuTiHobXVRUk297WB.jpg'),
(40483, 2753, 'NCIS: Los Angeles S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n3yC1KR9TCKCm2IqZbepnClFzmW.jpg'),
(40484, 2753, 'NCIS: Los Angeles S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/67LYYh67wSFtaxmVofHYdDhLtU1.jpg'),
(40485, 2753, 'NCIS: Los Angeles S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/47cg5TDv2PGPijhvWkFqw1aWMf1.jpg'),
(40486, 2753, 'NCIS: Los Angeles S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rPa0VIif9gT9njyqOJpjphJ36rB.jpg'),
(40487, 2753, 'NCIS: Los Angeles S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2IkGWgKyciiP0CWoSunhUlxL3vV.jpg'),
(40488, 2753, 'NCIS: Los Angeles S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rUpp3N4HsGhEzgqMHA740Nbk0lp.jpg'),
(40489, 2753, 'NCIS: Los Angeles S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJ90PUUCXkxJ5sfA7SJbETON2dt.jpg'),
(40490, 2753, 'NCIS: Los Angeles S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yAazZbGK4UDn4I0Aj2Wk5pB7UPx.jpg'),
(40491, 2753, 'NCIS: Los Angeles S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/otPpsnoL4mDYtulbfDQGWsr26g4.jpg'),
(40492, 2753, 'NCIS: Los Angeles S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bqnJcp9Wbf8b9aw0Cr5sLKzsoXl.jpg'),
(40493, 2753, 'NCIS: Los Angeles S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ovwgs5ILP2btNglZ3lFXyc2Tf1X.jpg'),
(40494, 2753, 'NCIS: Los Angeles S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/949mpXV0vJ6628sTyYXn69kFPLS.jpg'),
(40495, 2753, 'NCIS: Los Angeles S14 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s7DJCSgvnCuNaMkLu5sgqWvFFtg.jpg'),
(40496, 2754, 'Noturnos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131574.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(40497, 2754, 'Noturnos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131575.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(40498, 2754, 'Noturnos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131576.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(40499, 2754, 'Noturnos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131577.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(40500, 2754, 'Noturnos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131578.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(40501, 2754, 'Noturnos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131579.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(40502, 2755, 'O Gambito da Rainha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132321.mp4', 'http://timg.bdta.pro/images/4aaf620383c70b7c1bd793302b5b93d5.jpg'),
(40503, 2755, 'O Gambito da Rainha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132322.mp4', 'http://timg.bdta.pro/images/3c3e8b84fa65a9559e2af9f62a34582c.jpg'),
(40504, 2755, 'O Gambito da Rainha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132323.mp4', 'http://timg.bdta.pro/images/10792f0db7b0f46e952e560477848d59.jpg'),
(40505, 2755, 'O Gambito da Rainha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132324.mp4', 'http://timg.bdta.pro/images/cc6acdf9ab01ce13cef23907bc44e6ae.jpg'),
(40506, 2755, 'O Gambito da Rainha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132325.mp4', 'http://timg.bdta.pro/images/084fc030ef8c64e472982beaf3e9a171.jpg'),
(40507, 2755, 'O Gambito da Rainha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132326.mp4', 'http://timg.bdta.pro/images/3b63ee1f1451141666c49e4e63a83b1a.jpg'),
(40508, 2755, 'O Gambito da Rainha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132327.mp4', 'http://timg.bdta.pro/images/d3e543eae0686fd1c363596669d375a5.jpg'),
(40509, 2756, 'O Sangue de Zeus S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132313.mp4', 'http://timg.bdta.pro/images/dd92b658855a6c4e0a208af264aba6b0.jpg'),
(40510, 2756, 'O Sangue de Zeus S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132314.mp4', 'http://timg.bdta.pro/images/98ee05e3f864c921d940c43a27c662f3.jpg'),
(40511, 2756, 'O Sangue de Zeus S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132315.mp4', 'http://timg.bdta.pro/images/92b0a49a5578ff611de3f0dc56ed6c4a.jpg'),
(40512, 2756, 'O Sangue de Zeus S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132316.mp4', 'http://timg.bdta.pro/images/82525973b91e9723d2fb061519472e2a.jpg'),
(40513, 2756, 'O Sangue de Zeus S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132317.mp4', 'http://timg.bdta.pro/images/f69e18483727130599d814712eec2f70.jpg'),
(40514, 2756, 'O Sangue de Zeus S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132318.mp4', 'http://timg.bdta.pro/images/726c04a1ac5ecead970e93ce4586e106.jpg'),
(40515, 2756, 'O Sangue de Zeus S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132319.mp4', 'http://timg.bdta.pro/images/032b0d0848069c90768e9c10563bd947.jpg'),
(40516, 2756, 'O Sangue de Zeus S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132320.mp4', 'http://timg.bdta.pro/images/89468c4778f698c0ca46561e26e87e62.jpg'),
(40517, 2757, 'O Sangue de Zeus S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347190.mp4', 'http://gstaticontent.com/images/zXRR5tgGLtKrRmuN4ko9SLAdCiZ_big.jpg'),
(40518, 2757, 'O Sangue de Zeus S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347191.mp4', 'http://gstaticontent.com/images/zXRR5tgGLtKrRmuN4ko9SLAdCiZ_big.jpg'),
(40519, 2757, 'O Sangue de Zeus S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347192.mp4', 'http://gstaticontent.com/images/zXRR5tgGLtKrRmuN4ko9SLAdCiZ_big.jpg'),
(40520, 2757, 'O Sangue de Zeus S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347193.mp4', 'http://gstaticontent.com/images/zXRR5tgGLtKrRmuN4ko9SLAdCiZ_big.jpg'),
(40521, 2757, 'O Sangue de Zeus S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347194.mp4', 'http://gstaticontent.com/images/zXRR5tgGLtKrRmuN4ko9SLAdCiZ_big.jpg'),
(40522, 2757, 'O Sangue de Zeus S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347195.mp4', 'http://gstaticontent.com/images/zXRR5tgGLtKrRmuN4ko9SLAdCiZ_big.jpg'),
(40523, 2757, 'O Sangue de Zeus S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347196.mp4', 'http://gstaticontent.com/images/zXRR5tgGLtKrRmuN4ko9SLAdCiZ_big.jpg'),
(40524, 2757, 'O Sangue de Zeus S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347197.mp4', 'http://gstaticontent.com/images/zXRR5tgGLtKrRmuN4ko9SLAdCiZ_big.jpg'),
(40525, 2758, 'O Sangue de Zeus S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/880936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bo5uZB6jcwzu1OeJyf6HpeRb6bd.jpg'),
(40526, 2758, 'O Sangue de Zeus S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/880937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gqsjSTDVQMufqivJ8SByosx0cef.jpg'),
(40527, 2758, 'O Sangue de Zeus S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/880938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dE7JkSfzMRcadGfJMhYYvsUhUGX.jpg'),
(40528, 2758, 'O Sangue de Zeus S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/880939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Yox5yzDC75FcCaa0ywBBRsU0I2.jpg'),
(40529, 2758, 'O Sangue de Zeus S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/880940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pRzix3ZuUYnYVolv6jfqIulfOwW.jpg'),
(40530, 2758, 'O Sangue de Zeus S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/880941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7jAlse3WZav55dzwO1KUGon2isg.jpg'),
(40531, 2758, 'O Sangue de Zeus S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/880942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/39KunFOGgC6j5Bf8gSkZXfK7DZm.jpg'),
(40532, 2758, 'O Sangue de Zeus S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/880943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h3xDQ6A3plQtmYCx1ZdpKNdKhkM.jpg'),
(40533, 2759, 'Penny Dreadful Cidade dos Anjos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132303.mp4', 'http://timg.bdta.pro/images/7b05a788e7fad988a6b393ffa0deddb1.jpg'),
(40534, 2759, 'Penny Dreadful Cidade dos Anjos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132304.mp4', 'http://timg.bdta.pro/images/788e215f9b2b7ed55fc26d566b64313f.jpg'),
(40535, 2759, 'Penny Dreadful Cidade dos Anjos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132305.mp4', 'http://timg.bdta.pro/images/9b7ffcbbbfa9b4d5ac019e157491d45e.jpg'),
(40536, 2759, 'Penny Dreadful Cidade dos Anjos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132306.mp4', 'http://timg.bdta.pro/images/82b9c033d7e9138f4287db291ad4901d.jpg'),
(40537, 2759, 'Penny Dreadful Cidade dos Anjos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132307.mp4', 'http://timg.bdta.pro/images/4acdb264e17927c700cdc5c0cc58be99.jpg'),
(40538, 2759, 'Penny Dreadful Cidade dos Anjos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132308.mp4', 'http://timg.bdta.pro/images/06088def6d8cd1b54a34ee2badc59b95.jpg'),
(40539, 2759, 'Penny Dreadful Cidade dos Anjos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132309.mp4', 'http://timg.bdta.pro/images/d49ec834bc05db37316546abb23c9d4f.jpg'),
(40540, 2759, 'Penny Dreadful Cidade dos Anjos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132310.mp4', 'http://timg.bdta.pro/images/c81233879a83da58f08c33494b5b53e7.jpg'),
(40541, 2759, 'Penny Dreadful Cidade dos Anjos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132311.mp4', 'http://timg.bdta.pro/images/63fcedadbde1a47717e451cf11afcdff.jpg'),
(40542, 2759, 'Penny Dreadful Cidade dos Anjos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132312.mp4', 'http://timg.bdta.pro/images/718088bdbbc9ed2d379a634fd8c3d02e.jpg'),
(40543, 2760, 'Pessoa de Interesse S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132200.mp4', 'http://timg.bdta.pro/images/fdd8f57aa3628b3805150551598ad5d8.jpg'),
(40544, 2760, 'Pessoa de Interesse S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132201.mp4', 'http://timg.bdta.pro/images/f5c3e8f7467b7e2a3d15f05715c726a3.jpg'),
(40545, 2760, 'Pessoa de Interesse S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132202.mp4', 'http://timg.bdta.pro/images/12df622a2b7155cd3533b7bb826bf36b.jpg'),
(40546, 2760, 'Pessoa de Interesse S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132203.mp4', 'http://timg.bdta.pro/images/22f14b9cadcc9ab1db27dcb86178f403.jpg'),
(40547, 2760, 'Pessoa de Interesse S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132204.mp4', 'http://timg.bdta.pro/images/5cba50075a8955bcd6a4bec1bf9dc9d9.jpg'),
(40548, 2760, 'Pessoa de Interesse S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132205.mp4', 'http://timg.bdta.pro/images/893e38af39951a47f1f3cdf3b6b2f5de.jpg'),
(40549, 2760, 'Pessoa de Interesse S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132206.mp4', 'http://timg.bdta.pro/images/7879c6fd2a98ea244f4cf2b85b33cdf1.jpg'),
(40550, 2760, 'Pessoa de Interesse S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132207.mp4', 'http://timg.bdta.pro/images/784e952ca6105cd7d5b08f973615cfae.jpg'),
(40551, 2760, 'Pessoa de Interesse S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132208.mp4', 'http://timg.bdta.pro/images/3549c2fcc4d7fe4ec41e345b66c8d393.jpg'),
(40552, 2760, 'Pessoa de Interesse S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132209.mp4', 'http://timg.bdta.pro/images/e30f1ffc1cdca59fb917c98fd987881b.jpg'),
(40553, 2760, 'Pessoa de Interesse S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132210.mp4', 'http://timg.bdta.pro/images/efdc8551a906293a823ae84f61c7f086.jpg'),
(40554, 2760, 'Pessoa de Interesse S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132211.mp4', 'http://timg.bdta.pro/images/db07ef94c06b8d883948c199522903a5.jpg'),
(40555, 2760, 'Pessoa de Interesse S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132212.mp4', 'http://timg.bdta.pro/images/34bafdd0a2538ab79fd6aff0d4424f06.jpg'),
(40556, 2760, 'Pessoa de Interesse S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132213.mp4', 'http://timg.bdta.pro/images/eb504230f2cd57e29c987b2f339b4adb.jpg'),
(40557, 2760, 'Pessoa de Interesse S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132214.mp4', 'http://timg.bdta.pro/images/802d3e04ccb2238905cd822a2d305e6b.jpg'),
(40558, 2760, 'Pessoa de Interesse S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132215.mp4', 'http://timg.bdta.pro/images/933e1d2d79abf589303d1af230db5e67.jpg'),
(40559, 2760, 'Pessoa de Interesse S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132216.mp4', 'http://timg.bdta.pro/images/b5c8be32cf965bbb766bd3dbc9a9ce74.jpg'),
(40560, 2760, 'Pessoa de Interesse S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132217.mp4', 'http://timg.bdta.pro/images/1ab067bbf51412a3f16a2e045a24872e.jpg'),
(40561, 2760, 'Pessoa de Interesse S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132218.mp4', 'http://timg.bdta.pro/images/9f50b9602da04af365823c978d020a35.jpg'),
(40562, 2760, 'Pessoa de Interesse S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132219.mp4', 'http://timg.bdta.pro/images/8d0a6f462d7840d9b9ca75c2ba57fa7b.jpg'),
(40563, 2760, 'Pessoa de Interesse S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132220.mp4', 'http://timg.bdta.pro/images/86de0dbe80e5c806eaa16d5dd52ff87c.jpg'),
(40564, 2760, 'Pessoa de Interesse S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132221.mp4', 'http://timg.bdta.pro/images/e98187cb16ebd95648dcc72c1ae85281.jpg'),
(40565, 2760, 'Pessoa de Interesse S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/132222.mp4', 'http://timg.bdta.pro/images/ea9fe45185f870085e433c4f0f328448.jpg'),
(40566, 2761, 'Pessoa de Interesse S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132223.mp4', 'http://timg.bdta.pro/images/ce7861d1930b6cfb0d7f6fe4eabe0de5.jpg'),
(40567, 2761, 'Pessoa de Interesse S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132224.mp4', 'http://timg.bdta.pro/images/da3dcc9db71425abfb0760e42067c4c0.jpg'),
(40568, 2761, 'Pessoa de Interesse S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132225.mp4', 'http://timg.bdta.pro/images/fab0e9f09704ad7bbdb7a64bbff20e62.jpg'),
(40569, 2761, 'Pessoa de Interesse S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132226.mp4', 'http://timg.bdta.pro/images/246e7565e1f422aecc6c90a1cd076259.jpg'),
(40570, 2761, 'Pessoa de Interesse S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132227.mp4', 'http://timg.bdta.pro/images/8101f03c6d7c4076fd69ae675573a338.jpg'),
(40571, 2761, 'Pessoa de Interesse S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132228.mp4', 'http://timg.bdta.pro/images/9fc0aa525634b2624df9a8d8ab16a3f6.jpg'),
(40572, 2761, 'Pessoa de Interesse S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132229.mp4', 'http://timg.bdta.pro/images/10941d9ce5a09cecd74843620fe4b2c8.jpg'),
(40573, 2761, 'Pessoa de Interesse S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132230.mp4', 'http://timg.bdta.pro/images/a7433e954253f16d98b34c3a75aab679.jpg'),
(40574, 2761, 'Pessoa de Interesse S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132231.mp4', 'http://timg.bdta.pro/images/409f26b4b376b5c38dc150569da1320d.jpg'),
(40575, 2761, 'Pessoa de Interesse S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132232.mp4', 'http://timg.bdta.pro/images/1522011f90d3587a91555bde728034d1.jpg'),
(40576, 2761, 'Pessoa de Interesse S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132233.mp4', 'http://timg.bdta.pro/images/a6f9cc1dc03f43c474a0d64c8a390f0a.jpg'),
(40577, 2761, 'Pessoa de Interesse S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132234.mp4', 'http://timg.bdta.pro/images/bad2063ab52003109466ce61bfde6ff2.jpg'),
(40578, 2761, 'Pessoa de Interesse S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132235.mp4', 'http://timg.bdta.pro/images/040a0ed674e4e1b7ebfb5e098fe4924f.jpg'),
(40579, 2761, 'Pessoa de Interesse S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132236.mp4', 'http://timg.bdta.pro/images/8b43de27a49b2514141ab388db07b1c5.jpg'),
(40580, 2761, 'Pessoa de Interesse S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132237.mp4', 'http://timg.bdta.pro/images/dd3a586fa97a358943b6258112a498f1.jpg'),
(40581, 2761, 'Pessoa de Interesse S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132238.mp4', 'http://timg.bdta.pro/images/5e0966f6d1a023268ad30dd82622d407.jpg'),
(40582, 2761, 'Pessoa de Interesse S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132239.mp4', 'http://timg.bdta.pro/images/4aa3adbf9de050986f058e2d17c9d2af.jpg'),
(40583, 2761, 'Pessoa de Interesse S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132240.mp4', 'http://timg.bdta.pro/images/18144f1b3ed2ed446e10dbc23128abca.jpg'),
(40584, 2761, 'Pessoa de Interesse S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132241.mp4', 'http://timg.bdta.pro/images/6fca1c6e64d8a15b1cee570d2dd0f191.jpg'),
(40585, 2761, 'Pessoa de Interesse S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132242.mp4', 'http://timg.bdta.pro/images/d1d49e1270dd322b849f0464ea094f94.jpg'),
(40586, 2761, 'Pessoa de Interesse S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132243.mp4', 'http://timg.bdta.pro/images/b83c3eee9ac03b0f7928c158ad26b803.jpg'),
(40587, 2761, 'Pessoa de Interesse S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132244.mp4', 'http://timg.bdta.pro/images/ffb4a6c730f9f25f1e9f6743f16d35ff.jpg'),
(40588, 2762, 'Pessoa de Interesse S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132245.mp4', 'http://timg.bdta.pro/images/17f9affe41e45f07c47ef2e402d4bdd4.jpg'),
(40589, 2762, 'Pessoa de Interesse S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132246.mp4', 'http://timg.bdta.pro/images/dff5b2575bcd3053cda9148d77aad0f3.jpg'),
(40590, 2762, 'Pessoa de Interesse S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132247.mp4', 'http://timg.bdta.pro/images/8e7d5e3207bc16a981341a4a0d2ad464.jpg'),
(40591, 2762, 'Pessoa de Interesse S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132248.mp4', 'http://timg.bdta.pro/images/4aa12186fff640a071a8da26d07e6eab.jpg'),
(40592, 2762, 'Pessoa de Interesse S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132249.mp4', 'http://timg.bdta.pro/images/474d887c1c713448ceb301db5b82e3a2.jpg'),
(40593, 2762, 'Pessoa de Interesse S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132250.mp4', 'http://timg.bdta.pro/images/66109617a23fdc7dedbc3c58a9c84f1d.jpg'),
(40594, 2762, 'Pessoa de Interesse S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132251.mp4', 'http://timg.bdta.pro/images/0e46aca7e86abc482935dab61b735738.jpg'),
(40595, 2762, 'Pessoa de Interesse S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132252.mp4', 'http://timg.bdta.pro/images/ba8561a8f21e71702dfc444c4acb4808.jpg'),
(40596, 2762, 'Pessoa de Interesse S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132253.mp4', 'http://timg.bdta.pro/images/768c60407a794674ce335bf61a52ca34.jpg'),
(40597, 2762, 'Pessoa de Interesse S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132254.mp4', 'http://timg.bdta.pro/images/71e676d4fd059dac81f97e16c182912b.jpg'),
(40598, 2762, 'Pessoa de Interesse S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132255.mp4', 'http://timg.bdta.pro/images/7f195798ee6c7810979803d08f6532f2.jpg'),
(40599, 2762, 'Pessoa de Interesse S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132256.mp4', 'http://timg.bdta.pro/images/358ad8831d808306d19033d3c402d787.jpg'),
(40600, 2762, 'Pessoa de Interesse S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132257.mp4', 'http://timg.bdta.pro/images/f8dd3745f2aa6b48815a2852399abc07.jpg'),
(40601, 2762, 'Pessoa de Interesse S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132258.mp4', 'http://timg.bdta.pro/images/42d2a686b6090ce1ec2a47e3a458471f.jpg'),
(40602, 2762, 'Pessoa de Interesse S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132259.mp4', 'http://timg.bdta.pro/images/9faccb95bf857a5abac9710fec65b59d.jpg'),
(40603, 2762, 'Pessoa de Interesse S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132260.mp4', 'http://timg.bdta.pro/images/a7f0544a6abcf0e8da30cfe74324a198.jpg'),
(40604, 2762, 'Pessoa de Interesse S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132261.mp4', 'http://timg.bdta.pro/images/3700ac5012b25c2afbee9a28fa8ce49e.jpg'),
(40605, 2762, 'Pessoa de Interesse S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132262.mp4', 'http://timg.bdta.pro/images/6633075ab3a6801a27762afe4d9632d5.jpg'),
(40606, 2762, 'Pessoa de Interesse S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132263.mp4', 'http://timg.bdta.pro/images/beb7d0fca136c247ac5df75f80b67c53.jpg'),
(40607, 2762, 'Pessoa de Interesse S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132264.mp4', 'http://timg.bdta.pro/images/96fd44e3b21d2959206c0bb9d631e926.jpg'),
(40608, 2762, 'Pessoa de Interesse S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132265.mp4', 'http://timg.bdta.pro/images/21dfa5090d6114cf887164ea6c4f14a7.jpg'),
(40609, 2762, 'Pessoa de Interesse S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132266.mp4', 'http://timg.bdta.pro/images/e2339eb258d5d8e4e4140b008fdf5783.jpg'),
(40610, 2762, 'Pessoa de Interesse S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/132267.mp4', 'http://timg.bdta.pro/images/85b38cdaa552bfee2852cb9a8373e575.jpg'),
(40611, 2763, 'Pessoa de Interesse S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132268.mp4', 'http://timg.bdta.pro/images/b5a15a73875031500e74459278a89239.jpg'),
(40612, 2763, 'Pessoa de Interesse S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132269.mp4', 'http://timg.bdta.pro/images/a5abf611ea49a31f47003ebe331d35b3.jpg'),
(40613, 2763, 'Pessoa de Interesse S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132270.mp4', 'http://timg.bdta.pro/images/474b80b394cf8a92ca2042f5cd6bb9b3.jpg'),
(40614, 2763, 'Pessoa de Interesse S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132271.mp4', 'http://timg.bdta.pro/images/68953343299c29d3518ab43e875a2e27.jpg'),
(40615, 2763, 'Pessoa de Interesse S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132272.mp4', 'http://timg.bdta.pro/images/c2e681f526f9825772a35f6f27aa5749.jpg'),
(40616, 2763, 'Pessoa de Interesse S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132273.mp4', 'http://timg.bdta.pro/images/a5c947f03c8402bfd1f3fa13adb17b09.jpg'),
(40617, 2763, 'Pessoa de Interesse S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132274.mp4', 'http://timg.bdta.pro/images/fb976973fd4dc3f9c98c5a897c4edcca.jpg'),
(40618, 2763, 'Pessoa de Interesse S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132275.mp4', 'http://timg.bdta.pro/images/34a30e983167311a4b9fb3a0616602d8.jpg'),
(40619, 2763, 'Pessoa de Interesse S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132276.mp4', 'http://timg.bdta.pro/images/d6aea1c37b92fd30ea9a6a4aa349df72.jpg'),
(40620, 2763, 'Pessoa de Interesse S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132277.mp4', 'http://timg.bdta.pro/images/a3fd47f012164e333571eecdde25f3a5.jpg'),
(40621, 2763, 'Pessoa de Interesse S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132278.mp4', 'http://timg.bdta.pro/images/8cf1315bfb674fbb83c44015f9c13a7d.jpg'),
(40622, 2763, 'Pessoa de Interesse S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132279.mp4', 'http://timg.bdta.pro/images/d7a0b4535adb4138b5a59a4b6b3e9a1a.jpg'),
(40623, 2763, 'Pessoa de Interesse S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132280.mp4', 'http://timg.bdta.pro/images/407b1d7b0529ea431a1eb089458f358d.jpg'),
(40624, 2763, 'Pessoa de Interesse S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132281.mp4', 'http://timg.bdta.pro/images/2d37195049a8db4b7398df3f2b675790.jpg'),
(40625, 2763, 'Pessoa de Interesse S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/132282.mp4', 'http://timg.bdta.pro/images/8cfe6e7cc2f051362807260604063a5e.jpg'),
(40626, 2763, 'Pessoa de Interesse S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/132283.mp4', 'http://timg.bdta.pro/images/14c13d4ffe9aad1dfc31460c0ed50068.jpg'),
(40627, 2763, 'Pessoa de Interesse S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/132284.mp4', 'http://timg.bdta.pro/images/a918addf205cdc51eff3fc90e17d13ad.jpg'),
(40628, 2763, 'Pessoa de Interesse S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/132285.mp4', 'http://timg.bdta.pro/images/081b95d30e1a8dee739c81b9578d8c16.jpg'),
(40629, 2763, 'Pessoa de Interesse S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/132286.mp4', 'http://timg.bdta.pro/images/1ddc6ddf2a56559e99186926ab6ee0b1.jpg'),
(40630, 2763, 'Pessoa de Interesse S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/132287.mp4', 'http://timg.bdta.pro/images/9661998438c3bef84657dfd7efdc657e.jpg'),
(40631, 2763, 'Pessoa de Interesse S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/132288.mp4', 'http://timg.bdta.pro/images/acc0921931b75644d314204d3b49f113.jpg'),
(40632, 2763, 'Pessoa de Interesse S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/132289.mp4', 'http://timg.bdta.pro/images/b5e1d56bee6e8c9789fb5b92d8ada6d8.jpg'),
(40633, 2764, 'Pessoa de Interesse S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132290.mp4', 'http://timg.bdta.pro/images/4b2c9ba60a2ed847d955ae052db4e853.jpg'),
(40634, 2764, 'Pessoa de Interesse S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132291.mp4', 'http://timg.bdta.pro/images/0c9a6d5692104d33706877d3d3596fd3.jpg'),
(40635, 2764, 'Pessoa de Interesse S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132292.mp4', 'http://timg.bdta.pro/images/0166255388863ce8eef7b8ba5b3684e0.jpg'),
(40636, 2764, 'Pessoa de Interesse S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132293.mp4', 'http://timg.bdta.pro/images/c9cf0b1ea1775531b3f8b984980e0ad3.jpg'),
(40637, 2764, 'Pessoa de Interesse S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132294.mp4', 'http://timg.bdta.pro/images/f99bbcc6e749f8ce6dd70b6bf1dde9cc.jpg'),
(40638, 2764, 'Pessoa de Interesse S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132295.mp4', 'http://timg.bdta.pro/images/2ebc7d3f50013319c104da7d6723301a.jpg'),
(40639, 2764, 'Pessoa de Interesse S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132296.mp4', 'http://timg.bdta.pro/images/fcf24981cf9daf8d780558445f6f5846.jpg'),
(40640, 2764, 'Pessoa de Interesse S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132297.mp4', 'http://timg.bdta.pro/images/9098aa2461f74c1823f29ed783e218ae.jpg'),
(40641, 2764, 'Pessoa de Interesse S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132298.mp4', 'http://timg.bdta.pro/images/02f79764430a00cf530c0d0dd92654e4.jpg'),
(40642, 2764, 'Pessoa de Interesse S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132299.mp4', 'http://timg.bdta.pro/images/afa8987d144c8eb9c05791bbbd6c5d3f.jpg'),
(40643, 2764, 'Pessoa de Interesse S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132300.mp4', 'http://timg.bdta.pro/images/319ab0d0443b266b7fcdaf6dd60b6ace.jpg'),
(40644, 2764, 'Pessoa de Interesse S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132301.mp4', 'http://timg.bdta.pro/images/0d44ee3045da9853a80617bac524c048.jpg'),
(40645, 2764, 'Pessoa de Interesse S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132302.mp4', 'http://timg.bdta.pro/images/d04762d75aa80b7b06f314f093a7e6b2.jpg'),
(40646, 2765, 'The Undoing S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130688.mp4', 'http://timg.bdta.pro/images/cba8863bff19aafd2ced510b33d0cb97.jpg'),
(40647, 2765, 'The Undoing S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8POHAJfDbR31eKeQCfM6tPr5bAh.jpg'),
(40648, 2765, 'The Undoing S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1UEWzPMTZ61RDW8qRkGQGamUGtN.jpg'),
(40649, 2765, 'The Undoing S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130691.mp4', 'http://gstaticontent.com/images/3tDbJxobPN3EI2bBebL6zmusmw5_big.jpg'),
(40650, 2765, 'The Undoing S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130692.mp4', 'http://gstaticontent.com/images/3tDbJxobPN3EI2bBebL6zmusmw5_big.jpg'),
(40651, 2765, 'The Undoing S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130693.mp4', 'http://gstaticontent.com/images/3tDbJxobPN3EI2bBebL6zmusmw5_big.jpg'),
(40652, 2766, 'Um Rapaz Adequado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132194.mp4', 'http://timg.bdta.pro/images/e5b446f712a3da4ef02c24583c2f5f40.jpg'),
(40653, 2766, 'Um Rapaz Adequado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132195.mp4', 'http://timg.bdta.pro/images/1f227fd93575360daed27bbd28ae31a4.jpg'),
(40654, 2766, 'Um Rapaz Adequado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132196.mp4', 'http://timg.bdta.pro/images/303256296886e6fba65761a1b8927ebf.jpg'),
(40655, 2766, 'Um Rapaz Adequado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132197.mp4', 'http://timg.bdta.pro/images/7fe65944861885af9a0ac1bf370b3e17.jpg'),
(40656, 2766, 'Um Rapaz Adequado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132198.mp4', 'http://timg.bdta.pro/images/94f03dd8817dcc127d42eb767461d780.jpg'),
(40657, 2766, 'Um Rapaz Adequado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132199.mp4', 'http://timg.bdta.pro/images/034e8e88adf056a83b5200d2a7460bbd.jpg'),
(40658, 2767, 'Creepshow S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243287.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40659, 2767, 'Creepshow S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243288.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40660, 2767, 'Creepshow S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243289.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40661, 2767, 'Creepshow S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243290.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40662, 2767, 'Creepshow S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243291.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40663, 2767, 'Creepshow S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243292.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40664, 2768, 'Creepshow S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243293.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40665, 2768, 'Creepshow S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243294.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40666, 2768, 'Creepshow S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243295.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40667, 2768, 'Creepshow S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243296.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40668, 2768, 'Creepshow S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243297.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40669, 2768, 'Creepshow S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243298.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40670, 2768, 'Creepshow S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243299.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40671, 2769, 'Creepshow S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243300.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40672, 2769, 'Creepshow S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243301.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40673, 2769, 'Creepshow S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243302.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40674, 2769, 'Creepshow S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243303.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40675, 2769, 'Creepshow S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243304.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40676, 2769, 'Creepshow S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243305.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40677, 2770, 'Creepshow S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243306.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40678, 2770, 'Creepshow S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243307.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40679, 2770, 'Creepshow S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243308.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40680, 2770, 'Creepshow S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243309.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40681, 2770, 'Creepshow S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243310.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40682, 2770, 'Creepshow S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243311.mp4', 'http://gstaticontent.com/images/9Lyci5kKLWOTcB1xXjY2b27zqtm_big.jpg'),
(40683, 2771, 'Febre do Ouro: Corredeiras do Alasca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h4Rhi8IoPNwijbETGNTHgfHDXFo.jpg'),
(40684, 2771, 'Febre do Ouro: Corredeiras do Alasca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zsGNZ909Gz4pkG2BVwNTDMcEsCi.jpg'),
(40685, 2771, 'Febre do Ouro: Corredeiras do Alasca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBuGlf5yyM3GvoqIH9FX384Zxx1.jpg'),
(40686, 2771, 'Febre do Ouro: Corredeiras do Alasca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/saHSize9we7CAKOCmjXbQ3lzIKk.jpg'),
(40687, 2771, 'Febre do Ouro: Corredeiras do Alasca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x1FhnIjTxcladcWLPRGlClpwmSs.jpg'),
(40688, 2771, 'Febre do Ouro: Corredeiras do Alasca S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/itVZzNwvaZ6J0Y1ERUNcbqlfIZI.jpg'),
(40689, 2771, 'Febre do Ouro: Corredeiras do Alasca S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ugfPiMuKg5mFOwkjteGtNSS1SKI.jpg'),
(40690, 2771, 'Febre do Ouro: Corredeiras do Alasca S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9gsW4hFlOA6is0VrCdM7WpVMSPL.jpg'),
(40691, 2772, '50 States Of Fright [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132056.mp4', 'http://image.tmdb.org/t/p/w300/as6HiDpw0BqojeXq7cygJQEV1sL.jpg'),
(40692, 2772, '50 States Of Fright [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132057.mp4', 'http://image.tmdb.org/t/p/w300/kKAwv4fSfimsYJeINVb2MjEmttg.jpg'),
(40693, 2772, '50 States Of Fright [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132058.mp4', 'http://image.tmdb.org/t/p/w300/kKAwv4fSfimsYJeINVb2MjEmttg.jpg'),
(40694, 2772, '50 States Of Fright [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132059.mp4', 'http://image.tmdb.org/t/p/w300/g3Ld2dwfIdmhI7XeBjAGREKZT8O.jpg'),
(40695, 2772, '50 States Of Fright [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132060.mp4', 'http://image.tmdb.org/t/p/w300/q59ZNnAATEze5GyX3JOIK30jaia.jpg'),
(40696, 2772, '50 States Of Fright [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132061.mp4', 'http://image.tmdb.org/t/p/w300/zWZi4y1CHux3CVlZqX72wpqscd8.jpg'),
(40697, 2772, '50 States Of Fright [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132062.mp4', 'http://image.tmdb.org/t/p/w300/6AMoYPxCc86zcBtvoxLURmZCNFP.jpg'),
(40698, 2772, '50 States Of Fright [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132063.mp4', 'http://image.tmdb.org/t/p/w300/s5V7s9L6m2XSE9nTTYaEcim2dP7.jpg'),
(40699, 2772, '50 States Of Fright [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132064.mp4', 'http://image.tmdb.org/t/p/w300/hbOYElrTvfj4jq8RcgTPxpWdPzp.jpg'),
(40700, 2772, '50 States Of Fright [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132065.mp4', 'http://image.tmdb.org/t/p/w300/wmFbFOKMwMlduQVFKsH8fB36YRB.jpg'),
(40701, 2772, '50 States Of Fright [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132066.mp4', 'http://image.tmdb.org/t/p/w300/wmFbFOKMwMlduQVFKsH8fB36YRB.jpg'),
(40702, 2772, '50 States Of Fright [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132067.mp4', 'http://image.tmdb.org/t/p/w300/wmFbFOKMwMlduQVFKsH8fB36YRB.jpg'),
(40703, 2772, '50 States Of Fright [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132068.mp4', 'http://image.tmdb.org/t/p/w300/wmFbFOKMwMlduQVFKsH8fB36YRB.jpg'),
(40704, 2772, '50 States Of Fright [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/132069.mp4', 'http://image.tmdb.org/t/p/w300/wmFbFOKMwMlduQVFKsH8fB36YRB.jpg'),
(40705, 2773, '50 States Of Fright [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132070.mp4', 'http://image.tmdb.org/t/p/w300/rN0RdeQveD988KykI8yEqooknR8.jpg'),
(40706, 2773, '50 States Of Fright [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132071.mp4', 'http://image.tmdb.org/t/p/w300/woYAk6XUTgc2p1N56kDCQrc6BAv.jpg'),
(40707, 2773, '50 States Of Fright [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132072.mp4', 'http://image.tmdb.org/t/p/w300/uUO9Rty4btkAg7U3F4aMfm9187Q.jpg'),
(40708, 2773, '50 States Of Fright [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132073.mp4', 'http://image.tmdb.org/t/p/w300/ilJDBHrog6CbTYDEGotMVaffx2Z.jpg'),
(40709, 2773, '50 States Of Fright [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132074.mp4', 'http://image.tmdb.org/t/p/w300/l086TNyOSseliq03p34ZGP7oOhI.jpg'),
(40710, 2773, '50 States Of Fright [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132075.mp4', 'http://image.tmdb.org/t/p/w300/pzAkXjrdleMypmopDQtpLkTMX7H.jpg'),
(40711, 2774, 'Enemigo Intimo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131350.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40712, 2774, 'Enemigo Intimo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131351.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40713, 2774, 'Enemigo Intimo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131352.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40714, 2774, 'Enemigo Intimo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131353.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40715, 2774, 'Enemigo Intimo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131354.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40716, 2774, 'Enemigo Intimo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131355.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40717, 2774, 'Enemigo Intimo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131356.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40718, 2774, 'Enemigo Intimo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131357.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40719, 2774, 'Enemigo Intimo [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131358.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40720, 2774, 'Enemigo Intimo [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131359.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40721, 2774, 'Enemigo Intimo [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131360.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40722, 2774, 'Enemigo Intimo [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131361.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40723, 2774, 'Enemigo Intimo [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131362.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40724, 2774, 'Enemigo Intimo [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131363.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40725, 2774, 'Enemigo Intimo [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131364.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40726, 2774, 'Enemigo Intimo [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/131365.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40727, 2774, 'Enemigo Intimo [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/131366.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40728, 2774, 'Enemigo Intimo [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/131367.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40729, 2774, 'Enemigo Intimo [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/131368.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40730, 2774, 'Enemigo Intimo [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/131369.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40731, 2774, 'Enemigo Intimo [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/131370.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40732, 2774, 'Enemigo Intimo [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/131371.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40733, 2774, 'Enemigo Intimo [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/131372.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40734, 2774, 'Enemigo Intimo [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/131373.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40735, 2774, 'Enemigo Intimo [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/131374.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40736, 2774, 'Enemigo Intimo [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/131375.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40737, 2774, 'Enemigo Intimo [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/131376.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40738, 2774, 'Enemigo Intimo [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/131377.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40739, 2774, 'Enemigo Intimo [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/131378.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40740, 2774, 'Enemigo Intimo [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/131379.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40741, 2774, 'Enemigo Intimo [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/131380.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40742, 2774, 'Enemigo Intimo [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/131381.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40743, 2774, 'Enemigo Intimo [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/131382.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40744, 2774, 'Enemigo Intimo [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/131383.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(40745, 2774, 'Enemigo Intimo [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/131384.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40746, 2774, 'Enemigo Intimo [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/131385.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40747, 2774, 'Enemigo Intimo [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/131386.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40748, 2774, 'Enemigo Intimo [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/131387.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40749, 2774, 'Enemigo Intimo [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/131388.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40750, 2774, 'Enemigo Intimo [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/131389.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40751, 2774, 'Enemigo Intimo [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/131390.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40752, 2774, 'Enemigo Intimo [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/131391.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40753, 2774, 'Enemigo Intimo [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/131392.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40754, 2774, 'Enemigo Intimo [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/131393.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40755, 2774, 'Enemigo Intimo [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/131394.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40756, 2774, 'Enemigo Intimo [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/131395.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40757, 2774, 'Enemigo Intimo [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/131396.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40758, 2774, 'Enemigo Intimo [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/131397.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40759, 2774, 'Enemigo Intimo [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/131398.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40760, 2774, 'Enemigo Intimo [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/131399.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40761, 2774, 'Enemigo Intimo [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/131400.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40762, 2774, 'Enemigo Intimo [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/131401.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40763, 2774, 'Enemigo Intimo [L] S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/131402.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40764, 2775, 'Enemigo Intimo [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131403.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40765, 2775, 'Enemigo Intimo [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131404.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40766, 2775, 'Enemigo Intimo [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131405.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40767, 2775, 'Enemigo Intimo [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131406.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40768, 2775, 'Enemigo Intimo [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131407.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40769, 2775, 'Enemigo Intimo [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131408.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40770, 2775, 'Enemigo Intimo [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131409.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40771, 2775, 'Enemigo Intimo [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131410.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40772, 2775, 'Enemigo Intimo [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131411.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40773, 2775, 'Enemigo Intimo [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131412.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40774, 2775, 'Enemigo Intimo [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131413.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40775, 2775, 'Enemigo Intimo [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131414.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40776, 2775, 'Enemigo Intimo [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131415.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40777, 2775, 'Enemigo Intimo [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131416.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40778, 2775, 'Enemigo Intimo [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131417.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40779, 2775, 'Enemigo Intimo [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/131418.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40780, 2775, 'Enemigo Intimo [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/131419.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40781, 2775, 'Enemigo Intimo [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/131420.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40782, 2775, 'Enemigo Intimo [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/131421.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40783, 2775, 'Enemigo Intimo [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/131422.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40784, 2775, 'Enemigo Intimo [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/131423.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40785, 2775, 'Enemigo Intimo [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/131424.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40786, 2775, 'Enemigo Intimo [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/131425.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40787, 2775, 'Enemigo Intimo [L] S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/131426.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40788, 2775, 'Enemigo Intimo [L] S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/131427.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40789, 2775, 'Enemigo Intimo [L] S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/131428.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40790, 2775, 'Enemigo Intimo [L] S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/131429.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40791, 2775, 'Enemigo Intimo [L] S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/131430.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40792, 2775, 'Enemigo Intimo [L] S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/131431.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40793, 2775, 'Enemigo Intimo [L] S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/131432.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40794, 2775, 'Enemigo Intimo [L] S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/131433.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40795, 2775, 'Enemigo Intimo [L] S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/131434.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40796, 2775, 'Enemigo Intimo [L] S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/131435.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40797, 2775, 'Enemigo Intimo [L] S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/131436.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40798, 2775, 'Enemigo Intimo [L] S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/131437.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40799, 2775, 'Enemigo Intimo [L] S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/131438.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40800, 2775, 'Enemigo Intimo [L] S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/131439.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40801, 2775, 'Enemigo Intimo [L] S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/131440.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40802, 2775, 'Enemigo Intimo [L] S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/131441.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40803, 2775, 'Enemigo Intimo [L] S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/131442.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40804, 2775, 'Enemigo Intimo [L] S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/131443.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40805, 2775, 'Enemigo Intimo [L] S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/131444.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40806, 2775, 'Enemigo Intimo [L] S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/131445.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40807, 2775, 'Enemigo Intimo [L] S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/131446.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40808, 2775, 'Enemigo Intimo [L] S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/131447.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40809, 2775, 'Enemigo Intimo [L] S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/131448.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40810, 2775, 'Enemigo Intimo [L] S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/131449.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40811, 2775, 'Enemigo Intimo [L] S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/131450.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40812, 2775, 'Enemigo Intimo [L] S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/131451.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40813, 2775, 'Enemigo Intimo [L] S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/131452.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40814, 2775, 'Enemigo Intimo [L] S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/131453.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40815, 2775, 'Enemigo Intimo [L] S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/131454.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40816, 2775, 'Enemigo Intimo [L] S02 E53', 'http://sinalprivado.info:80/series/1533784/1533784/131455.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40817, 2775, 'Enemigo Intimo [L] S02 E54', 'http://sinalprivado.info:80/series/1533784/1533784/131456.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40818, 2775, 'Enemigo Intimo [L] S02 E55', 'http://sinalprivado.info:80/series/1533784/1533784/131457.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40819, 2775, 'Enemigo Intimo [L] S02 E56', 'http://sinalprivado.info:80/series/1533784/1533784/131458.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40820, 2775, 'Enemigo Intimo [L] S02 E57', 'http://sinalprivado.info:80/series/1533784/1533784/131459.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40821, 2775, 'Enemigo Intimo [L] S02 E58', 'http://sinalprivado.info:80/series/1533784/1533784/131460.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40822, 2775, 'Enemigo Intimo [L] S02 E59', 'http://sinalprivado.info:80/series/1533784/1533784/131461.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40823, 2775, 'Enemigo Intimo [L] S02 E60', 'http://sinalprivado.info:80/series/1533784/1533784/131462.mp4', 'http://gstaticontent.com/images/81URAPXi0GP9Ul4MxcVSiDEnpPq_big.jpg'),
(40824, 2776, 'Katy Keene S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3yQRFYXR0mKu8Mx6ETYhRtzWB7c.jpg'),
(40825, 2776, 'Katy Keene S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/beg0o0tDrF2VZDejbQzWoOfXSdo.jpg'),
(40826, 2776, 'Katy Keene S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9i9vgWkXbvKHORqvp90dcXWrNQR.jpg'),
(40827, 2776, 'Katy Keene S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t1RRGWpH55kWe8ngO8OmTEkWvwn.jpg'),
(40828, 2776, 'Katy Keene S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hIfBKrcBMyv3rdPviLRdl4exMbg.jpg'),
(40829, 2776, 'Katy Keene S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/orl1Z544AHGfIeVonYS53DVXQAA.jpg'),
(40830, 2776, 'Katy Keene S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sEcU64eQBxmIMQ1ToKCRuaDfJv0.jpg'),
(40831, 2776, 'Katy Keene S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/edVgxdJ6grsBEEiiPVROj1lBYaX.jpg'),
(40832, 2776, 'Katy Keene S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/132051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0fhkbp1HpRx7MtFOek3mOn6YHv.jpg'),
(40833, 2776, 'Katy Keene S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/132052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fZHyDfk0J4hEwDK74TxQR8aduUA.jpg'),
(40834, 2776, 'Katy Keene S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/132053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/satbjxAwa4an3dLGwHASZSXazVa.jpg'),
(40835, 2776, 'Katy Keene S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/132054.mp4', 'http://gstaticontent.com/images/bUTZY7EHg9mWrORKFY4piD0PehY_big.jpg'),
(40836, 2776, 'Katy Keene S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/132055.mp4', 'http://gstaticontent.com/images/bUTZY7EHg9mWrORKFY4piD0PehY_big.jpg'),
(40837, 2777, 'O Nome da Rosa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/132035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1PuffXgE5ju5OFAmzN3oDwtHGIa.jpg'),
(40838, 2777, 'O Nome da Rosa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/132036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8DnSUDqqUzTyaW9LKi1AliSRrA.jpg'),
(40839, 2777, 'O Nome da Rosa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/132037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6DLPSc9d4Rsea9XXzpZ8AuXXL1T.jpg'),
(40840, 2777, 'O Nome da Rosa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/132038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jWKjpZMsTjzgqR2uYirjidLtCpr.jpg'),
(40841, 2777, 'O Nome da Rosa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/132039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4LkNVLsmIH6nE1o9U8mcS9nR9Lp.jpg'),
(40842, 2777, 'O Nome da Rosa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/132040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/DfSD4cCGyQq4keMexzdBJXl5jc.jpg'),
(40843, 2777, 'O Nome da Rosa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/132041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vW1UcYN6rUUUILeGkQh7R8HzHLy.jpg'),
(40844, 2777, 'O Nome da Rosa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/132042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vZtHcPBAHST2P6kOdjVKO9MxT1y.jpg'),
(40845, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9F0giesCoij1jXh56PdTwRZ9rdx.jpg'),
(40846, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/znp8OEswXhZp2l3YrhOeuPBnOwY.jpg'),
(40847, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Adlf5sTW5RciyGwg3oly93ZNSp0.jpg'),
(40848, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lyI4a8pETFCcJ2MlVHr712inf0C.jpg'),
(40849, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/96bNzdsfTOFzEBZVxB6ypx14308.jpg'),
(40850, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wMhUJNQvRdNYblndVOfAQxBndrf.jpg'),
(40851, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4l7XIqYhhRuJn8y88fhYFcknbZG.jpg'),
(40852, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cPVafxFDlvi1z1YWZLo9lYwVrJH.jpg'),
(40853, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1YdFO36OUSHr1TkFX5BSfipcy2d.jpg'),
(40854, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yfPtoyANvbUsMnkPQRqeXBR6NCs.jpg'),
(40855, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xen3SMI4r1ZIanZvTTwpyC6JtWf.jpg'),
(40856, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a12yKvHTcFeybmpinKLPRxOPQiw.jpg'),
(40857, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sbIG3klDAmGkAjK1mDn7Qv2DRx0.jpg'),
(40858, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eySmVvz1Mqmq6nW3yvAR826WBkv.jpg'),
(40859, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yejDqCjZClVjuj13msWDZ0WbOMZ.jpg'),
(40860, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/131953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9NkCuCMMLqii9u3KtfZuVSna1Nt.jpg'),
(40861, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/131954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uDeEseFNhokucLSDkkaHSa59Yh7.jpg'),
(40862, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/131955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w1ang9JSX29tolcFx2jtSTMemPI.jpg'),
(40863, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/131956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mw3BBmTLWc58RNIDr0jRjtUSsea.jpg'),
(40864, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/131957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uYrAaX3vxRQr1kncTLn1e9mHW4I.jpg'),
(40865, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/131958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gTxHa7a5HBEfAKQN2CHZbt2tVHJ.jpg'),
(40866, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/131959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nxeyy8OxELDTv327CzszrvYrbuu.jpg'),
(40867, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/131960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nmrh56ZyHG2OOzWVYo3dEMPpMJg.jpg'),
(40868, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/131961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pmH3Ngc10GOM0yPZVreTuSMnb9E.jpg'),
(40869, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/131962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n3j9zHuRWykijG1iScUkTK8VvY5.jpg'),
(40870, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/131963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pRbcjk7ZkI1VKfq8c88qKGPMTCB.jpg'),
(40871, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/131964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s60k9isBOos2kUxV3EyMM0uzUlL.jpg'),
(40872, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/131965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oa8EEtBwbqoH4LiZx5IaMJQfloL.jpg'),
(40873, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/131966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uWg36u3ltH45dwwbg7SP7XHSBqe.jpg'),
(40874, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/131967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i41AYmvsc6aiBD4I2lr2WCZxIVN.jpg'),
(40875, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/131968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tOapqsnHz3cG5LJPWjLs10j0USA.jpg'),
(40876, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/131969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jSfJ3hD1anosvhthJ91I8AcWsuq.jpg'),
(40877, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/131970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zlrQjUh6uOMsb8vh38igaxvP0RP.jpg'),
(40878, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/131971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9TxpSKrDqgM21nFO8vVtqdHsvgn.jpg'),
(40879, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/131972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oZnTFFGmyTnk6h5LjxuZvo8kjXH.jpg'),
(40880, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/131973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7WPGUKidzoGkd0C819rP9JiZf8N.jpg'),
(40881, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/131974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2AtbxF0iRUwf8a6SHaUDMMX9BjG.jpg'),
(40882, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/131975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zKNgbomWzMG1lqWBJwq7k335rm8.jpg'),
(40883, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/131976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hM3Gc7zDRbO3mJ5jxcZoqEAJrnx.jpg'),
(40884, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/131977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pDBJt1eDZACZd1qKh8iniPhZBIu.jpg'),
(40885, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/131978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fFuf2JAwLqu09mUAXG4iQLYRAym.jpg'),
(40886, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/131979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nTKBnZnUhugJkjKnx0aUlhniS5W.jpg'),
(40887, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/131980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3kwaOn4Y0l33rLNJJvdWQZqqntR.jpg'),
(40888, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/131981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uxsqAeIZFe8G3VaimNHr9j0a6jp.jpg'),
(40889, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/131982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jNkGgm26Wf1Y9iPrwfg24WSUYaz.jpg'),
(40890, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/131983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zRt8xPWboIJwQOgUlftXMsC7A1a.jpg'),
(40891, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/131984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5cViPAjq02OF64seCLPYfNr6WtY.jpg'),
(40892, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/131985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9rC4zo8qcSuYgd2Uoa0rK9ojE8e.jpg'),
(40893, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/131986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/73MgdAyssJNAo6bvhAhNySW4A3S.jpg'),
(40894, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/131987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ho2rQQ6NGz2DD3c05Xyz36jfB4S.jpg'),
(40895, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/131988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o9Cod9BzMNewPxUmnMAAFUyxCBT.jpg'),
(40896, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/131989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7d3XhG42U63Z7ylOy1yPyuZQhI.jpg'),
(40897, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/131990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/263VJxn7s4Y5bPI9e2HPl0OUjAL.jpg'),
(40898, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/131991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6pbWozn4t07cfeQy6DhHXSO86Q.jpg'),
(40899, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/131992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6dkYrDMaMFZlHgZv3YSsmNAWNoV.jpg'),
(40900, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/131993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ys6keccj4AjUbIeqj1sZyihDnNi.jpg'),
(40901, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/131994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/opqGJancUI8xDXFVFUmU87ZWlDC.jpg'),
(40902, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/131995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/573bcUvTQcTwBcfrnyOXerRqvxE.jpg'),
(40903, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/131996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6eYZNnqWXpiSyI4IFVp88pDbe5.jpg'),
(40904, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/131997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wMoKaG10yDaBNRDEzFX71Pkeyey.jpg'),
(40905, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/131998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cU17iRNeXTy3EHrmrW51PXyeDOW.jpg'),
(40906, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/131999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/llyF72OnsSLz6zQNQekttudgF7M.jpg'),
(40907, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/132000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l4S7a1HRNu0L55I7Q8ZnVNMhVBP.jpg'),
(40908, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/132001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4op7u6ADzVz0Bkdnnwdqjb3bQYs.jpg'),
(40909, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/132002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jf7JePhxwbLkUEeVXRvRqztxlD9.jpg'),
(40910, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/132003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cxCqTmiZ8i0j1pWqhkNUrp86zuV.jpg'),
(40911, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/132004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kgxIJ1LLA6sThThUIddsYZpTRNa.jpg'),
(40912, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/132005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oRmAFrvde7p2TMDXC18WM1UftmW.jpg'),
(40913, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/132006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ebzMygNME7J62eyossK2q0m29Cs.jpg'),
(40914, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/132007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n6OxVfyuagMSpo6vZ9TTmuPxLgT.jpg'),
(40915, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/132008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tH1WviAQmiN14qijgFGPt5YenAQ.jpg'),
(40916, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/132009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rFGzPvpy15TQIlWaYEdxbnuXJU9.jpg'),
(40917, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/132010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u1IQjqoS5Ndo6FU3AnZa9YptQAq.jpg'),
(40918, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/132011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o3H5FzfofItIOtoQiJfd1ZR9LVY.jpg'),
(40919, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/132012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lYEEMlRLAANQtSBmCtiIRWxusn0.jpg'),
(40920, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/132013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfj4ZrvAQy9NjPLNKXxY9h3oHWK.jpg'),
(40921, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/132014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dcbFogKX6KppqY9Vee2lgXVwBlf.jpg'),
(40922, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/132015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gagHg6fZpAd3Mxny50NEaQr8eBF.jpg'),
(40923, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/132016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9LByJB2IkoEFL96B6R2diQTh2gQ.jpg'),
(40924, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/132017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3IDbuJlDB6V7vwLl7mj7KFgKCv0.jpg'),
(40925, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/132018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zkkWhcQeLsCHoJ7hFbqf1NA0878.jpg'),
(40926, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/132019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qdgGlMauKbkHambuTezo8sI9Ka4.jpg'),
(40927, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/132020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/stT8h3N5RZb23h08Wv6PKs5QR6.jpg'),
(40928, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/132021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xDIFC3G5K4oWjqwOZM151vbbygU.jpg'),
(40929, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/132022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/trwNUuS8gdtvWpiPrywSt5Cgkeh.jpg'),
(40930, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/132023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bJoYt4ChZSY6wkh6lZBxIGo4SZb.jpg'),
(40931, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/132024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/22GsreD6n381mv4E7zB4uN5j1C9.jpg'),
(40932, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/132025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tkNEGWweAQV1Osn1mMIcR7Xuuf3.jpg'),
(40933, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/132026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ORlhRrq20Uv3am7IBD0GmVgaiP.jpg'),
(40934, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/132027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vVC2DRNEhpDkjpOcw8OPufbZPfE.jpg'),
(40935, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/132028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jEUFUC9M3LvbD4yWvSLczLDxtjD.jpg'),
(40936, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/132029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0IEoBK2dmJDmHli0NfKR7SDXjO.jpg'),
(40937, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/132030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2wGDpGycnopilrunlchinsCKpOL.jpg'),
(40938, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/132031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Qgigvdlj1LuoqXP0gJRBfNQaNy.jpg'),
(40939, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/132032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lmYobc8T35F8CCFf7fWJitr3ada.jpg'),
(40940, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/132033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1KUvaRzSmjpIFwdOaWijl1H2wn9.jpg'),
(40941, 2778, 'Os Cavaleiros do Zodíaco: Ômega S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/132034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQ6nVGUTEsVLBtdYU23ugGyBsZ5.jpg'),
(40942, 2779, 'Paranormal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oWkXAkdUijqvOZqrQXCnhWARWr4.jpg'),
(40943, 2779, 'Paranormal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bWkhjuwkj7LsswnqL49e7fMHyGp.jpg'),
(40944, 2779, 'Paranormal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/64phbD2JkdzvKu3eGAzf9O59Tiw.jpg'),
(40945, 2779, 'Paranormal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eD1oBaukiP2WHm1hXU2WSKTvgCW.jpg'),
(40946, 2779, 'Paranormal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gWT0p3peZYmpkOKKSJIZCasKyDg.jpg'),
(40947, 2779, 'Paranormal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A9lIdEq2wTcK8ng0zyPmfzLqnqK.jpg'),
(40948, 2780, 'Suburra: Sangue em Roma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131908.mp4', 'http://image.tmdb.org/t/p/w300/9jYmv5IJFEEDyI2Cwv0FZd80eGf.jpg'),
(40949, 2780, 'Suburra: Sangue em Roma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131909.mp4', 'http://image.tmdb.org/t/p/w300/3ZFoNcntHyNkBurECnOUhjCzXvk.jpg'),
(40950, 2780, 'Suburra: Sangue em Roma S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131910.mp4', 'http://image.tmdb.org/t/p/w300/vNAvkPwZfgGwfd5klOwNiXc6SEo.jpg'),
(40951, 2780, 'Suburra: Sangue em Roma S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131911.mp4', 'http://image.tmdb.org/t/p/w300/u8EZLUN2o0oA8TLExIP9FTZZf4p.jpg'),
(40952, 2780, 'Suburra: Sangue em Roma S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131912.mp4', 'http://image.tmdb.org/t/p/w300/nH3FYRJpyS6TZPn0cMsgLJLwd1x.jpg'),
(40953, 2780, 'Suburra: Sangue em Roma S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131913.mp4', 'http://image.tmdb.org/t/p/w300/mliLHfYEfgdiB887JfRDGcpvq34.jpg'),
(40954, 2780, 'Suburra: Sangue em Roma S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131914.mp4', 'http://image.tmdb.org/t/p/w300/yl6Bbe9qMMwk8udZDiVq9DqVV0l.jpg'),
(40955, 2780, 'Suburra: Sangue em Roma S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131915.mp4', 'http://image.tmdb.org/t/p/w300/6WAGFs4C2tdiuiLmuCSRmuJMYJc.jpg'),
(40956, 2780, 'Suburra: Sangue em Roma S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131916.mp4', 'http://image.tmdb.org/t/p/w300/iPffqDebiQbajxERVjkf9jYXTG8.jpg'),
(40957, 2780, 'Suburra: Sangue em Roma S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131917.mp4', 'http://image.tmdb.org/t/p/w300/vn5zd8Gas89D1JtaBNaPZk94oyL.jpg'),
(40958, 2781, 'Suburra: Sangue em Roma S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131918.mp4', 'http://image.tmdb.org/t/p/w300/vn5zd8Gas89D1JtaBNaPZk94oyL.jpg'),
(40959, 2781, 'Suburra: Sangue em Roma S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131919.mp4', 'http://image.tmdb.org/t/p/w300/vn5zd8Gas89D1JtaBNaPZk94oyL.jpg'),
(40960, 2781, 'Suburra: Sangue em Roma S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131920.mp4', 'http://image.tmdb.org/t/p/w300/vn5zd8Gas89D1JtaBNaPZk94oyL.jpg'),
(40961, 2781, 'Suburra: Sangue em Roma S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131921.mp4', 'http://image.tmdb.org/t/p/w300/vn5zd8Gas89D1JtaBNaPZk94oyL.jpg'),
(40962, 2781, 'Suburra: Sangue em Roma S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131922.mp4', 'http://image.tmdb.org/t/p/w300/vn5zd8Gas89D1JtaBNaPZk94oyL.jpg'),
(40963, 2781, 'Suburra: Sangue em Roma S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131923.mp4', 'http://image.tmdb.org/t/p/w300/vn5zd8Gas89D1JtaBNaPZk94oyL.jpg'),
(40964, 2781, 'Suburra: Sangue em Roma S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131924.mp4', 'http://image.tmdb.org/t/p/w300/vn5zd8Gas89D1JtaBNaPZk94oyL.jpg'),
(40965, 2781, 'Suburra: Sangue em Roma S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131925.mp4', 'http://image.tmdb.org/t/p/w300/vn5zd8Gas89D1JtaBNaPZk94oyL.jpg'),
(40966, 2782, 'Suburra: Sangue em Roma S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131926.mp4', 'http://image.tmdb.org/t/p/w300/vmGgQlXBJRuBlZ9Jl4QapN6JZ0Z.jpg'),
(40967, 2782, 'Suburra: Sangue em Roma S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131927.mp4', 'http://image.tmdb.org/t/p/w300/zmrQixsteUyZAXRMQxcBEglyFYy.jpg'),
(40968, 2782, 'Suburra: Sangue em Roma S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131928.mp4', 'http://image.tmdb.org/t/p/w300/gPkNPhtWc3EL7P2XquztJZZT32B.jpg'),
(40969, 2782, 'Suburra: Sangue em Roma S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131929.mp4', 'http://image.tmdb.org/t/p/w300/qWrICNwEnNuzk5qACrCYdAs43a9.jpg'),
(40970, 2782, 'Suburra: Sangue em Roma S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131930.mp4', 'http://image.tmdb.org/t/p/w300/nOJoQb9avfGUB74PAuFVUE7XEzT.jpg'),
(40971, 2782, 'Suburra: Sangue em Roma S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131931.mp4', 'http://image.tmdb.org/t/p/w300/6QekIi6O0CY3QxmxrfIUxoXAKAl.jpg'),
(40972, 2783, 'The Middle S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131697.mp4', 'http://image.tmdb.org/t/p/w300/vgJsLMwGHWLEoOZB6qOpn2TLB4Q.jpg'),
(40973, 2783, 'The Middle S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131698.mp4', 'http://image.tmdb.org/t/p/w300/lsrcs8z2wbejP9HjoskZa2JXZz5.jpg'),
(40974, 2783, 'The Middle S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131699.mp4', 'http://image.tmdb.org/t/p/w300/cSBGYqW9hRljyBsg6HJ5kkwFH2C.jpg'),
(40975, 2783, 'The Middle S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131700.mp4', 'http://image.tmdb.org/t/p/w300/rfTi8OVKi4rj9bX0Vlmec1HJX9d.jpg'),
(40976, 2783, 'The Middle S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131701.mp4', 'http://image.tmdb.org/t/p/w300/8pwAIhtockzqpDE2GNtxCN4dDRp.jpg'),
(40977, 2783, 'The Middle S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131702.mp4', 'http://image.tmdb.org/t/p/w300/3qba72N7tpzLfy23C8WclIFUmk6.jpg'),
(40978, 2783, 'The Middle S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131703.mp4', 'http://image.tmdb.org/t/p/w300/xl7bYopZWoA6U4JF0aLkzUCzw6Q.jpg'),
(40979, 2783, 'The Middle S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131704.mp4', 'http://image.tmdb.org/t/p/w300/oGFmH0HsayKOVp30NWDwKQfOzr4.jpg'),
(40980, 2783, 'The Middle S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131705.mp4', 'http://image.tmdb.org/t/p/w300/hAaB62lP3UGTe40BJjfge50EV0k.jpg'),
(40981, 2783, 'The Middle S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131706.mp4', 'http://image.tmdb.org/t/p/w300/4ZXg4ZL2PhSpk9oMGupvJUMlAMU.jpg'),
(40982, 2783, 'The Middle S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131707.mp4', 'http://image.tmdb.org/t/p/w300/k2l4Ym6fEnLZVuoVaxP3rYgvCpi.jpg'),
(40983, 2783, 'The Middle S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131708.mp4', 'http://image.tmdb.org/t/p/w300/uG260p5piYGIhXG9Dfn4ARnlYrt.jpg'),
(40984, 2783, 'The Middle S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131709.mp4', 'http://image.tmdb.org/t/p/w300/nMXq8fmIXE7wfhA03cGuYFSct4q.jpg'),
(40985, 2783, 'The Middle S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131710.mp4', 'http://image.tmdb.org/t/p/w300/kUCf1SgK6AwRMdJEe3SVeqxe8wV.jpg'),
(40986, 2783, 'The Middle S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131711.mp4', 'http://image.tmdb.org/t/p/w300/27sLMXTg3FVy7a4wjL2OWl0B9Vf.jpg'),
(40987, 2783, 'The Middle S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/131712.mp4', 'http://image.tmdb.org/t/p/w300/hp6KAGCGi8kAivJt5aeWu5X1wAD.jpg'),
(40988, 2783, 'The Middle S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/131713.mp4', 'http://image.tmdb.org/t/p/w300/2cN1xgxDgCOfoB6Ik9H1Hu0P6M8.jpg'),
(40989, 2783, 'The Middle S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/131714.mp4', 'http://image.tmdb.org/t/p/w300/92DmLutOw99yQjtVpPx4lqFspwW.jpg'),
(40990, 2783, 'The Middle S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/131715.mp4', 'http://image.tmdb.org/t/p/w300/eq9GdnFNKMQz5EHyIqGzLqBzaBR.jpg'),
(40991, 2783, 'The Middle S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/131716.mp4', 'http://image.tmdb.org/t/p/w300/frFOj3eOemLY1KdngllIc2IUf9U.jpg'),
(40992, 2783, 'The Middle S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/131717.mp4', 'http://image.tmdb.org/t/p/w300/uzxLVLP5k4D6bg10fOkZltjE0bG.jpg'),
(40993, 2783, 'The Middle S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/131718.mp4', 'http://image.tmdb.org/t/p/w300/72SrTvDn16O4VSOj7xShf1AfWVx.jpg'),
(40994, 2783, 'The Middle S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/131719.mp4', 'http://image.tmdb.org/t/p/w300/mgUhfmRJrNw8FO4JJ84E5xFW4RI.jpg'),
(40995, 2783, 'The Middle S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/131720.mp4', 'http://image.tmdb.org/t/p/w300/sQWHRTBU2lOXug5ZUDrpzvliYKG.jpg'),
(40996, 2784, 'The Middle S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131721.mp4', 'http://image.tmdb.org/t/p/w300/4BYpLQC2wFQxHSikP70D0jQdrlI.jpg'),
(40997, 2784, 'The Middle S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131722.mp4', 'http://image.tmdb.org/t/p/w300/A6HUARe3M8DJ7nKbJ7YGmMtrg2f.jpg'),
(40998, 2784, 'The Middle S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131723.mp4', 'http://image.tmdb.org/t/p/w300/dIxVdpW1oBo8022jz2x5qfVTmCs.jpg'),
(40999, 2784, 'The Middle S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131724.mp4', 'http://image.tmdb.org/t/p/w300/uOQNzcqaZePx2SP3nICOBI7SoC5.jpg'),
(41000, 2784, 'The Middle S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131725.mp4', 'http://image.tmdb.org/t/p/w300/ziGy7xqVk7s1hjZE8f5hsnWTX68.jpg'),
(41001, 2784, 'The Middle S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131726.mp4', 'http://image.tmdb.org/t/p/w300/3Xb24HL5ryV3SuM7pxUGdu8FYlo.jpg'),
(41002, 2784, 'The Middle S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131727.mp4', 'http://image.tmdb.org/t/p/w300/2jOaV37NelPlrzOs4tVOPVnTSTg.jpg'),
(41003, 2784, 'The Middle S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131728.mp4', 'http://image.tmdb.org/t/p/w300/AjS34ndRMFBaQdjUrIohlg7Wy57.jpg'),
(41004, 2784, 'The Middle S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131729.mp4', 'http://image.tmdb.org/t/p/w300/hrJ8HuPoDv3GIQnVPTZEoQqJ4kh.jpg'),
(41005, 2784, 'The Middle S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131730.mp4', 'http://image.tmdb.org/t/p/w300/8bkePjNKlCIjiotxixR8xJiB2j5.jpg'),
(41006, 2784, 'The Middle S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131731.mp4', 'http://image.tmdb.org/t/p/w300/9tOsMRbS0pOeOP7XwDRYCysTiqC.jpg'),
(41007, 2784, 'The Middle S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131732.mp4', 'http://image.tmdb.org/t/p/w300/pYGvGo8ZjXRA2HUVGpBoZEU3Zfo.jpg'),
(41008, 2784, 'The Middle S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131733.mp4', 'http://image.tmdb.org/t/p/w300/ttcIA5wvt7FKH8FfbWQRUtdu747.jpg'),
(41009, 2784, 'The Middle S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131734.mp4', 'http://image.tmdb.org/t/p/w300/wV2PxdFHDxjf58HMFzZkR8oV39M.jpg'),
(41010, 2784, 'The Middle S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131735.mp4', 'http://image.tmdb.org/t/p/w300/rpdnxpUt1WXsKelDLlYIgIVcUVh.jpg'),
(41011, 2784, 'The Middle S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/131736.mp4', 'http://image.tmdb.org/t/p/w300/zbODKKnttxEf7z7tEl1hfRNMv1g.jpg'),
(41012, 2784, 'The Middle S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/131737.mp4', 'http://image.tmdb.org/t/p/w300/myFXdcMWOjc7N23111XLdXjWgbE.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(41013, 2784, 'The Middle S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/131738.mp4', 'http://image.tmdb.org/t/p/w300/z4WbEmhdcg3eKcp3Hj5oCwrGwl0.jpg'),
(41014, 2784, 'The Middle S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/131739.mp4', 'http://image.tmdb.org/t/p/w300/sjhevu842sl1WXqJVChQmFQEk1R.jpg'),
(41015, 2784, 'The Middle S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/131740.mp4', 'http://image.tmdb.org/t/p/w300/enx4FwAbnnSUo0sJCLHk4AmIMZA.jpg'),
(41016, 2784, 'The Middle S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/131741.mp4', 'http://image.tmdb.org/t/p/w300/5Kksah9NZ4VgNRAkp8kpM8xXZYy.jpg'),
(41017, 2784, 'The Middle S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/131742.mp4', 'http://image.tmdb.org/t/p/w300/XO2QK4JSOXVsjG9wcJcBz5ABaw.jpg'),
(41018, 2784, 'The Middle S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/131743.mp4', 'http://image.tmdb.org/t/p/w300/fsXyks4ZqEE9NAelMOhK5VGoBO3.jpg'),
(41019, 2784, 'The Middle S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/131744.mp4', 'http://image.tmdb.org/t/p/w300/VpWDG3CU0m0Q4LIDi7CWkf9Kuk.jpg'),
(41020, 2785, 'The Middle S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131745.mp4', 'http://image.tmdb.org/t/p/w300/eruqr3VASh1aCjZVpDICFxIyqbv.jpg'),
(41021, 2785, 'The Middle S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131746.mp4', 'http://image.tmdb.org/t/p/w300/itNnnw3JLlEtCuwKuDAPlV6o4EX.jpg'),
(41022, 2785, 'The Middle S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131747.mp4', 'http://image.tmdb.org/t/p/w300/bDcYHsu4rWTuDr3iJanoWKAt4Yl.jpg'),
(41023, 2785, 'The Middle S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131748.mp4', 'http://image.tmdb.org/t/p/w300/bgGDyADFQOC19WJb85OFjWt6uGw.jpg'),
(41024, 2785, 'The Middle S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131749.mp4', 'http://image.tmdb.org/t/p/w300/jhluJAN6Lu3RpaEvBKQBj1SQs2j.jpg'),
(41025, 2785, 'The Middle S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131750.mp4', 'http://image.tmdb.org/t/p/w300/6vCj69mKJ8HNmmiuZ3noKzyXPZa.jpg'),
(41026, 2785, 'The Middle S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131751.mp4', 'http://image.tmdb.org/t/p/w300/7C00VeHXe49L9X0D5lyDEGBu6MO.jpg'),
(41027, 2785, 'The Middle S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131752.mp4', 'http://image.tmdb.org/t/p/w300/mancTjmJAXHWWkhthT5FvLZDa09.jpg'),
(41028, 2785, 'The Middle S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131753.mp4', 'http://image.tmdb.org/t/p/w300/bl6UsjbFfM70wEpncBQQgaQuJFG.jpg'),
(41029, 2785, 'The Middle S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131754.mp4', 'http://image.tmdb.org/t/p/w300/gCzbkwrpsU8KApdmAB3vxpdAQxQ.jpg'),
(41030, 2785, 'The Middle S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131755.mp4', 'http://image.tmdb.org/t/p/w300/mGnTeS9Klv1NrL0LIsVL35CLSq9.jpg'),
(41031, 2785, 'The Middle S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131756.mp4', 'http://image.tmdb.org/t/p/w300/ecO48IEPZtsLENn9gjLmnqg50wW.jpg'),
(41032, 2785, 'The Middle S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131757.mp4', 'http://image.tmdb.org/t/p/w300/duyTDyguHV3ZQSNSCF6GcsUedBj.jpg'),
(41033, 2785, 'The Middle S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131758.mp4', 'http://image.tmdb.org/t/p/w300/lFU0Bfv69ifz9QXdLiv3hS7trK3.jpg'),
(41034, 2785, 'The Middle S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131759.mp4', 'http://image.tmdb.org/t/p/w300/pmc7rP3ej0WQMkffzLTbqBsmNad.jpg'),
(41035, 2785, 'The Middle S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/131760.mp4', 'http://image.tmdb.org/t/p/w300/9RHt8PgPkcHQtO9S78xMezrNYN7.jpg'),
(41036, 2785, 'The Middle S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/131761.mp4', 'http://image.tmdb.org/t/p/w300/mN03hKaxeSt2uK06UNZ3ATEPUG.jpg'),
(41037, 2785, 'The Middle S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/131762.mp4', 'http://image.tmdb.org/t/p/w300/1d5wxKTZFCDlPaefSFFBbXY5mGh.jpg'),
(41038, 2785, 'The Middle S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/131763.mp4', 'http://image.tmdb.org/t/p/w300/94ECWJ8fGMocCfrq5mZEd1hMQku.jpg'),
(41039, 2785, 'The Middle S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/131764.mp4', 'http://image.tmdb.org/t/p/w300/zLaR6Fbl8NLmERNX4J9gFEg82uP.jpg'),
(41040, 2785, 'The Middle S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/131765.mp4', 'http://image.tmdb.org/t/p/w300/jXMnL0RHfaRokf5m2CFd1q1kfu4.jpg'),
(41041, 2785, 'The Middle S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/131766.mp4', 'http://image.tmdb.org/t/p/w300/9l5gRIDcN6mlJnSZa4suZvgM9En.jpg'),
(41042, 2785, 'The Middle S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/131767.mp4', 'http://image.tmdb.org/t/p/w300/mqOobWcm5VhxCgS1YWIU4p1DW75.jpg'),
(41043, 2786, 'The Middle S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131768.mp4', 'http://image.tmdb.org/t/p/w300/lGRejPCeYsi7XjGycVRQ78rCfch.jpg'),
(41044, 2786, 'The Middle S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131769.mp4', 'http://image.tmdb.org/t/p/w300/h5CssduLLsOmBObiP0TKFfALifD.jpg'),
(41045, 2786, 'The Middle S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131770.mp4', 'http://image.tmdb.org/t/p/w300/fYauAlMZOGnyOWDHUL3G4xLL8Nj.jpg'),
(41046, 2786, 'The Middle S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131771.mp4', 'http://image.tmdb.org/t/p/w300/hR3NChrorNwxkcDQD7xmm6bAHj8.jpg'),
(41047, 2786, 'The Middle S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131772.mp4', 'http://image.tmdb.org/t/p/w300/kEdtzs6gnXrrs3nl4kSF6NiixBp.jpg'),
(41048, 2786, 'The Middle S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131773.mp4', 'http://image.tmdb.org/t/p/w300/qwOw46mIqqEWBatENdgUoOz5Hmb.jpg'),
(41049, 2786, 'The Middle S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131774.mp4', 'http://image.tmdb.org/t/p/w300/7zf0zxgUo9oQHDmZPquglI0ZNqK.jpg'),
(41050, 2786, 'The Middle S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131775.mp4', 'http://image.tmdb.org/t/p/w300/3Bit9sCxJ0lhbPQmMxfaSMB6uIO.jpg'),
(41051, 2786, 'The Middle S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131776.mp4', 'http://image.tmdb.org/t/p/w300/jqmHnIZvPTf7jaIkQZyicdzWBYo.jpg'),
(41052, 2786, 'The Middle S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131777.mp4', 'http://image.tmdb.org/t/p/w300/hIht8OV2PxjKuyvwWemZglnO9BW.jpg'),
(41053, 2786, 'The Middle S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131778.mp4', 'http://image.tmdb.org/t/p/w300/yNZg2v8nvRY0H4cMDAKN32xyvMP.jpg'),
(41054, 2786, 'The Middle S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131779.mp4', 'http://image.tmdb.org/t/p/w300/cqFAyoaCLoH4T5MPpm7mDZy64qx.jpg'),
(41055, 2786, 'The Middle S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131780.mp4', 'http://image.tmdb.org/t/p/w300/t57S7478a3pCeyFW9KvVuAFcSSt.jpg'),
(41056, 2786, 'The Middle S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131781.mp4', 'http://image.tmdb.org/t/p/w300/aXhqicfWYGSV3E3zhnzyGlEcWMo.jpg'),
(41057, 2786, 'The Middle S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131782.mp4', 'http://image.tmdb.org/t/p/w300/lSi0KVo6HXEo4OKvWTTCyLWxKeY.jpg'),
(41058, 2786, 'The Middle S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/131783.mp4', 'http://image.tmdb.org/t/p/w300/eSD0uABfEDt3oRG3jAGAjWfdRay.jpg'),
(41059, 2786, 'The Middle S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/131784.mp4', 'http://image.tmdb.org/t/p/w300/2QZYHOAB7JldceSGlXzfdLgeySA.jpg'),
(41060, 2786, 'The Middle S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/131785.mp4', 'http://image.tmdb.org/t/p/w300/fw5lUpWXcpeLhubeuf5Gq3rNwq6.jpg'),
(41061, 2786, 'The Middle S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/131786.mp4', 'http://image.tmdb.org/t/p/w300/vRRkWN4sKJRqrw2GWoCaIFxM9CG.jpg'),
(41062, 2786, 'The Middle S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/131787.mp4', 'http://image.tmdb.org/t/p/w300/xtiHWxcf8ysYEagXpGtM3vuz9GF.jpg'),
(41063, 2786, 'The Middle S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/131788.mp4', 'http://image.tmdb.org/t/p/w300/ugLdDw9QlCFdXJVN0X9Bp8CuTyu.jpg'),
(41064, 2786, 'The Middle S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/131789.mp4', 'http://image.tmdb.org/t/p/w300/hPTXjKp7w8KKFyfmvVrlXoYXhJe.jpg'),
(41065, 2786, 'The Middle S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/131790.mp4', 'http://image.tmdb.org/t/p/w300/kNwQ2UJ9IsogPUNArfptD1K1UTr.jpg'),
(41066, 2787, 'The Middle S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131791.mp4', 'http://image.tmdb.org/t/p/w300/1zpXR2IkMEy35FQFB1RqfOFwfAM.jpg'),
(41067, 2787, 'The Middle S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131792.mp4', 'http://image.tmdb.org/t/p/w300/ypC9I4cLQL6QP3tetLClLTr0SHv.jpg'),
(41068, 2787, 'The Middle S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131793.mp4', 'http://image.tmdb.org/t/p/w300/rf3T00kjvum8ykcfUDxoM1pMFla.jpg'),
(41069, 2787, 'The Middle S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131794.mp4', 'http://image.tmdb.org/t/p/w300/rWjpOFcPuDq7NjUtCBIg5MJ5hhG.jpg'),
(41070, 2787, 'The Middle S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131795.mp4', 'http://image.tmdb.org/t/p/w300/33P2WHAoeL5UVBakDuht1cwxVgT.jpg'),
(41071, 2787, 'The Middle S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131796.mp4', 'http://image.tmdb.org/t/p/w300/pzjVA5YwQ2aBPuCbdiMhoLlFUa4.jpg'),
(41072, 2787, 'The Middle S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131797.mp4', 'http://image.tmdb.org/t/p/w300/7wLnzMPAF7CNZ7LpcewbNLonCGE.jpg'),
(41073, 2787, 'The Middle S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131798.mp4', 'http://image.tmdb.org/t/p/w300/bmtbxmSC85ihjY21TRs14C5EJBc.jpg'),
(41074, 2787, 'The Middle S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131799.mp4', 'http://image.tmdb.org/t/p/w300/4ecHOo32uri1DyXyITdYzRKAQto.jpg'),
(41075, 2787, 'The Middle S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131800.mp4', 'http://image.tmdb.org/t/p/w300/JvzTXufhYKPnAuYmxZCvpx1Iyo.jpg'),
(41076, 2787, 'The Middle S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131801.mp4', 'http://image.tmdb.org/t/p/w300/cn2AUeF7IbGAU0vuELcr7BuBbOZ.jpg'),
(41077, 2787, 'The Middle S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131802.mp4', 'http://image.tmdb.org/t/p/w300/gY1pvblB8j3txXJPflbgRBBbe1C.jpg'),
(41078, 2787, 'The Middle S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131803.mp4', 'http://image.tmdb.org/t/p/w300/rTsXIqp1pSzZUHA5llCk6NzVUOE.jpg'),
(41079, 2787, 'The Middle S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131804.mp4', 'http://image.tmdb.org/t/p/w300/6DdKbM2XGUq4V2x8cbJoxsfL2EE.jpg'),
(41080, 2787, 'The Middle S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131805.mp4', 'http://image.tmdb.org/t/p/w300/54LXyZrXwfg6Rgyb6nNCrtxGMHL.jpg'),
(41081, 2787, 'The Middle S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/131806.mp4', 'http://image.tmdb.org/t/p/w300/20x8gMBTOQZhkxxStNT2EN2rAOb.jpg'),
(41082, 2787, 'The Middle S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/131807.mp4', 'http://image.tmdb.org/t/p/w300/h3ccPxK8eZDtdSFFLPgDiognEO0.jpg'),
(41083, 2787, 'The Middle S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/131808.mp4', 'http://image.tmdb.org/t/p/w300/sOliTgtIxz3wF46vUs5owmW6gl2.jpg'),
(41084, 2787, 'The Middle S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/131809.mp4', 'http://image.tmdb.org/t/p/w300/paaL6NfXbExNZA0iCZPpWA2rLDy.jpg'),
(41085, 2787, 'The Middle S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/131810.mp4', 'http://image.tmdb.org/t/p/w300/k3GFC7fpyUGuOQzo5bMMCiD4ZvL.jpg'),
(41086, 2787, 'The Middle S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/131811.mp4', 'http://image.tmdb.org/t/p/w300/clSgWtsg1nWVvkaZQ0CWDKsh7ne.jpg'),
(41087, 2787, 'The Middle S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/131812.mp4', 'http://image.tmdb.org/t/p/w300/5Ag4rfXfwi88C57i4drkqyIRepm.jpg'),
(41088, 2787, 'The Middle S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/131813.mp4', 'http://image.tmdb.org/t/p/w300/wVxYvZBdvPYeCyjQInuHtj5mrtj.jpg'),
(41089, 2788, 'The Middle S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131814.mp4', 'http://image.tmdb.org/t/p/w300/3gmz394pZQzxVwBuPkM9L2MA9IK.jpg'),
(41090, 2788, 'The Middle S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131815.mp4', 'http://image.tmdb.org/t/p/w300/puyR1ayxpRBUt5yziZEJDiIoYD2.jpg'),
(41091, 2788, 'The Middle S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131816.mp4', 'http://image.tmdb.org/t/p/w300/fONwmH7HUhOnsBIskGz0aP90nVS.jpg'),
(41092, 2788, 'The Middle S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131817.mp4', 'http://image.tmdb.org/t/p/w300/kQeSrd2yxDg7Koe2hQv00K1qs0o.jpg'),
(41093, 2788, 'The Middle S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131818.mp4', 'http://image.tmdb.org/t/p/w300/pNvumMREeenZlr10eOSQXWOWqj6.jpg'),
(41094, 2788, 'The Middle S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131819.mp4', 'http://image.tmdb.org/t/p/w300/yKBCMcpYXJsqXjRbbP2V14HPnba.jpg'),
(41095, 2788, 'The Middle S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131820.mp4', 'http://image.tmdb.org/t/p/w300/bodWbom1Tdo72Bduj8wuxa90ofD.jpg'),
(41096, 2788, 'The Middle S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131821.mp4', 'http://image.tmdb.org/t/p/w300/kVyS3sGDrww5yGP37czWXeRzM2z.jpg'),
(41097, 2788, 'The Middle S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131822.mp4', 'http://image.tmdb.org/t/p/w300/7q8uXyFzfDmvTpoJymtObp9Mbll.jpg'),
(41098, 2788, 'The Middle S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131823.mp4', 'http://image.tmdb.org/t/p/w300/atO1dYoLFmIAxQZaZ7F2ZDm4j2Z.jpg'),
(41099, 2788, 'The Middle S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131824.mp4', 'http://image.tmdb.org/t/p/w300/gvIKu53ypP5rA7D27Fy2mGB9TXh.jpg'),
(41100, 2788, 'The Middle S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131825.mp4', 'http://image.tmdb.org/t/p/w300/gwuEO8N4Vqq9nxYNNf0rmryzyIs.jpg'),
(41101, 2788, 'The Middle S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131826.mp4', 'http://image.tmdb.org/t/p/w300/jmrvSetoohqJZAGavJDpXvhunyN.jpg'),
(41102, 2788, 'The Middle S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131827.mp4', 'http://image.tmdb.org/t/p/w300/lB3qUEFoN99Rv3RjPInNjt4IYpo.jpg'),
(41103, 2788, 'The Middle S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131828.mp4', 'http://image.tmdb.org/t/p/w300/83Z0xKoA9KhzPNSUb9whjaZlLVb.jpg'),
(41104, 2788, 'The Middle S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/131829.mp4', 'http://image.tmdb.org/t/p/w300/kOSaVfPc7xK7CLXrI6hFxi51Ah2.jpg'),
(41105, 2788, 'The Middle S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/131830.mp4', 'http://image.tmdb.org/t/p/w300/889LxLPuc5b93pt7nNfdmWImZhU.jpg'),
(41106, 2788, 'The Middle S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/131831.mp4', 'http://image.tmdb.org/t/p/w300/8j5v3qJi5UHJWO0G3tYS0RV4GgJ.jpg'),
(41107, 2788, 'The Middle S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/131832.mp4', 'http://image.tmdb.org/t/p/w300/bw7q3TCLOQJFal2JGWhYhtuGmje.jpg'),
(41108, 2788, 'The Middle S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/131833.mp4', 'http://image.tmdb.org/t/p/w300/rP1wlhWqMh1hrxN3T7wI5uipgq6.jpg'),
(41109, 2788, 'The Middle S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/131834.mp4', 'http://image.tmdb.org/t/p/w300/eDRSHuIPs6BOfANaUJIhJNOINTV.jpg'),
(41110, 2788, 'The Middle S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/131835.mp4', 'http://image.tmdb.org/t/p/w300/u2cnuz1XGqapIsN9sgvzvKaxnrd.jpg'),
(41111, 2788, 'The Middle S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/131836.mp4', 'http://image.tmdb.org/t/p/w300/ooHDGjzMzaLUQujUfoh48ahRlKO.jpg'),
(41112, 2788, 'The Middle S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/131837.mp4', 'http://image.tmdb.org/t/p/w300/fUSWKtm3At3db8vl5bBVkoc9rp8.jpg'),
(41113, 2789, 'The Middle S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131838.mp4', 'http://image.tmdb.org/t/p/w300/wQvbllb8xDyy5zfUHaU48bXcW2O.jpg'),
(41114, 2789, 'The Middle S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131839.mp4', 'http://image.tmdb.org/t/p/w300/wceTF9A9GbCfuAzr4m4oDBBwsHJ.jpg'),
(41115, 2789, 'The Middle S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131840.mp4', 'http://image.tmdb.org/t/p/w300/dsduoxSPDjYXR7wfDJdkhNtBTgd.jpg'),
(41116, 2789, 'The Middle S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131841.mp4', 'http://image.tmdb.org/t/p/w300/suUXy3HPX0p4ojjBStu8lKBGHno.jpg'),
(41117, 2789, 'The Middle S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131842.mp4', 'http://image.tmdb.org/t/p/w300/rFu6CPtjddLt4JoQzoSiwffIgPg.jpg'),
(41118, 2789, 'The Middle S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131843.mp4', 'http://image.tmdb.org/t/p/w300/zuHtG4B5MqnTEDdkuUv9F8KZ5En.jpg'),
(41119, 2789, 'The Middle S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131844.mp4', 'http://image.tmdb.org/t/p/w300/aK1jDM9hoHFQ9zXVIWIaqnA2Fq5.jpg'),
(41120, 2789, 'The Middle S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131845.mp4', 'http://image.tmdb.org/t/p/w300/fXWfL2FhuegfpoPiFtPUTvkZlPk.jpg'),
(41121, 2789, 'The Middle S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131846.mp4', 'http://image.tmdb.org/t/p/w300/2Se1JjLEiroTE28hGpD2OCtbjbE.jpg'),
(41122, 2789, 'The Middle S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131847.mp4', 'http://image.tmdb.org/t/p/w300/9wx1aWmpjJxrfP9OLhxNVeDD4VS.jpg'),
(41123, 2789, 'The Middle S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131848.mp4', 'http://image.tmdb.org/t/p/w300/tAh9KgJdZuxEbr7iLrWxpED3cMS.jpg'),
(41124, 2789, 'The Middle S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131849.mp4', 'http://image.tmdb.org/t/p/w300/icDGD0C6orqadaBzVLm28Oy0i5W.jpg'),
(41125, 2789, 'The Middle S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131850.mp4', 'http://image.tmdb.org/t/p/w300/wJiFS485aW1yn3rs6VDAFEAtWbq.jpg'),
(41126, 2789, 'The Middle S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131851.mp4', 'http://image.tmdb.org/t/p/w300/f6ecjciJauSAIdlyuC4rUjcVeeJ.jpg'),
(41127, 2789, 'The Middle S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131852.mp4', 'http://image.tmdb.org/t/p/w300/f0Rcpq1l0VMtWohicxSgd8x6u6J.jpg'),
(41128, 2789, 'The Middle S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/131853.mp4', 'http://image.tmdb.org/t/p/w300/yS21x60C3wLr68cOJQmZ6u4m3Cn.jpg'),
(41129, 2789, 'The Middle S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/131854.mp4', 'http://image.tmdb.org/t/p/w300/3LMIsJDB4mbKuoutFTO0wb7eqQU.jpg'),
(41130, 2789, 'The Middle S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/131855.mp4', 'http://image.tmdb.org/t/p/w300/8r8uvYGDyGkP6uJaWtXx5cLDdtY.jpg'),
(41131, 2789, 'The Middle S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/131856.mp4', 'http://image.tmdb.org/t/p/w300/mdQtLUzbsgmLgEFikJqXlRtaXBK.jpg'),
(41132, 2789, 'The Middle S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/131857.mp4', 'http://image.tmdb.org/t/p/w300/xJJNHb8cYg992Wf7Z0PUUGz8m3m.jpg'),
(41133, 2789, 'The Middle S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/131858.mp4', 'http://image.tmdb.org/t/p/w300/malHvnV68RJfhnYnq3n2CRnqb9b.jpg'),
(41134, 2789, 'The Middle S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/131859.mp4', 'http://image.tmdb.org/t/p/w300/vv1awGFYyAPgzWVFz3dzUMacSux.jpg'),
(41135, 2789, 'The Middle S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/131860.mp4', 'http://image.tmdb.org/t/p/w300/upnx2eaEFGHJpO6Vo5Ya6iqrbYe.jpg'),
(41136, 2789, 'The Middle S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/131861.mp4', 'http://image.tmdb.org/t/p/w300/pBfjwbhKIXDTJa0XIc6MHZsCuSs.jpg'),
(41137, 2790, 'The Middle S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131862.mp4', 'http://image.tmdb.org/t/p/w300/1sztMsTWJPlNqYnp3ERiFDXgaQF.jpg'),
(41138, 2790, 'The Middle S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131863.mp4', 'http://image.tmdb.org/t/p/w300/rdZY8ceJegRlPfb0LKgazOHKReH.jpg'),
(41139, 2790, 'The Middle S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131864.mp4', 'http://image.tmdb.org/t/p/w300/56384DoUasLN2xQVuU2kjEN6kWZ.jpg'),
(41140, 2790, 'The Middle S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131865.mp4', 'http://image.tmdb.org/t/p/w300/ixWDjoeUGUXTErR00eRXZyjHDCS.jpg'),
(41141, 2790, 'The Middle S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131866.mp4', 'http://image.tmdb.org/t/p/w300/yv93PaRiEVhRMvtozU5oRe7kBkq.jpg'),
(41142, 2790, 'The Middle S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131867.mp4', 'http://image.tmdb.org/t/p/w300/1hGvIreiioIy37UcsphydGn4nwn.jpg'),
(41143, 2790, 'The Middle S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131868.mp4', 'http://image.tmdb.org/t/p/w300/blwusT9Es56hpV6IuT5cVqPef0D.jpg'),
(41144, 2790, 'The Middle S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131869.mp4', 'http://image.tmdb.org/t/p/w300/uTTIiBreCmA9Q3JVA0lo7rnGcON.jpg'),
(41145, 2790, 'The Middle S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131870.mp4', 'http://image.tmdb.org/t/p/w300/mpH73qm3itMpcFGMAsNwdQUKUrV.jpg'),
(41146, 2790, 'The Middle S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131871.mp4', 'http://image.tmdb.org/t/p/w300/fdBm6pGYiijfnxBrySNVoRNDHcS.jpg'),
(41147, 2790, 'The Middle S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131872.mp4', 'http://image.tmdb.org/t/p/w300/z3WMaqBDn3dLC9t5gICksuXqgwu.jpg'),
(41148, 2790, 'The Middle S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131873.mp4', 'http://image.tmdb.org/t/p/w300/KJhQINEMwgO37htYcf03P49mJB.jpg'),
(41149, 2790, 'The Middle S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131874.mp4', 'http://image.tmdb.org/t/p/w300/aXa2gvCpJ4Q2ZMYYrdkoS3z0nAK.jpg'),
(41150, 2790, 'The Middle S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131875.mp4', 'http://image.tmdb.org/t/p/w300/i95jiKKOB98CfcaGP6OvCUJbrn8.jpg'),
(41151, 2790, 'The Middle S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131876.mp4', 'http://image.tmdb.org/t/p/w300/kMZ5RFIQyOKQzGEqGB0br8fp5p7.jpg'),
(41152, 2790, 'The Middle S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/131877.mp4', 'http://image.tmdb.org/t/p/w300/yyOE01p0Dm7PYxFwvqSHY3WLOuc.jpg'),
(41153, 2790, 'The Middle S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/131878.mp4', 'http://image.tmdb.org/t/p/w300/3YTDaCU4F5CWoDZUxUdqwpt6B1o.jpg'),
(41154, 2790, 'The Middle S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/131879.mp4', 'http://image.tmdb.org/t/p/w300/5fSv49tYlBVJb7mZNGboh11xNNw.jpg'),
(41155, 2790, 'The Middle S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/131880.mp4', 'http://image.tmdb.org/t/p/w300/8EZqtU3V6hO1KwjsNRnHAvE0poI.jpg'),
(41156, 2790, 'The Middle S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/131881.mp4', 'http://image.tmdb.org/t/p/w300/gD4AMqbOBja7SwNw7lR6B4Hv4rw.jpg'),
(41157, 2790, 'The Middle S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/131882.mp4', 'http://image.tmdb.org/t/p/w300/kW3SWRnhGLbTkUPBC8pyVF7jYFw.jpg'),
(41158, 2790, 'The Middle S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/131883.mp4', 'http://image.tmdb.org/t/p/w300/2kXGwRkSVUvcxojTQjTQKaOkG3a.jpg'),
(41159, 2790, 'The Middle S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/131884.mp4', 'http://image.tmdb.org/t/p/w300/gDmi1vYQFYlfu99WY5chZXXmke2.jpg'),
(41160, 2791, 'The Middle S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131885.mp4', 'http://image.tmdb.org/t/p/w300/9YzlgkgtN1TzZqTMVfx9Bl0nMgb.jpg'),
(41161, 2791, 'The Middle S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131886.mp4', 'http://image.tmdb.org/t/p/w300/pRw1gqO4RAKaLaq9vg5JmuV7Upb.jpg'),
(41162, 2791, 'The Middle S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131887.mp4', 'http://image.tmdb.org/t/p/w300/8DCUvQ5VRakmrOBQcWmU1lAPhEf.jpg'),
(41163, 2791, 'The Middle S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131888.mp4', 'http://image.tmdb.org/t/p/w300/z2YpDSpEpcg0eAgh3TZ4vSn1Lmv.jpg'),
(41164, 2791, 'The Middle S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131889.mp4', 'http://image.tmdb.org/t/p/w300/iYZx4YuAb0gec46GlEhGbXPd4Q2.jpg'),
(41165, 2791, 'The Middle S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131890.mp4', 'http://image.tmdb.org/t/p/w300/yqpanCQO4axA2wh59hZMFCJkq7f.jpg'),
(41166, 2791, 'The Middle S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131891.mp4', 'http://image.tmdb.org/t/p/w300/vcaBoD1rMdCcVIVCj2zbh2vgl27.jpg'),
(41167, 2791, 'The Middle S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131892.mp4', 'http://image.tmdb.org/t/p/w300/7l2BzRME6Mekz4CFxt6pGzBwNvK.jpg'),
(41168, 2791, 'The Middle S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131893.mp4', 'http://image.tmdb.org/t/p/w300/gfj5Em3zdS3gyiFFAbGR2Wo7WoP.jpg'),
(41169, 2791, 'The Middle S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131894.mp4', 'http://image.tmdb.org/t/p/w300/2qdHwrbp9yQHm28ys5qVn3ufQDv.jpg'),
(41170, 2791, 'The Middle S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131895.mp4', 'http://image.tmdb.org/t/p/w300/7UoYnQaTJZGdQBP4M6YOHwOyMNU.jpg'),
(41171, 2791, 'The Middle S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131896.mp4', 'http://image.tmdb.org/t/p/w300/4qa0aWofEyn9TYjtxjjaqPhL7GB.jpg'),
(41172, 2791, 'The Middle S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131897.mp4', 'http://image.tmdb.org/t/p/w300/aKFpZ0elNH3LczLcehvkS5YOKOA.jpg'),
(41173, 2791, 'The Middle S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131898.mp4', 'http://image.tmdb.org/t/p/w300/3uy0PChQUC6QEIqImUajCveRqAT.jpg'),
(41174, 2791, 'The Middle S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131899.mp4', 'http://image.tmdb.org/t/p/w300/odqr2AADVAoIsuNicXslsm03q2x.jpg'),
(41175, 2791, 'The Middle S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/131900.mp4', 'http://image.tmdb.org/t/p/w300/qwle7qisc1jh62dDbtgkXPn8zrC.jpg'),
(41176, 2791, 'The Middle S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/131901.mp4', 'http://image.tmdb.org/t/p/w300/o8MCpwVfJGXVi5N7EMjN8oyKnzl.jpg'),
(41177, 2791, 'The Middle S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/131902.mp4', 'http://image.tmdb.org/t/p/w300/9svqyvWLBXmrs6xxBjHZPaFwbjw.jpg'),
(41178, 2791, 'The Middle S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/131903.mp4', 'http://image.tmdb.org/t/p/w300/ct7ipnm0MKVZZY9h8Va8Rpcaeoq.jpg'),
(41179, 2791, 'The Middle S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/131904.mp4', 'http://image.tmdb.org/t/p/w300/uRqGMguiDiaokoNUzqX41wxuSUu.jpg'),
(41180, 2791, 'The Middle S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/131905.mp4', 'http://image.tmdb.org/t/p/w300/zfEkYFWQXGVXRDSvpxXpoPa7ZS5.jpg'),
(41181, 2791, 'The Middle S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/131906.mp4', 'http://image.tmdb.org/t/p/w300/xwF9aAtgMDoGkPHrebd7rWsyDRC.jpg'),
(41182, 2791, 'The Middle S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/131907.mp4', 'http://image.tmdb.org/t/p/w300/zo5x22mJyNLvZA6EF2dk1PSkrM4.jpg'),
(41183, 2792, 'Z Nation S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131629.mp4', 'http://image.tmdb.org/t/p/w300/pBTCOCyjsG4ZnjKLq0lDQAMKn3b.jpg'),
(41184, 2792, 'Z Nation S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131630.mp4', 'http://image.tmdb.org/t/p/w300/sgobOtVDzy5V9NqlPwG5Oe5O6Z7.jpg'),
(41185, 2792, 'Z Nation S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131631.mp4', 'http://image.tmdb.org/t/p/w300/wdOa9JIEe9EO7UaQux5g6PtQYkm.jpg'),
(41186, 2792, 'Z Nation S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131632.mp4', 'http://image.tmdb.org/t/p/w300/quy5zPpTIIuP6R2nHj6Yp8QwNqY.jpg'),
(41187, 2792, 'Z Nation S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131633.mp4', 'http://image.tmdb.org/t/p/w300/uV1dWfdcgQIz8gO4VdbEI2s8KEz.jpg'),
(41188, 2792, 'Z Nation S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131634.mp4', 'http://image.tmdb.org/t/p/w300/v3jZO4nrU1Sc2XB8aX4r7nEk6YQ.jpg'),
(41189, 2792, 'Z Nation S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131635.mp4', 'http://image.tmdb.org/t/p/w300/nvsjExSV4izzMtTDz8cZap6EtvI.jpg'),
(41190, 2792, 'Z Nation S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131636.mp4', 'http://image.tmdb.org/t/p/w300/e9V1J6M1ozZZCoWfloQu2LdKybh.jpg'),
(41191, 2792, 'Z Nation S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131637.mp4', 'http://image.tmdb.org/t/p/w300/rcu3LYKHWqXwWft7zQjHc7DTkza.jpg'),
(41192, 2792, 'Z Nation S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131638.mp4', 'http://image.tmdb.org/t/p/w300/2yqlWI6hRVEP67yOeFKkAKF7DAz.jpg'),
(41193, 2792, 'Z Nation S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131639.mp4', 'http://image.tmdb.org/t/p/w300/2KFhGgiJhwdNfXcLP8PawcOYzGH.jpg'),
(41194, 2792, 'Z Nation S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131640.mp4', 'http://image.tmdb.org/t/p/w300/jEUFbxasgrtcz6R5XMs1UO8CBqx.jpg'),
(41195, 2792, 'Z Nation S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131641.mp4', 'http://image.tmdb.org/t/p/w300/3w5mvnRm5jiXeTMMEVjHPyaTKWy.jpg'),
(41196, 2793, 'Z Nation S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131642.mp4', 'http://image.tmdb.org/t/p/w300/7tufIbz8SPg7dxq4cmWxyjoq92e.jpg'),
(41197, 2793, 'Z Nation S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131643.mp4', 'http://image.tmdb.org/t/p/w300/lMFmzptKFSkdinMjxQxDsSWHv6j.jpg'),
(41198, 2793, 'Z Nation S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131644.mp4', 'http://image.tmdb.org/t/p/w300/s5hX9GSc9PD7pt0KVRhE95yPtnc.jpg'),
(41199, 2793, 'Z Nation S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131645.mp4', 'http://image.tmdb.org/t/p/w300/oV7qr3Rjmtm7lC9U0mMFUBhZ4tD.jpg'),
(41200, 2793, 'Z Nation S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131646.mp4', 'http://image.tmdb.org/t/p/w300/6wewoobnp0SMZzFfdboM5AddkdF.jpg'),
(41201, 2793, 'Z Nation S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131647.mp4', 'http://image.tmdb.org/t/p/w300/1BHyejW2If5b7iPPLet5SKJUo83.jpg'),
(41202, 2793, 'Z Nation S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131648.mp4', 'http://image.tmdb.org/t/p/w300/61RVeSwaHRx32sv3yD8TdjBv5X1.jpg'),
(41203, 2793, 'Z Nation S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131649.mp4', 'http://image.tmdb.org/t/p/w300/4fY6wloqwTHOneTc2KFVOgbf6Nz.jpg'),
(41204, 2793, 'Z Nation S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131650.mp4', 'http://image.tmdb.org/t/p/w300/qRD1JMk0IA0yF2wwit8U95iDTJT.jpg'),
(41205, 2793, 'Z Nation S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131651.mp4', 'http://image.tmdb.org/t/p/w300/9y8f7Be2E1sbvWgt0UX8VyCAHKu.jpg'),
(41206, 2793, 'Z Nation S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131652.mp4', 'http://image.tmdb.org/t/p/w300/zC7wBNAFopgOPsyyWaaXwH0tl9v.jpg'),
(41207, 2793, 'Z Nation S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131653.mp4', 'http://image.tmdb.org/t/p/w300/17WnlbDtdiH9FYr8KpOVDpoDCZb.jpg'),
(41208, 2793, 'Z Nation S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131654.mp4', 'http://image.tmdb.org/t/p/w300/mSXyZXY83YLj0cZdzG4xY21oRAx.jpg'),
(41209, 2793, 'Z Nation S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131655.mp4', 'http://image.tmdb.org/t/p/w300/tej7xeyjSya8o5Oo3kMPwnVpLai.jpg'),
(41210, 2793, 'Z Nation S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131656.mp4', 'http://image.tmdb.org/t/p/w300/AlwcHLIIOLLsywexWS4Mmf57Wge.jpg'),
(41211, 2794, 'Z Nation S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131657.mp4', 'http://image.tmdb.org/t/p/w300/FinF57EuPUM7ADF1tDMMWjtjIN.jpg'),
(41212, 2794, 'Z Nation S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131658.mp4', 'http://image.tmdb.org/t/p/w300/iSw3ZqqTaE397VrwmtpTA71zuTW.jpg'),
(41213, 2794, 'Z Nation S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131659.mp4', 'http://image.tmdb.org/t/p/w300/levyNJK0o5T2zDDjFye6LJjh3xs.jpg'),
(41214, 2794, 'Z Nation S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131660.mp4', 'http://image.tmdb.org/t/p/w300/6KcdD7AajUGlxmeAZqGOwYyW6c5.jpg'),
(41215, 2794, 'Z Nation S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131661.mp4', 'http://image.tmdb.org/t/p/w300/qzqXGxPz02tVfdmbo3GVVkAv18H.jpg'),
(41216, 2794, 'Z Nation S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131662.mp4', 'http://image.tmdb.org/t/p/w300/j53a6SM0uqJQY25HvyvhxFc8OyB.jpg'),
(41217, 2794, 'Z Nation S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131663.mp4', 'http://image.tmdb.org/t/p/w300/eSUEmW1j6wj4xLBnGL28OlwMfuI.jpg'),
(41218, 2794, 'Z Nation S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131664.mp4', 'http://image.tmdb.org/t/p/w300/9C7unH6bcPvljcqKezCfaMcOubt.jpg'),
(41219, 2794, 'Z Nation S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131665.mp4', 'http://image.tmdb.org/t/p/w300/i2VyRTvhD1PgNHqNGcqt24uYDKt.jpg'),
(41220, 2794, 'Z Nation S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131666.mp4', 'http://image.tmdb.org/t/p/w300/t4BDcrr26JWVKznaq1WUZpIANa.jpg'),
(41221, 2794, 'Z Nation S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131667.mp4', 'http://image.tmdb.org/t/p/w300/iBM6Pfb2uNQ1HbDWTa3j51XwLSW.jpg'),
(41222, 2794, 'Z Nation S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131668.mp4', 'http://image.tmdb.org/t/p/w300/hYcTPW3z5y8UIhROaamvvDKuLmr.jpg'),
(41223, 2794, 'Z Nation S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131669.mp4', 'http://image.tmdb.org/t/p/w300/uFC2ImS3IhR3frJt3EcHnUYJyBB.jpg'),
(41224, 2794, 'Z Nation S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131670.mp4', 'http://image.tmdb.org/t/p/w300/aTHVMcIg2ylu6Q58UiaZLsmxBBD.jpg'),
(41225, 2795, 'Z Nation S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131671.mp4', 'http://image.tmdb.org/t/p/w300/822cKIBNRBWOyBsEHc2oxmtJAS3.jpg'),
(41226, 2795, 'Z Nation S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131672.mp4', 'http://image.tmdb.org/t/p/w300/vrlMmDdxMsDaif382PGnAqoHPEs.jpg'),
(41227, 2795, 'Z Nation S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131673.mp4', 'http://image.tmdb.org/t/p/w300/mAHsOZCGVjJc96WO7O8c9xBZHSs.jpg'),
(41228, 2795, 'Z Nation S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131674.mp4', 'http://image.tmdb.org/t/p/w300/3dSe5S1vxpnaK91PUDlxpnCrOnb.jpg'),
(41229, 2795, 'Z Nation S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131675.mp4', 'http://image.tmdb.org/t/p/w300/6WcMxD4Ezf0xtNsBjZ4LPAac1HX.jpg'),
(41230, 2795, 'Z Nation S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131676.mp4', 'http://image.tmdb.org/t/p/w300/1lbkOYPxepZvg7SLRnZuPtHzhwJ.jpg'),
(41231, 2795, 'Z Nation S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131677.mp4', 'http://image.tmdb.org/t/p/w300/dyNh3V8O6Wb33Xg7DrE9TmBvc2z.jpg'),
(41232, 2795, 'Z Nation S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131678.mp4', 'http://image.tmdb.org/t/p/w300/9g4nsVZCP3apzgq58A840AHr16i.jpg'),
(41233, 2795, 'Z Nation S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131679.mp4', 'http://image.tmdb.org/t/p/w300/1jf81Az3hALXdCVA8spB8Z3Qp0z.jpg'),
(41234, 2795, 'Z Nation S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131680.mp4', 'http://image.tmdb.org/t/p/w300/8KXuWDd21U3afZ5ZOZPw4KX7yR8.jpg'),
(41235, 2795, 'Z Nation S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131681.mp4', 'http://image.tmdb.org/t/p/w300/dOTM2fyM8l4YLrGqs2pHLxrX6DN.jpg'),
(41236, 2795, 'Z Nation S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131682.mp4', 'http://image.tmdb.org/t/p/w300/envBKCoaHcb7LUsxl6yvpNEPP8A.jpg'),
(41237, 2795, 'Z Nation S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131683.mp4', 'http://image.tmdb.org/t/p/w300/eaVKeUWPRDX1jC8yvXIUPhZ2Yxk.jpg'),
(41238, 2796, 'Z Nation S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131684.mp4', 'http://image.tmdb.org/t/p/w300/2D6nk7OyEw9D0pK5fCaHnhXBgJx.jpg'),
(41239, 2796, 'Z Nation S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131685.mp4', 'http://image.tmdb.org/t/p/w300/rTDGHqqMe2djXMdxaGFqMhZzFYO.jpg'),
(41240, 2796, 'Z Nation S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131686.mp4', 'http://image.tmdb.org/t/p/w300/vFIrq7JzTtYG27bEgxsaCgr11Vk.jpg'),
(41241, 2796, 'Z Nation S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131687.mp4', 'http://image.tmdb.org/t/p/w300/h6OgOT4q8wUtmNcCCO4UhhZ8OVn.jpg'),
(41242, 2796, 'Z Nation S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131688.mp4', 'http://image.tmdb.org/t/p/w300/9bNEqEinIi7deqoOhwGj3MQSZcJ.jpg'),
(41243, 2796, 'Z Nation S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131689.mp4', 'http://image.tmdb.org/t/p/w300/rhWTCrmNeecPY6W1bXopPxMkerB.jpg'),
(41244, 2796, 'Z Nation S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131690.mp4', 'http://image.tmdb.org/t/p/w300/cQkK2GDHp1kzhoGEopILKHO1dV0.jpg'),
(41245, 2796, 'Z Nation S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131691.mp4', 'http://image.tmdb.org/t/p/w300/s0dQnpXO4nMasq104qOKVL8OB7r.jpg'),
(41246, 2796, 'Z Nation S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131692.mp4', 'http://image.tmdb.org/t/p/w300/8dWUpKAiWizYgrN4MANez3Bhbt3.jpg'),
(41247, 2796, 'Z Nation S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131693.mp4', 'http://image.tmdb.org/t/p/w300/4Hj158NdD6jBQwavjrCasGyxxdW.jpg'),
(41248, 2796, 'Z Nation S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131694.mp4', 'http://image.tmdb.org/t/p/w300/jHqEl3FcyoSIFRopsZaAx43BOOS.jpg'),
(41249, 2796, 'Z Nation S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131695.mp4', 'http://image.tmdb.org/t/p/w300/42KksP5f5nhDzyL7HB6PRNDtJs3.jpg'),
(41250, 2796, 'Z Nation S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131696.mp4', 'http://image.tmdb.org/t/p/w300/cPBwoQY8NvqMkyhg3ONwhFKtT1g.jpg'),
(41251, 2797, 'The Liberator S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131625.mp4', 'http://gstaticontent.com/images/kivHJpsGFWgqnDMRDnnpOSgLD1s_big.jpg'),
(41252, 2797, 'The Liberator S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131626.mp4', 'http://gstaticontent.com/images/kivHJpsGFWgqnDMRDnnpOSgLD1s_big.jpg'),
(41253, 2797, 'The Liberator S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131627.mp4', 'http://gstaticontent.com/images/kivHJpsGFWgqnDMRDnnpOSgLD1s_big.jpg'),
(41254, 2797, 'The Liberator S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131628.mp4', 'http://gstaticontent.com/images/kivHJpsGFWgqnDMRDnnpOSgLD1s_big.jpg'),
(41255, 2798, 'Power Book II Ghost S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rWeZaPlPeEP8dA426BKLhjiLQuV.jpg'),
(41256, 2798, 'Power Book II Ghost S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s2Q2EYFt2c7LlWMCm3XOSGql9tu.jpg'),
(41257, 2798, 'Power Book II Ghost S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ejmxR0sxiamFdbDkzlUXnJWD2O6.jpg'),
(41258, 2798, 'Power Book II Ghost S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6BY9TmvYmyu2mfMVfPAdgtyDMbl.jpg'),
(41259, 2798, 'Power Book II Ghost S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bT0AsoZDjv7DHsZfsNKDD10FRvE.jpg'),
(41260, 2798, 'Power Book II Ghost S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217398.mp4', 'http://gstaticontent.com/images/f6b0ea6a448d4b3f733d0aa84076d737.jpg'),
(41261, 2798, 'Power Book II Ghost S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217399.mp4', 'http://gstaticontent.com/images/f6b0ea6a448d4b3f733d0aa84076d737.jpg'),
(41262, 2798, 'Power Book II Ghost S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217400.mp4', 'http://gstaticontent.com/images/f6b0ea6a448d4b3f733d0aa84076d737.jpg'),
(41263, 2798, 'Power Book II Ghost S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217401.mp4', 'http://gstaticontent.com/images/f6b0ea6a448d4b3f733d0aa84076d737.jpg'),
(41264, 2798, 'Power Book II Ghost S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217402.mp4', 'http://gstaticontent.com/images/f6b0ea6a448d4b3f733d0aa84076d737.jpg'),
(41265, 2799, 'Power Book II Ghost S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217403.mp4', 'http://image.tmdb.org/t/p/w1280/hiWfl4pJ5PnM3nqelOWBcpL56a2.jpg'),
(41266, 2799, 'Power Book II Ghost S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217404.mp4', 'http://gstaticontent.com/images/f6b0ea6a448d4b3f733d0aa84076d737.jpg'),
(41267, 2799, 'Power Book II Ghost S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217405.mp4', 'http://image.tmdb.org/t/p/w1280/yvQF618NhqdfTWj4HIQbID739He.jpg'),
(41268, 2799, 'Power Book II Ghost S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217406.mp4', 'http://image.tmdb.org/t/p/w1280/4TaObU2XdW0xa5vPhk8A89wJj7P.jpg'),
(41269, 2799, 'Power Book II Ghost S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wr11IlZEia76YMTSHpmefYG1QFs.jpg'),
(41270, 2799, 'Power Book II Ghost S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k58Dnqd8XlRU2wuzSn9bdrruCUS.jpg'),
(41271, 2799, 'Power Book II Ghost S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217409.mp4', 'http://timg.bdta.pro/images/fc2d7840fa8cb0c7f9b0eb5fa8337029.jpg'),
(41272, 2799, 'Power Book II Ghost S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217410.mp4', 'http://timg.bdta.pro/images/299d1520972d4eccfdcc0fd351f6b7ea.jpg'),
(41273, 2799, 'Power Book II Ghost S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217411.mp4', 'http://gstaticontent.com/images/f6b0ea6a448d4b3f733d0aa84076d737.jpg'),
(41274, 2799, 'Power Book II Ghost S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217412.mp4', 'http://gstaticontent.com/images/f6b0ea6a448d4b3f733d0aa84076d737.jpg'),
(41275, 2800, 'Power Book II Ghost S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217413.mp4', 'http://image.tmdb.org/t/p/w1280/2rTOTdqG9K72dQbqK6027BZpDes.jpg'),
(41276, 2800, 'Power Book II Ghost S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217414.mp4', 'http://image.tmdb.org/t/p/w1280/3pPTBTb0BoVQ0d3qK87XOzXEvJO.jpg'),
(41277, 2800, 'Power Book II Ghost S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217415.mp4', 'http://image.tmdb.org/t/p/w1280/uGgs78L0j23tOB4DKUx59DDgh9C.jpg'),
(41278, 2800, 'Power Book II Ghost S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217416.mp4', 'http://image.tmdb.org/t/p/w1280/zBS0u0uuxHgAa5s97OMNujMKYGj.jpg'),
(41279, 2800, 'Power Book II Ghost S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217417.mp4', 'http://image.tmdb.org/t/p/w1280/jcJHLQmVCIzYOa8tGcs4sZvrKBc.jpg'),
(41280, 2800, 'Power Book II Ghost S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217418.mp4', 'http://image.tmdb.org/t/p/w1280/suJF0hBO5aOh6kTZFHNe1b2UDRL.jpg'),
(41281, 2800, 'Power Book II Ghost S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217419.mp4', 'http://image.tmdb.org/t/p/w1280/qqWYx38OEtVsqsm66J4YOT4Wi16.jpg'),
(41282, 2800, 'Power Book II Ghost S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217420.mp4', 'http://image.tmdb.org/t/p/w1280/yqr7OsiSwTtiavhkPMBHHxHWYnN.jpg'),
(41283, 2800, 'Power Book II Ghost S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217421.mp4', 'http://image.tmdb.org/t/p/w1280/q96Ih01RT9fKsYrYrIdbqo2jB1S.jpg'),
(41284, 2800, 'Power Book II Ghost S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217422.mp4', 'http://image.tmdb.org/t/p/w1280/wiMR3yRiT0H5A3h1hiKqHK8FzQ2.jpg'),
(41285, 2801, 'Power Book II Ghost S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/379708.mp4', 'http://gstaticontent.com/images/f6b0ea6a448d4b3f733d0aa84076d737.jpg'),
(41286, 2801, 'Power Book II Ghost S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/386438.mp4', 'http://gstaticontent.com/images/f6b0ea6a448d4b3f733d0aa84076d737.jpg'),
(41287, 2801, 'Power Book II Ghost S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/391112.mp4', 'http://gstaticontent.com/images/f6b0ea6a448d4b3f733d0aa84076d737.jpg'),
(41288, 2801, 'Power Book II Ghost S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/394529.mp4', 'http://gstaticontent.com/images/f6b0ea6a448d4b3f733d0aa84076d737.jpg'),
(41289, 2801, 'Power Book II Ghost S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/401608.mp4', 'http://gstaticontent.com/images/f6b0ea6a448d4b3f733d0aa84076d737.jpg'),
(41290, 2801, 'Power Book II Ghost S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/451276.mp4', 'http://gstaticontent.com/images/f6b0ea6a448d4b3f733d0aa84076d737.jpg'),
(41291, 2801, 'Power Book II Ghost S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/454620.mp4', 'http://gstaticontent.com/images/f6b0ea6a448d4b3f733d0aa84076d737.jpg'),
(41292, 2801, 'Power Book II Ghost S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/459340.mp4', 'http://gstaticontent.com/images/f6b0ea6a448d4b3f733d0aa84076d737.jpg'),
(41293, 2801, 'Power Book II Ghost S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/466927.mp4', 'http://gstaticontent.com/images/f6b0ea6a448d4b3f733d0aa84076d737.jpg'),
(41294, 2801, 'Power Book II Ghost S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/472697.mp4', 'http://gstaticontent.com/images/f6b0ea6a448d4b3f733d0aa84076d737.jpg'),
(41295, 2802, 'The Chosen Os Escolhidos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cnZpv1i6DGcpANb4QhnLAXoNDdG.jpg'),
(41296, 2802, 'The Chosen Os Escolhidos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hWjNZg0iVGlWYI3C25Pb3AzCd8S.jpg'),
(41297, 2802, 'The Chosen Os Escolhidos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mil3FRj9B6VAYJ9dNLPwdRX40N2.jpg'),
(41298, 2802, 'The Chosen Os Escolhidos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yGjn2PYrTWwQPezqFXFxTaHxqZr.jpg'),
(41299, 2802, 'The Chosen Os Escolhidos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/90xa35HibP2cibu7XcgJetRA7Ku.jpg'),
(41300, 2802, 'The Chosen Os Escolhidos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iH84OMZfSXNvsSPdK84jnF3M9QX.jpg'),
(41301, 2802, 'The Chosen Os Escolhidos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/endRXmg12QtiuoB4O70LzZLXNMi.jpg'),
(41302, 2802, 'The Chosen Os Escolhidos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yKKvoNLrYTnJqPAUUxU9xhVD0sH.jpg'),
(41303, 2802, 'The Chosen Os Escolhidos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41304, 2803, 'The Chosen Os Escolhidos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/veYGGZcBkrrJ73WFtfjPVxmlm3t.jpg'),
(41305, 2803, 'The Chosen Os Escolhidos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97LTcBNO5myOVy5tmtO2eXOLBgs.jpg'),
(41306, 2803, 'The Chosen Os Escolhidos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jf0KqK2x7ezDP7XKT7TG6YVcJEh.jpg'),
(41307, 2803, 'The Chosen Os Escolhidos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmrBv1TbbA7TgcnJ7WuopCMAZzg.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(41308, 2803, 'The Chosen Os Escolhidos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qglp6jovceCGncL6vPfF1d4Dvei.jpg'),
(41309, 2803, 'The Chosen Os Escolhidos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zsdnjukB2Qm52odGXE8DcrYqwOK.jpg'),
(41310, 2803, 'The Chosen Os Escolhidos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r3tZUs2inkBLofPHh6Da8JKQ6yt.jpg'),
(41311, 2803, 'The Chosen Os Escolhidos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oXVWhQzhrbnFnotQfn4xNPRUyym.jpg'),
(41312, 2804, 'The Chosen Os Escolhidos S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41313, 2804, 'The Chosen Os Escolhidos S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41314, 2804, 'The Chosen Os Escolhidos S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41315, 2804, 'The Chosen Os Escolhidos S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41316, 2804, 'The Chosen Os Escolhidos S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41317, 2804, 'The Chosen Os Escolhidos S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41318, 2804, 'The Chosen Os Escolhidos S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41319, 2804, 'The Chosen Os Escolhidos S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41320, 2805, 'The Chosen Os Escolhidos S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41321, 2805, 'The Chosen Os Escolhidos S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41322, 2805, 'The Chosen Os Escolhidos S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/400219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41323, 2805, 'The Chosen Os Escolhidos S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/400220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41324, 2805, 'The Chosen Os Escolhidos S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/404046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41325, 2805, 'The Chosen Os Escolhidos S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/404047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41326, 2805, 'The Chosen Os Escolhidos S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/411238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41327, 2805, 'The Chosen Os Escolhidos S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/411239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41328, 2806, 'The Chosen Os Escolhidos S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/847873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41329, 2806, 'The Chosen Os Escolhidos S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/847874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41330, 2806, 'The Chosen Os Escolhidos S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/847875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41331, 2806, 'The Chosen Os Escolhidos S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/872222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41332, 2806, 'The Chosen Os Escolhidos S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/872223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41333, 2806, 'The Chosen Os Escolhidos S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/878043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41334, 2806, 'The Chosen Os Escolhidos S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/878044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41335, 2806, 'The Chosen Os Escolhidos S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/878045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Um6qPWSWHP8cl60fTtOU15uXqb.jpg'),
(41336, 2807, 'Dash & Lily S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rhyUQ6n03XpenjTEvGExrSf0FKa.jpg'),
(41337, 2807, 'Dash & Lily S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8TLcdTwbIdHxTFQwH9S3wvJyxS.jpg'),
(41338, 2807, 'Dash & Lily S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ofDmBDFqydGfhHVbaE527Rg0F7A.jpg'),
(41339, 2807, 'Dash & Lily S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c2TydFkoCx70pdHClCnlhkJc1Sv.jpg'),
(41340, 2807, 'Dash & Lily S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zabfVR9LCLI6UtG6TVsiRdBJ7z3.jpg'),
(41341, 2807, 'Dash & Lily S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gpKaMjaZyNh1vFGX0oIKjsrXFAK.jpg'),
(41342, 2807, 'Dash & Lily S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCDbRoxyGEMcfteOvPIH8I9NQVs.jpg'),
(41343, 2807, 'Dash & Lily S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFM3wnQsS8Zp0hX8Kq5TCWczrn4.jpg'),
(41344, 2808, 'Zé Coleta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143924.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41345, 2808, 'Zé Coleta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143925.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41346, 2808, 'Zé Coleta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143926.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41347, 2808, 'Zé Coleta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143927.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41348, 2808, 'Zé Coleta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143928.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41349, 2808, 'Zé Coleta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143929.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41350, 2808, 'Zé Coleta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143930.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41351, 2808, 'Zé Coleta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143931.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41352, 2808, 'Zé Coleta S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143932.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41353, 2808, 'Zé Coleta S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143933.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41354, 2808, 'Zé Coleta S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143934.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41355, 2808, 'Zé Coleta S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143935.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41356, 2809, 'Zé Coleta S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143936.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41357, 2809, 'Zé Coleta S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143937.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41358, 2809, 'Zé Coleta S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143938.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41359, 2809, 'Zé Coleta S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143939.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41360, 2809, 'Zé Coleta S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143940.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41361, 2809, 'Zé Coleta S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143941.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41362, 2809, 'Zé Coleta S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143942.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41363, 2809, 'Zé Coleta S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143943.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41364, 2809, 'Zé Coleta S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143944.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41365, 2809, 'Zé Coleta S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143945.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41366, 2809, 'Zé Coleta S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143946.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41367, 2809, 'Zé Coleta S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143947.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41368, 2809, 'Zé Coleta S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143948.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41369, 2809, 'Zé Coleta S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143949.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41370, 2809, 'Zé Coleta S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143950.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41371, 2809, 'Zé Coleta S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143951.mp4', 'http://gstaticontent.com/images/uEKw1dG7mJuIdpbQox073xQ12Tf_big.jpg'),
(41372, 2810, 'Younger S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131581.mp4', 'http://image.tmdb.org/t/p/w300/qrHbxmkH8MffurEYpdbPACF8ZhJ.jpg'),
(41373, 2810, 'Younger S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131582.mp4', 'http://image.tmdb.org/t/p/w300/9CDBd0IfFb3GkJVO2QdVcZ6g3I8.jpg'),
(41374, 2810, 'Younger S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131583.mp4', 'http://image.tmdb.org/t/p/w300/aHKC7XwTnYYJt1g3rOASaS2mXVF.jpg'),
(41375, 2810, 'Younger S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131584.mp4', 'http://image.tmdb.org/t/p/w300/sYbklkFJyH95htKSADDDsdvkJGg.jpg'),
(41376, 2810, 'Younger S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131585.mp4', 'http://image.tmdb.org/t/p/w300/bFHLrCZD4w7RHuvsAuOSAdBTcdY.jpg'),
(41377, 2810, 'Younger S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131586.mp4', 'http://image.tmdb.org/t/p/w300/m73EhJnOz9zL7ee0QFByMLzlmyj.jpg'),
(41378, 2810, 'Younger S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131587.mp4', 'http://image.tmdb.org/t/p/w300/58fVSet5mFo2gWJu4J9DHVZCKRi.jpg'),
(41379, 2810, 'Younger S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131588.mp4', 'http://image.tmdb.org/t/p/w300/oX7Ake0UX8nzJ8jLahCdXxNhf8r.jpg'),
(41380, 2810, 'Younger S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131589.mp4', 'http://image.tmdb.org/t/p/w300/7WjYeEtQH7v9nI0XaQpjknoGeoB.jpg'),
(41381, 2810, 'Younger S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131590.mp4', 'http://image.tmdb.org/t/p/w300/zVqQMMYbPREfzJF5RjItkUWdfhN.jpg'),
(41382, 2810, 'Younger S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131591.mp4', 'http://image.tmdb.org/t/p/w300/bdJDFwR2Wjelb0fGjhXnpBXYKjg.jpg'),
(41383, 2810, 'Younger S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131592.mp4', 'http://image.tmdb.org/t/p/w300/vapOO07YHVGMdY09NcEH2li5Uqh.jpg'),
(41384, 2811, 'Younger S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131593.mp4', 'http://image.tmdb.org/t/p/w300/mHv9vhESvCBpCSnXZCnvoLyO0EU.jpg'),
(41385, 2811, 'Younger S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131594.mp4', 'http://image.tmdb.org/t/p/w300/nPiEajB3mkiFOZyQ1oYcGS1A09P.jpg'),
(41386, 2811, 'Younger S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131595.mp4', 'http://image.tmdb.org/t/p/w300/epsjyVFBLTPeYoebkXyQenzJ48U.jpg'),
(41387, 2811, 'Younger S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131596.mp4', 'http://image.tmdb.org/t/p/w300/mVDtodLxG00l6IOVfuI6yLplHWp.jpg'),
(41388, 2811, 'Younger S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131597.mp4', 'http://image.tmdb.org/t/p/w300/piaWVCyH4hXvuGjQscFFSLKy4lY.jpg'),
(41389, 2811, 'Younger S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131598.mp4', 'http://image.tmdb.org/t/p/w300/nVKAXkBSi65ePanABCCekBjIUhF.jpg'),
(41390, 2811, 'Younger S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131599.mp4', 'http://image.tmdb.org/t/p/w300/p9siat5Vis6qkOWdXrY71I6tNbE.jpg'),
(41391, 2811, 'Younger S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131600.mp4', 'http://image.tmdb.org/t/p/w300/ecwnEvxuPTJUywYRWS5j7vEabpi.jpg'),
(41392, 2811, 'Younger S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131601.mp4', 'http://image.tmdb.org/t/p/w300/gf41iW0mZCJaIL8FIoBDhSEriid.jpg'),
(41393, 2811, 'Younger S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131602.mp4', 'http://image.tmdb.org/t/p/w300/liL1fHpfl9iHFf5Pm33iiHRsdSv.jpg'),
(41394, 2811, 'Younger S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131603.mp4', 'http://image.tmdb.org/t/p/w300/6VIO0TsXVXlEmHLJRBI24J6J1aU.jpg'),
(41395, 2811, 'Younger S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131604.mp4', 'http://image.tmdb.org/t/p/w300/4tEE3tXFqa5wuiZz8mD78yITAZm.jpg'),
(41396, 2812, 'Younger S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131605.mp4', 'http://image.tmdb.org/t/p/w300/tcpp5duzhW5acmftsREw0NO3Nym.jpg'),
(41397, 2812, 'Younger S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131606.mp4', 'http://image.tmdb.org/t/p/w300/7PXtt3ARNC9DAWBMRX30BXFMkH8.jpg'),
(41398, 2812, 'Younger S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131607.mp4', 'http://image.tmdb.org/t/p/w300/za0ffxvjXQQjDNHOpzkRZMaUAVk.jpg'),
(41399, 2812, 'Younger S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131608.mp4', 'http://image.tmdb.org/t/p/w300/81VfIbkqPHWvPbr1FMgrQPa9Ghe.jpg'),
(41400, 2812, 'Younger S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131609.mp4', 'http://image.tmdb.org/t/p/w300/zjiS8xMnMPwVieCMU8emMjG6jxG.jpg'),
(41401, 2812, 'Younger S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131610.mp4', 'http://image.tmdb.org/t/p/w300/w8EQhU5QzHaAIWwfJpwE0PO1iwu.jpg'),
(41402, 2812, 'Younger S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131611.mp4', 'http://image.tmdb.org/t/p/w300/iPzjkfWchEEImuUM7GMNpxEhpOg.jpg'),
(41403, 2812, 'Younger S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131612.mp4', 'http://image.tmdb.org/t/p/w300/rvflmqhWlCtkbSCO5vEygY1RgUI.jpg'),
(41404, 2812, 'Younger S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131613.mp4', 'http://image.tmdb.org/t/p/w300/sR0vgqpcirQRlvqdiyoGMPLqZx2.jpg'),
(41405, 2812, 'Younger S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131614.mp4', 'http://image.tmdb.org/t/p/w300/f675XdDkauelrwPbcqzpik3jIkO.jpg'),
(41406, 2812, 'Younger S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131615.mp4', 'http://image.tmdb.org/t/p/w300/bcGEfp5VykQ5cbq79SLNGpoAQ2n.jpg'),
(41407, 2812, 'Younger S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131616.mp4', 'http://image.tmdb.org/t/p/w300/3uiYDEjg7um5A7CCeplhbAZPZPz.jpg'),
(41408, 2813, 'Younger S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/882118.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41409, 2813, 'Younger S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/882119.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41410, 2813, 'Younger S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/882120.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41411, 2813, 'Younger S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/882121.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41412, 2813, 'Younger S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/882122.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41413, 2813, 'Younger S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/882123.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41414, 2813, 'Younger S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/882124.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41415, 2813, 'Younger S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/882125.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41416, 2813, 'Younger S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/882126.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41417, 2813, 'Younger S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/882127.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41418, 2813, 'Younger S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/882128.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41419, 2813, 'Younger S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/882129.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41420, 2814, 'Younger S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/882130.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41421, 2814, 'Younger S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/882131.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41422, 2814, 'Younger S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/882132.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41423, 2814, 'Younger S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/882133.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41424, 2814, 'Younger S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/882134.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41425, 2814, 'Younger S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/882135.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41426, 2814, 'Younger S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/882136.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41427, 2814, 'Younger S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/882137.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41428, 2814, 'Younger S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/882138.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41429, 2814, 'Younger S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/882139.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41430, 2815, 'Younger S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/882140.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41431, 2815, 'Younger S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/882141.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41432, 2815, 'Younger S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/882142.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41433, 2815, 'Younger S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/882143.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41434, 2815, 'Younger S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/882144.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41435, 2815, 'Younger S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/882145.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41436, 2815, 'Younger S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/882146.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41437, 2815, 'Younger S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/882147.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41438, 2815, 'Younger S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/882148.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41439, 2815, 'Younger S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/882149.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41440, 2815, 'Younger S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/882150.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41441, 2815, 'Younger S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/882151.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41442, 2816, 'Younger S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/882152.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41443, 2816, 'Younger S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/882153.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41444, 2816, 'Younger S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/882154.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41445, 2816, 'Younger S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/882155.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41446, 2816, 'Younger S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/882156.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41447, 2816, 'Younger S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/882157.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41448, 2816, 'Younger S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/882158.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41449, 2816, 'Younger S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/882159.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41450, 2816, 'Younger S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/882160.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41451, 2816, 'Younger S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/882161.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41452, 2816, 'Younger S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/882162.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41453, 2816, 'Younger S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/882163.mp4', 'http://gstaticontent.com/images/mF1g0J0EKSrxnYMr5t9uAzBbJIa_big.jpg'),
(41454, 2817, 'Council of Dads Lembranças do Meu Pai S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mRyyJkwFustpIFCmdNdOPEga2QW.jpg'),
(41455, 2818, 'As Five S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206814.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41456, 2818, 'As Five S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206815.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41457, 2818, 'As Five S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206816.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41458, 2818, 'As Five S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206817.mp4', 'http://timg.bdta.pro/images/_small.jpg'),
(41459, 2818, 'As Five S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206818.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41460, 2818, 'As Five S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206819.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41461, 2818, 'As Five S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206820.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41462, 2818, 'As Five S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206821.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41463, 2818, 'As Five S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206822.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41464, 2818, 'As Five S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206823.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41465, 2819, 'As Five S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206824.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41466, 2819, 'As Five S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206825.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41467, 2819, 'As Five S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206826.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41468, 2819, 'As Five S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206827.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41469, 2819, 'As Five S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206828.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41470, 2819, 'As Five S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206829.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41471, 2819, 'As Five S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206830.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41472, 2819, 'As Five S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206831.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41473, 2820, 'As Five S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289352.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41474, 2820, 'As Five S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289353.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41475, 2820, 'As Five S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289354.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41476, 2820, 'As Five S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289355.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41477, 2820, 'As Five S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289356.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41478, 2820, 'As Five S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289357.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41479, 2820, 'As Five S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289358.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41480, 2820, 'As Five S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289359.mp4', 'http://gstaticontent.com/images/dR2RO4MMXPBQ8CaaQB39oGDTsD1_big.jpg'),
(41481, 2821, 'Wolfblood S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131311.mp4', 'http://gstaticontent.com/images/vc8mcUflyYow88CXYiaeAFoVTXI_big.jpg'),
(41482, 2821, 'Wolfblood S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131312.mp4', 'http://gstaticontent.com/images/vc8mcUflyYow88CXYiaeAFoVTXI_big.jpg'),
(41483, 2821, 'Wolfblood S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131313.mp4', 'http://gstaticontent.com/images/vc8mcUflyYow88CXYiaeAFoVTXI_big.jpg'),
(41484, 2821, 'Wolfblood S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131314.mp4', 'http://gstaticontent.com/images/vc8mcUflyYow88CXYiaeAFoVTXI_big.jpg'),
(41485, 2821, 'Wolfblood S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131315.mp4', 'http://gstaticontent.com/images/vc8mcUflyYow88CXYiaeAFoVTXI_big.jpg'),
(41486, 2821, 'Wolfblood S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131316.mp4', 'http://gstaticontent.com/images/vc8mcUflyYow88CXYiaeAFoVTXI_big.jpg'),
(41487, 2821, 'Wolfblood S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131317.mp4', 'http://gstaticontent.com/images/vc8mcUflyYow88CXYiaeAFoVTXI_big.jpg'),
(41488, 2821, 'Wolfblood S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131318.mp4', 'http://gstaticontent.com/images/vc8mcUflyYow88CXYiaeAFoVTXI_big.jpg'),
(41489, 2821, 'Wolfblood S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131319.mp4', 'http://gstaticontent.com/images/vc8mcUflyYow88CXYiaeAFoVTXI_big.jpg'),
(41490, 2821, 'Wolfblood S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131320.mp4', 'http://gstaticontent.com/images/vc8mcUflyYow88CXYiaeAFoVTXI_big.jpg'),
(41491, 2821, 'Wolfblood S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131321.mp4', 'http://gstaticontent.com/images/vc8mcUflyYow88CXYiaeAFoVTXI_big.jpg'),
(41492, 2821, 'Wolfblood S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131322.mp4', 'http://gstaticontent.com/images/vc8mcUflyYow88CXYiaeAFoVTXI_big.jpg'),
(41493, 2821, 'Wolfblood S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131323.mp4', 'http://gstaticontent.com/images/vc8mcUflyYow88CXYiaeAFoVTXI_big.jpg'),
(41494, 2822, 'Wolfblood S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/385475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lI2zUqAjwYcYuTSBQzYIwePW2f.jpg'),
(41495, 2822, 'Wolfblood S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/385476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6pdpw40EbJ8VXCybzp5OfNyGklC.jpg'),
(41496, 2822, 'Wolfblood S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/385477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g6kJtCJP57RGnLEGTGHsO5zRQFy.jpg'),
(41497, 2822, 'Wolfblood S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/385478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/84Gs7OAKfiljiIoZ0e654uRniAU.jpg'),
(41498, 2822, 'Wolfblood S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/385479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xVNSamydcZXeMdmsw0579TcpgEn.jpg'),
(41499, 2822, 'Wolfblood S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/385480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svW2mOJUdL3bg4jdFxGyOagS30J.jpg'),
(41500, 2822, 'Wolfblood S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/385481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nUXTfYFncCcjesVKTfBvkLIorZ8.jpg'),
(41501, 2822, 'Wolfblood S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/385482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/su1ZHtz2etHD68izDB9BXHdTwC3.jpg'),
(41502, 2822, 'Wolfblood S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/385483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZrWf1YPKM7Qk9eoQ5abPFPgoBs.jpg'),
(41503, 2822, 'Wolfblood S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/385484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFKiSxnMbCk1txZMzRSU2hxSvqo.jpg'),
(41504, 2822, 'Wolfblood S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/385485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A8Huy853E0uNaCxKzySdDSFHuyN.jpg'),
(41505, 2822, 'Wolfblood S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/385486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h3PacYCSDUSU1xLPbp2IdTephrW.jpg'),
(41506, 2822, 'Wolfblood S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/385487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gMkGxYPwnaS4J4ExdPbhXUubGEl.jpg'),
(41507, 2823, 'Wolfblood S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/385488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uPN11xOJaceubv7r6p5OLiAtcfW.jpg'),
(41508, 2823, 'Wolfblood S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/385489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3xK6QATy0V0CzuyxnZoRavVvtI5.jpg'),
(41509, 2823, 'Wolfblood S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/385490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c7u1xIkoTI09qfOfD3n1je45mwy.jpg'),
(41510, 2823, 'Wolfblood S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/385491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fW9CJITF90227dSGziTZmoERSxD.jpg'),
(41511, 2823, 'Wolfblood S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/385492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9wngPi5HUGAaewrDWTjlT1xCSki.jpg'),
(41512, 2823, 'Wolfblood S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/385493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/43igCldjp2FMiN7KyVPMsnDTkKV.jpg'),
(41513, 2823, 'Wolfblood S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/385494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/okfAEMQvAcfAa8eqOhwHFYfOhSz.jpg'),
(41514, 2823, 'Wolfblood S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/385495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c86tAXbZ7YO8muMfEEHDRzr3yWO.jpg'),
(41515, 2823, 'Wolfblood S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/385496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3J93ngT4KvRTPpPJf5hOx985mv.jpg'),
(41516, 2823, 'Wolfblood S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/385497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g06MG4MoIxfigzSQXZfNLaO1lzd.jpg'),
(41517, 2823, 'Wolfblood S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/385498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aimjZzqHviDfFrjPp1sH34v5EvX.jpg'),
(41518, 2823, 'Wolfblood S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/385499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/moGm1actmPEYRM160iM6Evp5fzG.jpg'),
(41519, 2823, 'Wolfblood S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/385500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/93AH2OnhsrPvHgZTaGbn6FCmLQW.jpg'),
(41520, 2823, 'Wolfblood S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/385501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBkh1C4fXdlNQgTyR9nodM44EpT.jpg'),
(41521, 2824, 'Wolfblood S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/385502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2WYSnMzpHslP2Ar6GhsHvfukvkT.jpg'),
(41522, 2824, 'Wolfblood S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/385503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5SWOMaLzP1boHjQw3nJTLRlkiro.jpg'),
(41523, 2824, 'Wolfblood S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/385504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x3JxlnAqDHjweMKTZAk5j2J5Hok.jpg'),
(41524, 2824, 'Wolfblood S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/385505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fWUa7aCxT6t1QH9aObM5Jki5XA2.jpg'),
(41525, 2824, 'Wolfblood S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/385506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ySeWQEpznFJQOV3thTciW50SZbz.jpg'),
(41526, 2824, 'Wolfblood S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/385507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/NObFk3eCD7GhfX6Muah938EjYS.jpg'),
(41527, 2824, 'Wolfblood S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/385508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5iEfTaRyb0Aaj5CihS7nL7e8Xfp.jpg'),
(41528, 2824, 'Wolfblood S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/385509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c5ODwcA36BjiuaFkJCS8tMaEOSn.jpg'),
(41529, 2824, 'Wolfblood S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/385510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cq0pbeQ3ZZHYvKSifhApYJZMTsX.jpg'),
(41530, 2824, 'Wolfblood S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/385511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nv3w6MSaTVAfU3NR2K43fq6WuoF.jpg'),
(41531, 2824, 'Wolfblood S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/385512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AjQ2L0yIjppSKgGmXlHTgZE3K2S.jpg'),
(41532, 2824, 'Wolfblood S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/385513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3DGRGfWgupiAL23mAyWjXqWKnrN.jpg'),
(41533, 2825, 'Wolfblood S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/385514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bChDziLi4bzWELgeLTG59m2nn1l.jpg'),
(41534, 2825, 'Wolfblood S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/385515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/foVFkTgwdryjWqrFWhiKNsPgUMF.jpg'),
(41535, 2825, 'Wolfblood S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/385516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wEDe6U2jLR6j3wDvX4ESttiWUGF.jpg'),
(41536, 2825, 'Wolfblood S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/385517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1Bztf1Vg98dtZQF8mWRJc1n8g3.jpg'),
(41537, 2825, 'Wolfblood S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/385518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fy6S4BJZK6zQ7Pgdt6gZYUAfpwj.jpg'),
(41538, 2825, 'Wolfblood S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/385519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3FfQsBqZgrZN8DnJX5giMSfQP4I.jpg'),
(41539, 2825, 'Wolfblood S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/385520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wkAB4DHNrSDmb9Ul8hVHhSxLQXF.jpg'),
(41540, 2825, 'Wolfblood S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/385521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tGPGlch5wWEcgsWM0aFSkMrgO5z.jpg'),
(41541, 2825, 'Wolfblood S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/385522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rLgsLLcTTv7X7vaBKkdmQmGbckM.jpg'),
(41542, 2825, 'Wolfblood S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/385523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lYZ6LEmcOw5XfVUJzx6cLfr9N3X.jpg'),
(41543, 2826, 'Liv e Maddie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131231.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41544, 2826, 'Liv e Maddie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131232.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41545, 2826, 'Liv e Maddie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131233.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41546, 2826, 'Liv e Maddie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131234.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41547, 2826, 'Liv e Maddie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131235.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41548, 2826, 'Liv e Maddie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131236.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41549, 2826, 'Liv e Maddie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131237.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41550, 2826, 'Liv e Maddie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131238.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41551, 2826, 'Liv e Maddie S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131239.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41552, 2826, 'Liv e Maddie S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131240.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41553, 2826, 'Liv e Maddie S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131241.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41554, 2826, 'Liv e Maddie S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131242.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41555, 2826, 'Liv e Maddie S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131243.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41556, 2826, 'Liv e Maddie S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131244.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41557, 2826, 'Liv e Maddie S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131245.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41558, 2826, 'Liv e Maddie S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/131246.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41559, 2826, 'Liv e Maddie S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/131247.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41560, 2826, 'Liv e Maddie S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/131248.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41561, 2826, 'Liv e Maddie S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/131249.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41562, 2826, 'Liv e Maddie S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/131250.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41563, 2826, 'Liv e Maddie S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/131251.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41564, 2827, 'Liv e Maddie S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131252.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41565, 2827, 'Liv e Maddie S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131253.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41566, 2827, 'Liv e Maddie S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131254.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41567, 2827, 'Liv e Maddie S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131255.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41568, 2827, 'Liv e Maddie S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131256.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41569, 2827, 'Liv e Maddie S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131257.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41570, 2827, 'Liv e Maddie S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131258.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41571, 2827, 'Liv e Maddie S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131259.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41572, 2827, 'Liv e Maddie S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131260.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41573, 2827, 'Liv e Maddie S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131261.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41574, 2827, 'Liv e Maddie S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131262.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41575, 2827, 'Liv e Maddie S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131263.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41576, 2827, 'Liv e Maddie S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131264.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41577, 2827, 'Liv e Maddie S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131265.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41578, 2827, 'Liv e Maddie S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131266.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41579, 2827, 'Liv e Maddie S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/131267.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41580, 2827, 'Liv e Maddie S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/131268.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41581, 2827, 'Liv e Maddie S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/131269.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41582, 2827, 'Liv e Maddie S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/131270.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41583, 2827, 'Liv e Maddie S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/131271.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41584, 2827, 'Liv e Maddie S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/131272.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41585, 2827, 'Liv e Maddie S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/131273.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41586, 2827, 'Liv e Maddie S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/131274.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41587, 2827, 'Liv e Maddie S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/131275.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41588, 2828, 'Liv e Maddie S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131276.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41589, 2828, 'Liv e Maddie S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131277.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41590, 2828, 'Liv e Maddie S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131278.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41591, 2828, 'Liv e Maddie S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131279.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41592, 2828, 'Liv e Maddie S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131280.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41593, 2828, 'Liv e Maddie S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131281.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(41594, 2828, 'Liv e Maddie S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131282.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41595, 2828, 'Liv e Maddie S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131283.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41596, 2828, 'Liv e Maddie S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131284.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41597, 2828, 'Liv e Maddie S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131285.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41598, 2828, 'Liv e Maddie S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131286.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41599, 2828, 'Liv e Maddie S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131287.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41600, 2828, 'Liv e Maddie S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131288.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41601, 2828, 'Liv e Maddie S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131289.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41602, 2828, 'Liv e Maddie S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131290.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41603, 2828, 'Liv e Maddie S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/131291.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41604, 2828, 'Liv e Maddie S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/131292.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41605, 2828, 'Liv e Maddie S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/131293.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41606, 2828, 'Liv e Maddie S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/131294.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41607, 2828, 'Liv e Maddie S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/131295.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41608, 2829, 'Liv e Maddie S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131296.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41609, 2829, 'Liv e Maddie S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131297.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41610, 2829, 'Liv e Maddie S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131298.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41611, 2829, 'Liv e Maddie S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131299.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41612, 2829, 'Liv e Maddie S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131300.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41613, 2829, 'Liv e Maddie S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131301.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41614, 2829, 'Liv e Maddie S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131302.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41615, 2829, 'Liv e Maddie S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131303.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41616, 2829, 'Liv e Maddie S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131304.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41617, 2829, 'Liv e Maddie S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131305.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41618, 2829, 'Liv e Maddie S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131306.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41619, 2829, 'Liv e Maddie S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131307.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41620, 2829, 'Liv e Maddie S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131308.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41621, 2829, 'Liv e Maddie S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131309.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41622, 2829, 'Liv e Maddie S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131310.mp4', 'http://gstaticontent.com/images/vkPvG49nXuGhT4kfLIG2VuAROOD_big.jpg'),
(41623, 2830, 'Dignidade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131223.mp4', 'http://gstaticontent.com/images/frfglATu6M9yr3XRwzKr4tON9Rt_big.jpg'),
(41624, 2830, 'Dignidade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131224.mp4', 'http://gstaticontent.com/images/frfglATu6M9yr3XRwzKr4tON9Rt_big.jpg'),
(41625, 2830, 'Dignidade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131225.mp4', 'http://gstaticontent.com/images/frfglATu6M9yr3XRwzKr4tON9Rt_big.jpg'),
(41626, 2830, 'Dignidade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131226.mp4', 'http://gstaticontent.com/images/frfglATu6M9yr3XRwzKr4tON9Rt_big.jpg'),
(41627, 2830, 'Dignidade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131227.mp4', 'http://gstaticontent.com/images/frfglATu6M9yr3XRwzKr4tON9Rt_big.jpg'),
(41628, 2830, 'Dignidade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131228.mp4', 'http://gstaticontent.com/images/frfglATu6M9yr3XRwzKr4tON9Rt_big.jpg'),
(41629, 2830, 'Dignidade S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131229.mp4', 'http://gstaticontent.com/images/frfglATu6M9yr3XRwzKr4tON9Rt_big.jpg'),
(41630, 2830, 'Dignidade S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131230.mp4', 'http://gstaticontent.com/images/frfglATu6M9yr3XRwzKr4tON9Rt_big.jpg'),
(41631, 2831, 'Alex Rider S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170666.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(41632, 2831, 'Alex Rider S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170667.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(41633, 2831, 'Alex Rider S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170668.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(41634, 2831, 'Alex Rider S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170669.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(41635, 2831, 'Alex Rider S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170670.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(41636, 2831, 'Alex Rider S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170671.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(41637, 2831, 'Alex Rider S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170672.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(41638, 2831, 'Alex Rider S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170673.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(41639, 2832, 'Alex Rider S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170674.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(41640, 2832, 'Alex Rider S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170675.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(41641, 2832, 'Alex Rider S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170676.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(41642, 2832, 'Alex Rider S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170677.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(41643, 2832, 'Alex Rider S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170678.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(41644, 2832, 'Alex Rider S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170679.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(41645, 2832, 'Alex Rider S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170680.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(41646, 2832, 'Alex Rider S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170681.mp4', 'http://gstaticontent.com/images/7VkzkvA0XckUClWrlkt4fnmTrkL_big.jpg'),
(41647, 2833, 'Por Um Respiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131217.mp4', 'http://gstaticontent.com/images/7QLnGblyNlwFpEadyQVG1kyROvX_big.jpg'),
(41648, 2833, 'Por Um Respiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131218.mp4', 'http://gstaticontent.com/images/7QLnGblyNlwFpEadyQVG1kyROvX_big.jpg'),
(41649, 2833, 'Por Um Respiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131219.mp4', 'http://gstaticontent.com/images/7QLnGblyNlwFpEadyQVG1kyROvX_big.jpg'),
(41650, 2833, 'Por Um Respiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131220.mp4', 'http://gstaticontent.com/images/7QLnGblyNlwFpEadyQVG1kyROvX_big.jpg'),
(41651, 2833, 'Por Um Respiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131221.mp4', 'http://gstaticontent.com/images/7QLnGblyNlwFpEadyQVG1kyROvX_big.jpg'),
(41652, 2833, 'Por Um Respiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131222.mp4', 'http://gstaticontent.com/images/7QLnGblyNlwFpEadyQVG1kyROvX_big.jpg'),
(41653, 2834, 'Boku no Hero Academia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216971.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41654, 2834, 'Boku no Hero Academia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216972.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41655, 2834, 'Boku no Hero Academia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216973.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41656, 2834, 'Boku no Hero Academia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216974.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41657, 2834, 'Boku no Hero Academia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216975.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41658, 2834, 'Boku no Hero Academia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216976.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41659, 2834, 'Boku no Hero Academia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216977.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41660, 2834, 'Boku no Hero Academia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216978.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41661, 2834, 'Boku no Hero Academia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216979.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41662, 2834, 'Boku no Hero Academia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216980.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41663, 2834, 'Boku no Hero Academia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216981.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41664, 2834, 'Boku no Hero Academia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216982.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41665, 2834, 'Boku no Hero Academia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216983.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41666, 2835, 'Boku no Hero Academia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216984.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41667, 2835, 'Boku no Hero Academia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216985.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41668, 2835, 'Boku no Hero Academia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216986.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41669, 2835, 'Boku no Hero Academia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216987.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41670, 2835, 'Boku no Hero Academia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216988.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41671, 2835, 'Boku no Hero Academia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216989.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41672, 2835, 'Boku no Hero Academia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216990.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41673, 2835, 'Boku no Hero Academia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216991.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41674, 2835, 'Boku no Hero Academia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216992.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41675, 2835, 'Boku no Hero Academia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216993.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41676, 2835, 'Boku no Hero Academia S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216994.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41677, 2835, 'Boku no Hero Academia S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216995.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41678, 2835, 'Boku no Hero Academia S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216996.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41679, 2835, 'Boku no Hero Academia S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216997.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41680, 2835, 'Boku no Hero Academia S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/216998.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41681, 2835, 'Boku no Hero Academia S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/216999.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41682, 2835, 'Boku no Hero Academia S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/217000.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41683, 2835, 'Boku no Hero Academia S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/217001.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41684, 2835, 'Boku no Hero Academia S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/217002.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41685, 2835, 'Boku no Hero Academia S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/217003.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41686, 2835, 'Boku no Hero Academia S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/217004.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41687, 2835, 'Boku no Hero Academia S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/217005.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41688, 2835, 'Boku no Hero Academia S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/217006.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41689, 2835, 'Boku no Hero Academia S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/217007.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41690, 2835, 'Boku no Hero Academia S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/217008.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41691, 2836, 'Boku no Hero Academia S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217009.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41692, 2836, 'Boku no Hero Academia S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217010.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41693, 2836, 'Boku no Hero Academia S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217011.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41694, 2836, 'Boku no Hero Academia S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217012.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41695, 2836, 'Boku no Hero Academia S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217013.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41696, 2836, 'Boku no Hero Academia S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217014.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41697, 2836, 'Boku no Hero Academia S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217015.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41698, 2836, 'Boku no Hero Academia S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217016.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41699, 2836, 'Boku no Hero Academia S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217017.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41700, 2836, 'Boku no Hero Academia S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217018.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41701, 2836, 'Boku no Hero Academia S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217019.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41702, 2836, 'Boku no Hero Academia S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217020.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41703, 2836, 'Boku no Hero Academia S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217021.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41704, 2836, 'Boku no Hero Academia S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/217022.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41705, 2836, 'Boku no Hero Academia S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/217023.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41706, 2836, 'Boku no Hero Academia S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/217024.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41707, 2836, 'Boku no Hero Academia S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/217025.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41708, 2836, 'Boku no Hero Academia S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/217026.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41709, 2836, 'Boku no Hero Academia S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/217027.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41710, 2836, 'Boku no Hero Academia S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/217028.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41711, 2836, 'Boku no Hero Academia S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/217029.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41712, 2836, 'Boku no Hero Academia S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/217030.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41713, 2836, 'Boku no Hero Academia S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/217031.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41714, 2836, 'Boku no Hero Academia S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/217032.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41715, 2836, 'Boku no Hero Academia S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/217033.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41716, 2837, 'Boku no Hero Academia S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217034.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41717, 2837, 'Boku no Hero Academia S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217035.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41718, 2837, 'Boku no Hero Academia S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217036.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41719, 2837, 'Boku no Hero Academia S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217037.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41720, 2837, 'Boku no Hero Academia S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217038.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41721, 2837, 'Boku no Hero Academia S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217039.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41722, 2837, 'Boku no Hero Academia S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217040.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41723, 2837, 'Boku no Hero Academia S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217041.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41724, 2837, 'Boku no Hero Academia S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217042.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41725, 2837, 'Boku no Hero Academia S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217043.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41726, 2837, 'Boku no Hero Academia S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217044.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41727, 2837, 'Boku no Hero Academia S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217045.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41728, 2837, 'Boku no Hero Academia S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217046.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41729, 2837, 'Boku no Hero Academia S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/217047.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41730, 2837, 'Boku no Hero Academia S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/217048.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41731, 2837, 'Boku no Hero Academia S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/217049.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41732, 2837, 'Boku no Hero Academia S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/217050.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41733, 2837, 'Boku no Hero Academia S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/217051.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41734, 2837, 'Boku no Hero Academia S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/217052.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41735, 2837, 'Boku no Hero Academia S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/217053.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41736, 2837, 'Boku no Hero Academia S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/217054.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41737, 2837, 'Boku no Hero Academia S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/217055.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41738, 2837, 'Boku no Hero Academia S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/217056.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41739, 2837, 'Boku no Hero Academia S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/217057.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41740, 2837, 'Boku no Hero Academia S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/217058.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41741, 2838, 'Boku no Hero Academia S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217059.mp4', 'http://timg.bdta.pro/images/f0fa233c258bbfa8b9c39bec3c806f4e.jpg'),
(41742, 2838, 'Boku no Hero Academia S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217060.mp4', 'http://timg.bdta.pro/images/adb93f20200e067d2fba453b4e1a5830.jpg'),
(41743, 2838, 'Boku no Hero Academia S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217061.mp4', 'http://timg.bdta.pro/images/ed1ff80c82a762f4b02767a1734fed66.jpg'),
(41744, 2838, 'Boku no Hero Academia S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217062.mp4', 'http://timg.bdta.pro/images/4b3c37679f560bd6711d999ce89ffe3b.jpg'),
(41745, 2838, 'Boku no Hero Academia S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217063.mp4', 'http://timg.bdta.pro/images/af757d1c600928d42aca058b69775b27.jpg'),
(41746, 2838, 'Boku no Hero Academia S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217064.mp4', 'http://timg.bdta.pro/images/169a04a750086fa735edcd3a12c2c0c5.jpg'),
(41747, 2838, 'Boku no Hero Academia S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217065.mp4', 'http://timg.bdta.pro/images/002c0b535040db856b20655f870a5a6e.jpg'),
(41748, 2838, 'Boku no Hero Academia S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217066.mp4', 'http://timg.bdta.pro/images/97e7603b09e7dfc5ca5da9b0e8b4d978.jpg'),
(41749, 2838, 'Boku no Hero Academia S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217067.mp4', 'http://timg.bdta.pro/images/b2d1e60a1839e610d2637927b9bba929.jpg'),
(41750, 2838, 'Boku no Hero Academia S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217068.mp4', 'http://timg.bdta.pro/images/fc1c51c9fbc8065d43a6a4151d53a02b.jpg'),
(41751, 2838, 'Boku no Hero Academia S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217069.mp4', 'http://timg.bdta.pro/images/efc24786f2126852d8d0fa7cb937ad66.jpg'),
(41752, 2838, 'Boku no Hero Academia S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217070.mp4', 'http://timg.bdta.pro/images/fcd60a9b6ba6dbb89a68b5e76f5f3e87.jpg'),
(41753, 2838, 'Boku no Hero Academia S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217071.mp4', 'http://timg.bdta.pro/images/e30b6a15a7d07ac11d54ae95b8ce6ea6.jpg'),
(41754, 2838, 'Boku no Hero Academia S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/217072.mp4', 'http://timg.bdta.pro/images/86e1f0a468d94794cc12febc07716c13.jpg'),
(41755, 2838, 'Boku no Hero Academia S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/217073.mp4', 'http://timg.bdta.pro/images/7439402592e7196cd6766a12c6f2dc1d.jpg'),
(41756, 2838, 'Boku no Hero Academia S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/217074.mp4', 'http://timg.bdta.pro/images/a472d38f65843aef6b7de70cbbefcc65.jpg'),
(41757, 2838, 'Boku no Hero Academia S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/217075.mp4', 'http://timg.bdta.pro/images/c1eb1657dd67d35d497962b61b021d93.jpg'),
(41758, 2838, 'Boku no Hero Academia S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/217076.mp4', 'http://timg.bdta.pro/images/3beb204315fdac4a2a68c57df504bb75.jpg'),
(41759, 2838, 'Boku no Hero Academia S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/217077.mp4', 'http://timg.bdta.pro/images/3a79782073ba1a41de47c25afb678b86.jpg'),
(41760, 2838, 'Boku no Hero Academia S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/217078.mp4', 'http://timg.bdta.pro/images/a1e8fe3b89514c5472acb004d826d43d.jpg'),
(41761, 2838, 'Boku no Hero Academia S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/217079.mp4', 'http://timg.bdta.pro/images/ce22c395f72ceff1624959b546aed00e.jpg'),
(41762, 2838, 'Boku no Hero Academia S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/217080.mp4', 'http://timg.bdta.pro/images/566593c2eabd35ff54bdb2297c4505eb.jpg'),
(41763, 2838, 'Boku no Hero Academia S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/217081.mp4', 'http://timg.bdta.pro/images/05b7abe2b5042eef4da24fa6660b4b11.jpg'),
(41764, 2838, 'Boku no Hero Academia S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/217082.mp4', 'http://timg.bdta.pro/images/bce781a3433808cac266c25253dcd5dc.jpg'),
(41765, 2838, 'Boku no Hero Academia S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/217083.mp4', 'http://timg.bdta.pro/images/4226856eb50011acf44ca43f12242683.jpg'),
(41766, 2839, 'Boku no Hero Academia S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ezH8zW6UB11eCXBR4rDI1SuQ5gs.jpg'),
(41767, 2839, 'Boku no Hero Academia S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7iCmJKtbHHprGjc9Li5o6inRj1o.jpg'),
(41768, 2839, 'Boku no Hero Academia S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6pN47KLtkjvIipATGB9Dhypfkts.jpg'),
(41769, 2839, 'Boku no Hero Academia S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/blB13XgeDs8bFaA80uX2xM9jO9j.jpg'),
(41770, 2839, 'Boku no Hero Academia S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u6lDEdrnM6Z99S0KHQPp8ZWx8DZ.jpg'),
(41771, 2839, 'Boku no Hero Academia S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4waajYqQmwZQS2toXumWpiDBA8p.jpg'),
(41772, 2839, 'Boku no Hero Academia S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6mnUhO9gWWqhx864Ilg46lPBVrX.jpg'),
(41773, 2839, 'Boku no Hero Academia S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLFBNafIKMyEMjg4xFzj1cAoE2g.jpg'),
(41774, 2839, 'Boku no Hero Academia S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fvPZ32wW3s7kvcpHLUyzPTtUeCp.jpg'),
(41775, 2839, 'Boku no Hero Academia S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5wR8qmywy1Rto8riX9bopp0bKCW.jpg'),
(41776, 2839, 'Boku no Hero Academia S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4mceUKrI8Jk11Z9vxN238IJdM5Q.jpg'),
(41777, 2839, 'Boku no Hero Academia S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y7PY9Xt86AYaBSC1eNateMgWKcE.jpg'),
(41778, 2839, 'Boku no Hero Academia S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xM0yAQk6A8nFTJx0CD327PtanvG.jpg'),
(41779, 2839, 'Boku no Hero Academia S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/217097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6y9e7wCPbWxrzA3Uhj3F1bnYwW.jpg'),
(41780, 2839, 'Boku no Hero Academia S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/217098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/faKL4xUY6UvROUMJYsWjYOPj9Jw.jpg'),
(41781, 2839, 'Boku no Hero Academia S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/217099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yeWoqC48XOOrwMLJt8jkgrJyN1r.jpg'),
(41782, 2839, 'Boku no Hero Academia S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/217100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aLzD6lxekNUnpHF22dpMB6PmEd9.jpg'),
(41783, 2839, 'Boku no Hero Academia S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/217101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rFN8Abn3ZChkhJ2UXZ7yiZPmvYt.jpg'),
(41784, 2839, 'Boku no Hero Academia S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/217102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qsuiAqpcq21c04060f1WDCNpX19.jpg'),
(41785, 2839, 'Boku no Hero Academia S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/217103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qS6YnhRhc6YeKIEZZtETXH60fwU.jpg'),
(41786, 2839, 'Boku no Hero Academia S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/217104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lDWHItqpBBNqDB4P7HGCQru0eFe.jpg'),
(41787, 2839, 'Boku no Hero Academia S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/217105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2FUih57geusmQxr65PIIV5L3nF7.jpg'),
(41788, 2839, 'Boku no Hero Academia S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/217106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5iwVOV442xICdQxlirhYkSE0rq8.jpg'),
(41789, 2839, 'Boku no Hero Academia S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/217107.mp4', 'http://image.tmdb.org/t/p/w1280/tappKU5KIjiCAMVb7jlGksFD8Hx.jpg'),
(41790, 2839, 'Boku no Hero Academia S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/217108.mp4', 'http://image.tmdb.org/t/p/w1280/4xERRuWvV59p6wssrakxi4kLynO.jpg'),
(41791, 2840, 'Boku no Hero Academia S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/363710.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41792, 2840, 'Boku no Hero Academia S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/627354.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41793, 2840, 'Boku no Hero Academia S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/378414.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41794, 2840, 'Boku no Hero Academia S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/387583.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41795, 2840, 'Boku no Hero Academia S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/403649.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41796, 2840, 'Boku no Hero Academia S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/403650.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41797, 2840, 'Boku no Hero Academia S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/403651.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41798, 2840, 'Boku no Hero Academia S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/409523.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41799, 2840, 'Boku no Hero Academia S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/415961.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41800, 2840, 'Boku no Hero Academia S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/425387.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41801, 2840, 'Boku no Hero Academia S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/432749.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41802, 2840, 'Boku no Hero Academia S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/437361.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41803, 2840, 'Boku no Hero Academia S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/448528.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41804, 2840, 'Boku no Hero Academia S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/456550.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41805, 2840, 'Boku no Hero Academia S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/461826.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41806, 2840, 'Boku no Hero Academia S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/468024.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41807, 2840, 'Boku no Hero Academia S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/475065.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41808, 2840, 'Boku no Hero Academia S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/478767.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41809, 2840, 'Boku no Hero Academia S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/485652.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41810, 2840, 'Boku no Hero Academia S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/493893.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41811, 2840, 'Boku no Hero Academia S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/497036.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41812, 2841, 'Boku no Hero Academia S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/890157.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41813, 2841, 'Boku no Hero Academia S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/891068.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41814, 2841, 'Boku no Hero Academia S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/892484.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41815, 2841, 'Boku no Hero Academia S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/892671.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41816, 2841, 'Boku no Hero Academia S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/893392.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41817, 2841, 'Boku no Hero Academia S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/893606.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41818, 2841, 'Boku no Hero Academia S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/894942.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41819, 2841, 'Boku no Hero Academia S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/896233.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41820, 2841, 'Boku no Hero Academia S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/896719.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41821, 2841, 'Boku no Hero Academia S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/897470.mp4', 'http://gstaticontent.com/images/mWHCII5OWHx5pRSN2VYYLvT8DbB_big.jpg'),
(41822, 2842, 'A Coroa Vazia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131198.mp4', 'http://gstaticontent.com/images/4wBCVkunzmYLpuyyogZS84GUWM0_big.jpg'),
(41823, 2842, 'A Coroa Vazia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131199.mp4', 'http://gstaticontent.com/images/4wBCVkunzmYLpuyyogZS84GUWM0_big.jpg'),
(41824, 2842, 'A Coroa Vazia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131200.mp4', 'http://gstaticontent.com/images/4wBCVkunzmYLpuyyogZS84GUWM0_big.jpg'),
(41825, 2842, 'A Coroa Vazia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131201.mp4', 'http://gstaticontent.com/images/4wBCVkunzmYLpuyyogZS84GUWM0_big.jpg'),
(41826, 2842, 'A Coroa Vazia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131202.mp4', 'http://gstaticontent.com/images/4wBCVkunzmYLpuyyogZS84GUWM0_big.jpg'),
(41827, 2842, 'A Coroa Vazia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131203.mp4', 'http://gstaticontent.com/images/4wBCVkunzmYLpuyyogZS84GUWM0_big.jpg'),
(41828, 2842, 'A Coroa Vazia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131204.mp4', 'http://gstaticontent.com/images/4wBCVkunzmYLpuyyogZS84GUWM0_big.jpg'),
(41829, 2842, 'A Coroa Vazia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131205.mp4', 'http://gstaticontent.com/images/4wBCVkunzmYLpuyyogZS84GUWM0_big.jpg'),
(41830, 2842, 'A Coroa Vazia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131206.mp4', 'http://gstaticontent.com/images/4wBCVkunzmYLpuyyogZS84GUWM0_big.jpg'),
(41831, 2842, 'A Coroa Vazia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131207.mp4', 'http://gstaticontent.com/images/4wBCVkunzmYLpuyyogZS84GUWM0_big.jpg'),
(41832, 2842, 'A Coroa Vazia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131208.mp4', 'http://gstaticontent.com/images/4wBCVkunzmYLpuyyogZS84GUWM0_big.jpg'),
(41833, 2843, 'A Coroa Vazia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131209.mp4', 'http://gstaticontent.com/images/4wBCVkunzmYLpuyyogZS84GUWM0_big.jpg'),
(41834, 2843, 'A Coroa Vazia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131210.mp4', 'http://gstaticontent.com/images/4wBCVkunzmYLpuyyogZS84GUWM0_big.jpg'),
(41835, 2843, 'A Coroa Vazia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131211.mp4', 'http://gstaticontent.com/images/4wBCVkunzmYLpuyyogZS84GUWM0_big.jpg'),
(41836, 2843, 'A Coroa Vazia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131212.mp4', 'http://gstaticontent.com/images/4wBCVkunzmYLpuyyogZS84GUWM0_big.jpg'),
(41837, 2843, 'A Coroa Vazia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131213.mp4', 'http://gstaticontent.com/images/4wBCVkunzmYLpuyyogZS84GUWM0_big.jpg'),
(41838, 2843, 'A Coroa Vazia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131214.mp4', 'http://gstaticontent.com/images/4wBCVkunzmYLpuyyogZS84GUWM0_big.jpg'),
(41839, 2843, 'A Coroa Vazia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131215.mp4', 'http://gstaticontent.com/images/4wBCVkunzmYLpuyyogZS84GUWM0_big.jpg'),
(41840, 2843, 'A Coroa Vazia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131216.mp4', 'http://gstaticontent.com/images/4wBCVkunzmYLpuyyogZS84GUWM0_big.jpg'),
(41841, 2844, 'UnREAL S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131159.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41842, 2844, 'UnREAL S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131160.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41843, 2844, 'UnREAL S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131161.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41844, 2844, 'UnREAL S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131162.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41845, 2844, 'UnREAL S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131163.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41846, 2844, 'UnREAL S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131164.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41847, 2844, 'UnREAL S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131165.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41848, 2844, 'UnREAL S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131166.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41849, 2844, 'UnREAL S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131167.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41850, 2844, 'UnREAL S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131168.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41851, 2845, 'UnREAL S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131169.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41852, 2845, 'UnREAL S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131170.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41853, 2845, 'UnREAL S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131171.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41854, 2845, 'UnREAL S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131172.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41855, 2845, 'UnREAL S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131173.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41856, 2845, 'UnREAL S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131174.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41857, 2845, 'UnREAL S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131175.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41858, 2845, 'UnREAL S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131176.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41859, 2845, 'UnREAL S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131177.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41860, 2845, 'UnREAL S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131178.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41861, 2845, 'UnREAL S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131179.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41862, 2846, 'UnREAL S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131180.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41863, 2846, 'UnREAL S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131181.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41864, 2846, 'UnREAL S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131182.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41865, 2846, 'UnREAL S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131183.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41866, 2846, 'UnREAL S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131184.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41867, 2846, 'UnREAL S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131185.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41868, 2846, 'UnREAL S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131186.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41869, 2846, 'UnREAL S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131187.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41870, 2846, 'UnREAL S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131188.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41871, 2846, 'UnREAL S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131189.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41872, 2847, 'UnREAL S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131190.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41873, 2847, 'UnREAL S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131191.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(41874, 2847, 'UnREAL S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131192.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41875, 2847, 'UnREAL S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131193.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41876, 2847, 'UnREAL S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131194.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41877, 2847, 'UnREAL S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131195.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41878, 2847, 'UnREAL S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131196.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41879, 2847, 'UnREAL S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131197.mp4', 'http://gstaticontent.com/images/ldLTSFnLR642BAjFca96VOY7L98_big.jpg'),
(41880, 2848, 'Casual S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131149.mp4', 'http://gstaticontent.com/images/ait0egwYCFSyW7hIfVbWrS7357U_big.jpg'),
(41881, 2848, 'Casual S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131150.mp4', 'http://gstaticontent.com/images/ait0egwYCFSyW7hIfVbWrS7357U_big.jpg'),
(41882, 2848, 'Casual S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131151.mp4', 'http://gstaticontent.com/images/ait0egwYCFSyW7hIfVbWrS7357U_big.jpg'),
(41883, 2848, 'Casual S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131152.mp4', 'http://gstaticontent.com/images/ait0egwYCFSyW7hIfVbWrS7357U_big.jpg'),
(41884, 2848, 'Casual S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131153.mp4', 'http://gstaticontent.com/images/ait0egwYCFSyW7hIfVbWrS7357U_big.jpg'),
(41885, 2848, 'Casual S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131154.mp4', 'http://gstaticontent.com/images/ait0egwYCFSyW7hIfVbWrS7357U_big.jpg'),
(41886, 2848, 'Casual S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131155.mp4', 'http://gstaticontent.com/images/ait0egwYCFSyW7hIfVbWrS7357U_big.jpg'),
(41887, 2848, 'Casual S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131156.mp4', 'http://gstaticontent.com/images/ait0egwYCFSyW7hIfVbWrS7357U_big.jpg'),
(41888, 2848, 'Casual S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131157.mp4', 'http://gstaticontent.com/images/ait0egwYCFSyW7hIfVbWrS7357U_big.jpg'),
(41889, 2848, 'Casual S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131158.mp4', 'http://gstaticontent.com/images/ait0egwYCFSyW7hIfVbWrS7357U_big.jpg'),
(41890, 2849, 'Stumptown: Investigadora Sem Limite S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131131.mp4', 'http://gstaticontent.com/images/7DXrkbnTdrxyfYcSFi9H2my7HSY_big.jpg'),
(41891, 2849, 'Stumptown: Investigadora Sem Limite S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131132.mp4', 'http://gstaticontent.com/images/7DXrkbnTdrxyfYcSFi9H2my7HSY_big.jpg'),
(41892, 2849, 'Stumptown: Investigadora Sem Limite S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131133.mp4', 'http://gstaticontent.com/images/7DXrkbnTdrxyfYcSFi9H2my7HSY_big.jpg'),
(41893, 2849, 'Stumptown: Investigadora Sem Limite S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131134.mp4', 'http://gstaticontent.com/images/7DXrkbnTdrxyfYcSFi9H2my7HSY_big.jpg'),
(41894, 2849, 'Stumptown: Investigadora Sem Limite S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131135.mp4', 'http://gstaticontent.com/images/7DXrkbnTdrxyfYcSFi9H2my7HSY_big.jpg'),
(41895, 2849, 'Stumptown: Investigadora Sem Limite S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131136.mp4', 'http://gstaticontent.com/images/7DXrkbnTdrxyfYcSFi9H2my7HSY_big.jpg'),
(41896, 2849, 'Stumptown: Investigadora Sem Limite S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131137.mp4', 'http://gstaticontent.com/images/7DXrkbnTdrxyfYcSFi9H2my7HSY_big.jpg'),
(41897, 2849, 'Stumptown: Investigadora Sem Limite S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131138.mp4', 'http://gstaticontent.com/images/7DXrkbnTdrxyfYcSFi9H2my7HSY_big.jpg'),
(41898, 2849, 'Stumptown: Investigadora Sem Limite S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131139.mp4', 'http://gstaticontent.com/images/7DXrkbnTdrxyfYcSFi9H2my7HSY_big.jpg'),
(41899, 2849, 'Stumptown: Investigadora Sem Limite S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131140.mp4', 'http://gstaticontent.com/images/7DXrkbnTdrxyfYcSFi9H2my7HSY_big.jpg'),
(41900, 2849, 'Stumptown: Investigadora Sem Limite S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131141.mp4', 'http://gstaticontent.com/images/7DXrkbnTdrxyfYcSFi9H2my7HSY_big.jpg'),
(41901, 2849, 'Stumptown: Investigadora Sem Limite S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131142.mp4', 'http://gstaticontent.com/images/7DXrkbnTdrxyfYcSFi9H2my7HSY_big.jpg'),
(41902, 2849, 'Stumptown: Investigadora Sem Limite S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131143.mp4', 'http://gstaticontent.com/images/7DXrkbnTdrxyfYcSFi9H2my7HSY_big.jpg'),
(41903, 2849, 'Stumptown: Investigadora Sem Limite S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131144.mp4', 'http://gstaticontent.com/images/7DXrkbnTdrxyfYcSFi9H2my7HSY_big.jpg'),
(41904, 2849, 'Stumptown: Investigadora Sem Limite S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131145.mp4', 'http://gstaticontent.com/images/7DXrkbnTdrxyfYcSFi9H2my7HSY_big.jpg'),
(41905, 2849, 'Stumptown: Investigadora Sem Limite S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/131146.mp4', 'http://gstaticontent.com/images/7DXrkbnTdrxyfYcSFi9H2my7HSY_big.jpg'),
(41906, 2849, 'Stumptown: Investigadora Sem Limite S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/131147.mp4', 'http://gstaticontent.com/images/7DXrkbnTdrxyfYcSFi9H2my7HSY_big.jpg'),
(41907, 2849, 'Stumptown: Investigadora Sem Limite S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/131148.mp4', 'http://gstaticontent.com/images/7DXrkbnTdrxyfYcSFi9H2my7HSY_big.jpg'),
(41908, 2850, 'Objetos Cortantes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Yipm8X7jp2BJ84jlYL07IsvUHj.jpg'),
(41909, 2850, 'Objetos Cortantes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Yipm8X7jp2BJ84jlYL07IsvUHj.jpg'),
(41910, 2850, 'Objetos Cortantes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Yipm8X7jp2BJ84jlYL07IsvUHj.jpg'),
(41911, 2850, 'Objetos Cortantes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Yipm8X7jp2BJ84jlYL07IsvUHj.jpg'),
(41912, 2850, 'Objetos Cortantes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Yipm8X7jp2BJ84jlYL07IsvUHj.jpg'),
(41913, 2850, 'Objetos Cortantes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Yipm8X7jp2BJ84jlYL07IsvUHj.jpg'),
(41914, 2850, 'Objetos Cortantes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Yipm8X7jp2BJ84jlYL07IsvUHj.jpg'),
(41915, 2850, 'Objetos Cortantes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Yipm8X7jp2BJ84jlYL07IsvUHj.jpg'),
(41916, 2851, 'Destinos Inesperados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131117.mp4', 'http://gstaticontent.com/images/uvIQhIwupS0yOG9BrbXVlhpzCch_big.jpg'),
(41917, 2851, 'Destinos Inesperados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131118.mp4', 'http://gstaticontent.com/images/uvIQhIwupS0yOG9BrbXVlhpzCch_big.jpg'),
(41918, 2851, 'Destinos Inesperados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131119.mp4', 'http://gstaticontent.com/images/uvIQhIwupS0yOG9BrbXVlhpzCch_big.jpg'),
(41919, 2851, 'Destinos Inesperados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131120.mp4', 'http://gstaticontent.com/images/uvIQhIwupS0yOG9BrbXVlhpzCch_big.jpg'),
(41920, 2851, 'Destinos Inesperados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131121.mp4', 'http://gstaticontent.com/images/uvIQhIwupS0yOG9BrbXVlhpzCch_big.jpg'),
(41921, 2851, 'Destinos Inesperados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131122.mp4', 'http://gstaticontent.com/images/uvIQhIwupS0yOG9BrbXVlhpzCch_big.jpg'),
(41922, 2852, 'Sobe Na Minha Moto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131102.mp4', 'http://gstaticontent.com/images/9Fsee2p5qiac3GGmQjRUOK8oCp0_big.jpg'),
(41923, 2852, 'Sobe Na Minha Moto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131103.mp4', 'http://gstaticontent.com/images/9Fsee2p5qiac3GGmQjRUOK8oCp0_big.jpg'),
(41924, 2852, 'Sobe Na Minha Moto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131104.mp4', 'http://gstaticontent.com/images/9Fsee2p5qiac3GGmQjRUOK8oCp0_big.jpg'),
(41925, 2852, 'Sobe Na Minha Moto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131105.mp4', 'http://gstaticontent.com/images/9Fsee2p5qiac3GGmQjRUOK8oCp0_big.jpg'),
(41926, 2852, 'Sobe Na Minha Moto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131106.mp4', 'http://gstaticontent.com/images/9Fsee2p5qiac3GGmQjRUOK8oCp0_big.jpg'),
(41927, 2852, 'Sobe Na Minha Moto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/131107.mp4', 'http://gstaticontent.com/images/9Fsee2p5qiac3GGmQjRUOK8oCp0_big.jpg'),
(41928, 2852, 'Sobe Na Minha Moto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/131108.mp4', 'http://gstaticontent.com/images/9Fsee2p5qiac3GGmQjRUOK8oCp0_big.jpg'),
(41929, 2852, 'Sobe Na Minha Moto S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/131109.mp4', 'http://gstaticontent.com/images/9Fsee2p5qiac3GGmQjRUOK8oCp0_big.jpg'),
(41930, 2852, 'Sobe Na Minha Moto S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/131110.mp4', 'http://gstaticontent.com/images/9Fsee2p5qiac3GGmQjRUOK8oCp0_big.jpg'),
(41931, 2852, 'Sobe Na Minha Moto S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/131111.mp4', 'http://gstaticontent.com/images/9Fsee2p5qiac3GGmQjRUOK8oCp0_big.jpg'),
(41932, 2852, 'Sobe Na Minha Moto S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/131112.mp4', 'http://gstaticontent.com/images/9Fsee2p5qiac3GGmQjRUOK8oCp0_big.jpg'),
(41933, 2852, 'Sobe Na Minha Moto S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/131113.mp4', 'http://gstaticontent.com/images/9Fsee2p5qiac3GGmQjRUOK8oCp0_big.jpg'),
(41934, 2852, 'Sobe Na Minha Moto S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/131114.mp4', 'http://gstaticontent.com/images/9Fsee2p5qiac3GGmQjRUOK8oCp0_big.jpg'),
(41935, 2852, 'Sobe Na Minha Moto S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/131115.mp4', 'http://gstaticontent.com/images/9Fsee2p5qiac3GGmQjRUOK8oCp0_big.jpg'),
(41936, 2852, 'Sobe Na Minha Moto S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/131116.mp4', 'http://gstaticontent.com/images/9Fsee2p5qiac3GGmQjRUOK8oCp0_big.jpg'),
(41937, 2853, 'Mildred Pierce S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/131097.mp4', 'http://gstaticontent.com/images/eZ7TUocetldADAXZfnMSEVl7SbJ_big.jpg'),
(41938, 2853, 'Mildred Pierce S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/131098.mp4', 'http://gstaticontent.com/images/eZ7TUocetldADAXZfnMSEVl7SbJ_big.jpg'),
(41939, 2853, 'Mildred Pierce S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/131099.mp4', 'http://gstaticontent.com/images/eZ7TUocetldADAXZfnMSEVl7SbJ_big.jpg'),
(41940, 2853, 'Mildred Pierce S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/131100.mp4', 'http://gstaticontent.com/images/eZ7TUocetldADAXZfnMSEVl7SbJ_big.jpg'),
(41941, 2853, 'Mildred Pierce S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/131101.mp4', 'http://gstaticontent.com/images/eZ7TUocetldADAXZfnMSEVl7SbJ_big.jpg'),
(41942, 2854, 'Vergonha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137556.mp4', 'http://gstaticontent.com/images/rWMbqEai3tprM3ii3bUxbaIOglj_big.jpg'),
(41943, 2854, 'Vergonha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137557.mp4', 'http://gstaticontent.com/images/rWMbqEai3tprM3ii3bUxbaIOglj_big.jpg'),
(41944, 2854, 'Vergonha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137558.mp4', 'http://gstaticontent.com/images/rWMbqEai3tprM3ii3bUxbaIOglj_big.jpg'),
(41945, 2854, 'Vergonha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137559.mp4', 'http://gstaticontent.com/images/rWMbqEai3tprM3ii3bUxbaIOglj_big.jpg'),
(41946, 2854, 'Vergonha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137560.mp4', 'http://gstaticontent.com/images/rWMbqEai3tprM3ii3bUxbaIOglj_big.jpg'),
(41947, 2854, 'Vergonha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137561.mp4', 'http://gstaticontent.com/images/rWMbqEai3tprM3ii3bUxbaIOglj_big.jpg'),
(41948, 2854, 'Vergonha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137562.mp4', 'http://gstaticontent.com/images/rWMbqEai3tprM3ii3bUxbaIOglj_big.jpg'),
(41949, 2854, 'Vergonha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137563.mp4', 'http://gstaticontent.com/images/rWMbqEai3tprM3ii3bUxbaIOglj_big.jpg'),
(41950, 2854, 'Vergonha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137564.mp4', 'http://gstaticontent.com/images/rWMbqEai3tprM3ii3bUxbaIOglj_big.jpg'),
(41951, 2855, 'Gangs Of London S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dTwjHpged17xJFC2ESf338fX5l.jpg'),
(41952, 2855, 'Gangs Of London S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dTwjHpged17xJFC2ESf338fX5l.jpg'),
(41953, 2855, 'Gangs Of London S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dTwjHpged17xJFC2ESf338fX5l.jpg'),
(41954, 2855, 'Gangs Of London S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dTwjHpged17xJFC2ESf338fX5l.jpg'),
(41955, 2855, 'Gangs Of London S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dTwjHpged17xJFC2ESf338fX5l.jpg'),
(41956, 2855, 'Gangs Of London S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dTwjHpged17xJFC2ESf338fX5l.jpg'),
(41957, 2855, 'Gangs Of London S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dTwjHpged17xJFC2ESf338fX5l.jpg'),
(41958, 2855, 'Gangs Of London S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dTwjHpged17xJFC2ESf338fX5l.jpg'),
(41959, 2855, 'Gangs Of London S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dTwjHpged17xJFC2ESf338fX5l.jpg'),
(41960, 2856, 'Gangs Of London S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/10LgY1W71IEGSbHryFffGiftJTR.jpg'),
(41961, 2856, 'Gangs Of London S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uTID15RknYRsXoy6fbwNA1DxrHm.jpg'),
(41962, 2856, 'Gangs Of London S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m6lvoyk4SZg5yAubjno5qi57MmT.jpg'),
(41963, 2856, 'Gangs Of London S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201981.mp4', 'http://image.tmdb.org/t/p/w1280/jsxmbKVjtRSEL79fegmYg8EjcYG.jpg'),
(41964, 2856, 'Gangs Of London S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gvKSe308pBQhvIdwtIHURSHfDYh.jpg'),
(41965, 2856, 'Gangs Of London S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Ks4kfJEhc9LqaQqX0GEoMbX7Qo.jpg'),
(41966, 2856, 'Gangs Of London S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mKrrmzPfBxwbYvhe5CwlUaPd0nC.jpg'),
(41967, 2856, 'Gangs Of London S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201985.mp4', 'http://image.tmdb.org/t/p/w1280/tn79hKgbx2Pow8LvJE7z9G63qtA.jpg'),
(41968, 2857, 'Seduced: Inside the NXIVM Cult S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130530.mp4', 'http://gstaticontent.com/images/2algVl1riUbFcFBxxy1Ops6FNM7_big.jpg'),
(41969, 2857, 'Seduced: Inside the NXIVM Cult S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130531.mp4', 'http://gstaticontent.com/images/2algVl1riUbFcFBxxy1Ops6FNM7_big.jpg'),
(41970, 2857, 'Seduced: Inside the NXIVM Cult S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130532.mp4', 'http://gstaticontent.com/images/2algVl1riUbFcFBxxy1Ops6FNM7_big.jpg'),
(41971, 2857, 'Seduced: Inside the NXIVM Cult S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130533.mp4', 'http://gstaticontent.com/images/2algVl1riUbFcFBxxy1Ops6FNM7_big.jpg'),
(41972, 2858, 'I Know This Much Is True S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136819.mp4', 'http://gstaticontent.com/images/y6bjZiYZa1U8UJ2KxgJuU0B8M5K_big.jpg'),
(41973, 2858, 'I Know This Much Is True S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136820.mp4', 'http://gstaticontent.com/images/y6bjZiYZa1U8UJ2KxgJuU0B8M5K_big.jpg'),
(41974, 2858, 'I Know This Much Is True S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136821.mp4', 'http://gstaticontent.com/images/y6bjZiYZa1U8UJ2KxgJuU0B8M5K_big.jpg'),
(41975, 2858, 'I Know This Much Is True S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136822.mp4', 'http://gstaticontent.com/images/y6bjZiYZa1U8UJ2KxgJuU0B8M5K_big.jpg'),
(41976, 2858, 'I Know This Much Is True S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136823.mp4', 'http://gstaticontent.com/images/y6bjZiYZa1U8UJ2KxgJuU0B8M5K_big.jpg'),
(41977, 2858, 'I Know This Much Is True S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136824.mp4', 'http://gstaticontent.com/images/y6bjZiYZa1U8UJ2KxgJuU0B8M5K_big.jpg'),
(41978, 2859, 'No Mans Land S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136811.mp4', 'http://gstaticontent.com/images/jdf3GaBuyPBWnC84HtcJlyBawWb_big.jpg'),
(41979, 2859, 'No Mans Land S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136812.mp4', 'http://gstaticontent.com/images/jdf3GaBuyPBWnC84HtcJlyBawWb_big.jpg'),
(41980, 2859, 'No Mans Land S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136813.mp4', 'http://gstaticontent.com/images/jdf3GaBuyPBWnC84HtcJlyBawWb_big.jpg'),
(41981, 2859, 'No Mans Land S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136814.mp4', 'http://gstaticontent.com/images/jdf3GaBuyPBWnC84HtcJlyBawWb_big.jpg'),
(41982, 2859, 'No Mans Land S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136815.mp4', 'http://gstaticontent.com/images/jdf3GaBuyPBWnC84HtcJlyBawWb_big.jpg'),
(41983, 2859, 'No Mans Land S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136816.mp4', 'http://gstaticontent.com/images/jdf3GaBuyPBWnC84HtcJlyBawWb_big.jpg'),
(41984, 2859, 'No Mans Land S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136817.mp4', 'http://gstaticontent.com/images/jdf3GaBuyPBWnC84HtcJlyBawWb_big.jpg'),
(41985, 2859, 'No Mans Land S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136818.mp4', 'http://gstaticontent.com/images/jdf3GaBuyPBWnC84HtcJlyBawWb_big.jpg'),
(41986, 2860, 'A Última Onda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130682.mp4', 'http://gstaticontent.com/images/4OO7jdAp8n95nIRd8S4JU700mHV_big.jpg'),
(41987, 2860, 'A Última Onda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130683.mp4', 'http://gstaticontent.com/images/4OO7jdAp8n95nIRd8S4JU700mHV_big.jpg'),
(41988, 2860, 'A Última Onda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130684.mp4', 'http://gstaticontent.com/images/4OO7jdAp8n95nIRd8S4JU700mHV_big.jpg'),
(41989, 2860, 'A Última Onda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130685.mp4', 'http://gstaticontent.com/images/4OO7jdAp8n95nIRd8S4JU700mHV_big.jpg'),
(41990, 2860, 'A Última Onda S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130686.mp4', 'http://gstaticontent.com/images/4OO7jdAp8n95nIRd8S4JU700mHV_big.jpg'),
(41991, 2860, 'A Última Onda S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130687.mp4', 'http://gstaticontent.com/images/4OO7jdAp8n95nIRd8S4JU700mHV_big.jpg'),
(41992, 2861, '30 Moedas [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yo3udZRKPbhfzI7sWaI2hhyfhRM.jpg'),
(41993, 2861, '30 Moedas [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yo3udZRKPbhfzI7sWaI2hhyfhRM.jpg'),
(41994, 2861, '30 Moedas [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yo3udZRKPbhfzI7sWaI2hhyfhRM.jpg'),
(41995, 2861, '30 Moedas [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yo3udZRKPbhfzI7sWaI2hhyfhRM.jpg'),
(41996, 2861, '30 Moedas [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yo3udZRKPbhfzI7sWaI2hhyfhRM.jpg'),
(41997, 2861, '30 Moedas [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yo3udZRKPbhfzI7sWaI2hhyfhRM.jpg'),
(41998, 2861, '30 Moedas [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yo3udZRKPbhfzI7sWaI2hhyfhRM.jpg'),
(41999, 2861, '30 Moedas [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yo3udZRKPbhfzI7sWaI2hhyfhRM.jpg'),
(42000, 2862, '30 Moedas [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yo3udZRKPbhfzI7sWaI2hhyfhRM.jpg'),
(42001, 2862, '30 Moedas [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yo3udZRKPbhfzI7sWaI2hhyfhRM.jpg'),
(42002, 2862, '30 Moedas [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yo3udZRKPbhfzI7sWaI2hhyfhRM.jpg'),
(42003, 2862, '30 Moedas [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yo3udZRKPbhfzI7sWaI2hhyfhRM.jpg'),
(42004, 2862, '30 Moedas [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yo3udZRKPbhfzI7sWaI2hhyfhRM.jpg'),
(42005, 2862, '30 Moedas [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yo3udZRKPbhfzI7sWaI2hhyfhRM.jpg'),
(42006, 2862, '30 Moedas [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yo3udZRKPbhfzI7sWaI2hhyfhRM.jpg'),
(42007, 2862, '30 Moedas [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yo3udZRKPbhfzI7sWaI2hhyfhRM.jpg'),
(42008, 2863, 'Black Narcissus [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130679.mp4', 'http://gstaticontent.com/images/3eYusIhAodlw2Lgoh1k8npejW8Z_big.jpg'),
(42009, 2863, 'Black Narcissus [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130680.mp4', 'http://gstaticontent.com/images/3eYusIhAodlw2Lgoh1k8npejW8Z_big.jpg'),
(42010, 2863, 'Black Narcissus [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130681.mp4', 'http://gstaticontent.com/images/3eYusIhAodlw2Lgoh1k8npejW8Z_big.jpg'),
(42011, 2864, 'Industry S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198102.mp4', 'http://gstaticontent.com/images/y1jdCmAVdB5r8amiZmFuNnWnqXA_big.jpg'),
(42012, 2864, 'Industry S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198103.mp4', 'http://gstaticontent.com/images/y1jdCmAVdB5r8amiZmFuNnWnqXA_big.jpg'),
(42013, 2864, 'Industry S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198104.mp4', 'http://gstaticontent.com/images/y1jdCmAVdB5r8amiZmFuNnWnqXA_big.jpg'),
(42014, 2864, 'Industry S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198105.mp4', 'http://gstaticontent.com/images/y1jdCmAVdB5r8amiZmFuNnWnqXA_big.jpg'),
(42015, 2864, 'Industry S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198106.mp4', 'http://gstaticontent.com/images/y1jdCmAVdB5r8amiZmFuNnWnqXA_big.jpg'),
(42016, 2864, 'Industry S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198107.mp4', 'http://gstaticontent.com/images/y1jdCmAVdB5r8amiZmFuNnWnqXA_big.jpg'),
(42017, 2864, 'Industry S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198108.mp4', 'http://gstaticontent.com/images/y1jdCmAVdB5r8amiZmFuNnWnqXA_big.jpg'),
(42018, 2864, 'Industry S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198109.mp4', 'http://gstaticontent.com/images/y1jdCmAVdB5r8amiZmFuNnWnqXA_big.jpg'),
(42019, 2865, 'Industry S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198110.mp4', 'http://timg.bdta.pro/images/930a3e95d97b6df9ccea45c1fdae02db.jpg'),
(42020, 2865, 'Industry S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198111.mp4', 'http://timg.bdta.pro/images/e5ef5c1bea60c3dfa18a8e06c82721ed.jpg'),
(42021, 2865, 'Industry S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198112.mp4', 'http://timg.bdta.pro/images/dd4a9a40b428ad454a7469f685d6cf7d.jpg'),
(42022, 2865, 'Industry S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198113.mp4', 'http://timg.bdta.pro/images/fd15f055c2e258753b059610b0b96e92.jpg'),
(42023, 2865, 'Industry S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198114.mp4', 'http://timg.bdta.pro/images/eb49aff019ce3061d82b7dc205332d61.jpg'),
(42024, 2865, 'Industry S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198115.mp4', 'http://timg.bdta.pro/images/27c79e75da4a6e55b2f280856de8d527.jpg'),
(42025, 2865, 'Industry S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198116.mp4', 'http://timg.bdta.pro/images/f467c0684eb26a2ca4e9bc915bd854e6.jpg'),
(42026, 2865, 'Industry S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198117.mp4', 'http://timg.bdta.pro/images/d0c37dbdc65e08a8f257bf649abbba15.jpg'),
(42027, 2866, 'Industry S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/434711.mp4', 'http://gstaticontent.com/images/y1jdCmAVdB5r8amiZmFuNnWnqXA_big.jpg'),
(42028, 2866, 'Industry S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/434712.mp4', 'http://gstaticontent.com/images/y1jdCmAVdB5r8amiZmFuNnWnqXA_big.jpg'),
(42029, 2866, 'Industry S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/436593.mp4', 'http://gstaticontent.com/images/y1jdCmAVdB5r8amiZmFuNnWnqXA_big.jpg'),
(42030, 2866, 'Industry S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/444566.mp4', 'http://gstaticontent.com/images/y1jdCmAVdB5r8amiZmFuNnWnqXA_big.jpg'),
(42031, 2866, 'Industry S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/447817.mp4', 'http://gstaticontent.com/images/y1jdCmAVdB5r8amiZmFuNnWnqXA_big.jpg'),
(42032, 2866, 'Industry S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/456114.mp4', 'http://gstaticontent.com/images/y1jdCmAVdB5r8amiZmFuNnWnqXA_big.jpg'),
(42033, 2866, 'Industry S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/460973.mp4', 'http://gstaticontent.com/images/y1jdCmAVdB5r8amiZmFuNnWnqXA_big.jpg'),
(42034, 2866, 'Industry S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/467400.mp4', 'http://gstaticontent.com/images/y1jdCmAVdB5r8amiZmFuNnWnqXA_big.jpg'),
(42035, 2867, 'Te Devo Essa Reforma das Estrelas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163801.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42036, 2867, 'Te Devo Essa Reforma das Estrelas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163802.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42037, 2867, 'Te Devo Essa Reforma das Estrelas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163803.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42038, 2867, 'Te Devo Essa Reforma das Estrelas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163804.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42039, 2867, 'Te Devo Essa Reforma das Estrelas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163805.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42040, 2867, 'Te Devo Essa Reforma das Estrelas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163806.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42041, 2868, 'Te Devo Essa Reforma das Estrelas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2tObMdgZvwwEvDEY4axtmucsM9P.jpg'),
(42042, 2868, 'Te Devo Essa Reforma das Estrelas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/meG4rAa50PapmFANOnLSXiykVXF.jpg'),
(42043, 2868, 'Te Devo Essa Reforma das Estrelas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/clRvSScKXWk0dDNHfM8FHUQHQhu.jpg'),
(42044, 2868, 'Te Devo Essa Reforma das Estrelas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bWIHaWNpxHbdHcYzlNrkbGYR4Jm.jpg'),
(42045, 2869, 'Te Devo Essa Reforma das Estrelas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/480893.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42046, 2869, 'Te Devo Essa Reforma das Estrelas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/480894.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42047, 2869, 'Te Devo Essa Reforma das Estrelas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/480895.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42048, 2869, 'Te Devo Essa Reforma das Estrelas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/480896.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42049, 2869, 'Te Devo Essa Reforma das Estrelas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/480897.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42050, 2869, 'Te Devo Essa Reforma das Estrelas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/480898.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42051, 2870, 'Te Devo Essa Reforma das Estrelas S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/480899.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42052, 2870, 'Te Devo Essa Reforma das Estrelas S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/480900.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42053, 2870, 'Te Devo Essa Reforma das Estrelas S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/480901.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42054, 2870, 'Te Devo Essa Reforma das Estrelas S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/480902.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42055, 2870, 'Te Devo Essa Reforma das Estrelas S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/480903.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42056, 2870, 'Te Devo Essa Reforma das Estrelas S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/480904.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42057, 2870, 'Te Devo Essa Reforma das Estrelas S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/480905.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42058, 2870, 'Te Devo Essa Reforma das Estrelas S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/480906.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42059, 2871, 'Te Devo Essa Reforma das Estrelas S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/480907.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42060, 2871, 'Te Devo Essa Reforma das Estrelas S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/480908.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42061, 2871, 'Te Devo Essa Reforma das Estrelas S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/480909.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42062, 2871, 'Te Devo Essa Reforma das Estrelas S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/480910.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42063, 2871, 'Te Devo Essa Reforma das Estrelas S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/480911.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42064, 2871, 'Te Devo Essa Reforma das Estrelas S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/480912.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42065, 2871, 'Te Devo Essa Reforma das Estrelas S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/480913.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42066, 2871, 'Te Devo Essa Reforma das Estrelas S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/480914.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42067, 2872, 'Te Devo Essa Reforma das Estrelas S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/480915.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42068, 2872, 'Te Devo Essa Reforma das Estrelas S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/480916.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42069, 2872, 'Te Devo Essa Reforma das Estrelas S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/480917.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42070, 2872, 'Te Devo Essa Reforma das Estrelas S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/480918.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42071, 2872, 'Te Devo Essa Reforma das Estrelas S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/480919.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42072, 2872, 'Te Devo Essa Reforma das Estrelas S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/480920.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42073, 2872, 'Te Devo Essa Reforma das Estrelas S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/480921.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42074, 2872, 'Te Devo Essa Reforma das Estrelas S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/480922.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42075, 2873, 'Te Devo Essa Reforma das Estrelas S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/480923.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42076, 2873, 'Te Devo Essa Reforma das Estrelas S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/480924.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42077, 2873, 'Te Devo Essa Reforma das Estrelas S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/480925.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42078, 2873, 'Te Devo Essa Reforma das Estrelas S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/480926.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42079, 2873, 'Te Devo Essa Reforma das Estrelas S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/480927.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42080, 2873, 'Te Devo Essa Reforma das Estrelas S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/480928.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42081, 2873, 'Te Devo Essa Reforma das Estrelas S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/480929.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42082, 2873, 'Te Devo Essa Reforma das Estrelas S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/480930.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42083, 2873, 'Te Devo Essa Reforma das Estrelas S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/480931.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42084, 2873, 'Te Devo Essa Reforma das Estrelas S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/480932.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42085, 2873, 'Te Devo Essa Reforma das Estrelas S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/630088.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42086, 2874, 'Te Devo Essa Reforma das Estrelas S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/480934.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42087, 2874, 'Te Devo Essa Reforma das Estrelas S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/480935.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42088, 2874, 'Te Devo Essa Reforma das Estrelas S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/480936.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42089, 2874, 'Te Devo Essa Reforma das Estrelas S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/489995.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42090, 2874, 'Te Devo Essa Reforma das Estrelas S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/497829.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42091, 2874, 'Te Devo Essa Reforma das Estrelas S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/499416.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42092, 2874, 'Te Devo Essa Reforma das Estrelas S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/504638.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42093, 2875, 'Te Devo Essa Reforma das Estrelas S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/818519.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42094, 2875, 'Te Devo Essa Reforma das Estrelas S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/818520.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42095, 2875, 'Te Devo Essa Reforma das Estrelas S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/818521.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42096, 2875, 'Te Devo Essa Reforma das Estrelas S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/818522.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42097, 2875, 'Te Devo Essa Reforma das Estrelas S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/823763.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42098, 2875, 'Te Devo Essa Reforma das Estrelas S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/835184.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42099, 2876, 'Te Devo Essa Reforma das Estrelas S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/879399.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42100, 2876, 'Te Devo Essa Reforma das Estrelas S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/879400.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42101, 2876, 'Te Devo Essa Reforma das Estrelas S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/879401.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42102, 2876, 'Te Devo Essa Reforma das Estrelas S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/879943.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42103, 2876, 'Te Devo Essa Reforma das Estrelas S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/879944.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42104, 2876, 'Te Devo Essa Reforma das Estrelas S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/880341.mp4', 'http://gstaticontent.com/images/zRPG7v5BANsHI4K7BMvjmxFnzXk_big.jpg'),
(42105, 2877, 'A Vida em Outros Planetas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130562.mp4', 'http://gstaticontent.com/images/9EZSfJ4kc4wxk3EgqeGpw4xvcUj_big.jpg'),
(42106, 2877, 'A Vida em Outros Planetas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130563.mp4', 'http://gstaticontent.com/images/9EZSfJ4kc4wxk3EgqeGpw4xvcUj_big.jpg'),
(42107, 2877, 'A Vida em Outros Planetas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130564.mp4', 'http://gstaticontent.com/images/9EZSfJ4kc4wxk3EgqeGpw4xvcUj_big.jpg'),
(42108, 2877, 'A Vida em Outros Planetas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130565.mp4', 'http://gstaticontent.com/images/9EZSfJ4kc4wxk3EgqeGpw4xvcUj_big.jpg'),
(42109, 2878, 'Ataque dos Titas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258599.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42110, 2878, 'Ataque dos Titas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258600.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42111, 2878, 'Ataque dos Titas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258601.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42112, 2878, 'Ataque dos Titas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258602.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42113, 2878, 'Ataque dos Titas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258603.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42114, 2878, 'Ataque dos Titas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258604.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42115, 2878, 'Ataque dos Titas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258605.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42116, 2878, 'Ataque dos Titas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258606.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42117, 2878, 'Ataque dos Titas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258607.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42118, 2878, 'Ataque dos Titas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258608.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42119, 2878, 'Ataque dos Titas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/258609.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42120, 2878, 'Ataque dos Titas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/258610.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42121, 2878, 'Ataque dos Titas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/258611.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42122, 2878, 'Ataque dos Titas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/258612.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42123, 2878, 'Ataque dos Titas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/258613.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42124, 2878, 'Ataque dos Titas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/258614.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42125, 2878, 'Ataque dos Titas S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/258615.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42126, 2878, 'Ataque dos Titas S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/258616.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42127, 2878, 'Ataque dos Titas S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/258617.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42128, 2878, 'Ataque dos Titas S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/258618.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42129, 2878, 'Ataque dos Titas S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/258619.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42130, 2878, 'Ataque dos Titas S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/258620.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42131, 2878, 'Ataque dos Titas S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/258621.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42132, 2878, 'Ataque dos Titas S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/258622.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42133, 2878, 'Ataque dos Titas S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/258623.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42134, 2879, 'Ataque dos Titas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258624.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42135, 2879, 'Ataque dos Titas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258625.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42136, 2879, 'Ataque dos Titas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258626.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42137, 2879, 'Ataque dos Titas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258627.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42138, 2879, 'Ataque dos Titas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258628.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42139, 2879, 'Ataque dos Titas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258629.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42140, 2879, 'Ataque dos Titas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258630.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42141, 2879, 'Ataque dos Titas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258631.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42142, 2879, 'Ataque dos Titas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258632.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42143, 2879, 'Ataque dos Titas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258633.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42144, 2879, 'Ataque dos Titas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/258634.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42145, 2879, 'Ataque dos Titas S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/258635.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(42146, 2880, 'Ataque dos Titas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258636.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42147, 2880, 'Ataque dos Titas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258637.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42148, 2880, 'Ataque dos Titas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258638.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42149, 2880, 'Ataque dos Titas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258639.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42150, 2880, 'Ataque dos Titas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258640.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42151, 2880, 'Ataque dos Titas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258641.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42152, 2880, 'Ataque dos Titas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258642.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42153, 2880, 'Ataque dos Titas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258643.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42154, 2880, 'Ataque dos Titas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258644.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42155, 2880, 'Ataque dos Titas S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258645.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42156, 2880, 'Ataque dos Titas S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/258646.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42157, 2880, 'Ataque dos Titas S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/258647.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42158, 2880, 'Ataque dos Titas S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/258648.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42159, 2880, 'Ataque dos Titas S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/258649.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42160, 2880, 'Ataque dos Titas S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/258650.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42161, 2880, 'Ataque dos Titas S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/258651.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42162, 2880, 'Ataque dos Titas S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/258652.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42163, 2880, 'Ataque dos Titas S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/258653.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42164, 2880, 'Ataque dos Titas S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/258654.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42165, 2880, 'Ataque dos Titas S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/258655.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42166, 2880, 'Ataque dos Titas S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/258656.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42167, 2880, 'Ataque dos Titas S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/258657.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42168, 2881, 'Ataque dos Titas S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258658.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42169, 2881, 'Ataque dos Titas S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258659.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42170, 2881, 'Ataque dos Titas S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258660.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42171, 2881, 'Ataque dos Titas S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258661.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42172, 2881, 'Ataque dos Titas S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258662.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42173, 2881, 'Ataque dos Titas S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258663.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42174, 2881, 'Ataque dos Titas S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258664.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42175, 2881, 'Ataque dos Titas S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258665.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42176, 2881, 'Ataque dos Titas S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258666.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42177, 2881, 'Ataque dos Titas S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258667.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42178, 2881, 'Ataque dos Titas S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/258668.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42179, 2881, 'Ataque dos Titas S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/258669.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42180, 2881, 'Ataque dos Titas S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/258670.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42181, 2881, 'Ataque dos Titas S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/258671.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42182, 2881, 'Ataque dos Titas S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/258672.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42183, 2881, 'Ataque dos Titas S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/258673.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42184, 2881, 'Ataque dos Titas S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/258674.mp4', 'http://timg.bdta.pro/images/7c53e8ce96f305215ca08d721940d569.jpg'),
(42185, 2881, 'Ataque dos Titas S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/258675.mp4', 'http://timg.bdta.pro/images/0fd03f39f7b2fe96ca971e2e841ecc70.jpg'),
(42186, 2881, 'Ataque dos Titas S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/258676.mp4', 'http://timg.bdta.pro/images/15853f5a9af6edd3b2c16d943de9d8cb.jpg'),
(42187, 2881, 'Ataque dos Titas S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/258677.mp4', 'http://timg.bdta.pro/images/9c725fd72f5b616799f5caced16c263b.jpg'),
(42188, 2881, 'Ataque dos Titas S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/258678.mp4', 'http://timg.bdta.pro/images/c233aee3f6c912308befd74759cf3c7e.jpg'),
(42189, 2881, 'Ataque dos Titas S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/258679.mp4', 'http://timg.bdta.pro/images/821465a9fc96fa00f6bf79f75ae91c89.jpg'),
(42190, 2881, 'Ataque dos Titas S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/258680.mp4', 'http://timg.bdta.pro/images/49827d78c81dae38e196c764b1004501.jpg'),
(42191, 2881, 'Ataque dos Titas S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/258681.mp4', 'http://timg.bdta.pro/images/3a798aaa779b4a0995959f3f30828815.jpg'),
(42192, 2881, 'Ataque dos Titas S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/258682.mp4', 'http://timg.bdta.pro/images/ee62e82fe16226533c9d510538e3ceba.jpg'),
(42193, 2881, 'Ataque dos Titas S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/258683.mp4', 'http://timg.bdta.pro/images/1f54ca267f7d36e8e9f93f2925e6d097.jpg'),
(42194, 2881, 'Ataque dos Titas S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/258684.mp4', 'http://timg.bdta.pro/images/1229a64eaf26ccd550417f5d201ba320.jpg'),
(42195, 2881, 'Ataque dos Titas S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/258685.mp4', 'http://timg.bdta.pro/images/b6fe829e9fbfc3b61f67ae8b1ececc6a.jpg'),
(42196, 2881, 'Ataque dos Titas S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/258686.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42197, 2881, 'Ataque dos Titas S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/258687.mp4', 'http://gstaticontent.com/images/zMnQh4sNYySLJvSZSSJ2HGIeKw6_big.jpg'),
(42198, 2882, 'New Mexico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192259.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42199, 2882, 'New Mexico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192260.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42200, 2882, 'New Mexico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192261.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42201, 2882, 'New Mexico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192262.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42202, 2882, 'New Mexico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192263.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42203, 2882, 'New Mexico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192264.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42204, 2882, 'New Mexico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192265.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42205, 2882, 'New Mexico S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192266.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42206, 2882, 'New Mexico S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192267.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42207, 2882, 'New Mexico S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192268.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42208, 2882, 'New Mexico S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192269.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42209, 2882, 'New Mexico S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192270.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42210, 2882, 'New Mexico S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/192271.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42211, 2883, 'New Mexico S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192272.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42212, 2883, 'New Mexico S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192273.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42213, 2883, 'New Mexico S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192274.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42214, 2883, 'New Mexico S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192275.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42215, 2883, 'New Mexico S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192276.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42216, 2883, 'New Mexico S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192277.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42217, 2883, 'New Mexico S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192278.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42218, 2883, 'New Mexico S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192279.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42219, 2883, 'New Mexico S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192280.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42220, 2883, 'New Mexico S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192281.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42221, 2883, 'New Mexico S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192282.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42222, 2883, 'New Mexico S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192283.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42223, 2883, 'New Mexico S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/192284.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42224, 2884, 'New Mexico S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192285.mp4', 'http://timg.bdta.pro/images/528982196a8781d3659bd392522aee76.jpg'),
(42225, 2884, 'New Mexico S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192286.mp4', 'http://timg.bdta.pro/images/f22dcc216818bb4cf88809d253dc9dc1.jpg'),
(42226, 2884, 'New Mexico S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192287.mp4', 'http://timg.bdta.pro/images/65428d11a52dc054e01c0a477377f49b.jpg'),
(42227, 2884, 'New Mexico S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192288.mp4', 'http://timg.bdta.pro/images/8831c32ad039c479eefa9d9c0f6a2f4e.jpg'),
(42228, 2884, 'New Mexico S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192289.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42229, 2884, 'New Mexico S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192290.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42230, 2884, 'New Mexico S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192291.mp4', 'http://timg.bdta.pro/images/1406c9a7eff9b83ea8b8b13b5d8290ec.jpg'),
(42231, 2884, 'New Mexico S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192292.mp4', 'http://timg.bdta.pro/images/e5414d9c194c0c97b3204ad2a880ff95.jpg'),
(42232, 2884, 'New Mexico S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192293.mp4', 'http://gstaticontent.com/images/39NeXGZHGVjLvT10zCiTwVW4gdj_big.jpg'),
(42233, 2884, 'New Mexico S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192294.mp4', 'http://image.tmdb.org/t/p/w1280/5dGnYNf9SrBDt8p9nJqqAmVDfts.jpg'),
(42234, 2884, 'New Mexico S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192295.mp4', 'http://image.tmdb.org/t/p/w1280/m28OI3nfdrYNGc3lxiLouRFgIyc.jpg'),
(42235, 2884, 'New Mexico S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mgvh6P1EZa6xd7AyDs67njJbAC0.jpg'),
(42236, 2884, 'New Mexico S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/192297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gOLq4NIdXOgwZ91siuXTg6dgjM3.jpg'),
(42237, 2885, 'New Mexico S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192298.mp4', 'http://timg.bdta.pro/images/945831a70e7e359c7bf506af22326771.jpg'),
(42238, 2885, 'New Mexico S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192299.mp4', 'http://timg.bdta.pro/images/7282597793f633a21c0f155c47777a84.jpg'),
(42239, 2885, 'New Mexico S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192300.mp4', 'http://timg.bdta.pro/images/20a3f3906b6dc04ce3728a1250f4739c.jpg'),
(42240, 2885, 'New Mexico S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192301.mp4', 'http://timg.bdta.pro/images/694fbe18d24dacb3d1c8a5ed285dc484.jpg'),
(42241, 2885, 'New Mexico S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192302.mp4', 'http://timg.bdta.pro/images/b88ff28ad98ff8cc16fbebe4b16ae441.jpg'),
(42242, 2885, 'New Mexico S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192303.mp4', 'http://timg.bdta.pro/images/22105147d4a38d651d18acddfc6e7156.jpg'),
(42243, 2885, 'New Mexico S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192304.mp4', 'http://timg.bdta.pro/images/901c9ed84f5eaac652a955a7a13e70ab.jpg'),
(42244, 2885, 'New Mexico S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192305.mp4', 'http://timg.bdta.pro/images/126eaace99af5d4ab033ad1e8edeb472.jpg'),
(42245, 2885, 'New Mexico S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192306.mp4', 'http://timg.bdta.pro/images/fe1aadc655187d7fb4585268117fa179.jpg'),
(42246, 2885, 'New Mexico S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192307.mp4', 'http://timg.bdta.pro/images/262eac984f13136b0f14837d5b30766c.jpg'),
(42247, 2885, 'New Mexico S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192308.mp4', 'http://timg.bdta.pro/images/c7bbe30a9282da77fd86fac76d2ee740.jpg'),
(42248, 2885, 'New Mexico S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192309.mp4', 'http://timg.bdta.pro/images/8d82f140fb88d349deb174e98fdc7471.jpg'),
(42249, 2885, 'New Mexico S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/192310.mp4', 'http://timg.bdta.pro/images/b2a6ca427c18546436786ddb4187e2bf.jpg'),
(42250, 2886, 'Underground - Uma História de Resistência S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130552.mp4', 'http://gstaticontent.com/images/hBgYiAHqZBY0ypGKMd8NzYbEwnq_big.jpg'),
(42251, 2886, 'Underground - Uma História de Resistência S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130553.mp4', 'http://gstaticontent.com/images/hBgYiAHqZBY0ypGKMd8NzYbEwnq_big.jpg'),
(42252, 2886, 'Underground - Uma História de Resistência S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130554.mp4', 'http://gstaticontent.com/images/hBgYiAHqZBY0ypGKMd8NzYbEwnq_big.jpg'),
(42253, 2886, 'Underground - Uma História de Resistência S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130555.mp4', 'http://gstaticontent.com/images/hBgYiAHqZBY0ypGKMd8NzYbEwnq_big.jpg'),
(42254, 2886, 'Underground - Uma História de Resistência S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130556.mp4', 'http://gstaticontent.com/images/hBgYiAHqZBY0ypGKMd8NzYbEwnq_big.jpg'),
(42255, 2886, 'Underground - Uma História de Resistência S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130557.mp4', 'http://gstaticontent.com/images/hBgYiAHqZBY0ypGKMd8NzYbEwnq_big.jpg'),
(42256, 2886, 'Underground - Uma História de Resistência S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130558.mp4', 'http://gstaticontent.com/images/hBgYiAHqZBY0ypGKMd8NzYbEwnq_big.jpg'),
(42257, 2886, 'Underground - Uma História de Resistência S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130559.mp4', 'http://gstaticontent.com/images/hBgYiAHqZBY0ypGKMd8NzYbEwnq_big.jpg'),
(42258, 2886, 'Underground - Uma História de Resistência S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/130560.mp4', 'http://gstaticontent.com/images/hBgYiAHqZBY0ypGKMd8NzYbEwnq_big.jpg'),
(42259, 2886, 'Underground - Uma História de Resistência S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/130561.mp4', 'http://gstaticontent.com/images/hBgYiAHqZBY0ypGKMd8NzYbEwnq_big.jpg'),
(42260, 2887, 'The Wilds: Vidas Selvagens S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181492.mp4', 'http://gstaticontent.com/images/hPP9N0PgyNfO6kazsSBa4AnFcFY_big.jpg'),
(42261, 2887, 'The Wilds: Vidas Selvagens S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181493.mp4', 'http://gstaticontent.com/images/hPP9N0PgyNfO6kazsSBa4AnFcFY_big.jpg'),
(42262, 2887, 'The Wilds: Vidas Selvagens S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181494.mp4', 'http://gstaticontent.com/images/hPP9N0PgyNfO6kazsSBa4AnFcFY_big.jpg'),
(42263, 2887, 'The Wilds: Vidas Selvagens S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181495.mp4', 'http://gstaticontent.com/images/hPP9N0PgyNfO6kazsSBa4AnFcFY_big.jpg'),
(42264, 2887, 'The Wilds: Vidas Selvagens S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181496.mp4', 'http://gstaticontent.com/images/hPP9N0PgyNfO6kazsSBa4AnFcFY_big.jpg'),
(42265, 2887, 'The Wilds: Vidas Selvagens S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181497.mp4', 'http://gstaticontent.com/images/hPP9N0PgyNfO6kazsSBa4AnFcFY_big.jpg'),
(42266, 2887, 'The Wilds: Vidas Selvagens S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181498.mp4', 'http://gstaticontent.com/images/hPP9N0PgyNfO6kazsSBa4AnFcFY_big.jpg'),
(42267, 2887, 'The Wilds: Vidas Selvagens S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181499.mp4', 'http://gstaticontent.com/images/hPP9N0PgyNfO6kazsSBa4AnFcFY_big.jpg'),
(42268, 2887, 'The Wilds: Vidas Selvagens S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181500.mp4', 'http://gstaticontent.com/images/hPP9N0PgyNfO6kazsSBa4AnFcFY_big.jpg'),
(42269, 2887, 'The Wilds: Vidas Selvagens S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181501.mp4', 'http://gstaticontent.com/images/hPP9N0PgyNfO6kazsSBa4AnFcFY_big.jpg'),
(42270, 2888, 'The Wilds: Vidas Selvagens S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181502.mp4', 'http://timg.bdta.pro/images/e0ac53217957de84039996d50e97a49d.jpg'),
(42271, 2888, 'The Wilds: Vidas Selvagens S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181503.mp4', 'http://timg.bdta.pro/images/cac6104318f8327033626614880907b6.jpg'),
(42272, 2888, 'The Wilds: Vidas Selvagens S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181504.mp4', 'http://timg.bdta.pro/images/e65a2aa8de506329b6f1bb4f156417ed.jpg'),
(42273, 2888, 'The Wilds: Vidas Selvagens S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181505.mp4', 'http://timg.bdta.pro/images/71f0facfbcdf7c412367c5e55d132335.jpg'),
(42274, 2888, 'The Wilds: Vidas Selvagens S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181506.mp4', 'http://timg.bdta.pro/images/e2fc8c299027211132e28cc9125ef7e7.jpg'),
(42275, 2888, 'The Wilds: Vidas Selvagens S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181507.mp4', 'http://timg.bdta.pro/images/8512168c895d4c37c11d71ba747456fd.jpg'),
(42276, 2888, 'The Wilds: Vidas Selvagens S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181508.mp4', 'http://timg.bdta.pro/images/34373d4f440dd09d137f9d93c597a1e8.jpg'),
(42277, 2888, 'The Wilds: Vidas Selvagens S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181509.mp4', 'http://timg.bdta.pro/images/b38c1ba1a15ea67418851e836352ab0a.jpg'),
(42278, 2889, 'A Desordem que Ficou S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130544.mp4', 'http://gstaticontent.com/images/qBkpU4dhfE36BgwQ0hT2xQ8tAZ0_big.jpg'),
(42279, 2889, 'A Desordem que Ficou S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130545.mp4', 'http://gstaticontent.com/images/qBkpU4dhfE36BgwQ0hT2xQ8tAZ0_big.jpg'),
(42280, 2889, 'A Desordem que Ficou S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130546.mp4', 'http://gstaticontent.com/images/qBkpU4dhfE36BgwQ0hT2xQ8tAZ0_big.jpg'),
(42281, 2889, 'A Desordem que Ficou S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130547.mp4', 'http://gstaticontent.com/images/qBkpU4dhfE36BgwQ0hT2xQ8tAZ0_big.jpg'),
(42282, 2889, 'A Desordem que Ficou S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130548.mp4', 'http://gstaticontent.com/images/qBkpU4dhfE36BgwQ0hT2xQ8tAZ0_big.jpg'),
(42283, 2889, 'A Desordem que Ficou S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130549.mp4', 'http://gstaticontent.com/images/qBkpU4dhfE36BgwQ0hT2xQ8tAZ0_big.jpg'),
(42284, 2889, 'A Desordem que Ficou S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/130550.mp4', 'http://gstaticontent.com/images/qBkpU4dhfE36BgwQ0hT2xQ8tAZ0_big.jpg'),
(42285, 2889, 'A Desordem que Ficou S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/130551.mp4', 'http://gstaticontent.com/images/qBkpU4dhfE36BgwQ0hT2xQ8tAZ0_big.jpg'),
(42286, 2890, 'Alice in Borderland S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206570.mp4', 'http://gstaticontent.com/images/i0i7kGDrArtM1sCd8niZDC7iboV_big.jpg'),
(42287, 2890, 'Alice in Borderland S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206571.mp4', 'http://gstaticontent.com/images/i0i7kGDrArtM1sCd8niZDC7iboV_big.jpg'),
(42288, 2890, 'Alice in Borderland S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206572.mp4', 'http://gstaticontent.com/images/i0i7kGDrArtM1sCd8niZDC7iboV_big.jpg'),
(42289, 2890, 'Alice in Borderland S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206573.mp4', 'http://gstaticontent.com/images/i0i7kGDrArtM1sCd8niZDC7iboV_big.jpg'),
(42290, 2890, 'Alice in Borderland S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206574.mp4', 'http://gstaticontent.com/images/i0i7kGDrArtM1sCd8niZDC7iboV_big.jpg'),
(42291, 2890, 'Alice in Borderland S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206575.mp4', 'http://gstaticontent.com/images/i0i7kGDrArtM1sCd8niZDC7iboV_big.jpg'),
(42292, 2890, 'Alice in Borderland S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206576.mp4', 'http://gstaticontent.com/images/i0i7kGDrArtM1sCd8niZDC7iboV_big.jpg'),
(42293, 2890, 'Alice in Borderland S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206577.mp4', 'http://gstaticontent.com/images/i0i7kGDrArtM1sCd8niZDC7iboV_big.jpg'),
(42294, 2891, 'Alice in Borderland S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zn9cvSgOFWyx41TkvI6s6Xco38T.jpg'),
(42295, 2891, 'Alice in Borderland S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x1IVk1an9uV1MSKpLWdr3mOoEH.jpg'),
(42296, 2891, 'Alice in Borderland S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h3d0WmfrfrlNukE96J5vH2WrPGO.jpg'),
(42297, 2891, 'Alice in Borderland S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AotjStplMJGO83GYIuJaBifoIez.jpg'),
(42298, 2891, 'Alice in Borderland S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8MQML6kCwQO9V3woj2ua7kiUIuD.jpg'),
(42299, 2891, 'Alice in Borderland S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dRoosQUpMetp6RiFBDpdevYqejo.jpg'),
(42300, 2891, 'Alice in Borderland S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/unFWdVCZaVzQNBlsfu2RuyLSsVG.jpg'),
(42301, 2891, 'Alice in Borderland S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vRtYgdhRn7i1BDVeG6VLweGXyoI.jpg'),
(42302, 2892, 'Alice in Borderland S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/886286.mp4', 'http://gstaticontent.com/images/i0i7kGDrArtM1sCd8niZDC7iboV_big.jpg'),
(42303, 2892, 'Alice in Borderland S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/886287.mp4', 'http://gstaticontent.com/images/i0i7kGDrArtM1sCd8niZDC7iboV_big.jpg'),
(42304, 2892, 'Alice in Borderland S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/886288.mp4', 'http://gstaticontent.com/images/i0i7kGDrArtM1sCd8niZDC7iboV_big.jpg'),
(42305, 2892, 'Alice in Borderland S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/886289.mp4', 'http://gstaticontent.com/images/i0i7kGDrArtM1sCd8niZDC7iboV_big.jpg'),
(42306, 2892, 'Alice in Borderland S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/886290.mp4', 'http://gstaticontent.com/images/i0i7kGDrArtM1sCd8niZDC7iboV_big.jpg'),
(42307, 2892, 'Alice in Borderland S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/886291.mp4', 'http://gstaticontent.com/images/i0i7kGDrArtM1sCd8niZDC7iboV_big.jpg'),
(42308, 2893, 'Candice Renoir S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234048.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42309, 2893, 'Candice Renoir S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234049.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42310, 2893, 'Candice Renoir S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234050.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42311, 2893, 'Candice Renoir S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234051.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42312, 2893, 'Candice Renoir S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234052.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42313, 2893, 'Candice Renoir S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234053.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42314, 2893, 'Candice Renoir S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234054.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42315, 2893, 'Candice Renoir S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234055.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42316, 2894, 'Candice Renoir S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234056.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42317, 2894, 'Candice Renoir S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234057.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42318, 2894, 'Candice Renoir S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234058.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42319, 2894, 'Candice Renoir S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234059.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42320, 2894, 'Candice Renoir S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234060.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42321, 2894, 'Candice Renoir S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234061.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42322, 2894, 'Candice Renoir S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234062.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42323, 2894, 'Candice Renoir S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234063.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42324, 2894, 'Candice Renoir S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234064.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42325, 2894, 'Candice Renoir S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234065.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42326, 2895, 'Candice Renoir S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234066.mp4', 'http://timg.bdta.pro/images/0df5c70eaa88d5f439b539c84f42708a.jpg'),
(42327, 2895, 'Candice Renoir S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234067.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42328, 2895, 'Candice Renoir S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234068.mp4', 'http://timg.bdta.pro/images/a97fe3b4614999e2e85b64cf5a8ddebe.jpg'),
(42329, 2895, 'Candice Renoir S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234069.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42330, 2895, 'Candice Renoir S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234070.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42331, 2895, 'Candice Renoir S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234071.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42332, 2895, 'Candice Renoir S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234072.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42333, 2895, 'Candice Renoir S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234073.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42334, 2895, 'Candice Renoir S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234074.mp4', 'http://timg.bdta.pro/images/c191b8956eefea35aa0c3c7b5bb2c5e3.jpg'),
(42335, 2895, 'Candice Renoir S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234075.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42336, 2896, 'Candice Renoir S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234076.mp4', 'http://timg.bdta.pro/images/179f0fe8bfb2e07620d357d855b0a270.jpg'),
(42337, 2896, 'Candice Renoir S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234077.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42338, 2896, 'Candice Renoir S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234078.mp4', 'http://timg.bdta.pro/images/0af288740d31da3adeebe0a2e9e2dfbd.jpg'),
(42339, 2896, 'Candice Renoir S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234079.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42340, 2896, 'Candice Renoir S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234080.mp4', 'http://timg.bdta.pro/images/3ecfcfb0c4bdcb1b9c48302a7ac43c99.jpg'),
(42341, 2896, 'Candice Renoir S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234081.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42342, 2896, 'Candice Renoir S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234082.mp4', 'http://timg.bdta.pro/images/c9dfdadae752794775852248769d90bb.jpg'),
(42343, 2896, 'Candice Renoir S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234083.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42344, 2896, 'Candice Renoir S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234084.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42345, 2896, 'Candice Renoir S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234085.mp4', 'http://timg.bdta.pro/images/f5901ea63a2d7c3744318c59b47050c5.jpg'),
(42346, 2897, 'Candice Renoir S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234086.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42347, 2897, 'Candice Renoir S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234087.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42348, 2897, 'Candice Renoir S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234088.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42349, 2897, 'Candice Renoir S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234089.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42350, 2897, 'Candice Renoir S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234090.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42351, 2897, 'Candice Renoir S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234091.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42352, 2897, 'Candice Renoir S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234092.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42353, 2897, 'Candice Renoir S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234093.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42354, 2897, 'Candice Renoir S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234094.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42355, 2897, 'Candice Renoir S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234095.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42356, 2898, 'Candice Renoir S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234096.mp4', 'http://timg.bdta.pro/images/17c094a4f2f222be484f287c2c122aee.jpg'),
(42357, 2898, 'Candice Renoir S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234097.mp4', 'http://timg.bdta.pro/images/024a6cf9fc11ecc03cfd6d272008ad3d.jpg'),
(42358, 2898, 'Candice Renoir S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234098.mp4', 'http://timg.bdta.pro/images/a75f69b58733b6f5296dce804fe12286.jpg'),
(42359, 2898, 'Candice Renoir S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234099.mp4', 'http://timg.bdta.pro/images/bc7819cf198e2814f53791abad598da8.jpg'),
(42360, 2898, 'Candice Renoir S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234100.mp4', 'http://timg.bdta.pro/images/088cdcc39ed7880d9d96dafd830cea5e.jpg'),
(42361, 2899, 'Candice Renoir S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cRlxvkgVMfWptzzVZLULYh6xyqS.jpg'),
(42362, 2899, 'Candice Renoir S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AwdE4hEMDTpSApGkW9ibRLSWDgM.jpg'),
(42363, 2899, 'Candice Renoir S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yareYFvfHNgLptA44tRITFpNUhy.jpg'),
(42364, 2899, 'Candice Renoir S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2bFyLopJLYHvxWo8JYl5rOejmbs.jpg'),
(42365, 2899, 'Candice Renoir S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234105.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42366, 2899, 'Candice Renoir S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234106.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42367, 2899, 'Candice Renoir S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234107.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42368, 2899, 'Candice Renoir S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234108.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42369, 2899, 'Candice Renoir S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234109.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42370, 2899, 'Candice Renoir S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234110.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42371, 2900, 'Candice Renoir S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdyAS1nhpjVqOKqXfE7SHBqlnID.jpg'),
(42372, 2900, 'Candice Renoir S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGtZuFvKxarVg5NEo6AwnU4eFzM.jpg'),
(42373, 2900, 'Candice Renoir S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Bg07i8VpNSgueUSIfxtwTNYyBk.jpg'),
(42374, 2900, 'Candice Renoir S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zKHj3uQxBMGN3soIYTcirdSuwOu.jpg'),
(42375, 2900, 'Candice Renoir S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p4dX4S3jptkAzI8NVZVfJyUIUMU.jpg'),
(42376, 2900, 'Candice Renoir S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p4dX4S3jptkAzI8NVZVfJyUIUMU.jpg'),
(42377, 2900, 'Candice Renoir S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234117.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42378, 2900, 'Candice Renoir S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234118.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42379, 2900, 'Candice Renoir S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234119.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42380, 2900, 'Candice Renoir S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234120.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42381, 2901, 'Candice Renoir S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234121.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42382, 2901, 'Candice Renoir S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234122.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42383, 2901, 'Candice Renoir S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234123.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42384, 2901, 'Candice Renoir S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234124.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42385, 2901, 'Candice Renoir S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234125.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42386, 2901, 'Candice Renoir S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234126.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42387, 2901, 'Candice Renoir S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234127.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42388, 2901, 'Candice Renoir S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234128.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42389, 2901, 'Candice Renoir S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234129.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42390, 2901, 'Candice Renoir S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234130.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42391, 2902, 'Candice Renoir S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234131.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42392, 2902, 'Candice Renoir S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234132.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42393, 2902, 'Candice Renoir S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234133.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42394, 2902, 'Candice Renoir S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234134.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42395, 2902, 'Candice Renoir S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234135.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42396, 2902, 'Candice Renoir S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234136.mp4', 'http://gstaticontent.com/images/yinQce5khtVovY2oDcZsP6slAf1_big.jpg'),
(42397, 2903, 'Overlord S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137079.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42398, 2903, 'Overlord S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137080.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42399, 2903, 'Overlord S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137081.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42400, 2903, 'Overlord S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137082.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42401, 2903, 'Overlord S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137083.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42402, 2903, 'Overlord S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137084.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42403, 2903, 'Overlord S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137085.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42404, 2903, 'Overlord S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137086.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42405, 2903, 'Overlord S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137087.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42406, 2903, 'Overlord S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137088.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42407, 2903, 'Overlord S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137089.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42408, 2903, 'Overlord S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137090.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42409, 2903, 'Overlord S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137091.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42410, 2904, 'Overlord S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137092.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42411, 2904, 'Overlord S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137093.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42412, 2904, 'Overlord S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137094.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42413, 2904, 'Overlord S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137095.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42414, 2904, 'Overlord S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137096.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42415, 2904, 'Overlord S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137097.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42416, 2904, 'Overlord S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137098.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42417, 2904, 'Overlord S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137099.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42418, 2904, 'Overlord S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137100.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42419, 2904, 'Overlord S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137101.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42420, 2904, 'Overlord S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137102.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42421, 2904, 'Overlord S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137103.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42422, 2904, 'Overlord S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137104.mp4', 'http://gstaticontent.com/images/1dVyeauPEJwa4Uv6K1ESuhi8Rb6_big.jpg'),
(42423, 2905, 'Overlord S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/868809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hRQV2GxCEs4py7JQ99nv3rnqIHm.jpg'),
(42424, 2905, 'Overlord S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/868810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5MTK1vSA9Yjh0NcsfxuGWtlLpIr.jpg'),
(42425, 2905, 'Overlord S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/868811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nBtno6Z2cNEQlcqfeyZBxzHKkEx.jpg'),
(42426, 2905, 'Overlord S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/868812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37Jmrqot5NsGiFWTpT4PDJ652UA.jpg'),
(42427, 2905, 'Overlord S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/868813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMqo6oyjnrwaDXC1M2HGB4FbJeh.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(42428, 2905, 'Overlord S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/868814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7OjOmPIaUSn6N3Qp5OaKJV7EiCm.jpg'),
(42429, 2905, 'Overlord S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/868815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYeA85N4nZQy9Qqk0f97EiSKEXK.jpg'),
(42430, 2905, 'Overlord S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/868816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oWWXfvqNzRad3ZKyELAL9Mvn5AY.jpg'),
(42431, 2905, 'Overlord S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/868817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iW5bHIxzTTmmlh6gJg4gpaTVXCM.jpg'),
(42432, 2905, 'Overlord S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/868818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9zmtMt3zU0qpjvtWECFMA3207V.jpg'),
(42433, 2905, 'Overlord S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/868819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h1lqFum5vH0gsAVYIwTuK2eDAU5.jpg'),
(42434, 2905, 'Overlord S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/868820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o0kr52klt1Qv3EwQjpCrM7gwd4M.jpg'),
(42435, 2905, 'Overlord S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/868821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/15FD17qUoZjz4tKkMrsNiqdMAQO.jpg'),
(42436, 2906, 'Overlord S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/868822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iwkVCzzY3Z9utQKDIJbbRKR8QsJ.jpg'),
(42437, 2906, 'Overlord S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/868823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/D2C1STGhW0v4fQLEpVFTXexb96.jpg'),
(42438, 2906, 'Overlord S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/868824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nihWW8H0xwqMIRhVzghWZHVJN3J.jpg'),
(42439, 2906, 'Overlord S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/868825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JziYMFI5FA2Wi9Mzf1nrlt4QQ5.jpg'),
(42440, 2906, 'Overlord S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/868826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8EODEwH5P98cBhASmtEgrjydDEI.jpg'),
(42441, 2906, 'Overlord S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/868827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cdKnnv4TT6WtqwlVi1mIJZhEd19.jpg'),
(42442, 2906, 'Overlord S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/868828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gJ59fROhqNKmOmWTjDbWPaI5Ifu.jpg'),
(42443, 2906, 'Overlord S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/868829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/miWRzjH7KQOTwVs8JtwJvSFXDbI.jpg'),
(42444, 2906, 'Overlord S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/868830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mM3GDYi4Zx2OjcmdLm5xdxhU78n.jpg'),
(42445, 2906, 'Overlord S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/868831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Fooq9uyPByLoClZbgq5kh0jh38.jpg'),
(42446, 2906, 'Overlord S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/868832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t73YTLD7Wm7gD5ZgKjt5Xvavyne.jpg'),
(42447, 2906, 'Overlord S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/868833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u449dFidrESWD0cIw9nvEO8eLRo.jpg'),
(42448, 2906, 'Overlord S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/868834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qF8JQjzOawnS6LJp4JxIv2APDqi.jpg'),
(42449, 2907, 'Earth At Night In Color [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130538.mp4', 'http://gstaticontent.com/images/zabRFOr7LHzZdDKEdKDK3NooYD4_big.jpg'),
(42450, 2907, 'Earth At Night In Color [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130539.mp4', 'http://gstaticontent.com/images/zabRFOr7LHzZdDKEdKDK3NooYD4_big.jpg'),
(42451, 2907, 'Earth At Night In Color [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130540.mp4', 'http://gstaticontent.com/images/zabRFOr7LHzZdDKEdKDK3NooYD4_big.jpg'),
(42452, 2907, 'Earth At Night In Color [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/130541.mp4', 'http://gstaticontent.com/images/zabRFOr7LHzZdDKEdKDK3NooYD4_big.jpg'),
(42453, 2907, 'Earth At Night In Color [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/130542.mp4', 'http://gstaticontent.com/images/zabRFOr7LHzZdDKEdKDK3NooYD4_big.jpg'),
(42454, 2907, 'Earth At Night In Color [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/130543.mp4', 'http://gstaticontent.com/images/zabRFOr7LHzZdDKEdKDK3NooYD4_big.jpg'),
(42455, 2908, 'Rastro Perdido S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130537.mp4', 'http://gstaticontent.com/images/8xAuh1KvxT9vHkJNwQIzyroMCqY_big.jpg'),
(42456, 2909, 'The Hardy Boys [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233950.mp4', 'http://timg.bdta.pro/images/986c2a3dfa8947448df557913d984ecf.jpg'),
(42457, 2909, 'The Hardy Boys [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233951.mp4', 'http://timg.bdta.pro/images/1b12390699372a653b052a648120ef3b.jpg'),
(42458, 2909, 'The Hardy Boys [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233952.mp4', 'http://timg.bdta.pro/images/2966e3a23fffdeddc076e26449fdf48b.jpg'),
(42459, 2909, 'The Hardy Boys [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233953.mp4', 'http://timg.bdta.pro/images/6d681efa1021f445c39280fde2181238.jpg'),
(42460, 2909, 'The Hardy Boys [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233954.mp4', 'http://timg.bdta.pro/images/8b1fd737afc4313002d942d6cfce8f3e.jpg'),
(42461, 2909, 'The Hardy Boys [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7dC5YaEc1RoSwa980D8sZrJWNRd.jpg'),
(42462, 2909, 'The Hardy Boys [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233956.mp4', 'http://timg.bdta.pro/images/cd19e64dd7159525db006a22af959848.jpg'),
(42463, 2909, 'The Hardy Boys [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233957.mp4', 'http://timg.bdta.pro/images/deda8297e2bfe6c5de39ad433c978b46.jpg'),
(42464, 2909, 'The Hardy Boys [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233958.mp4', 'http://timg.bdta.pro/images/f51c3a71ca4b9aa46cb476966eba3075.jpg'),
(42465, 2909, 'The Hardy Boys [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233959.mp4', 'http://timg.bdta.pro/images/b679193f3dc93150b81077c9f2265ef7.jpg'),
(42466, 2909, 'The Hardy Boys [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233960.mp4', 'http://timg.bdta.pro/images/56633d9579d1ae0c8e60d69795e8cd87.jpg'),
(42467, 2909, 'The Hardy Boys [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233961.mp4', 'http://timg.bdta.pro/images/7fd3b23dd18d24c318ab68116e3f60a1.jpg'),
(42468, 2909, 'The Hardy Boys [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/233962.mp4', 'http://timg.bdta.pro/images/47bc8c1dc3ba51ddc9754e3020406bb2.jpg'),
(42469, 2910, 'The Hardy Boys [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nagq0aTwHPt6jKkmOMyL4u0Cv9M.jpg'),
(42470, 2910, 'The Hardy Boys [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xg7UlYXLmXIVmviZsQ9eZwxbHte.jpg'),
(42471, 2910, 'The Hardy Boys [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wbRwJHBOg4DPZWpRXa02ZtJ9k2U.jpg'),
(42472, 2910, 'The Hardy Boys [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyWSwLPaMN6GxfxX3vAaoKxyU53.jpg'),
(42473, 2910, 'The Hardy Boys [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6J364wsXR9ORhZcuX1J1NMjcxkL.jpg'),
(42474, 2910, 'The Hardy Boys [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2gl5KKeRNZD136It9ivzag14rAk.jpg'),
(42475, 2910, 'The Hardy Boys [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/phc5CEwwCSIotWyaRY3H7cjAjTF.jpg'),
(42476, 2910, 'The Hardy Boys [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pqXc4Ci0WEtHp39vPi4ehEVoQ1j.jpg'),
(42477, 2910, 'The Hardy Boys [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lxTjjcWP9lRrd6CYJy9OmlvEWGA.jpg'),
(42478, 2910, 'The Hardy Boys [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTAjStqdBywKqYbnvyeYWWzXExZ.jpg'),
(42479, 2911, 'The Hardy Boys [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uoh408Pnc4ggjc9KsUwhLbVS6uY.jpg'),
(42480, 2911, 'The Hardy Boys [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oXPcFlFHSbwURI38Qi1xY0VNdJ8.jpg'),
(42481, 2911, 'The Hardy Boys [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6qT1c5LLfC71tC02TkPvrcaOuD9.jpg'),
(42482, 2911, 'The Hardy Boys [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gG8pXvv3yxkz3I110ayBoArHAkk.jpg'),
(42483, 2911, 'The Hardy Boys [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzhGMvykrllCvPHf3pBNUu8ftmU.jpg'),
(42484, 2911, 'The Hardy Boys [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gdQH78wLhEJEo0dZagaNf8NBsmS.jpg'),
(42485, 2911, 'The Hardy Boys [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hISvzBn4NWX2FDxou5bDN6KASt3.jpg'),
(42486, 2911, 'The Hardy Boys [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/weddjGIGGElRATHyrSJEJuqcoTU.jpg'),
(42487, 2912, 'Diz me Quem Sou S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134959.mp4', 'http://gstaticontent.com/images/a1lDn1epe7IbodAMvPuqER5SVWH_big.jpg'),
(42488, 2912, 'Diz me Quem Sou S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134960.mp4', 'http://gstaticontent.com/images/a1lDn1epe7IbodAMvPuqER5SVWH_big.jpg'),
(42489, 2912, 'Diz me Quem Sou S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134961.mp4', 'http://gstaticontent.com/images/a1lDn1epe7IbodAMvPuqER5SVWH_big.jpg'),
(42490, 2912, 'Diz me Quem Sou S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134962.mp4', 'http://gstaticontent.com/images/a1lDn1epe7IbodAMvPuqER5SVWH_big.jpg'),
(42491, 2912, 'Diz me Quem Sou S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134963.mp4', 'http://gstaticontent.com/images/a1lDn1epe7IbodAMvPuqER5SVWH_big.jpg'),
(42492, 2912, 'Diz me Quem Sou S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134964.mp4', 'http://gstaticontent.com/images/a1lDn1epe7IbodAMvPuqER5SVWH_big.jpg'),
(42493, 2912, 'Diz me Quem Sou S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134965.mp4', 'http://gstaticontent.com/images/a1lDn1epe7IbodAMvPuqER5SVWH_big.jpg'),
(42494, 2912, 'Diz me Quem Sou S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134966.mp4', 'http://gstaticontent.com/images/a1lDn1epe7IbodAMvPuqER5SVWH_big.jpg'),
(42495, 2912, 'Diz me Quem Sou S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/134967.mp4', 'http://gstaticontent.com/images/a1lDn1epe7IbodAMvPuqER5SVWH_big.jpg'),
(42496, 2913, 'Gigantes dos Motores S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/130534.mp4', 'http://gstaticontent.com/images/w7lD8iUYnJA4A7Rl1WJq6YNpG5W_big.jpg'),
(42497, 2913, 'Gigantes dos Motores S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/130535.mp4', 'http://gstaticontent.com/images/w7lD8iUYnJA4A7Rl1WJq6YNpG5W_big.jpg'),
(42498, 2913, 'Gigantes dos Motores S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/130536.mp4', 'http://gstaticontent.com/images/w7lD8iUYnJA4A7Rl1WJq6YNpG5W_big.jpg'),
(42499, 2914, 'Anitta Made In Honorio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137856.mp4', 'http://gstaticontent.com/images/cT9JANVgLvxRKAjubFbC0jpN5Ib_big.jpg'),
(42500, 2914, 'Anitta Made In Honorio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137857.mp4', 'http://gstaticontent.com/images/cT9JANVgLvxRKAjubFbC0jpN5Ib_big.jpg'),
(42501, 2914, 'Anitta Made In Honorio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137858.mp4', 'http://gstaticontent.com/images/cT9JANVgLvxRKAjubFbC0jpN5Ib_big.jpg'),
(42502, 2914, 'Anitta Made In Honorio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137859.mp4', 'http://gstaticontent.com/images/cT9JANVgLvxRKAjubFbC0jpN5Ib_big.jpg'),
(42503, 2914, 'Anitta Made In Honorio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137860.mp4', 'http://gstaticontent.com/images/cT9JANVgLvxRKAjubFbC0jpN5Ib_big.jpg'),
(42504, 2914, 'Anitta Made In Honorio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137861.mp4', 'http://gstaticontent.com/images/cT9JANVgLvxRKAjubFbC0jpN5Ib_big.jpg'),
(42505, 2915, 'Blaze and the Monster Machines S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9C5SuzvfhMVy6xTETzuP6NnMUTT.jpg'),
(42506, 2915, 'Blaze and the Monster Machines S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9C5SuzvfhMVy6xTETzuP6NnMUTT.jpg'),
(42507, 2915, 'Blaze and the Monster Machines S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1wCJo4JE2zJ4hf2D543oS765mvH.jpg'),
(42508, 2915, 'Blaze and the Monster Machines S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybwHzxI1l5ONxCPsLRTUII0Ozlv.jpg'),
(42509, 2915, 'Blaze and the Monster Machines S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2OSbtNg8ekB5EawzO9qt7gh7a1F.jpg'),
(42510, 2915, 'Blaze and the Monster Machines S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dKQZg7TFJThzZSKn8us0HZOIssn.jpg'),
(42511, 2915, 'Blaze and the Monster Machines S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bMafGPMVdNVOlYed1rk6LmnBYJJ.jpg'),
(42512, 2915, 'Blaze and the Monster Machines S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3LIOdjbH3V9d30QRnMiVhsjdfbL.jpg'),
(42513, 2915, 'Blaze and the Monster Machines S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g3pWE77thv6MQcfW2gjTa8hslBX.jpg'),
(42514, 2915, 'Blaze and the Monster Machines S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nBFAHnepzH3pYlqHZNvXJFxLUiz.jpg'),
(42515, 2915, 'Blaze and the Monster Machines S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lijFXSTLx07LOuUuz7olkLxHxZd.jpg'),
(42516, 2915, 'Blaze and the Monster Machines S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Z6nbMnjhLHIeS7FsDgkVrxOpjf.jpg'),
(42517, 2915, 'Blaze and the Monster Machines S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3T04WW7zwLlZwunh3Dc6mmUsPWO.jpg'),
(42518, 2915, 'Blaze and the Monster Machines S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3OVCG4pKhLw4rFp2eYnrST2UJhd.jpg'),
(42519, 2915, 'Blaze and the Monster Machines S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uSCUHAljwpDeW5cZ1vZ8kA4KWur.jpg'),
(42520, 2915, 'Blaze and the Monster Machines S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oJGzrUlsVQbTXQQ3yyTmKcwWm77.jpg'),
(42521, 2915, 'Blaze and the Monster Machines S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5936C2sOB7ZO4Ued6MKgVatzyDi.jpg'),
(42522, 2915, 'Blaze and the Monster Machines S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iUOjrhT97Iav3U8iSBC3RwfipKm.jpg'),
(42523, 2915, 'Blaze and the Monster Machines S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/roWEqTR3dPKQWQXTI1cNL5cS4ul.jpg'),
(42524, 2915, 'Blaze and the Monster Machines S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rgaAQFb1Fn1LkYa8ChTqWM7Zfso.jpg'),
(42525, 2916, 'Condor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137837.mp4', 'http://gstaticontent.com/images/28cIK70tN2t4gPTV8CBQZED1H2G_big.jpg'),
(42526, 2916, 'Condor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137838.mp4', 'http://gstaticontent.com/images/28cIK70tN2t4gPTV8CBQZED1H2G_big.jpg'),
(42527, 2916, 'Condor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137839.mp4', 'http://gstaticontent.com/images/28cIK70tN2t4gPTV8CBQZED1H2G_big.jpg'),
(42528, 2916, 'Condor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137840.mp4', 'http://gstaticontent.com/images/28cIK70tN2t4gPTV8CBQZED1H2G_big.jpg'),
(42529, 2916, 'Condor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137841.mp4', 'http://gstaticontent.com/images/28cIK70tN2t4gPTV8CBQZED1H2G_big.jpg'),
(42530, 2916, 'Condor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137842.mp4', 'http://gstaticontent.com/images/28cIK70tN2t4gPTV8CBQZED1H2G_big.jpg'),
(42531, 2916, 'Condor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137843.mp4', 'http://gstaticontent.com/images/28cIK70tN2t4gPTV8CBQZED1H2G_big.jpg'),
(42532, 2916, 'Condor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137844.mp4', 'http://gstaticontent.com/images/28cIK70tN2t4gPTV8CBQZED1H2G_big.jpg'),
(42533, 2916, 'Condor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137845.mp4', 'http://gstaticontent.com/images/28cIK70tN2t4gPTV8CBQZED1H2G_big.jpg'),
(42534, 2916, 'Condor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137846.mp4', 'http://gstaticontent.com/images/28cIK70tN2t4gPTV8CBQZED1H2G_big.jpg'),
(42535, 2917, 'Condor S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137847.mp4', 'http://gstaticontent.com/images/28cIK70tN2t4gPTV8CBQZED1H2G_big.jpg'),
(42536, 2917, 'Condor S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137848.mp4', 'http://gstaticontent.com/images/28cIK70tN2t4gPTV8CBQZED1H2G_big.jpg'),
(42537, 2917, 'Condor S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137849.mp4', 'http://gstaticontent.com/images/28cIK70tN2t4gPTV8CBQZED1H2G_big.jpg'),
(42538, 2917, 'Condor S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137850.mp4', 'http://gstaticontent.com/images/28cIK70tN2t4gPTV8CBQZED1H2G_big.jpg'),
(42539, 2917, 'Condor S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137851.mp4', 'http://gstaticontent.com/images/28cIK70tN2t4gPTV8CBQZED1H2G_big.jpg'),
(42540, 2917, 'Condor S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137852.mp4', 'http://gstaticontent.com/images/28cIK70tN2t4gPTV8CBQZED1H2G_big.jpg'),
(42541, 2917, 'Condor S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137853.mp4', 'http://gstaticontent.com/images/28cIK70tN2t4gPTV8CBQZED1H2G_big.jpg'),
(42542, 2917, 'Condor S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137854.mp4', 'http://gstaticontent.com/images/28cIK70tN2t4gPTV8CBQZED1H2G_big.jpg'),
(42543, 2917, 'Condor S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137855.mp4', 'http://gstaticontent.com/images/28cIK70tN2t4gPTV8CBQZED1H2G_big.jpg'),
(42544, 2918, 'Great Pretender S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137814.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42545, 2918, 'Great Pretender S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137815.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42546, 2918, 'Great Pretender S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137816.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42547, 2918, 'Great Pretender S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137817.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42548, 2918, 'Great Pretender S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137818.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42549, 2918, 'Great Pretender S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137819.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42550, 2918, 'Great Pretender S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137820.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42551, 2918, 'Great Pretender S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137821.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42552, 2918, 'Great Pretender S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137822.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42553, 2918, 'Great Pretender S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137823.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42554, 2918, 'Great Pretender S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137824.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42555, 2918, 'Great Pretender S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137825.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42556, 2918, 'Great Pretender S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137826.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42557, 2918, 'Great Pretender S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137827.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42558, 2919, 'Great Pretender S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137828.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42559, 2919, 'Great Pretender S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137829.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42560, 2919, 'Great Pretender S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137830.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42561, 2919, 'Great Pretender S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137831.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42562, 2919, 'Great Pretender S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137832.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42563, 2919, 'Great Pretender S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137833.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42564, 2919, 'Great Pretender S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137834.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42565, 2919, 'Great Pretender S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137835.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42566, 2919, 'Great Pretender S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137836.mp4', 'http://gstaticontent.com/images/xJBjJ1tuQHWn5rdDARatmLwiSsg_big.jpg'),
(42567, 2920, '40m S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137552.mp4', 'http://gstaticontent.com/images/6bb51e0f85b30c285c95bab3776e7431.jpg'),
(42568, 2920, '40m S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137553.mp4', 'http://gstaticontent.com/images/6bb51e0f85b30c285c95bab3776e7431.jpg'),
(42569, 2920, '40m S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137554.mp4', 'http://gstaticontent.com/images/6bb51e0f85b30c285c95bab3776e7431.jpg'),
(42570, 2920, '40m S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137555.mp4', 'http://gstaticontent.com/images/6bb51e0f85b30c285c95bab3776e7431.jpg'),
(42571, 2921, 'Bridgerton S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177396.mp4', 'http://gstaticontent.com/images/qaewZKBKmXjb4ZfFBb1LCug6BE8_big.jpg'),
(42572, 2921, 'Bridgerton S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177397.mp4', 'http://gstaticontent.com/images/qaewZKBKmXjb4ZfFBb1LCug6BE8_big.jpg'),
(42573, 2921, 'Bridgerton S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177398.mp4', 'http://gstaticontent.com/images/qaewZKBKmXjb4ZfFBb1LCug6BE8_big.jpg'),
(42574, 2921, 'Bridgerton S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177399.mp4', 'http://gstaticontent.com/images/qaewZKBKmXjb4ZfFBb1LCug6BE8_big.jpg'),
(42575, 2921, 'Bridgerton S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177400.mp4', 'http://gstaticontent.com/images/qaewZKBKmXjb4ZfFBb1LCug6BE8_big.jpg'),
(42576, 2921, 'Bridgerton S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177401.mp4', 'http://gstaticontent.com/images/qaewZKBKmXjb4ZfFBb1LCug6BE8_big.jpg'),
(42577, 2921, 'Bridgerton S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177402.mp4', 'http://gstaticontent.com/images/qaewZKBKmXjb4ZfFBb1LCug6BE8_big.jpg'),
(42578, 2921, 'Bridgerton S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177403.mp4', 'http://gstaticontent.com/images/qaewZKBKmXjb4ZfFBb1LCug6BE8_big.jpg'),
(42579, 2922, 'Bridgerton S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177404.mp4', 'http://timg.bdta.pro/images/2882dbebcbc9e01355cfeff7550e486d.jpg'),
(42580, 2922, 'Bridgerton S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177405.mp4', 'http://timg.bdta.pro/images/82cfaf576da40373992dc261105f5c42.jpg'),
(42581, 2922, 'Bridgerton S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177406.mp4', 'http://timg.bdta.pro/images/8dc02cd8fb86aa10c347f74fc6be4b58.jpg'),
(42582, 2922, 'Bridgerton S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177407.mp4', 'http://timg.bdta.pro/images/edc5d27c2e95c5de5cd221b5d14a9cf4.jpg'),
(42583, 2922, 'Bridgerton S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177408.mp4', 'http://timg.bdta.pro/images/c49adb7be9745f54ebf10ce373abb40c.jpg'),
(42584, 2922, 'Bridgerton S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177409.mp4', 'http://timg.bdta.pro/images/878ca670b439431f95d3ce857d95ec1e.jpg'),
(42585, 2922, 'Bridgerton S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177410.mp4', 'http://timg.bdta.pro/images/b906c05c271a6a801b18f2614e1429a8.jpg'),
(42586, 2922, 'Bridgerton S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177411.mp4', 'http://timg.bdta.pro/images/fd02604f4bd662e38facc99ae5af80e2.jpg'),
(42587, 2923, 'Bridgerton S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/346714.mp4', 'http://gstaticontent.com/images/qaewZKBKmXjb4ZfFBb1LCug6BE8_big.jpg'),
(42588, 2923, 'Bridgerton S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/346715.mp4', 'http://gstaticontent.com/images/qaewZKBKmXjb4ZfFBb1LCug6BE8_big.jpg'),
(42589, 2923, 'Bridgerton S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/346716.mp4', 'http://gstaticontent.com/images/qaewZKBKmXjb4ZfFBb1LCug6BE8_big.jpg'),
(42590, 2923, 'Bridgerton S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/346717.mp4', 'http://gstaticontent.com/images/qaewZKBKmXjb4ZfFBb1LCug6BE8_big.jpg'),
(42591, 2923, 'Bridgerton S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/383310.mp4', 'http://gstaticontent.com/images/qaewZKBKmXjb4ZfFBb1LCug6BE8_big.jpg'),
(42592, 2923, 'Bridgerton S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/383311.mp4', 'http://gstaticontent.com/images/qaewZKBKmXjb4ZfFBb1LCug6BE8_big.jpg'),
(42593, 2923, 'Bridgerton S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/383312.mp4', 'http://gstaticontent.com/images/qaewZKBKmXjb4ZfFBb1LCug6BE8_big.jpg'),
(42594, 2923, 'Bridgerton S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/383313.mp4', 'http://gstaticontent.com/images/qaewZKBKmXjb4ZfFBb1LCug6BE8_big.jpg'),
(42595, 2924, 'Capadocia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137513.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42596, 2924, 'Capadocia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137514.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42597, 2924, 'Capadocia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137515.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42598, 2924, 'Capadocia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137516.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42599, 2924, 'Capadocia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137517.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42600, 2924, 'Capadocia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137518.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42601, 2924, 'Capadocia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137519.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42602, 2924, 'Capadocia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137520.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42603, 2924, 'Capadocia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137521.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42604, 2924, 'Capadocia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137522.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42605, 2924, 'Capadocia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137523.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42606, 2924, 'Capadocia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137524.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42607, 2924, 'Capadocia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137525.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42608, 2925, 'Capadocia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137526.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42609, 2925, 'Capadocia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137527.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42610, 2925, 'Capadocia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137528.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42611, 2925, 'Capadocia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137529.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42612, 2925, 'Capadocia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137530.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42613, 2925, 'Capadocia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137531.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42614, 2925, 'Capadocia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137532.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42615, 2925, 'Capadocia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137533.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42616, 2925, 'Capadocia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137534.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42617, 2925, 'Capadocia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137535.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42618, 2925, 'Capadocia S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137536.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42619, 2925, 'Capadocia S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137537.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42620, 2925, 'Capadocia S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137538.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42621, 2926, 'Capadocia S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137539.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42622, 2926, 'Capadocia S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137540.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42623, 2926, 'Capadocia S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137541.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42624, 2926, 'Capadocia S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137542.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42625, 2926, 'Capadocia S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137543.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42626, 2926, 'Capadocia S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137544.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42627, 2926, 'Capadocia S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137545.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42628, 2926, 'Capadocia S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137546.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42629, 2926, 'Capadocia S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137547.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42630, 2926, 'Capadocia S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137548.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42631, 2926, 'Capadocia S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137549.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42632, 2926, 'Capadocia S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137550.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42633, 2926, 'Capadocia S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137551.mp4', 'http://gstaticontent.com/images/fUTgY7Od8QvSwPiEjrt4YmR40LK_big.jpg'),
(42634, 2927, 'Epitáfios S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137487.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42635, 2927, 'Epitáfios S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137488.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42636, 2927, 'Epitáfios S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137489.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42637, 2927, 'Epitáfios S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137490.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42638, 2927, 'Epitáfios S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137491.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42639, 2927, 'Epitáfios S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137492.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42640, 2927, 'Epitáfios S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137493.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42641, 2927, 'Epitáfios S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137494.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42642, 2927, 'Epitáfios S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137495.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42643, 2927, 'Epitáfios S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137496.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42644, 2927, 'Epitáfios S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137497.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42645, 2927, 'Epitáfios S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137498.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42646, 2927, 'Epitáfios S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137499.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42647, 2928, 'Epitáfios S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137500.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42648, 2928, 'Epitáfios S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137501.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42649, 2928, 'Epitáfios S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137502.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42650, 2928, 'Epitáfios S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137503.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42651, 2928, 'Epitáfios S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137504.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42652, 2928, 'Epitáfios S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137505.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42653, 2928, 'Epitáfios S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137506.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42654, 2928, 'Epitáfios S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137507.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42655, 2928, 'Epitáfios S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137508.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42656, 2928, 'Epitáfios S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137509.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42657, 2928, 'Epitáfios S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137510.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42658, 2928, 'Epitáfios S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137511.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42659, 2928, 'Epitáfios S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137512.mp4', 'http://gstaticontent.com/images/6067wGVlceL9ro3Ka3JKYGPz7Ej_big.jpg'),
(42660, 2929, 'Equinox S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137481.mp4', 'http://gstaticontent.com/images/bnU3Rz3nR844WZNOyrCk8W52DUs_big.jpg'),
(42661, 2929, 'Equinox S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137482.mp4', 'http://gstaticontent.com/images/bnU3Rz3nR844WZNOyrCk8W52DUs_big.jpg'),
(42662, 2929, 'Equinox S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137483.mp4', 'http://gstaticontent.com/images/bnU3Rz3nR844WZNOyrCk8W52DUs_big.jpg'),
(42663, 2929, 'Equinox S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137484.mp4', 'http://gstaticontent.com/images/bnU3Rz3nR844WZNOyrCk8W52DUs_big.jpg'),
(42664, 2929, 'Equinox S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137485.mp4', 'http://gstaticontent.com/images/bnU3Rz3nR844WZNOyrCk8W52DUs_big.jpg'),
(42665, 2929, 'Equinox S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137486.mp4', 'http://gstaticontent.com/images/bnU3Rz3nR844WZNOyrCk8W52DUs_big.jpg'),
(42666, 2930, 'Japão de Norte a Sul S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137478.mp4', 'http://gstaticontent.com/images/mDLrwTKgJ8KWhQNyEJbsDAyJMqg_big.jpg'),
(42667, 2930, 'Japão de Norte a Sul S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137479.mp4', 'http://gstaticontent.com/images/mDLrwTKgJ8KWhQNyEJbsDAyJMqg_big.jpg'),
(42668, 2930, 'Japão de Norte a Sul S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137480.mp4', 'http://gstaticontent.com/images/mDLrwTKgJ8KWhQNyEJbsDAyJMqg_big.jpg'),
(42669, 2931, 'Sweet Home S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249714.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42670, 2931, 'Sweet Home S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249715.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42671, 2931, 'Sweet Home S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249716.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42672, 2931, 'Sweet Home S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249717.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42673, 2931, 'Sweet Home S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249718.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42674, 2931, 'Sweet Home S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249719.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42675, 2931, 'Sweet Home S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249720.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42676, 2931, 'Sweet Home S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249721.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42677, 2931, 'Sweet Home S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249722.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42678, 2931, 'Sweet Home S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249723.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42679, 2932, 'Sweet Home S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249724.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42680, 2932, 'Sweet Home S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249725.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42681, 2932, 'Sweet Home S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249726.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42682, 2932, 'Sweet Home S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249727.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42683, 2932, 'Sweet Home S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249728.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42684, 2932, 'Sweet Home S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249729.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42685, 2932, 'Sweet Home S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249730.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42686, 2932, 'Sweet Home S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249731.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42687, 2933, 'Sweet Home S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/415543.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42688, 2933, 'Sweet Home S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/415544.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42689, 2933, 'Sweet Home S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/415545.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42690, 2933, 'Sweet Home S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/415546.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42691, 2933, 'Sweet Home S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/415547.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42692, 2933, 'Sweet Home S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/415548.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42693, 2933, 'Sweet Home S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/415549.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42694, 2933, 'Sweet Home S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/415550.mp4', 'http://gstaticontent.com/images/uIz0TUUDBVDXszJPazlvwMzY7vM_big.jpg'),
(42695, 2934, 'Crashing S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136825.mp4', 'http://gstaticontent.com/images/qiGLRtgsSwVEI6DWaeSP8IiW4rK_big.jpg'),
(42696, 2934, 'Crashing S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136826.mp4', 'http://gstaticontent.com/images/qiGLRtgsSwVEI6DWaeSP8IiW4rK_big.jpg'),
(42697, 2934, 'Crashing S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136827.mp4', 'http://gstaticontent.com/images/qiGLRtgsSwVEI6DWaeSP8IiW4rK_big.jpg'),
(42698, 2934, 'Crashing S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136828.mp4', 'http://gstaticontent.com/images/qiGLRtgsSwVEI6DWaeSP8IiW4rK_big.jpg'),
(42699, 2934, 'Crashing S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136829.mp4', 'http://gstaticontent.com/images/qiGLRtgsSwVEI6DWaeSP8IiW4rK_big.jpg'),
(42700, 2934, 'Crashing S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136830.mp4', 'http://gstaticontent.com/images/qiGLRtgsSwVEI6DWaeSP8IiW4rK_big.jpg'),
(42701, 2934, 'Crashing S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136831.mp4', 'http://gstaticontent.com/images/qiGLRtgsSwVEI6DWaeSP8IiW4rK_big.jpg'),
(42702, 2934, 'Crashing S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136832.mp4', 'http://gstaticontent.com/images/qiGLRtgsSwVEI6DWaeSP8IiW4rK_big.jpg'),
(42703, 2935, 'Crashing S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136833.mp4', 'http://gstaticontent.com/images/qiGLRtgsSwVEI6DWaeSP8IiW4rK_big.jpg'),
(42704, 2935, 'Crashing S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136834.mp4', 'http://gstaticontent.com/images/qiGLRtgsSwVEI6DWaeSP8IiW4rK_big.jpg'),
(42705, 2935, 'Crashing S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136835.mp4', 'http://gstaticontent.com/images/qiGLRtgsSwVEI6DWaeSP8IiW4rK_big.jpg'),
(42706, 2935, 'Crashing S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136836.mp4', 'http://gstaticontent.com/images/qiGLRtgsSwVEI6DWaeSP8IiW4rK_big.jpg'),
(42707, 2935, 'Crashing S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136837.mp4', 'http://gstaticontent.com/images/qiGLRtgsSwVEI6DWaeSP8IiW4rK_big.jpg'),
(42708, 2935, 'Crashing S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136838.mp4', 'http://gstaticontent.com/images/qiGLRtgsSwVEI6DWaeSP8IiW4rK_big.jpg'),
(42709, 2935, 'Crashing S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136839.mp4', 'http://gstaticontent.com/images/qiGLRtgsSwVEI6DWaeSP8IiW4rK_big.jpg'),
(42710, 2935, 'Crashing S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136840.mp4', 'http://gstaticontent.com/images/qiGLRtgsSwVEI6DWaeSP8IiW4rK_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(42711, 2936, 'A Comissária de Bordo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137271.mp4', 'http://gstaticontent.com/images/6f146b01eb7138f623a486f8c8487f90.jpg'),
(42712, 2936, 'A Comissária de Bordo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137272.mp4', 'http://gstaticontent.com/images/6f146b01eb7138f623a486f8c8487f90.jpg'),
(42713, 2936, 'A Comissária de Bordo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137273.mp4', 'http://gstaticontent.com/images/6f146b01eb7138f623a486f8c8487f90.jpg'),
(42714, 2936, 'A Comissária de Bordo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137274.mp4', 'http://gstaticontent.com/images/6f146b01eb7138f623a486f8c8487f90.jpg'),
(42715, 2936, 'A Comissária de Bordo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137275.mp4', 'http://gstaticontent.com/images/6f146b01eb7138f623a486f8c8487f90.jpg'),
(42716, 2936, 'A Comissária de Bordo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137276.mp4', 'http://gstaticontent.com/images/6f146b01eb7138f623a486f8c8487f90.jpg'),
(42717, 2936, 'A Comissária de Bordo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137277.mp4', 'http://gstaticontent.com/images/6f146b01eb7138f623a486f8c8487f90.jpg'),
(42718, 2936, 'A Comissária de Bordo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137278.mp4', 'http://gstaticontent.com/images/6f146b01eb7138f623a486f8c8487f90.jpg'),
(42719, 2937, 'Headspace Meditação Guiada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137263.mp4', 'http://gstaticontent.com/images/idWdyd1jGQiR6p9F4I1UqKbzYic_big.jpg'),
(42720, 2937, 'Headspace Meditação Guiada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137264.mp4', 'http://gstaticontent.com/images/idWdyd1jGQiR6p9F4I1UqKbzYic_big.jpg'),
(42721, 2937, 'Headspace Meditação Guiada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137265.mp4', 'http://gstaticontent.com/images/idWdyd1jGQiR6p9F4I1UqKbzYic_big.jpg'),
(42722, 2937, 'Headspace Meditação Guiada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137266.mp4', 'http://gstaticontent.com/images/idWdyd1jGQiR6p9F4I1UqKbzYic_big.jpg'),
(42723, 2937, 'Headspace Meditação Guiada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137267.mp4', 'http://gstaticontent.com/images/idWdyd1jGQiR6p9F4I1UqKbzYic_big.jpg'),
(42724, 2937, 'Headspace Meditação Guiada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137268.mp4', 'http://gstaticontent.com/images/idWdyd1jGQiR6p9F4I1UqKbzYic_big.jpg'),
(42725, 2937, 'Headspace Meditação Guiada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137269.mp4', 'http://gstaticontent.com/images/idWdyd1jGQiR6p9F4I1UqKbzYic_big.jpg'),
(42726, 2937, 'Headspace Meditação Guiada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137270.mp4', 'http://gstaticontent.com/images/idWdyd1jGQiR6p9F4I1UqKbzYic_big.jpg'),
(42727, 2938, 'Irmão do Jorel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172855.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42728, 2938, 'Irmão do Jorel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172856.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42729, 2938, 'Irmão do Jorel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172857.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42730, 2938, 'Irmão do Jorel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172858.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42731, 2938, 'Irmão do Jorel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172859.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42732, 2938, 'Irmão do Jorel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172860.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42733, 2938, 'Irmão do Jorel S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172861.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42734, 2938, 'Irmão do Jorel S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172862.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42735, 2938, 'Irmão do Jorel S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172863.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42736, 2938, 'Irmão do Jorel S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172864.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42737, 2938, 'Irmão do Jorel S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172865.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42738, 2938, 'Irmão do Jorel S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172866.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42739, 2938, 'Irmão do Jorel S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172867.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42740, 2938, 'Irmão do Jorel S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172868.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42741, 2938, 'Irmão do Jorel S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/172869.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42742, 2938, 'Irmão do Jorel S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/172870.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42743, 2938, 'Irmão do Jorel S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/172871.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42744, 2938, 'Irmão do Jorel S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/172872.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42745, 2938, 'Irmão do Jorel S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/172873.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42746, 2938, 'Irmão do Jorel S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/172874.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42747, 2938, 'Irmão do Jorel S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/172875.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42748, 2938, 'Irmão do Jorel S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/172876.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42749, 2938, 'Irmão do Jorel S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/172877.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42750, 2938, 'Irmão do Jorel S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/172878.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42751, 2938, 'Irmão do Jorel S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/172879.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42752, 2938, 'Irmão do Jorel S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/172880.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42753, 2939, 'Irmão do Jorel S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172881.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42754, 2939, 'Irmão do Jorel S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172882.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42755, 2939, 'Irmão do Jorel S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172883.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42756, 2939, 'Irmão do Jorel S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172884.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42757, 2939, 'Irmão do Jorel S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172885.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42758, 2939, 'Irmão do Jorel S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172886.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42759, 2939, 'Irmão do Jorel S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172887.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42760, 2939, 'Irmão do Jorel S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172888.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42761, 2939, 'Irmão do Jorel S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172889.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42762, 2939, 'Irmão do Jorel S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172890.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42763, 2939, 'Irmão do Jorel S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172891.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42764, 2939, 'Irmão do Jorel S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172892.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42765, 2939, 'Irmão do Jorel S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172893.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42766, 2939, 'Irmão do Jorel S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172894.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42767, 2939, 'Irmão do Jorel S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/172895.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42768, 2939, 'Irmão do Jorel S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/172896.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42769, 2939, 'Irmão do Jorel S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/172897.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42770, 2939, 'Irmão do Jorel S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/172898.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42771, 2939, 'Irmão do Jorel S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/172899.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42772, 2939, 'Irmão do Jorel S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/172900.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42773, 2939, 'Irmão do Jorel S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/172901.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42774, 2939, 'Irmão do Jorel S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/172902.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42775, 2939, 'Irmão do Jorel S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/172903.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42776, 2939, 'Irmão do Jorel S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/172904.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42777, 2939, 'Irmão do Jorel S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/172905.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42778, 2940, 'Irmão do Jorel S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172906.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42779, 2940, 'Irmão do Jorel S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172907.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42780, 2940, 'Irmão do Jorel S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172908.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42781, 2940, 'Irmão do Jorel S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172909.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42782, 2940, 'Irmão do Jorel S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172910.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42783, 2940, 'Irmão do Jorel S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172911.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42784, 2940, 'Irmão do Jorel S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172912.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42785, 2940, 'Irmão do Jorel S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172913.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42786, 2940, 'Irmão do Jorel S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172914.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42787, 2940, 'Irmão do Jorel S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172915.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42788, 2940, 'Irmão do Jorel S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172916.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42789, 2940, 'Irmão do Jorel S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172917.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42790, 2940, 'Irmão do Jorel S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172918.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42791, 2940, 'Irmão do Jorel S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172919.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42792, 2940, 'Irmão do Jorel S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/172920.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42793, 2940, 'Irmão do Jorel S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/172921.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42794, 2940, 'Irmão do Jorel S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/172922.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42795, 2940, 'Irmão do Jorel S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/172923.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42796, 2940, 'Irmão do Jorel S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/172924.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42797, 2940, 'Irmão do Jorel S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/172925.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42798, 2940, 'Irmão do Jorel S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/172926.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42799, 2940, 'Irmão do Jorel S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/172927.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42800, 2940, 'Irmão do Jorel S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/172928.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42801, 2940, 'Irmão do Jorel S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/172929.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42802, 2940, 'Irmão do Jorel S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/172930.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42803, 2940, 'Irmão do Jorel S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/172931.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42804, 2941, 'Irmão do Jorel S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172932.mp4', 'http://timg.bdta.pro/images/d8d826ae7f55f71155aa1b5a984edfed.jpg'),
(42805, 2941, 'Irmão do Jorel S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172933.mp4', 'http://timg.bdta.pro/images/76bef62ceb9d6f8b99c3bd649ace6941.jpg'),
(42806, 2941, 'Irmão do Jorel S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172934.mp4', 'http://timg.bdta.pro/images/660f4a81bf72d969a4ab223d89bf5bb6.jpg'),
(42807, 2941, 'Irmão do Jorel S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172935.mp4', 'http://timg.bdta.pro/images/2319cec44079d0a78e1a893357b8bdf9.jpg'),
(42808, 2941, 'Irmão do Jorel S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172936.mp4', 'http://timg.bdta.pro/images/72739a0dafe042faca218ab2960eccab.jpg'),
(42809, 2941, 'Irmão do Jorel S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172937.mp4', 'http://timg.bdta.pro/images/2d6cb617f8ef4661c94bfc6457d529a2.jpg'),
(42810, 2941, 'Irmão do Jorel S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172938.mp4', 'http://timg.bdta.pro/images/bf30a1923dc29c65cdd02e9f3cde0404.jpg'),
(42811, 2941, 'Irmão do Jorel S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172939.mp4', 'http://timg.bdta.pro/images/f6428192c6893beb6b6860004a131f6b.jpg'),
(42812, 2941, 'Irmão do Jorel S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172940.mp4', 'http://timg.bdta.pro/images/1fc234383d654159081dcaa34886a057.jpg'),
(42813, 2941, 'Irmão do Jorel S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172941.mp4', 'http://timg.bdta.pro/images/326d03fda4eb1bd25148d408cf6ea0eb.jpg'),
(42814, 2941, 'Irmão do Jorel S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172942.mp4', 'http://timg.bdta.pro/images/ba5329b47e7387dcc2dbd24466901c07.jpg'),
(42815, 2941, 'Irmão do Jorel S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172943.mp4', 'http://timg.bdta.pro/images/027e99031d0750879a94199faf854b41.jpg'),
(42816, 2941, 'Irmão do Jorel S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172944.mp4', 'http://timg.bdta.pro/images/c405d2a16d4432cd46b1c41695dcc6d0.jpg'),
(42817, 2941, 'Irmão do Jorel S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172945.mp4', 'http://timg.bdta.pro/images/33be951892884cb07f307821cf371327.jpg'),
(42818, 2941, 'Irmão do Jorel S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/172946.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42819, 2941, 'Irmão do Jorel S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/172947.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42820, 2941, 'Irmão do Jorel S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/172948.mp4', 'http://timg.bdta.pro/images/9f7e3d75ec1b6d96da23bcb651ffcb32.jpg'),
(42821, 2941, 'Irmão do Jorel S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/172949.mp4', 'http://timg.bdta.pro/images/ac690a8e43384dc3278dee3a7f215855.jpg'),
(42822, 2941, 'Irmão do Jorel S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/172950.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42823, 2941, 'Irmão do Jorel S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/172951.mp4', 'http://timg.bdta.pro/images/2bfb630d81b0bcee0284cd07136ab80b.jpg'),
(42824, 2941, 'Irmão do Jorel S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/172952.mp4', 'http://timg.bdta.pro/images/465703841003342a8ccb010de09bf526.jpg'),
(42825, 2941, 'Irmão do Jorel S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/172953.mp4', 'http://timg.bdta.pro/images/d6b80bffe11031fe4b94d3f617f31f70.jpg'),
(42826, 2941, 'Irmão do Jorel S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/172954.mp4', 'http://timg.bdta.pro/images/ef4345ccc9a0951b38b10fe17025199c.jpg'),
(42827, 2941, 'Irmão do Jorel S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/172955.mp4', 'http://timg.bdta.pro/images/474901f45e00619213aa96f0843f3de9.jpg'),
(42828, 2941, 'Irmão do Jorel S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/172956.mp4', 'http://timg.bdta.pro/images/57ed557c6dce66dea3ab39be0dde284d.jpg'),
(42829, 2941, 'Irmão do Jorel S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/172957.mp4', 'http://timg.bdta.pro/images/c77cd41c70833cdabc3adb62b0864459.jpg'),
(42830, 2942, 'Irmão do Jorel S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/485345.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42831, 2942, 'Irmão do Jorel S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/485346.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42832, 2942, 'Irmão do Jorel S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/485347.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42833, 2942, 'Irmão do Jorel S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/485348.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42834, 2942, 'Irmão do Jorel S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/485349.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42835, 2942, 'Irmão do Jorel S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/485350.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42836, 2942, 'Irmão do Jorel S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/485351.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42837, 2942, 'Irmão do Jorel S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/485352.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42838, 2942, 'Irmão do Jorel S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/485353.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42839, 2942, 'Irmão do Jorel S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/485354.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42840, 2942, 'Irmão do Jorel S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/485355.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42841, 2942, 'Irmão do Jorel S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/698018.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42842, 2942, 'Irmão do Jorel S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/698019.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42843, 2942, 'Irmão do Jorel S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/698020.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42844, 2942, 'Irmão do Jorel S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/698021.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42845, 2942, 'Irmão do Jorel S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/698022.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42846, 2942, 'Irmão do Jorel S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/698023.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42847, 2942, 'Irmão do Jorel S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/800870.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42848, 2942, 'Irmão do Jorel S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/800871.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42849, 2942, 'Irmão do Jorel S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/800872.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42850, 2942, 'Irmão do Jorel S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/800873.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42851, 2942, 'Irmão do Jorel S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/800874.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42852, 2942, 'Irmão do Jorel S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/800875.mp4', 'http://gstaticontent.com/images/yrgTP9gbSAvCXwsN0mU0iVigtLZ_big.jpg'),
(42853, 2943, 'A Cara do Pai S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137238.mp4', 'https://i.bj-share.info/98e888f35178c13c0481e69419bd7448.jpg'),
(42854, 2943, 'A Cara do Pai S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137239.mp4', 'https://i.bj-share.info/98e888f35178c13c0481e69419bd7448.jpg'),
(42855, 2943, 'A Cara do Pai S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137240.mp4', 'https://i.bj-share.info/98e888f35178c13c0481e69419bd7448.jpg'),
(42856, 2944, 'A Cara do Pai S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137241.mp4', 'https://i.bj-share.info/98e888f35178c13c0481e69419bd7448.jpg'),
(42857, 2944, 'A Cara do Pai S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137242.mp4', 'https://i.bj-share.info/98e888f35178c13c0481e69419bd7448.jpg'),
(42858, 2944, 'A Cara do Pai S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137243.mp4', 'https://i.bj-share.info/98e888f35178c13c0481e69419bd7448.jpg'),
(42859, 2944, 'A Cara do Pai S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137244.mp4', 'https://i.bj-share.info/98e888f35178c13c0481e69419bd7448.jpg'),
(42860, 2944, 'A Cara do Pai S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137245.mp4', 'https://i.bj-share.info/98e888f35178c13c0481e69419bd7448.jpg'),
(42861, 2944, 'A Cara do Pai S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137246.mp4', 'https://i.bj-share.info/98e888f35178c13c0481e69419bd7448.jpg'),
(42862, 2944, 'A Cara do Pai S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137247.mp4', 'https://i.bj-share.info/98e888f35178c13c0481e69419bd7448.jpg'),
(42863, 2944, 'A Cara do Pai S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137248.mp4', 'https://i.bj-share.info/98e888f35178c13c0481e69419bd7448.jpg'),
(42864, 2944, 'A Cara do Pai S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137249.mp4', 'https://i.bj-share.info/98e888f35178c13c0481e69419bd7448.jpg'),
(42865, 2944, 'A Cara do Pai S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137250.mp4', 'https://i.bj-share.info/98e888f35178c13c0481e69419bd7448.jpg'),
(42866, 2944, 'A Cara do Pai S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137251.mp4', 'https://i.bj-share.info/98e888f35178c13c0481e69419bd7448.jpg'),
(42867, 2944, 'A Cara do Pai S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137252.mp4', 'https://i.bj-share.info/98e888f35178c13c0481e69419bd7448.jpg'),
(42868, 2945, 'A Perfect Planet [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137233.mp4', 'http://gstaticontent.com/images/8JJa4gduVytwpXQzFtZNibRA6S_big.jpg'),
(42869, 2945, 'A Perfect Planet [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137234.mp4', 'http://gstaticontent.com/images/8JJa4gduVytwpXQzFtZNibRA6S_big.jpg'),
(42870, 2945, 'A Perfect Planet [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137235.mp4', 'http://gstaticontent.com/images/8JJa4gduVytwpXQzFtZNibRA6S_big.jpg'),
(42871, 2945, 'A Perfect Planet [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137236.mp4', 'http://gstaticontent.com/images/8JJa4gduVytwpXQzFtZNibRA6S_big.jpg'),
(42872, 2945, 'A Perfect Planet [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137237.mp4', 'http://gstaticontent.com/images/8JJa4gduVytwpXQzFtZNibRA6S_big.jpg'),
(42873, 2946, 'Biologia Avançada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137199.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42874, 2946, 'Biologia Avançada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137200.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42875, 2946, 'Biologia Avançada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137201.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42876, 2946, 'Biologia Avançada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137202.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42877, 2946, 'Biologia Avançada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137203.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42878, 2946, 'Biologia Avançada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137204.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42879, 2946, 'Biologia Avançada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137205.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42880, 2946, 'Biologia Avançada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137206.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42881, 2946, 'Biologia Avançada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137207.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42882, 2946, 'Biologia Avançada S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137208.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42883, 2946, 'Biologia Avançada S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137209.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42884, 2946, 'Biologia Avançada S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137210.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42885, 2946, 'Biologia Avançada S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137211.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42886, 2947, 'Biologia Avançada S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137212.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42887, 2947, 'Biologia Avançada S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137213.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42888, 2947, 'Biologia Avançada S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137214.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42889, 2947, 'Biologia Avançada S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137215.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42890, 2947, 'Biologia Avançada S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137216.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42891, 2947, 'Biologia Avançada S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137217.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42892, 2947, 'Biologia Avançada S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137218.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42893, 2947, 'Biologia Avançada S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137219.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42894, 2947, 'Biologia Avançada S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137220.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42895, 2947, 'Biologia Avançada S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137221.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42896, 2947, 'Biologia Avançada S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137222.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42897, 2947, 'Biologia Avançada S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137223.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42898, 2947, 'Biologia Avançada S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137224.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42899, 2948, 'Biologia Avançada S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137225.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42900, 2948, 'Biologia Avançada S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137226.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42901, 2948, 'Biologia Avançada S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137227.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42902, 2948, 'Biologia Avançada S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137228.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42903, 2948, 'Biologia Avançada S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137229.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42904, 2948, 'Biologia Avançada S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137230.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42905, 2948, 'Biologia Avançada S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137231.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42906, 2948, 'Biologia Avançada S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137232.mp4', 'http://gstaticontent.com/images/wBD4XS7rPTTpA7xMrwxL3cilqem_big.jpg'),
(42907, 2949, 'Broadchurch [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137183.mp4', 'http://gstaticontent.com/images/f5gQRyTZ3v4asugU2F5HXE2FIDg_big.jpg'),
(42908, 2949, 'Broadchurch [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137184.mp4', 'http://gstaticontent.com/images/f5gQRyTZ3v4asugU2F5HXE2FIDg_big.jpg'),
(42909, 2949, 'Broadchurch [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137185.mp4', 'http://gstaticontent.com/images/f5gQRyTZ3v4asugU2F5HXE2FIDg_big.jpg'),
(42910, 2949, 'Broadchurch [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137186.mp4', 'http://gstaticontent.com/images/f5gQRyTZ3v4asugU2F5HXE2FIDg_big.jpg'),
(42911, 2949, 'Broadchurch [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137187.mp4', 'http://gstaticontent.com/images/f5gQRyTZ3v4asugU2F5HXE2FIDg_big.jpg'),
(42912, 2949, 'Broadchurch [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137188.mp4', 'http://gstaticontent.com/images/f5gQRyTZ3v4asugU2F5HXE2FIDg_big.jpg'),
(42913, 2949, 'Broadchurch [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137189.mp4', 'http://gstaticontent.com/images/f5gQRyTZ3v4asugU2F5HXE2FIDg_big.jpg'),
(42914, 2949, 'Broadchurch [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137190.mp4', 'http://gstaticontent.com/images/f5gQRyTZ3v4asugU2F5HXE2FIDg_big.jpg'),
(42915, 2950, 'Broadchurch [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137191.mp4', 'http://gstaticontent.com/images/f5gQRyTZ3v4asugU2F5HXE2FIDg_big.jpg'),
(42916, 2950, 'Broadchurch [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137192.mp4', 'http://gstaticontent.com/images/f5gQRyTZ3v4asugU2F5HXE2FIDg_big.jpg'),
(42917, 2950, 'Broadchurch [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137193.mp4', 'http://gstaticontent.com/images/f5gQRyTZ3v4asugU2F5HXE2FIDg_big.jpg'),
(42918, 2950, 'Broadchurch [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137194.mp4', 'http://gstaticontent.com/images/f5gQRyTZ3v4asugU2F5HXE2FIDg_big.jpg'),
(42919, 2950, 'Broadchurch [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137195.mp4', 'http://gstaticontent.com/images/f5gQRyTZ3v4asugU2F5HXE2FIDg_big.jpg'),
(42920, 2950, 'Broadchurch [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137196.mp4', 'http://gstaticontent.com/images/f5gQRyTZ3v4asugU2F5HXE2FIDg_big.jpg'),
(42921, 2950, 'Broadchurch [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137197.mp4', 'http://gstaticontent.com/images/f5gQRyTZ3v4asugU2F5HXE2FIDg_big.jpg'),
(42922, 2950, 'Broadchurch [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137198.mp4', 'http://gstaticontent.com/images/f5gQRyTZ3v4asugU2F5HXE2FIDg_big.jpg'),
(42923, 2951, 'Comidas Cheias de História S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137163.mp4', 'http://gstaticontent.com/images/4JBlGuZWcot3EdOkeG9IFalIyWR_big.jpg'),
(42924, 2951, 'Comidas Cheias de História S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137164.mp4', 'http://gstaticontent.com/images/4JBlGuZWcot3EdOkeG9IFalIyWR_big.jpg'),
(42925, 2951, 'Comidas Cheias de História S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137165.mp4', 'http://gstaticontent.com/images/4JBlGuZWcot3EdOkeG9IFalIyWR_big.jpg'),
(42926, 2951, 'Comidas Cheias de História S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137166.mp4', 'http://gstaticontent.com/images/4JBlGuZWcot3EdOkeG9IFalIyWR_big.jpg'),
(42927, 2951, 'Comidas Cheias de História S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137167.mp4', 'http://gstaticontent.com/images/4JBlGuZWcot3EdOkeG9IFalIyWR_big.jpg'),
(42928, 2951, 'Comidas Cheias de História S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137168.mp4', 'http://gstaticontent.com/images/4JBlGuZWcot3EdOkeG9IFalIyWR_big.jpg'),
(42929, 2951, 'Comidas Cheias de História S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137169.mp4', 'http://gstaticontent.com/images/4JBlGuZWcot3EdOkeG9IFalIyWR_big.jpg'),
(42930, 2951, 'Comidas Cheias de História S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137170.mp4', 'http://gstaticontent.com/images/4JBlGuZWcot3EdOkeG9IFalIyWR_big.jpg'),
(42931, 2951, 'Comidas Cheias de História S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137171.mp4', 'http://gstaticontent.com/images/4JBlGuZWcot3EdOkeG9IFalIyWR_big.jpg'),
(42932, 2951, 'Comidas Cheias de História S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137172.mp4', 'http://gstaticontent.com/images/4JBlGuZWcot3EdOkeG9IFalIyWR_big.jpg'),
(42933, 2951, 'Comidas Cheias de História S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137173.mp4', 'http://gstaticontent.com/images/4JBlGuZWcot3EdOkeG9IFalIyWR_big.jpg'),
(42934, 2951, 'Comidas Cheias de História S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137174.mp4', 'http://gstaticontent.com/images/4JBlGuZWcot3EdOkeG9IFalIyWR_big.jpg'),
(42935, 2951, 'Comidas Cheias de História S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137175.mp4', 'http://gstaticontent.com/images/4JBlGuZWcot3EdOkeG9IFalIyWR_big.jpg'),
(42936, 2951, 'Comidas Cheias de História S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137176.mp4', 'http://gstaticontent.com/images/4JBlGuZWcot3EdOkeG9IFalIyWR_big.jpg'),
(42937, 2951, 'Comidas Cheias de História S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137177.mp4', 'http://gstaticontent.com/images/4JBlGuZWcot3EdOkeG9IFalIyWR_big.jpg'),
(42938, 2951, 'Comidas Cheias de História S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137178.mp4', 'http://gstaticontent.com/images/4JBlGuZWcot3EdOkeG9IFalIyWR_big.jpg'),
(42939, 2951, 'Comidas Cheias de História S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137179.mp4', 'http://gstaticontent.com/images/4JBlGuZWcot3EdOkeG9IFalIyWR_big.jpg'),
(42940, 2951, 'Comidas Cheias de História S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137180.mp4', 'http://gstaticontent.com/images/4JBlGuZWcot3EdOkeG9IFalIyWR_big.jpg'),
(42941, 2951, 'Comidas Cheias de História S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137181.mp4', 'http://gstaticontent.com/images/4JBlGuZWcot3EdOkeG9IFalIyWR_big.jpg'),
(42942, 2951, 'Comidas Cheias de História S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137182.mp4', 'http://gstaticontent.com/images/4JBlGuZWcot3EdOkeG9IFalIyWR_big.jpg'),
(42943, 2952, 'Everythings Gonna Be Okay [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137153.mp4', 'http://gstaticontent.com/images/xLTsekgk4qI7gYBKruhFFJVlg36_big.jpg'),
(42944, 2952, 'Everythings Gonna Be Okay [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137154.mp4', 'http://gstaticontent.com/images/xLTsekgk4qI7gYBKruhFFJVlg36_big.jpg'),
(42945, 2952, 'Everythings Gonna Be Okay [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137155.mp4', 'http://gstaticontent.com/images/xLTsekgk4qI7gYBKruhFFJVlg36_big.jpg'),
(42946, 2952, 'Everythings Gonna Be Okay [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137156.mp4', 'http://gstaticontent.com/images/xLTsekgk4qI7gYBKruhFFJVlg36_big.jpg'),
(42947, 2952, 'Everythings Gonna Be Okay [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137157.mp4', 'http://gstaticontent.com/images/xLTsekgk4qI7gYBKruhFFJVlg36_big.jpg'),
(42948, 2952, 'Everythings Gonna Be Okay [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137158.mp4', 'http://gstaticontent.com/images/xLTsekgk4qI7gYBKruhFFJVlg36_big.jpg'),
(42949, 2952, 'Everythings Gonna Be Okay [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137159.mp4', 'http://gstaticontent.com/images/xLTsekgk4qI7gYBKruhFFJVlg36_big.jpg'),
(42950, 2952, 'Everythings Gonna Be Okay [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137160.mp4', 'http://gstaticontent.com/images/xLTsekgk4qI7gYBKruhFFJVlg36_big.jpg'),
(42951, 2952, 'Everythings Gonna Be Okay [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137161.mp4', 'http://gstaticontent.com/images/xLTsekgk4qI7gYBKruhFFJVlg36_big.jpg'),
(42952, 2952, 'Everythings Gonna Be Okay [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137162.mp4', 'http://gstaticontent.com/images/xLTsekgk4qI7gYBKruhFFJVlg36_big.jpg'),
(42953, 2953, 'O Legado Dos Anos 90 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137151.mp4', 'http://gstaticontent.com/images/rZZQXLBa4yFsQrWvID4O3HUYTOI_big.jpg'),
(42954, 2953, 'O Legado Dos Anos 90 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137152.mp4', 'http://gstaticontent.com/images/rZZQXLBa4yFsQrWvID4O3HUYTOI_big.jpg'),
(42955, 2954, 'Riacho Doce S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137111.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42956, 2954, 'Riacho Doce S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137112.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42957, 2954, 'Riacho Doce S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137113.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42958, 2954, 'Riacho Doce S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137114.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42959, 2954, 'Riacho Doce S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137115.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42960, 2954, 'Riacho Doce S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137116.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42961, 2954, 'Riacho Doce S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137117.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42962, 2954, 'Riacho Doce S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137118.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42963, 2954, 'Riacho Doce S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137119.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42964, 2954, 'Riacho Doce S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137120.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42965, 2954, 'Riacho Doce S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137121.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42966, 2954, 'Riacho Doce S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137122.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42967, 2954, 'Riacho Doce S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137123.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42968, 2954, 'Riacho Doce S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137124.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42969, 2954, 'Riacho Doce S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137125.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42970, 2954, 'Riacho Doce S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137126.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42971, 2954, 'Riacho Doce S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137127.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42972, 2954, 'Riacho Doce S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137128.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42973, 2954, 'Riacho Doce S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137129.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42974, 2954, 'Riacho Doce S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137130.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42975, 2954, 'Riacho Doce S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/137131.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42976, 2954, 'Riacho Doce S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/137132.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42977, 2954, 'Riacho Doce S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/137133.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42978, 2954, 'Riacho Doce S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/137134.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42979, 2954, 'Riacho Doce S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/137135.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42980, 2954, 'Riacho Doce S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/137136.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42981, 2954, 'Riacho Doce S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/137137.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42982, 2954, 'Riacho Doce S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/137138.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42983, 2954, 'Riacho Doce S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/137139.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42984, 2954, 'Riacho Doce S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/137140.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42985, 2954, 'Riacho Doce S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/137141.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42986, 2954, 'Riacho Doce S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/137142.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42987, 2954, 'Riacho Doce S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/137143.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42988, 2954, 'Riacho Doce S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/137144.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42989, 2954, 'Riacho Doce S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/137145.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42990, 2954, 'Riacho Doce S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/137146.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42991, 2954, 'Riacho Doce S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/137147.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42992, 2954, 'Riacho Doce S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/137148.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(42993, 2954, 'Riacho Doce S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/137149.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42994, 2954, 'Riacho Doce S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/137150.mp4', 'http://gstaticontent.com/images/2NF2gpZDaAjMEneptGYJCZ8jBur_big.jpg'),
(42995, 2955, 'Vida Após a Morte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137105.mp4', 'http://gstaticontent.com/images/8vQwdV33tthEHmPjGz70ogBUpnR_big.jpg'),
(42996, 2955, 'Vida Após a Morte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137106.mp4', 'http://gstaticontent.com/images/8vQwdV33tthEHmPjGz70ogBUpnR_big.jpg'),
(42997, 2955, 'Vida Após a Morte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137107.mp4', 'http://gstaticontent.com/images/8vQwdV33tthEHmPjGz70ogBUpnR_big.jpg'),
(42998, 2955, 'Vida Após a Morte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137108.mp4', 'http://gstaticontent.com/images/8vQwdV33tthEHmPjGz70ogBUpnR_big.jpg'),
(42999, 2955, 'Vida Após a Morte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137109.mp4', 'http://gstaticontent.com/images/8vQwdV33tthEHmPjGz70ogBUpnR_big.jpg'),
(43000, 2955, 'Vida Após a Morte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137110.mp4', 'http://gstaticontent.com/images/8vQwdV33tthEHmPjGz70ogBUpnR_big.jpg'),
(43001, 2956, 'A Cor do Poder S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198989.mp4', 'http://gstaticontent.com/images/jYwTFTd6RTNc53oySS1FARB1iB2_big.jpg'),
(43002, 2956, 'A Cor do Poder S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198990.mp4', 'http://gstaticontent.com/images/jYwTFTd6RTNc53oySS1FARB1iB2_big.jpg'),
(43003, 2956, 'A Cor do Poder S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198991.mp4', 'http://gstaticontent.com/images/jYwTFTd6RTNc53oySS1FARB1iB2_big.jpg'),
(43004, 2956, 'A Cor do Poder S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198992.mp4', 'http://gstaticontent.com/images/jYwTFTd6RTNc53oySS1FARB1iB2_big.jpg'),
(43005, 2956, 'A Cor do Poder S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198993.mp4', 'http://gstaticontent.com/images/jYwTFTd6RTNc53oySS1FARB1iB2_big.jpg'),
(43006, 2956, 'A Cor do Poder S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198994.mp4', 'http://gstaticontent.com/images/jYwTFTd6RTNc53oySS1FARB1iB2_big.jpg'),
(43007, 2957, 'A Cor do Poder S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tXGoiYS43MnqRWIDQPQjpQph8e0.jpg'),
(43008, 2957, 'A Cor do Poder S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hUtHJJhA3fVaQ6DFVzygaZw4Sah.jpg'),
(43009, 2957, 'A Cor do Poder S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/voSBMkIwJGCMXAX8QZcG1V3XuxZ.jpg'),
(43010, 2957, 'A Cor do Poder S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nkV7auxD92gQtajkazmWIwN1UJi.jpg'),
(43011, 2958, 'A Teacher [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137069.mp4', 'http://gstaticontent.com/images/8ASlc9OKkca4yaaDvZfB6Gkzl6y_big.jpg'),
(43012, 2958, 'A Teacher [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137070.mp4', 'http://gstaticontent.com/images/8ASlc9OKkca4yaaDvZfB6Gkzl6y_big.jpg'),
(43013, 2958, 'A Teacher [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137071.mp4', 'http://gstaticontent.com/images/8ASlc9OKkca4yaaDvZfB6Gkzl6y_big.jpg'),
(43014, 2958, 'A Teacher [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137072.mp4', 'http://gstaticontent.com/images/8ASlc9OKkca4yaaDvZfB6Gkzl6y_big.jpg'),
(43015, 2958, 'A Teacher [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137073.mp4', 'http://gstaticontent.com/images/8ASlc9OKkca4yaaDvZfB6Gkzl6y_big.jpg'),
(43016, 2958, 'A Teacher [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137074.mp4', 'http://gstaticontent.com/images/8ASlc9OKkca4yaaDvZfB6Gkzl6y_big.jpg'),
(43017, 2958, 'A Teacher [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137075.mp4', 'http://gstaticontent.com/images/8ASlc9OKkca4yaaDvZfB6Gkzl6y_big.jpg'),
(43018, 2958, 'A Teacher [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137076.mp4', 'http://gstaticontent.com/images/8ASlc9OKkca4yaaDvZfB6Gkzl6y_big.jpg'),
(43019, 2958, 'A Teacher [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137077.mp4', 'http://gstaticontent.com/images/8ASlc9OKkca4yaaDvZfB6Gkzl6y_big.jpg'),
(43020, 2958, 'A Teacher [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137078.mp4', 'http://gstaticontent.com/images/8ASlc9OKkca4yaaDvZfB6Gkzl6y_big.jpg'),
(43021, 2959, 'Arashis Diary Voyage [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137046.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43022, 2959, 'Arashis Diary Voyage [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137047.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43023, 2959, 'Arashis Diary Voyage [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137048.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43024, 2959, 'Arashis Diary Voyage [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137049.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43025, 2959, 'Arashis Diary Voyage [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137050.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43026, 2959, 'Arashis Diary Voyage [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137051.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43027, 2959, 'Arashis Diary Voyage [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137052.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43028, 2959, 'Arashis Diary Voyage [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137053.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43029, 2959, 'Arashis Diary Voyage [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137054.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43030, 2959, 'Arashis Diary Voyage [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137055.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43031, 2959, 'Arashis Diary Voyage [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137056.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43032, 2959, 'Arashis Diary Voyage [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137057.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43033, 2959, 'Arashis Diary Voyage [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137058.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43034, 2959, 'Arashis Diary Voyage [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137059.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43035, 2959, 'Arashis Diary Voyage [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137060.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43036, 2959, 'Arashis Diary Voyage [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137061.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43037, 2959, 'Arashis Diary Voyage [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137062.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43038, 2959, 'Arashis Diary Voyage [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137063.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43039, 2959, 'Arashis Diary Voyage [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137064.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43040, 2959, 'Arashis Diary Voyage [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137065.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43041, 2959, 'Arashis Diary Voyage [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/137066.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43042, 2959, 'Arashis Diary Voyage [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/137067.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43043, 2959, 'Arashis Diary Voyage [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/137068.mp4', 'http://gstaticontent.com/images/wL1WdWUgRVnK3dkMK5kYYRiyLvX_big.jpg'),
(43044, 2960, 'Beforeigners: Os Visitantes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177412.mp4', 'http://timg.bdta.pro/images/d2b0cdc2b2d9256aeac5e53a18a80995.jpg'),
(43045, 2960, 'Beforeigners: Os Visitantes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177413.mp4', 'http://timg.bdta.pro/images/6a0b5d02baebad60fdacfcf855bec2ef.jpg'),
(43046, 2960, 'Beforeigners: Os Visitantes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177414.mp4', 'http://timg.bdta.pro/images/f63bba3ca404b0e1cf88b0707661c4cb.jpg'),
(43047, 2960, 'Beforeigners: Os Visitantes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177415.mp4', 'http://timg.bdta.pro/images/bd94736be63de53f0f92d008dda5a586.jpg'),
(43048, 2960, 'Beforeigners: Os Visitantes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177416.mp4', 'http://timg.bdta.pro/images/084cb41540d3e02d9726d972798e8214.jpg'),
(43049, 2960, 'Beforeigners: Os Visitantes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177417.mp4', 'http://timg.bdta.pro/images/d0f437886fe3c638f9297f53a7608b98.jpg'),
(43050, 2961, 'Beforeigners: Os Visitantes S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177418.mp4', 'http://timg.bdta.pro/images/32c7f328fad8986eabbc95d266195744.jpg'),
(43051, 2961, 'Beforeigners: Os Visitantes S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177419.mp4', 'http://timg.bdta.pro/images/a1078d20cda437f9049c2f4cc5891108.jpg'),
(43052, 2961, 'Beforeigners: Os Visitantes S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177420.mp4', 'http://timg.bdta.pro/images/37d53e2b8848a161376b94a608a1336a.jpg'),
(43053, 2961, 'Beforeigners: Os Visitantes S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177421.mp4', 'http://timg.bdta.pro/images/c12f7a67f4c360f257b2ed6f873d7339.jpg'),
(43054, 2961, 'Beforeigners: Os Visitantes S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177422.mp4', 'http://timg.bdta.pro/images/a163f970361248b6fb23eae6804cbd37.jpg'),
(43055, 2961, 'Beforeigners: Os Visitantes S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177423.mp4', 'http://timg.bdta.pro/images/6e1575b39a968b6531d16a366c989e2d.jpg'),
(43056, 2962, 'Fauda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136356.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43057, 2962, 'Fauda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136357.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43058, 2962, 'Fauda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136358.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43059, 2962, 'Fauda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136359.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43060, 2962, 'Fauda S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136360.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43061, 2962, 'Fauda S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136361.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43062, 2962, 'Fauda S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136362.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43063, 2962, 'Fauda S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136363.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43064, 2962, 'Fauda S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136364.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43065, 2962, 'Fauda S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136365.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43066, 2962, 'Fauda S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136366.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43067, 2962, 'Fauda S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136367.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43068, 2963, 'Fauda S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136368.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43069, 2963, 'Fauda S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136369.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43070, 2963, 'Fauda S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136370.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43071, 2963, 'Fauda S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136371.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43072, 2963, 'Fauda S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136372.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43073, 2963, 'Fauda S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136373.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43074, 2963, 'Fauda S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136374.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43075, 2963, 'Fauda S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136375.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43076, 2963, 'Fauda S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136376.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43077, 2963, 'Fauda S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136377.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43078, 2963, 'Fauda S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136378.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43079, 2963, 'Fauda S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136379.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43080, 2964, 'Fauda S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136380.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43081, 2964, 'Fauda S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136381.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43082, 2964, 'Fauda S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136382.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43083, 2964, 'Fauda S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136383.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43084, 2964, 'Fauda S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136384.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43085, 2964, 'Fauda S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136385.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43086, 2964, 'Fauda S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136386.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43087, 2964, 'Fauda S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136387.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43088, 2964, 'Fauda S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136388.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43089, 2964, 'Fauda S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136389.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43090, 2964, 'Fauda S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136390.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43091, 2964, 'Fauda S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136391.mp4', 'http://gstaticontent.com/images/awgmWk2TrCLrwynSjeK4zmI6iXR_big.jpg'),
(43092, 2965, 'Grant S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137043.mp4', 'http://gstaticontent.com/images/dxRQTh6BE3rWqKPtqcx82G4RGOj_big.jpg'),
(43093, 2965, 'Grant S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137044.mp4', 'http://gstaticontent.com/images/dxRQTh6BE3rWqKPtqcx82G4RGOj_big.jpg'),
(43094, 2965, 'Grant S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137045.mp4', 'http://gstaticontent.com/images/dxRQTh6BE3rWqKPtqcx82G4RGOj_big.jpg'),
(43095, 2966, 'Ideias Sinistras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137035.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(43096, 2966, 'Ideias Sinistras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137036.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(43097, 2966, 'Ideias Sinistras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137037.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(43098, 2966, 'Ideias Sinistras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137038.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(43099, 2966, 'Ideias Sinistras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137039.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(43100, 2966, 'Ideias Sinistras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137040.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(43101, 2966, 'Ideias Sinistras S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137041.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(43102, 2966, 'Ideias Sinistras S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137042.mp4', 'http://gstaticontent.com/images/_big.jpg'),
(43103, 2967, 'In the Dark S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137009.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43104, 2967, 'In the Dark S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137010.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43105, 2967, 'In the Dark S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137011.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43106, 2967, 'In the Dark S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137012.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43107, 2967, 'In the Dark S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137013.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43108, 2967, 'In the Dark S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137014.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43109, 2967, 'In the Dark S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137015.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43110, 2967, 'In the Dark S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137016.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43111, 2967, 'In the Dark S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137017.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43112, 2967, 'In the Dark S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137018.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43113, 2967, 'In the Dark S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137019.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43114, 2967, 'In the Dark S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137020.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43115, 2967, 'In the Dark S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137021.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43116, 2968, 'In the Dark S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137022.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43117, 2968, 'In the Dark S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137023.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43118, 2968, 'In the Dark S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137024.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43119, 2968, 'In the Dark S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137025.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43120, 2968, 'In the Dark S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137026.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43121, 2968, 'In the Dark S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137027.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43122, 2968, 'In the Dark S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137028.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43123, 2968, 'In the Dark S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137029.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43124, 2968, 'In the Dark S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137030.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43125, 2968, 'In the Dark S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137031.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43126, 2968, 'In the Dark S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137032.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43127, 2968, 'In the Dark S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137033.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43128, 2968, 'In the Dark S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137034.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43129, 2969, 'In the Dark S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/875100.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43130, 2969, 'In the Dark S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/875101.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43131, 2969, 'In the Dark S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/875102.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43132, 2969, 'In the Dark S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/875103.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43133, 2969, 'In the Dark S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/875104.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43134, 2969, 'In the Dark S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/875105.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43135, 2969, 'In the Dark S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/875106.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43136, 2969, 'In the Dark S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/875107.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43137, 2969, 'In the Dark S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/875108.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43138, 2969, 'In the Dark S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/875109.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43139, 2969, 'In the Dark S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/875110.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43140, 2969, 'In the Dark S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/875111.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43141, 2969, 'In the Dark S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/875112.mp4', 'http://gstaticontent.com/images/ecUKYm6Pf8dEHk2IZiNaLtbprRQ_big.jpg'),
(43142, 2970, 'Lupin S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237642.mp4', 'http://gstaticontent.com/images/sgxawbFB5Vi5OkPWQLNfl3dvkNJ_big.jpg'),
(43143, 2970, 'Lupin S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237643.mp4', 'http://gstaticontent.com/images/sgxawbFB5Vi5OkPWQLNfl3dvkNJ_big.jpg'),
(43144, 2970, 'Lupin S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237644.mp4', 'http://gstaticontent.com/images/sgxawbFB5Vi5OkPWQLNfl3dvkNJ_big.jpg'),
(43145, 2970, 'Lupin S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237645.mp4', 'http://gstaticontent.com/images/sgxawbFB5Vi5OkPWQLNfl3dvkNJ_big.jpg'),
(43146, 2970, 'Lupin S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237646.mp4', 'http://gstaticontent.com/images/sgxawbFB5Vi5OkPWQLNfl3dvkNJ_big.jpg'),
(43147, 2971, 'Lupin S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237647.mp4', 'http://gstaticontent.com/images/sgxawbFB5Vi5OkPWQLNfl3dvkNJ_big.jpg'),
(43148, 2971, 'Lupin S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237648.mp4', 'http://gstaticontent.com/images/sgxawbFB5Vi5OkPWQLNfl3dvkNJ_big.jpg'),
(43149, 2971, 'Lupin S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237649.mp4', 'http://gstaticontent.com/images/sgxawbFB5Vi5OkPWQLNfl3dvkNJ_big.jpg'),
(43150, 2971, 'Lupin S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237650.mp4', 'http://gstaticontent.com/images/sgxawbFB5Vi5OkPWQLNfl3dvkNJ_big.jpg'),
(43151, 2971, 'Lupin S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237651.mp4', 'http://gstaticontent.com/images/sgxawbFB5Vi5OkPWQLNfl3dvkNJ_big.jpg'),
(43152, 2972, 'Lupin S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237652.mp4', 'http://gstaticontent.com/images/sgxawbFB5Vi5OkPWQLNfl3dvkNJ_big.jpg'),
(43153, 2972, 'Lupin S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237653.mp4', 'http://gstaticontent.com/images/sgxawbFB5Vi5OkPWQLNfl3dvkNJ_big.jpg'),
(43154, 2972, 'Lupin S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237654.mp4', 'http://gstaticontent.com/images/sgxawbFB5Vi5OkPWQLNfl3dvkNJ_big.jpg'),
(43155, 2972, 'Lupin S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237655.mp4', 'http://gstaticontent.com/images/sgxawbFB5Vi5OkPWQLNfl3dvkNJ_big.jpg'),
(43156, 2972, 'Lupin S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237656.mp4', 'http://gstaticontent.com/images/sgxawbFB5Vi5OkPWQLNfl3dvkNJ_big.jpg'),
(43157, 2972, 'Lupin S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237657.mp4', 'http://gstaticontent.com/images/sgxawbFB5Vi5OkPWQLNfl3dvkNJ_big.jpg'),
(43158, 2972, 'Lupin S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237658.mp4', 'http://gstaticontent.com/images/sgxawbFB5Vi5OkPWQLNfl3dvkNJ_big.jpg'),
(43159, 2973, 'Marvel Studios Legends [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147551.mp4', 'http://gstaticontent.com/images/5GKRz38rqy2B45fj3T4MR6sJxAm_big.jpg'),
(43160, 2973, 'Marvel Studios Legends [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147552.mp4', 'http://gstaticontent.com/images/5GKRz38rqy2B45fj3T4MR6sJxAm_big.jpg'),
(43161, 2973, 'Marvel Studios Legends [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147553.mp4', 'http://gstaticontent.com/images/5GKRz38rqy2B45fj3T4MR6sJxAm_big.jpg'),
(43162, 2973, 'Marvel Studios Legends [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147554.mp4', 'http://gstaticontent.com/images/5GKRz38rqy2B45fj3T4MR6sJxAm_big.jpg'),
(43163, 2973, 'Marvel Studios Legends [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147555.mp4', 'http://gstaticontent.com/images/5GKRz38rqy2B45fj3T4MR6sJxAm_big.jpg'),
(43164, 2973, 'Marvel Studios Legends [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147556.mp4', 'http://gstaticontent.com/images/5GKRz38rqy2B45fj3T4MR6sJxAm_big.jpg'),
(43165, 2973, 'Marvel Studios Legends [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147557.mp4', 'http://gstaticontent.com/images/5GKRz38rqy2B45fj3T4MR6sJxAm_big.jpg'),
(43166, 2973, 'Marvel Studios Legends [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147558.mp4', 'http://gstaticontent.com/images/5GKRz38rqy2B45fj3T4MR6sJxAm_big.jpg'),
(43167, 2974, 'Mrs America [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137000.mp4', 'http://gstaticontent.com/images/cTJYU7lpFbrz5hoIQugGBDEdezy_big.jpg'),
(43168, 2974, 'Mrs America [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137001.mp4', 'http://gstaticontent.com/images/cTJYU7lpFbrz5hoIQugGBDEdezy_big.jpg'),
(43169, 2974, 'Mrs America [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137002.mp4', 'http://gstaticontent.com/images/cTJYU7lpFbrz5hoIQugGBDEdezy_big.jpg'),
(43170, 2974, 'Mrs America [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137003.mp4', 'http://gstaticontent.com/images/cTJYU7lpFbrz5hoIQugGBDEdezy_big.jpg'),
(43171, 2974, 'Mrs America [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137004.mp4', 'http://gstaticontent.com/images/cTJYU7lpFbrz5hoIQugGBDEdezy_big.jpg'),
(43172, 2974, 'Mrs America [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137005.mp4', 'http://gstaticontent.com/images/cTJYU7lpFbrz5hoIQugGBDEdezy_big.jpg'),
(43173, 2974, 'Mrs America [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137006.mp4', 'http://gstaticontent.com/images/cTJYU7lpFbrz5hoIQugGBDEdezy_big.jpg'),
(43174, 2974, 'Mrs America [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137007.mp4', 'http://gstaticontent.com/images/cTJYU7lpFbrz5hoIQugGBDEdezy_big.jpg'),
(43175, 2974, 'Mrs America [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137008.mp4', 'http://gstaticontent.com/images/cTJYU7lpFbrz5hoIQugGBDEdezy_big.jpg'),
(43176, 2975, 'Night Stalker: Tortura e Terror S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136996.mp4', 'http://gstaticontent.com/images/fOX6cKsDSCRKrDCk4vWFv2MgzM3_big.jpg'),
(43177, 2975, 'Night Stalker: Tortura e Terror S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136997.mp4', 'http://gstaticontent.com/images/fOX6cKsDSCRKrDCk4vWFv2MgzM3_big.jpg'),
(43178, 2975, 'Night Stalker: Tortura e Terror S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136998.mp4', 'http://gstaticontent.com/images/fOX6cKsDSCRKrDCk4vWFv2MgzM3_big.jpg'),
(43179, 2975, 'Night Stalker: Tortura e Terror S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136999.mp4', 'http://gstaticontent.com/images/fOX6cKsDSCRKrDCk4vWFv2MgzM3_big.jpg'),
(43180, 2976, 'O Dono do Lar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43181, 2976, 'O Dono do Lar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43182, 2976, 'O Dono do Lar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43183, 2976, 'O Dono do Lar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43184, 2976, 'O Dono do Lar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43185, 2976, 'O Dono do Lar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43186, 2976, 'O Dono do Lar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43187, 2976, 'O Dono do Lar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43188, 2976, 'O Dono do Lar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43189, 2976, 'O Dono do Lar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43190, 2977, 'O Dono do Lar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43191, 2977, 'O Dono do Lar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43192, 2977, 'O Dono do Lar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43193, 2977, 'O Dono do Lar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43194, 2977, 'O Dono do Lar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43195, 2977, 'O Dono do Lar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43196, 2977, 'O Dono do Lar S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43197, 2977, 'O Dono do Lar S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43198, 2977, 'O Dono do Lar S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43199, 2977, 'O Dono do Lar S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43200, 2978, 'O Dono do Lar S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43201, 2978, 'O Dono do Lar S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43202, 2978, 'O Dono do Lar S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43203, 2978, 'O Dono do Lar S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43204, 2978, 'O Dono do Lar S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43205, 2978, 'O Dono do Lar S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43206, 2978, 'O Dono do Lar S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43207, 2978, 'O Dono do Lar S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43208, 2978, 'O Dono do Lar S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43209, 2978, 'O Dono do Lar S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43210, 2978, 'O Dono do Lar S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43211, 2978, 'O Dono do Lar S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43212, 2978, 'O Dono do Lar S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43213, 2978, 'O Dono do Lar S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43214, 2978, 'O Dono do Lar S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43215, 2978, 'O Dono do Lar S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43216, 2978, 'O Dono do Lar S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43217, 2978, 'O Dono do Lar S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43218, 2978, 'O Dono do Lar S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43219, 2978, 'O Dono do Lar S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43220, 2979, 'O Dono do Lar S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43221, 2979, 'O Dono do Lar S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43222, 2979, 'O Dono do Lar S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43223, 2979, 'O Dono do Lar S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43224, 2979, 'O Dono do Lar S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43225, 2979, 'O Dono do Lar S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43226, 2979, 'O Dono do Lar S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43227, 2979, 'O Dono do Lar S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43228, 2979, 'O Dono do Lar S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43229, 2979, 'O Dono do Lar S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43230, 2979, 'O Dono do Lar S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43231, 2979, 'O Dono do Lar S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43232, 2979, 'O Dono do Lar S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43233, 2979, 'O Dono do Lar S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43234, 2979, 'O Dono do Lar S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43235, 2979, 'O Dono do Lar S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43236, 2979, 'O Dono do Lar S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43237, 2979, 'O Dono do Lar S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43238, 2979, 'O Dono do Lar S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43239, 2979, 'O Dono do Lar S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43240, 2980, 'O Dono do Lar S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43241, 2980, 'O Dono do Lar S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43242, 2980, 'O Dono do Lar S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43243, 2980, 'O Dono do Lar S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43244, 2980, 'O Dono do Lar S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43245, 2980, 'O Dono do Lar S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43246, 2980, 'O Dono do Lar S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43247, 2980, 'O Dono do Lar S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43248, 2980, 'O Dono do Lar S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43249, 2980, 'O Dono do Lar S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43250, 2980, 'O Dono do Lar S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43251, 2980, 'O Dono do Lar S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43252, 2980, 'O Dono do Lar S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43253, 2980, 'O Dono do Lar S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43254, 2980, 'O Dono do Lar S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43255, 2980, 'O Dono do Lar S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43256, 2980, 'O Dono do Lar S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43257, 2980, 'O Dono do Lar S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43258, 2980, 'O Dono do Lar S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43259, 2980, 'O Dono do Lar S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43260, 2981, 'O Dono do Lar S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43261, 2981, 'O Dono do Lar S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43262, 2981, 'O Dono do Lar S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43263, 2981, 'O Dono do Lar S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43264, 2981, 'O Dono do Lar S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43265, 2981, 'O Dono do Lar S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43266, 2981, 'O Dono do Lar S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43267, 2981, 'O Dono do Lar S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43268, 2981, 'O Dono do Lar S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43269, 2981, 'O Dono do Lar S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43270, 2981, 'O Dono do Lar S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43271, 2981, 'O Dono do Lar S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43272, 2981, 'O Dono do Lar S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(43273, 2981, 'O Dono do Lar S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43274, 2981, 'O Dono do Lar S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43275, 2981, 'O Dono do Lar S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43276, 2981, 'O Dono do Lar S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43277, 2981, 'O Dono do Lar S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43278, 2981, 'O Dono do Lar S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43279, 2981, 'O Dono do Lar S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43280, 2982, 'O Dono do Lar S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/338500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43281, 2982, 'O Dono do Lar S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/338501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43282, 2982, 'O Dono do Lar S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/338502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43283, 2982, 'O Dono do Lar S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/338503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43284, 2982, 'O Dono do Lar S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/338504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43285, 2982, 'O Dono do Lar S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/340833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43286, 2982, 'O Dono do Lar S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/340834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43287, 2982, 'O Dono do Lar S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/345040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43288, 2982, 'O Dono do Lar S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/345041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43289, 2982, 'O Dono do Lar S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/345042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43290, 2982, 'O Dono do Lar S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/356225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43291, 2982, 'O Dono do Lar S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/356226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43292, 2982, 'O Dono do Lar S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/356227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43293, 2982, 'O Dono do Lar S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/356228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43294, 2982, 'O Dono do Lar S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/356229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43295, 2982, 'O Dono do Lar S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/356230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43296, 2982, 'O Dono do Lar S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/356231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43297, 2982, 'O Dono do Lar S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/356232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43298, 2982, 'O Dono do Lar S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/356233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43299, 2982, 'O Dono do Lar S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/356234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43300, 2983, 'O Dono do Lar S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/893462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43301, 2983, 'O Dono do Lar S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/893572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43302, 2983, 'O Dono do Lar S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/893573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43303, 2983, 'O Dono do Lar S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/893574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43304, 2983, 'O Dono do Lar S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/894209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43305, 2983, 'O Dono do Lar S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/894210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43306, 2983, 'O Dono do Lar S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/894878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43307, 2983, 'O Dono do Lar S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/894879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43308, 2983, 'O Dono do Lar S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/894880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43309, 2983, 'O Dono do Lar S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/895869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43310, 2983, 'O Dono do Lar S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/895870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43311, 2983, 'O Dono do Lar S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/895871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43312, 2983, 'O Dono do Lar S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/895872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43313, 2983, 'O Dono do Lar S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/896217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43314, 2983, 'O Dono do Lar S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/896471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43315, 2983, 'O Dono do Lar S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/896472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43316, 2983, 'O Dono do Lar S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/896473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43317, 2983, 'O Dono do Lar S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/896662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43318, 2983, 'O Dono do Lar S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/896663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43319, 2983, 'O Dono do Lar S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/897440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipbiev4I2ZSO1buIn7fn5rp6QAc.jpg'),
(43320, 2984, 'Pretend Its a City [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136989.mp4', 'http://gstaticontent.com/images/ltD9Y5p17TKqvVrDfTfZdPPcw57_big.jpg'),
(43321, 2984, 'Pretend Its a City [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136990.mp4', 'http://gstaticontent.com/images/ltD9Y5p17TKqvVrDfTfZdPPcw57_big.jpg'),
(43322, 2984, 'Pretend Its a City [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136991.mp4', 'http://gstaticontent.com/images/ltD9Y5p17TKqvVrDfTfZdPPcw57_big.jpg'),
(43323, 2984, 'Pretend Its a City [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136992.mp4', 'http://gstaticontent.com/images/ltD9Y5p17TKqvVrDfTfZdPPcw57_big.jpg'),
(43324, 2984, 'Pretend Its a City [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136993.mp4', 'http://gstaticontent.com/images/ltD9Y5p17TKqvVrDfTfZdPPcw57_big.jpg'),
(43325, 2984, 'Pretend Its a City [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136994.mp4', 'http://gstaticontent.com/images/ltD9Y5p17TKqvVrDfTfZdPPcw57_big.jpg'),
(43326, 2984, 'Pretend Its a City [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136995.mp4', 'http://gstaticontent.com/images/ltD9Y5p17TKqvVrDfTfZdPPcw57_big.jpg'),
(43327, 2985, 'Red Oaks S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136963.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43328, 2985, 'Red Oaks S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136964.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43329, 2985, 'Red Oaks S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136965.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43330, 2985, 'Red Oaks S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136966.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43331, 2985, 'Red Oaks S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136967.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43332, 2985, 'Red Oaks S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136968.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43333, 2985, 'Red Oaks S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136969.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43334, 2985, 'Red Oaks S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136970.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43335, 2985, 'Red Oaks S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136971.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43336, 2985, 'Red Oaks S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136972.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43337, 2986, 'Red Oaks S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136973.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43338, 2986, 'Red Oaks S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136974.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43339, 2986, 'Red Oaks S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136975.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43340, 2986, 'Red Oaks S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136976.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43341, 2986, 'Red Oaks S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136977.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43342, 2986, 'Red Oaks S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136978.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43343, 2986, 'Red Oaks S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136979.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43344, 2986, 'Red Oaks S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136980.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43345, 2986, 'Red Oaks S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136981.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43346, 2986, 'Red Oaks S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136982.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43347, 2987, 'Red Oaks S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136983.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43348, 2987, 'Red Oaks S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136984.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43349, 2987, 'Red Oaks S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136985.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43350, 2987, 'Red Oaks S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136986.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43351, 2987, 'Red Oaks S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136987.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43352, 2987, 'Red Oaks S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136988.mp4', 'http://gstaticontent.com/images/jGI54TyocVBOAAfPmq8sytJGxeG_big.jpg'),
(43353, 2988, 'Ruas Mundo Afora S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142197.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43354, 2988, 'Ruas Mundo Afora S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142198.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43355, 2988, 'Ruas Mundo Afora S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142199.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43356, 2988, 'Ruas Mundo Afora S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142200.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43357, 2988, 'Ruas Mundo Afora S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142201.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43358, 2988, 'Ruas Mundo Afora S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142202.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43359, 2988, 'Ruas Mundo Afora S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142203.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43360, 2988, 'Ruas Mundo Afora S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142204.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43361, 2988, 'Ruas Mundo Afora S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142205.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43362, 2988, 'Ruas Mundo Afora S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142206.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43363, 2988, 'Ruas Mundo Afora S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142207.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43364, 2988, 'Ruas Mundo Afora S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142208.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43365, 2988, 'Ruas Mundo Afora S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142209.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43366, 2988, 'Ruas Mundo Afora S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/142210.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43367, 2988, 'Ruas Mundo Afora S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142211.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43368, 2988, 'Ruas Mundo Afora S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/142212.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43369, 2988, 'Ruas Mundo Afora S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/142213.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43370, 2988, 'Ruas Mundo Afora S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/142214.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43371, 2988, 'Ruas Mundo Afora S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/142215.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43372, 2988, 'Ruas Mundo Afora S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/142216.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43373, 2988, 'Ruas Mundo Afora S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/142217.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43374, 2988, 'Ruas Mundo Afora S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/142218.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43375, 2988, 'Ruas Mundo Afora S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/142219.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43376, 2988, 'Ruas Mundo Afora S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/142220.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43377, 2988, 'Ruas Mundo Afora S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/142221.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43378, 2988, 'Ruas Mundo Afora S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/142222.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43379, 2988, 'Ruas Mundo Afora S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/142223.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43380, 2988, 'Ruas Mundo Afora S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/142224.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43381, 2988, 'Ruas Mundo Afora S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/142225.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43382, 2988, 'Ruas Mundo Afora S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/142226.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43383, 2988, 'Ruas Mundo Afora S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/142227.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43384, 2988, 'Ruas Mundo Afora S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/142228.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43385, 2988, 'Ruas Mundo Afora S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/142229.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43386, 2988, 'Ruas Mundo Afora S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/142230.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43387, 2988, 'Ruas Mundo Afora S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/142231.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43388, 2988, 'Ruas Mundo Afora S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/142232.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43389, 2988, 'Ruas Mundo Afora S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/142233.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43390, 2988, 'Ruas Mundo Afora S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/142234.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43391, 2988, 'Ruas Mundo Afora S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/142235.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43392, 2988, 'Ruas Mundo Afora S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/142236.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43393, 2988, 'Ruas Mundo Afora S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/142237.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43394, 2988, 'Ruas Mundo Afora S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/142238.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43395, 2988, 'Ruas Mundo Afora S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/142239.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43396, 2988, 'Ruas Mundo Afora S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/142240.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43397, 2988, 'Ruas Mundo Afora S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/142241.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43398, 2988, 'Ruas Mundo Afora S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/142242.mp4', 'https://i.bj-share.info/8643531c19cab8891c17cee046ef044b.jpg'),
(43399, 2989, 'Sakho Mangane [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136955.mp4', 'http://gstaticontent.com/images/vGIo0ONq8wYqU7bLmiXJahtGgBv_big.jpg'),
(43400, 2989, 'Sakho Mangane [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136956.mp4', 'http://gstaticontent.com/images/vGIo0ONq8wYqU7bLmiXJahtGgBv_big.jpg'),
(43401, 2989, 'Sakho Mangane [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136957.mp4', 'http://gstaticontent.com/images/vGIo0ONq8wYqU7bLmiXJahtGgBv_big.jpg'),
(43402, 2989, 'Sakho Mangane [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136958.mp4', 'http://gstaticontent.com/images/vGIo0ONq8wYqU7bLmiXJahtGgBv_big.jpg'),
(43403, 2989, 'Sakho Mangane [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136959.mp4', 'http://gstaticontent.com/images/vGIo0ONq8wYqU7bLmiXJahtGgBv_big.jpg'),
(43404, 2989, 'Sakho Mangane [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136960.mp4', 'http://gstaticontent.com/images/vGIo0ONq8wYqU7bLmiXJahtGgBv_big.jpg'),
(43405, 2989, 'Sakho Mangane [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136961.mp4', 'http://gstaticontent.com/images/vGIo0ONq8wYqU7bLmiXJahtGgBv_big.jpg'),
(43406, 2989, 'Sakho Mangane [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136962.mp4', 'http://gstaticontent.com/images/vGIo0ONq8wYqU7bLmiXJahtGgBv_big.jpg'),
(43407, 2990, 'Seinfeld S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144082.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43408, 2990, 'Seinfeld S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144083.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43409, 2990, 'Seinfeld S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144084.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43410, 2990, 'Seinfeld S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144085.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43411, 2990, 'Seinfeld S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144086.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43412, 2991, 'Seinfeld S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144087.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43413, 2991, 'Seinfeld S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144088.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43414, 2991, 'Seinfeld S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144089.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43415, 2991, 'Seinfeld S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144090.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43416, 2991, 'Seinfeld S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144091.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43417, 2991, 'Seinfeld S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144092.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43418, 2991, 'Seinfeld S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144093.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43419, 2991, 'Seinfeld S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144094.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43420, 2991, 'Seinfeld S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144095.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43421, 2991, 'Seinfeld S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144096.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43422, 2991, 'Seinfeld S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144097.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43423, 2991, 'Seinfeld S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144098.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43424, 2992, 'Seinfeld S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144099.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43425, 2992, 'Seinfeld S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144100.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43426, 2992, 'Seinfeld S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144101.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43427, 2992, 'Seinfeld S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144102.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43428, 2992, 'Seinfeld S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144103.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43429, 2992, 'Seinfeld S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144104.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43430, 2992, 'Seinfeld S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144105.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43431, 2992, 'Seinfeld S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144106.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43432, 2992, 'Seinfeld S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144107.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43433, 2992, 'Seinfeld S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144108.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43434, 2992, 'Seinfeld S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144109.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43435, 2992, 'Seinfeld S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144110.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43436, 2992, 'Seinfeld S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144111.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43437, 2992, 'Seinfeld S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144112.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43438, 2992, 'Seinfeld S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144113.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43439, 2992, 'Seinfeld S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144114.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43440, 2992, 'Seinfeld S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144115.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43441, 2992, 'Seinfeld S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/885630.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43442, 2992, 'Seinfeld S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/144116.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43443, 2992, 'Seinfeld S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144117.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43444, 2992, 'Seinfeld S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/144118.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43445, 2992, 'Seinfeld S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/144119.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43446, 2992, 'Seinfeld S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/144120.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43447, 2993, 'Seinfeld S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144121.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43448, 2993, 'Seinfeld S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144122.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43449, 2993, 'Seinfeld S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144123.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43450, 2993, 'Seinfeld S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/885631.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43451, 2993, 'Seinfeld S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144124.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43452, 2993, 'Seinfeld S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144125.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43453, 2993, 'Seinfeld S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144126.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43454, 2993, 'Seinfeld S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144127.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43455, 2993, 'Seinfeld S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144128.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43456, 2993, 'Seinfeld S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144129.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43457, 2993, 'Seinfeld S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144130.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43458, 2993, 'Seinfeld S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144131.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43459, 2993, 'Seinfeld S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144132.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43460, 2993, 'Seinfeld S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144133.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43461, 2993, 'Seinfeld S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144134.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43462, 2993, 'Seinfeld S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144135.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43463, 2993, 'Seinfeld S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144136.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43464, 2993, 'Seinfeld S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/144137.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43465, 2993, 'Seinfeld S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/144138.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43466, 2993, 'Seinfeld S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144139.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43467, 2993, 'Seinfeld S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/144140.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43468, 2993, 'Seinfeld S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/144141.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43469, 2993, 'Seinfeld S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/144142.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43470, 2994, 'Seinfeld S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144143.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43471, 2994, 'Seinfeld S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144144.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43472, 2994, 'Seinfeld S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144145.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43473, 2994, 'Seinfeld S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144146.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43474, 2994, 'Seinfeld S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144147.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43475, 2994, 'Seinfeld S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144148.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43476, 2994, 'Seinfeld S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144149.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43477, 2994, 'Seinfeld S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144150.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43478, 2994, 'Seinfeld S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144151.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43479, 2994, 'Seinfeld S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144152.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43480, 2994, 'Seinfeld S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144153.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43481, 2994, 'Seinfeld S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144154.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43482, 2994, 'Seinfeld S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144155.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43483, 2994, 'Seinfeld S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144156.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43484, 2994, 'Seinfeld S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144157.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43485, 2994, 'Seinfeld S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144158.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43486, 2994, 'Seinfeld S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144159.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43487, 2994, 'Seinfeld S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/144160.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43488, 2994, 'Seinfeld S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/885632.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43489, 2994, 'Seinfeld S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144161.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43490, 2994, 'Seinfeld S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/144162.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43491, 2994, 'Seinfeld S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/144163.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43492, 2995, 'Seinfeld S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144164.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43493, 2995, 'Seinfeld S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144165.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43494, 2995, 'Seinfeld S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144166.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43495, 2995, 'Seinfeld S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144167.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43496, 2995, 'Seinfeld S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144168.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43497, 2995, 'Seinfeld S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144169.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43498, 2995, 'Seinfeld S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144170.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43499, 2995, 'Seinfeld S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144171.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43500, 2995, 'Seinfeld S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144172.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43501, 2995, 'Seinfeld S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144173.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43502, 2995, 'Seinfeld S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144174.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43503, 2995, 'Seinfeld S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144175.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43504, 2995, 'Seinfeld S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144176.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43505, 2995, 'Seinfeld S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144177.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43506, 2995, 'Seinfeld S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/885633.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43507, 2995, 'Seinfeld S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144178.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43508, 2995, 'Seinfeld S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144179.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43509, 2995, 'Seinfeld S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/144180.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43510, 2995, 'Seinfeld S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/144181.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43511, 2995, 'Seinfeld S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144182.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43512, 2995, 'Seinfeld S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/144183.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43513, 2995, 'Seinfeld S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/144184.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43514, 2995, 'Seinfeld S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/144185.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43515, 2995, 'Seinfeld S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/144186.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43516, 2996, 'Seinfeld S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144187.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43517, 2996, 'Seinfeld S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144188.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43518, 2996, 'Seinfeld S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144189.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43519, 2996, 'Seinfeld S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144190.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43520, 2996, 'Seinfeld S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144191.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43521, 2996, 'Seinfeld S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144192.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43522, 2996, 'Seinfeld S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144193.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43523, 2996, 'Seinfeld S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144194.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43524, 2996, 'Seinfeld S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144195.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43525, 2996, 'Seinfeld S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144196.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43526, 2996, 'Seinfeld S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144197.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43527, 2996, 'Seinfeld S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144198.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43528, 2996, 'Seinfeld S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144199.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43529, 2996, 'Seinfeld S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144200.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43530, 2996, 'Seinfeld S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/885634.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43531, 2996, 'Seinfeld S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144201.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43532, 2996, 'Seinfeld S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144202.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43533, 2996, 'Seinfeld S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/144203.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43534, 2996, 'Seinfeld S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/144204.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43535, 2996, 'Seinfeld S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144205.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43536, 2996, 'Seinfeld S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/144206.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43537, 2996, 'Seinfeld S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/885635.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43538, 2996, 'Seinfeld S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/144207.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43539, 2996, 'Seinfeld S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/144208.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43540, 2997, 'Seinfeld S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144209.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43541, 2997, 'Seinfeld S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144210.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43542, 2997, 'Seinfeld S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144211.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43543, 2997, 'Seinfeld S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144212.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43544, 2997, 'Seinfeld S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144213.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43545, 2997, 'Seinfeld S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144214.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43546, 2997, 'Seinfeld S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144215.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43547, 2997, 'Seinfeld S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144216.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43548, 2997, 'Seinfeld S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144217.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43549, 2997, 'Seinfeld S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144218.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43550, 2997, 'Seinfeld S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144219.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43551, 2997, 'Seinfeld S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144220.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43552, 2997, 'Seinfeld S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144221.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43553, 2997, 'Seinfeld S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144222.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43554, 2997, 'Seinfeld S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144223.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43555, 2997, 'Seinfeld S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144224.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43556, 2997, 'Seinfeld S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144225.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43557, 2997, 'Seinfeld S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/144226.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43558, 2997, 'Seinfeld S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/144227.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43559, 2997, 'Seinfeld S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144228.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43560, 2997, 'Seinfeld S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/144229.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43561, 2997, 'Seinfeld S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/144230.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(43562, 2998, 'Seinfeld S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144231.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43563, 2998, 'Seinfeld S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144232.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43564, 2998, 'Seinfeld S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144233.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43565, 2998, 'Seinfeld S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144234.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43566, 2998, 'Seinfeld S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144235.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43567, 2998, 'Seinfeld S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144236.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43568, 2998, 'Seinfeld S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144237.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43569, 2998, 'Seinfeld S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144238.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43570, 2998, 'Seinfeld S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144239.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43571, 2998, 'Seinfeld S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144240.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43572, 2998, 'Seinfeld S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144241.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43573, 2998, 'Seinfeld S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144242.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43574, 2998, 'Seinfeld S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144243.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43575, 2998, 'Seinfeld S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144244.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43576, 2998, 'Seinfeld S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144245.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43577, 2998, 'Seinfeld S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144246.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43578, 2998, 'Seinfeld S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144247.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43579, 2998, 'Seinfeld S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/144248.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43580, 2998, 'Seinfeld S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/144249.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43581, 2998, 'Seinfeld S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144250.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43582, 2998, 'Seinfeld S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/144251.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43583, 2998, 'Seinfeld S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/144252.mp4', 'http://gstaticontent.com/images/u3mFyqIprL5ou8Ue04Ecac6iDi7_big.jpg'),
(43584, 2999, 'The Serpent [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136947.mp4', 'http://gstaticontent.com/images/mZve7vS8S7nyYMIJ5rJrjzOGwAZ_big.jpg'),
(43585, 2999, 'The Serpent [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136948.mp4', 'http://gstaticontent.com/images/mZve7vS8S7nyYMIJ5rJrjzOGwAZ_big.jpg'),
(43586, 2999, 'The Serpent [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136949.mp4', 'http://gstaticontent.com/images/mZve7vS8S7nyYMIJ5rJrjzOGwAZ_big.jpg'),
(43587, 2999, 'The Serpent [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136950.mp4', 'http://gstaticontent.com/images/mZve7vS8S7nyYMIJ5rJrjzOGwAZ_big.jpg'),
(43588, 2999, 'The Serpent [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136951.mp4', 'http://gstaticontent.com/images/mZve7vS8S7nyYMIJ5rJrjzOGwAZ_big.jpg'),
(43589, 2999, 'The Serpent [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136952.mp4', 'http://gstaticontent.com/images/mZve7vS8S7nyYMIJ5rJrjzOGwAZ_big.jpg'),
(43590, 2999, 'The Serpent [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136953.mp4', 'http://gstaticontent.com/images/mZve7vS8S7nyYMIJ5rJrjzOGwAZ_big.jpg'),
(43591, 2999, 'The Serpent [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136954.mp4', 'http://gstaticontent.com/images/mZve7vS8S7nyYMIJ5rJrjzOGwAZ_big.jpg'),
(43592, 3000, 'The Stand S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134946.mp4', 'http://gstaticontent.com/images/w6XiuRK5QQaLNmIqDRCWOpEcHwi_big.jpg'),
(43593, 3000, 'The Stand S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134947.mp4', 'http://gstaticontent.com/images/w6XiuRK5QQaLNmIqDRCWOpEcHwi_big.jpg'),
(43594, 3000, 'The Stand S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134948.mp4', 'http://gstaticontent.com/images/w6XiuRK5QQaLNmIqDRCWOpEcHwi_big.jpg'),
(43595, 3000, 'The Stand S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134949.mp4', 'http://gstaticontent.com/images/w6XiuRK5QQaLNmIqDRCWOpEcHwi_big.jpg'),
(43596, 3000, 'The Stand S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134950.mp4', 'http://gstaticontent.com/images/w6XiuRK5QQaLNmIqDRCWOpEcHwi_big.jpg'),
(43597, 3000, 'The Stand S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134951.mp4', 'http://gstaticontent.com/images/w6XiuRK5QQaLNmIqDRCWOpEcHwi_big.jpg'),
(43598, 3000, 'The Stand S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134952.mp4', 'http://gstaticontent.com/images/w6XiuRK5QQaLNmIqDRCWOpEcHwi_big.jpg'),
(43599, 3000, 'The Stand S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134953.mp4', 'http://gstaticontent.com/images/w6XiuRK5QQaLNmIqDRCWOpEcHwi_big.jpg'),
(43600, 3000, 'The Stand S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/134954.mp4', 'http://gstaticontent.com/images/w6XiuRK5QQaLNmIqDRCWOpEcHwi_big.jpg'),
(43601, 3001, 'When My Love Blooms [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136931.mp4', 'http://gstaticontent.com/images/2NhS5ucmKrRIBlvy6XNuDAHyVDO_big.jpg'),
(43602, 3001, 'When My Love Blooms [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136932.mp4', 'http://gstaticontent.com/images/2NhS5ucmKrRIBlvy6XNuDAHyVDO_big.jpg'),
(43603, 3001, 'When My Love Blooms [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136933.mp4', 'http://gstaticontent.com/images/2NhS5ucmKrRIBlvy6XNuDAHyVDO_big.jpg'),
(43604, 3001, 'When My Love Blooms [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136934.mp4', 'http://gstaticontent.com/images/2NhS5ucmKrRIBlvy6XNuDAHyVDO_big.jpg'),
(43605, 3001, 'When My Love Blooms [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136935.mp4', 'http://gstaticontent.com/images/2NhS5ucmKrRIBlvy6XNuDAHyVDO_big.jpg'),
(43606, 3001, 'When My Love Blooms [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136936.mp4', 'http://gstaticontent.com/images/2NhS5ucmKrRIBlvy6XNuDAHyVDO_big.jpg'),
(43607, 3001, 'When My Love Blooms [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136937.mp4', 'http://gstaticontent.com/images/2NhS5ucmKrRIBlvy6XNuDAHyVDO_big.jpg'),
(43608, 3001, 'When My Love Blooms [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136938.mp4', 'http://gstaticontent.com/images/2NhS5ucmKrRIBlvy6XNuDAHyVDO_big.jpg'),
(43609, 3001, 'When My Love Blooms [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136939.mp4', 'http://gstaticontent.com/images/2NhS5ucmKrRIBlvy6XNuDAHyVDO_big.jpg'),
(43610, 3001, 'When My Love Blooms [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136940.mp4', 'http://gstaticontent.com/images/2NhS5ucmKrRIBlvy6XNuDAHyVDO_big.jpg'),
(43611, 3001, 'When My Love Blooms [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136941.mp4', 'http://gstaticontent.com/images/2NhS5ucmKrRIBlvy6XNuDAHyVDO_big.jpg'),
(43612, 3001, 'When My Love Blooms [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136942.mp4', 'http://gstaticontent.com/images/2NhS5ucmKrRIBlvy6XNuDAHyVDO_big.jpg'),
(43613, 3001, 'When My Love Blooms [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136943.mp4', 'http://gstaticontent.com/images/2NhS5ucmKrRIBlvy6XNuDAHyVDO_big.jpg'),
(43614, 3001, 'When My Love Blooms [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/136944.mp4', 'http://gstaticontent.com/images/2NhS5ucmKrRIBlvy6XNuDAHyVDO_big.jpg'),
(43615, 3001, 'When My Love Blooms [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/136945.mp4', 'http://gstaticontent.com/images/2NhS5ucmKrRIBlvy6XNuDAHyVDO_big.jpg'),
(43616, 3001, 'When My Love Blooms [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/136946.mp4', 'http://gstaticontent.com/images/2NhS5ucmKrRIBlvy6XNuDAHyVDO_big.jpg'),
(43617, 3002, 'WandaVision S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141721.mp4', 'http://gstaticontent.com/images/cm5xwxoWl2ZWuCKzwa0umHHsbmI_big.jpg'),
(43618, 3002, 'WandaVision S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141722.mp4', 'http://gstaticontent.com/images/cm5xwxoWl2ZWuCKzwa0umHHsbmI_big.jpg'),
(43619, 3002, 'WandaVision S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141723.mp4', 'http://gstaticontent.com/images/cm5xwxoWl2ZWuCKzwa0umHHsbmI_big.jpg'),
(43620, 3002, 'WandaVision S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141724.mp4', 'http://gstaticontent.com/images/cm5xwxoWl2ZWuCKzwa0umHHsbmI_big.jpg'),
(43621, 3002, 'WandaVision S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141725.mp4', 'http://gstaticontent.com/images/cm5xwxoWl2ZWuCKzwa0umHHsbmI_big.jpg'),
(43622, 3002, 'WandaVision S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141726.mp4', 'http://gstaticontent.com/images/cm5xwxoWl2ZWuCKzwa0umHHsbmI_big.jpg'),
(43623, 3002, 'WandaVision S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141727.mp4', 'http://gstaticontent.com/images/cm5xwxoWl2ZWuCKzwa0umHHsbmI_big.jpg'),
(43624, 3002, 'WandaVision S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141728.mp4', 'http://gstaticontent.com/images/cm5xwxoWl2ZWuCKzwa0umHHsbmI_big.jpg'),
(43625, 3002, 'WandaVision S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141729.mp4', 'http://timg.bdta.pro/images/jBWcxrPR2SlxPyt5jMQa1vZWF66_small.jpg'),
(43626, 3003, 'A Peste S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138924.mp4', 'http://gstaticontent.com/images/lMv9BfXtClkvjWk2yFL2JyuKXLt_big.jpg'),
(43627, 3003, 'A Peste S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138925.mp4', 'http://gstaticontent.com/images/lMv9BfXtClkvjWk2yFL2JyuKXLt_big.jpg'),
(43628, 3003, 'A Peste S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138926.mp4', 'http://gstaticontent.com/images/lMv9BfXtClkvjWk2yFL2JyuKXLt_big.jpg'),
(43629, 3003, 'A Peste S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138927.mp4', 'http://gstaticontent.com/images/lMv9BfXtClkvjWk2yFL2JyuKXLt_big.jpg'),
(43630, 3003, 'A Peste S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138928.mp4', 'http://gstaticontent.com/images/lMv9BfXtClkvjWk2yFL2JyuKXLt_big.jpg'),
(43631, 3003, 'A Peste S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138929.mp4', 'http://gstaticontent.com/images/lMv9BfXtClkvjWk2yFL2JyuKXLt_big.jpg'),
(43632, 3004, 'A Peste S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138930.mp4', 'http://gstaticontent.com/images/lMv9BfXtClkvjWk2yFL2JyuKXLt_big.jpg'),
(43633, 3004, 'A Peste S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138931.mp4', 'http://gstaticontent.com/images/lMv9BfXtClkvjWk2yFL2JyuKXLt_big.jpg'),
(43634, 3004, 'A Peste S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138932.mp4', 'http://gstaticontent.com/images/lMv9BfXtClkvjWk2yFL2JyuKXLt_big.jpg'),
(43635, 3004, 'A Peste S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138933.mp4', 'http://gstaticontent.com/images/lMv9BfXtClkvjWk2yFL2JyuKXLt_big.jpg'),
(43636, 3004, 'A Peste S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138934.mp4', 'http://gstaticontent.com/images/lMv9BfXtClkvjWk2yFL2JyuKXLt_big.jpg'),
(43637, 3004, 'A Peste S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138935.mp4', 'http://gstaticontent.com/images/lMv9BfXtClkvjWk2yFL2JyuKXLt_big.jpg'),
(43638, 3005, 'A Pior das Bruxas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136437.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43639, 3005, 'A Pior das Bruxas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136438.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43640, 3005, 'A Pior das Bruxas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136439.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43641, 3005, 'A Pior das Bruxas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136440.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43642, 3005, 'A Pior das Bruxas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136441.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43643, 3005, 'A Pior das Bruxas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136442.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43644, 3005, 'A Pior das Bruxas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136443.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43645, 3005, 'A Pior das Bruxas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136444.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43646, 3005, 'A Pior das Bruxas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136445.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43647, 3005, 'A Pior das Bruxas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136446.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43648, 3005, 'A Pior das Bruxas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136447.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43649, 3005, 'A Pior das Bruxas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136448.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43650, 3006, 'A Pior das Bruxas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136449.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43651, 3006, 'A Pior das Bruxas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136450.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43652, 3006, 'A Pior das Bruxas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136451.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43653, 3006, 'A Pior das Bruxas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136452.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43654, 3006, 'A Pior das Bruxas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136453.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43655, 3006, 'A Pior das Bruxas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136454.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43656, 3006, 'A Pior das Bruxas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136455.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43657, 3006, 'A Pior das Bruxas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136456.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43658, 3006, 'A Pior das Bruxas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136457.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43659, 3006, 'A Pior das Bruxas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136458.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43660, 3006, 'A Pior das Bruxas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136459.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43661, 3006, 'A Pior das Bruxas S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136460.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43662, 3006, 'A Pior das Bruxas S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136461.mp4', 'http://gstaticontent.com/images/fLhJKgPKeBsQaSe0i7VOnRQl37r_big.jpg'),
(43663, 3007, 'Ana S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223442.mp4', 'http://gstaticontent.com/images/qWd7o05ioAjEzJgWH3C0xn0F9l3_big.jpg'),
(43664, 3007, 'Ana S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223443.mp4', 'http://gstaticontent.com/images/qWd7o05ioAjEzJgWH3C0xn0F9l3_big.jpg'),
(43665, 3007, 'Ana S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223444.mp4', 'http://gstaticontent.com/images/qWd7o05ioAjEzJgWH3C0xn0F9l3_big.jpg'),
(43666, 3007, 'Ana S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223445.mp4', 'http://gstaticontent.com/images/qWd7o05ioAjEzJgWH3C0xn0F9l3_big.jpg'),
(43667, 3007, 'Ana S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223446.mp4', 'http://gstaticontent.com/images/qWd7o05ioAjEzJgWH3C0xn0F9l3_big.jpg'),
(43668, 3007, 'Ana S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223447.mp4', 'http://gstaticontent.com/images/qWd7o05ioAjEzJgWH3C0xn0F9l3_big.jpg'),
(43669, 3007, 'Ana S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223448.mp4', 'http://gstaticontent.com/images/qWd7o05ioAjEzJgWH3C0xn0F9l3_big.jpg'),
(43670, 3007, 'Ana S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223449.mp4', 'http://gstaticontent.com/images/qWd7o05ioAjEzJgWH3C0xn0F9l3_big.jpg'),
(43671, 3007, 'Ana S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223450.mp4', 'http://gstaticontent.com/images/qWd7o05ioAjEzJgWH3C0xn0F9l3_big.jpg'),
(43672, 3007, 'Ana S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223451.mp4', 'http://gstaticontent.com/images/qWd7o05ioAjEzJgWH3C0xn0F9l3_big.jpg'),
(43673, 3008, 'Ana S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223452.mp4', 'http://timg.bdta.pro/images/daef2410aa5dcd15f897387672d0fb32.jpg'),
(43674, 3008, 'Ana S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223453.mp4', 'http://timg.bdta.pro/images/ed397e9467ede8a71847fe2a4ed9abef.jpg'),
(43675, 3008, 'Ana S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223455.mp4', 'http://timg.bdta.pro/images/de47754fe34959d78fe2b0472044be65.jpg'),
(43676, 3008, 'Ana S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223456.mp4', 'http://timg.bdta.pro/images/363422f2152ce44589f3ecd6a7c98af0.jpg'),
(43677, 3008, 'Ana S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223457.mp4', 'http://timg.bdta.pro/images/f450663d53f3b7e5621f3035406d3f94.jpg'),
(43678, 3009, 'Ana S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223458.mp4', 'http://gstaticontent.com/images/qWd7o05ioAjEzJgWH3C0xn0F9l3_big.jpg'),
(43679, 3009, 'Ana S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223459.mp4', 'http://gstaticontent.com/images/qWd7o05ioAjEzJgWH3C0xn0F9l3_big.jpg'),
(43680, 3009, 'Ana S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223460.mp4', 'http://gstaticontent.com/images/qWd7o05ioAjEzJgWH3C0xn0F9l3_big.jpg'),
(43681, 3009, 'Ana S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223461.mp4', 'http://gstaticontent.com/images/qWd7o05ioAjEzJgWH3C0xn0F9l3_big.jpg'),
(43682, 3009, 'Ana S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223462.mp4', 'http://gstaticontent.com/images/qWd7o05ioAjEzJgWH3C0xn0F9l3_big.jpg'),
(43683, 3009, 'Ana S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223463.mp4', 'http://gstaticontent.com/images/qWd7o05ioAjEzJgWH3C0xn0F9l3_big.jpg'),
(43684, 3010, 'Cartas Para Eva S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136462.mp4', 'https://s2.glbimg.com/gdovbEmu-s4tYitY3zSyUG8IIHE=/362x536/https://s2.glbimg.com/r9fvkcajYrBCd8DVOzvMByZDuDw=/i.s3.glbimg.com/v1/AUTH_8b507d480c314f97a3b4b28346d025f5/internal_photos/bs/2021/H/s/DgbPaeTDOVgLO8X8EgMQ/2020-1403-cartas-para-eva-poster.jpg'),
(43685, 3010, 'Cartas Para Eva S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136463.mp4', 'https://s2.glbimg.com/gdovbEmu-s4tYitY3zSyUG8IIHE=/362x536/https://s2.glbimg.com/r9fvkcajYrBCd8DVOzvMByZDuDw=/i.s3.glbimg.com/v1/AUTH_8b507d480c314f97a3b4b28346d025f5/internal_photos/bs/2021/H/s/DgbPaeTDOVgLO8X8EgMQ/2020-1403-cartas-para-eva-poster.jpg'),
(43686, 3010, 'Cartas Para Eva S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136464.mp4', 'https://s2.glbimg.com/gdovbEmu-s4tYitY3zSyUG8IIHE=/362x536/https://s2.glbimg.com/r9fvkcajYrBCd8DVOzvMByZDuDw=/i.s3.glbimg.com/v1/AUTH_8b507d480c314f97a3b4b28346d025f5/internal_photos/bs/2021/H/s/DgbPaeTDOVgLO8X8EgMQ/2020-1403-cartas-para-eva-poster.jpg'),
(43687, 3010, 'Cartas Para Eva S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136465.mp4', 'https://s2.glbimg.com/gdovbEmu-s4tYitY3zSyUG8IIHE=/362x536/https://s2.glbimg.com/r9fvkcajYrBCd8DVOzvMByZDuDw=/i.s3.glbimg.com/v1/AUTH_8b507d480c314f97a3b4b28346d025f5/internal_photos/bs/2021/H/s/DgbPaeTDOVgLO8X8EgMQ/2020-1403-cartas-para-eva-poster.jpg'),
(43688, 3010, 'Cartas Para Eva S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136466.mp4', 'https://s2.glbimg.com/gdovbEmu-s4tYitY3zSyUG8IIHE=/362x536/https://s2.glbimg.com/r9fvkcajYrBCd8DVOzvMByZDuDw=/i.s3.glbimg.com/v1/AUTH_8b507d480c314f97a3b4b28346d025f5/internal_photos/bs/2021/H/s/DgbPaeTDOVgLO8X8EgMQ/2020-1403-cartas-para-eva-poster.jpg'),
(43689, 3011, 'Haven S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136467.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43690, 3011, 'Haven S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136468.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43691, 3011, 'Haven S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136469.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43692, 3011, 'Haven S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136470.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43693, 3011, 'Haven S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136471.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43694, 3011, 'Haven S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136472.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43695, 3011, 'Haven S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136473.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43696, 3011, 'Haven S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136474.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43697, 3011, 'Haven S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136475.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43698, 3011, 'Haven S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136476.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43699, 3011, 'Haven S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136477.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43700, 3011, 'Haven S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136478.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43701, 3011, 'Haven S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136479.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43702, 3012, 'Haven S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136480.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43703, 3012, 'Haven S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136481.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43704, 3012, 'Haven S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136482.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43705, 3012, 'Haven S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136483.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43706, 3012, 'Haven S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136484.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43707, 3012, 'Haven S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136485.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43708, 3012, 'Haven S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136486.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43709, 3012, 'Haven S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136487.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43710, 3012, 'Haven S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136488.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43711, 3012, 'Haven S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136489.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43712, 3012, 'Haven S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136490.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43713, 3012, 'Haven S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136491.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43714, 3012, 'Haven S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136492.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43715, 3013, 'Haven S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136493.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43716, 3013, 'Haven S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136494.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43717, 3013, 'Haven S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136495.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43718, 3013, 'Haven S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136496.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43719, 3013, 'Haven S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136497.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43720, 3013, 'Haven S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136498.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43721, 3013, 'Haven S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136499.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43722, 3013, 'Haven S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136500.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43723, 3013, 'Haven S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136501.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43724, 3013, 'Haven S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136502.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43725, 3013, 'Haven S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136503.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43726, 3013, 'Haven S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136504.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43727, 3013, 'Haven S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136505.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43728, 3014, 'Haven S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136506.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43729, 3014, 'Haven S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136507.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43730, 3014, 'Haven S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136508.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43731, 3014, 'Haven S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136509.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43732, 3014, 'Haven S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136510.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43733, 3014, 'Haven S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136511.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43734, 3014, 'Haven S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136512.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43735, 3014, 'Haven S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136513.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43736, 3014, 'Haven S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136514.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43737, 3014, 'Haven S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136515.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43738, 3014, 'Haven S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136516.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43739, 3014, 'Haven S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136517.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43740, 3014, 'Haven S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136518.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43741, 3015, 'Haven S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136519.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43742, 3015, 'Haven S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136520.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43743, 3015, 'Haven S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136521.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43744, 3015, 'Haven S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136522.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43745, 3015, 'Haven S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136523.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43746, 3015, 'Haven S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136524.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43747, 3015, 'Haven S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136525.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43748, 3015, 'Haven S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136526.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43749, 3015, 'Haven S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136527.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43750, 3015, 'Haven S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136528.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43751, 3015, 'Haven S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136529.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43752, 3015, 'Haven S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136530.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43753, 3015, 'Haven S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136531.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43754, 3015, 'Haven S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/136532.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43755, 3015, 'Haven S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/136533.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43756, 3015, 'Haven S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/136534.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43757, 3015, 'Haven S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/136535.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43758, 3015, 'Haven S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/136536.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43759, 3015, 'Haven S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/136537.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43760, 3015, 'Haven S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/136538.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43761, 3015, 'Haven S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/136539.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43762, 3015, 'Haven S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/136540.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43763, 3015, 'Haven S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/136541.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43764, 3015, 'Haven S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/136542.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43765, 3015, 'Haven S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/136543.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43766, 3015, 'Haven S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/136544.mp4', 'http://gstaticontent.com/images/hvAex9f31tzcA9eNhseHYVR8bsZ_big.jpg'),
(43767, 3016, 'Império da Ostentação S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196382.mp4', 'http://gstaticontent.com/images/cjfy9i5unNnVmH9aG4cE3oDg6NY_big.jpg'),
(43768, 3016, 'Império da Ostentação S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196383.mp4', 'http://gstaticontent.com/images/cjfy9i5unNnVmH9aG4cE3oDg6NY_big.jpg'),
(43769, 3016, 'Império da Ostentação S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196384.mp4', 'http://gstaticontent.com/images/cjfy9i5unNnVmH9aG4cE3oDg6NY_big.jpg'),
(43770, 3016, 'Império da Ostentação S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196385.mp4', 'http://gstaticontent.com/images/cjfy9i5unNnVmH9aG4cE3oDg6NY_big.jpg'),
(43771, 3016, 'Império da Ostentação S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196386.mp4', 'http://gstaticontent.com/images/cjfy9i5unNnVmH9aG4cE3oDg6NY_big.jpg'),
(43772, 3016, 'Império da Ostentação S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196387.mp4', 'http://gstaticontent.com/images/cjfy9i5unNnVmH9aG4cE3oDg6NY_big.jpg'),
(43773, 3016, 'Império da Ostentação S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196388.mp4', 'http://gstaticontent.com/images/cjfy9i5unNnVmH9aG4cE3oDg6NY_big.jpg'),
(43774, 3016, 'Império da Ostentação S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196389.mp4', 'http://gstaticontent.com/images/cjfy9i5unNnVmH9aG4cE3oDg6NY_big.jpg'),
(43775, 3017, 'Império da Ostentação S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196390.mp4', 'http://timg.bdta.pro/images/2d4f46eb219aaa76ae8b423089fcff05.jpg'),
(43776, 3017, 'Império da Ostentação S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196391.mp4', 'http://timg.bdta.pro/images/0db2510994f9d960e065909bd1e25029.jpg'),
(43777, 3017, 'Império da Ostentação S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196392.mp4', 'http://timg.bdta.pro/images/77ed7fb782ea6739b0f6247a4fc6c90d.jpg'),
(43778, 3017, 'Império da Ostentação S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196393.mp4', 'http://timg.bdta.pro/images/b37b810fea3aa5e1955cdde022769b0e.jpg'),
(43779, 3017, 'Império da Ostentação S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196394.mp4', 'http://timg.bdta.pro/images/952cbd473cd924b6492cfd98293dbf83.jpg'),
(43780, 3017, 'Império da Ostentação S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196395.mp4', 'http://timg.bdta.pro/images/2da5bc87cf6a2554a9303adc9295aa01.jpg'),
(43781, 3017, 'Império da Ostentação S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196396.mp4', 'http://timg.bdta.pro/images/309357bf368f9ae7560ec5a28837f3dc.jpg'),
(43782, 3017, 'Império da Ostentação S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196397.mp4', 'http://timg.bdta.pro/images/b681a96478e1296825be9557be82b3b9.jpg'),
(43783, 3018, 'Império da Ostentação S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196398.mp4', 'http://gstaticontent.com/images/cjfy9i5unNnVmH9aG4cE3oDg6NY_big.jpg'),
(43784, 3018, 'Império da Ostentação S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196399.mp4', 'http://gstaticontent.com/images/cjfy9i5unNnVmH9aG4cE3oDg6NY_big.jpg'),
(43785, 3018, 'Império da Ostentação S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196400.mp4', 'http://gstaticontent.com/images/cjfy9i5unNnVmH9aG4cE3oDg6NY_big.jpg'),
(43786, 3018, 'Império da Ostentação S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196401.mp4', 'http://gstaticontent.com/images/cjfy9i5unNnVmH9aG4cE3oDg6NY_big.jpg'),
(43787, 3018, 'Império da Ostentação S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196402.mp4', 'http://gstaticontent.com/images/cjfy9i5unNnVmH9aG4cE3oDg6NY_big.jpg'),
(43788, 3018, 'Império da Ostentação S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196403.mp4', 'http://gstaticontent.com/images/cjfy9i5unNnVmH9aG4cE3oDg6NY_big.jpg'),
(43789, 3018, 'Império da Ostentação S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196404.mp4', 'http://gstaticontent.com/images/cjfy9i5unNnVmH9aG4cE3oDg6NY_big.jpg'),
(43790, 3018, 'Império da Ostentação S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196405.mp4', 'http://gstaticontent.com/images/cjfy9i5unNnVmH9aG4cE3oDg6NY_big.jpg'),
(43791, 3018, 'Império da Ostentação S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196406.mp4', 'http://gstaticontent.com/images/cjfy9i5unNnVmH9aG4cE3oDg6NY_big.jpg'),
(43792, 3018, 'Império da Ostentação S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196407.mp4', 'http://gstaticontent.com/images/cjfy9i5unNnVmH9aG4cE3oDg6NY_big.jpg'),
(43793, 3019, 'Liga da Justiça Sem Limites S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136545.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43794, 3019, 'Liga da Justiça Sem Limites S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136546.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43795, 3019, 'Liga da Justiça Sem Limites S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136547.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43796, 3019, 'Liga da Justiça Sem Limites S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136548.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43797, 3019, 'Liga da Justiça Sem Limites S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136549.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43798, 3019, 'Liga da Justiça Sem Limites S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136550.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43799, 3019, 'Liga da Justiça Sem Limites S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136551.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43800, 3019, 'Liga da Justiça Sem Limites S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136552.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43801, 3019, 'Liga da Justiça Sem Limites S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136553.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43802, 3019, 'Liga da Justiça Sem Limites S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136554.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43803, 3019, 'Liga da Justiça Sem Limites S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136555.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43804, 3019, 'Liga da Justiça Sem Limites S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136556.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43805, 3019, 'Liga da Justiça Sem Limites S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136557.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43806, 3020, 'Liga da Justiça Sem Limites S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136558.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43807, 3020, 'Liga da Justiça Sem Limites S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136559.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43808, 3020, 'Liga da Justiça Sem Limites S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136560.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43809, 3020, 'Liga da Justiça Sem Limites S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136561.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43810, 3020, 'Liga da Justiça Sem Limites S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136562.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43811, 3020, 'Liga da Justiça Sem Limites S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136563.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43812, 3020, 'Liga da Justiça Sem Limites S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136564.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43813, 3020, 'Liga da Justiça Sem Limites S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136565.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43814, 3020, 'Liga da Justiça Sem Limites S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136566.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43815, 3020, 'Liga da Justiça Sem Limites S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136567.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43816, 3020, 'Liga da Justiça Sem Limites S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136568.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43817, 3020, 'Liga da Justiça Sem Limites S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136569.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43818, 3020, 'Liga da Justiça Sem Limites S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136570.mp4', 'http://gstaticontent.com/images/xUCiqtQeCfHUVOXYfWj0BlZnRqC_big.jpg'),
(43819, 3021, 'Liga da Justiça Sem Limites S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/757512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wEqS6ChRJdEf69urxRUqAVgFUoS.jpg'),
(43820, 3021, 'Liga da Justiça Sem Limites S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/757513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AcYnCy0q1MErk2U32XLCIS9nawz.jpg'),
(43821, 3021, 'Liga da Justiça Sem Limites S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/757514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hwc81qNDKlhIOxWS62qU1RMyC2n.jpg'),
(43822, 3021, 'Liga da Justiça Sem Limites S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/757515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBN0Qx5yQWFZ1kRKJAlYGU0eKvx.jpg'),
(43823, 3021, 'Liga da Justiça Sem Limites S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/757516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/33EsHI0doKZJWfLWgHhTBtNdfic.jpg'),
(43824, 3021, 'Liga da Justiça Sem Limites S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/757517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ap5qpVDHsrNcLc6TqFVVdyVN9lT.jpg'),
(43825, 3021, 'Liga da Justiça Sem Limites S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/757518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8IDrw9yD8q5Gya7deo4RWZkKu3S.jpg'),
(43826, 3021, 'Liga da Justiça Sem Limites S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/757519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dRsPDC98Hx723JQf7q5WQo9fKrX.jpg'),
(43827, 3021, 'Liga da Justiça Sem Limites S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/757520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0dvxklrsaUl4EFhG2CiMRaXcCg.jpg'),
(43828, 3021, 'Liga da Justiça Sem Limites S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/757521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mMumQiAN848yKvEoNkOdoVkg9B6.jpg'),
(43829, 3021, 'Liga da Justiça Sem Limites S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/757522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x79Xhiyr6VtB16lXMC1uNdpU0ya.jpg'),
(43830, 3021, 'Liga da Justiça Sem Limites S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/757523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/85vKxB6dupfoAed2bGxItRzlJ0F.jpg'),
(43831, 3021, 'Liga da Justiça Sem Limites S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/757524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62eGl9u2vMV2ONIbHGFt3vRuT3T.jpg'),
(43832, 3022, 'Longmire: O Xerife S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136571.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43833, 3022, 'Longmire: O Xerife S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136572.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43834, 3022, 'Longmire: O Xerife S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136573.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43835, 3022, 'Longmire: O Xerife S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136574.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43836, 3022, 'Longmire: O Xerife S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136575.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43837, 3022, 'Longmire: O Xerife S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136576.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43838, 3022, 'Longmire: O Xerife S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136577.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43839, 3022, 'Longmire: O Xerife S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136578.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43840, 3022, 'Longmire: O Xerife S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136579.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43841, 3022, 'Longmire: O Xerife S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136580.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(43842, 3023, 'Longmire: O Xerife S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136581.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43843, 3023, 'Longmire: O Xerife S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136582.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43844, 3023, 'Longmire: O Xerife S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136583.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43845, 3023, 'Longmire: O Xerife S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136584.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43846, 3023, 'Longmire: O Xerife S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136585.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43847, 3023, 'Longmire: O Xerife S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136586.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43848, 3023, 'Longmire: O Xerife S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136587.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43849, 3023, 'Longmire: O Xerife S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136588.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43850, 3023, 'Longmire: O Xerife S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136589.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43851, 3023, 'Longmire: O Xerife S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136590.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43852, 3023, 'Longmire: O Xerife S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136591.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43853, 3023, 'Longmire: O Xerife S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136592.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43854, 3023, 'Longmire: O Xerife S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136593.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43855, 3024, 'Longmire: O Xerife S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136594.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43856, 3024, 'Longmire: O Xerife S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136595.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43857, 3024, 'Longmire: O Xerife S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136596.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43858, 3024, 'Longmire: O Xerife S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136597.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43859, 3024, 'Longmire: O Xerife S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136598.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43860, 3024, 'Longmire: O Xerife S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136599.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43861, 3024, 'Longmire: O Xerife S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136600.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43862, 3024, 'Longmire: O Xerife S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136601.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43863, 3024, 'Longmire: O Xerife S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136602.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43864, 3024, 'Longmire: O Xerife S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136603.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43865, 3025, 'Longmire: O Xerife S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136604.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43866, 3025, 'Longmire: O Xerife S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136605.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43867, 3025, 'Longmire: O Xerife S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136606.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43868, 3025, 'Longmire: O Xerife S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136607.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43869, 3025, 'Longmire: O Xerife S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136608.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43870, 3025, 'Longmire: O Xerife S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136609.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43871, 3025, 'Longmire: O Xerife S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136610.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43872, 3025, 'Longmire: O Xerife S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136611.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43873, 3025, 'Longmire: O Xerife S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136612.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43874, 3025, 'Longmire: O Xerife S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136613.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43875, 3026, 'Longmire: O Xerife S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136614.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43876, 3026, 'Longmire: O Xerife S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136615.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43877, 3026, 'Longmire: O Xerife S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136616.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43878, 3026, 'Longmire: O Xerife S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136617.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43879, 3026, 'Longmire: O Xerife S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136618.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43880, 3026, 'Longmire: O Xerife S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136619.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43881, 3026, 'Longmire: O Xerife S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136620.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43882, 3026, 'Longmire: O Xerife S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136621.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43883, 3026, 'Longmire: O Xerife S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136622.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43884, 3026, 'Longmire: O Xerife S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136623.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43885, 3027, 'Longmire: O Xerife S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136624.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43886, 3027, 'Longmire: O Xerife S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136625.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43887, 3027, 'Longmire: O Xerife S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136626.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43888, 3027, 'Longmire: O Xerife S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136627.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43889, 3027, 'Longmire: O Xerife S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136628.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43890, 3027, 'Longmire: O Xerife S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136629.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43891, 3027, 'Longmire: O Xerife S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136630.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43892, 3027, 'Longmire: O Xerife S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136631.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43893, 3027, 'Longmire: O Xerife S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136632.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43894, 3027, 'Longmire: O Xerife S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136633.mp4', 'http://gstaticontent.com/images/ba2nuLDLejuAcFnqJYfmztUqym4_big.jpg'),
(43895, 3028, 'Mãe Só Tem Duas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205102.mp4', 'http://gstaticontent.com/images/v3S0wWlKharBKR0kHHof7uRXq9H_big.jpg'),
(43896, 3028, 'Mãe Só Tem Duas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205103.mp4', 'http://gstaticontent.com/images/v3S0wWlKharBKR0kHHof7uRXq9H_big.jpg'),
(43897, 3028, 'Mãe Só Tem Duas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205104.mp4', 'http://gstaticontent.com/images/v3S0wWlKharBKR0kHHof7uRXq9H_big.jpg'),
(43898, 3028, 'Mãe Só Tem Duas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205105.mp4', 'http://gstaticontent.com/images/v3S0wWlKharBKR0kHHof7uRXq9H_big.jpg'),
(43899, 3028, 'Mãe Só Tem Duas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205106.mp4', 'http://gstaticontent.com/images/v3S0wWlKharBKR0kHHof7uRXq9H_big.jpg'),
(43900, 3028, 'Mãe Só Tem Duas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205107.mp4', 'http://gstaticontent.com/images/v3S0wWlKharBKR0kHHof7uRXq9H_big.jpg'),
(43901, 3028, 'Mãe Só Tem Duas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205108.mp4', 'http://gstaticontent.com/images/v3S0wWlKharBKR0kHHof7uRXq9H_big.jpg'),
(43902, 3028, 'Mãe Só Tem Duas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205109.mp4', 'http://gstaticontent.com/images/v3S0wWlKharBKR0kHHof7uRXq9H_big.jpg'),
(43903, 3028, 'Mãe Só Tem Duas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205110.mp4', 'http://gstaticontent.com/images/v3S0wWlKharBKR0kHHof7uRXq9H_big.jpg'),
(43904, 3029, 'Mãe Só Tem Duas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jxyktaoS13UqbIaRy1bbNwFt04v.jpg'),
(43905, 3029, 'Mãe Só Tem Duas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6GnxpIpDmWlHjAQge6V0U4AH4j4.jpg'),
(43906, 3029, 'Mãe Só Tem Duas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iL2UVnPFux5BLW6MFcMqr2Uc1Li.jpg'),
(43907, 3029, 'Mãe Só Tem Duas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lHe595l424sVEoHWTU3Affz5QIQ.jpg'),
(43908, 3029, 'Mãe Só Tem Duas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1TPGxSfy0cBf2Dt7AtSy9QhSnQ.jpg'),
(43909, 3029, 'Mãe Só Tem Duas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fTjoWRohWT2TGFJJu3kisIfrdhk.jpg'),
(43910, 3029, 'Mãe Só Tem Duas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ahx4bWnDK2WcA6r0rKAIyc6Vt5r.jpg'),
(43911, 3029, 'Mãe Só Tem Duas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cUDOxb5E04erZMgM2JSkX4bXIvz.jpg'),
(43912, 3030, 'Mãe Só Tem Duas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uJEwwcPTPg9mqQOtlF143A4VhYg.jpg'),
(43913, 3030, 'Mãe Só Tem Duas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yCW9CU49IoDIeTdRfHmyiWL1NEU.jpg'),
(43914, 3030, 'Mãe Só Tem Duas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d0Y50F2fMYgegGFmxhI1Zz6ff2C.jpg'),
(43915, 3030, 'Mãe Só Tem Duas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wirT7IIkHzXNG98MVnU3mlyi136.jpg'),
(43916, 3030, 'Mãe Só Tem Duas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7m0g38tZANh0sOZGkiXV1IxcHR.jpg'),
(43917, 3030, 'Mãe Só Tem Duas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vyisX31sztRgwwqTU0HMDGAcsQk.jpg'),
(43918, 3030, 'Mãe Só Tem Duas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8vvr3xWfyi0kblQ8Iwx84Aj3nGx.jpg'),
(43919, 3030, 'Mãe Só Tem Duas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yp9fnahom6b2BJef63qR2U9LTW4.jpg'),
(43920, 3030, 'Mãe Só Tem Duas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJWZuPDqSjl5NMN5buhDF7fnKyy.jpg'),
(43921, 3030, 'Mãe Só Tem Duas S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0TRdxP3EiPuEKM0SukHD8EyV5W.jpg'),
(43922, 3031, 'O Fantasma Escritor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136634.mp4', 'http://gstaticontent.com/images/1enj0PMkMBUtRYbWZbfsmv7DUrO_big.jpg'),
(43923, 3031, 'O Fantasma Escritor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136635.mp4', 'http://gstaticontent.com/images/1enj0PMkMBUtRYbWZbfsmv7DUrO_big.jpg'),
(43924, 3031, 'O Fantasma Escritor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136636.mp4', 'http://gstaticontent.com/images/1enj0PMkMBUtRYbWZbfsmv7DUrO_big.jpg'),
(43925, 3031, 'O Fantasma Escritor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136637.mp4', 'http://gstaticontent.com/images/1enj0PMkMBUtRYbWZbfsmv7DUrO_big.jpg'),
(43926, 3031, 'O Fantasma Escritor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136638.mp4', 'http://gstaticontent.com/images/1enj0PMkMBUtRYbWZbfsmv7DUrO_big.jpg'),
(43927, 3031, 'O Fantasma Escritor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136639.mp4', 'http://gstaticontent.com/images/1enj0PMkMBUtRYbWZbfsmv7DUrO_big.jpg'),
(43928, 3031, 'O Fantasma Escritor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136640.mp4', 'http://gstaticontent.com/images/1enj0PMkMBUtRYbWZbfsmv7DUrO_big.jpg'),
(43929, 3032, 'Por Que As Mulheres Matam S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175673.mp4', 'http://gstaticontent.com/images/48wU1WhF1220h2InFL35BIH5IRZ_big.jpg'),
(43930, 3032, 'Por Que As Mulheres Matam S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175674.mp4', 'http://gstaticontent.com/images/48wU1WhF1220h2InFL35BIH5IRZ_big.jpg'),
(43931, 3032, 'Por Que As Mulheres Matam S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175675.mp4', 'http://gstaticontent.com/images/48wU1WhF1220h2InFL35BIH5IRZ_big.jpg'),
(43932, 3032, 'Por Que As Mulheres Matam S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175676.mp4', 'http://gstaticontent.com/images/48wU1WhF1220h2InFL35BIH5IRZ_big.jpg'),
(43933, 3032, 'Por Que As Mulheres Matam S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175677.mp4', 'http://gstaticontent.com/images/48wU1WhF1220h2InFL35BIH5IRZ_big.jpg'),
(43934, 3032, 'Por Que As Mulheres Matam S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175678.mp4', 'http://gstaticontent.com/images/48wU1WhF1220h2InFL35BIH5IRZ_big.jpg'),
(43935, 3032, 'Por Que As Mulheres Matam S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175679.mp4', 'http://gstaticontent.com/images/48wU1WhF1220h2InFL35BIH5IRZ_big.jpg'),
(43936, 3032, 'Por Que As Mulheres Matam S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175680.mp4', 'http://gstaticontent.com/images/48wU1WhF1220h2InFL35BIH5IRZ_big.jpg'),
(43937, 3032, 'Por Que As Mulheres Matam S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/175681.mp4', 'http://gstaticontent.com/images/48wU1WhF1220h2InFL35BIH5IRZ_big.jpg'),
(43938, 3032, 'Por Que As Mulheres Matam S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/175682.mp4', 'http://gstaticontent.com/images/48wU1WhF1220h2InFL35BIH5IRZ_big.jpg'),
(43939, 3033, 'Por Que As Mulheres Matam S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175683.mp4', 'http://timg.bdta.pro/images/0b11f0099e0a301b6068e6188924485c.jpg'),
(43940, 3033, 'Por Que As Mulheres Matam S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175684.mp4', 'http://timg.bdta.pro/images/1422b6e1413197f54581afccb68920ba.jpg'),
(43941, 3033, 'Por Que As Mulheres Matam S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175685.mp4', 'http://timg.bdta.pro/images/3baa0c98c4258544288f1ae3b6775e0a.jpg'),
(43942, 3033, 'Por Que As Mulheres Matam S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175686.mp4', 'http://timg.bdta.pro/images/92fcdbd27be82eb8c90942167001f8e8.jpg'),
(43943, 3033, 'Por Que As Mulheres Matam S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175687.mp4', 'http://timg.bdta.pro/images/3f4f9f2888b62460374d0a9be7dacfb7.jpg'),
(43944, 3033, 'Por Que As Mulheres Matam S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175688.mp4', 'http://timg.bdta.pro/images/83c429c22ce171eec07e28b79a4d3d95.jpg'),
(43945, 3033, 'Por Que As Mulheres Matam S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175689.mp4', 'http://timg.bdta.pro/images/636d308ce109e1ce569f5c32af75cea3.jpg'),
(43946, 3033, 'Por Que As Mulheres Matam S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175690.mp4', 'http://timg.bdta.pro/images/75fa00d93e69e3b1c93ceab1772b173d.jpg'),
(43947, 3033, 'Por Que As Mulheres Matam S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/175691.mp4', 'http://timg.bdta.pro/images/b722d2040159e20728033bf3cf571cc8.jpg'),
(43948, 3033, 'Por Que As Mulheres Matam S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/175692.mp4', 'http://timg.bdta.pro/images/918b1d80302bed54edee2b512a4abf0a.jpg'),
(43949, 3034, 'Quem Financiou Hitler? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136641.mp4', 'http://gstaticontent.com/images/cjR1LiBfTrqXEV3HLukMufXUka3_big.jpg'),
(43950, 3034, 'Quem Financiou Hitler? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136642.mp4', 'http://gstaticontent.com/images/cjR1LiBfTrqXEV3HLukMufXUka3_big.jpg'),
(43951, 3034, 'Quem Financiou Hitler? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136643.mp4', 'http://gstaticontent.com/images/cjR1LiBfTrqXEV3HLukMufXUka3_big.jpg'),
(43952, 3034, 'Quem Financiou Hitler? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136644.mp4', 'http://gstaticontent.com/images/cjR1LiBfTrqXEV3HLukMufXUka3_big.jpg'),
(43953, 3035, 'Sobrevivendo a Escobar [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136645.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43954, 3035, 'Sobrevivendo a Escobar [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136646.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43955, 3035, 'Sobrevivendo a Escobar [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136647.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43956, 3035, 'Sobrevivendo a Escobar [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136648.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43957, 3035, 'Sobrevivendo a Escobar [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136649.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43958, 3035, 'Sobrevivendo a Escobar [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136650.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43959, 3035, 'Sobrevivendo a Escobar [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136651.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43960, 3035, 'Sobrevivendo a Escobar [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136652.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43961, 3035, 'Sobrevivendo a Escobar [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136653.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43962, 3035, 'Sobrevivendo a Escobar [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136654.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43963, 3035, 'Sobrevivendo a Escobar [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136655.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43964, 3035, 'Sobrevivendo a Escobar [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136656.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43965, 3035, 'Sobrevivendo a Escobar [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136657.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43966, 3035, 'Sobrevivendo a Escobar [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/136658.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43967, 3035, 'Sobrevivendo a Escobar [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/136659.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43968, 3035, 'Sobrevivendo a Escobar [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/136660.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43969, 3035, 'Sobrevivendo a Escobar [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/136661.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43970, 3035, 'Sobrevivendo a Escobar [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/136662.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43971, 3035, 'Sobrevivendo a Escobar [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/136663.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43972, 3035, 'Sobrevivendo a Escobar [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/136664.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43973, 3035, 'Sobrevivendo a Escobar [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/136665.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43974, 3035, 'Sobrevivendo a Escobar [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/136666.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43975, 3035, 'Sobrevivendo a Escobar [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/136667.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43976, 3035, 'Sobrevivendo a Escobar [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/136668.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43977, 3035, 'Sobrevivendo a Escobar [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/136669.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43978, 3035, 'Sobrevivendo a Escobar [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/136670.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43979, 3035, 'Sobrevivendo a Escobar [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/136671.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43980, 3035, 'Sobrevivendo a Escobar [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/136672.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43981, 3035, 'Sobrevivendo a Escobar [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/136673.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43982, 3035, 'Sobrevivendo a Escobar [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/136674.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43983, 3035, 'Sobrevivendo a Escobar [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/136675.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43984, 3035, 'Sobrevivendo a Escobar [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/136676.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43985, 3035, 'Sobrevivendo a Escobar [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/136677.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43986, 3035, 'Sobrevivendo a Escobar [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/136678.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43987, 3035, 'Sobrevivendo a Escobar [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/136679.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43988, 3035, 'Sobrevivendo a Escobar [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/136680.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43989, 3035, 'Sobrevivendo a Escobar [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/136681.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43990, 3035, 'Sobrevivendo a Escobar [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/136682.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43991, 3035, 'Sobrevivendo a Escobar [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/136683.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43992, 3035, 'Sobrevivendo a Escobar [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/136684.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43993, 3035, 'Sobrevivendo a Escobar [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/136685.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43994, 3035, 'Sobrevivendo a Escobar [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/136686.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43995, 3035, 'Sobrevivendo a Escobar [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/136687.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43996, 3035, 'Sobrevivendo a Escobar [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/136688.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43997, 3035, 'Sobrevivendo a Escobar [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/136689.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43998, 3035, 'Sobrevivendo a Escobar [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/136690.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(43999, 3035, 'Sobrevivendo a Escobar [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/136691.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(44000, 3035, 'Sobrevivendo a Escobar [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/136692.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(44001, 3035, 'Sobrevivendo a Escobar [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/136693.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(44002, 3035, 'Sobrevivendo a Escobar [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/136694.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(44003, 3035, 'Sobrevivendo a Escobar [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/136695.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(44004, 3035, 'Sobrevivendo a Escobar [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/136696.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(44005, 3035, 'Sobrevivendo a Escobar [L] S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/136697.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(44006, 3035, 'Sobrevivendo a Escobar [L] S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/136698.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(44007, 3035, 'Sobrevivendo a Escobar [L] S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/136699.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(44008, 3035, 'Sobrevivendo a Escobar [L] S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/136700.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(44009, 3035, 'Sobrevivendo a Escobar [L] S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/136701.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(44010, 3035, 'Sobrevivendo a Escobar [L] S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/136702.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(44011, 3035, 'Sobrevivendo a Escobar [L] S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/136703.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(44012, 3035, 'Sobrevivendo a Escobar [L] S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/136704.mp4', 'http://gstaticontent.com/images/0b29c1d7000e986dd80ee5eb1f70254d.jpg'),
(44013, 3036, 'The Watch [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135118.mp4', 'http://gstaticontent.com/images/y1AWUlJUxsnwEiC0gTfP2nUZ9c5_big.jpg'),
(44014, 3036, 'The Watch [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135119.mp4', 'http://gstaticontent.com/images/y1AWUlJUxsnwEiC0gTfP2nUZ9c5_big.jpg'),
(44015, 3036, 'The Watch [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135120.mp4', 'http://gstaticontent.com/images/y1AWUlJUxsnwEiC0gTfP2nUZ9c5_big.jpg'),
(44016, 3036, 'The Watch [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135121.mp4', 'http://gstaticontent.com/images/y1AWUlJUxsnwEiC0gTfP2nUZ9c5_big.jpg'),
(44017, 3036, 'The Watch [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135122.mp4', 'http://gstaticontent.com/images/y1AWUlJUxsnwEiC0gTfP2nUZ9c5_big.jpg'),
(44018, 3036, 'The Watch [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135123.mp4', 'http://gstaticontent.com/images/y1AWUlJUxsnwEiC0gTfP2nUZ9c5_big.jpg'),
(44019, 3036, 'The Watch [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135124.mp4', 'http://gstaticontent.com/images/y1AWUlJUxsnwEiC0gTfP2nUZ9c5_big.jpg'),
(44020, 3036, 'The Watch [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135125.mp4', 'http://gstaticontent.com/images/y1AWUlJUxsnwEiC0gTfP2nUZ9c5_big.jpg'),
(44021, 3037, 'X-Men: Evolution S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136705.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44022, 3037, 'X-Men: Evolution S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136706.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44023, 3037, 'X-Men: Evolution S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136707.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44024, 3037, 'X-Men: Evolution S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136708.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44025, 3037, 'X-Men: Evolution S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136709.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44026, 3037, 'X-Men: Evolution S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136710.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44027, 3037, 'X-Men: Evolution S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136711.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44028, 3037, 'X-Men: Evolution S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136712.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44029, 3037, 'X-Men: Evolution S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136713.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44030, 3037, 'X-Men: Evolution S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136714.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44031, 3037, 'X-Men: Evolution S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136715.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44032, 3037, 'X-Men: Evolution S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136716.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44033, 3037, 'X-Men: Evolution S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136717.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44034, 3038, 'X-Men: Evolution S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136718.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44035, 3038, 'X-Men: Evolution S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136719.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44036, 3038, 'X-Men: Evolution S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136720.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44037, 3038, 'X-Men: Evolution S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136721.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44038, 3038, 'X-Men: Evolution S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136722.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44039, 3038, 'X-Men: Evolution S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136723.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44040, 3038, 'X-Men: Evolution S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136724.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44041, 3038, 'X-Men: Evolution S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136725.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44042, 3038, 'X-Men: Evolution S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136726.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44043, 3038, 'X-Men: Evolution S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136727.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44044, 3038, 'X-Men: Evolution S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136728.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44045, 3038, 'X-Men: Evolution S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136729.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44046, 3038, 'X-Men: Evolution S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136730.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44047, 3038, 'X-Men: Evolution S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/136731.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44048, 3038, 'X-Men: Evolution S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/136732.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44049, 3038, 'X-Men: Evolution S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/136733.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44050, 3038, 'X-Men: Evolution S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/136734.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44051, 3039, 'X-Men: Evolution S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136735.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44052, 3039, 'X-Men: Evolution S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136736.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44053, 3039, 'X-Men: Evolution S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136737.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44054, 3039, 'X-Men: Evolution S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136738.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44055, 3039, 'X-Men: Evolution S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136739.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44056, 3039, 'X-Men: Evolution S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136740.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44057, 3039, 'X-Men: Evolution S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136741.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44058, 3039, 'X-Men: Evolution S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136742.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44059, 3039, 'X-Men: Evolution S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136743.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44060, 3039, 'X-Men: Evolution S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/136744.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44061, 3039, 'X-Men: Evolution S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/136745.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44062, 3039, 'X-Men: Evolution S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/136746.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44063, 3039, 'X-Men: Evolution S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/136747.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44064, 3040, 'X-Men: Evolution S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136748.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44065, 3040, 'X-Men: Evolution S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136749.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44066, 3040, 'X-Men: Evolution S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136750.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44067, 3040, 'X-Men: Evolution S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136751.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44068, 3040, 'X-Men: Evolution S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136752.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44069, 3040, 'X-Men: Evolution S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136753.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44070, 3040, 'X-Men: Evolution S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136754.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44071, 3040, 'X-Men: Evolution S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136755.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44072, 3040, 'X-Men: Evolution S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/136756.mp4', 'http://gstaticontent.com/images/whZRsqrMYoigHoPRme1Pdsyf5UO_big.jpg'),
(44073, 3041, 'Fate: A Saga Winx S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192433.mp4', 'http://gstaticontent.com/images/dEZK7wb5VQsflOXHoEMYwv4aV1g_big.jpg'),
(44074, 3041, 'Fate: A Saga Winx S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192434.mp4', 'http://gstaticontent.com/images/dEZK7wb5VQsflOXHoEMYwv4aV1g_big.jpg'),
(44075, 3041, 'Fate: A Saga Winx S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192435.mp4', 'http://gstaticontent.com/images/dEZK7wb5VQsflOXHoEMYwv4aV1g_big.jpg'),
(44076, 3041, 'Fate: A Saga Winx S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192436.mp4', 'http://gstaticontent.com/images/dEZK7wb5VQsflOXHoEMYwv4aV1g_big.jpg'),
(44077, 3041, 'Fate: A Saga Winx S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192437.mp4', 'http://gstaticontent.com/images/dEZK7wb5VQsflOXHoEMYwv4aV1g_big.jpg'),
(44078, 3041, 'Fate: A Saga Winx S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192438.mp4', 'http://gstaticontent.com/images/dEZK7wb5VQsflOXHoEMYwv4aV1g_big.jpg'),
(44079, 3042, 'Fate: A Saga Winx S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192439.mp4', 'http://timg.bdta.pro/images/2f0d77b56bc3cfadbf4ccb7193c3fb25.jpg'),
(44080, 3042, 'Fate: A Saga Winx S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192440.mp4', 'http://timg.bdta.pro/images/7308e3bff9f49fac08823653598c5032.jpg'),
(44081, 3042, 'Fate: A Saga Winx S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192441.mp4', 'http://timg.bdta.pro/images/fd38322f37cad7be716dee13a5194097.jpg'),
(44082, 3042, 'Fate: A Saga Winx S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192442.mp4', 'http://timg.bdta.pro/images/4870f52025bcaf16e5c191c8d2f0f633.jpg'),
(44083, 3042, 'Fate: A Saga Winx S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192443.mp4', 'http://timg.bdta.pro/images/ead90eaa16d3accf695d06124180daab.jpg'),
(44084, 3042, 'Fate: A Saga Winx S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192444.mp4', 'http://timg.bdta.pro/images/10924480b262c20175a870170181741f.jpg'),
(44085, 3042, 'Fate: A Saga Winx S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192445.mp4', 'http://timg.bdta.pro/images/a495979f2b1f217322e63df06ee45f6f.jpg'),
(44086, 3043, 'O Arsenal dos Espiões S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136256.mp4', 'http://gstaticontent.com/images/3JJMgQ09UpZKzfsbjHatqhSmPJc_big.jpg'),
(44087, 3043, 'O Arsenal dos Espiões S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136257.mp4', 'http://gstaticontent.com/images/3JJMgQ09UpZKzfsbjHatqhSmPJc_big.jpg'),
(44088, 3043, 'O Arsenal dos Espiões S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136258.mp4', 'http://gstaticontent.com/images/3JJMgQ09UpZKzfsbjHatqhSmPJc_big.jpg'),
(44089, 3043, 'O Arsenal dos Espiões S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136259.mp4', 'http://gstaticontent.com/images/3JJMgQ09UpZKzfsbjHatqhSmPJc_big.jpg'),
(44090, 3043, 'O Arsenal dos Espiões S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136260.mp4', 'http://gstaticontent.com/images/3JJMgQ09UpZKzfsbjHatqhSmPJc_big.jpg'),
(44091, 3043, 'O Arsenal dos Espiões S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136261.mp4', 'http://gstaticontent.com/images/3JJMgQ09UpZKzfsbjHatqhSmPJc_big.jpg'),
(44092, 3043, 'O Arsenal dos Espiões S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136262.mp4', 'http://gstaticontent.com/images/3JJMgQ09UpZKzfsbjHatqhSmPJc_big.jpg'),
(44093, 3043, 'O Arsenal dos Espiões S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136263.mp4', 'http://gstaticontent.com/images/3JJMgQ09UpZKzfsbjHatqhSmPJc_big.jpg'),
(44094, 3044, 'Transplant: Uma Nova Vida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213723.mp4', 'http://gstaticontent.com/images/4J84tDaDDFN6V4qkfu4h5A6V3IE_big.jpg'),
(44095, 3044, 'Transplant: Uma Nova Vida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213724.mp4', 'http://gstaticontent.com/images/4J84tDaDDFN6V4qkfu4h5A6V3IE_big.jpg'),
(44096, 3044, 'Transplant: Uma Nova Vida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213725.mp4', 'http://gstaticontent.com/images/4J84tDaDDFN6V4qkfu4h5A6V3IE_big.jpg'),
(44097, 3044, 'Transplant: Uma Nova Vida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213726.mp4', 'http://gstaticontent.com/images/4J84tDaDDFN6V4qkfu4h5A6V3IE_big.jpg'),
(44098, 3044, 'Transplant: Uma Nova Vida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213727.mp4', 'http://gstaticontent.com/images/4J84tDaDDFN6V4qkfu4h5A6V3IE_big.jpg'),
(44099, 3044, 'Transplant: Uma Nova Vida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213728.mp4', 'http://gstaticontent.com/images/4J84tDaDDFN6V4qkfu4h5A6V3IE_big.jpg'),
(44100, 3044, 'Transplant: Uma Nova Vida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213729.mp4', 'http://gstaticontent.com/images/4J84tDaDDFN6V4qkfu4h5A6V3IE_big.jpg'),
(44101, 3044, 'Transplant: Uma Nova Vida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213730.mp4', 'http://gstaticontent.com/images/4J84tDaDDFN6V4qkfu4h5A6V3IE_big.jpg'),
(44102, 3044, 'Transplant: Uma Nova Vida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213731.mp4', 'http://gstaticontent.com/images/4J84tDaDDFN6V4qkfu4h5A6V3IE_big.jpg'),
(44103, 3044, 'Transplant: Uma Nova Vida S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213732.mp4', 'http://gstaticontent.com/images/4J84tDaDDFN6V4qkfu4h5A6V3IE_big.jpg'),
(44104, 3044, 'Transplant: Uma Nova Vida S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/213733.mp4', 'http://gstaticontent.com/images/4J84tDaDDFN6V4qkfu4h5A6V3IE_big.jpg'),
(44105, 3044, 'Transplant: Uma Nova Vida S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/213734.mp4', 'http://gstaticontent.com/images/4J84tDaDDFN6V4qkfu4h5A6V3IE_big.jpg'),
(44106, 3044, 'Transplant: Uma Nova Vida S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/213735.mp4', 'http://gstaticontent.com/images/4J84tDaDDFN6V4qkfu4h5A6V3IE_big.jpg'),
(44107, 3045, 'Transplant: Uma Nova Vida S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213736.mp4', 'http://timg.bdta.pro/images/c94f6e93f7ffbde15ca324655432a638.jpg'),
(44108, 3045, 'Transplant: Uma Nova Vida S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213737.mp4', 'http://timg.bdta.pro/images/2510d40bef6d48183fc8a0a834009706.jpg'),
(44109, 3045, 'Transplant: Uma Nova Vida S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213738.mp4', 'http://timg.bdta.pro/images/1fe76ac6bd8274fe333c373c5538de27.jpg'),
(44110, 3045, 'Transplant: Uma Nova Vida S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213739.mp4', 'http://timg.bdta.pro/images/e92e0e749e50e55bdac2d63943107311.jpg'),
(44111, 3045, 'Transplant: Uma Nova Vida S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213740.mp4', 'http://timg.bdta.pro/images/33344aaebe9ed6cdaa8b9b657d74933e.jpg'),
(44112, 3045, 'Transplant: Uma Nova Vida S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213741.mp4', 'http://timg.bdta.pro/images/6fe56234916ee8ff956d0e7c9fd8bc67.jpg'),
(44113, 3045, 'Transplant: Uma Nova Vida S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213742.mp4', 'http://timg.bdta.pro/images/df57cd9686113f704bec3206a1e77d0a.jpg'),
(44114, 3045, 'Transplant: Uma Nova Vida S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213743.mp4', 'http://timg.bdta.pro/images/edc11fe2236b64106df8c7617e64cd14.jpg'),
(44115, 3045, 'Transplant: Uma Nova Vida S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213744.mp4', 'http://timg.bdta.pro/images/b95d6e3f1882e75a4923899b3be00a23.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(44116, 3045, 'Transplant: Uma Nova Vida S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213745.mp4', 'http://timg.bdta.pro/images/71c7df0870fe172fec5a66ec61381593.jpg'),
(44117, 3045, 'Transplant: Uma Nova Vida S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/213746.mp4', 'http://timg.bdta.pro/images/181d7cd9cee1b6878308e4ae00f356b3.jpg'),
(44118, 3045, 'Transplant: Uma Nova Vida S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/213747.mp4', 'http://timg.bdta.pro/images/c279f19c977012bb66d6b77bd4091fdc.jpg'),
(44119, 3045, 'Transplant: Uma Nova Vida S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/213748.mp4', 'http://timg.bdta.pro/images/2bd02686d075853f688cc354942c5313.jpg'),
(44120, 3046, 'Transplant: Uma Nova Vida S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqt2NrmoXGpWAUc4rJ3yC2Gwo9W.jpg'),
(44121, 3046, 'Transplant: Uma Nova Vida S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nw9tx7L0OEbAhAeaNrMl7cXWfsk.jpg'),
(44122, 3046, 'Transplant: Uma Nova Vida S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mJTIWpdyvzTTBGLmMhfWhRIUhnC.jpg'),
(44123, 3046, 'Transplant: Uma Nova Vida S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6vXHGB2twkEpN0gB8udbD7iXIyo.jpg'),
(44124, 3046, 'Transplant: Uma Nova Vida S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wj946r4oujAhO9b3MXbnShAh7rD.jpg'),
(44125, 3046, 'Transplant: Uma Nova Vida S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/krfb6llu67qrTEDw8qqZ4EzLNt2.jpg'),
(44126, 3046, 'Transplant: Uma Nova Vida S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/znC0AjniHWkJgrLhWlF5esDMIOD.jpg'),
(44127, 3046, 'Transplant: Uma Nova Vida S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jLk23tZlF6nK7U0tovhaB0zGG46.jpg'),
(44128, 3046, 'Transplant: Uma Nova Vida S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7MY8Q8fkDTQiQk23noCUJY66EMO.jpg'),
(44129, 3046, 'Transplant: Uma Nova Vida S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pYGF6wdfqlXdrEK2X808bXvNO4C.jpg'),
(44130, 3046, 'Transplant: Uma Nova Vida S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/213759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xDUW36VZXgvBKAyBYAaJyVAtqYz.jpg'),
(44131, 3046, 'Transplant: Uma Nova Vida S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/213760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNSaAqiiUgeWNZhkZIqvNSojNkJ.jpg'),
(44132, 3046, 'Transplant: Uma Nova Vida S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/213761.mp4', 'http://gstaticontent.com/images/4J84tDaDDFN6V4qkfu4h5A6V3IE_big.jpg'),
(44133, 3047, '(Des)encanto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44134, 3047, '(Des)encanto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44135, 3047, '(Des)encanto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44136, 3047, '(Des)encanto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44137, 3047, '(Des)encanto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44138, 3047, '(Des)encanto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44139, 3047, '(Des)encanto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44140, 3047, '(Des)encanto S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44141, 3047, '(Des)encanto S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44142, 3047, '(Des)encanto S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44143, 3048, '(Des)encanto S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44144, 3048, '(Des)encanto S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44145, 3048, '(Des)encanto S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44146, 3048, '(Des)encanto S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44147, 3048, '(Des)encanto S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44148, 3048, '(Des)encanto S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44149, 3048, '(Des)encanto S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44150, 3048, '(Des)encanto S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44151, 3048, '(Des)encanto S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44152, 3048, '(Des)encanto S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44153, 3049, '(Des)encanto S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44154, 3049, '(Des)encanto S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44155, 3049, '(Des)encanto S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44156, 3049, '(Des)encanto S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44157, 3049, '(Des)encanto S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44158, 3049, '(Des)encanto S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44159, 3049, '(Des)encanto S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44160, 3049, '(Des)encanto S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44161, 3049, '(Des)encanto S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44162, 3049, '(Des)encanto S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44163, 3050, '(Des)encanto S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44164, 3050, '(Des)encanto S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44165, 3050, '(Des)encanto S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44166, 3050, '(Des)encanto S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44167, 3050, '(Des)encanto S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44168, 3050, '(Des)encanto S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44169, 3050, '(Des)encanto S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44170, 3050, '(Des)encanto S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44171, 3050, '(Des)encanto S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44172, 3050, '(Des)encanto S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44173, 3051, '(Des)encanto S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44174, 3051, '(Des)encanto S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44175, 3051, '(Des)encanto S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44176, 3051, '(Des)encanto S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44177, 3051, '(Des)encanto S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44178, 3051, '(Des)encanto S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44179, 3051, '(Des)encanto S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44180, 3051, '(Des)encanto S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44181, 3051, '(Des)encanto S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44182, 3051, '(Des)encanto S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yEoQq7w8cxaHFBAff5d6NaVxJH.jpg'),
(44183, 3052, 'The Lady and the Dale S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134955.mp4', 'http://gstaticontent.com/images/crMJcKrkrVLPhWU69AgxMB8LFtY_big.jpg'),
(44184, 3052, 'The Lady and the Dale S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134956.mp4', 'http://gstaticontent.com/images/crMJcKrkrVLPhWU69AgxMB8LFtY_big.jpg'),
(44185, 3052, 'The Lady and the Dale S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134957.mp4', 'http://gstaticontent.com/images/crMJcKrkrVLPhWU69AgxMB8LFtY_big.jpg'),
(44186, 3052, 'The Lady and the Dale S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134958.mp4', 'http://gstaticontent.com/images/crMJcKrkrVLPhWU69AgxMB8LFtY_big.jpg'),
(44187, 3053, 'The Devil Punisher [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140355.mp4', 'http://gstaticontent.com/images/5IqheXmeFSymI4GDhJQcAHwXotg_big.jpg'),
(44188, 3053, 'The Devil Punisher [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140356.mp4', 'http://gstaticontent.com/images/5IqheXmeFSymI4GDhJQcAHwXotg_big.jpg'),
(44189, 3053, 'The Devil Punisher [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140357.mp4', 'http://gstaticontent.com/images/5IqheXmeFSymI4GDhJQcAHwXotg_big.jpg'),
(44190, 3053, 'The Devil Punisher [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140358.mp4', 'http://gstaticontent.com/images/5IqheXmeFSymI4GDhJQcAHwXotg_big.jpg'),
(44191, 3053, 'The Devil Punisher [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140359.mp4', 'http://gstaticontent.com/images/5IqheXmeFSymI4GDhJQcAHwXotg_big.jpg'),
(44192, 3053, 'The Devil Punisher [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140360.mp4', 'http://gstaticontent.com/images/5IqheXmeFSymI4GDhJQcAHwXotg_big.jpg'),
(44193, 3053, 'The Devil Punisher [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140361.mp4', 'http://gstaticontent.com/images/5IqheXmeFSymI4GDhJQcAHwXotg_big.jpg'),
(44194, 3053, 'The Devil Punisher [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140362.mp4', 'http://gstaticontent.com/images/5IqheXmeFSymI4GDhJQcAHwXotg_big.jpg'),
(44195, 3053, 'The Devil Punisher [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140363.mp4', 'http://gstaticontent.com/images/5IqheXmeFSymI4GDhJQcAHwXotg_big.jpg'),
(44196, 3053, 'The Devil Punisher [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140364.mp4', 'http://gstaticontent.com/images/5IqheXmeFSymI4GDhJQcAHwXotg_big.jpg'),
(44197, 3053, 'The Devil Punisher [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140365.mp4', 'http://gstaticontent.com/images/5IqheXmeFSymI4GDhJQcAHwXotg_big.jpg'),
(44198, 3053, 'The Devil Punisher [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140366.mp4', 'http://gstaticontent.com/images/5IqheXmeFSymI4GDhJQcAHwXotg_big.jpg'),
(44199, 3053, 'The Devil Punisher [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140367.mp4', 'http://gstaticontent.com/images/5IqheXmeFSymI4GDhJQcAHwXotg_big.jpg'),
(44200, 3053, 'The Devil Punisher [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/140368.mp4', 'http://gstaticontent.com/images/5IqheXmeFSymI4GDhJQcAHwXotg_big.jpg'),
(44201, 3053, 'The Devil Punisher [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/140369.mp4', 'http://gstaticontent.com/images/5IqheXmeFSymI4GDhJQcAHwXotg_big.jpg'),
(44202, 3053, 'The Devil Punisher [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/140370.mp4', 'http://gstaticontent.com/images/5IqheXmeFSymI4GDhJQcAHwXotg_big.jpg'),
(44203, 3053, 'The Devil Punisher [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/140371.mp4', 'http://gstaticontent.com/images/5IqheXmeFSymI4GDhJQcAHwXotg_big.jpg'),
(44204, 3053, 'The Devil Punisher [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/140372.mp4', 'http://gstaticontent.com/images/5IqheXmeFSymI4GDhJQcAHwXotg_big.jpg'),
(44205, 3053, 'The Devil Punisher [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/140373.mp4', 'http://gstaticontent.com/images/5IqheXmeFSymI4GDhJQcAHwXotg_big.jpg'),
(44206, 3053, 'The Devil Punisher [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/140374.mp4', 'http://gstaticontent.com/images/5IqheXmeFSymI4GDhJQcAHwXotg_big.jpg'),
(44207, 3054, 'Strike S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44208, 3054, 'Strike S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44209, 3054, 'Strike S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44210, 3054, 'Strike S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44211, 3054, 'Strike S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44212, 3055, 'Strike S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44213, 3055, 'Strike S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44214, 3056, 'Strike S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/643599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44215, 3056, 'Strike S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/643600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44216, 3056, 'Strike S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/643601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44217, 3056, 'Strike S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/643602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44218, 3057, 'Strike S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/643603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44219, 3057, 'Strike S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/643604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44220, 3057, 'Strike S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/643605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44221, 3057, 'Strike S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/643606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44222, 3058, 'Strike S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/692698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44223, 3058, 'Strike S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/692699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44224, 3058, 'Strike S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/692700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44225, 3058, 'Strike S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/692701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44226, 3059, 'Strike S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/692702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44227, 3059, 'Strike S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/692703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44228, 3059, 'Strike S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/692704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44229, 3059, 'Strike S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/697343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPTJfwuMLz6Lr3suGK4584MAJAC.jpg'),
(44230, 3060, 'O Cavalo Amarelo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136159.mp4', 'http://gstaticontent.com/images/pFCzhg4W89ZuIJCKwVqoLueOjHy_big.jpg'),
(44231, 3060, 'O Cavalo Amarelo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136160.mp4', 'http://gstaticontent.com/images/pFCzhg4W89ZuIJCKwVqoLueOjHy_big.jpg'),
(44232, 3060, 'O Cavalo Amarelo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136161.mp4', 'http://gstaticontent.com/images/pFCzhg4W89ZuIJCKwVqoLueOjHy_big.jpg'),
(44233, 3061, 'O Corredor da Morte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136162.mp4', 'http://gstaticontent.com/images/4KvLL9Xaq8o5PTLugzYZk8qrbFL_big.jpg'),
(44234, 3061, 'O Corredor da Morte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136163.mp4', 'http://gstaticontent.com/images/4KvLL9Xaq8o5PTLugzYZk8qrbFL_big.jpg'),
(44235, 3061, 'O Corredor da Morte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136164.mp4', 'http://gstaticontent.com/images/4KvLL9Xaq8o5PTLugzYZk8qrbFL_big.jpg'),
(44236, 3061, 'O Corredor da Morte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136165.mp4', 'http://gstaticontent.com/images/4KvLL9Xaq8o5PTLugzYZk8qrbFL_big.jpg'),
(44237, 3062, 'La Jauría S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136166.mp4', 'http://gstaticontent.com/images/siTwS1bBCzFFzjBEyoZg51jsfmv_big.jpg'),
(44238, 3062, 'La Jauría S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136167.mp4', 'http://gstaticontent.com/images/siTwS1bBCzFFzjBEyoZg51jsfmv_big.jpg'),
(44239, 3062, 'La Jauría S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136168.mp4', 'http://gstaticontent.com/images/siTwS1bBCzFFzjBEyoZg51jsfmv_big.jpg'),
(44240, 3062, 'La Jauría S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136169.mp4', 'http://gstaticontent.com/images/siTwS1bBCzFFzjBEyoZg51jsfmv_big.jpg'),
(44241, 3062, 'La Jauría S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136170.mp4', 'http://gstaticontent.com/images/siTwS1bBCzFFzjBEyoZg51jsfmv_big.jpg'),
(44242, 3062, 'La Jauría S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136171.mp4', 'http://gstaticontent.com/images/siTwS1bBCzFFzjBEyoZg51jsfmv_big.jpg'),
(44243, 3062, 'La Jauría S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136172.mp4', 'http://gstaticontent.com/images/siTwS1bBCzFFzjBEyoZg51jsfmv_big.jpg'),
(44244, 3062, 'La Jauría S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136173.mp4', 'http://gstaticontent.com/images/siTwS1bBCzFFzjBEyoZg51jsfmv_big.jpg'),
(44245, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219223.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44246, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219224.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44247, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219225.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44248, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219226.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44249, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219227.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44250, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219228.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44251, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219229.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44252, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219230.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44253, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219231.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44254, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219232.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44255, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219233.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44256, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219234.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44257, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219235.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44258, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/219236.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44259, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/219237.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44260, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/219238.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44261, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/219239.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44262, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/219240.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44263, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/219241.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44264, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/219242.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44265, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/219243.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44266, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/219244.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44267, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/219245.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44268, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/219246.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44269, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/219247.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44270, 3063, 'Demon Slayer Kimetsu no Yaiba S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/219248.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44271, 3064, 'Demon Slayer Kimetsu no Yaiba S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219249.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44272, 3064, 'Demon Slayer Kimetsu no Yaiba S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219250.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44273, 3064, 'Demon Slayer Kimetsu no Yaiba S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219251.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44274, 3064, 'Demon Slayer Kimetsu no Yaiba S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219252.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44275, 3064, 'Demon Slayer Kimetsu no Yaiba S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219253.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44276, 3064, 'Demon Slayer Kimetsu no Yaiba S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219254.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44277, 3064, 'Demon Slayer Kimetsu no Yaiba S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219255.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44278, 3065, 'Demon Slayer Kimetsu no Yaiba S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219256.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44279, 3065, 'Demon Slayer Kimetsu no Yaiba S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219257.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44280, 3065, 'Demon Slayer Kimetsu no Yaiba S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219258.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44281, 3065, 'Demon Slayer Kimetsu no Yaiba S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219259.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44282, 3065, 'Demon Slayer Kimetsu no Yaiba S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219260.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44283, 3065, 'Demon Slayer Kimetsu no Yaiba S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219261.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44284, 3065, 'Demon Slayer Kimetsu no Yaiba S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219262.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44285, 3065, 'Demon Slayer Kimetsu no Yaiba S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219263.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44286, 3065, 'Demon Slayer Kimetsu no Yaiba S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219264.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44287, 3065, 'Demon Slayer Kimetsu no Yaiba S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219265.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44288, 3065, 'Demon Slayer Kimetsu no Yaiba S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219266.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44289, 3066, 'Demon Slayer Kimetsu no Yaiba S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268034.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44290, 3066, 'Demon Slayer Kimetsu no Yaiba S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268035.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44291, 3066, 'Demon Slayer Kimetsu no Yaiba S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268036.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44292, 3066, 'Demon Slayer Kimetsu no Yaiba S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268037.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44293, 3066, 'Demon Slayer Kimetsu no Yaiba S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268038.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44294, 3066, 'Demon Slayer Kimetsu no Yaiba S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268039.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44295, 3066, 'Demon Slayer Kimetsu no Yaiba S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268040.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44296, 3066, 'Demon Slayer Kimetsu no Yaiba S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268041.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44297, 3066, 'Demon Slayer Kimetsu no Yaiba S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268042.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44298, 3066, 'Demon Slayer Kimetsu no Yaiba S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268043.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44299, 3066, 'Demon Slayer Kimetsu no Yaiba S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268044.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44300, 3067, 'Demon Slayer Kimetsu no Yaiba S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/665293.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44301, 3067, 'Demon Slayer Kimetsu no Yaiba S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/665294.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44302, 3067, 'Demon Slayer Kimetsu no Yaiba S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/665295.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44303, 3067, 'Demon Slayer Kimetsu no Yaiba S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/665296.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44304, 3067, 'Demon Slayer Kimetsu no Yaiba S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/665297.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44305, 3067, 'Demon Slayer Kimetsu no Yaiba S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/665298.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44306, 3067, 'Demon Slayer Kimetsu no Yaiba S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/665299.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44307, 3067, 'Demon Slayer Kimetsu no Yaiba S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/665300.mp4', 'http://gstaticontent.com/images/7Uj6vqmznWQ3w3hpQ1eIY9mMyMw_big.jpg'),
(44308, 3068, '50M S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/136174.mp4', 'http://gstaticontent.com/images/dec4e097ef2c8454394caed853df0697.jpg'),
(44309, 3068, '50M S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/136175.mp4', 'http://gstaticontent.com/images/dec4e097ef2c8454394caed853df0697.jpg'),
(44310, 3068, '50M S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/136176.mp4', 'http://gstaticontent.com/images/dec4e097ef2c8454394caed853df0697.jpg'),
(44311, 3068, '50M S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/136177.mp4', 'http://gstaticontent.com/images/dec4e097ef2c8454394caed853df0697.jpg'),
(44312, 3068, '50M S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/136178.mp4', 'http://gstaticontent.com/images/dec4e097ef2c8454394caed853df0697.jpg'),
(44313, 3068, '50M S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/136179.mp4', 'http://gstaticontent.com/images/dec4e097ef2c8454394caed853df0697.jpg'),
(44314, 3068, '50M S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/136180.mp4', 'http://gstaticontent.com/images/dec4e097ef2c8454394caed853df0697.jpg'),
(44315, 3068, '50M S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/136181.mp4', 'http://gstaticontent.com/images/dec4e097ef2c8454394caed853df0697.jpg'),
(44316, 3069, 'The Disappearance S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135938.mp4', 'http://gstaticontent.com/images/wDw0ItLofAmLoMUYxVyhdK4lI0p_big.jpg'),
(44317, 3069, 'The Disappearance S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135939.mp4', 'http://gstaticontent.com/images/wDw0ItLofAmLoMUYxVyhdK4lI0p_big.jpg'),
(44318, 3069, 'The Disappearance S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135940.mp4', 'http://gstaticontent.com/images/wDw0ItLofAmLoMUYxVyhdK4lI0p_big.jpg'),
(44319, 3069, 'The Disappearance S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135941.mp4', 'http://gstaticontent.com/images/wDw0ItLofAmLoMUYxVyhdK4lI0p_big.jpg'),
(44320, 3069, 'The Disappearance S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135942.mp4', 'http://gstaticontent.com/images/wDw0ItLofAmLoMUYxVyhdK4lI0p_big.jpg'),
(44321, 3069, 'The Disappearance S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135943.mp4', 'http://gstaticontent.com/images/wDw0ItLofAmLoMUYxVyhdK4lI0p_big.jpg'),
(44322, 3070, 'Cidade Invisível S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208451.mp4', 'http://gstaticontent.com/images/hh4uZv4lVkTBsBqtHCA5B4EMHBR_big.jpg'),
(44323, 3070, 'Cidade Invisível S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208452.mp4', 'http://gstaticontent.com/images/hh4uZv4lVkTBsBqtHCA5B4EMHBR_big.jpg'),
(44324, 3070, 'Cidade Invisível S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208453.mp4', 'http://gstaticontent.com/images/hh4uZv4lVkTBsBqtHCA5B4EMHBR_big.jpg'),
(44325, 3070, 'Cidade Invisível S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208454.mp4', 'http://gstaticontent.com/images/hh4uZv4lVkTBsBqtHCA5B4EMHBR_big.jpg'),
(44326, 3070, 'Cidade Invisível S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208455.mp4', 'http://gstaticontent.com/images/hh4uZv4lVkTBsBqtHCA5B4EMHBR_big.jpg'),
(44327, 3070, 'Cidade Invisível S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208456.mp4', 'http://gstaticontent.com/images/hh4uZv4lVkTBsBqtHCA5B4EMHBR_big.jpg'),
(44328, 3070, 'Cidade Invisível S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208457.mp4', 'http://gstaticontent.com/images/hh4uZv4lVkTBsBqtHCA5B4EMHBR_big.jpg'),
(44329, 3071, 'Cidade Invisível S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pqSBYDc3X9d4NdrnF15FNnrewDN.jpg'),
(44330, 3071, 'Cidade Invisível S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oFHqdv9Xk2QWGBXIjJ5W8ryyxEM.jpg'),
(44331, 3071, 'Cidade Invisível S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x8PYPteI15qTg4ph9TIx8BryjQu.jpg'),
(44332, 3071, 'Cidade Invisível S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bdFlL8F1kePD5Zmgm4qwcxUPR3e.jpg'),
(44333, 3071, 'Cidade Invisível S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aLeoOvfGjsrBcJxSaIGHfILQfiQ.jpg'),
(44334, 3072, 'Austin & Ally S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135411.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44335, 3072, 'Austin & Ally S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135412.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44336, 3072, 'Austin & Ally S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135413.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44337, 3072, 'Austin & Ally S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135414.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44338, 3072, 'Austin & Ally S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135415.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44339, 3072, 'Austin & Ally S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135416.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44340, 3072, 'Austin & Ally S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135417.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44341, 3072, 'Austin & Ally S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135418.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44342, 3072, 'Austin & Ally S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135419.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44343, 3072, 'Austin & Ally S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135420.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44344, 3072, 'Austin & Ally S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/135421.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44345, 3072, 'Austin & Ally S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/135422.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44346, 3072, 'Austin & Ally S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/135423.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44347, 3072, 'Austin & Ally S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/135424.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44348, 3072, 'Austin & Ally S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/135425.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44349, 3072, 'Austin & Ally S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/135426.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44350, 3072, 'Austin & Ally S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/135427.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44351, 3072, 'Austin & Ally S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/135428.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44352, 3072, 'Austin & Ally S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/135429.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44353, 3073, 'Austin & Ally S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135430.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44354, 3073, 'Austin & Ally S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135431.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44355, 3073, 'Austin & Ally S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135432.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44356, 3073, 'Austin & Ally S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135433.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44357, 3073, 'Austin & Ally S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135434.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44358, 3073, 'Austin & Ally S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135435.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44359, 3073, 'Austin & Ally S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135436.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44360, 3073, 'Austin & Ally S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135437.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44361, 3073, 'Austin & Ally S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135438.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44362, 3073, 'Austin & Ally S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135439.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44363, 3073, 'Austin & Ally S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/135440.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44364, 3073, 'Austin & Ally S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/135441.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44365, 3073, 'Austin & Ally S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/135442.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44366, 3073, 'Austin & Ally S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/135443.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44367, 3073, 'Austin & Ally S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/135444.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44368, 3073, 'Austin & Ally S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/135445.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44369, 3073, 'Austin & Ally S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/135446.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44370, 3073, 'Austin & Ally S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/135447.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44371, 3073, 'Austin & Ally S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/135448.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44372, 3073, 'Austin & Ally S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/135449.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44373, 3073, 'Austin & Ally S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/135450.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44374, 3073, 'Austin & Ally S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/135451.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44375, 3073, 'Austin & Ally S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/135452.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44376, 3073, 'Austin & Ally S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/135453.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44377, 3073, 'Austin & Ally S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/135454.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44378, 3073, 'Austin & Ally S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/135455.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44379, 3074, 'Austin & Ally S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135456.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44380, 3074, 'Austin & Ally S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135457.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44381, 3074, 'Austin & Ally S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135458.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44382, 3074, 'Austin & Ally S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135459.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44383, 3074, 'Austin & Ally S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135460.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44384, 3074, 'Austin & Ally S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135461.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44385, 3074, 'Austin & Ally S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135462.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44386, 3074, 'Austin & Ally S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135463.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44387, 3074, 'Austin & Ally S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135464.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44388, 3074, 'Austin & Ally S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135465.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(44389, 3074, 'Austin & Ally S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/135466.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44390, 3074, 'Austin & Ally S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/135467.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44391, 3074, 'Austin & Ally S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/135468.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44392, 3074, 'Austin & Ally S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/135469.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44393, 3074, 'Austin & Ally S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/135470.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44394, 3074, 'Austin & Ally S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/135471.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44395, 3074, 'Austin & Ally S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/135472.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44396, 3074, 'Austin & Ally S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/135473.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44397, 3074, 'Austin & Ally S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/135474.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44398, 3074, 'Austin & Ally S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/135475.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44399, 3074, 'Austin & Ally S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/135476.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44400, 3074, 'Austin & Ally S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/135477.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44401, 3075, 'Austin & Ally S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135478.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44402, 3075, 'Austin & Ally S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135479.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44403, 3075, 'Austin & Ally S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135480.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44404, 3075, 'Austin & Ally S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135481.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44405, 3075, 'Austin & Ally S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135482.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44406, 3075, 'Austin & Ally S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135483.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44407, 3075, 'Austin & Ally S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135484.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44408, 3075, 'Austin & Ally S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135485.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44409, 3075, 'Austin & Ally S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135486.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44410, 3075, 'Austin & Ally S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135487.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44411, 3075, 'Austin & Ally S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/135488.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44412, 3075, 'Austin & Ally S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/135489.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44413, 3075, 'Austin & Ally S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/135490.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44414, 3075, 'Austin & Ally S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/135491.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44415, 3075, 'Austin & Ally S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/135492.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44416, 3075, 'Austin & Ally S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/135493.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44417, 3075, 'Austin & Ally S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/135494.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44418, 3075, 'Austin & Ally S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/135495.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44419, 3075, 'Austin & Ally S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/135496.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44420, 3075, 'Austin & Ally S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/135497.mp4', 'http://gstaticontent.com/images/u1PzZqvPgxEnDbNYzjlaPR9mWhF_big.jpg'),
(44421, 3076, 'Cena do Crime: Mistério e Morte no Hotel Cecil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135407.mp4', 'http://gstaticontent.com/images/2JECBiHk8U8PIhswVd3Pthc13tG_big.jpg'),
(44422, 3076, 'Cena do Crime: Mistério e Morte no Hotel Cecil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135408.mp4', 'http://gstaticontent.com/images/2JECBiHk8U8PIhswVd3Pthc13tG_big.jpg'),
(44423, 3076, 'Cena do Crime: Mistério e Morte no Hotel Cecil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135409.mp4', 'http://gstaticontent.com/images/2JECBiHk8U8PIhswVd3Pthc13tG_big.jpg'),
(44424, 3076, 'Cena do Crime: Mistério e Morte no Hotel Cecil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135410.mp4', 'http://gstaticontent.com/images/2JECBiHk8U8PIhswVd3Pthc13tG_big.jpg'),
(44425, 3077, 'Filho Pródigo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149253.mp4', 'http://gstaticontent.com/images/rnXefHDdU73iK1YZiDlTZEPTl9C_big.jpg'),
(44426, 3077, 'Filho Pródigo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149254.mp4', 'http://gstaticontent.com/images/rnXefHDdU73iK1YZiDlTZEPTl9C_big.jpg'),
(44427, 3077, 'Filho Pródigo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149255.mp4', 'http://gstaticontent.com/images/rnXefHDdU73iK1YZiDlTZEPTl9C_big.jpg'),
(44428, 3077, 'Filho Pródigo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149256.mp4', 'http://gstaticontent.com/images/rnXefHDdU73iK1YZiDlTZEPTl9C_big.jpg'),
(44429, 3077, 'Filho Pródigo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149257.mp4', 'http://gstaticontent.com/images/rnXefHDdU73iK1YZiDlTZEPTl9C_big.jpg'),
(44430, 3077, 'Filho Pródigo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149258.mp4', 'http://gstaticontent.com/images/rnXefHDdU73iK1YZiDlTZEPTl9C_big.jpg'),
(44431, 3077, 'Filho Pródigo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149259.mp4', 'http://gstaticontent.com/images/rnXefHDdU73iK1YZiDlTZEPTl9C_big.jpg'),
(44432, 3077, 'Filho Pródigo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149260.mp4', 'http://gstaticontent.com/images/rnXefHDdU73iK1YZiDlTZEPTl9C_big.jpg'),
(44433, 3077, 'Filho Pródigo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149261.mp4', 'http://gstaticontent.com/images/rnXefHDdU73iK1YZiDlTZEPTl9C_big.jpg'),
(44434, 3077, 'Filho Pródigo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149262.mp4', 'http://gstaticontent.com/images/rnXefHDdU73iK1YZiDlTZEPTl9C_big.jpg'),
(44435, 3077, 'Filho Pródigo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149263.mp4', 'http://gstaticontent.com/images/rnXefHDdU73iK1YZiDlTZEPTl9C_big.jpg'),
(44436, 3077, 'Filho Pródigo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149264.mp4', 'http://gstaticontent.com/images/rnXefHDdU73iK1YZiDlTZEPTl9C_big.jpg'),
(44437, 3077, 'Filho Pródigo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/149265.mp4', 'http://gstaticontent.com/images/rnXefHDdU73iK1YZiDlTZEPTl9C_big.jpg'),
(44438, 3077, 'Filho Pródigo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/149266.mp4', 'http://gstaticontent.com/images/rnXefHDdU73iK1YZiDlTZEPTl9C_big.jpg'),
(44439, 3077, 'Filho Pródigo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/149267.mp4', 'http://gstaticontent.com/images/rnXefHDdU73iK1YZiDlTZEPTl9C_big.jpg'),
(44440, 3077, 'Filho Pródigo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/149268.mp4', 'http://gstaticontent.com/images/rnXefHDdU73iK1YZiDlTZEPTl9C_big.jpg'),
(44441, 3077, 'Filho Pródigo S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/149269.mp4', 'http://gstaticontent.com/images/rnXefHDdU73iK1YZiDlTZEPTl9C_big.jpg'),
(44442, 3077, 'Filho Pródigo S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/149270.mp4', 'http://gstaticontent.com/images/rnXefHDdU73iK1YZiDlTZEPTl9C_big.jpg'),
(44443, 3077, 'Filho Pródigo S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/149271.mp4', 'http://gstaticontent.com/images/rnXefHDdU73iK1YZiDlTZEPTl9C_big.jpg'),
(44444, 3077, 'Filho Pródigo S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/149272.mp4', 'http://gstaticontent.com/images/rnXefHDdU73iK1YZiDlTZEPTl9C_big.jpg'),
(44445, 3078, 'Filho Pródigo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149273.mp4', 'http://timg.bdta.pro/images/03b818c4e71343ca212d298b64547694.jpg'),
(44446, 3078, 'Filho Pródigo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149274.mp4', 'http://timg.bdta.pro/images/a44f30b4426e9cafc502031659dd77f2.jpg'),
(44447, 3078, 'Filho Pródigo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149275.mp4', 'http://timg.bdta.pro/images/e4a49c62f255b11d8f8f6792f4a8da8f.jpg'),
(44448, 3078, 'Filho Pródigo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149276.mp4', 'http://timg.bdta.pro/images/b64e23db33b0ac8334822661fdbeccf4.jpg'),
(44449, 3078, 'Filho Pródigo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149277.mp4', 'http://timg.bdta.pro/images/cb44369a5fad8f38a962d778aaf766f4.jpg'),
(44450, 3078, 'Filho Pródigo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149278.mp4', 'http://timg.bdta.pro/images/105788c00552935a80136ebc9d73e93f.jpg'),
(44451, 3078, 'Filho Pródigo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149279.mp4', 'http://timg.bdta.pro/images/2a3e7e21d8b30df9a198db6332fa363d.jpg'),
(44452, 3078, 'Filho Pródigo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149280.mp4', 'http://timg.bdta.pro/images/5de20bf2b3ea55bb54b2352c5d805163.jpg'),
(44453, 3078, 'Filho Pródigo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149281.mp4', 'http://timg.bdta.pro/images/813976957f783bef28fe70426b5a1405.jpg'),
(44454, 3078, 'Filho Pródigo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149282.mp4', 'http://timg.bdta.pro/images/c90c8f7aa43fe2bef1cf3d552893696d.jpg'),
(44455, 3078, 'Filho Pródigo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149283.mp4', 'http://timg.bdta.pro/images/b9877d1d0baede319352dd90026ef52c.jpg'),
(44456, 3078, 'Filho Pródigo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149284.mp4', 'http://timg.bdta.pro/images/68a900fd099e723c31aca3eece4ec98b.jpg'),
(44457, 3078, 'Filho Pródigo S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/149285.mp4', 'http://timg.bdta.pro/images/1f4d51d1e0be3deb213a1962c1a8b2ed.jpg'),
(44458, 3079, 'Hache S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135399.mp4', 'http://gstaticontent.com/images/yScOKZTBlug31LF89M3Dccymw5b_big.jpg'),
(44459, 3079, 'Hache S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135400.mp4', 'http://gstaticontent.com/images/yScOKZTBlug31LF89M3Dccymw5b_big.jpg'),
(44460, 3079, 'Hache S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135401.mp4', 'http://gstaticontent.com/images/yScOKZTBlug31LF89M3Dccymw5b_big.jpg'),
(44461, 3079, 'Hache S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135402.mp4', 'http://gstaticontent.com/images/yScOKZTBlug31LF89M3Dccymw5b_big.jpg'),
(44462, 3079, 'Hache S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135403.mp4', 'http://gstaticontent.com/images/yScOKZTBlug31LF89M3Dccymw5b_big.jpg'),
(44463, 3079, 'Hache S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135404.mp4', 'http://gstaticontent.com/images/yScOKZTBlug31LF89M3Dccymw5b_big.jpg'),
(44464, 3079, 'Hache S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135405.mp4', 'http://gstaticontent.com/images/yScOKZTBlug31LF89M3Dccymw5b_big.jpg'),
(44465, 3079, 'Hache S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135406.mp4', 'http://gstaticontent.com/images/yScOKZTBlug31LF89M3Dccymw5b_big.jpg'),
(44466, 3080, 'Sem Limites S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135377.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44467, 3080, 'Sem Limites S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135378.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44468, 3080, 'Sem Limites S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135379.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44469, 3080, 'Sem Limites S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135380.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44470, 3080, 'Sem Limites S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135381.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44471, 3080, 'Sem Limites S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135382.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44472, 3080, 'Sem Limites S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135383.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44473, 3080, 'Sem Limites S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135384.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44474, 3080, 'Sem Limites S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135385.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44475, 3080, 'Sem Limites S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135386.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44476, 3080, 'Sem Limites S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/135387.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44477, 3080, 'Sem Limites S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/135388.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44478, 3080, 'Sem Limites S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/135389.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44479, 3080, 'Sem Limites S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/135390.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44480, 3080, 'Sem Limites S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/135391.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44481, 3080, 'Sem Limites S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/135392.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44482, 3080, 'Sem Limites S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/135393.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44483, 3080, 'Sem Limites S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/135394.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44484, 3080, 'Sem Limites S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/135395.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44485, 3080, 'Sem Limites S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/135396.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44486, 3080, 'Sem Limites S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/135397.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44487, 3080, 'Sem Limites S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/135398.mp4', 'http://gstaticontent.com/images/p7a2DPQUGh5x18Rt9immmVmdZFV_big.jpg'),
(44488, 3081, 'Soulmates S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135371.mp4', 'http://gstaticontent.com/images/rh4Rx4q9TtHyaqDFwORKnHNGyIq_big.jpg'),
(44489, 3081, 'Soulmates S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135372.mp4', 'http://gstaticontent.com/images/rh4Rx4q9TtHyaqDFwORKnHNGyIq_big.jpg'),
(44490, 3081, 'Soulmates S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135373.mp4', 'http://gstaticontent.com/images/rh4Rx4q9TtHyaqDFwORKnHNGyIq_big.jpg'),
(44491, 3081, 'Soulmates S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135374.mp4', 'http://gstaticontent.com/images/rh4Rx4q9TtHyaqDFwORKnHNGyIq_big.jpg'),
(44492, 3081, 'Soulmates S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135375.mp4', 'http://gstaticontent.com/images/rh4Rx4q9TtHyaqDFwORKnHNGyIq_big.jpg'),
(44493, 3081, 'Soulmates S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135376.mp4', 'http://gstaticontent.com/images/rh4Rx4q9TtHyaqDFwORKnHNGyIq_big.jpg'),
(44494, 3082, 'Steven Universo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135197.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44495, 3082, 'Steven Universo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135198.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44496, 3082, 'Steven Universo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135199.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44497, 3082, 'Steven Universo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135200.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44498, 3082, 'Steven Universo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135201.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44499, 3082, 'Steven Universo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135202.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44500, 3082, 'Steven Universo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135203.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44501, 3082, 'Steven Universo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135204.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44502, 3082, 'Steven Universo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135205.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44503, 3082, 'Steven Universo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135206.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44504, 3082, 'Steven Universo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/135207.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44505, 3082, 'Steven Universo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/135208.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44506, 3082, 'Steven Universo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/135209.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44507, 3082, 'Steven Universo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/135210.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44508, 3082, 'Steven Universo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/135211.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44509, 3082, 'Steven Universo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/135212.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44510, 3082, 'Steven Universo S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/135213.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44511, 3082, 'Steven Universo S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/135214.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44512, 3082, 'Steven Universo S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/135215.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44513, 3082, 'Steven Universo S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/135216.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44514, 3082, 'Steven Universo S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/135217.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44515, 3082, 'Steven Universo S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/135218.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44516, 3082, 'Steven Universo S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/135219.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44517, 3082, 'Steven Universo S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/135220.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44518, 3082, 'Steven Universo S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/135221.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44519, 3082, 'Steven Universo S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/135222.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44520, 3082, 'Steven Universo S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/135223.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44521, 3082, 'Steven Universo S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/135224.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44522, 3082, 'Steven Universo S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/135225.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44523, 3082, 'Steven Universo S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/135226.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44524, 3082, 'Steven Universo S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/135227.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44525, 3082, 'Steven Universo S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/135228.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44526, 3082, 'Steven Universo S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/135229.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44527, 3082, 'Steven Universo S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/135230.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44528, 3082, 'Steven Universo S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/135231.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44529, 3082, 'Steven Universo S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/135232.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44530, 3082, 'Steven Universo S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/135233.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44531, 3082, 'Steven Universo S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/135234.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44532, 3082, 'Steven Universo S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/135235.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44533, 3082, 'Steven Universo S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/135236.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44534, 3082, 'Steven Universo S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/135237.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44535, 3082, 'Steven Universo S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/135238.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44536, 3082, 'Steven Universo S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/135239.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44537, 3082, 'Steven Universo S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/135240.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44538, 3082, 'Steven Universo S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/135241.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44539, 3082, 'Steven Universo S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/135242.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44540, 3082, 'Steven Universo S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/135243.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44541, 3082, 'Steven Universo S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/135244.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44542, 3082, 'Steven Universo S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/135245.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44543, 3082, 'Steven Universo S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/135246.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44544, 3082, 'Steven Universo S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/135247.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44545, 3082, 'Steven Universo S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/135248.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44546, 3082, 'Steven Universo S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/135249.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44547, 3083, 'Steven Universo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135250.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44548, 3083, 'Steven Universo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135251.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44549, 3083, 'Steven Universo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135252.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44550, 3083, 'Steven Universo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135253.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44551, 3083, 'Steven Universo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135254.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44552, 3083, 'Steven Universo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135255.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44553, 3083, 'Steven Universo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135256.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44554, 3083, 'Steven Universo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135257.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44555, 3083, 'Steven Universo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135258.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44556, 3083, 'Steven Universo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135259.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44557, 3083, 'Steven Universo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/135260.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44558, 3083, 'Steven Universo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/135261.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44559, 3083, 'Steven Universo S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/135262.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44560, 3083, 'Steven Universo S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/135263.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44561, 3083, 'Steven Universo S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/135264.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44562, 3083, 'Steven Universo S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/135265.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44563, 3083, 'Steven Universo S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/135266.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44564, 3083, 'Steven Universo S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/135267.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44565, 3083, 'Steven Universo S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/135268.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44566, 3083, 'Steven Universo S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/135269.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44567, 3083, 'Steven Universo S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/135270.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44568, 3083, 'Steven Universo S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/135271.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44569, 3083, 'Steven Universo S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/135272.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44570, 3083, 'Steven Universo S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/135273.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44571, 3083, 'Steven Universo S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/135274.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44572, 3084, 'Steven Universo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135275.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44573, 3084, 'Steven Universo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135276.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44574, 3084, 'Steven Universo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135277.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44575, 3084, 'Steven Universo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135278.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44576, 3084, 'Steven Universo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135279.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44577, 3084, 'Steven Universo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135280.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44578, 3084, 'Steven Universo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135281.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44579, 3084, 'Steven Universo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135282.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44580, 3084, 'Steven Universo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135283.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44581, 3084, 'Steven Universo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135284.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44582, 3084, 'Steven Universo S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/135285.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44583, 3084, 'Steven Universo S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/135286.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44584, 3084, 'Steven Universo S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/135287.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44585, 3084, 'Steven Universo S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/135288.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44586, 3084, 'Steven Universo S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/135289.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44587, 3084, 'Steven Universo S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/135290.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44588, 3084, 'Steven Universo S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/135291.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44589, 3084, 'Steven Universo S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/135292.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44590, 3084, 'Steven Universo S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/135293.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44591, 3084, 'Steven Universo S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/135294.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44592, 3084, 'Steven Universo S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/135295.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44593, 3084, 'Steven Universo S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/135296.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44594, 3084, 'Steven Universo S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/135297.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44595, 3084, 'Steven Universo S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/135298.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44596, 3085, 'Steven Universo S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135299.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44597, 3085, 'Steven Universo S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135300.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44598, 3085, 'Steven Universo S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135301.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44599, 3085, 'Steven Universo S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135302.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44600, 3085, 'Steven Universo S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135303.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44601, 3085, 'Steven Universo S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135304.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44602, 3085, 'Steven Universo S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135305.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44603, 3085, 'Steven Universo S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135306.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44604, 3085, 'Steven Universo S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135307.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44605, 3085, 'Steven Universo S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135308.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44606, 3085, 'Steven Universo S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/135309.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44607, 3085, 'Steven Universo S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/135310.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44608, 3085, 'Steven Universo S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/135311.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44609, 3085, 'Steven Universo S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/135312.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44610, 3085, 'Steven Universo S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/135313.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44611, 3085, 'Steven Universo S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/135314.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44612, 3085, 'Steven Universo S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/135315.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44613, 3085, 'Steven Universo S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/135316.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44614, 3085, 'Steven Universo S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/135317.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44615, 3085, 'Steven Universo S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/135318.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44616, 3085, 'Steven Universo S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/135319.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44617, 3085, 'Steven Universo S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/135320.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44618, 3085, 'Steven Universo S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/135321.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44619, 3085, 'Steven Universo S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/135322.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44620, 3086, 'Steven Universo S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135323.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44621, 3086, 'Steven Universo S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135324.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44622, 3086, 'Steven Universo S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135325.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44623, 3086, 'Steven Universo S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135326.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44624, 3086, 'Steven Universo S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135327.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44625, 3086, 'Steven Universo S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135328.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44626, 3086, 'Steven Universo S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135329.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44627, 3086, 'Steven Universo S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135330.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44628, 3086, 'Steven Universo S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135331.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44629, 3086, 'Steven Universo S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135332.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44630, 3086, 'Steven Universo S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/135333.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44631, 3086, 'Steven Universo S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/135334.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44632, 3086, 'Steven Universo S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/135335.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44633, 3086, 'Steven Universo S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/135336.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44634, 3086, 'Steven Universo S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/135337.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44635, 3086, 'Steven Universo S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/135338.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44636, 3086, 'Steven Universo S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/135339.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44637, 3086, 'Steven Universo S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/135340.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44638, 3086, 'Steven Universo S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/135341.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44639, 3086, 'Steven Universo S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/135342.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44640, 3086, 'Steven Universo S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/135343.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44641, 3086, 'Steven Universo S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/135344.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44642, 3086, 'Steven Universo S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/135345.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44643, 3086, 'Steven Universo S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/135346.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44644, 3086, 'Steven Universo S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/135347.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44645, 3086, 'Steven Universo S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/135348.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44646, 3086, 'Steven Universo S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/135349.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44647, 3086, 'Steven Universo S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/135350.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44648, 3087, 'Steven Universo S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135351.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44649, 3087, 'Steven Universo S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135352.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44650, 3087, 'Steven Universo S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135353.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44651, 3087, 'Steven Universo S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135354.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44652, 3087, 'Steven Universo S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135355.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44653, 3087, 'Steven Universo S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135356.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44654, 3087, 'Steven Universo S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135357.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44655, 3087, 'Steven Universo S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135358.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44656, 3087, 'Steven Universo S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135359.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44657, 3087, 'Steven Universo S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135360.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44658, 3087, 'Steven Universo S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/135361.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44659, 3087, 'Steven Universo S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/135362.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44660, 3087, 'Steven Universo S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/135363.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44661, 3087, 'Steven Universo S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/135364.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44662, 3087, 'Steven Universo S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/135365.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44663, 3087, 'Steven Universo S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/135366.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44664, 3087, 'Steven Universo S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/135367.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44665, 3087, 'Steven Universo S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/135368.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44666, 3087, 'Steven Universo S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/135369.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44667, 3087, 'Steven Universo S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/135370.mp4', 'http://gstaticontent.com/images/g31ZPZSjv8ySPbclyYZZU50XhZy_big.jpg'),
(44668, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214153.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44669, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214154.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44670, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214155.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44671, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214156.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44672, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214157.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(44673, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214158.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44674, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214159.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44675, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214160.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44676, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214161.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44677, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214162.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44678, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214163.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44679, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214164.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44680, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214165.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44681, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214166.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44682, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214167.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44683, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214168.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44684, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214169.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44685, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214170.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44686, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214171.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44687, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214172.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44688, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214173.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44689, 3088, 'Lei & Ordem: Unidade de Vítimas Especiais S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214174.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44690, 3089, 'Lei & Ordem: Unidade de Vítimas Especiais S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214175.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44691, 3089, 'Lei & Ordem: Unidade de Vítimas Especiais S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214176.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44692, 3089, 'Lei & Ordem: Unidade de Vítimas Especiais S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214177.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44693, 3089, 'Lei & Ordem: Unidade de Vítimas Especiais S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214178.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44694, 3089, 'Lei & Ordem: Unidade de Vítimas Especiais S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214179.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44695, 3089, 'Lei & Ordem: Unidade de Vítimas Especiais S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214180.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44696, 3089, 'Lei & Ordem: Unidade de Vítimas Especiais S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214181.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44697, 3089, 'Lei & Ordem: Unidade de Vítimas Especiais S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214182.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44698, 3089, 'Lei & Ordem: Unidade de Vítimas Especiais S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214183.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44699, 3089, 'Lei & Ordem: Unidade de Vítimas Especiais S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214184.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44700, 3089, 'Lei & Ordem: Unidade de Vítimas Especiais S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214185.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44701, 3089, 'Lei & Ordem: Unidade de Vítimas Especiais S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214186.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44702, 3089, 'Lei & Ordem: Unidade de Vítimas Especiais S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214187.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44703, 3089, 'Lei & Ordem: Unidade de Vítimas Especiais S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214188.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44704, 3089, 'Lei & Ordem: Unidade de Vítimas Especiais S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214189.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44705, 3089, 'Lei & Ordem: Unidade de Vítimas Especiais S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214190.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44706, 3089, 'Lei & Ordem: Unidade de Vítimas Especiais S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214191.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44707, 3089, 'Lei & Ordem: Unidade de Vítimas Especiais S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214192.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44708, 3089, 'Lei & Ordem: Unidade de Vítimas Especiais S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214193.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44709, 3089, 'Lei & Ordem: Unidade de Vítimas Especiais S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214194.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44710, 3089, 'Lei & Ordem: Unidade de Vítimas Especiais S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214195.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44711, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214196.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44712, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214197.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44713, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214198.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44714, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214199.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44715, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214200.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44716, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214201.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44717, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214202.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44718, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214203.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44719, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214204.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44720, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214205.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44721, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214206.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44722, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214207.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44723, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214208.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44724, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214209.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44725, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214210.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44726, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214211.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44727, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214212.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44728, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214213.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44729, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214214.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44730, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214215.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44731, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214216.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44732, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214217.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44733, 3090, 'Lei & Ordem: Unidade de Vítimas Especiais S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/214218.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44734, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214219.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44735, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214220.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44736, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214221.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44737, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214222.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44738, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214223.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44739, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214224.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44740, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214225.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44741, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214226.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44742, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214227.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44743, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214228.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44744, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214229.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44745, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214230.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44746, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214231.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44747, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214232.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44748, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214233.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44749, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214234.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44750, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214235.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44751, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214236.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44752, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214237.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44753, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214238.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44754, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214239.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44755, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214240.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44756, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/214241.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44757, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/214242.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44758, 3091, 'Lei & Ordem: Unidade de Vítimas Especiais S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/214243.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44759, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214244.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44760, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214245.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44761, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214246.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44762, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214247.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44763, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214248.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44764, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214249.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44765, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214250.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44766, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214251.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44767, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214252.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44768, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214253.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44769, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214254.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44770, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214255.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44771, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214256.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44772, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214257.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44773, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214258.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44774, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214259.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44775, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214260.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44776, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214261.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44777, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214262.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44778, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214263.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44779, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214264.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44780, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214265.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44781, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/214266.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44782, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/214267.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44783, 3092, 'Lei & Ordem: Unidade de Vítimas Especiais S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/214268.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44784, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214269.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44785, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214270.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44786, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214271.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44787, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214272.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44788, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214273.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44789, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214274.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44790, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214275.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44791, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214276.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44792, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214277.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44793, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214278.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44794, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214279.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44795, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214280.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44796, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214281.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44797, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214282.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44798, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214283.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44799, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214284.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44800, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214285.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44801, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214286.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44802, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214287.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44803, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214288.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44804, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214289.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44805, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214290.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44806, 3093, 'Lei & Ordem: Unidade de Vítimas Especiais S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/214291.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44807, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214292.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44808, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214293.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44809, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214294.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44810, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214295.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44811, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214296.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44812, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214297.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44813, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214298.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44814, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214299.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44815, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214300.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44816, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214301.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44817, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214302.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44818, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214303.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44819, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214304.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44820, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214305.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44821, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214306.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44822, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214307.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44823, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214308.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44824, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214309.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44825, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214310.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44826, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214311.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44827, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214312.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44828, 3094, 'Lei & Ordem: Unidade de Vítimas Especiais S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214313.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44829, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214314.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44830, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214315.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44831, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214316.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44832, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214317.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44833, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214318.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44834, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214319.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44835, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214320.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44836, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214321.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44837, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214322.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44838, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214323.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44839, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214324.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44840, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214325.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44841, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214326.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44842, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214327.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44843, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214328.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44844, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214329.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44845, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214330.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44846, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214331.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44847, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214332.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44848, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214333.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44849, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214334.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44850, 3095, 'Lei & Ordem: Unidade de Vítimas Especiais S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214335.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44851, 3096, 'Lei & Ordem: Unidade de Vítimas Especiais S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214336.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44852, 3096, 'Lei & Ordem: Unidade de Vítimas Especiais S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214337.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44853, 3096, 'Lei & Ordem: Unidade de Vítimas Especiais S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214338.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44854, 3096, 'Lei & Ordem: Unidade de Vítimas Especiais S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214339.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44855, 3096, 'Lei & Ordem: Unidade de Vítimas Especiais S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214340.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44856, 3096, 'Lei & Ordem: Unidade de Vítimas Especiais S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214341.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44857, 3096, 'Lei & Ordem: Unidade de Vítimas Especiais S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214342.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44858, 3096, 'Lei & Ordem: Unidade de Vítimas Especiais S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214343.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44859, 3096, 'Lei & Ordem: Unidade de Vítimas Especiais S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214344.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44860, 3096, 'Lei & Ordem: Unidade de Vítimas Especiais S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214345.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44861, 3096, 'Lei & Ordem: Unidade de Vítimas Especiais S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214346.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44862, 3096, 'Lei & Ordem: Unidade de Vítimas Especiais S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214347.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44863, 3096, 'Lei & Ordem: Unidade de Vítimas Especiais S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214348.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44864, 3096, 'Lei & Ordem: Unidade de Vítimas Especiais S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214349.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44865, 3096, 'Lei & Ordem: Unidade de Vítimas Especiais S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214350.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44866, 3096, 'Lei & Ordem: Unidade de Vítimas Especiais S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214351.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44867, 3096, 'Lei & Ordem: Unidade de Vítimas Especiais S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214352.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44868, 3096, 'Lei & Ordem: Unidade de Vítimas Especiais S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214353.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44869, 3096, 'Lei & Ordem: Unidade de Vítimas Especiais S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214354.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44870, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214355.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44871, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214356.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44872, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214357.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44873, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214358.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44874, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214359.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44875, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214360.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44876, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214361.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44877, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214362.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44878, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214363.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44879, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214364.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44880, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214365.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44881, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214366.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44882, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214367.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44883, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214368.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44884, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214369.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44885, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214370.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44886, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214371.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44887, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214372.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44888, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214373.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44889, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214374.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44890, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214375.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44891, 3097, 'Lei & Ordem: Unidade de Vítimas Especiais S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214376.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44892, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214377.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44893, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214378.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44894, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214379.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44895, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214380.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44896, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214381.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44897, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214382.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44898, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214383.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44899, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214384.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44900, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214385.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44901, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214386.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44902, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214387.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44903, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214388.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44904, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214389.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44905, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214390.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44906, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214391.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44907, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214392.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44908, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214393.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44909, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214394.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44910, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214395.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44911, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214396.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44912, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214397.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44913, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214398.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44914, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E23', 'http://sinalprivado.info:80/series/1533784/1533784/214399.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44915, 3098, 'Lei & Ordem: Unidade de Vítimas Especiais S11 E24', 'http://sinalprivado.info:80/series/1533784/1533784/214400.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44916, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214401.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44917, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214402.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44918, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214403.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44919, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214404.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44920, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214405.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44921, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214406.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44922, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214407.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(44923, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214408.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44924, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214409.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44925, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214410.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44926, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214411.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44927, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214412.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44928, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214413.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44929, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214414.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44930, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214415.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44931, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214416.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44932, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214417.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44933, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214418.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44934, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214419.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44935, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214420.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44936, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214421.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44937, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214422.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44938, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E23', 'http://sinalprivado.info:80/series/1533784/1533784/214423.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44939, 3099, 'Lei & Ordem: Unidade de Vítimas Especiais S12 E24', 'http://sinalprivado.info:80/series/1533784/1533784/214424.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44940, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214425.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44941, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214426.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44942, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214427.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44943, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214428.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44944, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214429.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44945, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214430.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44946, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214431.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44947, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214432.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44948, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214433.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44949, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214434.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44950, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214435.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44951, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214436.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44952, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214437.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44953, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214438.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44954, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214439.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44955, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214440.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44956, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214441.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44957, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214442.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44958, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214443.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44959, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214444.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44960, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214445.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44961, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214446.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44962, 3100, 'Lei & Ordem: Unidade de Vítimas Especiais S13 E23', 'http://sinalprivado.info:80/series/1533784/1533784/214447.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44963, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214448.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44964, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214449.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44965, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214450.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44966, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214451.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44967, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214452.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44968, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214453.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44969, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214454.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44970, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214455.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44971, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214456.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44972, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214457.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44973, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214458.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44974, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214459.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44975, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214460.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44976, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214461.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44977, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214462.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44978, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214463.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44979, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214464.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44980, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214465.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44981, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214466.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44982, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214467.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44983, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214468.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44984, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214469.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44985, 3101, 'Lei & Ordem: Unidade de Vítimas Especiais S14 E23', 'http://sinalprivado.info:80/series/1533784/1533784/214470.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44986, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214471.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44987, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214472.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44988, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214473.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44989, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214474.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44990, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214475.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44991, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214476.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44992, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214477.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44993, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214478.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44994, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214479.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44995, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214480.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44996, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214481.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44997, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214482.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44998, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214483.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(44999, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214484.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45000, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214485.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45001, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214486.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45002, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214487.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45003, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214488.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45004, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214489.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45005, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214490.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45006, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214491.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45007, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214492.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45008, 3102, 'Lei & Ordem: Unidade de Vítimas Especiais S15 E23', 'http://sinalprivado.info:80/series/1533784/1533784/214493.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45009, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214494.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45010, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214495.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45011, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214496.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45012, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214497.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45013, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214498.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45014, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214499.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45015, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214500.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45016, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214501.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45017, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214502.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45018, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214503.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45019, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214504.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45020, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214505.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45021, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214506.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45022, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214507.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45023, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214508.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45024, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214509.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45025, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214510.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45026, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214511.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45027, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214512.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45028, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214513.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45029, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214514.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45030, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214515.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45031, 3103, 'Lei & Ordem: Unidade de Vítimas Especiais S16 E23', 'http://sinalprivado.info:80/series/1533784/1533784/214516.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45032, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214517.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45033, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214518.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45034, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214519.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45035, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214520.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45036, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214521.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45037, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214522.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45038, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214523.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45039, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214524.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45040, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214525.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45041, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214526.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45042, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214527.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45043, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214528.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45044, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214529.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45045, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214530.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45046, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214531.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45047, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214532.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45048, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214533.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45049, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214534.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45050, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214535.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45051, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214536.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45052, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214537.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45053, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214538.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45054, 3104, 'Lei & Ordem: Unidade de Vítimas Especiais S17 E23', 'http://sinalprivado.info:80/series/1533784/1533784/214539.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45055, 3105, 'Lei & Ordem: Unidade de Vítimas Especiais S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214540.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45056, 3105, 'Lei & Ordem: Unidade de Vítimas Especiais S18 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214541.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45057, 3105, 'Lei & Ordem: Unidade de Vítimas Especiais S18 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214542.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45058, 3105, 'Lei & Ordem: Unidade de Vítimas Especiais S18 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214543.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45059, 3105, 'Lei & Ordem: Unidade de Vítimas Especiais S18 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214544.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45060, 3105, 'Lei & Ordem: Unidade de Vítimas Especiais S18 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214545.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45061, 3105, 'Lei & Ordem: Unidade de Vítimas Especiais S18 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214546.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45062, 3105, 'Lei & Ordem: Unidade de Vítimas Especiais S18 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214547.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45063, 3105, 'Lei & Ordem: Unidade de Vítimas Especiais S18 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214548.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45064, 3105, 'Lei & Ordem: Unidade de Vítimas Especiais S18 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214549.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45065, 3105, 'Lei & Ordem: Unidade de Vítimas Especiais S18 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214550.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45066, 3105, 'Lei & Ordem: Unidade de Vítimas Especiais S18 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214551.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45067, 3105, 'Lei & Ordem: Unidade de Vítimas Especiais S18 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214552.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45068, 3105, 'Lei & Ordem: Unidade de Vítimas Especiais S18 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214553.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45069, 3105, 'Lei & Ordem: Unidade de Vítimas Especiais S18 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214554.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45070, 3105, 'Lei & Ordem: Unidade de Vítimas Especiais S18 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214555.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45071, 3105, 'Lei & Ordem: Unidade de Vítimas Especiais S18 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214556.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45072, 3105, 'Lei & Ordem: Unidade de Vítimas Especiais S18 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214557.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45073, 3105, 'Lei & Ordem: Unidade de Vítimas Especiais S18 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214558.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45074, 3105, 'Lei & Ordem: Unidade de Vítimas Especiais S18 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214559.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45075, 3105, 'Lei & Ordem: Unidade de Vítimas Especiais S18 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214560.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45076, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214561.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45077, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214562.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45078, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214563.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45079, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214564.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45080, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214565.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45081, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214566.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45082, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214567.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45083, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214568.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45084, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214569.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45085, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214570.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45086, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214571.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45087, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214572.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45088, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214573.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45089, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214574.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45090, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214575.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45091, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214576.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45092, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214577.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45093, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214578.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45094, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214579.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45095, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214580.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45096, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214581.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45097, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214582.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45098, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E23', 'http://sinalprivado.info:80/series/1533784/1533784/214583.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45099, 3106, 'Lei & Ordem: Unidade de Vítimas Especiais S19 E24', 'http://sinalprivado.info:80/series/1533784/1533784/214584.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45100, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214585.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45101, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214586.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45102, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214587.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45103, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214588.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45104, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214589.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45105, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214590.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45106, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214591.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45107, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214592.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45108, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214593.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45109, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214594.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45110, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214595.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45111, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214596.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45112, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214597.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45113, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214598.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45114, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214599.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45115, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214600.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45116, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214601.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45117, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214602.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45118, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214603.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45119, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214604.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45120, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214605.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45121, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214606.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45122, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E23', 'http://sinalprivado.info:80/series/1533784/1533784/214607.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45123, 3107, 'Lei & Ordem: Unidade de Vítimas Especiais S20 E24', 'http://sinalprivado.info:80/series/1533784/1533784/214608.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45124, 3108, 'Lei & Ordem: Unidade de Vítimas Especiais S21 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214609.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45125, 3108, 'Lei & Ordem: Unidade de Vítimas Especiais S21 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214610.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45126, 3108, 'Lei & Ordem: Unidade de Vítimas Especiais S21 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214611.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45127, 3108, 'Lei & Ordem: Unidade de Vítimas Especiais S21 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214612.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45128, 3108, 'Lei & Ordem: Unidade de Vítimas Especiais S21 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214613.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45129, 3108, 'Lei & Ordem: Unidade de Vítimas Especiais S21 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214614.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45130, 3108, 'Lei & Ordem: Unidade de Vítimas Especiais S21 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214615.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45131, 3108, 'Lei & Ordem: Unidade de Vítimas Especiais S21 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214616.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45132, 3108, 'Lei & Ordem: Unidade de Vítimas Especiais S21 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214617.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45133, 3108, 'Lei & Ordem: Unidade de Vítimas Especiais S21 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214618.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45134, 3108, 'Lei & Ordem: Unidade de Vítimas Especiais S21 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214619.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45135, 3108, 'Lei & Ordem: Unidade de Vítimas Especiais S21 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214620.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45136, 3108, 'Lei & Ordem: Unidade de Vítimas Especiais S21 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214621.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45137, 3108, 'Lei & Ordem: Unidade de Vítimas Especiais S21 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214622.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45138, 3108, 'Lei & Ordem: Unidade de Vítimas Especiais S21 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214623.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45139, 3108, 'Lei & Ordem: Unidade de Vítimas Especiais S21 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214624.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45140, 3108, 'Lei & Ordem: Unidade de Vítimas Especiais S21 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214625.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45141, 3108, 'Lei & Ordem: Unidade de Vítimas Especiais S21 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214626.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45142, 3108, 'Lei & Ordem: Unidade de Vítimas Especiais S21 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214627.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45143, 3108, 'Lei & Ordem: Unidade de Vítimas Especiais S21 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214628.mp4', 'http://imagecdn.sh:80/images/vVK1fXFEDjvwBJW6PEeuJUgRLxk_big.jpg'),
(45144, 3109, 'Lei & Ordem: Unidade de Vítimas Especiais S22 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yT9lTUkwbGV64wN0rqW7DubKp0h.jpg'),
(45145, 3109, 'Lei & Ordem: Unidade de Vítimas Especiais S22 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/40YJOXudRI5E5p5I35A8IYNty1g.jpg'),
(45146, 3109, 'Lei & Ordem: Unidade de Vítimas Especiais S22 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zD4OYUctQk8IWQGY7jNgL7N9JMa.jpg'),
(45147, 3109, 'Lei & Ordem: Unidade de Vítimas Especiais S22 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/20JkHQlrpBEOGe3eFCmkSsV9SaP.jpg'),
(45148, 3109, 'Lei & Ordem: Unidade de Vítimas Especiais S22 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8hT41fvOybnEq3dB2uL39HrSEsZ.jpg'),
(45149, 3109, 'Lei & Ordem: Unidade de Vítimas Especiais S22 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1VqeFbb5CKrZLQMAPqwIthM3pbT.jpg'),
(45150, 3109, 'Lei & Ordem: Unidade de Vítimas Especiais S22 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rrC1UakjhHaLq1rmPNTKB4nz0Xa.jpg'),
(45151, 3109, 'Lei & Ordem: Unidade de Vítimas Especiais S22 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s6Kgc2yndcpZe1hTVmvf889JFW4.jpg'),
(45152, 3109, 'Lei & Ordem: Unidade de Vítimas Especiais S22 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Qn3hOBiHtzHVhaOEMSpxbiPdAs.jpg'),
(45153, 3109, 'Lei & Ordem: Unidade de Vítimas Especiais S22 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gIj4diGJzIH75ySZK6ixxo20G7b.jpg'),
(45154, 3109, 'Lei & Ordem: Unidade de Vítimas Especiais S22 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1QYc4P26tVzkcCOcbpfj4kwIW3s.jpg'),
(45155, 3109, 'Lei & Ordem: Unidade de Vítimas Especiais S22 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kagsfb5PZ3OrQM3LijRAIymZFCz.jpg'),
(45156, 3109, 'Lei & Ordem: Unidade de Vítimas Especiais S22 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhgfnlm8bYPnuLVtzVaMjNKzFg9.jpg'),
(45157, 3109, 'Lei & Ordem: Unidade de Vítimas Especiais S22 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hxx3vL9Mvxa3QXWUMCv1H8YYtYz.jpg'),
(45158, 3109, 'Lei & Ordem: Unidade de Vítimas Especiais S22 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/MDON3UfrSf6zauToDeQLAVohCL.jpg'),
(45159, 3109, 'Lei & Ordem: Unidade de Vítimas Especiais S22 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/geMPX60gevizzBD3HN5Cs6x4Po.jpg'),
(45160, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214645.mp4', 'http://timg.bdta.pro/images/e86b7a4ef00dba7bff1f313d0eed73e4.jpg'),
(45161, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214646.mp4', 'http://timg.bdta.pro/images/38469271640c2879b91df7a1d4186df7.jpg'),
(45162, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214647.mp4', 'http://timg.bdta.pro/images/2f47385c60518767071adf0c07fe0f05.jpg'),
(45163, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214648.mp4', 'http://timg.bdta.pro/images/2b2ac86b7611754a640b342e3abfde00.jpg'),
(45164, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214649.mp4', 'http://timg.bdta.pro/images/b97e0d41fe24b9a51095adee3360ea59.jpg'),
(45165, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214650.mp4', 'http://timg.bdta.pro/images/a5e8ecfd0dd5ccec51762ea533a159a1.jpg'),
(45166, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214651.mp4', 'http://timg.bdta.pro/images/111fc34c6c5e4312002e95a4a1bd3ed6.jpg'),
(45167, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214652.mp4', 'http://timg.bdta.pro/images/db15704fb1186a808a147ff785062cc9.jpg'),
(45168, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214653.mp4', 'http://timg.bdta.pro/images/74b217c7c7fadb8ae7e06422c4c67d88.jpg'),
(45169, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214654.mp4', 'http://timg.bdta.pro/images/b83e74b30cb9ebf19f012e0253f9f17b.jpg'),
(45170, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214655.mp4', 'http://timg.bdta.pro/images/3fc9d2e1c57ad4e1168a553324763496.jpg'),
(45171, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214656.mp4', 'http://timg.bdta.pro/images/5dd22b166f4318cebcef3340acf147d2.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(45172, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214657.mp4', 'http://timg.bdta.pro/images/aea0583bb262479db3fcafeb42f46beb.jpg'),
(45173, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214658.mp4', 'http://timg.bdta.pro/images/1825521c3bcb8db0082eadc071362fcc.jpg'),
(45174, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214659.mp4', 'http://timg.bdta.pro/images/d4d7460ac1d5ff3672520e3bd3380b1e.jpg'),
(45175, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214660.mp4', 'http://timg.bdta.pro/images/b9f969d84920fb49fa636a17ce8eb870.jpg'),
(45176, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214661.mp4', 'http://timg.bdta.pro/images/f36b09d015db9d0cb60728bf05565f43.jpg'),
(45177, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214662.mp4', 'http://timg.bdta.pro/images/18aec53f165219926e780d322444f26e.jpg'),
(45178, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214663.mp4', 'http://timg.bdta.pro/images/098208aa7dd14755341c1d09d245f400.jpg'),
(45179, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214664.mp4', 'http://timg.bdta.pro/images/b7feb7c3df86d206cdacc1ab7ec9566d.jpg'),
(45180, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214665.mp4', 'http://timg.bdta.pro/images/6401233a7b5dfd4eb2c67a862b46f91b.jpg'),
(45181, 3110, 'Lei & Ordem: Unidade de Vítimas Especiais S23 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214666.mp4', 'http://timg.bdta.pro/images/f1892a31dc45d75fdb2d08b8eab21703.jpg'),
(45182, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ctbErHzYe3moaLuMGVbGdb2fYiz.jpg'),
(45183, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gUsxBrZDhq8nlDX9fENibSo7idE.jpg'),
(45184, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nu7Rvvyh5tqmxmksbNHIdFL49Vo.jpg'),
(45185, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hUPlM0deKOzcNQk93Tch3AWAeEA.jpg'),
(45186, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3RsjQm2In9DFUAmSoevQe8hs5nt.jpg'),
(45187, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2RtMhCPorl3h2EodWxcDveuYRni.jpg'),
(45188, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eJSMlViXmSuypBGoWcoTkD2BRUg.jpg'),
(45189, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sbmtqieWrIEMQXQIO1uiL7eRn7f.jpg'),
(45190, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tNtiI5ZHDhafBcd8yfw2AuAZY0L.jpg'),
(45191, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8JwTiy6k6MbfZrvbTdarbAOhZ2L.jpg'),
(45192, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhj0uYGrckqGzqCN6tmHvwQQsyx.jpg'),
(45193, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/otPG1NdvjEzdDXlabewcOxcUoUg.jpg'),
(45194, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kiOJl1DnNeTPUeutTx9xsf6p0mo.jpg'),
(45195, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mYTYK5TlYiUpgOVkOM7p3RG0Xo3.jpg'),
(45196, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/grPa7eMuHPWRTMsVk0zQVvE8kCl.jpg'),
(45197, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wRoohjZvulczCYK2TKkkTePvBSz.jpg'),
(45198, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eoxTePBU3XJVHMDraKIjrJy5oEb.jpg'),
(45199, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vsWgS07vzCUZS3OdRxBf6YpoJNc.jpg'),
(45200, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Or9nwsUo5T4H1xvC6nUudzMwu0.jpg'),
(45201, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kEJdVLaCFZjghrgATzLWagbqOWk.jpg'),
(45202, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qzgnmDHLviK4S8At6tkTyNHv34e.jpg'),
(45203, 3111, 'Lei & Ordem: Unidade de Vítimas Especiais S24 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pTiji50bPcLKhoJnsMIdoifjE1R.jpg'),
(45204, 3112, 'Lei & Ordem: Unidade de Vítimas Especiais S25 E01', 'http://sinalprivado.info:80/series/1533784/1533784/420410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5xr3VpQUuPuENOHnkA46u8O4WO5.jpg'),
(45205, 3112, 'Lei & Ordem: Unidade de Vítimas Especiais S25 E02', 'http://sinalprivado.info:80/series/1533784/1533784/420411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8f0RMZ3BAgy1S4OI2aK4QgukDrj.jpg'),
(45206, 3112, 'Lei & Ordem: Unidade de Vítimas Especiais S25 E03', 'http://sinalprivado.info:80/series/1533784/1533784/420412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7wS35P4fPkRO80lqJV7uHhUsIcz.jpg'),
(45207, 3112, 'Lei & Ordem: Unidade de Vítimas Especiais S25 E04', 'http://sinalprivado.info:80/series/1533784/1533784/420413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uD28kB750gL2aAffCPIXyWrsw82.jpg'),
(45208, 3112, 'Lei & Ordem: Unidade de Vítimas Especiais S25 E05', 'http://sinalprivado.info:80/series/1533784/1533784/420414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5gnfgDbZR9C2T312SOeIcspKAw5.jpg'),
(45209, 3112, 'Lei & Ordem: Unidade de Vítimas Especiais S25 E06', 'http://sinalprivado.info:80/series/1533784/1533784/420415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f6l2h2ny8lXSFRHKIJ8lyfX8Tm9.jpg'),
(45210, 3112, 'Lei & Ordem: Unidade de Vítimas Especiais S25 E07', 'http://sinalprivado.info:80/series/1533784/1533784/420416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ngf4SreHnzwTgxUhn1hqy6PDGVV.jpg'),
(45211, 3112, 'Lei & Ordem: Unidade de Vítimas Especiais S25 E08', 'http://sinalprivado.info:80/series/1533784/1533784/420417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ji7nqaGjZZTZgJluhVWtPdECrrj.jpg'),
(45212, 3112, 'Lei & Ordem: Unidade de Vítimas Especiais S25 E09', 'http://sinalprivado.info:80/series/1533784/1533784/420418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eEryTZKGbUHiqkAhRPiZpdq87np.jpg'),
(45213, 3112, 'Lei & Ordem: Unidade de Vítimas Especiais S25 E10', 'http://sinalprivado.info:80/series/1533784/1533784/420419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/su0lVRyBxtb2z8IlHzbofJ0707M.jpg'),
(45214, 3112, 'Lei & Ordem: Unidade de Vítimas Especiais S25 E11', 'http://sinalprivado.info:80/series/1533784/1533784/420420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fm0U5nyfcgB6LT9Ihoa0osc0mcj.jpg'),
(45215, 3112, 'Lei & Ordem: Unidade de Vítimas Especiais S25 E12', 'http://sinalprivado.info:80/series/1533784/1533784/420421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z0BlESXZSWY7VJ9ZAwEeDGsXKLz.jpg'),
(45216, 3112, 'Lei & Ordem: Unidade de Vítimas Especiais S25 E13', 'http://sinalprivado.info:80/series/1533784/1533784/420422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vQuFBtQEs4w1xt4b4WBFAcglrs0.jpg'),
(45217, 3113, 'Doutor Castor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135193.mp4', 'http://gstaticontent.com/images/77hnVQI68FeFsqcSB1VlCQ9xPOL_big.jpg'),
(45218, 3113, 'Doutor Castor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135194.mp4', 'http://gstaticontent.com/images/77hnVQI68FeFsqcSB1VlCQ9xPOL_big.jpg'),
(45219, 3113, 'Doutor Castor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135195.mp4', 'http://gstaticontent.com/images/77hnVQI68FeFsqcSB1VlCQ9xPOL_big.jpg'),
(45220, 3113, 'Doutor Castor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135196.mp4', 'http://gstaticontent.com/images/77hnVQI68FeFsqcSB1VlCQ9xPOL_big.jpg'),
(45221, 3114, 'Pit Stop S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135183.mp4', 'http://gstaticontent.com/images/boX6dfiael6rH1K6CAqMkrE6nHL_big.jpg'),
(45222, 3114, 'Pit Stop S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135184.mp4', 'http://gstaticontent.com/images/boX6dfiael6rH1K6CAqMkrE6nHL_big.jpg'),
(45223, 3114, 'Pit Stop S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135185.mp4', 'http://gstaticontent.com/images/boX6dfiael6rH1K6CAqMkrE6nHL_big.jpg'),
(45224, 3114, 'Pit Stop S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135186.mp4', 'http://gstaticontent.com/images/boX6dfiael6rH1K6CAqMkrE6nHL_big.jpg'),
(45225, 3114, 'Pit Stop S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135187.mp4', 'http://gstaticontent.com/images/boX6dfiael6rH1K6CAqMkrE6nHL_big.jpg'),
(45226, 3114, 'Pit Stop S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135188.mp4', 'http://gstaticontent.com/images/boX6dfiael6rH1K6CAqMkrE6nHL_big.jpg'),
(45227, 3114, 'Pit Stop S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135189.mp4', 'http://gstaticontent.com/images/boX6dfiael6rH1K6CAqMkrE6nHL_big.jpg'),
(45228, 3114, 'Pit Stop S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135190.mp4', 'http://gstaticontent.com/images/boX6dfiael6rH1K6CAqMkrE6nHL_big.jpg'),
(45229, 3114, 'Pit Stop S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135191.mp4', 'http://gstaticontent.com/images/boX6dfiael6rH1K6CAqMkrE6nHL_big.jpg'),
(45230, 3114, 'Pit Stop S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135192.mp4', 'http://gstaticontent.com/images/boX6dfiael6rH1K6CAqMkrE6nHL_big.jpg'),
(45231, 3115, 'Por Tras de Seus Olhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135177.mp4', 'http://gstaticontent.com/images/77707193ed7d8115f4e3f924d7a7d12d.jpg'),
(45232, 3115, 'Por Tras de Seus Olhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135178.mp4', 'http://gstaticontent.com/images/77707193ed7d8115f4e3f924d7a7d12d.jpg'),
(45233, 3115, 'Por Tras de Seus Olhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135179.mp4', 'http://gstaticontent.com/images/77707193ed7d8115f4e3f924d7a7d12d.jpg'),
(45234, 3115, 'Por Tras de Seus Olhos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135180.mp4', 'http://gstaticontent.com/images/77707193ed7d8115f4e3f924d7a7d12d.jpg'),
(45235, 3115, 'Por Tras de Seus Olhos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135181.mp4', 'http://gstaticontent.com/images/77707193ed7d8115f4e3f924d7a7d12d.jpg'),
(45236, 3115, 'Por Tras de Seus Olhos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135182.mp4', 'http://gstaticontent.com/images/77707193ed7d8115f4e3f924d7a7d12d.jpg'),
(45237, 3116, 'StartUp S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135147.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45238, 3116, 'StartUp S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135148.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45239, 3116, 'StartUp S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135149.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45240, 3116, 'StartUp S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135150.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45241, 3116, 'StartUp S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135151.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45242, 3116, 'StartUp S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135152.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45243, 3116, 'StartUp S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135153.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45244, 3116, 'StartUp S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135154.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45245, 3116, 'StartUp S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135155.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45246, 3116, 'StartUp S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135156.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45247, 3117, 'StartUp S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135157.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45248, 3117, 'StartUp S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135158.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45249, 3117, 'StartUp S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135159.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45250, 3117, 'StartUp S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135160.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45251, 3117, 'StartUp S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135161.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45252, 3117, 'StartUp S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135162.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45253, 3117, 'StartUp S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135163.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45254, 3117, 'StartUp S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135164.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45255, 3117, 'StartUp S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135165.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45256, 3117, 'StartUp S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135166.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45257, 3118, 'StartUp S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135167.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45258, 3118, 'StartUp S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135168.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45259, 3118, 'StartUp S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135169.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45260, 3118, 'StartUp S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135170.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45261, 3118, 'StartUp S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135171.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45262, 3118, 'StartUp S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135172.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45263, 3118, 'StartUp S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135173.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45264, 3118, 'StartUp S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135174.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45265, 3118, 'StartUp S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135175.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45266, 3118, 'StartUp S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135176.mp4', 'http://gstaticontent.com/images/gEYKEwkb73URlFcg9lV6kndFzMu_big.jpg'),
(45267, 3119, 'The Head: Mistério na Antártida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234760.mp4', 'http://gstaticontent.com/images/vLNRamoZlSfODRvPucp1vi4Fqeh_big.jpg'),
(45268, 3119, 'The Head: Mistério na Antártida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234761.mp4', 'http://gstaticontent.com/images/vLNRamoZlSfODRvPucp1vi4Fqeh_big.jpg'),
(45269, 3119, 'The Head: Mistério na Antártida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234762.mp4', 'http://gstaticontent.com/images/vLNRamoZlSfODRvPucp1vi4Fqeh_big.jpg'),
(45270, 3119, 'The Head: Mistério na Antártida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234763.mp4', 'http://gstaticontent.com/images/vLNRamoZlSfODRvPucp1vi4Fqeh_big.jpg'),
(45271, 3119, 'The Head: Mistério na Antártida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234764.mp4', 'http://gstaticontent.com/images/vLNRamoZlSfODRvPucp1vi4Fqeh_big.jpg'),
(45272, 3119, 'The Head: Mistério na Antártida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234765.mp4', 'http://gstaticontent.com/images/vLNRamoZlSfODRvPucp1vi4Fqeh_big.jpg'),
(45273, 3120, 'The Head: Mistério na Antártida S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234766.mp4', 'http://gstaticontent.com/images/vLNRamoZlSfODRvPucp1vi4Fqeh_big.jpg'),
(45274, 3120, 'The Head: Mistério na Antártida S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234767.mp4', 'http://gstaticontent.com/images/vLNRamoZlSfODRvPucp1vi4Fqeh_big.jpg'),
(45275, 3120, 'The Head: Mistério na Antártida S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234768.mp4', 'http://gstaticontent.com/images/vLNRamoZlSfODRvPucp1vi4Fqeh_big.jpg'),
(45276, 3120, 'The Head: Mistério na Antártida S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234769.mp4', 'http://gstaticontent.com/images/vLNRamoZlSfODRvPucp1vi4Fqeh_big.jpg'),
(45277, 3120, 'The Head: Mistério na Antártida S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234770.mp4', 'http://gstaticontent.com/images/vLNRamoZlSfODRvPucp1vi4Fqeh_big.jpg'),
(45278, 3120, 'The Head: Mistério na Antártida S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234771.mp4', 'http://gstaticontent.com/images/vLNRamoZlSfODRvPucp1vi4Fqeh_big.jpg'),
(45279, 3120, 'The Head: Mistério na Antártida S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/820216.mp4', 'http://gstaticontent.com/images/vLNRamoZlSfODRvPucp1vi4Fqeh_big.jpg'),
(45280, 3121, 'Vade Retro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135136.mp4', 'http://gstaticontent.com/images/vKoixdVn3NQHkzGqOJSJo4ukZWt_big.jpg'),
(45281, 3121, 'Vade Retro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135137.mp4', 'http://gstaticontent.com/images/vKoixdVn3NQHkzGqOJSJo4ukZWt_big.jpg'),
(45282, 3121, 'Vade Retro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135138.mp4', 'http://gstaticontent.com/images/vKoixdVn3NQHkzGqOJSJo4ukZWt_big.jpg'),
(45283, 3121, 'Vade Retro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135139.mp4', 'http://gstaticontent.com/images/vKoixdVn3NQHkzGqOJSJo4ukZWt_big.jpg'),
(45284, 3121, 'Vade Retro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135140.mp4', 'http://gstaticontent.com/images/vKoixdVn3NQHkzGqOJSJo4ukZWt_big.jpg'),
(45285, 3121, 'Vade Retro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135141.mp4', 'http://gstaticontent.com/images/vKoixdVn3NQHkzGqOJSJo4ukZWt_big.jpg'),
(45286, 3121, 'Vade Retro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135142.mp4', 'http://gstaticontent.com/images/vKoixdVn3NQHkzGqOJSJo4ukZWt_big.jpg'),
(45287, 3121, 'Vade Retro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135143.mp4', 'http://gstaticontent.com/images/vKoixdVn3NQHkzGqOJSJo4ukZWt_big.jpg'),
(45288, 3121, 'Vade Retro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135144.mp4', 'http://gstaticontent.com/images/vKoixdVn3NQHkzGqOJSJo4ukZWt_big.jpg'),
(45289, 3121, 'Vade Retro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135145.mp4', 'http://gstaticontent.com/images/vKoixdVn3NQHkzGqOJSJo4ukZWt_big.jpg'),
(45290, 3121, 'Vade Retro S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/135146.mp4', 'http://gstaticontent.com/images/vKoixdVn3NQHkzGqOJSJo4ukZWt_big.jpg'),
(45291, 3122, 'A Guerra dos Samurais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135102.mp4', 'http://gstaticontent.com/images/wIKQRtc2kKiBmBnkOjjvMqIDfah_big.jpg'),
(45292, 3122, 'A Guerra dos Samurais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135103.mp4', 'http://gstaticontent.com/images/wIKQRtc2kKiBmBnkOjjvMqIDfah_big.jpg'),
(45293, 3122, 'A Guerra dos Samurais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135104.mp4', 'http://gstaticontent.com/images/wIKQRtc2kKiBmBnkOjjvMqIDfah_big.jpg'),
(45294, 3122, 'A Guerra dos Samurais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135105.mp4', 'http://gstaticontent.com/images/wIKQRtc2kKiBmBnkOjjvMqIDfah_big.jpg'),
(45295, 3122, 'A Guerra dos Samurais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135106.mp4', 'http://gstaticontent.com/images/wIKQRtc2kKiBmBnkOjjvMqIDfah_big.jpg'),
(45296, 3122, 'A Guerra dos Samurais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135107.mp4', 'http://gstaticontent.com/images/wIKQRtc2kKiBmBnkOjjvMqIDfah_big.jpg'),
(45297, 3123, 'Bake Off Brasil – Celebridades S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/574969.mp4', 'http://gstaticontent.com/images/1Z3wyQylg0GpZqo69IOdfCDtU9N_big.jpg'),
(45298, 3123, 'Bake Off Brasil – Celebridades S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/574971.mp4', 'http://gstaticontent.com/images/1Z3wyQylg0GpZqo69IOdfCDtU9N_big.jpg'),
(45299, 3123, 'Bake Off Brasil – Celebridades S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/574973.mp4', 'http://gstaticontent.com/images/1Z3wyQylg0GpZqo69IOdfCDtU9N_big.jpg'),
(45300, 3123, 'Bake Off Brasil – Celebridades S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/574975.mp4', 'http://gstaticontent.com/images/1Z3wyQylg0GpZqo69IOdfCDtU9N_big.jpg'),
(45301, 3123, 'Bake Off Brasil – Celebridades S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/574977.mp4', 'http://gstaticontent.com/images/1Z3wyQylg0GpZqo69IOdfCDtU9N_big.jpg'),
(45302, 3123, 'Bake Off Brasil – Celebridades S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/574979.mp4', 'http://gstaticontent.com/images/1Z3wyQylg0GpZqo69IOdfCDtU9N_big.jpg'),
(45303, 3123, 'Bake Off Brasil – Celebridades S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/574981.mp4', 'http://gstaticontent.com/images/1Z3wyQylg0GpZqo69IOdfCDtU9N_big.jpg'),
(45304, 3123, 'Bake Off Brasil – Celebridades S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/574983.mp4', 'http://gstaticontent.com/images/1Z3wyQylg0GpZqo69IOdfCDtU9N_big.jpg'),
(45305, 3123, 'Bake Off Brasil – Celebridades S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/574985.mp4', 'http://gstaticontent.com/images/1Z3wyQylg0GpZqo69IOdfCDtU9N_big.jpg'),
(45306, 3124, 'Bake Off Brasil – Celebridades S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227973.mp4', 'http://gstaticontent.com/images/1Z3wyQylg0GpZqo69IOdfCDtU9N_big.jpg'),
(45307, 3124, 'Bake Off Brasil – Celebridades S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227974.mp4', 'http://gstaticontent.com/images/1Z3wyQylg0GpZqo69IOdfCDtU9N_big.jpg'),
(45308, 3124, 'Bake Off Brasil – Celebridades S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227975.mp4', 'http://gstaticontent.com/images/1Z3wyQylg0GpZqo69IOdfCDtU9N_big.jpg'),
(45309, 3124, 'Bake Off Brasil – Celebridades S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227976.mp4', 'http://gstaticontent.com/images/1Z3wyQylg0GpZqo69IOdfCDtU9N_big.jpg'),
(45310, 3124, 'Bake Off Brasil – Celebridades S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227977.mp4', 'http://gstaticontent.com/images/1Z3wyQylg0GpZqo69IOdfCDtU9N_big.jpg'),
(45311, 3124, 'Bake Off Brasil – Celebridades S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227978.mp4', 'http://gstaticontent.com/images/1Z3wyQylg0GpZqo69IOdfCDtU9N_big.jpg'),
(45312, 3124, 'Bake Off Brasil – Celebridades S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227979.mp4', 'http://gstaticontent.com/images/1Z3wyQylg0GpZqo69IOdfCDtU9N_big.jpg'),
(45313, 3124, 'Bake Off Brasil – Celebridades S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227980.mp4', 'http://gstaticontent.com/images/1Z3wyQylg0GpZqo69IOdfCDtU9N_big.jpg'),
(45314, 3124, 'Bake Off Brasil – Celebridades S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227981.mp4', 'http://gstaticontent.com/images/1Z3wyQylg0GpZqo69IOdfCDtU9N_big.jpg'),
(45315, 3125, 'Big Mouth S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240389.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45316, 3125, 'Big Mouth S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240390.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45317, 3125, 'Big Mouth S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240391.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45318, 3125, 'Big Mouth S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240392.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45319, 3125, 'Big Mouth S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240393.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45320, 3125, 'Big Mouth S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240394.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45321, 3125, 'Big Mouth S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240395.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45322, 3125, 'Big Mouth S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240396.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45323, 3125, 'Big Mouth S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240397.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45324, 3125, 'Big Mouth S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240398.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45325, 3126, 'Big Mouth S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240399.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45326, 3126, 'Big Mouth S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240400.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45327, 3126, 'Big Mouth S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240401.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45328, 3126, 'Big Mouth S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240402.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45329, 3126, 'Big Mouth S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240403.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45330, 3126, 'Big Mouth S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240404.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45331, 3126, 'Big Mouth S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240405.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45332, 3126, 'Big Mouth S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240406.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45333, 3126, 'Big Mouth S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240407.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45334, 3126, 'Big Mouth S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240408.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45335, 3127, 'Big Mouth S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240409.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45336, 3127, 'Big Mouth S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240410.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45337, 3127, 'Big Mouth S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240411.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45338, 3127, 'Big Mouth S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240412.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45339, 3127, 'Big Mouth S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240413.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45340, 3127, 'Big Mouth S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240414.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45341, 3127, 'Big Mouth S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240415.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45342, 3127, 'Big Mouth S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240416.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45343, 3127, 'Big Mouth S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240417.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45344, 3127, 'Big Mouth S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240418.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45345, 3127, 'Big Mouth S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240419.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45346, 3128, 'Big Mouth S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240420.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45347, 3128, 'Big Mouth S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240421.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45348, 3128, 'Big Mouth S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240422.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45349, 3128, 'Big Mouth S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240423.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45350, 3128, 'Big Mouth S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240424.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45351, 3128, 'Big Mouth S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240425.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45352, 3128, 'Big Mouth S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240426.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45353, 3128, 'Big Mouth S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240427.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45354, 3128, 'Big Mouth S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240428.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45355, 3128, 'Big Mouth S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240429.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45356, 3129, 'Big Mouth S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240430.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45357, 3129, 'Big Mouth S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240431.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45358, 3129, 'Big Mouth S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240432.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45359, 3129, 'Big Mouth S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240433.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45360, 3129, 'Big Mouth S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240434.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45361, 3129, 'Big Mouth S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240435.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45362, 3129, 'Big Mouth S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240436.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45363, 3129, 'Big Mouth S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240437.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45364, 3129, 'Big Mouth S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240438.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45365, 3129, 'Big Mouth S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240439.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45366, 3130, 'Big Mouth S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240440.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45367, 3130, 'Big Mouth S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240441.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45368, 3130, 'Big Mouth S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240442.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45369, 3130, 'Big Mouth S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240443.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45370, 3130, 'Big Mouth S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240444.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45371, 3130, 'Big Mouth S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240445.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45372, 3130, 'Big Mouth S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240446.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45373, 3130, 'Big Mouth S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240447.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45374, 3130, 'Big Mouth S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240448.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45375, 3130, 'Big Mouth S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240449.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45376, 3131, 'Big Mouth S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240450.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45377, 3131, 'Big Mouth S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240451.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45378, 3131, 'Big Mouth S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240452.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45379, 3131, 'Big Mouth S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240453.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45380, 3131, 'Big Mouth S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240454.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45381, 3131, 'Big Mouth S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240455.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45382, 3131, 'Big Mouth S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240456.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45383, 3131, 'Big Mouth S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240457.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45384, 3131, 'Big Mouth S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240458.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45385, 3131, 'Big Mouth S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240459.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45386, 3132, 'Big Mouth S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/826194.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45387, 3132, 'Big Mouth S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/826195.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45388, 3132, 'Big Mouth S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/826196.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45389, 3132, 'Big Mouth S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/826197.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45390, 3132, 'Big Mouth S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/826198.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45391, 3132, 'Big Mouth S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/826199.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45392, 3132, 'Big Mouth S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/826200.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45393, 3132, 'Big Mouth S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/826201.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45394, 3132, 'Big Mouth S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/826202.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45395, 3132, 'Big Mouth S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/826203.mp4', 'http://gstaticontent.com/images/noRl3I5YSKARK3dq83rTlMezp3Y_big.jpg'),
(45396, 3133, 'Desperate Housewives S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166160.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45397, 3133, 'Desperate Housewives S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166161.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45398, 3133, 'Desperate Housewives S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166162.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45399, 3133, 'Desperate Housewives S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166163.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45400, 3133, 'Desperate Housewives S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166164.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45401, 3133, 'Desperate Housewives S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166165.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45402, 3133, 'Desperate Housewives S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166166.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45403, 3133, 'Desperate Housewives S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166167.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45404, 3133, 'Desperate Housewives S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166168.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45405, 3133, 'Desperate Housewives S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166169.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45406, 3133, 'Desperate Housewives S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166170.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45407, 3133, 'Desperate Housewives S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166171.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45408, 3133, 'Desperate Housewives S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166172.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45409, 3133, 'Desperate Housewives S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166173.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45410, 3133, 'Desperate Housewives S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166174.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45411, 3133, 'Desperate Housewives S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166175.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45412, 3133, 'Desperate Housewives S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166176.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45413, 3133, 'Desperate Housewives S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166177.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45414, 3133, 'Desperate Housewives S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/166178.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45415, 3133, 'Desperate Housewives S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/166179.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45416, 3133, 'Desperate Housewives S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/166180.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45417, 3133, 'Desperate Housewives S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/166181.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45418, 3133, 'Desperate Housewives S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/166182.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45419, 3134, 'Desperate Housewives S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166183.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45420, 3134, 'Desperate Housewives S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166184.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45421, 3134, 'Desperate Housewives S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166185.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45422, 3134, 'Desperate Housewives S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166186.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45423, 3134, 'Desperate Housewives S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166187.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45424, 3134, 'Desperate Housewives S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166188.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45425, 3134, 'Desperate Housewives S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166189.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45426, 3134, 'Desperate Housewives S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166190.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45427, 3134, 'Desperate Housewives S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166191.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45428, 3134, 'Desperate Housewives S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166192.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45429, 3134, 'Desperate Housewives S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166193.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45430, 3134, 'Desperate Housewives S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166194.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45431, 3134, 'Desperate Housewives S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166195.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45432, 3134, 'Desperate Housewives S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166196.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45433, 3134, 'Desperate Housewives S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166197.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45434, 3134, 'Desperate Housewives S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166198.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45435, 3134, 'Desperate Housewives S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166199.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45436, 3134, 'Desperate Housewives S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166200.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45437, 3134, 'Desperate Housewives S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/166201.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45438, 3134, 'Desperate Housewives S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/166202.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45439, 3134, 'Desperate Housewives S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/166203.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45440, 3134, 'Desperate Housewives S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/166204.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45441, 3134, 'Desperate Housewives S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/166205.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45442, 3134, 'Desperate Housewives S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/166206.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45443, 3135, 'Desperate Housewives S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166207.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45444, 3135, 'Desperate Housewives S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166208.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45445, 3135, 'Desperate Housewives S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166209.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45446, 3135, 'Desperate Housewives S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166210.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(45447, 3135, 'Desperate Housewives S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166211.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45448, 3135, 'Desperate Housewives S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166212.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45449, 3135, 'Desperate Housewives S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166213.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45450, 3135, 'Desperate Housewives S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166214.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45451, 3135, 'Desperate Housewives S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166215.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45452, 3135, 'Desperate Housewives S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166216.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45453, 3135, 'Desperate Housewives S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166217.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45454, 3135, 'Desperate Housewives S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166218.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45455, 3135, 'Desperate Housewives S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166219.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45456, 3135, 'Desperate Housewives S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166220.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45457, 3135, 'Desperate Housewives S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166221.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45458, 3135, 'Desperate Housewives S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166222.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45459, 3135, 'Desperate Housewives S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166223.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45460, 3135, 'Desperate Housewives S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166224.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45461, 3135, 'Desperate Housewives S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/166225.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45462, 3135, 'Desperate Housewives S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/166226.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45463, 3135, 'Desperate Housewives S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/166227.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45464, 3135, 'Desperate Housewives S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/166228.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45465, 3135, 'Desperate Housewives S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/166229.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45466, 3136, 'Desperate Housewives S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166230.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45467, 3136, 'Desperate Housewives S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166231.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45468, 3136, 'Desperate Housewives S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166232.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45469, 3136, 'Desperate Housewives S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166233.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45470, 3136, 'Desperate Housewives S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166234.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45471, 3136, 'Desperate Housewives S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166235.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45472, 3136, 'Desperate Housewives S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166236.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45473, 3136, 'Desperate Housewives S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166237.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45474, 3136, 'Desperate Housewives S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166238.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45475, 3136, 'Desperate Housewives S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166239.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45476, 3136, 'Desperate Housewives S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166240.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45477, 3136, 'Desperate Housewives S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166241.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45478, 3136, 'Desperate Housewives S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166242.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45479, 3136, 'Desperate Housewives S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166243.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45480, 3136, 'Desperate Housewives S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166244.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45481, 3136, 'Desperate Housewives S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166245.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45482, 3136, 'Desperate Housewives S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166246.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45483, 3137, 'Desperate Housewives S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166247.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45484, 3137, 'Desperate Housewives S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166248.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45485, 3137, 'Desperate Housewives S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166249.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45486, 3137, 'Desperate Housewives S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166250.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45487, 3137, 'Desperate Housewives S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166251.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45488, 3137, 'Desperate Housewives S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166252.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45489, 3137, 'Desperate Housewives S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166253.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45490, 3137, 'Desperate Housewives S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166254.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45491, 3137, 'Desperate Housewives S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166255.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45492, 3137, 'Desperate Housewives S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166256.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45493, 3137, 'Desperate Housewives S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166257.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45494, 3137, 'Desperate Housewives S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166258.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45495, 3137, 'Desperate Housewives S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166259.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45496, 3137, 'Desperate Housewives S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166260.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45497, 3137, 'Desperate Housewives S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166261.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45498, 3137, 'Desperate Housewives S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166262.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45499, 3137, 'Desperate Housewives S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166263.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45500, 3137, 'Desperate Housewives S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166264.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45501, 3137, 'Desperate Housewives S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/166265.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45502, 3137, 'Desperate Housewives S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/166266.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45503, 3137, 'Desperate Housewives S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/166267.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45504, 3137, 'Desperate Housewives S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/166268.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45505, 3137, 'Desperate Housewives S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/166269.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45506, 3137, 'Desperate Housewives S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/166270.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45507, 3138, 'Desperate Housewives S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166271.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45508, 3138, 'Desperate Housewives S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166272.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45509, 3138, 'Desperate Housewives S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166273.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45510, 3138, 'Desperate Housewives S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166274.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45511, 3138, 'Desperate Housewives S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166275.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45512, 3138, 'Desperate Housewives S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166276.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45513, 3138, 'Desperate Housewives S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166277.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45514, 3138, 'Desperate Housewives S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166278.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45515, 3138, 'Desperate Housewives S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166279.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45516, 3138, 'Desperate Housewives S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166280.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45517, 3138, 'Desperate Housewives S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166281.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45518, 3138, 'Desperate Housewives S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166282.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45519, 3138, 'Desperate Housewives S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166283.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45520, 3138, 'Desperate Housewives S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166284.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45521, 3138, 'Desperate Housewives S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166285.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45522, 3138, 'Desperate Housewives S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166286.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45523, 3138, 'Desperate Housewives S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166287.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45524, 3138, 'Desperate Housewives S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166288.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45525, 3138, 'Desperate Housewives S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/166289.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45526, 3138, 'Desperate Housewives S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/166290.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45527, 3138, 'Desperate Housewives S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/166291.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45528, 3138, 'Desperate Housewives S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/166292.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45529, 3138, 'Desperate Housewives S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/166293.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45530, 3139, 'Desperate Housewives S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166294.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45531, 3139, 'Desperate Housewives S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166295.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45532, 3139, 'Desperate Housewives S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166296.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45533, 3139, 'Desperate Housewives S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166297.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45534, 3139, 'Desperate Housewives S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166298.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45535, 3139, 'Desperate Housewives S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166299.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45536, 3139, 'Desperate Housewives S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166300.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45537, 3139, 'Desperate Housewives S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166301.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45538, 3139, 'Desperate Housewives S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166302.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45539, 3139, 'Desperate Housewives S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166303.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45540, 3139, 'Desperate Housewives S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166304.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45541, 3139, 'Desperate Housewives S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166305.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45542, 3139, 'Desperate Housewives S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166306.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45543, 3139, 'Desperate Housewives S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166307.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45544, 3139, 'Desperate Housewives S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166308.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45545, 3139, 'Desperate Housewives S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166309.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45546, 3139, 'Desperate Housewives S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166310.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45547, 3139, 'Desperate Housewives S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166311.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45548, 3139, 'Desperate Housewives S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/166312.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45549, 3139, 'Desperate Housewives S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/166313.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45550, 3139, 'Desperate Housewives S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/166314.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45551, 3139, 'Desperate Housewives S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/166315.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45552, 3139, 'Desperate Housewives S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/166316.mp4', 'http://gstaticontent.com/images/gdbFcFdFt4Jd1zTcUHdScMLubr6_big.jpg'),
(45553, 3140, 'Desperate Housewives S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AqkXwxXkp9T6AkpZq7YwH754U6X.jpg'),
(45554, 3140, 'Desperate Housewives S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6h8UjQ3FuagFDzmUf0dwZ99cDZJ.jpg'),
(45555, 3140, 'Desperate Housewives S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l1cghAMczGFyzvrz9BHtulz3B5z.jpg'),
(45556, 3140, 'Desperate Housewives S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/knMCFqaZ3Itcpx20sSNmCQY6o7J.jpg'),
(45557, 3140, 'Desperate Housewives S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6p8EUDdLkZSVbXbasKvFC59nilc.jpg'),
(45558, 3140, 'Desperate Housewives S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t9C5zKDWgxbYGVDW1s7pFv0edu8.jpg'),
(45559, 3140, 'Desperate Housewives S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lIwtCJXpFJXpUgqA1H1FCYI4fAK.jpg'),
(45560, 3140, 'Desperate Housewives S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g3tn0gneNs8x8K0AxngIw1MtO60.jpg'),
(45561, 3140, 'Desperate Housewives S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4d5wgdvJaAFno7bSdcSjkcWkY9h.jpg'),
(45562, 3140, 'Desperate Housewives S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ox7EgvznxnIuJugVS3FR6i9PWZ.jpg'),
(45563, 3140, 'Desperate Housewives S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6vbIlnGInhRt2GLVONnJLIBQwSe.jpg'),
(45564, 3140, 'Desperate Housewives S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aHoimXBCDcADyozK0gNeA5AyeFD.jpg'),
(45565, 3140, 'Desperate Housewives S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iQJiDwasox8wAetOLjrI8Si61Ib.jpg'),
(45566, 3140, 'Desperate Housewives S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2CYWA1LOHGmLXm0Qzhd5FG9UyX2.jpg'),
(45567, 3140, 'Desperate Housewives S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xv1T9DJdroO6G4bWi7RxvBXenx0.jpg'),
(45568, 3140, 'Desperate Housewives S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3cLfbMJEsTqMKpWNWyCZMK3NdB.jpg'),
(45569, 3140, 'Desperate Housewives S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZS7syR2G5MbR60syQ6M5BlDeUu.jpg'),
(45570, 3140, 'Desperate Housewives S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y6IAbfgBRacNXoMZUTRA9XmEmZ.jpg'),
(45571, 3140, 'Desperate Housewives S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/166335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ziAfQKKCgQwdMewHkGpySN3kjAj.jpg'),
(45572, 3140, 'Desperate Housewives S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/166336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nEPhs3LfjX5OsKQ8wZncDCArv4B.jpg'),
(45573, 3140, 'Desperate Housewives S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/166337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bqt9l1eOVUL8oMXzZxjdLh5kope.jpg'),
(45574, 3140, 'Desperate Housewives S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/166338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/37WEvAhJcYv19yXL4FdPZnYlRpg.jpg'),
(45575, 3140, 'Desperate Housewives S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/166339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cWHF1o60h6clrVkzc60e5USUzyI.jpg'),
(45576, 3141, 'Ginny e Georgia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205517.mp4', 'http://gstaticontent.com/images/e4aqizYQ8eeTGNZMq6WiFfqoZbz_big.jpg'),
(45577, 3141, 'Ginny e Georgia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205518.mp4', 'http://gstaticontent.com/images/e4aqizYQ8eeTGNZMq6WiFfqoZbz_big.jpg'),
(45578, 3141, 'Ginny e Georgia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205519.mp4', 'http://gstaticontent.com/images/e4aqizYQ8eeTGNZMq6WiFfqoZbz_big.jpg'),
(45579, 3141, 'Ginny e Georgia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205520.mp4', 'http://gstaticontent.com/images/e4aqizYQ8eeTGNZMq6WiFfqoZbz_big.jpg'),
(45580, 3141, 'Ginny e Georgia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205521.mp4', 'http://gstaticontent.com/images/e4aqizYQ8eeTGNZMq6WiFfqoZbz_big.jpg'),
(45581, 3141, 'Ginny e Georgia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205522.mp4', 'http://gstaticontent.com/images/e4aqizYQ8eeTGNZMq6WiFfqoZbz_big.jpg'),
(45582, 3141, 'Ginny e Georgia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205523.mp4', 'http://gstaticontent.com/images/e4aqizYQ8eeTGNZMq6WiFfqoZbz_big.jpg'),
(45583, 3141, 'Ginny e Georgia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205524.mp4', 'http://gstaticontent.com/images/e4aqizYQ8eeTGNZMq6WiFfqoZbz_big.jpg'),
(45584, 3141, 'Ginny e Georgia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205525.mp4', 'http://gstaticontent.com/images/e4aqizYQ8eeTGNZMq6WiFfqoZbz_big.jpg'),
(45585, 3141, 'Ginny e Georgia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205526.mp4', 'http://gstaticontent.com/images/e4aqizYQ8eeTGNZMq6WiFfqoZbz_big.jpg'),
(45586, 3142, 'Ginny e Georgia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zcZRFkRViETNRLPSb6gbolFLrtW.jpg'),
(45587, 3142, 'Ginny e Georgia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9kKx7tethGQ0PPn9cPp2d9OMZEH.jpg'),
(45588, 3142, 'Ginny e Georgia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wvbg5RUb6JpsyNQtUjQhWSU7tBX.jpg'),
(45589, 3142, 'Ginny e Georgia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c1qFSAEnsXmeRpd3dZiqo5vSKYV.jpg'),
(45590, 3142, 'Ginny e Georgia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dUSZOL5cri97lzUcOJFvfLj4Va6.jpg'),
(45591, 3142, 'Ginny e Georgia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ucUalsp2cjO9L25LiJE5NpXaSOf.jpg'),
(45592, 3142, 'Ginny e Georgia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odljQ3ieBT4fTDIMgQSL1THDM6M.jpg'),
(45593, 3142, 'Ginny e Georgia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xAJh14CifL8v5Rl85xMEDcECw2q.jpg'),
(45594, 3142, 'Ginny e Georgia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205535.mp4', 'http://image.tmdb.org/t/p/w1280/yXlYskEQcf5ardOij5s6mek6eqX.jpg'),
(45595, 3142, 'Ginny e Georgia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205536.mp4', 'http://image.tmdb.org/t/p/w1280/xgXJW4HoY2jUBSz037K2e3yA8zb.jpg'),
(45596, 3143, 'Ginny e Georgia S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/843122.mp4', 'http://gstaticontent.com/images/e4aqizYQ8eeTGNZMq6WiFfqoZbz_big.jpg'),
(45597, 3143, 'Ginny e Georgia S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/843123.mp4', 'http://gstaticontent.com/images/e4aqizYQ8eeTGNZMq6WiFfqoZbz_big.jpg'),
(45598, 3143, 'Ginny e Georgia S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/843124.mp4', 'http://gstaticontent.com/images/e4aqizYQ8eeTGNZMq6WiFfqoZbz_big.jpg'),
(45599, 3143, 'Ginny e Georgia S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/843125.mp4', 'http://gstaticontent.com/images/e4aqizYQ8eeTGNZMq6WiFfqoZbz_big.jpg'),
(45600, 3143, 'Ginny e Georgia S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/843126.mp4', 'http://gstaticontent.com/images/e4aqizYQ8eeTGNZMq6WiFfqoZbz_big.jpg'),
(45601, 3143, 'Ginny e Georgia S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/843127.mp4', 'http://gstaticontent.com/images/e4aqizYQ8eeTGNZMq6WiFfqoZbz_big.jpg'),
(45602, 3143, 'Ginny e Georgia S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/843128.mp4', 'http://gstaticontent.com/images/e4aqizYQ8eeTGNZMq6WiFfqoZbz_big.jpg'),
(45603, 3143, 'Ginny e Georgia S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/843129.mp4', 'http://gstaticontent.com/images/e4aqizYQ8eeTGNZMq6WiFfqoZbz_big.jpg'),
(45604, 3143, 'Ginny e Georgia S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/843130.mp4', 'http://gstaticontent.com/images/e4aqizYQ8eeTGNZMq6WiFfqoZbz_big.jpg'),
(45605, 3143, 'Ginny e Georgia S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/843131.mp4', 'http://gstaticontent.com/images/e4aqizYQ8eeTGNZMq6WiFfqoZbz_big.jpg'),
(45606, 3144, 'Intervenção Canina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135096.mp4', 'http://gstaticontent.com/images/2di7dBLfYpTo4DOeISgxRkL30g9_big.jpg'),
(45607, 3144, 'Intervenção Canina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135097.mp4', 'http://gstaticontent.com/images/2di7dBLfYpTo4DOeISgxRkL30g9_big.jpg'),
(45608, 3144, 'Intervenção Canina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135098.mp4', 'http://gstaticontent.com/images/2di7dBLfYpTo4DOeISgxRkL30g9_big.jpg'),
(45609, 3144, 'Intervenção Canina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135099.mp4', 'http://gstaticontent.com/images/2di7dBLfYpTo4DOeISgxRkL30g9_big.jpg'),
(45610, 3144, 'Intervenção Canina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135100.mp4', 'http://gstaticontent.com/images/2di7dBLfYpTo4DOeISgxRkL30g9_big.jpg'),
(45611, 3144, 'Intervenção Canina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135101.mp4', 'http://gstaticontent.com/images/2di7dBLfYpTo4DOeISgxRkL30g9_big.jpg'),
(45612, 3145, 'Mary de Morte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135078.mp4', 'http://gstaticontent.com/images/4oWmHHU97xAZMIoAfCDQzxOy9Cc_big.jpg'),
(45613, 3145, 'Mary de Morte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135079.mp4', 'http://gstaticontent.com/images/4oWmHHU97xAZMIoAfCDQzxOy9Cc_big.jpg'),
(45614, 3145, 'Mary de Morte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135080.mp4', 'http://gstaticontent.com/images/4oWmHHU97xAZMIoAfCDQzxOy9Cc_big.jpg'),
(45615, 3145, 'Mary de Morte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135081.mp4', 'http://gstaticontent.com/images/4oWmHHU97xAZMIoAfCDQzxOy9Cc_big.jpg'),
(45616, 3145, 'Mary de Morte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135082.mp4', 'http://gstaticontent.com/images/4oWmHHU97xAZMIoAfCDQzxOy9Cc_big.jpg'),
(45617, 3145, 'Mary de Morte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135083.mp4', 'http://gstaticontent.com/images/4oWmHHU97xAZMIoAfCDQzxOy9Cc_big.jpg'),
(45618, 3146, 'Mary de Morte S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135084.mp4', 'http://gstaticontent.com/images/4oWmHHU97xAZMIoAfCDQzxOy9Cc_big.jpg'),
(45619, 3146, 'Mary de Morte S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135085.mp4', 'http://gstaticontent.com/images/4oWmHHU97xAZMIoAfCDQzxOy9Cc_big.jpg'),
(45620, 3146, 'Mary de Morte S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135086.mp4', 'http://gstaticontent.com/images/4oWmHHU97xAZMIoAfCDQzxOy9Cc_big.jpg'),
(45621, 3146, 'Mary de Morte S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135087.mp4', 'http://gstaticontent.com/images/4oWmHHU97xAZMIoAfCDQzxOy9Cc_big.jpg'),
(45622, 3146, 'Mary de Morte S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135088.mp4', 'http://gstaticontent.com/images/4oWmHHU97xAZMIoAfCDQzxOy9Cc_big.jpg'),
(45623, 3146, 'Mary de Morte S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135089.mp4', 'http://gstaticontent.com/images/4oWmHHU97xAZMIoAfCDQzxOy9Cc_big.jpg'),
(45624, 3147, 'Mary de Morte S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135090.mp4', 'http://gstaticontent.com/images/4oWmHHU97xAZMIoAfCDQzxOy9Cc_big.jpg'),
(45625, 3147, 'Mary de Morte S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135091.mp4', 'http://gstaticontent.com/images/4oWmHHU97xAZMIoAfCDQzxOy9Cc_big.jpg'),
(45626, 3147, 'Mary de Morte S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135092.mp4', 'http://gstaticontent.com/images/4oWmHHU97xAZMIoAfCDQzxOy9Cc_big.jpg'),
(45627, 3147, 'Mary de Morte S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135093.mp4', 'http://gstaticontent.com/images/4oWmHHU97xAZMIoAfCDQzxOy9Cc_big.jpg'),
(45628, 3147, 'Mary de Morte S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135094.mp4', 'http://gstaticontent.com/images/4oWmHHU97xAZMIoAfCDQzxOy9Cc_big.jpg'),
(45629, 3147, 'Mary de Morte S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135095.mp4', 'http://gstaticontent.com/images/4oWmHHU97xAZMIoAfCDQzxOy9Cc_big.jpg'),
(45630, 3148, 'O Internato: Las Cumbres S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176605.mp4', 'http://gstaticontent.com/images/xXxPttRWKQcMPnMIglOctqYozkU_big.jpg'),
(45631, 3148, 'O Internato: Las Cumbres S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176606.mp4', 'http://gstaticontent.com/images/xXxPttRWKQcMPnMIglOctqYozkU_big.jpg'),
(45632, 3148, 'O Internato: Las Cumbres S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176607.mp4', 'http://gstaticontent.com/images/xXxPttRWKQcMPnMIglOctqYozkU_big.jpg'),
(45633, 3148, 'O Internato: Las Cumbres S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176608.mp4', 'http://gstaticontent.com/images/xXxPttRWKQcMPnMIglOctqYozkU_big.jpg'),
(45634, 3148, 'O Internato: Las Cumbres S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176609.mp4', 'http://gstaticontent.com/images/xXxPttRWKQcMPnMIglOctqYozkU_big.jpg'),
(45635, 3148, 'O Internato: Las Cumbres S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176610.mp4', 'http://gstaticontent.com/images/xXxPttRWKQcMPnMIglOctqYozkU_big.jpg'),
(45636, 3148, 'O Internato: Las Cumbres S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176611.mp4', 'http://gstaticontent.com/images/xXxPttRWKQcMPnMIglOctqYozkU_big.jpg'),
(45637, 3148, 'O Internato: Las Cumbres S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176612.mp4', 'http://gstaticontent.com/images/xXxPttRWKQcMPnMIglOctqYozkU_big.jpg'),
(45638, 3149, 'O Internato: Las Cumbres S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176613.mp4', 'http://timg.bdta.pro/images/a8c830360faef549d72990dcb1133b70.jpg'),
(45639, 3149, 'O Internato: Las Cumbres S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176614.mp4', 'http://timg.bdta.pro/images/cbce76ffec78228a4cba12b20b5068ca.jpg'),
(45640, 3149, 'O Internato: Las Cumbres S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176615.mp4', 'http://timg.bdta.pro/images/ec8d4d47f1da5a9722f29ec5a9265381.jpg'),
(45641, 3149, 'O Internato: Las Cumbres S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176616.mp4', 'http://timg.bdta.pro/images/c2fad09286356e2ac70a885ec1b2c6b4.jpg'),
(45642, 3149, 'O Internato: Las Cumbres S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176617.mp4', 'http://timg.bdta.pro/images/93ed499c5f23324a29dc759353d61e8c.jpg'),
(45643, 3149, 'O Internato: Las Cumbres S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176618.mp4', 'http://timg.bdta.pro/images/2e208494aa5a76c63a42977dc66cb6a7.jpg'),
(45644, 3149, 'O Internato: Las Cumbres S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176619.mp4', 'http://timg.bdta.pro/images/8c12cb250d4c449bd5a8dcd9f52f5b05.jpg'),
(45645, 3149, 'O Internato: Las Cumbres S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176620.mp4', 'http://timg.bdta.pro/images/47fc1e33a8120faa71fafeb95892c4ca.jpg'),
(45646, 3150, 'The Hour S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135066.mp4', 'http://gstaticontent.com/images/72JWVRK6VvqNx1gYumVxhtoXc03_big.jpg'),
(45647, 3150, 'The Hour S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135067.mp4', 'http://gstaticontent.com/images/72JWVRK6VvqNx1gYumVxhtoXc03_big.jpg'),
(45648, 3150, 'The Hour S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135068.mp4', 'http://gstaticontent.com/images/72JWVRK6VvqNx1gYumVxhtoXc03_big.jpg'),
(45649, 3150, 'The Hour S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135069.mp4', 'http://gstaticontent.com/images/72JWVRK6VvqNx1gYumVxhtoXc03_big.jpg'),
(45650, 3150, 'The Hour S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135070.mp4', 'http://gstaticontent.com/images/72JWVRK6VvqNx1gYumVxhtoXc03_big.jpg'),
(45651, 3150, 'The Hour S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135071.mp4', 'http://gstaticontent.com/images/72JWVRK6VvqNx1gYumVxhtoXc03_big.jpg'),
(45652, 3151, 'The Hour S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135072.mp4', 'http://gstaticontent.com/images/72JWVRK6VvqNx1gYumVxhtoXc03_big.jpg'),
(45653, 3151, 'The Hour S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135073.mp4', 'http://gstaticontent.com/images/72JWVRK6VvqNx1gYumVxhtoXc03_big.jpg'),
(45654, 3151, 'The Hour S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135074.mp4', 'http://gstaticontent.com/images/72JWVRK6VvqNx1gYumVxhtoXc03_big.jpg'),
(45655, 3151, 'The Hour S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135075.mp4', 'http://gstaticontent.com/images/72JWVRK6VvqNx1gYumVxhtoXc03_big.jpg'),
(45656, 3151, 'The Hour S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135076.mp4', 'http://gstaticontent.com/images/72JWVRK6VvqNx1gYumVxhtoXc03_big.jpg'),
(45657, 3151, 'The Hour S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135077.mp4', 'http://gstaticontent.com/images/72JWVRK6VvqNx1gYumVxhtoXc03_big.jpg'),
(45658, 3152, 'Tribos da Europa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135060.mp4', 'http://gstaticontent.com/images/ewEgxHvSJnQxH4nwYUr8yajqHOQ_big.jpg'),
(45659, 3152, 'Tribos da Europa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135061.mp4', 'http://gstaticontent.com/images/ewEgxHvSJnQxH4nwYUr8yajqHOQ_big.jpg'),
(45660, 3152, 'Tribos da Europa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135062.mp4', 'http://gstaticontent.com/images/ewEgxHvSJnQxH4nwYUr8yajqHOQ_big.jpg'),
(45661, 3152, 'Tribos da Europa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135063.mp4', 'http://gstaticontent.com/images/ewEgxHvSJnQxH4nwYUr8yajqHOQ_big.jpg'),
(45662, 3152, 'Tribos da Europa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135064.mp4', 'http://gstaticontent.com/images/ewEgxHvSJnQxH4nwYUr8yajqHOQ_big.jpg'),
(45663, 3152, 'Tribos da Europa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135065.mp4', 'http://gstaticontent.com/images/ewEgxHvSJnQxH4nwYUr8yajqHOQ_big.jpg'),
(45664, 3153, 'Ugly Betty S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134975.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45665, 3153, 'Ugly Betty S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134976.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45666, 3153, 'Ugly Betty S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134977.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45667, 3153, 'Ugly Betty S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134978.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45668, 3153, 'Ugly Betty S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134979.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45669, 3153, 'Ugly Betty S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134980.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45670, 3153, 'Ugly Betty S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134981.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45671, 3153, 'Ugly Betty S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134982.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45672, 3153, 'Ugly Betty S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/134983.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45673, 3153, 'Ugly Betty S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/134984.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45674, 3153, 'Ugly Betty S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/134985.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45675, 3153, 'Ugly Betty S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/134986.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45676, 3153, 'Ugly Betty S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/134987.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45677, 3153, 'Ugly Betty S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/134988.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45678, 3153, 'Ugly Betty S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/134989.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45679, 3153, 'Ugly Betty S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/134990.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45680, 3153, 'Ugly Betty S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/134991.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45681, 3153, 'Ugly Betty S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/134992.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45682, 3153, 'Ugly Betty S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/134993.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45683, 3153, 'Ugly Betty S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/134994.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45684, 3153, 'Ugly Betty S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/134995.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45685, 3153, 'Ugly Betty S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/134996.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45686, 3153, 'Ugly Betty S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/134997.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45687, 3154, 'Ugly Betty S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134998.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45688, 3154, 'Ugly Betty S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134999.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45689, 3154, 'Ugly Betty S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135000.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45690, 3154, 'Ugly Betty S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135001.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45691, 3154, 'Ugly Betty S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135002.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45692, 3154, 'Ugly Betty S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135003.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45693, 3154, 'Ugly Betty S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135004.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45694, 3154, 'Ugly Betty S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135005.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45695, 3154, 'Ugly Betty S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135006.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45696, 3154, 'Ugly Betty S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135007.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45697, 3154, 'Ugly Betty S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/135008.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45698, 3154, 'Ugly Betty S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/135009.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45699, 3154, 'Ugly Betty S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/135010.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45700, 3154, 'Ugly Betty S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/135011.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45701, 3154, 'Ugly Betty S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/135012.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45702, 3154, 'Ugly Betty S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/135013.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45703, 3154, 'Ugly Betty S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/135014.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45704, 3154, 'Ugly Betty S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/135015.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45705, 3155, 'Ugly Betty S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135016.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45706, 3155, 'Ugly Betty S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135017.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45707, 3155, 'Ugly Betty S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135018.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45708, 3155, 'Ugly Betty S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135019.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45709, 3155, 'Ugly Betty S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135020.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45710, 3155, 'Ugly Betty S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135021.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45711, 3155, 'Ugly Betty S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135022.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45712, 3155, 'Ugly Betty S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135023.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45713, 3155, 'Ugly Betty S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135024.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45714, 3155, 'Ugly Betty S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135025.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45715, 3155, 'Ugly Betty S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/135026.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45716, 3155, 'Ugly Betty S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/135027.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45717, 3155, 'Ugly Betty S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/135028.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45718, 3155, 'Ugly Betty S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/135029.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45719, 3155, 'Ugly Betty S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/135030.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45720, 3155, 'Ugly Betty S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/135031.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45721, 3155, 'Ugly Betty S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/135032.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45722, 3155, 'Ugly Betty S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/135033.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45723, 3155, 'Ugly Betty S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/135034.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45724, 3155, 'Ugly Betty S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/135035.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45725, 3155, 'Ugly Betty S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/135036.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(45726, 3155, 'Ugly Betty S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/135037.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45727, 3155, 'Ugly Betty S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/135038.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45728, 3155, 'Ugly Betty S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/135039.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45729, 3156, 'Ugly Betty S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/135040.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45730, 3156, 'Ugly Betty S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/135041.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45731, 3156, 'Ugly Betty S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/135042.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45732, 3156, 'Ugly Betty S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/135043.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45733, 3156, 'Ugly Betty S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/135044.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45734, 3156, 'Ugly Betty S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/135045.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45735, 3156, 'Ugly Betty S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/135046.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45736, 3156, 'Ugly Betty S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/135047.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45737, 3156, 'Ugly Betty S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/135048.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45738, 3156, 'Ugly Betty S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/135049.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45739, 3156, 'Ugly Betty S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/135050.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45740, 3156, 'Ugly Betty S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/135051.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45741, 3156, 'Ugly Betty S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/135052.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45742, 3156, 'Ugly Betty S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/135053.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45743, 3156, 'Ugly Betty S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/135054.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45744, 3156, 'Ugly Betty S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/135055.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45745, 3156, 'Ugly Betty S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/135056.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45746, 3156, 'Ugly Betty S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/135057.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45747, 3156, 'Ugly Betty S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/135058.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45748, 3156, 'Ugly Betty S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/135059.mp4', 'http://gstaticontent.com/images/prGylxnFpIWMcvHh9sUC46hmiIC_big.jpg'),
(45749, 3157, '9-1-1: Lone Star S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215671.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45750, 3157, '9-1-1: Lone Star S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215672.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45751, 3157, '9-1-1: Lone Star S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215673.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45752, 3157, '9-1-1: Lone Star S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215674.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45753, 3157, '9-1-1: Lone Star S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215675.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45754, 3157, '9-1-1: Lone Star S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215676.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45755, 3157, '9-1-1: Lone Star S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215677.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45756, 3157, '9-1-1: Lone Star S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215678.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45757, 3157, '9-1-1: Lone Star S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215679.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45758, 3157, '9-1-1: Lone Star S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215680.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45759, 3158, '9-1-1: Lone Star S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215681.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45760, 3158, '9-1-1: Lone Star S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215682.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45761, 3158, '9-1-1: Lone Star S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215683.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45762, 3158, '9-1-1: Lone Star S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215684.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45763, 3158, '9-1-1: Lone Star S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215685.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45764, 3158, '9-1-1: Lone Star S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215686.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45765, 3158, '9-1-1: Lone Star S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215687.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45766, 3158, '9-1-1: Lone Star S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215688.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45767, 3158, '9-1-1: Lone Star S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215689.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45768, 3158, '9-1-1: Lone Star S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215690.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45769, 3158, '9-1-1: Lone Star S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215691.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45770, 3158, '9-1-1: Lone Star S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215692.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45771, 3158, '9-1-1: Lone Star S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215693.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45772, 3158, '9-1-1: Lone Star S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215694.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45773, 3159, '9-1-1: Lone Star S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215695.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45774, 3159, '9-1-1: Lone Star S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215696.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45775, 3159, '9-1-1: Lone Star S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215697.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45776, 3159, '9-1-1: Lone Star S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215698.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45777, 3159, '9-1-1: Lone Star S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215699.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45778, 3159, '9-1-1: Lone Star S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215700.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45779, 3159, '9-1-1: Lone Star S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215701.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45780, 3159, '9-1-1: Lone Star S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215702.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45781, 3159, '9-1-1: Lone Star S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215703.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45782, 3159, '9-1-1: Lone Star S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215704.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45783, 3159, '9-1-1: Lone Star S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215705.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45784, 3159, '9-1-1: Lone Star S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215706.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45785, 3159, '9-1-1: Lone Star S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215707.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45786, 3159, '9-1-1: Lone Star S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215708.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45787, 3159, '9-1-1: Lone Star S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215709.mp4', 'http://timg.bdta.pro/images/bea20bbdcece7b6c0d05c5be9af8e292.jpg'),
(45788, 3159, '9-1-1: Lone Star S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215710.mp4', 'http://timg.bdta.pro/images/1f6c2112e86e3d007a5103b5c7f772f1.jpg'),
(45789, 3159, '9-1-1: Lone Star S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/215711.mp4', 'http://timg.bdta.pro/images/1a188329ac2a369b60f84928b41f807c.jpg'),
(45790, 3159, '9-1-1: Lone Star S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/215712.mp4', 'http://timg.bdta.pro/images/e7b154cc22a42a5ce77d53e4631f70b2.jpg'),
(45791, 3160, '9-1-1: Lone Star S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/umlbUY7kps9ma8WebvprSovSbjq.jpg'),
(45792, 3160, '9-1-1: Lone Star S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjjGTdN8c8IBdwNAOAG71CRH6aO.jpg'),
(45793, 3160, '9-1-1: Lone Star S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ZWrBRWtSTSwKqhZ8wi6pUv8lVq.jpg'),
(45794, 3160, '9-1-1: Lone Star S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eoL0NS7xSoh9Cm00419pwfhDMS6.jpg'),
(45795, 3160, '9-1-1: Lone Star S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/buwiCzEfziqsRagcqZXOiDSjC5e.jpg'),
(45796, 3160, '9-1-1: Lone Star S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cxONsk9PORbAMZFA34DnlPzHDOx.jpg'),
(45797, 3160, '9-1-1: Lone Star S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215719.mp4', 'http://image.tmdb.org/t/p/w1280/2BVikAWulyuCt5FeZG94QnBdduO.jpg'),
(45798, 3160, '9-1-1: Lone Star S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215720.mp4', 'http://image.tmdb.org/t/p/w1280/aVyaId0XeGRTO3z27WYgha9iIUw.jpg'),
(45799, 3160, '9-1-1: Lone Star S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215721.mp4', 'http://image.tmdb.org/t/p/w1280/8Hw8BSJ5FfKdDuh0Zt79sOEW4If.jpg'),
(45800, 3160, '9-1-1: Lone Star S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215722.mp4', 'http://image.tmdb.org/t/p/w1280/58CPEcIrLTKapNO5Fw4Fv7uD74S.jpg'),
(45801, 3160, '9-1-1: Lone Star S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6zh1L888lbrM6HaZKV9X2dAQvJt.jpg'),
(45802, 3160, '9-1-1: Lone Star S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ilWuKPTjw2GK8ZYBFA2nHjyY8RO.jpg'),
(45803, 3160, '9-1-1: Lone Star S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oDYbFMvefcU2m99Li4crQVcrHqt.jpg'),
(45804, 3160, '9-1-1: Lone Star S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kbVssiltVHz805OmljsaBBJMW4X.jpg'),
(45805, 3160, '9-1-1: Lone Star S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qHpHx7hN3xFfsX9OSZnz62111mk.jpg'),
(45806, 3160, '9-1-1: Lone Star S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215728.mp4', 'http://image.tmdb.org/t/p/w1280/rskpGYu4KgGVK2TICjYbpTetYuy.jpg'),
(45807, 3160, '9-1-1: Lone Star S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/514838.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3ciYHUCHapujud9AURaxbJlGLnh.jpg'),
(45808, 3160, '9-1-1: Lone Star S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/514839.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7rwV3MDvGKvOaWeymjIKS8ileDs.jpg'),
(45809, 3161, '9-1-1: Lone Star S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/632253.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cvzJuh1aBFQAqawklkdfWdHaZUR.jpg'),
(45810, 3161, '9-1-1: Lone Star S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508669.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45811, 3161, '9-1-1: Lone Star S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657213.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1yTu4ecZGHi0wNeBlF2oewUcHjG.jpg'),
(45812, 3161, '9-1-1: Lone Star S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479801.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45813, 3161, '9-1-1: Lone Star S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508670.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45814, 3161, '9-1-1: Lone Star S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508671.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45815, 3161, '9-1-1: Lone Star S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508672.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45816, 3161, '9-1-1: Lone Star S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/508673.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45817, 3161, '9-1-1: Lone Star S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/684963.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45818, 3161, '9-1-1: Lone Star S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/684964.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45819, 3161, '9-1-1: Lone Star S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/698964.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45820, 3161, '9-1-1: Lone Star S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/719448.mp4', 'http://gstaticontent.com/images/84354fd6fbcee718a3eca9f12d89482c.jpg'),
(45821, 3162, 'Mundo em Chamas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134968.mp4', 'http://gstaticontent.com/images/yhzBXDsiZjQv0EaIAy2Z6csEjyU_big.jpg'),
(45822, 3162, 'Mundo em Chamas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134969.mp4', 'http://gstaticontent.com/images/yhzBXDsiZjQv0EaIAy2Z6csEjyU_big.jpg'),
(45823, 3162, 'Mundo em Chamas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134970.mp4', 'http://gstaticontent.com/images/yhzBXDsiZjQv0EaIAy2Z6csEjyU_big.jpg'),
(45824, 3162, 'Mundo em Chamas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134971.mp4', 'http://gstaticontent.com/images/yhzBXDsiZjQv0EaIAy2Z6csEjyU_big.jpg'),
(45825, 3162, 'Mundo em Chamas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134972.mp4', 'http://gstaticontent.com/images/yhzBXDsiZjQv0EaIAy2Z6csEjyU_big.jpg'),
(45826, 3162, 'Mundo em Chamas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134973.mp4', 'http://gstaticontent.com/images/yhzBXDsiZjQv0EaIAy2Z6csEjyU_big.jpg'),
(45827, 3162, 'Mundo em Chamas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134974.mp4', 'http://gstaticontent.com/images/yhzBXDsiZjQv0EaIAy2Z6csEjyU_big.jpg'),
(45828, 3163, 'Mundo em Chamas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/310012.mp4', 'http://gstaticontent.com/images/yhzBXDsiZjQv0EaIAy2Z6csEjyU_big.jpg'),
(45829, 3163, 'Mundo em Chamas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/310013.mp4', 'http://gstaticontent.com/images/yhzBXDsiZjQv0EaIAy2Z6csEjyU_big.jpg'),
(45830, 3163, 'Mundo em Chamas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/310014.mp4', 'http://gstaticontent.com/images/yhzBXDsiZjQv0EaIAy2Z6csEjyU_big.jpg'),
(45831, 3163, 'Mundo em Chamas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/310015.mp4', 'http://gstaticontent.com/images/yhzBXDsiZjQv0EaIAy2Z6csEjyU_big.jpg'),
(45832, 3163, 'Mundo em Chamas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/310016.mp4', 'http://gstaticontent.com/images/yhzBXDsiZjQv0EaIAy2Z6csEjyU_big.jpg'),
(45833, 3163, 'Mundo em Chamas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/310017.mp4', 'http://gstaticontent.com/images/yhzBXDsiZjQv0EaIAy2Z6csEjyU_big.jpg'),
(45834, 3164, 'Predestinado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139598.mp4', 'http://gstaticontent.com/images/b0aES0JTee5Rt12WXTuSDggZI5G_big.jpg'),
(45835, 3164, 'Predestinado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139599.mp4', 'http://gstaticontent.com/images/b0aES0JTee5Rt12WXTuSDggZI5G_big.jpg'),
(45836, 3164, 'Predestinado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139600.mp4', 'http://gstaticontent.com/images/b0aES0JTee5Rt12WXTuSDggZI5G_big.jpg'),
(45837, 3164, 'Predestinado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139601.mp4', 'http://gstaticontent.com/images/b0aES0JTee5Rt12WXTuSDggZI5G_big.jpg'),
(45838, 3165, 'A Casa do Mickey Mouse S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134814.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45839, 3165, 'A Casa do Mickey Mouse S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134815.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45840, 3165, 'A Casa do Mickey Mouse S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134816.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45841, 3165, 'A Casa do Mickey Mouse S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134817.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45842, 3165, 'A Casa do Mickey Mouse S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134818.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45843, 3165, 'A Casa do Mickey Mouse S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134819.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45844, 3165, 'A Casa do Mickey Mouse S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134820.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45845, 3165, 'A Casa do Mickey Mouse S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134821.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45846, 3165, 'A Casa do Mickey Mouse S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/134822.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45847, 3165, 'A Casa do Mickey Mouse S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/134823.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45848, 3165, 'A Casa do Mickey Mouse S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/134824.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45849, 3165, 'A Casa do Mickey Mouse S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/134825.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45850, 3165, 'A Casa do Mickey Mouse S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/134826.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45851, 3165, 'A Casa do Mickey Mouse S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/134827.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45852, 3165, 'A Casa do Mickey Mouse S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/134828.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45853, 3165, 'A Casa do Mickey Mouse S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/134829.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45854, 3165, 'A Casa do Mickey Mouse S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/134830.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45855, 3165, 'A Casa do Mickey Mouse S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/134831.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45856, 3165, 'A Casa do Mickey Mouse S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/134832.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45857, 3165, 'A Casa do Mickey Mouse S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/134833.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45858, 3165, 'A Casa do Mickey Mouse S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/134834.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45859, 3165, 'A Casa do Mickey Mouse S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/134835.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45860, 3165, 'A Casa do Mickey Mouse S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/134836.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45861, 3165, 'A Casa do Mickey Mouse S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/134837.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45862, 3165, 'A Casa do Mickey Mouse S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/134838.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45863, 3165, 'A Casa do Mickey Mouse S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/134839.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45864, 3166, 'A Casa do Mickey Mouse S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134840.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45865, 3166, 'A Casa do Mickey Mouse S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134841.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45866, 3166, 'A Casa do Mickey Mouse S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134842.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45867, 3166, 'A Casa do Mickey Mouse S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134843.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45868, 3166, 'A Casa do Mickey Mouse S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134844.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45869, 3166, 'A Casa do Mickey Mouse S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134845.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45870, 3166, 'A Casa do Mickey Mouse S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134846.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45871, 3166, 'A Casa do Mickey Mouse S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134847.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45872, 3166, 'A Casa do Mickey Mouse S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/134848.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45873, 3166, 'A Casa do Mickey Mouse S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/134849.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45874, 3166, 'A Casa do Mickey Mouse S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/134850.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45875, 3166, 'A Casa do Mickey Mouse S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/134851.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45876, 3166, 'A Casa do Mickey Mouse S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/134852.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45877, 3166, 'A Casa do Mickey Mouse S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/134853.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45878, 3166, 'A Casa do Mickey Mouse S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/134854.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45879, 3166, 'A Casa do Mickey Mouse S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/134855.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45880, 3166, 'A Casa do Mickey Mouse S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/134856.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45881, 3166, 'A Casa do Mickey Mouse S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/134857.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45882, 3166, 'A Casa do Mickey Mouse S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/134858.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45883, 3166, 'A Casa do Mickey Mouse S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/134859.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45884, 3166, 'A Casa do Mickey Mouse S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/134860.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45885, 3166, 'A Casa do Mickey Mouse S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/134861.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45886, 3166, 'A Casa do Mickey Mouse S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/134862.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45887, 3166, 'A Casa do Mickey Mouse S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/134863.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45888, 3166, 'A Casa do Mickey Mouse S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/134864.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45889, 3166, 'A Casa do Mickey Mouse S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/134865.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45890, 3166, 'A Casa do Mickey Mouse S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/134866.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45891, 3166, 'A Casa do Mickey Mouse S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/134867.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45892, 3166, 'A Casa do Mickey Mouse S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/134868.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45893, 3166, 'A Casa do Mickey Mouse S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/134869.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45894, 3166, 'A Casa do Mickey Mouse S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/134870.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45895, 3166, 'A Casa do Mickey Mouse S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/134871.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45896, 3166, 'A Casa do Mickey Mouse S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/134872.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45897, 3166, 'A Casa do Mickey Mouse S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/134873.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45898, 3166, 'A Casa do Mickey Mouse S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/134874.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45899, 3166, 'A Casa do Mickey Mouse S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/134875.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45900, 3166, 'A Casa do Mickey Mouse S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/134876.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45901, 3166, 'A Casa do Mickey Mouse S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/134877.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45902, 3166, 'A Casa do Mickey Mouse S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/134878.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45903, 3167, 'A Casa do Mickey Mouse S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134879.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45904, 3167, 'A Casa do Mickey Mouse S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134880.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45905, 3167, 'A Casa do Mickey Mouse S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134881.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45906, 3167, 'A Casa do Mickey Mouse S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134882.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45907, 3167, 'A Casa do Mickey Mouse S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134883.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45908, 3167, 'A Casa do Mickey Mouse S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134884.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45909, 3167, 'A Casa do Mickey Mouse S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134885.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45910, 3167, 'A Casa do Mickey Mouse S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134886.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45911, 3167, 'A Casa do Mickey Mouse S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/134887.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45912, 3167, 'A Casa do Mickey Mouse S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/134888.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45913, 3167, 'A Casa do Mickey Mouse S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/134889.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45914, 3167, 'A Casa do Mickey Mouse S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/134890.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45915, 3167, 'A Casa do Mickey Mouse S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/134891.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45916, 3167, 'A Casa do Mickey Mouse S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/134892.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45917, 3167, 'A Casa do Mickey Mouse S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/134893.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45918, 3167, 'A Casa do Mickey Mouse S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/134894.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45919, 3167, 'A Casa do Mickey Mouse S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/134895.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45920, 3167, 'A Casa do Mickey Mouse S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/134896.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45921, 3167, 'A Casa do Mickey Mouse S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/134897.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45922, 3167, 'A Casa do Mickey Mouse S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/134898.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45923, 3167, 'A Casa do Mickey Mouse S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/134899.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45924, 3167, 'A Casa do Mickey Mouse S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/134900.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45925, 3167, 'A Casa do Mickey Mouse S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/134901.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45926, 3167, 'A Casa do Mickey Mouse S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/134902.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45927, 3167, 'A Casa do Mickey Mouse S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/134903.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45928, 3167, 'A Casa do Mickey Mouse S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/134904.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45929, 3167, 'A Casa do Mickey Mouse S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/134905.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45930, 3167, 'A Casa do Mickey Mouse S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/134906.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45931, 3167, 'A Casa do Mickey Mouse S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/134907.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45932, 3167, 'A Casa do Mickey Mouse S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/134908.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45933, 3167, 'A Casa do Mickey Mouse S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/134909.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45934, 3167, 'A Casa do Mickey Mouse S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/134910.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45935, 3167, 'A Casa do Mickey Mouse S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/134911.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45936, 3167, 'A Casa do Mickey Mouse S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/134912.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45937, 3167, 'A Casa do Mickey Mouse S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/134913.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45938, 3168, 'A Casa do Mickey Mouse S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134914.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45939, 3168, 'A Casa do Mickey Mouse S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134915.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45940, 3168, 'A Casa do Mickey Mouse S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134916.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45941, 3168, 'A Casa do Mickey Mouse S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134917.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45942, 3168, 'A Casa do Mickey Mouse S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134918.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45943, 3168, 'A Casa do Mickey Mouse S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134919.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45944, 3168, 'A Casa do Mickey Mouse S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134920.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45945, 3168, 'A Casa do Mickey Mouse S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134921.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45946, 3168, 'A Casa do Mickey Mouse S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/134922.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45947, 3168, 'A Casa do Mickey Mouse S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/134923.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45948, 3168, 'A Casa do Mickey Mouse S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/134924.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45949, 3168, 'A Casa do Mickey Mouse S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/134925.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45950, 3168, 'A Casa do Mickey Mouse S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/134926.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45951, 3168, 'A Casa do Mickey Mouse S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/134927.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45952, 3168, 'A Casa do Mickey Mouse S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/134928.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45953, 3168, 'A Casa do Mickey Mouse S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/134929.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45954, 3168, 'A Casa do Mickey Mouse S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/134930.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45955, 3168, 'A Casa do Mickey Mouse S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/134931.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45956, 3168, 'A Casa do Mickey Mouse S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/134932.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45957, 3168, 'A Casa do Mickey Mouse S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/134933.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45958, 3168, 'A Casa do Mickey Mouse S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/134934.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45959, 3168, 'A Casa do Mickey Mouse S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/134935.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45960, 3169, 'A Casa do Mickey Mouse S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134936.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45961, 3169, 'A Casa do Mickey Mouse S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134937.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45962, 3169, 'A Casa do Mickey Mouse S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134938.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45963, 3169, 'A Casa do Mickey Mouse S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/134939.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45964, 3169, 'A Casa do Mickey Mouse S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/134940.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45965, 3169, 'A Casa do Mickey Mouse S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/134941.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45966, 3169, 'A Casa do Mickey Mouse S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/134942.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45967, 3169, 'A Casa do Mickey Mouse S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/134943.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45968, 3169, 'A Casa do Mickey Mouse S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/134944.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45969, 3169, 'A Casa do Mickey Mouse S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/134945.mp4', 'http://gstaticontent.com/images/4vNQVFa4icNSphODjw1wFXTfDcJ_big.jpg'),
(45970, 3170, 'O Falsificador Mórmon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/134811.mp4', 'http://gstaticontent.com/images/pmoi9rbtAmcqQOLFN1LbsAHIjyO_big.jpg'),
(45971, 3170, 'O Falsificador Mórmon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/134812.mp4', 'http://gstaticontent.com/images/pmoi9rbtAmcqQOLFN1LbsAHIjyO_big.jpg'),
(45972, 3170, 'O Falsificador Mórmon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/134813.mp4', 'http://gstaticontent.com/images/pmoi9rbtAmcqQOLFN1LbsAHIjyO_big.jpg'),
(45973, 3171, 'Os Jovens Titãs em Ação S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260398.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45974, 3171, 'Os Jovens Titãs em Ação S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260399.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45975, 3171, 'Os Jovens Titãs em Ação S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260400.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45976, 3171, 'Os Jovens Titãs em Ação S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260401.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45977, 3171, 'Os Jovens Titãs em Ação S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260402.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45978, 3171, 'Os Jovens Titãs em Ação S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260403.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45979, 3171, 'Os Jovens Titãs em Ação S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260404.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45980, 3171, 'Os Jovens Titãs em Ação S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260405.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45981, 3171, 'Os Jovens Titãs em Ação S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260406.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45982, 3171, 'Os Jovens Titãs em Ação S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260407.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45983, 3171, 'Os Jovens Titãs em Ação S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260408.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45984, 3171, 'Os Jovens Titãs em Ação S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260409.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45985, 3171, 'Os Jovens Titãs em Ação S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260410.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45986, 3171, 'Os Jovens Titãs em Ação S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260411.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45987, 3171, 'Os Jovens Titãs em Ação S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260412.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45988, 3171, 'Os Jovens Titãs em Ação S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260413.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45989, 3171, 'Os Jovens Titãs em Ação S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260414.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45990, 3171, 'Os Jovens Titãs em Ação S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260415.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45991, 3171, 'Os Jovens Titãs em Ação S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260416.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45992, 3171, 'Os Jovens Titãs em Ação S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260417.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45993, 3171, 'Os Jovens Titãs em Ação S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260418.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45994, 3171, 'Os Jovens Titãs em Ação S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260419.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45995, 3171, 'Os Jovens Titãs em Ação S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/260420.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45996, 3171, 'Os Jovens Titãs em Ação S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/260421.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45997, 3171, 'Os Jovens Titãs em Ação S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/260422.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45998, 3171, 'Os Jovens Titãs em Ação S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/260423.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(45999, 3172, 'Os Jovens Titãs em Ação S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260424.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46000, 3172, 'Os Jovens Titãs em Ação S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260425.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46001, 3172, 'Os Jovens Titãs em Ação S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260426.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(46002, 3172, 'Os Jovens Titãs em Ação S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260427.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46003, 3172, 'Os Jovens Titãs em Ação S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260428.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46004, 3172, 'Os Jovens Titãs em Ação S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260429.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46005, 3172, 'Os Jovens Titãs em Ação S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260430.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46006, 3172, 'Os Jovens Titãs em Ação S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260431.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46007, 3172, 'Os Jovens Titãs em Ação S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260432.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46008, 3172, 'Os Jovens Titãs em Ação S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260433.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46009, 3172, 'Os Jovens Titãs em Ação S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260434.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46010, 3172, 'Os Jovens Titãs em Ação S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260435.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46011, 3172, 'Os Jovens Titãs em Ação S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260436.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46012, 3172, 'Os Jovens Titãs em Ação S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260437.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46013, 3172, 'Os Jovens Titãs em Ação S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260438.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46014, 3172, 'Os Jovens Titãs em Ação S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260439.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46015, 3172, 'Os Jovens Titãs em Ação S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260440.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46016, 3172, 'Os Jovens Titãs em Ação S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260441.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46017, 3172, 'Os Jovens Titãs em Ação S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260442.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46018, 3172, 'Os Jovens Titãs em Ação S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260443.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46019, 3172, 'Os Jovens Titãs em Ação S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260444.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46020, 3172, 'Os Jovens Titãs em Ação S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260445.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46021, 3172, 'Os Jovens Titãs em Ação S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/260446.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46022, 3172, 'Os Jovens Titãs em Ação S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/260447.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46023, 3172, 'Os Jovens Titãs em Ação S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/260448.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46024, 3172, 'Os Jovens Titãs em Ação S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/260449.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46025, 3173, 'Os Jovens Titãs em Ação S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260450.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46026, 3173, 'Os Jovens Titãs em Ação S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260451.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46027, 3173, 'Os Jovens Titãs em Ação S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260452.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46028, 3173, 'Os Jovens Titãs em Ação S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260453.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46029, 3173, 'Os Jovens Titãs em Ação S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260454.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46030, 3173, 'Os Jovens Titãs em Ação S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260455.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46031, 3173, 'Os Jovens Titãs em Ação S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260456.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46032, 3173, 'Os Jovens Titãs em Ação S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260457.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46033, 3173, 'Os Jovens Titãs em Ação S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260458.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46034, 3173, 'Os Jovens Titãs em Ação S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260459.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46035, 3173, 'Os Jovens Titãs em Ação S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260460.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46036, 3173, 'Os Jovens Titãs em Ação S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260461.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46037, 3173, 'Os Jovens Titãs em Ação S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260462.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46038, 3173, 'Os Jovens Titãs em Ação S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260463.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46039, 3173, 'Os Jovens Titãs em Ação S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260464.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46040, 3173, 'Os Jovens Titãs em Ação S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260465.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46041, 3173, 'Os Jovens Titãs em Ação S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260466.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46042, 3173, 'Os Jovens Titãs em Ação S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260467.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46043, 3173, 'Os Jovens Titãs em Ação S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260468.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46044, 3173, 'Os Jovens Titãs em Ação S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260469.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46045, 3173, 'Os Jovens Titãs em Ação S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260470.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46046, 3173, 'Os Jovens Titãs em Ação S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260471.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46047, 3173, 'Os Jovens Titãs em Ação S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/260472.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46048, 3174, 'Os Jovens Titãs em Ação S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260473.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46049, 3174, 'Os Jovens Titãs em Ação S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260474.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46050, 3174, 'Os Jovens Titãs em Ação S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260475.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46051, 3174, 'Os Jovens Titãs em Ação S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260476.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46052, 3174, 'Os Jovens Titãs em Ação S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260477.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46053, 3174, 'Os Jovens Titãs em Ação S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260478.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46054, 3174, 'Os Jovens Titãs em Ação S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260479.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46055, 3174, 'Os Jovens Titãs em Ação S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260480.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46056, 3174, 'Os Jovens Titãs em Ação S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260481.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46057, 3174, 'Os Jovens Titãs em Ação S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260482.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46058, 3174, 'Os Jovens Titãs em Ação S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260483.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46059, 3174, 'Os Jovens Titãs em Ação S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260484.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46060, 3174, 'Os Jovens Titãs em Ação S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260485.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46061, 3174, 'Os Jovens Titãs em Ação S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260486.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46062, 3174, 'Os Jovens Titãs em Ação S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260487.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46063, 3174, 'Os Jovens Titãs em Ação S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260488.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46064, 3174, 'Os Jovens Titãs em Ação S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260489.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46065, 3174, 'Os Jovens Titãs em Ação S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260490.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46066, 3174, 'Os Jovens Titãs em Ação S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260491.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46067, 3174, 'Os Jovens Titãs em Ação S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260492.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46068, 3174, 'Os Jovens Titãs em Ação S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260493.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46069, 3174, 'Os Jovens Titãs em Ação S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260494.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46070, 3174, 'Os Jovens Titãs em Ação S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/260495.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46071, 3174, 'Os Jovens Titãs em Ação S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/260496.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46072, 3174, 'Os Jovens Titãs em Ação S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/260497.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46073, 3174, 'Os Jovens Titãs em Ação S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/260498.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46074, 3175, 'Os Jovens Titãs em Ação S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260499.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46075, 3175, 'Os Jovens Titãs em Ação S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260500.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46076, 3175, 'Os Jovens Titãs em Ação S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260501.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46077, 3175, 'Os Jovens Titãs em Ação S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260502.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46078, 3175, 'Os Jovens Titãs em Ação S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260503.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46079, 3175, 'Os Jovens Titãs em Ação S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260504.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46080, 3175, 'Os Jovens Titãs em Ação S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260505.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46081, 3175, 'Os Jovens Titãs em Ação S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260506.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46082, 3175, 'Os Jovens Titãs em Ação S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260507.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46083, 3175, 'Os Jovens Titãs em Ação S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260508.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46084, 3175, 'Os Jovens Titãs em Ação S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260509.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46085, 3175, 'Os Jovens Titãs em Ação S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260510.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46086, 3175, 'Os Jovens Titãs em Ação S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260511.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46087, 3175, 'Os Jovens Titãs em Ação S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260512.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46088, 3175, 'Os Jovens Titãs em Ação S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260513.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46089, 3175, 'Os Jovens Titãs em Ação S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260514.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46090, 3175, 'Os Jovens Titãs em Ação S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260515.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46091, 3175, 'Os Jovens Titãs em Ação S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260516.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46092, 3175, 'Os Jovens Titãs em Ação S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260517.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46093, 3175, 'Os Jovens Titãs em Ação S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260518.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46094, 3175, 'Os Jovens Titãs em Ação S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260519.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46095, 3175, 'Os Jovens Titãs em Ação S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260520.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46096, 3175, 'Os Jovens Titãs em Ação S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/260521.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46097, 3175, 'Os Jovens Titãs em Ação S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/260522.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46098, 3175, 'Os Jovens Titãs em Ação S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/260523.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46099, 3175, 'Os Jovens Titãs em Ação S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/260524.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46100, 3176, 'Os Jovens Titãs em Ação S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3f7YrSXrlkwARxl9IBVNDElAcOf.jpg'),
(46101, 3176, 'Os Jovens Titãs em Ação S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/S60YaLetuQzSrFVBNWfqeoxoxp.jpg'),
(46102, 3176, 'Os Jovens Titãs em Ação S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vLy3Zhoj88mvSn17MYn9bmjzMsb.jpg'),
(46103, 3176, 'Os Jovens Titãs em Ação S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vxRQpGA3LmtWoHhTiwIQ56nqvFS.jpg'),
(46104, 3176, 'Os Jovens Titãs em Ação S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eRYd8o1fSVAOs74TWOhv4aN7COj.jpg'),
(46105, 3176, 'Os Jovens Titãs em Ação S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tBzFhsosY55d2lE1nnqT3vjqClY.jpg'),
(46106, 3176, 'Os Jovens Titãs em Ação S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sVMsDqIETPAVW02XJU1AdDur17t.jpg'),
(46107, 3176, 'Os Jovens Titãs em Ação S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tCIPM5bl8o0L0ubk4qiEyo54bfk.jpg'),
(46108, 3176, 'Os Jovens Titãs em Ação S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sLqyZ9bAW4Vc1hkeIJoSfilASRu.jpg'),
(46109, 3176, 'Os Jovens Titãs em Ação S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k5s5fApGC0GmEqbSunEJn2zEcUL.jpg'),
(46110, 3176, 'Os Jovens Titãs em Ação S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/VRam4ua58xRNhtMPxOsvvBXe1J.jpg'),
(46111, 3176, 'Os Jovens Titãs em Ação S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jLQjyDwI7EZt6VmBme2yc4Rz3gp.jpg'),
(46112, 3176, 'Os Jovens Titãs em Ação S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Sl0Kxj4g5BTHJT5D4mUUhzLU66.jpg'),
(46113, 3176, 'Os Jovens Titãs em Ação S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sGFBxFbOKupgNUZi068TltMHpl1.jpg'),
(46114, 3176, 'Os Jovens Titãs em Ação S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aCv09KdaIshmsrYOobIQaLYNqC0.jpg'),
(46115, 3176, 'Os Jovens Titãs em Ação S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jP79uhhsqxHmXXaBcnj5ur8bBk.jpg'),
(46116, 3176, 'Os Jovens Titãs em Ação S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s4DdfAxDSFoFiUPWKKYUc26kaSk.jpg'),
(46117, 3176, 'Os Jovens Titãs em Ação S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sore0XkpQY1geEKjtg8MmWj4vrd.jpg'),
(46118, 3176, 'Os Jovens Titãs em Ação S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3yzFilvoEkp0XFzxsABg2MfZdcI.jpg'),
(46119, 3176, 'Os Jovens Titãs em Ação S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fJm2miolYcgT7PFqhQCvyOqP2MW.jpg'),
(46120, 3176, 'Os Jovens Titãs em Ação S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gxfe0WDJppQwxA4KQVZM7zM4DbS.jpg'),
(46121, 3176, 'Os Jovens Titãs em Ação S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Ed4NkqHUFBPJHLto8xWdGogxUr.jpg'),
(46122, 3176, 'Os Jovens Titãs em Ação S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/260547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4hxO6XGughTcmOSc2fD67ZSSVUm.jpg'),
(46123, 3176, 'Os Jovens Titãs em Ação S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/260548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/loTRrgY0UXxEmaLAl80hmyUwoyT.jpg'),
(46124, 3176, 'Os Jovens Titãs em Ação S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/260549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mSPsKGWSL70Q0G8hS48ehBGD1bZ.jpg'),
(46125, 3176, 'Os Jovens Titãs em Ação S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/260550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bwQdvF0dlPswunINE4nEahBOTPZ.jpg'),
(46126, 3176, 'Os Jovens Titãs em Ação S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/260551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/17509zlPLfQYR6OdLfsAwuzpojA.jpg'),
(46127, 3176, 'Os Jovens Titãs em Ação S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/260552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbokouS69KfnOAaWOyqGDmQd9f6.jpg'),
(46128, 3176, 'Os Jovens Titãs em Ação S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/260553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a2ifu0XWzdnBg6tD513p6DsKKeP.jpg'),
(46129, 3176, 'Os Jovens Titãs em Ação S06 E30', 'http://sinalprivado.info:80/series/1533784/1533784/260554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cOhluSWa2sfnpBlAHcyVPKYTezC.jpg'),
(46130, 3176, 'Os Jovens Titãs em Ação S06 E31', 'http://sinalprivado.info:80/series/1533784/1533784/260555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFhJTj1kucgYrfjhygd4lcGlEHm.jpg'),
(46131, 3176, 'Os Jovens Titãs em Ação S06 E32', 'http://sinalprivado.info:80/series/1533784/1533784/260556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/JGxqjyQ8MmZ8NiI1BpOz08Bj9R.jpg'),
(46132, 3176, 'Os Jovens Titãs em Ação S06 E33', 'http://sinalprivado.info:80/series/1533784/1533784/260557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/euX0GhF0hVdBFbHuilZny7CfcAr.jpg'),
(46133, 3176, 'Os Jovens Titãs em Ação S06 E34', 'http://sinalprivado.info:80/series/1533784/1533784/260558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/19DaTWn6k4DSOFCmOQN66oddTu3.jpg'),
(46134, 3176, 'Os Jovens Titãs em Ação S06 E35', 'http://sinalprivado.info:80/series/1533784/1533784/260559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8MrZsMZR2A2KGGmnbWYQApE1SAW.jpg'),
(46135, 3176, 'Os Jovens Titãs em Ação S06 E36', 'http://sinalprivado.info:80/series/1533784/1533784/260560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kOyhVP0XtZdf4b6MW2SwhcJfRv0.jpg'),
(46136, 3176, 'Os Jovens Titãs em Ação S06 E37', 'http://sinalprivado.info:80/series/1533784/1533784/260561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pUhJs2X6Vc65Tfz2rKfKz1DAPNW.jpg'),
(46137, 3176, 'Os Jovens Titãs em Ação S06 E38', 'http://sinalprivado.info:80/series/1533784/1533784/260562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyTiPhDWa1Zxc8S5O1FmfMGkHPb.jpg'),
(46138, 3176, 'Os Jovens Titãs em Ação S06 E39', 'http://sinalprivado.info:80/series/1533784/1533784/260563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n1kz4qJeSFzOCeH1eRzsn6l8FQb.jpg'),
(46139, 3176, 'Os Jovens Titãs em Ação S06 E40', 'http://sinalprivado.info:80/series/1533784/1533784/260564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/apzQPcKEjR7OwXkrurE4lzDih4Y.jpg'),
(46140, 3176, 'Os Jovens Titãs em Ação S06 E41', 'http://sinalprivado.info:80/series/1533784/1533784/260565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xRmKpiuk94vpb32VJ0UfusTVH8s.jpg'),
(46141, 3176, 'Os Jovens Titãs em Ação S06 E42', 'http://sinalprivado.info:80/series/1533784/1533784/260566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3bY2hQ6zCewGth85HiBtgC9kKds.jpg'),
(46142, 3176, 'Os Jovens Titãs em Ação S06 E43', 'http://sinalprivado.info:80/series/1533784/1533784/260567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/snso0k37rNWp1KYy6nvtUqY8PDE.jpg'),
(46143, 3176, 'Os Jovens Titãs em Ação S06 E44', 'http://sinalprivado.info:80/series/1533784/1533784/260568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u2tYgadX6U3BINFCwxyxwmpuGZ0.jpg'),
(46144, 3176, 'Os Jovens Titãs em Ação S06 E45', 'http://sinalprivado.info:80/series/1533784/1533784/260569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/69edd5JUvEQoqKzOVdb4zSLZyWJ.jpg'),
(46145, 3176, 'Os Jovens Titãs em Ação S06 E46', 'http://sinalprivado.info:80/series/1533784/1533784/260570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/drILlXJTs5HT7ZKa7O9ZyLGToRb.jpg'),
(46146, 3176, 'Os Jovens Titãs em Ação S06 E47', 'http://sinalprivado.info:80/series/1533784/1533784/260571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uJphxw7V3rPNwSANAgi8zA7OFv3.jpg'),
(46147, 3176, 'Os Jovens Titãs em Ação S06 E48', 'http://sinalprivado.info:80/series/1533784/1533784/260572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g8CBnPXQ9wV6g2pLV8pf6AFl7le.jpg'),
(46148, 3176, 'Os Jovens Titãs em Ação S06 E49', 'http://sinalprivado.info:80/series/1533784/1533784/260573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iAW43tJbdYq44poFnsYHiwgz0R2.jpg'),
(46149, 3176, 'Os Jovens Titãs em Ação S06 E50', 'http://sinalprivado.info:80/series/1533784/1533784/260574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9k71xMmO4W0heH9MEvMComfRcke.jpg'),
(46150, 3176, 'Os Jovens Titãs em Ação S06 E51', 'http://sinalprivado.info:80/series/1533784/1533784/260575.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46151, 3176, 'Os Jovens Titãs em Ação S06 E52', 'http://sinalprivado.info:80/series/1533784/1533784/260576.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46152, 3177, 'Os Jovens Titãs em Ação S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ypMvZORdX5h2q8NcqVDhZYzJZW.jpg'),
(46153, 3177, 'Os Jovens Titãs em Ação S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zVlyHeajQ0uxKOd5nMMv9fQYejS.jpg'),
(46154, 3177, 'Os Jovens Titãs em Ação S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ELY1BaDUVij4VFyelAV5W4VKQH.jpg'),
(46155, 3177, 'Os Jovens Titãs em Ação S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/98u8h5X4u1yRxSpdJ1uIfTFNC8.jpg'),
(46156, 3177, 'Os Jovens Titãs em Ação S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nIYedbepiOzmUMQpf67qY8NdxZe.jpg'),
(46157, 3177, 'Os Jovens Titãs em Ação S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pxsujJqtaDe0EHmoZsCVZOj5uo0.jpg'),
(46158, 3177, 'Os Jovens Titãs em Ação S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o8LVIwmNNeqMIHsLHbGqv0j8zV1.jpg'),
(46159, 3177, 'Os Jovens Titãs em Ação S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nYy1QKefFsRfG2Tl5riPT8QUpXI.jpg'),
(46160, 3177, 'Os Jovens Titãs em Ação S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a3RaojsG22YGdGpy7msRBHGN1rQ.jpg'),
(46161, 3177, 'Os Jovens Titãs em Ação S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6vMGSX50xDrqO7ZbnBhDRgOLny.jpg'),
(46162, 3177, 'Os Jovens Titãs em Ação S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sxh6eeQd5us339m9hF2Haz5hRwA.jpg'),
(46163, 3177, 'Os Jovens Titãs em Ação S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8DZNwpORGikgRcFJWvv87d1iFSQ.jpg'),
(46164, 3177, 'Os Jovens Titãs em Ação S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Knh64aw1CihMPgPeqBvMhMjESP.jpg'),
(46165, 3177, 'Os Jovens Titãs em Ação S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ivpENtuujWsqo5GQdmqzPfcMsM6.jpg'),
(46166, 3177, 'Os Jovens Titãs em Ação S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8fxIZxPGIotVwcRNh0ksCSkRoB.jpg'),
(46167, 3177, 'Os Jovens Titãs em Ação S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svL9j3kVaZif0NgfxfdFIcLbD0o.jpg'),
(46168, 3177, 'Os Jovens Titãs em Ação S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lJxjzZ1ZapQQYu8KqU9ZcU8Z8xX.jpg'),
(46169, 3177, 'Os Jovens Titãs em Ação S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aGZUJziPipZnVgUISDITlyDECZC.jpg'),
(46170, 3177, 'Os Jovens Titãs em Ação S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTFyTZmMwixXOInCdHBagA5SapF.jpg'),
(46171, 3177, 'Os Jovens Titãs em Ação S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mTzEeU2f5yw1nVnr8vsWNvaNyLl.jpg'),
(46172, 3177, 'Os Jovens Titãs em Ação S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oOhT1KTvRNNSln9B3fD2lLvh3i1.jpg'),
(46173, 3177, 'Os Jovens Titãs em Ação S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Sl5yQSqS6Ess7LrO8Ihny6VJtv.jpg'),
(46174, 3177, 'Os Jovens Titãs em Ação S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/260599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JNxbvY8AUWSXWA3gK28sRKLJSm.jpg'),
(46175, 3177, 'Os Jovens Titãs em Ação S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/260600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xVBUEMo7KlfUYfnlZgwHC65B70o.jpg'),
(46176, 3177, 'Os Jovens Titãs em Ação S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/260601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8dYIIyJ1OWPA2lhs0rcfwlbE09l.jpg'),
(46177, 3177, 'Os Jovens Titãs em Ação S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/260602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bZGa31OPqCLAroNyRqTpQotL5w5.jpg'),
(46178, 3177, 'Os Jovens Titãs em Ação S07 E27', 'http://sinalprivado.info:80/series/1533784/1533784/260603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s8DOOWYLVyerdxubTHJk2W4E6Gm.jpg'),
(46179, 3177, 'Os Jovens Titãs em Ação S07 E28', 'http://sinalprivado.info:80/series/1533784/1533784/260604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bJBM9k23gIDelDD35Darh2huXRx.jpg'),
(46180, 3177, 'Os Jovens Titãs em Ação S07 E29', 'http://sinalprivado.info:80/series/1533784/1533784/260605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6GpXryx65vYHfKKsU92130Osx5D.jpg'),
(46181, 3177, 'Os Jovens Titãs em Ação S07 E30', 'http://sinalprivado.info:80/series/1533784/1533784/260606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cMwfFyNRL0k7v4pJbHUofObJGsH.jpg'),
(46182, 3177, 'Os Jovens Titãs em Ação S07 E31', 'http://sinalprivado.info:80/series/1533784/1533784/260607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2uN3ORqtoroPa2kzWjUNhTrwKf.jpg'),
(46183, 3177, 'Os Jovens Titãs em Ação S07 E32', 'http://sinalprivado.info:80/series/1533784/1533784/260608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lZEZ05IcKoSEwKtYtsqpPz0vfAR.jpg'),
(46184, 3177, 'Os Jovens Titãs em Ação S07 E33', 'http://sinalprivado.info:80/series/1533784/1533784/260609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/30peoajV2YeRMvuwCDqxdi9FqBI.jpg'),
(46185, 3177, 'Os Jovens Titãs em Ação S07 E34', 'http://sinalprivado.info:80/series/1533784/1533784/260610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sgl6qY5PLZSq4pejjGbWFKZWXzN.jpg'),
(46186, 3177, 'Os Jovens Titãs em Ação S07 E35', 'http://sinalprivado.info:80/series/1533784/1533784/260611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gGJkhZV8WiJ0LMIDO1oDkBHZDbo.jpg'),
(46187, 3177, 'Os Jovens Titãs em Ação S07 E36', 'http://sinalprivado.info:80/series/1533784/1533784/260612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gr8wsnHIde14LDFiAIfGBS5NyJV.jpg'),
(46188, 3177, 'Os Jovens Titãs em Ação S07 E37', 'http://sinalprivado.info:80/series/1533784/1533784/260613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKQzpl3TypbEacyMVuOZEhl7ox7.jpg'),
(46189, 3177, 'Os Jovens Titãs em Ação S07 E38', 'http://sinalprivado.info:80/series/1533784/1533784/260614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wwcjig8iMXBAPQhjpjVlrDxtmd5.jpg'),
(46190, 3177, 'Os Jovens Titãs em Ação S07 E39', 'http://sinalprivado.info:80/series/1533784/1533784/260615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBk8Yj8XZL4nsHAdTcpQxeZyaNq.jpg'),
(46191, 3177, 'Os Jovens Titãs em Ação S07 E40', 'http://sinalprivado.info:80/series/1533784/1533784/260616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iCabkdFZ619VSlR60afO7q3wbKf.jpg'),
(46192, 3177, 'Os Jovens Titãs em Ação S07 E41', 'http://sinalprivado.info:80/series/1533784/1533784/260617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvXHLISORrbt70v90vxS6W4kbxB.jpg'),
(46193, 3177, 'Os Jovens Titãs em Ação S07 E42', 'http://sinalprivado.info:80/series/1533784/1533784/260618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6I8QW0aTNMbngZH5mFxKdLTmHC3.jpg'),
(46194, 3177, 'Os Jovens Titãs em Ação S07 E43', 'http://sinalprivado.info:80/series/1533784/1533784/260619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pTUKPbFeEtu1JGWTATMYEkSTtgJ.jpg'),
(46195, 3177, 'Os Jovens Titãs em Ação S07 E44', 'http://sinalprivado.info:80/series/1533784/1533784/260620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1H5SPEZLK0MzyVH2hHCwhEGBwD4.jpg'),
(46196, 3177, 'Os Jovens Titãs em Ação S07 E45', 'http://sinalprivado.info:80/series/1533784/1533784/260621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fgmaOY73sMvaIweYSFAsLY8Arrh.jpg'),
(46197, 3177, 'Os Jovens Titãs em Ação S07 E46', 'http://sinalprivado.info:80/series/1533784/1533784/260622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Xoco9bRmnP333fKhDJQuwV8ZL8.jpg'),
(46198, 3177, 'Os Jovens Titãs em Ação S07 E47', 'http://sinalprivado.info:80/series/1533784/1533784/260623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8DJ9YWpY8gxaimGSlvsiu0wmqH8.jpg'),
(46199, 3177, 'Os Jovens Titãs em Ação S07 E48', 'http://sinalprivado.info:80/series/1533784/1533784/260624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nzg0d1azn5eLG1KFdCuZzazDc8n.jpg'),
(46200, 3177, 'Os Jovens Titãs em Ação S07 E49', 'http://sinalprivado.info:80/series/1533784/1533784/260625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3odqIaNpXakwBZ5qj3bdQ1dp0Yj.jpg'),
(46201, 3177, 'Os Jovens Titãs em Ação S07 E50', 'http://sinalprivado.info:80/series/1533784/1533784/260626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b1OaGZ4em08wVEiPnKkJ0lEYPNe.jpg'),
(46202, 3177, 'Os Jovens Titãs em Ação S07 E51', 'http://sinalprivado.info:80/series/1533784/1533784/260627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j48Whd4I0m7MfTeBfP4gZI01XSX.jpg'),
(46203, 3177, 'Os Jovens Titãs em Ação S07 E52', 'http://sinalprivado.info:80/series/1533784/1533784/260628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qVW4lunwJ0zFMTLCIDjsjelCOya.jpg'),
(46204, 3178, 'Os Jovens Titãs em Ação S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260629.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46205, 3178, 'Os Jovens Titãs em Ação S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260630.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46206, 3178, 'Os Jovens Titãs em Ação S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260631.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46207, 3178, 'Os Jovens Titãs em Ação S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260632.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46208, 3178, 'Os Jovens Titãs em Ação S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260633.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46209, 3178, 'Os Jovens Titãs em Ação S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260634.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46210, 3178, 'Os Jovens Titãs em Ação S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260635.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46211, 3178, 'Os Jovens Titãs em Ação S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260636.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46212, 3178, 'Os Jovens Titãs em Ação S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260637.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46213, 3178, 'Os Jovens Titãs em Ação S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260638.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46214, 3178, 'Os Jovens Titãs em Ação S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260639.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46215, 3178, 'Os Jovens Titãs em Ação S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260640.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46216, 3178, 'Os Jovens Titãs em Ação S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260641.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46217, 3178, 'Os Jovens Titãs em Ação S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260642.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46218, 3178, 'Os Jovens Titãs em Ação S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260643.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46219, 3178, 'Os Jovens Titãs em Ação S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260644.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46220, 3178, 'Os Jovens Titãs em Ação S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260645.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46221, 3178, 'Os Jovens Titãs em Ação S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260646.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46222, 3178, 'Os Jovens Titãs em Ação S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260647.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46223, 3178, 'Os Jovens Titãs em Ação S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260648.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46224, 3178, 'Os Jovens Titãs em Ação S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260649.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46225, 3178, 'Os Jovens Titãs em Ação S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260650.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46226, 3178, 'Os Jovens Titãs em Ação S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/260651.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46227, 3178, 'Os Jovens Titãs em Ação S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/260652.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46228, 3179, 'Os Jovens Titãs em Ação S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/827528.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46229, 3179, 'Os Jovens Titãs em Ação S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/827529.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46230, 3179, 'Os Jovens Titãs em Ação S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/827530.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46231, 3179, 'Os Jovens Titãs em Ação S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/827531.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46232, 3179, 'Os Jovens Titãs em Ação S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/827532.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46233, 3179, 'Os Jovens Titãs em Ação S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/827533.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46234, 3179, 'Os Jovens Titãs em Ação S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/827534.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46235, 3179, 'Os Jovens Titãs em Ação S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/827535.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46236, 3179, 'Os Jovens Titãs em Ação S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/827536.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46237, 3179, 'Os Jovens Titãs em Ação S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/827537.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46238, 3179, 'Os Jovens Titãs em Ação S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/827538.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46239, 3179, 'Os Jovens Titãs em Ação S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/827539.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46240, 3179, 'Os Jovens Titãs em Ação S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/827540.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46241, 3179, 'Os Jovens Titãs em Ação S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/887353.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46242, 3179, 'Os Jovens Titãs em Ação S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/887354.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46243, 3179, 'Os Jovens Titãs em Ação S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/887355.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46244, 3179, 'Os Jovens Titãs em Ação S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/887356.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46245, 3179, 'Os Jovens Titãs em Ação S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/887357.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46246, 3179, 'Os Jovens Titãs em Ação S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/887358.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46247, 3179, 'Os Jovens Titãs em Ação S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/887359.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46248, 3179, 'Os Jovens Titãs em Ação S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/887360.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46249, 3179, 'Os Jovens Titãs em Ação S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/887361.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46250, 3179, 'Os Jovens Titãs em Ação S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/887362.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46251, 3179, 'Os Jovens Titãs em Ação S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/887363.mp4', 'http://gstaticontent.com/images/udaLIJ6Na7GOHjvTlyP9JFPTccv_big.jpg'),
(46252, 3180, 'O Colapso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141540.mp4', 'http://gstaticontent.com/images/2DKwGBkRxIy04rkcG8lLV1N7OdB_big.jpg'),
(46253, 3181, 'Papai S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141541.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46254, 3181, 'Papai S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141542.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46255, 3181, 'Papai S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141543.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46256, 3181, 'Papai S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141544.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46257, 3181, 'Papai S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141545.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46258, 3181, 'Papai S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141546.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46259, 3181, 'Papai S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141547.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46260, 3181, 'Papai S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141548.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46261, 3181, 'Papai S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141549.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46262, 3181, 'Papai S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141550.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46263, 3182, 'Papai S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141551.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46264, 3182, 'Papai S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141552.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46265, 3182, 'Papai S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141553.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46266, 3182, 'Papai S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141554.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46267, 3182, 'Papai S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141555.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(46268, 3182, 'Papai S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141556.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46269, 3182, 'Papai S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141557.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46270, 3182, 'Papai S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141558.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46271, 3182, 'Papai S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141559.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46272, 3182, 'Papai S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141560.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46273, 3182, 'Papai S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141561.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46274, 3182, 'Papai S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141562.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46275, 3182, 'Papai S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141563.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46276, 3182, 'Papai S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141564.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46277, 3182, 'Papai S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141565.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46278, 3182, 'Papai S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141566.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46279, 3183, 'Papai S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141567.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46280, 3183, 'Papai S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141568.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46281, 3183, 'Papai S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141569.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46282, 3183, 'Papai S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141570.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46283, 3183, 'Papai S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141571.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46284, 3183, 'Papai S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141572.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46285, 3183, 'Papai S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141573.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46286, 3183, 'Papai S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141574.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46287, 3183, 'Papai S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141575.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46288, 3183, 'Papai S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141576.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46289, 3183, 'Papai S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141577.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46290, 3183, 'Papai S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141578.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46291, 3183, 'Papai S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141579.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46292, 3183, 'Papai S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141580.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46293, 3183, 'Papai S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141581.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46294, 3183, 'Papai S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141582.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46295, 3183, 'Papai S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141583.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46296, 3183, 'Papai S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141584.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46297, 3183, 'Papai S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141585.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46298, 3183, 'Papai S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141586.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46299, 3183, 'Papai S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/141587.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46300, 3184, 'Papai S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141588.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46301, 3184, 'Papai S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141589.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46302, 3184, 'Papai S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141590.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46303, 3184, 'Papai S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141591.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46304, 3184, 'Papai S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141592.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46305, 3184, 'Papai S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141593.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46306, 3184, 'Papai S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141594.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46307, 3184, 'Papai S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141595.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46308, 3184, 'Papai S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141596.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46309, 3184, 'Papai S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141597.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46310, 3184, 'Papai S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141598.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46311, 3184, 'Papai S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141599.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46312, 3184, 'Papai S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141600.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46313, 3184, 'Papai S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141601.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46314, 3184, 'Papai S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141602.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46315, 3184, 'Papai S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141603.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46316, 3184, 'Papai S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141604.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46317, 3184, 'Papai S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141605.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46318, 3184, 'Papai S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141606.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46319, 3184, 'Papai S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141607.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46320, 3184, 'Papai S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/141608.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46321, 3184, 'Papai S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/141609.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46322, 3185, 'Papai S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141610.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46323, 3185, 'Papai S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141611.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46324, 3185, 'Papai S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141612.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46325, 3185, 'Papai S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141613.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46326, 3185, 'Papai S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141614.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46327, 3185, 'Papai S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141615.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46328, 3185, 'Papai S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141616.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46329, 3185, 'Papai S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141617.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46330, 3185, 'Papai S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141618.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46331, 3185, 'Papai S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141619.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46332, 3185, 'Papai S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141620.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46333, 3185, 'Papai S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141621.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46334, 3185, 'Papai S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141622.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46335, 3185, 'Papai S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141623.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46336, 3185, 'Papai S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141624.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46337, 3185, 'Papai S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141625.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46338, 3185, 'Papai S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141626.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46339, 3185, 'Papai S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141627.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46340, 3185, 'Papai S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141628.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46341, 3185, 'Papai S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141629.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46342, 3186, 'Papai S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141630.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46343, 3186, 'Papai S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141631.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46344, 3186, 'Papai S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141632.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46345, 3186, 'Papai S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141633.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46346, 3186, 'Papai S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141634.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46347, 3186, 'Papai S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141635.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46348, 3186, 'Papai S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141636.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46349, 3186, 'Papai S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141637.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46350, 3186, 'Papai S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141638.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46351, 3186, 'Papai S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141639.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46352, 3186, 'Papai S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141640.mp4', 'http://gstaticontent.com/images/kSqzhu9KqdhIDV8yoeNlGgnyvQM_big.jpg'),
(46353, 3187, 'ER Plantão Médico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167360.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46354, 3187, 'ER Plantão Médico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167361.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46355, 3187, 'ER Plantão Médico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167362.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46356, 3187, 'ER Plantão Médico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167363.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46357, 3187, 'ER Plantão Médico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167364.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46358, 3187, 'ER Plantão Médico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167365.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46359, 3187, 'ER Plantão Médico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167366.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46360, 3187, 'ER Plantão Médico S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167367.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46361, 3187, 'ER Plantão Médico S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167368.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46362, 3187, 'ER Plantão Médico S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167369.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46363, 3187, 'ER Plantão Médico S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167370.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46364, 3187, 'ER Plantão Médico S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167371.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46365, 3187, 'ER Plantão Médico S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167372.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46366, 3187, 'ER Plantão Médico S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167373.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46367, 3187, 'ER Plantão Médico S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167374.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46368, 3187, 'ER Plantão Médico S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167375.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46369, 3187, 'ER Plantão Médico S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167376.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46370, 3187, 'ER Plantão Médico S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167377.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46371, 3187, 'ER Plantão Médico S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167378.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46372, 3187, 'ER Plantão Médico S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167379.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46373, 3187, 'ER Plantão Médico S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/167380.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46374, 3187, 'ER Plantão Médico S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/167381.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46375, 3187, 'ER Plantão Médico S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/167382.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46376, 3187, 'ER Plantão Médico S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/167383.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46377, 3187, 'ER Plantão Médico S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/167384.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46378, 3188, 'ER Plantão Médico S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167385.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46379, 3188, 'ER Plantão Médico S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167386.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46380, 3188, 'ER Plantão Médico S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167387.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46381, 3188, 'ER Plantão Médico S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167388.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46382, 3188, 'ER Plantão Médico S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167389.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46383, 3188, 'ER Plantão Médico S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167390.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46384, 3188, 'ER Plantão Médico S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167391.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46385, 3188, 'ER Plantão Médico S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167392.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46386, 3188, 'ER Plantão Médico S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167393.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46387, 3188, 'ER Plantão Médico S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167394.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46388, 3188, 'ER Plantão Médico S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167395.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46389, 3188, 'ER Plantão Médico S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167396.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46390, 3188, 'ER Plantão Médico S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167397.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46391, 3188, 'ER Plantão Médico S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167398.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46392, 3188, 'ER Plantão Médico S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167399.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46393, 3188, 'ER Plantão Médico S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167400.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46394, 3188, 'ER Plantão Médico S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167401.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46395, 3188, 'ER Plantão Médico S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167402.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46396, 3188, 'ER Plantão Médico S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167403.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46397, 3188, 'ER Plantão Médico S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167404.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46398, 3188, 'ER Plantão Médico S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/167405.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46399, 3188, 'ER Plantão Médico S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/167406.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46400, 3189, 'ER Plantão Médico S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167407.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46401, 3189, 'ER Plantão Médico S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167408.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46402, 3189, 'ER Plantão Médico S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167409.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46403, 3189, 'ER Plantão Médico S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167410.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46404, 3189, 'ER Plantão Médico S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167411.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46405, 3189, 'ER Plantão Médico S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167412.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46406, 3189, 'ER Plantão Médico S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167413.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46407, 3189, 'ER Plantão Médico S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167414.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46408, 3189, 'ER Plantão Médico S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167415.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46409, 3189, 'ER Plantão Médico S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167416.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46410, 3189, 'ER Plantão Médico S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167417.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46411, 3189, 'ER Plantão Médico S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167418.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46412, 3189, 'ER Plantão Médico S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167419.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46413, 3189, 'ER Plantão Médico S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167420.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46414, 3189, 'ER Plantão Médico S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167421.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46415, 3189, 'ER Plantão Médico S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167422.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46416, 3189, 'ER Plantão Médico S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167423.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46417, 3189, 'ER Plantão Médico S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167424.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46418, 3189, 'ER Plantão Médico S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167425.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46419, 3189, 'ER Plantão Médico S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167426.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46420, 3189, 'ER Plantão Médico S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/167427.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46421, 3189, 'ER Plantão Médico S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/167428.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46422, 3190, 'ER Plantão Médico S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167429.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46423, 3190, 'ER Plantão Médico S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167430.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46424, 3190, 'ER Plantão Médico S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167431.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46425, 3190, 'ER Plantão Médico S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167432.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46426, 3190, 'ER Plantão Médico S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167433.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46427, 3190, 'ER Plantão Médico S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167434.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46428, 3190, 'ER Plantão Médico S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167435.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46429, 3190, 'ER Plantão Médico S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167436.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46430, 3190, 'ER Plantão Médico S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167437.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46431, 3190, 'ER Plantão Médico S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167438.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46432, 3190, 'ER Plantão Médico S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167439.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46433, 3190, 'ER Plantão Médico S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167440.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46434, 3190, 'ER Plantão Médico S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167441.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46435, 3190, 'ER Plantão Médico S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167442.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46436, 3190, 'ER Plantão Médico S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167443.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46437, 3190, 'ER Plantão Médico S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167444.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46438, 3190, 'ER Plantão Médico S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167445.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46439, 3190, 'ER Plantão Médico S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167446.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46440, 3190, 'ER Plantão Médico S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167447.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46441, 3190, 'ER Plantão Médico S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167448.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46442, 3190, 'ER Plantão Médico S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/167449.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46443, 3190, 'ER Plantão Médico S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/167450.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46444, 3191, 'ER Plantão Médico S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167451.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46445, 3191, 'ER Plantão Médico S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167452.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46446, 3191, 'ER Plantão Médico S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167453.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46447, 3191, 'ER Plantão Médico S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167454.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46448, 3191, 'ER Plantão Médico S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167455.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46449, 3191, 'ER Plantão Médico S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167456.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46450, 3191, 'ER Plantão Médico S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167457.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46451, 3191, 'ER Plantão Médico S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167458.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46452, 3191, 'ER Plantão Médico S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167459.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46453, 3191, 'ER Plantão Médico S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167460.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46454, 3191, 'ER Plantão Médico S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167461.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46455, 3191, 'ER Plantão Médico S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167462.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46456, 3191, 'ER Plantão Médico S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167463.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46457, 3191, 'ER Plantão Médico S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167464.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46458, 3191, 'ER Plantão Médico S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167465.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46459, 3191, 'ER Plantão Médico S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167466.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46460, 3191, 'ER Plantão Médico S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167467.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46461, 3191, 'ER Plantão Médico S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167468.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46462, 3191, 'ER Plantão Médico S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167469.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46463, 3191, 'ER Plantão Médico S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167470.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46464, 3191, 'ER Plantão Médico S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/167471.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46465, 3191, 'ER Plantão Médico S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/167472.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46466, 3192, 'ER Plantão Médico S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j87Mb6YDUdmUdNYxBsRO0ftMNYu.jpg'),
(46467, 3192, 'ER Plantão Médico S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jAYuiY52CCYIk3aJzdzPPsTeVbA.jpg'),
(46468, 3192, 'ER Plantão Médico S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pho3yqGD97mAy3kLdsGNzXPG24D.jpg'),
(46469, 3192, 'ER Plantão Médico S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eCO9Gg13mzjyBOtUsp8URqsXsB1.jpg'),
(46470, 3192, 'ER Plantão Médico S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dcbWOptugcRhChVof7qxeKxSM2.jpg'),
(46471, 3192, 'ER Plantão Médico S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7EJ832x8UQ4r4iOAg5DpTRNI2vZ.jpg'),
(46472, 3192, 'ER Plantão Médico S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jPS3JSFtZmdpnhTCnv7bn1PaENV.jpg'),
(46473, 3192, 'ER Plantão Médico S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dlrq1imRRDR6aUHOuUb1nl3XU3Y.jpg'),
(46474, 3192, 'ER Plantão Médico S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ov0Ps1SyA6ThiTB7aJ2xLalK84t.jpg'),
(46475, 3192, 'ER Plantão Médico S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4UdXSx0c3ZFftSqlGZXjsusqi7s.jpg'),
(46476, 3192, 'ER Plantão Médico S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rRVcIHQ0WJ9P0XzI6odlJONckOd.jpg'),
(46477, 3192, 'ER Plantão Médico S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yZi3dPzukQ62VgYhUMfzk6sbPIr.jpg'),
(46478, 3192, 'ER Plantão Médico S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5wA8uocugbleuqytnL0QPB2eBth.jpg'),
(46479, 3192, 'ER Plantão Médico S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ytUJWd0fNWJU5dw8sRnmG5u0NOO.jpg'),
(46480, 3192, 'ER Plantão Médico S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fFKu9pFj8Leb3FmkDB4pjQRang1.jpg'),
(46481, 3192, 'ER Plantão Médico S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/txOV9RvAQqJt2SpYBjMWHt5snM3.jpg'),
(46482, 3192, 'ER Plantão Médico S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6yPQbhSuJOzfaxxJ58c6QqLVa0v.jpg'),
(46483, 3192, 'ER Plantão Médico S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oZCa2ZBBbbUs0w4BaeiO14M6IA8.jpg'),
(46484, 3192, 'ER Plantão Médico S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xW25XtqR0NvXpfirzaP91P2Hejv.jpg'),
(46485, 3192, 'ER Plantão Médico S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1KUpxwgF9bfpUu145Uj5m0Om071.jpg'),
(46486, 3192, 'ER Plantão Médico S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/167493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qSdWijwnSL5WIBLP5KpkwlAG9TH.jpg'),
(46487, 3192, 'ER Plantão Médico S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/167494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Kw4ErepxGEtREOl22c99aPC4WS.jpg'),
(46488, 3193, 'ER Plantão Médico S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hYKEXiXtw41GJFbC2oiQy7wYPsI.jpg'),
(46489, 3193, 'ER Plantão Médico S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4eCRQF5o8aUw5G57vWg8BTe5Fyr.jpg'),
(46490, 3193, 'ER Plantão Médico S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6wbPgLkjNHd4ICfHQSpUJ9v7X5g.jpg'),
(46491, 3193, 'ER Plantão Médico S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s9I2Mhi9B2UOu92pfIXP67z7e9T.jpg'),
(46492, 3193, 'ER Plantão Médico S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qIWITa7GgVXsgLCO92oKiDwRIXs.jpg'),
(46493, 3193, 'ER Plantão Médico S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vIYx0aqeQw1nrGWTpdnhMV9YsQy.jpg'),
(46494, 3193, 'ER Plantão Médico S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6pPtXsmJlVcXMF8xSc2bRLM3x1L.jpg'),
(46495, 3193, 'ER Plantão Médico S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pz3FdVRttV9RAdoISoQcHwGVm5O.jpg'),
(46496, 3193, 'ER Plantão Médico S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jGG19omBS9Walri7lixKOXMMudz.jpg'),
(46497, 3193, 'ER Plantão Médico S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4TL7DZEHLfXHULaYnDV4FpGoZTb.jpg'),
(46498, 3193, 'ER Plantão Médico S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nsqKFZLdcVydit0s13z8YILumxt.jpg'),
(46499, 3193, 'ER Plantão Médico S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVPOJkKcUNrkDKAMzNazKUGYELP.jpg'),
(46500, 3193, 'ER Plantão Médico S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iunAZJDlNuwAHKi1EiF69aAy5Jk.jpg'),
(46501, 3193, 'ER Plantão Médico S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zYwDSrjLZIzJxWQxjh73CBNvfwP.jpg'),
(46502, 3193, 'ER Plantão Médico S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qi8kOU5a7NqSqiqygBW1QUOIr6F.jpg'),
(46503, 3193, 'ER Plantão Médico S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t2g8vvidpt3V5GKaxTLZRZ5TzPN.jpg'),
(46504, 3193, 'ER Plantão Médico S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBE1f6Y5lV5SeX7esD2Vivh9Qya.jpg'),
(46505, 3193, 'ER Plantão Médico S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jxfBlX2WKwzsGGTmT4l0Csm6Zij.jpg'),
(46506, 3193, 'ER Plantão Médico S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lavTkiVzjehGYgJ8k6Zw4ojW0SE.jpg'),
(46507, 3193, 'ER Plantão Médico S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rkcQMzCudDJNTWzpxyKeA69ps5V.jpg'),
(46508, 3193, 'ER Plantão Médico S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/167515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/heZ1IBAPzD8wGJw2FD3BcABFcoH.jpg'),
(46509, 3193, 'ER Plantão Médico S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/167516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ra4PNhZiytD0GrlwMqUOwVkfZky.jpg'),
(46510, 3194, 'ER Plantão Médico S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/djMDhDOi5ScSsxepvieuglWNrpr.jpg'),
(46511, 3194, 'ER Plantão Médico S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/df7btLWbMjIFSub1qm9KOk7p2vp.jpg'),
(46512, 3194, 'ER Plantão Médico S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xRLxQZFh0j5Czcl5hd0ZPiLmp5T.jpg'),
(46513, 3194, 'ER Plantão Médico S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jnr7WrN7RHnOjzmunpXtc8iSKUr.jpg'),
(46514, 3194, 'ER Plantão Médico S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pqH9dMdHIwwYomLNOEZ5pmv7ECw.jpg'),
(46515, 3194, 'ER Plantão Médico S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8PJNZb0tHuug3WCnfCEr1xk9LBq.jpg'),
(46516, 3194, 'ER Plantão Médico S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ecy0K6FdMP9b04Kjma8i1rfO2FF.jpg'),
(46517, 3194, 'ER Plantão Médico S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m6ww3v3Tw53ljNNkKsqAwczZFUV.jpg'),
(46518, 3194, 'ER Plantão Médico S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f88CMezHFqkBMw3sXDPmEgW1DED.jpg'),
(46519, 3194, 'ER Plantão Médico S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ApwKvtynsrDzc1MzTu0Lr93gdln.jpg'),
(46520, 3194, 'ER Plantão Médico S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tysrFCERElOcG8Gcag3BBnniBhd.jpg'),
(46521, 3194, 'ER Plantão Médico S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7dEnsT38gyWl3DsQWMqbyRlXoqO.jpg'),
(46522, 3194, 'ER Plantão Médico S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9LnyQVoAdjDzfAQZ816PDarE6oR.jpg'),
(46523, 3194, 'ER Plantão Médico S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nQnUp9giVmvC9bX51g3Ad6VtaKW.jpg'),
(46524, 3194, 'ER Plantão Médico S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bc71dyas01Cg6oLz5DxStGWRBsX.jpg'),
(46525, 3194, 'ER Plantão Médico S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ulT8JbmrQdXcWWGzPcD1XX0LjH4.jpg'),
(46526, 3194, 'ER Plantão Médico S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b3jSexaYyP3LGIfzEJEXGYXnA0p.jpg'),
(46527, 3194, 'ER Plantão Médico S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2kRSP30dcwlYsG4m3my09M0VRrw.jpg'),
(46528, 3194, 'ER Plantão Médico S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8vFcJ16omqQ5TuzxnCE6NPifP6H.jpg'),
(46529, 3194, 'ER Plantão Médico S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/riMwl9WQ3VKTT29okkVIhjP7a5I.jpg'),
(46530, 3194, 'ER Plantão Médico S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/167537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kiGUVxFPEoIhl2m9hM9ECfh7sFx.jpg'),
(46531, 3194, 'ER Plantão Médico S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/167538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSZELh389UzHam9qlfskE2hXWj7.jpg'),
(46532, 3195, 'ER Plantão Médico S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8kaTulD273VIWjYZqjBuxsNG5GA.jpg'),
(46533, 3195, 'ER Plantão Médico S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A173bciWRuQb4CHDQ1r6M0sb5VW.jpg'),
(46534, 3195, 'ER Plantão Médico S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iw6P8thkW1GFLyclQmxWpo8qiAp.jpg'),
(46535, 3195, 'ER Plantão Médico S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6YKkh6kqhUqqTws5UgcO0xyBNmd.jpg'),
(46536, 3195, 'ER Plantão Médico S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hAohPGYo0PuVYaTn0oqf45tukfw.jpg'),
(46537, 3195, 'ER Plantão Médico S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xi2LFt7V1N7grazQ9gEmvXXt4TU.jpg'),
(46538, 3195, 'ER Plantão Médico S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x9Kr8FSMAgDh0BmPp7QXBFd9FPS.jpg'),
(46539, 3195, 'ER Plantão Médico S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8y8ymlALTvL4QWPRNmfBeY7VkJl.jpg'),
(46540, 3195, 'ER Plantão Médico S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e52BPk4Z1jGG7xk33hji9ktoEwl.jpg'),
(46541, 3195, 'ER Plantão Médico S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nP5dE92qc4M1PPYz8SlZMWg34FU.jpg'),
(46542, 3195, 'ER Plantão Médico S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vu0ALJHf9fU87bcA9DROB2CFfxy.jpg'),
(46543, 3195, 'ER Plantão Médico S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pqGHD5Lq4zOGFQIqbjcCCMERKcK.jpg'),
(46544, 3195, 'ER Plantão Médico S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j6fU2WODtAHwuS1zTdw8AGD5M04.jpg'),
(46545, 3195, 'ER Plantão Médico S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rKEvZhJwkRpwZjw1iByjfR5VVpx.jpg'),
(46546, 3195, 'ER Plantão Médico S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jVzIYkyefmOzGV7KQE3u4mGX9C6.jpg'),
(46547, 3195, 'ER Plantão Médico S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6V0niunpyM5S48NPb5bdFyaBKdJ.jpg'),
(46548, 3195, 'ER Plantão Médico S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bF5uprcOSHVn6LI37W9o25zcq15.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(46549, 3195, 'ER Plantão Médico S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3lSpeKw8LJ3GTAeShBwoRP2Xh4c.jpg'),
(46550, 3195, 'ER Plantão Médico S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dMrEsOjoCd4LiLa80k8IeDeAgEd.jpg'),
(46551, 3195, 'ER Plantão Médico S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kCMxysgKqREoWfzvNJRmpzMZGr.jpg'),
(46552, 3195, 'ER Plantão Médico S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/167559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7TACJQJoejCx96yjjMCRAD1Ijmd.jpg'),
(46553, 3195, 'ER Plantão Médico S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/167560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m24I9lGNQ6BSPfkGx71IBsCksO7.jpg'),
(46554, 3196, 'ER Plantão Médico S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQ97TGmpPgQ4lwE3674CkMT88g3.jpg'),
(46555, 3196, 'ER Plantão Médico S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vd3ZGGzJkqeJxeDS6FtZwlV8TBf.jpg'),
(46556, 3196, 'ER Plantão Médico S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3xbA0hQe5wj9twEsuJPINtiyCOR.jpg'),
(46557, 3196, 'ER Plantão Médico S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9n0G99sWAE6LY5QPLyEsmBRrTGL.jpg'),
(46558, 3196, 'ER Plantão Médico S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6pZrwEKRax5R5DSAAw0GzRYzbox.jpg'),
(46559, 3196, 'ER Plantão Médico S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3Kdqx9M6psN7pMeSjdR6hxtW3J.jpg'),
(46560, 3196, 'ER Plantão Médico S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eKzJSAYHK5UBOnHd722P15z6lOZ.jpg'),
(46561, 3196, 'ER Plantão Médico S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Pkh0qBUw32WWvjhRXRsCAoDUfY.jpg'),
(46562, 3196, 'ER Plantão Médico S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ryHQBnVe2ZM7ttyvnT2ymmSPBSx.jpg'),
(46563, 3196, 'ER Plantão Médico S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3sH1SwrwZlIo3UJ4Gv0pAuv8WYN.jpg'),
(46564, 3196, 'ER Plantão Médico S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZNxBXLNh2Dk6M8aKzIPRnBbBCs.jpg'),
(46565, 3196, 'ER Plantão Médico S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3XBj7tvzPmtAjr8cEnBwvkZgpuz.jpg'),
(46566, 3196, 'ER Plantão Médico S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u4jbcVNV5i43hs5ELA9whrj159h.jpg'),
(46567, 3196, 'ER Plantão Médico S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xHSH0FWzGeHKUrPqVAFti93M3V.jpg'),
(46568, 3196, 'ER Plantão Médico S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mIffAaOu06cKDxwhzKA1zB4mxQU.jpg'),
(46569, 3196, 'ER Plantão Médico S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nUNgepmoN0pFhRIqjkrNoBWllvK.jpg'),
(46570, 3196, 'ER Plantão Médico S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q6bYs0By3xaupognBoqJi8yDO5C.jpg'),
(46571, 3196, 'ER Plantão Médico S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r0Ymqe7IqXe20cPDx1sfexORVDt.jpg'),
(46572, 3196, 'ER Plantão Médico S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jITqfejMRzEo9zKvXC5RvKboAys.jpg'),
(46573, 3196, 'ER Plantão Médico S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/miyctJ1byk2T0ftC0gP6UZ7EThW.jpg'),
(46574, 3196, 'ER Plantão Médico S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/167581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqC3xANYVIFgAZ3ZR8JigVaFv36.jpg'),
(46575, 3196, 'ER Plantão Médico S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/167582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qJOPzmC1msZo1Z2J0qz74U2BubK.jpg'),
(46576, 3197, 'ER Plantão Médico S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gy3Jcv5YODHLhwR9vow9FUm2NB7.jpg'),
(46577, 3197, 'ER Plantão Médico S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzBMqrUTjmedJVPv8yk6lMTFWvC.jpg'),
(46578, 3197, 'ER Plantão Médico S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7wtRdYcbPnkjQbZQcm00PncUeIQ.jpg'),
(46579, 3197, 'ER Plantão Médico S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y1j6tUFxMxEF3XUeN0wUzgSKmbx.jpg'),
(46580, 3197, 'ER Plantão Médico S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cfJlwX62HKtz41zARdZ7Te3gMdH.jpg'),
(46581, 3197, 'ER Plantão Médico S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/txLM4J3bQFiofQq4m3mvI1bv6uw.jpg'),
(46582, 3197, 'ER Plantão Médico S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rkJjqh3yFg2AurYm5nr8DEyoG0A.jpg'),
(46583, 3197, 'ER Plantão Médico S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A51KzxUa4tOR2pJut0AJXvpS8mu.jpg'),
(46584, 3197, 'ER Plantão Médico S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2PPRUasYCgieFSfS8LHxDWkmiKX.jpg'),
(46585, 3197, 'ER Plantão Médico S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lxWtLVRHOPPPRH97U4XngtNvHFG.jpg'),
(46586, 3197, 'ER Plantão Médico S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sPshp6NhJhzxJRKQysfu6WD4APT.jpg'),
(46587, 3197, 'ER Plantão Médico S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p0I5iv0HGF9wvJfw4qqfDWARAXB.jpg'),
(46588, 3197, 'ER Plantão Médico S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hYwQPUJN2lseB00UsuRJlZRn3H4.jpg'),
(46589, 3197, 'ER Plantão Médico S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jsVU2q5j75fPD4mVmMu4JxFBYHf.jpg'),
(46590, 3197, 'ER Plantão Médico S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nbNqfCs2QgwMOoCp57tuA9FQWbe.jpg'),
(46591, 3197, 'ER Plantão Médico S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/WALXfgd7BCsB2qVtU4FCn9vkkA.jpg'),
(46592, 3197, 'ER Plantão Médico S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6QLFk3XtNgBRkc2ri9CYkbG8LU.jpg'),
(46593, 3197, 'ER Plantão Médico S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gMIVZEEQoohkme0jPq2rTnQWJEm.jpg'),
(46594, 3197, 'ER Plantão Médico S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1VqpCcLNjHNZ24YGKtfH4LcG1g.jpg'),
(46595, 3197, 'ER Plantão Médico S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nYRV5SKxoB90OZrVvX2newy7p2U.jpg'),
(46596, 3197, 'ER Plantão Médico S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/167603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p8GCXdyirVpEDMdEs03IUdikz2g.jpg'),
(46597, 3197, 'ER Plantão Médico S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/167604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ji9a9cjjZi8gyvo9QVwlHSrtB40.jpg'),
(46598, 3198, 'ER Plantão Médico S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lfo24gUfkPZE9m2BIYTzFJ4CcaM.jpg'),
(46599, 3198, 'ER Plantão Médico S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gX7wTXMTTMzpmcpqKNse3RJmmhR.jpg'),
(46600, 3198, 'ER Plantão Médico S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wUgz0Zw6LnoHx8vTPM7q0OS4oUK.jpg'),
(46601, 3198, 'ER Plantão Médico S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTA3KLLGhglXjXj07oZFLJfHkmM.jpg'),
(46602, 3198, 'ER Plantão Médico S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bs0A9252sNK45a88QholbbQf12D.jpg'),
(46603, 3198, 'ER Plantão Médico S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/40YcexXTxLnJOtNWlvvUXAxa5qn.jpg'),
(46604, 3198, 'ER Plantão Médico S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kg9FPyTWAfu9nlJyBZTVHVK86kn.jpg'),
(46605, 3198, 'ER Plantão Médico S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iToisaThpbqKSGPnSkoVodC8SPT.jpg'),
(46606, 3198, 'ER Plantão Médico S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j8kkOjvqETxctviMgwDjAGndo8.jpg'),
(46607, 3198, 'ER Plantão Médico S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yzcp3iG4rPM2OnBDqb5vZcoGuVi.jpg'),
(46608, 3198, 'ER Plantão Médico S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnQ66pPKFR1N65mhy9AzG5NLLph.jpg'),
(46609, 3198, 'ER Plantão Médico S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7meXIKLv3jIjRwthXJlM71UoSX9.jpg'),
(46610, 3198, 'ER Plantão Médico S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f6HAs0DaXzGYVXxqBRF8FThj0yj.jpg'),
(46611, 3198, 'ER Plantão Médico S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iYt0A8u1qrYj4WPF0B3FcvqTMDw.jpg'),
(46612, 3198, 'ER Plantão Médico S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dEzK9QJhWiCS97SngXwjjNQ9MbG.jpg'),
(46613, 3198, 'ER Plantão Médico S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ydGGo35HrFvqAPEmynXf1rzix6u.jpg'),
(46614, 3198, 'ER Plantão Médico S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lTKIWL3uR8rjVuwwxllKHMjUOhv.jpg'),
(46615, 3198, 'ER Plantão Médico S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PaIQEocQHZ2yunVfoSKXXsQu3c.jpg'),
(46616, 3198, 'ER Plantão Médico S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ctziNejctFgbEHV3TKVqD4KFaCr.jpg'),
(46617, 3198, 'ER Plantão Médico S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6JMUlpITFkFIGtZgnxBMndKGzZP.jpg'),
(46618, 3198, 'ER Plantão Médico S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/167625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qsql2r5z6A4c3Om8Br5PvaVLyvy.jpg'),
(46619, 3198, 'ER Plantão Médico S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/167626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCSW8rPdAMka447mnN0iLoux8Zd.jpg'),
(46620, 3199, 'ER Plantão Médico S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/DBOPyvw0fyRC1Fjhh5D2mpiYye.jpg'),
(46621, 3199, 'ER Plantão Médico S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qh4tG5ltmJ6TVjhWERIf7BGFbFd.jpg'),
(46622, 3199, 'ER Plantão Médico S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/szhtQbxtsQQO17X3jX2wq85S5pt.jpg'),
(46623, 3199, 'ER Plantão Médico S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hL8KDz9VVEnwjyOstU3nelkgtsO.jpg'),
(46624, 3199, 'ER Plantão Médico S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVZ1Et8wU6pJQLiqHtpAcA8E9Pl.jpg'),
(46625, 3199, 'ER Plantão Médico S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/51KZpDwyj7NzIYLTYTpdiLa5GnX.jpg'),
(46626, 3199, 'ER Plantão Médico S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u0rMShkEgLiKLaXWiZb981d4sHc.jpg'),
(46627, 3199, 'ER Plantão Médico S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dAH2KWz7UZgbtskfa0ENKKTo2Iv.jpg'),
(46628, 3199, 'ER Plantão Médico S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hoJktfnRqkZPqqZhqQ4vSbhEyzj.jpg'),
(46629, 3199, 'ER Plantão Médico S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zOk3rQD06b5cBXuyV3rnkQn18vc.jpg'),
(46630, 3199, 'ER Plantão Médico S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167637.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46631, 3199, 'ER Plantão Médico S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167638.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46632, 3199, 'ER Plantão Médico S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167639.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46633, 3199, 'ER Plantão Médico S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sYpzPmy9g9hAsAbW1R8EviW4tmY.jpg'),
(46634, 3199, 'ER Plantão Médico S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/htOITnJcSWEFNxUQLGqYM175Cpu.jpg'),
(46635, 3199, 'ER Plantão Médico S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7vPagDxuuJYFtewgYNQgJQwOkUV.jpg'),
(46636, 3199, 'ER Plantão Médico S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/KwKKGuejqk2QSpiAt7f0t2hfqJ.jpg'),
(46637, 3199, 'ER Plantão Médico S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uiuDYVFDuyeIiTSjUZg3s1W6RZA.jpg'),
(46638, 3199, 'ER Plantão Médico S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2CZvtAkLjyKNALDnBi2ebW4TURI.jpg'),
(46639, 3199, 'ER Plantão Médico S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sxFgkJb77DXvr7D50gBedAGiQo9.jpg'),
(46640, 3199, 'ER Plantão Médico S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/167647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ceejBGTrkHRO2bpeTlK3h43mrud.jpg'),
(46641, 3199, 'ER Plantão Médico S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/167648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hUHGOZAHa4ksevIiOeUokg4szG7.jpg'),
(46642, 3199, 'ER Plantão Médico S13 E23', 'http://sinalprivado.info:80/series/1533784/1533784/167649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmFkW9a4HBhCBNUb08A75YZheFI.jpg'),
(46643, 3200, 'ER Plantão Médico S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqDGg4pCqSO0d5i9OBkUhwviF0N.jpg'),
(46644, 3200, 'ER Plantão Médico S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qAGxphXdyockmaeBBHjb6MqDycs.jpg'),
(46645, 3200, 'ER Plantão Médico S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iYrVvJ18DG7juJ3GRRdK4hZh98x.jpg'),
(46646, 3200, 'ER Plantão Médico S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/UywctlhXen62Mnxsl70KvOaxRn.jpg'),
(46647, 3200, 'ER Plantão Médico S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AtP5wzGhjgaPSOeTD2eKgEn7dqK.jpg'),
(46648, 3200, 'ER Plantão Médico S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kAG0TZkJnPO5efZ4XQT6ntbXcJ.jpg'),
(46649, 3200, 'ER Plantão Médico S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bwpJdy2E5m379g8Y00gyngvaiM4.jpg'),
(46650, 3200, 'ER Plantão Médico S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHLRuary8LFcK0ks8hlERg4Pqb1.jpg'),
(46651, 3200, 'ER Plantão Médico S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vs4flGjpw6P4GaNDg16ToJOxVUs.jpg'),
(46652, 3200, 'ER Plantão Médico S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kQIajfcR8uPAYfEkHlB1envo0ZO.jpg'),
(46653, 3200, 'ER Plantão Médico S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEq0CrZXu9E1Wo0UupdbL0gLPUE.jpg'),
(46654, 3200, 'ER Plantão Médico S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ttt63qHbhGhL77atcIVYHwTKwDU.jpg'),
(46655, 3200, 'ER Plantão Médico S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1BS4SbpS4xcindiWd51GAnVQiE9.jpg'),
(46656, 3200, 'ER Plantão Médico S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDBdrjU1sfbsyTJllCbVnLuo27Y.jpg'),
(46657, 3200, 'ER Plantão Médico S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Q007Iceb2U6C63yytQKjRldL6O.jpg'),
(46658, 3200, 'ER Plantão Médico S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUIuMgZnTrnOFv9VUdmFT97cX2k.jpg'),
(46659, 3200, 'ER Plantão Médico S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a2ylT4jDTAQS4E40S6FLBNKK15u.jpg'),
(46660, 3200, 'ER Plantão Médico S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2STJQwnBbqbeuZppu6BnHU7pq1A.jpg'),
(46661, 3200, 'ER Plantão Médico S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f1n8Ye3i6605Pu669cr5SuJ53FQ.jpg'),
(46662, 3201, 'ER Plantão Médico S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7hIdQc700dCALZ3DPPqqhigkpzF.jpg'),
(46663, 3201, 'ER Plantão Médico S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/usxXp9M9RvaAPaSel3wR3Dvg9U6.jpg'),
(46664, 3201, 'ER Plantão Médico S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bXmTuenZWqfsbfIDMF55N9ZObJ0.jpg'),
(46665, 3201, 'ER Plantão Médico S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ob5NnHcHFmLz21jRsCxn7yAv8VM.jpg'),
(46666, 3201, 'ER Plantão Médico S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqQr43da0HfvmnygOZn5lzabw5V.jpg'),
(46667, 3201, 'ER Plantão Médico S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xEY68b9X1GTpE3NEgj2K0bNwzb2.jpg'),
(46668, 3201, 'ER Plantão Médico S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6X6XkGYLI89COFsECLB0LxAHmQu.jpg'),
(46669, 3201, 'ER Plantão Médico S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xkVVBDjVXcHEHQPxzO8m5FXCWnM.jpg'),
(46670, 3201, 'ER Plantão Médico S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dzCeKeRWxEKDQ4U613NZGqjE86n.jpg'),
(46671, 3201, 'ER Plantão Médico S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2K2vf8b5UAmMjKPMCwrrxDkaPKa.jpg'),
(46672, 3201, 'ER Plantão Médico S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/unQ8Q1rkVlZ5g2qqYrRWOtDW0Ed.jpg'),
(46673, 3201, 'ER Plantão Médico S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nyRUnVFbRA4VCbDo3pbbZcXvPMB.jpg'),
(46674, 3201, 'ER Plantão Médico S15 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jedfM7DGXPXv0TlspiXHaP1O3Lv.jpg'),
(46675, 3201, 'ER Plantão Médico S15 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lOAfon1Ddulrwcw4HdzT44BWhHA.jpg'),
(46676, 3201, 'ER Plantão Médico S15 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rSYObqoPxYJgzUxXInyjRb1u5wX.jpg'),
(46677, 3201, 'ER Plantão Médico S15 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/OFgUnsQUh0385EjJd4NXjRr1gx.jpg'),
(46678, 3201, 'ER Plantão Médico S15 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q6Z8tfvpRYleSCBFMFn2HFDThJw.jpg'),
(46679, 3201, 'ER Plantão Médico S15 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vfcXVrQGe8PPWrmgbBepT9bTUiS.jpg'),
(46680, 3201, 'ER Plantão Médico S15 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/89ysgaLXbZUP2OVKDAi04Z5dz3P.jpg'),
(46681, 3201, 'ER Plantão Médico S15 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hbVh2xwULfKhw6X8TgerrTzxxGY.jpg'),
(46682, 3201, 'ER Plantão Médico S15 E21', 'http://sinalprivado.info:80/series/1533784/1533784/167689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eLHa6fYBPPJPvU3CSM9CpsMqJyf.jpg'),
(46683, 3201, 'ER Plantão Médico S15 E22', 'http://sinalprivado.info:80/series/1533784/1533784/167690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/biqWbfLUwqHR3I0czNZzmNT8eS8.jpg'),
(46684, 3201, 'ER Plantão Médico S15 E23', 'http://sinalprivado.info:80/series/1533784/1533784/167691.mp4', 'http://gstaticontent.com/images/dPj3iAXq0A5L5kwpHh32j0iccY6_big.jpg'),
(46685, 3202, 'Small Axe S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146223.mp4', 'http://gstaticontent.com/images/hrGv1TN5tWpM3n9IMpPPTdzFt57_big.jpg'),
(46686, 3202, 'Small Axe S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146224.mp4', 'http://gstaticontent.com/images/hrGv1TN5tWpM3n9IMpPPTdzFt57_big.jpg'),
(46687, 3202, 'Small Axe S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146225.mp4', 'http://gstaticontent.com/images/hrGv1TN5tWpM3n9IMpPPTdzFt57_big.jpg'),
(46688, 3202, 'Small Axe S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146226.mp4', 'http://gstaticontent.com/images/hrGv1TN5tWpM3n9IMpPPTdzFt57_big.jpg'),
(46689, 3202, 'Small Axe S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146227.mp4', 'http://gstaticontent.com/images/hrGv1TN5tWpM3n9IMpPPTdzFt57_big.jpg'),
(46690, 3203, 'Debris [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148014.mp4', 'http://gstaticontent.com/images/cILrZGHgsIEpZ6VKEB3VwC2CadB_big.jpg'),
(46691, 3203, 'Debris [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148015.mp4', 'http://gstaticontent.com/images/cILrZGHgsIEpZ6VKEB3VwC2CadB_big.jpg'),
(46692, 3203, 'Debris [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148016.mp4', 'http://gstaticontent.com/images/cILrZGHgsIEpZ6VKEB3VwC2CadB_big.jpg'),
(46693, 3203, 'Debris [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148017.mp4', 'http://gstaticontent.com/images/cILrZGHgsIEpZ6VKEB3VwC2CadB_big.jpg'),
(46694, 3203, 'Debris [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148018.mp4', 'http://gstaticontent.com/images/cILrZGHgsIEpZ6VKEB3VwC2CadB_big.jpg'),
(46695, 3203, 'Debris [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148019.mp4', 'http://gstaticontent.com/images/cILrZGHgsIEpZ6VKEB3VwC2CadB_big.jpg'),
(46696, 3203, 'Debris [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148020.mp4', 'http://gstaticontent.com/images/cILrZGHgsIEpZ6VKEB3VwC2CadB_big.jpg'),
(46697, 3203, 'Debris [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148021.mp4', 'http://gstaticontent.com/images/cILrZGHgsIEpZ6VKEB3VwC2CadB_big.jpg'),
(46698, 3203, 'Debris [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148022.mp4', 'http://gstaticontent.com/images/cILrZGHgsIEpZ6VKEB3VwC2CadB_big.jpg'),
(46699, 3203, 'Debris [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148023.mp4', 'http://gstaticontent.com/images/cILrZGHgsIEpZ6VKEB3VwC2CadB_big.jpg'),
(46700, 3203, 'Debris [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148024.mp4', 'http://gstaticontent.com/images/cILrZGHgsIEpZ6VKEB3VwC2CadB_big.jpg'),
(46701, 3203, 'Debris [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148025.mp4', 'http://gstaticontent.com/images/cILrZGHgsIEpZ6VKEB3VwC2CadB_big.jpg'),
(46702, 3203, 'Debris [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148026.mp4', 'http://gstaticontent.com/images/cILrZGHgsIEpZ6VKEB3VwC2CadB_big.jpg'),
(46703, 3204, 'Harrow S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174618.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46704, 3204, 'Harrow S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174619.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46705, 3204, 'Harrow S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174620.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46706, 3204, 'Harrow S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174621.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46707, 3204, 'Harrow S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174622.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46708, 3204, 'Harrow S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174623.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46709, 3204, 'Harrow S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174624.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46710, 3204, 'Harrow S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174625.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46711, 3204, 'Harrow S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174626.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46712, 3204, 'Harrow S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174627.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46713, 3205, 'Harrow S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174628.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46714, 3205, 'Harrow S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174629.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46715, 3205, 'Harrow S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174630.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46716, 3205, 'Harrow S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174631.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46717, 3205, 'Harrow S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174632.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46718, 3205, 'Harrow S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174633.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46719, 3205, 'Harrow S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174634.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46720, 3205, 'Harrow S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174635.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46721, 3205, 'Harrow S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174636.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46722, 3205, 'Harrow S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174637.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46723, 3206, 'Harrow S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174638.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46724, 3206, 'Harrow S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174639.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46725, 3206, 'Harrow S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174640.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46726, 3206, 'Harrow S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174641.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46727, 3206, 'Harrow S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174642.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46728, 3206, 'Harrow S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174643.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46729, 3206, 'Harrow S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174644.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46730, 3206, 'Harrow S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174645.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46731, 3206, 'Harrow S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174646.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46732, 3206, 'Harrow S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174647.mp4', 'http://gstaticontent.com/images/6IK84A1Pg5RRE3Bh28eG3gy2bB0_big.jpg'),
(46733, 3207, 'A Culpa é do Cabral S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250797.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46734, 3207, 'A Culpa é do Cabral S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250798.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46735, 3207, 'A Culpa é do Cabral S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250799.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46736, 3207, 'A Culpa é do Cabral S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250800.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46737, 3207, 'A Culpa é do Cabral S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250801.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46738, 3207, 'A Culpa é do Cabral S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250802.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46739, 3207, 'A Culpa é do Cabral S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250803.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46740, 3207, 'A Culpa é do Cabral S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250804.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46741, 3207, 'A Culpa é do Cabral S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250805.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46742, 3207, 'A Culpa é do Cabral S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250806.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46743, 3207, 'A Culpa é do Cabral S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250807.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46744, 3207, 'A Culpa é do Cabral S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250808.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46745, 3208, 'A Culpa é do Cabral S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250809.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46746, 3208, 'A Culpa é do Cabral S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250810.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46747, 3208, 'A Culpa é do Cabral S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250811.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46748, 3208, 'A Culpa é do Cabral S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250812.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46749, 3208, 'A Culpa é do Cabral S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250813.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46750, 3208, 'A Culpa é do Cabral S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250814.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46751, 3208, 'A Culpa é do Cabral S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250815.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46752, 3208, 'A Culpa é do Cabral S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250816.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46753, 3208, 'A Culpa é do Cabral S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250817.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46754, 3208, 'A Culpa é do Cabral S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250818.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46755, 3208, 'A Culpa é do Cabral S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250819.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46756, 3208, 'A Culpa é do Cabral S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250820.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46757, 3208, 'A Culpa é do Cabral S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250821.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46758, 3208, 'A Culpa é do Cabral S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250822.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46759, 3208, 'A Culpa é do Cabral S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250823.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46760, 3209, 'A Culpa é do Cabral S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250824.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46761, 3209, 'A Culpa é do Cabral S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250825.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46762, 3209, 'A Culpa é do Cabral S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250826.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46763, 3209, 'A Culpa é do Cabral S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250827.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46764, 3209, 'A Culpa é do Cabral S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250828.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46765, 3209, 'A Culpa é do Cabral S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250829.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46766, 3209, 'A Culpa é do Cabral S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250830.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46767, 3209, 'A Culpa é do Cabral S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250831.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46768, 3209, 'A Culpa é do Cabral S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250832.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46769, 3209, 'A Culpa é do Cabral S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250833.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46770, 3209, 'A Culpa é do Cabral S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250834.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46771, 3209, 'A Culpa é do Cabral S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250835.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46772, 3209, 'A Culpa é do Cabral S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250836.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46773, 3210, 'A Culpa é do Cabral S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250837.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46774, 3210, 'A Culpa é do Cabral S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250838.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46775, 3210, 'A Culpa é do Cabral S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250839.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46776, 3210, 'A Culpa é do Cabral S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250840.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46777, 3210, 'A Culpa é do Cabral S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250841.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46778, 3210, 'A Culpa é do Cabral S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250842.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46779, 3210, 'A Culpa é do Cabral S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250843.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46780, 3210, 'A Culpa é do Cabral S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250844.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46781, 3210, 'A Culpa é do Cabral S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250845.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46782, 3210, 'A Culpa é do Cabral S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250846.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46783, 3210, 'A Culpa é do Cabral S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250847.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46784, 3210, 'A Culpa é do Cabral S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250848.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46785, 3210, 'A Culpa é do Cabral S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250849.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46786, 3211, 'A Culpa é do Cabral S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250850.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46787, 3211, 'A Culpa é do Cabral S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250851.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46788, 3211, 'A Culpa é do Cabral S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250852.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46789, 3211, 'A Culpa é do Cabral S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250853.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46790, 3211, 'A Culpa é do Cabral S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250854.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46791, 3211, 'A Culpa é do Cabral S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250855.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46792, 3211, 'A Culpa é do Cabral S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250856.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46793, 3211, 'A Culpa é do Cabral S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250857.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46794, 3211, 'A Culpa é do Cabral S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250858.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46795, 3211, 'A Culpa é do Cabral S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250859.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46796, 3211, 'A Culpa é do Cabral S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250860.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46797, 3211, 'A Culpa é do Cabral S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250861.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46798, 3211, 'A Culpa é do Cabral S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250862.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46799, 3212, 'A Culpa é do Cabral S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250863.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46800, 3212, 'A Culpa é do Cabral S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250864.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46801, 3212, 'A Culpa é do Cabral S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250865.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46802, 3212, 'A Culpa é do Cabral S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250866.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46803, 3212, 'A Culpa é do Cabral S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250867.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46804, 3212, 'A Culpa é do Cabral S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250868.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46805, 3212, 'A Culpa é do Cabral S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250869.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46806, 3212, 'A Culpa é do Cabral S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250870.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46807, 3212, 'A Culpa é do Cabral S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250871.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46808, 3212, 'A Culpa é do Cabral S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250872.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46809, 3212, 'A Culpa é do Cabral S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250873.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46810, 3212, 'A Culpa é do Cabral S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250874.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46811, 3212, 'A Culpa é do Cabral S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250875.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46812, 3213, 'A Culpa é do Cabral S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250876.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46813, 3213, 'A Culpa é do Cabral S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250877.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46814, 3213, 'A Culpa é do Cabral S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250878.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46815, 3213, 'A Culpa é do Cabral S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250879.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46816, 3213, 'A Culpa é do Cabral S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250880.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46817, 3213, 'A Culpa é do Cabral S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250881.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46818, 3213, 'A Culpa é do Cabral S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250882.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46819, 3213, 'A Culpa é do Cabral S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250883.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46820, 3213, 'A Culpa é do Cabral S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250884.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46821, 3213, 'A Culpa é do Cabral S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250885.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46822, 3213, 'A Culpa é do Cabral S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250886.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(46823, 3213, 'A Culpa é do Cabral S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250887.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46824, 3213, 'A Culpa é do Cabral S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250888.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46825, 3214, 'A Culpa é do Cabral S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250889.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46826, 3214, 'A Culpa é do Cabral S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250890.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46827, 3214, 'A Culpa é do Cabral S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250891.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46828, 3214, 'A Culpa é do Cabral S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250892.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46829, 3214, 'A Culpa é do Cabral S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250893.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46830, 3214, 'A Culpa é do Cabral S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250894.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46831, 3214, 'A Culpa é do Cabral S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250895.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46832, 3214, 'A Culpa é do Cabral S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250896.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46833, 3214, 'A Culpa é do Cabral S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250897.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46834, 3214, 'A Culpa é do Cabral S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250898.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46835, 3214, 'A Culpa é do Cabral S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250899.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46836, 3214, 'A Culpa é do Cabral S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250900.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46837, 3214, 'A Culpa é do Cabral S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250901.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46838, 3215, 'A Culpa é do Cabral S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250902.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46839, 3215, 'A Culpa é do Cabral S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250903.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46840, 3215, 'A Culpa é do Cabral S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250904.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46841, 3215, 'A Culpa é do Cabral S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250905.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46842, 3215, 'A Culpa é do Cabral S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250906.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46843, 3215, 'A Culpa é do Cabral S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250907.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46844, 3215, 'A Culpa é do Cabral S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250908.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46845, 3215, 'A Culpa é do Cabral S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250909.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46846, 3215, 'A Culpa é do Cabral S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250910.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46847, 3215, 'A Culpa é do Cabral S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250911.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46848, 3215, 'A Culpa é do Cabral S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250912.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46849, 3215, 'A Culpa é do Cabral S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250913.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46850, 3216, 'A Culpa é do Cabral S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250914.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46851, 3216, 'A Culpa é do Cabral S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250915.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46852, 3216, 'A Culpa é do Cabral S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250916.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46853, 3216, 'A Culpa é do Cabral S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250917.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46854, 3216, 'A Culpa é do Cabral S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250918.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46855, 3216, 'A Culpa é do Cabral S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250919.mp4', 'http://image.tmdb.org/t/p/w1280/uCpLiKmv1eh7Fom2ND1aVzW1XmQ.jpg'),
(46856, 3216, 'A Culpa é do Cabral S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250920.mp4', 'http://image.tmdb.org/t/p/w1280/ci9PnrjJT26sgdoFRQ7QSX5cefJ.jpg'),
(46857, 3216, 'A Culpa é do Cabral S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250921.mp4', 'http://image.tmdb.org/t/p/w1280/fhkoT0L8goZ2tAEgnPb80Yt3qlX.jpg'),
(46858, 3216, 'A Culpa é do Cabral S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250922.mp4', 'http://image.tmdb.org/t/p/w1280/aN4MNZVvq1tH2YUXaVLCkxiF7Gm.jpg'),
(46859, 3216, 'A Culpa é do Cabral S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250923.mp4', 'http://timg.bdta.pro/images/260beb0cddc34b438872f02d5641b23f.jpg'),
(46860, 3216, 'A Culpa é do Cabral S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250924.mp4', 'http://timg.bdta.pro/images/43dca6e40da9904acb7a379638623d47.jpg'),
(46861, 3217, 'A Culpa é do Cabral S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250925.mp4', 'http://timg.bdta.pro/images/c5404fe6195b181615289fc5f9f8ef1a.jpg'),
(46862, 3217, 'A Culpa é do Cabral S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250926.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46863, 3217, 'A Culpa é do Cabral S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250927.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46864, 3217, 'A Culpa é do Cabral S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250928.mp4', 'http://timg.bdta.pro/images/4fa79c5c346b1793b3783e620e29fa15.jpg'),
(46865, 3217, 'A Culpa é do Cabral S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250929.mp4', 'http://timg.bdta.pro/images/917c6a6a743f11ba4c3dda65d7fb2ff9.jpg'),
(46866, 3217, 'A Culpa é do Cabral S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250930.mp4', 'http://timg.bdta.pro/images/f91aa4f99c64dcc8ed6c5ae47015c448.jpg'),
(46867, 3217, 'A Culpa é do Cabral S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250931.mp4', 'http://timg.bdta.pro/images/2b8be3f99222030dd343474257abc5c9.jpg'),
(46868, 3217, 'A Culpa é do Cabral S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250932.mp4', 'http://timg.bdta.pro/images/afc4e26287e376c893f30e10269d706e.jpg'),
(46869, 3217, 'A Culpa é do Cabral S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250933.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46870, 3217, 'A Culpa é do Cabral S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250934.mp4', 'http://timg.bdta.pro/images/e4a2d008885edad85a4c82d29b996cb5.jpg'),
(46871, 3217, 'A Culpa é do Cabral S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250935.mp4', 'http://timg.bdta.pro/images/6a9bab33556af53ee4c8e50cdfd3ad89.jpg'),
(46872, 3217, 'A Culpa é do Cabral S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250936.mp4', 'http://timg.bdta.pro/images/5a1afa2d94f5cc3b05af2cbbf55cf153.jpg'),
(46873, 3218, 'A Culpa é do Cabral S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250937.mp4', 'http://timg.bdta.pro/images/e3200f2cac62a27ea6f140b53d132b30.jpg'),
(46874, 3218, 'A Culpa é do Cabral S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250938.mp4', 'http://timg.bdta.pro/images/c797ed82a13d831549aaf21dd2c1206e.jpg'),
(46875, 3218, 'A Culpa é do Cabral S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250939.mp4', 'http://timg.bdta.pro/images/15204e8b0cf43618fe6e8ac7860420ba.jpg'),
(46876, 3218, 'A Culpa é do Cabral S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nOYKVv1HJ0L1VRr5JsOBp1tdqBC.jpg'),
(46877, 3218, 'A Culpa é do Cabral S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8W4GlES7HZ26oeWyzOln0OrVRmt.jpg'),
(46878, 3218, 'A Culpa é do Cabral S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250942.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46879, 3218, 'A Culpa é do Cabral S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sVsm2gKe0V8KXxTePO9jMfQ8yTF.jpg'),
(46880, 3218, 'A Culpa é do Cabral S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kUiv2qcaYuME042MEpNTCRWTSRP.jpg'),
(46881, 3218, 'A Culpa é do Cabral S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lQEuul4ErDoc7VzIpMeAYRRVS5H.jpg'),
(46882, 3218, 'A Culpa é do Cabral S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250946.mp4', 'http://image.tmdb.org/t/p/w1280/7ar8s4ZI0Z6ELTV5TNgrEigA7S.jpg'),
(46883, 3218, 'A Culpa é do Cabral S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250947.mp4', 'http://image.tmdb.org/t/p/w1280/iNfTVvUwYhDuaHmvnsiGWOGeaVw.jpg'),
(46884, 3218, 'A Culpa é do Cabral S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250948.mp4', 'http://image.tmdb.org/t/p/w1280/1NqxdcdkVKZpDDI9nSAR88dSFG1.jpg'),
(46885, 3219, 'A Culpa é do Cabral S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250949.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46886, 3219, 'A Culpa é do Cabral S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250950.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46887, 3219, 'A Culpa é do Cabral S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250951.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46888, 3219, 'A Culpa é do Cabral S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250952.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46889, 3219, 'A Culpa é do Cabral S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250953.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46890, 3219, 'A Culpa é do Cabral S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250954.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46891, 3219, 'A Culpa é do Cabral S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250955.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46892, 3219, 'A Culpa é do Cabral S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250956.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46893, 3219, 'A Culpa é do Cabral S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250957.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46894, 3219, 'A Culpa é do Cabral S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250958.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46895, 3219, 'A Culpa é do Cabral S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250959.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46896, 3219, 'A Culpa é do Cabral S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250960.mp4', 'http://gstaticontent.com/images/P9SsAeEvzAnBdK0aJb5aJtrFiS_big.jpg'),
(46897, 3220, 'Grown-ish S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234263.mp4', 'http://gstaticontent.com/images/7oRtOzhFxaBqCMxaTvd5N4FD5VZ_big.jpg'),
(46898, 3220, 'Grown-ish S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234264.mp4', 'http://gstaticontent.com/images/7oRtOzhFxaBqCMxaTvd5N4FD5VZ_big.jpg'),
(46899, 3220, 'Grown-ish S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234265.mp4', 'http://gstaticontent.com/images/7oRtOzhFxaBqCMxaTvd5N4FD5VZ_big.jpg'),
(46900, 3220, 'Grown-ish S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234266.mp4', 'http://gstaticontent.com/images/7oRtOzhFxaBqCMxaTvd5N4FD5VZ_big.jpg'),
(46901, 3220, 'Grown-ish S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234267.mp4', 'http://gstaticontent.com/images/7oRtOzhFxaBqCMxaTvd5N4FD5VZ_big.jpg'),
(46902, 3220, 'Grown-ish S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234268.mp4', 'http://gstaticontent.com/images/7oRtOzhFxaBqCMxaTvd5N4FD5VZ_big.jpg'),
(46903, 3220, 'Grown-ish S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234269.mp4', 'http://gstaticontent.com/images/7oRtOzhFxaBqCMxaTvd5N4FD5VZ_big.jpg'),
(46904, 3220, 'Grown-ish S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234270.mp4', 'http://gstaticontent.com/images/7oRtOzhFxaBqCMxaTvd5N4FD5VZ_big.jpg'),
(46905, 3220, 'Grown-ish S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234271.mp4', 'http://gstaticontent.com/images/7oRtOzhFxaBqCMxaTvd5N4FD5VZ_big.jpg'),
(46906, 3220, 'Grown-ish S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234272.mp4', 'http://gstaticontent.com/images/7oRtOzhFxaBqCMxaTvd5N4FD5VZ_big.jpg'),
(46907, 3220, 'Grown-ish S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234273.mp4', 'http://gstaticontent.com/images/7oRtOzhFxaBqCMxaTvd5N4FD5VZ_big.jpg'),
(46908, 3220, 'Grown-ish S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234274.mp4', 'http://gstaticontent.com/images/7oRtOzhFxaBqCMxaTvd5N4FD5VZ_big.jpg'),
(46909, 3220, 'Grown-ish S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234275.mp4', 'http://gstaticontent.com/images/7oRtOzhFxaBqCMxaTvd5N4FD5VZ_big.jpg'),
(46910, 3221, 'Grown-ish S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1D9t9mt2agyLvtEb8vuM1By4L36.jpg'),
(46911, 3221, 'Grown-ish S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7R7nFWUBMQwM5qVHXzliOoPwC0k.jpg'),
(46912, 3221, 'Grown-ish S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3miZPZo3tov6zfgL9tJzcy3q4JZ.jpg'),
(46913, 3221, 'Grown-ish S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1zOLRbhbOJuNm2lJQNGwT5Ypzg9.jpg'),
(46914, 3221, 'Grown-ish S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3NleZSBTMehkp1xBaMKioepQrqi.jpg'),
(46915, 3221, 'Grown-ish S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2dMlO2gmhKTU0igkzvkCg8hIgTa.jpg'),
(46916, 3221, 'Grown-ish S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sIGb23LfwwToF0MdFlvcjbldt4T.jpg'),
(46917, 3221, 'Grown-ish S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j1LdxnJtrmHAdNAAghFRVdRnaQZ.jpg'),
(46918, 3221, 'Grown-ish S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mzdvCZNyospiNHeVMZHLLhSm0S8.jpg'),
(46919, 3221, 'Grown-ish S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iIPpFgw9VuLr23cTq0NPgHmo6xp.jpg'),
(46920, 3221, 'Grown-ish S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/62pkV9qSmztsmzm9deFwJoCNCp2.jpg'),
(46921, 3221, 'Grown-ish S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A01Son4KsEQhfKrMDCgTsaQsVrZ.jpg'),
(46922, 3221, 'Grown-ish S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wB3SfXM5Koz7BaUdfdL2YuiF7A8.jpg'),
(46923, 3221, 'Grown-ish S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1fuDbITd82OI2k1lDFPU6cboAl.jpg'),
(46924, 3221, 'Grown-ish S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yc5egPv2LUcup6JIF58BMbAlgPM.jpg'),
(46925, 3221, 'Grown-ish S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ag723io6hF0KcmbzkF31k3vsZBD.jpg'),
(46926, 3221, 'Grown-ish S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wpsgVuN8FNSO6XSGBHHuUBlhIhG.jpg'),
(46927, 3221, 'Grown-ish S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/234293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lBxXI6jeU5BQ3VEQt4u5ww3puP9.jpg'),
(46928, 3221, 'Grown-ish S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/234294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ieItUjTwXYgtxtdwNW7jQFeyEFK.jpg'),
(46929, 3221, 'Grown-ish S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/234295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gkcZ46GKk9RgEATNpKQn33RHLnk.jpg'),
(46930, 3221, 'Grown-ish S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/234296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zUcby2QSUSAM2FfYV8fgLT7lQlD.jpg'),
(46931, 3222, 'Grown-ish S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXE19LnVq1ria9RnuFAo5mVY4C5.jpg'),
(46932, 3222, 'Grown-ish S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Ohkke7nKR67zi0uDBfOLvzgDTn.jpg'),
(46933, 3222, 'Grown-ish S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ummY63wRigTgLbq53RG8mPNsxfv.jpg'),
(46934, 3222, 'Grown-ish S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a01vK2iclReWuKTxsLVC7YhttKy.jpg'),
(46935, 3222, 'Grown-ish S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w7YoIqQQTM3XagYKrjIomP9K7tZ.jpg'),
(46936, 3222, 'Grown-ish S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y0CcDZx2QT1eTiJfDEcMaMXDCoM.jpg'),
(46937, 3222, 'Grown-ish S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/38Izj7mhelNVe5YtsanMWtKdI8V.jpg'),
(46938, 3222, 'Grown-ish S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDdQu9zxZjRLxpIC4gVGkpSXW1V.jpg'),
(46939, 3222, 'Grown-ish S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v2dUzxlF3dQQng0sECDGUroQwon.jpg'),
(46940, 3222, 'Grown-ish S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tnnWKY5NcxUX15JKRat4y2wiqon.jpg'),
(46941, 3222, 'Grown-ish S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rRKnvVg0GYlYjowJmpRP7xHXqAG.jpg'),
(46942, 3222, 'Grown-ish S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9nv6FsqxUC9DcSwKwLnr7UxQRm9.jpg'),
(46943, 3222, 'Grown-ish S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lb7XwdSKvJwp6aNDb2FjZAbgQNn.jpg'),
(46944, 3222, 'Grown-ish S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7n6pkHiHxbG547aLyQdBewG7oKz.jpg'),
(46945, 3222, 'Grown-ish S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zIKuornCqygfacYkWBwVHTHx83W.jpg'),
(46946, 3222, 'Grown-ish S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fU7SqJI2t19PQ2CzmJKBqSr2sGF.jpg'),
(46947, 3222, 'Grown-ish S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jT8o9GgSgjRKhvNbQmHmqZ0GiMe.jpg'),
(46948, 3223, 'Grown-ish S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7G6QY8g4kAXXCU7PeFPCNz1NFWG.jpg'),
(46949, 3223, 'Grown-ish S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1OeQaqONj6riwABbdXrIEMu4BQg.jpg'),
(46950, 3223, 'Grown-ish S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFg4p0uFm0xb6QEHaMP6prI6irg.jpg'),
(46951, 3223, 'Grown-ish S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/DZkf0S5eNmTNmVBUwugHP4Hi6M.jpg'),
(46952, 3223, 'Grown-ish S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hwEysoXn9S3jZMlTeH82mnnOZ9g.jpg'),
(46953, 3223, 'Grown-ish S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mis1JZfGwAuLeMla0sKSxqXnKXM.jpg'),
(46954, 3223, 'Grown-ish S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/GiOHJ1SDldjfcQdJQkmhxw8f8d.jpg'),
(46955, 3223, 'Grown-ish S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/YleKQeMyL3UTssdHMzF10WvsPL.jpg'),
(46956, 3223, 'Grown-ish S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nPofV10LtapSO8Xt2rMmK8nKcBm.jpg'),
(46957, 3223, 'Grown-ish S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lw3Epb8i22Z8F1y1njHnQZAHHIK.jpg'),
(46958, 3223, 'Grown-ish S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cIxrywSLlILDKBPNQFeZ5ztWRJ7.jpg'),
(46959, 3223, 'Grown-ish S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zrmHLvElyVqFcICdeawulfxi5pa.jpg'),
(46960, 3223, 'Grown-ish S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w1Ytj612DomJZl9tuikW5unqv4m.jpg'),
(46961, 3223, 'Grown-ish S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zttVf5WZEPmk6tjJemweD5OyCDw.jpg'),
(46962, 3223, 'Grown-ish S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/12DJxH54XVaJCsqNmPmEFGmkvZ9.jpg'),
(46963, 3223, 'Grown-ish S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wRIhTcgWidv4j6jTL2lSsd8URfy.jpg'),
(46964, 3223, 'Grown-ish S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Kg5o81FyP5CetP0lGmIBKZsr4J.jpg'),
(46965, 3223, 'Grown-ish S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/234331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7IRVWMO21jkZVDFjvR8DU1sO0vE.jpg'),
(46966, 3224, 'Lab Rats S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141330.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46967, 3224, 'Lab Rats S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141331.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46968, 3224, 'Lab Rats S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141332.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46969, 3224, 'Lab Rats S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141333.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46970, 3224, 'Lab Rats S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141334.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46971, 3224, 'Lab Rats S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141335.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46972, 3224, 'Lab Rats S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141336.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46973, 3224, 'Lab Rats S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141337.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46974, 3224, 'Lab Rats S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141338.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46975, 3224, 'Lab Rats S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141339.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46976, 3224, 'Lab Rats S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141340.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46977, 3224, 'Lab Rats S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141341.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46978, 3224, 'Lab Rats S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141342.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46979, 3224, 'Lab Rats S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141343.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46980, 3224, 'Lab Rats S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141344.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46981, 3224, 'Lab Rats S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141345.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46982, 3224, 'Lab Rats S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141346.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46983, 3224, 'Lab Rats S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141347.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46984, 3224, 'Lab Rats S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141348.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46985, 3224, 'Lab Rats S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141349.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46986, 3225, 'Lab Rats S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141350.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46987, 3225, 'Lab Rats S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141351.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46988, 3225, 'Lab Rats S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141352.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46989, 3225, 'Lab Rats S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141353.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46990, 3225, 'Lab Rats S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141354.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46991, 3225, 'Lab Rats S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141355.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46992, 3225, 'Lab Rats S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141356.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46993, 3225, 'Lab Rats S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141357.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46994, 3225, 'Lab Rats S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141358.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46995, 3225, 'Lab Rats S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141359.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46996, 3225, 'Lab Rats S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141360.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46997, 3225, 'Lab Rats S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141361.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46998, 3225, 'Lab Rats S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141362.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(46999, 3225, 'Lab Rats S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141363.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47000, 3225, 'Lab Rats S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141364.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47001, 3225, 'Lab Rats S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141365.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47002, 3225, 'Lab Rats S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141366.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47003, 3225, 'Lab Rats S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141367.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47004, 3225, 'Lab Rats S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141368.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47005, 3225, 'Lab Rats S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141369.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47006, 3225, 'Lab Rats S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/141370.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47007, 3225, 'Lab Rats S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/141371.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47008, 3225, 'Lab Rats S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/141372.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47009, 3225, 'Lab Rats S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/141373.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47010, 3225, 'Lab Rats S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/141374.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47011, 3225, 'Lab Rats S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/141375.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47012, 3226, 'Lab Rats S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141376.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47013, 3226, 'Lab Rats S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141377.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47014, 3226, 'Lab Rats S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141378.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47015, 3226, 'Lab Rats S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141379.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47016, 3226, 'Lab Rats S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141380.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47017, 3226, 'Lab Rats S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141381.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47018, 3226, 'Lab Rats S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141382.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47019, 3226, 'Lab Rats S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141383.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47020, 3226, 'Lab Rats S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141384.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47021, 3226, 'Lab Rats S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141385.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47022, 3226, 'Lab Rats S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141386.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47023, 3226, 'Lab Rats S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141387.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47024, 3226, 'Lab Rats S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141388.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47025, 3226, 'Lab Rats S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141389.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47026, 3226, 'Lab Rats S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141390.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47027, 3226, 'Lab Rats S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141391.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47028, 3226, 'Lab Rats S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141392.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47029, 3226, 'Lab Rats S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141393.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47030, 3226, 'Lab Rats S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141394.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47031, 3226, 'Lab Rats S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141395.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47032, 3226, 'Lab Rats S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/141396.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47033, 3226, 'Lab Rats S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/141397.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47034, 3226, 'Lab Rats S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/141398.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47035, 3226, 'Lab Rats S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/141399.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47036, 3226, 'Lab Rats S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/141400.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47037, 3226, 'Lab Rats S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/141401.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47038, 3227, 'Lab Rats S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141402.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47039, 3227, 'Lab Rats S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141403.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47040, 3227, 'Lab Rats S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141404.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47041, 3227, 'Lab Rats S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141405.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47042, 3227, 'Lab Rats S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141406.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47043, 3227, 'Lab Rats S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141407.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47044, 3227, 'Lab Rats S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141408.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47045, 3227, 'Lab Rats S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141409.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47046, 3227, 'Lab Rats S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141410.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47047, 3227, 'Lab Rats S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141411.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47048, 3227, 'Lab Rats S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141412.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47049, 3227, 'Lab Rats S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141413.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47050, 3227, 'Lab Rats S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141414.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47051, 3227, 'Lab Rats S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141415.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47052, 3227, 'Lab Rats S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141416.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47053, 3227, 'Lab Rats S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141417.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47054, 3227, 'Lab Rats S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141418.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47055, 3227, 'Lab Rats S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141419.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47056, 3227, 'Lab Rats S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141420.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47057, 3227, 'Lab Rats S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141421.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47058, 3227, 'Lab Rats S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/141422.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47059, 3227, 'Lab Rats S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/141423.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47060, 3227, 'Lab Rats S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/141424.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47061, 3227, 'Lab Rats S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/141425.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47062, 3227, 'Lab Rats S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/141426.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47063, 3227, 'Lab Rats S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/141427.mp4', 'http://gstaticontent.com/images/y0PWY1pKwyOJeru8u4wiqTRoPrb_big.jpg'),
(47064, 3228, 'O Traficante S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141428.mp4', 'http://gstaticontent.com/images/dQstisZnYgpZc8FhpnpxH3Xs1KZ_big.jpg'),
(47065, 3228, 'O Traficante S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141429.mp4', 'http://gstaticontent.com/images/dQstisZnYgpZc8FhpnpxH3Xs1KZ_big.jpg'),
(47066, 3228, 'O Traficante S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141430.mp4', 'http://gstaticontent.com/images/dQstisZnYgpZc8FhpnpxH3Xs1KZ_big.jpg'),
(47067, 3228, 'O Traficante S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141431.mp4', 'http://gstaticontent.com/images/dQstisZnYgpZc8FhpnpxH3Xs1KZ_big.jpg'),
(47068, 3228, 'O Traficante S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141432.mp4', 'http://gstaticontent.com/images/dQstisZnYgpZc8FhpnpxH3Xs1KZ_big.jpg'),
(47069, 3228, 'O Traficante S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141433.mp4', 'http://gstaticontent.com/images/dQstisZnYgpZc8FhpnpxH3Xs1KZ_big.jpg'),
(47070, 3228, 'O Traficante S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141434.mp4', 'http://gstaticontent.com/images/dQstisZnYgpZc8FhpnpxH3Xs1KZ_big.jpg'),
(47071, 3228, 'O Traficante S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141435.mp4', 'http://gstaticontent.com/images/dQstisZnYgpZc8FhpnpxH3Xs1KZ_big.jpg'),
(47072, 3228, 'O Traficante S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141436.mp4', 'http://gstaticontent.com/images/dQstisZnYgpZc8FhpnpxH3Xs1KZ_big.jpg'),
(47073, 3228, 'O Traficante S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141437.mp4', 'http://gstaticontent.com/images/dQstisZnYgpZc8FhpnpxH3Xs1KZ_big.jpg'),
(47074, 3229, 'Operação Berlim S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141438.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47075, 3229, 'Operação Berlim S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141439.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47076, 3229, 'Operação Berlim S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141440.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47077, 3229, 'Operação Berlim S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141441.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47078, 3229, 'Operação Berlim S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141442.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47079, 3229, 'Operação Berlim S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141443.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47080, 3229, 'Operação Berlim S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141444.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47081, 3229, 'Operação Berlim S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141445.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47082, 3229, 'Operação Berlim S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141446.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47083, 3229, 'Operação Berlim S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141447.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47084, 3230, 'Operação Berlim S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141448.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47085, 3230, 'Operação Berlim S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141449.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47086, 3230, 'Operação Berlim S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141450.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47087, 3230, 'Operação Berlim S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141451.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47088, 3230, 'Operação Berlim S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141452.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47089, 3230, 'Operação Berlim S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141453.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47090, 3230, 'Operação Berlim S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141454.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47091, 3230, 'Operação Berlim S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141455.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47092, 3230, 'Operação Berlim S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141456.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47093, 3231, 'Operação Berlim S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141457.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47094, 3231, 'Operação Berlim S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141458.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47095, 3231, 'Operação Berlim S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141459.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47096, 3231, 'Operação Berlim S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141460.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47097, 3231, 'Operação Berlim S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141461.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47098, 3231, 'Operação Berlim S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141462.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47099, 3231, 'Operação Berlim S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141463.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47100, 3231, 'Operação Berlim S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141464.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47101, 3231, 'Operação Berlim S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141465.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47102, 3231, 'Operação Berlim S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141466.mp4', 'http://gstaticontent.com/images/zn26BiTyU3LjQVB36ZQWtVBWseD_big.jpg'),
(47103, 3232, 'Snowfall S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233401.mp4', 'http://gstaticontent.com/images/xeSNi6T65ODCUDWOLnI1OJ6RPDp_big.jpg'),
(47104, 3232, 'Snowfall S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233402.mp4', 'http://gstaticontent.com/images/xeSNi6T65ODCUDWOLnI1OJ6RPDp_big.jpg'),
(47105, 3232, 'Snowfall S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233403.mp4', 'http://gstaticontent.com/images/xeSNi6T65ODCUDWOLnI1OJ6RPDp_big.jpg'),
(47106, 3232, 'Snowfall S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233404.mp4', 'http://gstaticontent.com/images/xeSNi6T65ODCUDWOLnI1OJ6RPDp_big.jpg'),
(47107, 3232, 'Snowfall S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233405.mp4', 'http://gstaticontent.com/images/xeSNi6T65ODCUDWOLnI1OJ6RPDp_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(47108, 3232, 'Snowfall S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233406.mp4', 'http://gstaticontent.com/images/xeSNi6T65ODCUDWOLnI1OJ6RPDp_big.jpg'),
(47109, 3232, 'Snowfall S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233407.mp4', 'http://gstaticontent.com/images/xeSNi6T65ODCUDWOLnI1OJ6RPDp_big.jpg'),
(47110, 3232, 'Snowfall S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233408.mp4', 'http://gstaticontent.com/images/xeSNi6T65ODCUDWOLnI1OJ6RPDp_big.jpg'),
(47111, 3232, 'Snowfall S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233409.mp4', 'http://gstaticontent.com/images/xeSNi6T65ODCUDWOLnI1OJ6RPDp_big.jpg'),
(47112, 3232, 'Snowfall S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233410.mp4', 'http://gstaticontent.com/images/xeSNi6T65ODCUDWOLnI1OJ6RPDp_big.jpg'),
(47113, 3233, 'Snowfall S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233411.mp4', 'http://gstaticontent.com/images/xeSNi6T65ODCUDWOLnI1OJ6RPDp_big.jpg'),
(47114, 3233, 'Snowfall S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233412.mp4', 'http://gstaticontent.com/images/xeSNi6T65ODCUDWOLnI1OJ6RPDp_big.jpg'),
(47115, 3233, 'Snowfall S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233413.mp4', 'http://gstaticontent.com/images/xeSNi6T65ODCUDWOLnI1OJ6RPDp_big.jpg'),
(47116, 3233, 'Snowfall S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233414.mp4', 'http://gstaticontent.com/images/xeSNi6T65ODCUDWOLnI1OJ6RPDp_big.jpg'),
(47117, 3233, 'Snowfall S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233415.mp4', 'http://gstaticontent.com/images/xeSNi6T65ODCUDWOLnI1OJ6RPDp_big.jpg'),
(47118, 3233, 'Snowfall S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233416.mp4', 'http://gstaticontent.com/images/xeSNi6T65ODCUDWOLnI1OJ6RPDp_big.jpg'),
(47119, 3233, 'Snowfall S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233417.mp4', 'http://gstaticontent.com/images/xeSNi6T65ODCUDWOLnI1OJ6RPDp_big.jpg'),
(47120, 3233, 'Snowfall S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233418.mp4', 'http://gstaticontent.com/images/xeSNi6T65ODCUDWOLnI1OJ6RPDp_big.jpg'),
(47121, 3233, 'Snowfall S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233419.mp4', 'http://gstaticontent.com/images/xeSNi6T65ODCUDWOLnI1OJ6RPDp_big.jpg'),
(47122, 3233, 'Snowfall S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233420.mp4', 'http://gstaticontent.com/images/xeSNi6T65ODCUDWOLnI1OJ6RPDp_big.jpg'),
(47123, 3234, 'Snowfall S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ounhCFdsfeoWqQUadpYObdsRY13.jpg'),
(47124, 3234, 'Snowfall S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l9kUQCoWqPjwtD6oMjnPLAYOIMT.jpg'),
(47125, 3234, 'Snowfall S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vIgpglf7YrrDMTab4pV2S0omMYB.jpg'),
(47126, 3234, 'Snowfall S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tQCQCCjsyq78p0t5hQB3x3CSONl.jpg'),
(47127, 3234, 'Snowfall S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sewArskbNchXWW70JnEMyOpblPd.jpg'),
(47128, 3234, 'Snowfall S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uTIZIZ2zS4cM5EcLZYb9Bzglt3o.jpg'),
(47129, 3234, 'Snowfall S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ztg6blWtFEhZYs4gfQmOdzWzMlG.jpg'),
(47130, 3234, 'Snowfall S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aefg9NFM36kT627C3DFiPoXUmqV.jpg'),
(47131, 3234, 'Snowfall S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8nECHvYK5D6c19yLsWzuMKM6AzD.jpg'),
(47132, 3234, 'Snowfall S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bH0LyJ7ZaQrRcCvKdmy967cguNK.jpg'),
(47133, 3235, 'Snowfall S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eeNkpPPnATjNZoinvGNTLp6T9ie.jpg'),
(47134, 3235, 'Snowfall S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iPGUtTNZdar8qvYob2ziARYpj1t.jpg'),
(47135, 3235, 'Snowfall S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gUkvuz6eiHreHAoa5l4kPpKCPqZ.jpg'),
(47136, 3235, 'Snowfall S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uAN6XzZIjUqjbV4Xa0o066VVFhe.jpg'),
(47137, 3235, 'Snowfall S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7jOdBMdvLvbaiyrqNnbwYEoFUS1.jpg'),
(47138, 3235, 'Snowfall S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8SEcvgPo9nfVzjzqxVnmQ2QO7M1.jpg'),
(47139, 3235, 'Snowfall S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/saUG6QhPUSyqB45Ytwlp6qrQKtE.jpg'),
(47140, 3235, 'Snowfall S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sgwveLgj1klYENdIjF8hA7pPfHh.jpg'),
(47141, 3235, 'Snowfall S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4HhGxqONltNBxZE83g8ymuIPmvk.jpg'),
(47142, 3235, 'Snowfall S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9uspLZxFnawKXeSOiBvobHjNn7l.jpg'),
(47143, 3236, 'Snowfall S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nMgvfhxAGVFmBBzJNhFObUydfMu.jpg'),
(47144, 3236, 'Snowfall S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzGuZLLtVf2gcQ19EyWhXtR9UrW.jpg'),
(47145, 3236, 'Snowfall S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pzElid1Z1MwuGj1Sb6PBKvvBdag.jpg'),
(47146, 3236, 'Snowfall S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vm0l37JkpynEyye5CxvEMbY9EGY.jpg'),
(47147, 3236, 'Snowfall S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7qppfpcOEw0UHF0XZ2iXzijhhuI.jpg'),
(47148, 3236, 'Snowfall S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8BPsgV7qCUuRbr2fxSvML5CTk6Q.jpg'),
(47149, 3236, 'Snowfall S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ebGGqT8hERg0brwrVavBQQd1ZAw.jpg'),
(47150, 3236, 'Snowfall S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h2IpVGvoG1l57GQ4QeeOYzZmgmv.jpg'),
(47151, 3236, 'Snowfall S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g9bZjJanrUTMuZCZ83w72tHLfdg.jpg'),
(47152, 3236, 'Snowfall S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ymH4SAtbRMb8KiPrKhX3zF7XZrZ.jpg'),
(47153, 3237, 'Snowfall S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a7ztz5VvVGCD0eLF0wyCEt8t4K0.jpg'),
(47154, 3237, 'Snowfall S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o9vIdrn0uty28cjfMw56Fl0HFiv.jpg'),
(47155, 3237, 'Snowfall S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7sO0fPosqM3QMrXS8oY2OywW4ul.jpg'),
(47156, 3237, 'Snowfall S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1TKE4fiAHihcAVug7lce7pq1UX.jpg'),
(47157, 3237, 'Snowfall S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x4UwYZSg8x4T6Qwr3oci9SfI5MW.jpg'),
(47158, 3237, 'Snowfall S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nRyc5FgDOEm3E6Hag3OdS3TD7rN.jpg'),
(47159, 3237, 'Snowfall S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q01eF3PM8xcg4TfBGh9gb3x9hfy.jpg'),
(47160, 3237, 'Snowfall S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sKuF0T2GviyG5aW2ElbgdPv8wIy.jpg'),
(47161, 3237, 'Snowfall S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aEH9KzIF3W6dbxZWUjd2jswA85c.jpg'),
(47162, 3237, 'Snowfall S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/smzxIxdiPMtVQAzWWhNeeYPrKPd.jpg'),
(47163, 3238, 'The Affair - Infidelidade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141467.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47164, 3238, 'The Affair - Infidelidade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141468.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47165, 3238, 'The Affair - Infidelidade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141469.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47166, 3238, 'The Affair - Infidelidade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141470.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47167, 3238, 'The Affair - Infidelidade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141471.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47168, 3238, 'The Affair - Infidelidade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141472.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47169, 3238, 'The Affair - Infidelidade S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141473.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47170, 3238, 'The Affair - Infidelidade S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141474.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47171, 3238, 'The Affair - Infidelidade S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141475.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47172, 3238, 'The Affair - Infidelidade S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141476.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47173, 3239, 'The Affair - Infidelidade S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141477.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47174, 3239, 'The Affair - Infidelidade S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141478.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47175, 3239, 'The Affair - Infidelidade S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141479.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47176, 3239, 'The Affair - Infidelidade S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141480.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47177, 3239, 'The Affair - Infidelidade S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141481.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47178, 3239, 'The Affair - Infidelidade S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141482.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47179, 3239, 'The Affair - Infidelidade S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141483.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47180, 3239, 'The Affair - Infidelidade S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141484.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47181, 3239, 'The Affair - Infidelidade S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141485.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47182, 3239, 'The Affair - Infidelidade S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141486.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47183, 3239, 'The Affair - Infidelidade S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141487.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47184, 3239, 'The Affair - Infidelidade S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141488.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47185, 3240, 'The Affair - Infidelidade S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141489.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47186, 3240, 'The Affair - Infidelidade S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141490.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47187, 3240, 'The Affair - Infidelidade S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141491.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47188, 3240, 'The Affair - Infidelidade S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141492.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47189, 3240, 'The Affair - Infidelidade S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141493.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47190, 3240, 'The Affair - Infidelidade S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141494.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47191, 3240, 'The Affair - Infidelidade S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141495.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47192, 3240, 'The Affair - Infidelidade S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141496.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47193, 3240, 'The Affair - Infidelidade S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141497.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47194, 3240, 'The Affair - Infidelidade S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141498.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47195, 3241, 'The Affair - Infidelidade S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141499.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47196, 3241, 'The Affair - Infidelidade S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141500.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47197, 3241, 'The Affair - Infidelidade S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141501.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47198, 3241, 'The Affair - Infidelidade S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141502.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47199, 3241, 'The Affair - Infidelidade S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141503.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47200, 3241, 'The Affair - Infidelidade S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141504.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47201, 3241, 'The Affair - Infidelidade S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141505.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47202, 3241, 'The Affair - Infidelidade S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141506.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47203, 3241, 'The Affair - Infidelidade S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141507.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47204, 3241, 'The Affair - Infidelidade S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141508.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47205, 3242, 'The Affair - Infidelidade S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141509.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47206, 3242, 'The Affair - Infidelidade S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141510.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47207, 3242, 'The Affair - Infidelidade S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141511.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47208, 3242, 'The Affair - Infidelidade S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141512.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47209, 3242, 'The Affair - Infidelidade S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141513.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47210, 3242, 'The Affair - Infidelidade S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141514.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47211, 3242, 'The Affair - Infidelidade S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141515.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47212, 3242, 'The Affair - Infidelidade S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141516.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47213, 3242, 'The Affair - Infidelidade S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141517.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47214, 3242, 'The Affair - Infidelidade S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141518.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47215, 3242, 'The Affair - Infidelidade S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141519.mp4', 'http://gstaticontent.com/images/oXnUUKANdmFOcgDq03mtnFSqlIj_big.jpg'),
(47216, 3243, 'The Returned S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141520.mp4', 'http://gstaticontent.com/images/cKp0ZDYGydWxI3v8KS3tY8W9aM7_big.jpg'),
(47217, 3243, 'The Returned S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141521.mp4', 'http://gstaticontent.com/images/cKp0ZDYGydWxI3v8KS3tY8W9aM7_big.jpg'),
(47218, 3243, 'The Returned S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141522.mp4', 'http://gstaticontent.com/images/cKp0ZDYGydWxI3v8KS3tY8W9aM7_big.jpg'),
(47219, 3243, 'The Returned S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141523.mp4', 'http://gstaticontent.com/images/cKp0ZDYGydWxI3v8KS3tY8W9aM7_big.jpg'),
(47220, 3243, 'The Returned S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141524.mp4', 'http://gstaticontent.com/images/cKp0ZDYGydWxI3v8KS3tY8W9aM7_big.jpg'),
(47221, 3243, 'The Returned S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141525.mp4', 'http://gstaticontent.com/images/cKp0ZDYGydWxI3v8KS3tY8W9aM7_big.jpg'),
(47222, 3243, 'The Returned S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141526.mp4', 'http://gstaticontent.com/images/cKp0ZDYGydWxI3v8KS3tY8W9aM7_big.jpg'),
(47223, 3243, 'The Returned S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141527.mp4', 'http://gstaticontent.com/images/cKp0ZDYGydWxI3v8KS3tY8W9aM7_big.jpg'),
(47224, 3243, 'The Returned S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141528.mp4', 'http://gstaticontent.com/images/cKp0ZDYGydWxI3v8KS3tY8W9aM7_big.jpg'),
(47225, 3243, 'The Returned S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141529.mp4', 'http://gstaticontent.com/images/cKp0ZDYGydWxI3v8KS3tY8W9aM7_big.jpg'),
(47226, 3244, 'Two Weeks to Live S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141324.mp4', 'http://gstaticontent.com/images/cOhQYHbHVo03elgWA4mTW5bzNAg_big.jpg'),
(47227, 3244, 'Two Weeks to Live S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141325.mp4', 'http://gstaticontent.com/images/cOhQYHbHVo03elgWA4mTW5bzNAg_big.jpg'),
(47228, 3244, 'Two Weeks to Live S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141326.mp4', 'http://gstaticontent.com/images/cOhQYHbHVo03elgWA4mTW5bzNAg_big.jpg'),
(47229, 3244, 'Two Weeks to Live S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141327.mp4', 'http://gstaticontent.com/images/cOhQYHbHVo03elgWA4mTW5bzNAg_big.jpg'),
(47230, 3244, 'Two Weeks to Live S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141328.mp4', 'http://gstaticontent.com/images/cOhQYHbHVo03elgWA4mTW5bzNAg_big.jpg'),
(47231, 3244, 'Two Weeks to Live S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141329.mp4', 'http://gstaticontent.com/images/cOhQYHbHVo03elgWA4mTW5bzNAg_big.jpg'),
(47232, 3245, 'Last Chance U: Basketball S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140985.mp4', 'http://gstaticontent.com/images/3VwBTaUt8gxk6wfFqX7VmKv00xd_big.jpg'),
(47233, 3245, 'Last Chance U: Basketball S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140986.mp4', 'http://gstaticontent.com/images/3VwBTaUt8gxk6wfFqX7VmKv00xd_big.jpg'),
(47234, 3245, 'Last Chance U: Basketball S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140987.mp4', 'http://gstaticontent.com/images/3VwBTaUt8gxk6wfFqX7VmKv00xd_big.jpg'),
(47235, 3245, 'Last Chance U: Basketball S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140988.mp4', 'http://gstaticontent.com/images/3VwBTaUt8gxk6wfFqX7VmKv00xd_big.jpg'),
(47236, 3245, 'Last Chance U: Basketball S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140989.mp4', 'http://gstaticontent.com/images/3VwBTaUt8gxk6wfFqX7VmKv00xd_big.jpg'),
(47237, 3245, 'Last Chance U: Basketball S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140990.mp4', 'http://gstaticontent.com/images/3VwBTaUt8gxk6wfFqX7VmKv00xd_big.jpg'),
(47238, 3245, 'Last Chance U: Basketball S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140991.mp4', 'http://gstaticontent.com/images/3VwBTaUt8gxk6wfFqX7VmKv00xd_big.jpg'),
(47239, 3245, 'Last Chance U: Basketball S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140992.mp4', 'http://gstaticontent.com/images/3VwBTaUt8gxk6wfFqX7VmKv00xd_big.jpg'),
(47240, 3246, 'Escape at Dannemora S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140993.mp4', 'http://gstaticontent.com/images/odk6ccUtUJlGTzPApKS6s4CTTrK_big.jpg'),
(47241, 3246, 'Escape at Dannemora S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140994.mp4', 'http://gstaticontent.com/images/odk6ccUtUJlGTzPApKS6s4CTTrK_big.jpg'),
(47242, 3246, 'Escape at Dannemora S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140995.mp4', 'http://gstaticontent.com/images/odk6ccUtUJlGTzPApKS6s4CTTrK_big.jpg'),
(47243, 3246, 'Escape at Dannemora S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140996.mp4', 'http://gstaticontent.com/images/odk6ccUtUJlGTzPApKS6s4CTTrK_big.jpg'),
(47244, 3246, 'Escape at Dannemora S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140997.mp4', 'http://gstaticontent.com/images/odk6ccUtUJlGTzPApKS6s4CTTrK_big.jpg'),
(47245, 3246, 'Escape at Dannemora S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140998.mp4', 'http://gstaticontent.com/images/odk6ccUtUJlGTzPApKS6s4CTTrK_big.jpg'),
(47246, 3246, 'Escape at Dannemora S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140999.mp4', 'http://gstaticontent.com/images/odk6ccUtUJlGTzPApKS6s4CTTrK_big.jpg'),
(47247, 3247, 'Trickster: O Agente do Caos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141000.mp4', 'http://gstaticontent.com/images/u6b55SmNZm5cCHWr1yQbLZZa7dK_big.jpg'),
(47248, 3247, 'Trickster: O Agente do Caos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141001.mp4', 'http://gstaticontent.com/images/u6b55SmNZm5cCHWr1yQbLZZa7dK_big.jpg'),
(47249, 3247, 'Trickster: O Agente do Caos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141002.mp4', 'http://gstaticontent.com/images/u6b55SmNZm5cCHWr1yQbLZZa7dK_big.jpg'),
(47250, 3247, 'Trickster: O Agente do Caos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141003.mp4', 'http://gstaticontent.com/images/u6b55SmNZm5cCHWr1yQbLZZa7dK_big.jpg'),
(47251, 3247, 'Trickster: O Agente do Caos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141004.mp4', 'http://gstaticontent.com/images/u6b55SmNZm5cCHWr1yQbLZZa7dK_big.jpg'),
(47252, 3247, 'Trickster: O Agente do Caos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141005.mp4', 'http://gstaticontent.com/images/u6b55SmNZm5cCHWr1yQbLZZa7dK_big.jpg'),
(47253, 3248, 'Batalha Makers Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141006.mp4', 'https://i.bj-share.info/a0bc32eee9aaef586b9f5a1a276ceb9c.jpg'),
(47254, 3248, 'Batalha Makers Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141007.mp4', 'https://i.bj-share.info/a0bc32eee9aaef586b9f5a1a276ceb9c.jpg'),
(47255, 3248, 'Batalha Makers Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141008.mp4', 'https://i.bj-share.info/a0bc32eee9aaef586b9f5a1a276ceb9c.jpg'),
(47256, 3248, 'Batalha Makers Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141009.mp4', 'https://i.bj-share.info/a0bc32eee9aaef586b9f5a1a276ceb9c.jpg'),
(47257, 3248, 'Batalha Makers Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141010.mp4', 'https://i.bj-share.info/a0bc32eee9aaef586b9f5a1a276ceb9c.jpg'),
(47258, 3248, 'Batalha Makers Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141011.mp4', 'https://i.bj-share.info/a0bc32eee9aaef586b9f5a1a276ceb9c.jpg'),
(47259, 3248, 'Batalha Makers Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141012.mp4', 'https://i.bj-share.info/a0bc32eee9aaef586b9f5a1a276ceb9c.jpg'),
(47260, 3248, 'Batalha Makers Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141013.mp4', 'https://i.bj-share.info/a0bc32eee9aaef586b9f5a1a276ceb9c.jpg'),
(47261, 3249, 'Your Honor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212789.mp4', 'http://gstaticontent.com/images/xWJZjIKPeEZhK3JRYKOe06yW6IU_big.jpg'),
(47262, 3249, 'Your Honor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212790.mp4', 'http://gstaticontent.com/images/xWJZjIKPeEZhK3JRYKOe06yW6IU_big.jpg'),
(47263, 3249, 'Your Honor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212791.mp4', 'http://gstaticontent.com/images/xWJZjIKPeEZhK3JRYKOe06yW6IU_big.jpg'),
(47264, 3249, 'Your Honor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212792.mp4', 'http://gstaticontent.com/images/xWJZjIKPeEZhK3JRYKOe06yW6IU_big.jpg'),
(47265, 3249, 'Your Honor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212793.mp4', 'http://gstaticontent.com/images/xWJZjIKPeEZhK3JRYKOe06yW6IU_big.jpg'),
(47266, 3249, 'Your Honor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212794.mp4', 'http://gstaticontent.com/images/xWJZjIKPeEZhK3JRYKOe06yW6IU_big.jpg'),
(47267, 3249, 'Your Honor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212795.mp4', 'http://gstaticontent.com/images/xWJZjIKPeEZhK3JRYKOe06yW6IU_big.jpg'),
(47268, 3249, 'Your Honor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212796.mp4', 'http://gstaticontent.com/images/xWJZjIKPeEZhK3JRYKOe06yW6IU_big.jpg'),
(47269, 3249, 'Your Honor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212797.mp4', 'http://gstaticontent.com/images/xWJZjIKPeEZhK3JRYKOe06yW6IU_big.jpg'),
(47270, 3249, 'Your Honor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212798.mp4', 'http://gstaticontent.com/images/xWJZjIKPeEZhK3JRYKOe06yW6IU_big.jpg'),
(47271, 3250, 'Your Honor S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/39dcffcM4KePJS1cYlvAAg3wk7n.jpg'),
(47272, 3250, 'Your Honor S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nR8CUcaxRwLIHsDZGGUti8kjHtB.jpg'),
(47273, 3250, 'Your Honor S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j5aDatgb9iDeXtMYbBUiEeoIc9N.jpg'),
(47274, 3250, 'Your Honor S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u25ujD6W1fqN7czsR7VydyBRBfv.jpg'),
(47275, 3250, 'Your Honor S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212803.mp4', 'http://image.tmdb.org/t/p/w1280/6CWQeQOAPmGBcd2prx4oQrVVPmu.jpg'),
(47276, 3250, 'Your Honor S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212804.mp4', 'http://image.tmdb.org/t/p/w1280/6y3wu7jU4M6jfrF4H2dEiL27hXz.jpg'),
(47277, 3250, 'Your Honor S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212805.mp4', 'http://image.tmdb.org/t/p/w1280/4t8NiU2aEWctBH6Js53Xmbohawl.jpg'),
(47278, 3250, 'Your Honor S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212806.mp4', 'http://image.tmdb.org/t/p/w1280/eYsYFPpvMhcDbtolu6eUD3k5lLf.jpg'),
(47279, 3250, 'Your Honor S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212807.mp4', 'http://image.tmdb.org/t/p/w1280/q4Li9iPURtXXX0k4mZyCgDrD1vB.jpg'),
(47280, 3250, 'Your Honor S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212808.mp4', 'http://image.tmdb.org/t/p/w1280/7Ig8sy7RODVUgEIxiMlSmTgg1D.jpg'),
(47281, 3251, 'Cidade de Fantasmas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141014.mp4', 'http://gstaticontent.com/images/rGSNlbq14XAn92SH22j3kao7CbS_big.jpg'),
(47282, 3251, 'Cidade de Fantasmas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141015.mp4', 'http://gstaticontent.com/images/rGSNlbq14XAn92SH22j3kao7CbS_big.jpg'),
(47283, 3251, 'Cidade de Fantasmas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141016.mp4', 'http://gstaticontent.com/images/rGSNlbq14XAn92SH22j3kao7CbS_big.jpg'),
(47284, 3251, 'Cidade de Fantasmas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141017.mp4', 'http://gstaticontent.com/images/rGSNlbq14XAn92SH22j3kao7CbS_big.jpg'),
(47285, 3251, 'Cidade de Fantasmas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141018.mp4', 'http://gstaticontent.com/images/rGSNlbq14XAn92SH22j3kao7CbS_big.jpg'),
(47286, 3251, 'Cidade de Fantasmas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141019.mp4', 'http://gstaticontent.com/images/rGSNlbq14XAn92SH22j3kao7CbS_big.jpg'),
(47287, 3252, 'Cacadores de Dinossauros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141020.mp4', 'http://gstaticontent.com/images/cPDT7YLeFoPtUvTPH4ANYJX09mE_big.jpg'),
(47288, 3252, 'Cacadores de Dinossauros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141021.mp4', 'http://gstaticontent.com/images/cPDT7YLeFoPtUvTPH4ANYJX09mE_big.jpg'),
(47289, 3252, 'Cacadores de Dinossauros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141022.mp4', 'http://gstaticontent.com/images/cPDT7YLeFoPtUvTPH4ANYJX09mE_big.jpg'),
(47290, 3252, 'Cacadores de Dinossauros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141023.mp4', 'http://gstaticontent.com/images/cPDT7YLeFoPtUvTPH4ANYJX09mE_big.jpg'),
(47291, 3252, 'Cacadores de Dinossauros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141024.mp4', 'http://gstaticontent.com/images/cPDT7YLeFoPtUvTPH4ANYJX09mE_big.jpg'),
(47292, 3253, '4X4 Sob Medida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164046.mp4', 'https://i.bj-share.info/63ccbbb5f2badbd870c2cdf03ca023fb.jpg'),
(47293, 3253, '4X4 Sob Medida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164047.mp4', 'https://i.bj-share.info/63ccbbb5f2badbd870c2cdf03ca023fb.jpg'),
(47294, 3253, '4X4 Sob Medida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164048.mp4', 'https://i.bj-share.info/63ccbbb5f2badbd870c2cdf03ca023fb.jpg'),
(47295, 3253, '4X4 Sob Medida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164049.mp4', 'https://i.bj-share.info/63ccbbb5f2badbd870c2cdf03ca023fb.jpg'),
(47296, 3253, '4X4 Sob Medida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164050.mp4', 'https://i.bj-share.info/63ccbbb5f2badbd870c2cdf03ca023fb.jpg'),
(47297, 3253, '4X4 Sob Medida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164051.mp4', 'https://i.bj-share.info/63ccbbb5f2badbd870c2cdf03ca023fb.jpg'),
(47298, 3253, '4X4 Sob Medida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164052.mp4', 'https://i.bj-share.info/63ccbbb5f2badbd870c2cdf03ca023fb.jpg'),
(47299, 3253, '4X4 Sob Medida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164053.mp4', 'https://i.bj-share.info/63ccbbb5f2badbd870c2cdf03ca023fb.jpg'),
(47300, 3253, '4X4 Sob Medida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164054.mp4', 'https://i.bj-share.info/63ccbbb5f2badbd870c2cdf03ca023fb.jpg'),
(47301, 3253, '4X4 Sob Medida S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164055.mp4', 'https://i.bj-share.info/63ccbbb5f2badbd870c2cdf03ca023fb.jpg'),
(47302, 3254, '4X4 Sob Medida S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164056.mp4', 'https://i.bj-share.info/63ccbbb5f2badbd870c2cdf03ca023fb.jpg'),
(47303, 3254, '4X4 Sob Medida S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164057.mp4', 'https://i.bj-share.info/63ccbbb5f2badbd870c2cdf03ca023fb.jpg'),
(47304, 3254, '4X4 Sob Medida S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164058.mp4', 'https://i.bj-share.info/63ccbbb5f2badbd870c2cdf03ca023fb.jpg'),
(47305, 3254, '4X4 Sob Medida S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164059.mp4', 'https://i.bj-share.info/63ccbbb5f2badbd870c2cdf03ca023fb.jpg'),
(47306, 3254, '4X4 Sob Medida S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164060.mp4', 'https://i.bj-share.info/63ccbbb5f2badbd870c2cdf03ca023fb.jpg'),
(47307, 3254, '4X4 Sob Medida S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164061.mp4', 'https://i.bj-share.info/63ccbbb5f2badbd870c2cdf03ca023fb.jpg'),
(47308, 3254, '4X4 Sob Medida S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164062.mp4', 'https://i.bj-share.info/63ccbbb5f2badbd870c2cdf03ca023fb.jpg'),
(47309, 3254, '4X4 Sob Medida S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164063.mp4', 'https://i.bj-share.info/63ccbbb5f2badbd870c2cdf03ca023fb.jpg'),
(47310, 3254, '4X4 Sob Medida S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164064.mp4', 'https://i.bj-share.info/63ccbbb5f2badbd870c2cdf03ca023fb.jpg'),
(47311, 3254, '4X4 Sob Medida S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164065.mp4', 'https://i.bj-share.info/63ccbbb5f2badbd870c2cdf03ca023fb.jpg'),
(47312, 3255, 'Hora de Aventura S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141025.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47313, 3255, 'Hora de Aventura S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141026.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47314, 3255, 'Hora de Aventura S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141027.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47315, 3255, 'Hora de Aventura S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141028.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47316, 3255, 'Hora de Aventura S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141029.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47317, 3255, 'Hora de Aventura S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141030.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47318, 3255, 'Hora de Aventura S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141031.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47319, 3255, 'Hora de Aventura S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141032.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47320, 3255, 'Hora de Aventura S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141033.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47321, 3255, 'Hora de Aventura S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141034.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47322, 3255, 'Hora de Aventura S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141035.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47323, 3255, 'Hora de Aventura S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141036.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47324, 3255, 'Hora de Aventura S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141037.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47325, 3255, 'Hora de Aventura S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141038.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47326, 3255, 'Hora de Aventura S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141039.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47327, 3255, 'Hora de Aventura S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141040.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47328, 3255, 'Hora de Aventura S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141041.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47329, 3255, 'Hora de Aventura S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141042.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47330, 3255, 'Hora de Aventura S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141043.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47331, 3255, 'Hora de Aventura S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141044.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47332, 3255, 'Hora de Aventura S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/141045.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47333, 3255, 'Hora de Aventura S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/141046.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47334, 3255, 'Hora de Aventura S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/141047.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47335, 3255, 'Hora de Aventura S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/141048.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47336, 3255, 'Hora de Aventura S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/141049.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47337, 3255, 'Hora de Aventura S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/141050.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47338, 3256, 'Hora de Aventura S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141051.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47339, 3256, 'Hora de Aventura S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141052.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47340, 3256, 'Hora de Aventura S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141053.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47341, 3256, 'Hora de Aventura S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141054.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47342, 3256, 'Hora de Aventura S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141055.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47343, 3256, 'Hora de Aventura S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141056.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47344, 3256, 'Hora de Aventura S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141057.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47345, 3256, 'Hora de Aventura S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141058.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47346, 3256, 'Hora de Aventura S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141059.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47347, 3256, 'Hora de Aventura S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141060.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47348, 3256, 'Hora de Aventura S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141061.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47349, 3256, 'Hora de Aventura S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141062.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47350, 3256, 'Hora de Aventura S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141063.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47351, 3256, 'Hora de Aventura S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141064.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47352, 3256, 'Hora de Aventura S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141065.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47353, 3256, 'Hora de Aventura S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141066.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47354, 3256, 'Hora de Aventura S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141067.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47355, 3256, 'Hora de Aventura S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141068.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47356, 3256, 'Hora de Aventura S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141069.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47357, 3256, 'Hora de Aventura S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141070.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47358, 3256, 'Hora de Aventura S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/141071.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47359, 3256, 'Hora de Aventura S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/141072.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47360, 3256, 'Hora de Aventura S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/141073.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47361, 3256, 'Hora de Aventura S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/141074.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47362, 3256, 'Hora de Aventura S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/141075.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47363, 3256, 'Hora de Aventura S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/141076.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47364, 3257, 'Hora de Aventura S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141077.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47365, 3257, 'Hora de Aventura S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141078.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47366, 3257, 'Hora de Aventura S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141079.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47367, 3257, 'Hora de Aventura S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141080.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47368, 3257, 'Hora de Aventura S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141081.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47369, 3257, 'Hora de Aventura S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141082.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47370, 3257, 'Hora de Aventura S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141083.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47371, 3257, 'Hora de Aventura S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141084.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47372, 3257, 'Hora de Aventura S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141085.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47373, 3257, 'Hora de Aventura S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141086.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47374, 3257, 'Hora de Aventura S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141087.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47375, 3257, 'Hora de Aventura S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141088.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47376, 3257, 'Hora de Aventura S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141089.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47377, 3257, 'Hora de Aventura S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141090.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47378, 3257, 'Hora de Aventura S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141091.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47379, 3257, 'Hora de Aventura S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141092.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47380, 3257, 'Hora de Aventura S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141093.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47381, 3257, 'Hora de Aventura S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141094.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47382, 3257, 'Hora de Aventura S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141095.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47383, 3257, 'Hora de Aventura S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141096.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47384, 3257, 'Hora de Aventura S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/141097.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47385, 3257, 'Hora de Aventura S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/141098.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47386, 3257, 'Hora de Aventura S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/141099.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(47387, 3257, 'Hora de Aventura S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/141100.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47388, 3257, 'Hora de Aventura S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/141101.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47389, 3257, 'Hora de Aventura S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/141102.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47390, 3258, 'Hora de Aventura S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141103.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47391, 3258, 'Hora de Aventura S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141104.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47392, 3258, 'Hora de Aventura S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141105.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47393, 3258, 'Hora de Aventura S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141106.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47394, 3258, 'Hora de Aventura S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141107.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47395, 3258, 'Hora de Aventura S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141108.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47396, 3258, 'Hora de Aventura S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141109.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47397, 3258, 'Hora de Aventura S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141110.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47398, 3258, 'Hora de Aventura S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141111.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47399, 3258, 'Hora de Aventura S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141112.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47400, 3258, 'Hora de Aventura S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141113.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47401, 3258, 'Hora de Aventura S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141114.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47402, 3258, 'Hora de Aventura S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141115.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47403, 3258, 'Hora de Aventura S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141116.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47404, 3258, 'Hora de Aventura S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141117.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47405, 3258, 'Hora de Aventura S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141118.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47406, 3258, 'Hora de Aventura S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141119.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47407, 3258, 'Hora de Aventura S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141120.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47408, 3258, 'Hora de Aventura S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141121.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47409, 3258, 'Hora de Aventura S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141122.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47410, 3258, 'Hora de Aventura S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/141123.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47411, 3258, 'Hora de Aventura S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/141124.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47412, 3258, 'Hora de Aventura S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/141125.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47413, 3258, 'Hora de Aventura S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/141126.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47414, 3258, 'Hora de Aventura S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/141127.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47415, 3259, 'Hora de Aventura S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141128.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47416, 3259, 'Hora de Aventura S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141129.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47417, 3259, 'Hora de Aventura S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141130.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47418, 3259, 'Hora de Aventura S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141131.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47419, 3259, 'Hora de Aventura S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141132.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47420, 3259, 'Hora de Aventura S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141133.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47421, 3259, 'Hora de Aventura S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141134.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47422, 3259, 'Hora de Aventura S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141135.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47423, 3259, 'Hora de Aventura S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141136.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47424, 3259, 'Hora de Aventura S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141137.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47425, 3259, 'Hora de Aventura S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141138.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47426, 3259, 'Hora de Aventura S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141139.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47427, 3259, 'Hora de Aventura S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141140.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47428, 3259, 'Hora de Aventura S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141141.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47429, 3259, 'Hora de Aventura S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141142.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47430, 3259, 'Hora de Aventura S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141143.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47431, 3259, 'Hora de Aventura S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141144.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47432, 3259, 'Hora de Aventura S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141145.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47433, 3259, 'Hora de Aventura S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141146.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47434, 3259, 'Hora de Aventura S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141147.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47435, 3259, 'Hora de Aventura S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/141148.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47436, 3259, 'Hora de Aventura S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/141149.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47437, 3259, 'Hora de Aventura S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/141150.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47438, 3259, 'Hora de Aventura S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/141151.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47439, 3259, 'Hora de Aventura S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/141152.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47440, 3259, 'Hora de Aventura S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/141153.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47441, 3259, 'Hora de Aventura S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/141154.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47442, 3259, 'Hora de Aventura S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/141155.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47443, 3259, 'Hora de Aventura S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/141156.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47444, 3259, 'Hora de Aventura S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/141157.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47445, 3259, 'Hora de Aventura S05 E31', 'http://sinalprivado.info:80/series/1533784/1533784/141158.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47446, 3259, 'Hora de Aventura S05 E32', 'http://sinalprivado.info:80/series/1533784/1533784/141159.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47447, 3259, 'Hora de Aventura S05 E33', 'http://sinalprivado.info:80/series/1533784/1533784/141160.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47448, 3259, 'Hora de Aventura S05 E34', 'http://sinalprivado.info:80/series/1533784/1533784/141161.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47449, 3259, 'Hora de Aventura S05 E35', 'http://sinalprivado.info:80/series/1533784/1533784/141162.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47450, 3259, 'Hora de Aventura S05 E36', 'http://sinalprivado.info:80/series/1533784/1533784/141163.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47451, 3259, 'Hora de Aventura S05 E37', 'http://sinalprivado.info:80/series/1533784/1533784/141164.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47452, 3259, 'Hora de Aventura S05 E38', 'http://sinalprivado.info:80/series/1533784/1533784/141165.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47453, 3259, 'Hora de Aventura S05 E39', 'http://sinalprivado.info:80/series/1533784/1533784/141166.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47454, 3259, 'Hora de Aventura S05 E40', 'http://sinalprivado.info:80/series/1533784/1533784/141167.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47455, 3259, 'Hora de Aventura S05 E41', 'http://sinalprivado.info:80/series/1533784/1533784/141168.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47456, 3259, 'Hora de Aventura S05 E42', 'http://sinalprivado.info:80/series/1533784/1533784/141169.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47457, 3259, 'Hora de Aventura S05 E43', 'http://sinalprivado.info:80/series/1533784/1533784/141170.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47458, 3259, 'Hora de Aventura S05 E44', 'http://sinalprivado.info:80/series/1533784/1533784/141171.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47459, 3259, 'Hora de Aventura S05 E45', 'http://sinalprivado.info:80/series/1533784/1533784/141172.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47460, 3259, 'Hora de Aventura S05 E46', 'http://sinalprivado.info:80/series/1533784/1533784/141173.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47461, 3259, 'Hora de Aventura S05 E47', 'http://sinalprivado.info:80/series/1533784/1533784/141174.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47462, 3259, 'Hora de Aventura S05 E48', 'http://sinalprivado.info:80/series/1533784/1533784/141175.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47463, 3259, 'Hora de Aventura S05 E49', 'http://sinalprivado.info:80/series/1533784/1533784/141176.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47464, 3259, 'Hora de Aventura S05 E50', 'http://sinalprivado.info:80/series/1533784/1533784/141177.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47465, 3259, 'Hora de Aventura S05 E51', 'http://sinalprivado.info:80/series/1533784/1533784/141178.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47466, 3259, 'Hora de Aventura S05 E52', 'http://sinalprivado.info:80/series/1533784/1533784/141179.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47467, 3260, 'Hora de Aventura S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141180.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47468, 3260, 'Hora de Aventura S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141181.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47469, 3260, 'Hora de Aventura S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141182.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47470, 3260, 'Hora de Aventura S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141183.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47471, 3260, 'Hora de Aventura S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141184.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47472, 3260, 'Hora de Aventura S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141185.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47473, 3260, 'Hora de Aventura S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141186.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47474, 3260, 'Hora de Aventura S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141187.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47475, 3260, 'Hora de Aventura S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141188.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47476, 3260, 'Hora de Aventura S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141189.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47477, 3260, 'Hora de Aventura S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141190.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47478, 3260, 'Hora de Aventura S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141191.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47479, 3260, 'Hora de Aventura S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141192.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47480, 3260, 'Hora de Aventura S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141193.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47481, 3260, 'Hora de Aventura S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141194.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47482, 3260, 'Hora de Aventura S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141195.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47483, 3260, 'Hora de Aventura S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141196.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47484, 3260, 'Hora de Aventura S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141197.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47485, 3260, 'Hora de Aventura S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141198.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47486, 3260, 'Hora de Aventura S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141199.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47487, 3260, 'Hora de Aventura S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/141200.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47488, 3260, 'Hora de Aventura S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/141201.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47489, 3260, 'Hora de Aventura S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/141202.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47490, 3260, 'Hora de Aventura S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/141203.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47491, 3260, 'Hora de Aventura S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/141204.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47492, 3260, 'Hora de Aventura S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/141205.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47493, 3260, 'Hora de Aventura S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/141206.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47494, 3260, 'Hora de Aventura S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/141207.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47495, 3260, 'Hora de Aventura S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/141208.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47496, 3260, 'Hora de Aventura S06 E30', 'http://sinalprivado.info:80/series/1533784/1533784/141209.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47497, 3260, 'Hora de Aventura S06 E31', 'http://sinalprivado.info:80/series/1533784/1533784/141210.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47498, 3260, 'Hora de Aventura S06 E32', 'http://sinalprivado.info:80/series/1533784/1533784/141211.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47499, 3260, 'Hora de Aventura S06 E33', 'http://sinalprivado.info:80/series/1533784/1533784/141212.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47500, 3260, 'Hora de Aventura S06 E34', 'http://sinalprivado.info:80/series/1533784/1533784/141213.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47501, 3260, 'Hora de Aventura S06 E35', 'http://sinalprivado.info:80/series/1533784/1533784/141214.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47502, 3260, 'Hora de Aventura S06 E36', 'http://sinalprivado.info:80/series/1533784/1533784/141215.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47503, 3260, 'Hora de Aventura S06 E37', 'http://sinalprivado.info:80/series/1533784/1533784/141216.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47504, 3260, 'Hora de Aventura S06 E38', 'http://sinalprivado.info:80/series/1533784/1533784/141217.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47505, 3260, 'Hora de Aventura S06 E39', 'http://sinalprivado.info:80/series/1533784/1533784/141218.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47506, 3260, 'Hora de Aventura S06 E40', 'http://sinalprivado.info:80/series/1533784/1533784/141219.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47507, 3260, 'Hora de Aventura S06 E41', 'http://sinalprivado.info:80/series/1533784/1533784/141220.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47508, 3260, 'Hora de Aventura S06 E42', 'http://sinalprivado.info:80/series/1533784/1533784/141221.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47509, 3260, 'Hora de Aventura S06 E43', 'http://sinalprivado.info:80/series/1533784/1533784/141222.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47510, 3261, 'Hora de Aventura S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141223.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47511, 3261, 'Hora de Aventura S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141224.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47512, 3261, 'Hora de Aventura S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141225.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47513, 3261, 'Hora de Aventura S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141226.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47514, 3261, 'Hora de Aventura S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141227.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47515, 3261, 'Hora de Aventura S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141228.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47516, 3261, 'Hora de Aventura S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141229.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47517, 3261, 'Hora de Aventura S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141230.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47518, 3261, 'Hora de Aventura S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141231.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47519, 3261, 'Hora de Aventura S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141232.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47520, 3261, 'Hora de Aventura S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141233.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47521, 3261, 'Hora de Aventura S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141234.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47522, 3261, 'Hora de Aventura S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141235.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47523, 3261, 'Hora de Aventura S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141236.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47524, 3261, 'Hora de Aventura S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141237.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47525, 3261, 'Hora de Aventura S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141238.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47526, 3261, 'Hora de Aventura S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141239.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47527, 3261, 'Hora de Aventura S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141240.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47528, 3261, 'Hora de Aventura S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141241.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47529, 3261, 'Hora de Aventura S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141242.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47530, 3261, 'Hora de Aventura S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/141243.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47531, 3261, 'Hora de Aventura S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/141244.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47532, 3261, 'Hora de Aventura S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/141245.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47533, 3261, 'Hora de Aventura S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/141246.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47534, 3261, 'Hora de Aventura S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/141247.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47535, 3261, 'Hora de Aventura S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/141248.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47536, 3261, 'Hora de Aventura S07 E27', 'http://sinalprivado.info:80/series/1533784/1533784/141249.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47537, 3261, 'Hora de Aventura S07 E28', 'http://sinalprivado.info:80/series/1533784/1533784/141250.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47538, 3261, 'Hora de Aventura S07 E29', 'http://sinalprivado.info:80/series/1533784/1533784/141251.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47539, 3261, 'Hora de Aventura S07 E30', 'http://sinalprivado.info:80/series/1533784/1533784/141252.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47540, 3261, 'Hora de Aventura S07 E31', 'http://sinalprivado.info:80/series/1533784/1533784/141253.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47541, 3261, 'Hora de Aventura S07 E32', 'http://sinalprivado.info:80/series/1533784/1533784/141254.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47542, 3261, 'Hora de Aventura S07 E33', 'http://sinalprivado.info:80/series/1533784/1533784/141255.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47543, 3261, 'Hora de Aventura S07 E34', 'http://sinalprivado.info:80/series/1533784/1533784/141256.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47544, 3261, 'Hora de Aventura S07 E35', 'http://sinalprivado.info:80/series/1533784/1533784/141257.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47545, 3261, 'Hora de Aventura S07 E36', 'http://sinalprivado.info:80/series/1533784/1533784/141258.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47546, 3262, 'Hora de Aventura S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141259.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47547, 3262, 'Hora de Aventura S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141260.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47548, 3262, 'Hora de Aventura S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141261.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47549, 3262, 'Hora de Aventura S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141262.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47550, 3262, 'Hora de Aventura S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141263.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47551, 3262, 'Hora de Aventura S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141264.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47552, 3262, 'Hora de Aventura S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141265.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47553, 3262, 'Hora de Aventura S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141266.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47554, 3262, 'Hora de Aventura S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141267.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47555, 3262, 'Hora de Aventura S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141268.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47556, 3262, 'Hora de Aventura S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141269.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47557, 3262, 'Hora de Aventura S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141270.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47558, 3262, 'Hora de Aventura S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141271.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47559, 3262, 'Hora de Aventura S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/141272.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47560, 3262, 'Hora de Aventura S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/141273.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47561, 3262, 'Hora de Aventura S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/141274.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47562, 3262, 'Hora de Aventura S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/141275.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47563, 3262, 'Hora de Aventura S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/141276.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47564, 3262, 'Hora de Aventura S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/141277.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47565, 3262, 'Hora de Aventura S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/141278.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47566, 3262, 'Hora de Aventura S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/141279.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47567, 3262, 'Hora de Aventura S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/141280.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47568, 3262, 'Hora de Aventura S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/141281.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47569, 3262, 'Hora de Aventura S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/141282.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47570, 3262, 'Hora de Aventura S08 E25', 'http://sinalprivado.info:80/series/1533784/1533784/141283.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47571, 3262, 'Hora de Aventura S08 E26', 'http://sinalprivado.info:80/series/1533784/1533784/141284.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47572, 3262, 'Hora de Aventura S08 E27', 'http://sinalprivado.info:80/series/1533784/1533784/141285.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47573, 3262, 'Hora de Aventura S08 E28', 'http://sinalprivado.info:80/series/1533784/1533784/141286.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47574, 3263, 'Hora de Aventura S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141287.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47575, 3263, 'Hora de Aventura S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141288.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47576, 3263, 'Hora de Aventura S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141289.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47577, 3263, 'Hora de Aventura S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141290.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47578, 3263, 'Hora de Aventura S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141291.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47579, 3263, 'Hora de Aventura S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141292.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47580, 3263, 'Hora de Aventura S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141293.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47581, 3263, 'Hora de Aventura S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141294.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47582, 3263, 'Hora de Aventura S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141295.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47583, 3263, 'Hora de Aventura S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141296.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47584, 3263, 'Hora de Aventura S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141297.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47585, 3263, 'Hora de Aventura S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141298.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47586, 3264, 'Hora de Aventura S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141299.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47587, 3264, 'Hora de Aventura S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141300.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47588, 3264, 'Hora de Aventura S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141301.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47589, 3264, 'Hora de Aventura S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141302.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47590, 3264, 'Hora de Aventura S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141303.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47591, 3264, 'Hora de Aventura S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141304.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47592, 3264, 'Hora de Aventura S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141305.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47593, 3264, 'Hora de Aventura S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141306.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47594, 3264, 'Hora de Aventura S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141307.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47595, 3264, 'Hora de Aventura S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141308.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47596, 3264, 'Hora de Aventura S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141309.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47597, 3264, 'Hora de Aventura S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141310.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47598, 3264, 'Hora de Aventura S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/141311.mp4', 'http://gstaticontent.com/images/rk9hP9oWxdz70HjH2khCl3wSYu8_big.jpg'),
(47599, 3265, 'Filhas de Eva S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141312.mp4', 'http://gstaticontent.com/images/4LE1pOcjIkr3LjApo6gFO4yay1_big.jpg'),
(47600, 3265, 'Filhas de Eva S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141313.mp4', 'http://gstaticontent.com/images/4LE1pOcjIkr3LjApo6gFO4yay1_big.jpg'),
(47601, 3265, 'Filhas de Eva S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141314.mp4', 'http://gstaticontent.com/images/4LE1pOcjIkr3LjApo6gFO4yay1_big.jpg'),
(47602, 3265, 'Filhas de Eva S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141315.mp4', 'http://gstaticontent.com/images/4LE1pOcjIkr3LjApo6gFO4yay1_big.jpg'),
(47603, 3265, 'Filhas de Eva S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141316.mp4', 'http://gstaticontent.com/images/4LE1pOcjIkr3LjApo6gFO4yay1_big.jpg'),
(47604, 3265, 'Filhas de Eva S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141317.mp4', 'http://gstaticontent.com/images/4LE1pOcjIkr3LjApo6gFO4yay1_big.jpg'),
(47605, 3265, 'Filhas de Eva S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141318.mp4', 'http://gstaticontent.com/images/4LE1pOcjIkr3LjApo6gFO4yay1_big.jpg'),
(47606, 3265, 'Filhas de Eva S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141319.mp4', 'http://gstaticontent.com/images/4LE1pOcjIkr3LjApo6gFO4yay1_big.jpg'),
(47607, 3265, 'Filhas de Eva S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141320.mp4', 'http://gstaticontent.com/images/4LE1pOcjIkr3LjApo6gFO4yay1_big.jpg'),
(47608, 3265, 'Filhas de Eva S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141321.mp4', 'http://gstaticontent.com/images/4LE1pOcjIkr3LjApo6gFO4yay1_big.jpg'),
(47609, 3265, 'Filhas de Eva S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141322.mp4', 'http://gstaticontent.com/images/4LE1pOcjIkr3LjApo6gFO4yay1_big.jpg'),
(47610, 3265, 'Filhas de Eva S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141323.mp4', 'http://gstaticontent.com/images/4LE1pOcjIkr3LjApo6gFO4yay1_big.jpg'),
(47611, 3266, 'Resident Alien [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190573.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47612, 3266, 'Resident Alien [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190574.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47613, 3266, 'Resident Alien [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190575.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47614, 3266, 'Resident Alien [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190576.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47615, 3266, 'Resident Alien [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190577.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47616, 3266, 'Resident Alien [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190578.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47617, 3266, 'Resident Alien [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190579.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47618, 3266, 'Resident Alien [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190580.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47619, 3266, 'Resident Alien [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190581.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47620, 3266, 'Resident Alien [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190582.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47621, 3267, 'Resident Alien [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190583.mp4', 'http://timg.bdta.pro/images/b853fcbac508c87ac6bd6fe2bc48dfce.jpg'),
(47622, 3267, 'Resident Alien [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190584.mp4', 'http://timg.bdta.pro/images/64325312770846d95c29b08d232b9493.jpg'),
(47623, 3267, 'Resident Alien [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190585.mp4', 'http://timg.bdta.pro/images/eab37c98d5303c5f3f48dce4f36c46b0.jpg'),
(47624, 3267, 'Resident Alien [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190586.mp4', 'http://timg.bdta.pro/images/47554d768a05258da111a96896c82e04.jpg'),
(47625, 3267, 'Resident Alien [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190587.mp4', 'http://timg.bdta.pro/images/5800d0f4d887082bb39c2b92c3525de7.jpg'),
(47626, 3267, 'Resident Alien [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190588.mp4', 'http://timg.bdta.pro/images/ac4f7bb9120abf63b08aff774bd8d515.jpg'),
(47627, 3267, 'Resident Alien [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190589.mp4', 'http://timg.bdta.pro/images/0e431c61da5e66088305563c4302a793.jpg'),
(47628, 3267, 'Resident Alien [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190590.mp4', 'http://timg.bdta.pro/images/1186977dd55d9a2d733776daf740c28c.jpg'),
(47629, 3267, 'Resident Alien [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/883045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5tsDW07SvAoJ4XquYAqKowxrOzk.jpg'),
(47630, 3267, 'Resident Alien [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/883046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i3GXwrVkr3GGlMple8Q9EsIqbsO.jpg'),
(47631, 3267, 'Resident Alien [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/883047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e3T5SSMp4n1mppFqTzZDVgLTqcY.jpg'),
(47632, 3267, 'Resident Alien [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/883048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gfIoPr5U09sYFIdYFX2143kWARj.jpg'),
(47633, 3267, 'Resident Alien [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/883049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fAEfV5kgjIUH9KsOkyLHymrTewG.jpg'),
(47634, 3267, 'Resident Alien [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/883050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sFjoSCzBcd7CHCVfKUYO2ZyOYQD.jpg'),
(47635, 3267, 'Resident Alien [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/883051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/odnkwmxHM0GKDxELqkyqMJtUDaR.jpg'),
(47636, 3268, 'Resident Alien [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/297425.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47637, 3268, 'Resident Alien [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/297426.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47638, 3268, 'Resident Alien [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/297427.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47639, 3268, 'Resident Alien [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/304055.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47640, 3268, 'Resident Alien [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/307290.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47641, 3268, 'Resident Alien [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/327239.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47642, 3268, 'Resident Alien [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/336003.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47643, 3268, 'Resident Alien [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/336004.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47644, 3269, 'Resident Alien [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/846679.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47645, 3269, 'Resident Alien [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/849352.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47646, 3269, 'Resident Alien [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/866600.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47647, 3269, 'Resident Alien [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/877641.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47648, 3269, 'Resident Alien [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/880853.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47649, 3269, 'Resident Alien [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/891774.mp4', 'http://gstaticontent.com/images/bG5aqfT5lTHuSbcQofNHtH0RyyP_big.jpg'),
(47650, 3270, 'A Bela e o Padeiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140896.mp4', 'http://gstaticontent.com/images/aThzoJr7gi6q5cRH94ykyKDDQKS_big.jpg'),
(47651, 3270, 'A Bela e o Padeiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140897.mp4', 'http://gstaticontent.com/images/aThzoJr7gi6q5cRH94ykyKDDQKS_big.jpg'),
(47652, 3270, 'A Bela e o Padeiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140898.mp4', 'http://gstaticontent.com/images/aThzoJr7gi6q5cRH94ykyKDDQKS_big.jpg'),
(47653, 3270, 'A Bela e o Padeiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140899.mp4', 'http://gstaticontent.com/images/aThzoJr7gi6q5cRH94ykyKDDQKS_big.jpg'),
(47654, 3270, 'A Bela e o Padeiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140900.mp4', 'http://gstaticontent.com/images/aThzoJr7gi6q5cRH94ykyKDDQKS_big.jpg'),
(47655, 3270, 'A Bela e o Padeiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140901.mp4', 'http://gstaticontent.com/images/aThzoJr7gi6q5cRH94ykyKDDQKS_big.jpg'),
(47656, 3270, 'A Bela e o Padeiro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140902.mp4', 'http://gstaticontent.com/images/aThzoJr7gi6q5cRH94ykyKDDQKS_big.jpg'),
(47657, 3270, 'A Bela e o Padeiro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140903.mp4', 'http://gstaticontent.com/images/aThzoJr7gi6q5cRH94ykyKDDQKS_big.jpg'),
(47658, 3270, 'A Bela e o Padeiro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140904.mp4', 'http://gstaticontent.com/images/aThzoJr7gi6q5cRH94ykyKDDQKS_big.jpg'),
(47659, 3271, 'Black Monday S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140876.mp4', 'http://gstaticontent.com/images/yidvzRidnDDpLxAXpO7aLNXRsS8_big.jpg'),
(47660, 3271, 'Black Monday S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140877.mp4', 'http://gstaticontent.com/images/yidvzRidnDDpLxAXpO7aLNXRsS8_big.jpg'),
(47661, 3271, 'Black Monday S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140878.mp4', 'http://gstaticontent.com/images/yidvzRidnDDpLxAXpO7aLNXRsS8_big.jpg'),
(47662, 3271, 'Black Monday S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140879.mp4', 'http://gstaticontent.com/images/yidvzRidnDDpLxAXpO7aLNXRsS8_big.jpg'),
(47663, 3271, 'Black Monday S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140880.mp4', 'http://gstaticontent.com/images/yidvzRidnDDpLxAXpO7aLNXRsS8_big.jpg'),
(47664, 3271, 'Black Monday S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140881.mp4', 'http://gstaticontent.com/images/yidvzRidnDDpLxAXpO7aLNXRsS8_big.jpg'),
(47665, 3271, 'Black Monday S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140882.mp4', 'http://gstaticontent.com/images/yidvzRidnDDpLxAXpO7aLNXRsS8_big.jpg'),
(47666, 3271, 'Black Monday S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140883.mp4', 'http://gstaticontent.com/images/yidvzRidnDDpLxAXpO7aLNXRsS8_big.jpg'),
(47667, 3271, 'Black Monday S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140884.mp4', 'http://gstaticontent.com/images/yidvzRidnDDpLxAXpO7aLNXRsS8_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(47668, 3271, 'Black Monday S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140885.mp4', 'http://gstaticontent.com/images/yidvzRidnDDpLxAXpO7aLNXRsS8_big.jpg'),
(47669, 3272, 'Black Monday S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140886.mp4', 'http://gstaticontent.com/images/yidvzRidnDDpLxAXpO7aLNXRsS8_big.jpg'),
(47670, 3272, 'Black Monday S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140887.mp4', 'http://gstaticontent.com/images/yidvzRidnDDpLxAXpO7aLNXRsS8_big.jpg'),
(47671, 3272, 'Black Monday S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140888.mp4', 'http://gstaticontent.com/images/yidvzRidnDDpLxAXpO7aLNXRsS8_big.jpg'),
(47672, 3272, 'Black Monday S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140889.mp4', 'http://gstaticontent.com/images/yidvzRidnDDpLxAXpO7aLNXRsS8_big.jpg'),
(47673, 3272, 'Black Monday S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140890.mp4', 'http://gstaticontent.com/images/yidvzRidnDDpLxAXpO7aLNXRsS8_big.jpg'),
(47674, 3272, 'Black Monday S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140891.mp4', 'http://gstaticontent.com/images/yidvzRidnDDpLxAXpO7aLNXRsS8_big.jpg'),
(47675, 3272, 'Black Monday S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140892.mp4', 'http://gstaticontent.com/images/yidvzRidnDDpLxAXpO7aLNXRsS8_big.jpg'),
(47676, 3272, 'Black Monday S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140893.mp4', 'http://gstaticontent.com/images/yidvzRidnDDpLxAXpO7aLNXRsS8_big.jpg'),
(47677, 3272, 'Black Monday S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140894.mp4', 'http://gstaticontent.com/images/yidvzRidnDDpLxAXpO7aLNXRsS8_big.jpg'),
(47678, 3272, 'Black Monday S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140895.mp4', 'http://gstaticontent.com/images/yidvzRidnDDpLxAXpO7aLNXRsS8_big.jpg'),
(47679, 3273, 'Black Narcissus S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140873.mp4', 'http://gstaticontent.com/images/3eYusIhAodlw2Lgoh1k8npejW8Z_big.jpg'),
(47680, 3273, 'Black Narcissus S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140874.mp4', 'http://gstaticontent.com/images/3eYusIhAodlw2Lgoh1k8npejW8Z_big.jpg'),
(47681, 3273, 'Black Narcissus S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140875.mp4', 'http://gstaticontent.com/images/3eYusIhAodlw2Lgoh1k8npejW8Z_big.jpg'),
(47682, 3274, 'For Life S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144277.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47683, 3274, 'For Life S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144278.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47684, 3274, 'For Life S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144279.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47685, 3274, 'For Life S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144280.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47686, 3274, 'For Life S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144281.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47687, 3274, 'For Life S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144282.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47688, 3274, 'For Life S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144283.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47689, 3274, 'For Life S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144284.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47690, 3274, 'For Life S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144285.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47691, 3274, 'For Life S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144286.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47692, 3274, 'For Life S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144287.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47693, 3274, 'For Life S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144288.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47694, 3274, 'For Life S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144289.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47695, 3275, 'For Life S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144290.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47696, 3275, 'For Life S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144291.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47697, 3275, 'For Life S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144292.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47698, 3275, 'For Life S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144293.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47699, 3275, 'For Life S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144294.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47700, 3275, 'For Life S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144295.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47701, 3275, 'For Life S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144296.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47702, 3275, 'For Life S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144297.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47703, 3275, 'For Life S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144298.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47704, 3275, 'For Life S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144299.mp4', 'http://gstaticontent.com/images/2zh9v2G29RxwdRsbhSZK42ccfiQ_big.jpg'),
(47705, 3276, 'Hanna S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140752.mp4', 'http://gstaticontent.com/images/5nSSkcM3TgpllZ7yTyBOQEgAX36_big.jpg'),
(47706, 3276, 'Hanna S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140753.mp4', 'http://gstaticontent.com/images/5nSSkcM3TgpllZ7yTyBOQEgAX36_big.jpg'),
(47707, 3276, 'Hanna S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140754.mp4', 'http://gstaticontent.com/images/5nSSkcM3TgpllZ7yTyBOQEgAX36_big.jpg'),
(47708, 3276, 'Hanna S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140755.mp4', 'http://gstaticontent.com/images/5nSSkcM3TgpllZ7yTyBOQEgAX36_big.jpg'),
(47709, 3276, 'Hanna S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140756.mp4', 'http://gstaticontent.com/images/5nSSkcM3TgpllZ7yTyBOQEgAX36_big.jpg'),
(47710, 3276, 'Hanna S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140757.mp4', 'http://gstaticontent.com/images/5nSSkcM3TgpllZ7yTyBOQEgAX36_big.jpg'),
(47711, 3276, 'Hanna S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140758.mp4', 'http://gstaticontent.com/images/5nSSkcM3TgpllZ7yTyBOQEgAX36_big.jpg'),
(47712, 3276, 'Hanna S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140759.mp4', 'http://gstaticontent.com/images/5nSSkcM3TgpllZ7yTyBOQEgAX36_big.jpg'),
(47713, 3277, 'Hanna S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140760.mp4', 'http://gstaticontent.com/images/5nSSkcM3TgpllZ7yTyBOQEgAX36_big.jpg'),
(47714, 3277, 'Hanna S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140761.mp4', 'http://gstaticontent.com/images/5nSSkcM3TgpllZ7yTyBOQEgAX36_big.jpg'),
(47715, 3277, 'Hanna S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140762.mp4', 'http://gstaticontent.com/images/5nSSkcM3TgpllZ7yTyBOQEgAX36_big.jpg'),
(47716, 3277, 'Hanna S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140763.mp4', 'http://gstaticontent.com/images/5nSSkcM3TgpllZ7yTyBOQEgAX36_big.jpg'),
(47717, 3277, 'Hanna S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140764.mp4', 'http://gstaticontent.com/images/5nSSkcM3TgpllZ7yTyBOQEgAX36_big.jpg'),
(47718, 3277, 'Hanna S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140765.mp4', 'http://gstaticontent.com/images/5nSSkcM3TgpllZ7yTyBOQEgAX36_big.jpg'),
(47719, 3277, 'Hanna S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140766.mp4', 'http://gstaticontent.com/images/5nSSkcM3TgpllZ7yTyBOQEgAX36_big.jpg'),
(47720, 3277, 'Hanna S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140767.mp4', 'http://gstaticontent.com/images/5nSSkcM3TgpllZ7yTyBOQEgAX36_big.jpg'),
(47721, 3278, 'Snoopy e sua turma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174606.mp4', 'http://gstaticontent.com/images/buY6ZLd35EZ3nRSw3s5bOkk5MQ6_big.jpg'),
(47722, 3278, 'Snoopy e sua turma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174607.mp4', 'http://gstaticontent.com/images/buY6ZLd35EZ3nRSw3s5bOkk5MQ6_big.jpg'),
(47723, 3278, 'Snoopy e sua turma S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174608.mp4', 'http://gstaticontent.com/images/buY6ZLd35EZ3nRSw3s5bOkk5MQ6_big.jpg'),
(47724, 3278, 'Snoopy e sua turma S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174609.mp4', 'http://gstaticontent.com/images/buY6ZLd35EZ3nRSw3s5bOkk5MQ6_big.jpg'),
(47725, 3278, 'Snoopy e sua turma S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174610.mp4', 'http://gstaticontent.com/images/buY6ZLd35EZ3nRSw3s5bOkk5MQ6_big.jpg'),
(47726, 3278, 'Snoopy e sua turma S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174611.mp4', 'http://gstaticontent.com/images/buY6ZLd35EZ3nRSw3s5bOkk5MQ6_big.jpg'),
(47727, 3279, 'Snoopy e sua turma S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174612.mp4', 'http://timg.bdta.pro/images/5b7195bd202c97aba155ffa2d24d6be4.jpg'),
(47728, 3279, 'Snoopy e sua turma S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174613.mp4', 'http://timg.bdta.pro/images/fe3951fa66bf6a4de381813c3f7b250d.jpg'),
(47729, 3279, 'Snoopy e sua turma S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174614.mp4', 'http://timg.bdta.pro/images/1525e024ef16630dd896a1d8b3944d97.jpg'),
(47730, 3279, 'Snoopy e sua turma S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174615.mp4', 'http://timg.bdta.pro/images/9d5d421014b63d9b89bf8a897263b95e.jpg'),
(47731, 3279, 'Snoopy e sua turma S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174616.mp4', 'http://timg.bdta.pro/images/ca7a57d8e373e77e032aee46d3314c5f.jpg'),
(47732, 3279, 'Snoopy e sua turma S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174617.mp4', 'http://timg.bdta.pro/images/d2280a7862fe60dcfcb480f0fd063e8c.jpg'),
(47733, 3280, 'Unidade Básica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245302.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47734, 3280, 'Unidade Básica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245303.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47735, 3280, 'Unidade Básica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245304.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47736, 3280, 'Unidade Básica S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245305.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47737, 3280, 'Unidade Básica S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245306.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47738, 3280, 'Unidade Básica S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245307.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47739, 3280, 'Unidade Básica S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245308.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47740, 3280, 'Unidade Básica S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245309.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47741, 3281, 'Unidade Básica S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245310.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47742, 3281, 'Unidade Básica S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245311.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47743, 3281, 'Unidade Básica S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245312.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47744, 3281, 'Unidade Básica S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245313.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47745, 3281, 'Unidade Básica S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245314.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47746, 3281, 'Unidade Básica S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245315.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47747, 3281, 'Unidade Básica S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245316.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47748, 3281, 'Unidade Básica S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245317.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47749, 3282, 'Unidade Básica S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245318.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47750, 3282, 'Unidade Básica S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245319.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47751, 3282, 'Unidade Básica S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245320.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47752, 3282, 'Unidade Básica S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245321.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47753, 3282, 'Unidade Básica S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245322.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47754, 3282, 'Unidade Básica S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245323.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47755, 3282, 'Unidade Básica S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245324.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47756, 3282, 'Unidade Básica S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245325.mp4', 'http://gstaticontent.com/images/zmxBmsFgSUF4rN76z1MIxEmZi69_big.jpg'),
(47757, 3283, 'Crimes Graves S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140768.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47758, 3283, 'Crimes Graves S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140769.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47759, 3283, 'Crimes Graves S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140770.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47760, 3283, 'Crimes Graves S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140771.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47761, 3283, 'Crimes Graves S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140772.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47762, 3283, 'Crimes Graves S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140773.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47763, 3283, 'Crimes Graves S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140774.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47764, 3283, 'Crimes Graves S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140775.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47765, 3283, 'Crimes Graves S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140776.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47766, 3283, 'Crimes Graves S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140777.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47767, 3284, 'Crimes Graves S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140778.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47768, 3284, 'Crimes Graves S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140779.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47769, 3284, 'Crimes Graves S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140780.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47770, 3284, 'Crimes Graves S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140781.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47771, 3284, 'Crimes Graves S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140782.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47772, 3284, 'Crimes Graves S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140783.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47773, 3284, 'Crimes Graves S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140784.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47774, 3284, 'Crimes Graves S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140785.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47775, 3284, 'Crimes Graves S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140786.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47776, 3284, 'Crimes Graves S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140787.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47777, 3284, 'Crimes Graves S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140788.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47778, 3284, 'Crimes Graves S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140789.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47779, 3284, 'Crimes Graves S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140790.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47780, 3284, 'Crimes Graves S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/140791.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47781, 3284, 'Crimes Graves S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/140792.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47782, 3284, 'Crimes Graves S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/140793.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47783, 3284, 'Crimes Graves S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/140794.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47784, 3284, 'Crimes Graves S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/140795.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47785, 3284, 'Crimes Graves S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/140796.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47786, 3285, 'Crimes Graves S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140797.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47787, 3285, 'Crimes Graves S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140798.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47788, 3285, 'Crimes Graves S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140799.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47789, 3285, 'Crimes Graves S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140800.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47790, 3285, 'Crimes Graves S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140801.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47791, 3285, 'Crimes Graves S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140802.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47792, 3285, 'Crimes Graves S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140803.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47793, 3285, 'Crimes Graves S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140804.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47794, 3285, 'Crimes Graves S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140805.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47795, 3285, 'Crimes Graves S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140806.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47796, 3285, 'Crimes Graves S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140807.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47797, 3285, 'Crimes Graves S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140808.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47798, 3285, 'Crimes Graves S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140809.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47799, 3285, 'Crimes Graves S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/140810.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47800, 3285, 'Crimes Graves S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/140811.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47801, 3285, 'Crimes Graves S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/140812.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47802, 3285, 'Crimes Graves S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/140813.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47803, 3285, 'Crimes Graves S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/140814.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47804, 3285, 'Crimes Graves S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/140815.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47805, 3286, 'Crimes Graves S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140816.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47806, 3286, 'Crimes Graves S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140817.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47807, 3286, 'Crimes Graves S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140818.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47808, 3286, 'Crimes Graves S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140819.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47809, 3286, 'Crimes Graves S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140820.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47810, 3286, 'Crimes Graves S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140821.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47811, 3286, 'Crimes Graves S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140822.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47812, 3286, 'Crimes Graves S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140823.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47813, 3286, 'Crimes Graves S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140824.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47814, 3286, 'Crimes Graves S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140825.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47815, 3286, 'Crimes Graves S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140826.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47816, 3286, 'Crimes Graves S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140827.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47817, 3286, 'Crimes Graves S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140828.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47818, 3286, 'Crimes Graves S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/140829.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47819, 3286, 'Crimes Graves S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/140830.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47820, 3286, 'Crimes Graves S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/140831.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47821, 3286, 'Crimes Graves S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/140832.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47822, 3286, 'Crimes Graves S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/140833.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47823, 3286, 'Crimes Graves S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/140834.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47824, 3286, 'Crimes Graves S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/140835.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47825, 3286, 'Crimes Graves S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/140836.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47826, 3286, 'Crimes Graves S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/140837.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47827, 3286, 'Crimes Graves S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/140838.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47828, 3287, 'Crimes Graves S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140839.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47829, 3287, 'Crimes Graves S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140840.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47830, 3287, 'Crimes Graves S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140841.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47831, 3287, 'Crimes Graves S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140842.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47832, 3287, 'Crimes Graves S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140843.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47833, 3287, 'Crimes Graves S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140844.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47834, 3287, 'Crimes Graves S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140845.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47835, 3287, 'Crimes Graves S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140846.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47836, 3287, 'Crimes Graves S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140847.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47837, 3287, 'Crimes Graves S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140848.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47838, 3287, 'Crimes Graves S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140849.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47839, 3287, 'Crimes Graves S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140850.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47840, 3287, 'Crimes Graves S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140851.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47841, 3287, 'Crimes Graves S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/140852.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47842, 3287, 'Crimes Graves S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/140853.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47843, 3287, 'Crimes Graves S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/140854.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47844, 3287, 'Crimes Graves S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/140855.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47845, 3287, 'Crimes Graves S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/140856.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47846, 3287, 'Crimes Graves S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/140857.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47847, 3287, 'Crimes Graves S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/140858.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47848, 3287, 'Crimes Graves S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/140859.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47849, 3288, 'Crimes Graves S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140860.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47850, 3288, 'Crimes Graves S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140861.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47851, 3288, 'Crimes Graves S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140862.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47852, 3288, 'Crimes Graves S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140863.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47853, 3288, 'Crimes Graves S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140864.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47854, 3288, 'Crimes Graves S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140865.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47855, 3288, 'Crimes Graves S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140866.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47856, 3288, 'Crimes Graves S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140867.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47857, 3288, 'Crimes Graves S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140868.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47858, 3288, 'Crimes Graves S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140869.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47859, 3288, 'Crimes Graves S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140870.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47860, 3288, 'Crimes Graves S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140871.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47861, 3288, 'Crimes Graves S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140872.mp4', 'http://gstaticontent.com/images/fZ502JXujnxVtprmigTO2jA205P_big.jpg'),
(47862, 3289, 'Círculo de Fogo: The Black S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178688.mp4', 'http://gstaticontent.com/images/4q1GGq86k5xmd9WJ30R3i6px1Yv_big.jpg'),
(47863, 3289, 'Círculo de Fogo: The Black S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178689.mp4', 'http://gstaticontent.com/images/4q1GGq86k5xmd9WJ30R3i6px1Yv_big.jpg'),
(47864, 3289, 'Círculo de Fogo: The Black S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178690.mp4', 'http://gstaticontent.com/images/4q1GGq86k5xmd9WJ30R3i6px1Yv_big.jpg'),
(47865, 3289, 'Círculo de Fogo: The Black S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178691.mp4', 'http://gstaticontent.com/images/4q1GGq86k5xmd9WJ30R3i6px1Yv_big.jpg'),
(47866, 3289, 'Círculo de Fogo: The Black S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178692.mp4', 'http://gstaticontent.com/images/4q1GGq86k5xmd9WJ30R3i6px1Yv_big.jpg'),
(47867, 3289, 'Círculo de Fogo: The Black S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178693.mp4', 'http://gstaticontent.com/images/4q1GGq86k5xmd9WJ30R3i6px1Yv_big.jpg'),
(47868, 3289, 'Círculo de Fogo: The Black S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178694.mp4', 'http://gstaticontent.com/images/4q1GGq86k5xmd9WJ30R3i6px1Yv_big.jpg'),
(47869, 3290, 'Círculo de Fogo: The Black S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178695.mp4', 'http://timg.bdta.pro/images/627def0d5978bf12da3d058c1962040b.jpg'),
(47870, 3290, 'Círculo de Fogo: The Black S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178696.mp4', 'http://timg.bdta.pro/images/e0aac86d8644cf4b7ff2bbd03a4d4072.jpg'),
(47871, 3290, 'Círculo de Fogo: The Black S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178697.mp4', 'http://timg.bdta.pro/images/ad23b1705a5986ed6466252ed15f60be.jpg'),
(47872, 3290, 'Círculo de Fogo: The Black S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178698.mp4', 'http://timg.bdta.pro/images/4654a65664873194956888ac14b5f7e4.jpg'),
(47873, 3290, 'Círculo de Fogo: The Black S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178699.mp4', 'http://timg.bdta.pro/images/ef093723c59e8bc7215073a6052ec1a1.jpg'),
(47874, 3290, 'Círculo de Fogo: The Black S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178700.mp4', 'http://timg.bdta.pro/images/5071afd21be6e0cc9e20065940336f9c.jpg'),
(47875, 3290, 'Círculo de Fogo: The Black S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178701.mp4', 'http://timg.bdta.pro/images/16be1478fa8e512aa5d7e5b5ab7b3dd2.jpg'),
(47876, 3291, 'Falcão e o Soldado Invernal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144875.mp4', 'http://gstaticontent.com/images/w8Hi3GI4q1oR6EImrDWrAQFn8Ha_big.jpg'),
(47877, 3291, 'Falcão e o Soldado Invernal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144876.mp4', 'http://gstaticontent.com/images/w8Hi3GI4q1oR6EImrDWrAQFn8Ha_big.jpg'),
(47878, 3291, 'Falcão e o Soldado Invernal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144877.mp4', 'http://gstaticontent.com/images/w8Hi3GI4q1oR6EImrDWrAQFn8Ha_big.jpg'),
(47879, 3291, 'Falcão e o Soldado Invernal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144878.mp4', 'http://gstaticontent.com/images/w8Hi3GI4q1oR6EImrDWrAQFn8Ha_big.jpg'),
(47880, 3291, 'Falcão e o Soldado Invernal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144879.mp4', 'http://gstaticontent.com/images/w8Hi3GI4q1oR6EImrDWrAQFn8Ha_big.jpg'),
(47881, 3291, 'Falcão e o Soldado Invernal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144880.mp4', 'http://gstaticontent.com/images/w8Hi3GI4q1oR6EImrDWrAQFn8Ha_big.jpg'),
(47882, 3292, 'City on a Hill S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195711.mp4', 'http://gstaticontent.com/images/gkapQgvgf9kH7VTr0dicsIRLoi_big.jpg'),
(47883, 3292, 'City on a Hill S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195712.mp4', 'http://gstaticontent.com/images/gkapQgvgf9kH7VTr0dicsIRLoi_big.jpg'),
(47884, 3292, 'City on a Hill S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195713.mp4', 'http://gstaticontent.com/images/gkapQgvgf9kH7VTr0dicsIRLoi_big.jpg'),
(47885, 3292, 'City on a Hill S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195714.mp4', 'http://gstaticontent.com/images/gkapQgvgf9kH7VTr0dicsIRLoi_big.jpg'),
(47886, 3292, 'City on a Hill S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195715.mp4', 'http://gstaticontent.com/images/gkapQgvgf9kH7VTr0dicsIRLoi_big.jpg'),
(47887, 3292, 'City on a Hill S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195716.mp4', 'http://gstaticontent.com/images/gkapQgvgf9kH7VTr0dicsIRLoi_big.jpg'),
(47888, 3292, 'City on a Hill S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195717.mp4', 'http://gstaticontent.com/images/gkapQgvgf9kH7VTr0dicsIRLoi_big.jpg'),
(47889, 3292, 'City on a Hill S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195718.mp4', 'http://gstaticontent.com/images/gkapQgvgf9kH7VTr0dicsIRLoi_big.jpg'),
(47890, 3292, 'City on a Hill S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195719.mp4', 'http://gstaticontent.com/images/gkapQgvgf9kH7VTr0dicsIRLoi_big.jpg'),
(47891, 3292, 'City on a Hill S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195720.mp4', 'http://gstaticontent.com/images/gkapQgvgf9kH7VTr0dicsIRLoi_big.jpg'),
(47892, 3293, 'City on a Hill S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDHaBZFY6BPV9I4G8iDNFw2l6hi.jpg'),
(47893, 3293, 'City on a Hill S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4S6B9cDIddLiiTuwwNI4BhB5Aiy.jpg'),
(47894, 3293, 'City on a Hill S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y5IEtC7gnoPXJPBzNX7wE2Lia5y.jpg'),
(47895, 3293, 'City on a Hill S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7i8FAD0SNrUeezHFXmREqnso3nV.jpg'),
(47896, 3293, 'City on a Hill S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xszxEhbToyEMd2ZgcsLlMXl70uj.jpg'),
(47897, 3293, 'City on a Hill S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pOE74FXWrxYZYgu6U5cJns65IYe.jpg'),
(47898, 3293, 'City on a Hill S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6QId1w8Rm2ox1z4lXB4w9iFy6ZE.jpg'),
(47899, 3293, 'City on a Hill S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/peTaH8XaFdRYg5oGH3q3N4k2g2E.jpg'),
(47900, 3294, 'City on a Hill S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195729.mp4', 'http://timg.bdta.pro/images/f50172b43ad91136b9f2f6e4dee53cea.jpg'),
(47901, 3294, 'City on a Hill S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195730.mp4', 'http://timg.bdta.pro/images/7070318ea6fe921955e5a734977d7749.jpg'),
(47902, 3294, 'City on a Hill S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195731.mp4', 'http://timg.bdta.pro/images/e30b8d3b407eea4878abd1e8ac9d5888.jpg'),
(47903, 3294, 'City on a Hill S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195732.mp4', 'http://timg.bdta.pro/images/c7cbdf70a22474644891da886d214de0.jpg'),
(47904, 3294, 'City on a Hill S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195733.mp4', 'http://timg.bdta.pro/images/0572874b4709011a5d4aecf43ede1ce2.jpg'),
(47905, 3294, 'City on a Hill S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195734.mp4', 'http://timg.bdta.pro/images/2341a2234a95d40402189307ecedc11f.jpg'),
(47906, 3294, 'City on a Hill S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195735.mp4', 'http://timg.bdta.pro/images/40920bff6a8657239531de4087ec5c1e.jpg'),
(47907, 3294, 'City on a Hill S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195736.mp4', 'http://timg.bdta.pro/images/a21e7ec5401087aef1c5c9b9888f707c.jpg'),
(47908, 3295, 'Defiance S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139636.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47909, 3295, 'Defiance S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139637.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47910, 3295, 'Defiance S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139638.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47911, 3295, 'Defiance S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139639.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47912, 3295, 'Defiance S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139640.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47913, 3295, 'Defiance S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139641.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47914, 3295, 'Defiance S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139642.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47915, 3295, 'Defiance S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139643.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47916, 3295, 'Defiance S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139644.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47917, 3295, 'Defiance S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139645.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47918, 3295, 'Defiance S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139646.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47919, 3295, 'Defiance S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139647.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47920, 3295, 'Defiance S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139648.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47921, 3296, 'Defiance S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139649.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47922, 3296, 'Defiance S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139650.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47923, 3296, 'Defiance S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139651.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47924, 3296, 'Defiance S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139652.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47925, 3296, 'Defiance S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139653.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47926, 3296, 'Defiance S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139654.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47927, 3296, 'Defiance S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139655.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47928, 3296, 'Defiance S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139656.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47929, 3296, 'Defiance S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139657.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47930, 3296, 'Defiance S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139658.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47931, 3296, 'Defiance S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139659.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47932, 3296, 'Defiance S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139660.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47933, 3296, 'Defiance S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139661.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47934, 3297, 'Defiance S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139662.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47935, 3297, 'Defiance S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139663.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47936, 3297, 'Defiance S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139664.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47937, 3297, 'Defiance S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139665.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47938, 3297, 'Defiance S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139666.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47939, 3297, 'Defiance S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139667.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47940, 3297, 'Defiance S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139668.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47941, 3297, 'Defiance S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139669.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47942, 3297, 'Defiance S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139670.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47943, 3297, 'Defiance S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139671.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47944, 3297, 'Defiance S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139672.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47945, 3297, 'Defiance S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139673.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47946, 3298, 'Dra Cathy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139674.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47947, 3298, 'Dra Cathy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139675.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47948, 3298, 'Dra Cathy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139676.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47949, 3298, 'Dra Cathy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139677.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47950, 3298, 'Dra Cathy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139678.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47951, 3298, 'Dra Cathy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139679.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47952, 3298, 'Dra Cathy S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139680.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47953, 3298, 'Dra Cathy S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139681.mp4', 'http://gstaticontent.com/images/1LnkD9QZWo2dPoB82f8jyRk9ukh_big.jpg'),
(47954, 3299, 'Heroes [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139682.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(47955, 3299, 'Heroes [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139683.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47956, 3299, 'Heroes [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139684.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47957, 3299, 'Heroes [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139685.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47958, 3299, 'Heroes [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139686.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47959, 3299, 'Heroes [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139687.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47960, 3299, 'Heroes [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139688.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47961, 3299, 'Heroes [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139689.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47962, 3299, 'Heroes [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139690.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47963, 3299, 'Heroes [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139691.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47964, 3299, 'Heroes [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139692.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47965, 3299, 'Heroes [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139693.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47966, 3299, 'Heroes [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139694.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47967, 3299, 'Heroes [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139695.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47968, 3299, 'Heroes [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139696.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47969, 3299, 'Heroes [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139697.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47970, 3299, 'Heroes [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/139698.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47971, 3299, 'Heroes [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/139699.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47972, 3299, 'Heroes [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/139700.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47973, 3299, 'Heroes [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/139701.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47974, 3299, 'Heroes [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/139702.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47975, 3299, 'Heroes [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/139703.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47976, 3299, 'Heroes [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/139704.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47977, 3299, 'Heroes [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/139705.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47978, 3299, 'Heroes [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/139706.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47979, 3299, 'Heroes [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/139707.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47980, 3299, 'Heroes [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/139708.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47981, 3299, 'Heroes [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/139709.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47982, 3299, 'Heroes [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/139710.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47983, 3299, 'Heroes [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/139711.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47984, 3299, 'Heroes [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/139712.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47985, 3299, 'Heroes [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/139713.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47986, 3299, 'Heroes [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/139714.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47987, 3299, 'Heroes [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/139715.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47988, 3299, 'Heroes [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/139716.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47989, 3299, 'Heroes [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/139717.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47990, 3299, 'Heroes [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/139718.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47991, 3299, 'Heroes [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/139719.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47992, 3299, 'Heroes [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/139720.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47993, 3299, 'Heroes [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/139721.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47994, 3299, 'Heroes [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/139722.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47995, 3299, 'Heroes [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/139723.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47996, 3299, 'Heroes [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/139724.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47997, 3299, 'Heroes [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/139725.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47998, 3299, 'Heroes [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/139726.mp4', 'http://gstaticontent.com/images/4lomPwB88OgPfcNJiqc4LstVWRa_big.jpg'),
(47999, 3300, 'Houdini S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139727.mp4', 'http://gstaticontent.com/images/ba43f5KXfH01ipDmDR4lZSQyDkL_big.jpg'),
(48000, 3300, 'Houdini S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139728.mp4', 'http://gstaticontent.com/images/ba43f5KXfH01ipDmDR4lZSQyDkL_big.jpg'),
(48001, 3301, 'Ingovernável S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139729.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48002, 3301, 'Ingovernável S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139730.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48003, 3301, 'Ingovernável S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139731.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48004, 3301, 'Ingovernável S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139732.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48005, 3301, 'Ingovernável S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139733.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48006, 3301, 'Ingovernável S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139734.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48007, 3301, 'Ingovernável S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139735.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48008, 3301, 'Ingovernável S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139736.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48009, 3301, 'Ingovernável S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139737.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48010, 3301, 'Ingovernável S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139738.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48011, 3301, 'Ingovernável S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139739.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48012, 3301, 'Ingovernável S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139740.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48013, 3301, 'Ingovernável S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139741.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48014, 3301, 'Ingovernável S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139742.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48015, 3301, 'Ingovernável S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139743.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48016, 3302, 'Ingovernável S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139744.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48017, 3302, 'Ingovernável S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139745.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48018, 3302, 'Ingovernável S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139746.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48019, 3302, 'Ingovernável S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139747.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48020, 3302, 'Ingovernável S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139748.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48021, 3302, 'Ingovernável S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139749.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48022, 3302, 'Ingovernável S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139750.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48023, 3302, 'Ingovernável S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139751.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48024, 3302, 'Ingovernável S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139752.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48025, 3302, 'Ingovernável S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139753.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48026, 3302, 'Ingovernável S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139754.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48027, 3302, 'Ingovernável S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139755.mp4', 'http://gstaticontent.com/images/mREc0h6fpGRQ3OEfiWqD9TfudaC_big.jpg'),
(48028, 3303, 'O Fantástico Jaspion S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139756.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48029, 3303, 'O Fantástico Jaspion S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139757.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48030, 3303, 'O Fantástico Jaspion S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139758.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48031, 3303, 'O Fantástico Jaspion S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139759.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48032, 3303, 'O Fantástico Jaspion S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139760.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48033, 3303, 'O Fantástico Jaspion S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139761.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48034, 3303, 'O Fantástico Jaspion S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139762.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48035, 3303, 'O Fantástico Jaspion S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139763.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48036, 3303, 'O Fantástico Jaspion S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139764.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48037, 3303, 'O Fantástico Jaspion S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139765.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48038, 3303, 'O Fantástico Jaspion S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139766.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48039, 3303, 'O Fantástico Jaspion S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139767.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48040, 3303, 'O Fantástico Jaspion S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139768.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48041, 3303, 'O Fantástico Jaspion S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139769.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48042, 3303, 'O Fantástico Jaspion S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139770.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48043, 3303, 'O Fantástico Jaspion S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139771.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48044, 3303, 'O Fantástico Jaspion S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/139772.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48045, 3303, 'O Fantástico Jaspion S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/139773.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48046, 3303, 'O Fantástico Jaspion S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/139774.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48047, 3303, 'O Fantástico Jaspion S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/139775.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48048, 3303, 'O Fantástico Jaspion S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/139776.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48049, 3303, 'O Fantástico Jaspion S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/139777.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48050, 3303, 'O Fantástico Jaspion S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/139778.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48051, 3303, 'O Fantástico Jaspion S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/139779.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48052, 3303, 'O Fantástico Jaspion S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/139780.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48053, 3303, 'O Fantástico Jaspion S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/139781.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48054, 3303, 'O Fantástico Jaspion S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/139782.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48055, 3303, 'O Fantástico Jaspion S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/139783.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48056, 3303, 'O Fantástico Jaspion S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/139784.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48057, 3303, 'O Fantástico Jaspion S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/139785.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48058, 3303, 'O Fantástico Jaspion S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/139786.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48059, 3303, 'O Fantástico Jaspion S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/139787.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48060, 3303, 'O Fantástico Jaspion S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/139788.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48061, 3303, 'O Fantástico Jaspion S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/139789.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48062, 3303, 'O Fantástico Jaspion S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/139790.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48063, 3303, 'O Fantástico Jaspion S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/139791.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48064, 3303, 'O Fantástico Jaspion S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/139792.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48065, 3303, 'O Fantástico Jaspion S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/139793.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48066, 3303, 'O Fantástico Jaspion S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/139794.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48067, 3303, 'O Fantástico Jaspion S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/139795.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48068, 3303, 'O Fantástico Jaspion S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/139796.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48069, 3303, 'O Fantástico Jaspion S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/139797.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48070, 3303, 'O Fantástico Jaspion S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/139798.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48071, 3303, 'O Fantástico Jaspion S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/139799.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48072, 3303, 'O Fantástico Jaspion S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/139800.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48073, 3303, 'O Fantástico Jaspion S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/139801.mp4', 'http://gstaticontent.com/images/Ab0CmiyA83TSZsMDzVNg7mZs3mm_big.jpg'),
(48074, 3304, 'Kenan e Kel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205847.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48075, 3304, 'Kenan e Kel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205848.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48076, 3304, 'Kenan e Kel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205849.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48077, 3304, 'Kenan e Kel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205850.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48078, 3304, 'Kenan e Kel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205851.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48079, 3304, 'Kenan e Kel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205852.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48080, 3304, 'Kenan e Kel S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205853.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48081, 3304, 'Kenan e Kel S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205854.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48082, 3304, 'Kenan e Kel S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205855.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48083, 3304, 'Kenan e Kel S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205856.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48084, 3304, 'Kenan e Kel S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205857.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48085, 3304, 'Kenan e Kel S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205858.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48086, 3304, 'Kenan e Kel S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205859.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48087, 3304, 'Kenan e Kel S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/205860.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48088, 3305, 'Kenan e Kel S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205861.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48089, 3305, 'Kenan e Kel S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205862.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48090, 3305, 'Kenan e Kel S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205863.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48091, 3305, 'Kenan e Kel S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205864.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48092, 3305, 'Kenan e Kel S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205865.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48093, 3305, 'Kenan e Kel S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205866.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48094, 3305, 'Kenan e Kel S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205867.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48095, 3305, 'Kenan e Kel S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205868.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48096, 3305, 'Kenan e Kel S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205869.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48097, 3305, 'Kenan e Kel S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205870.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48098, 3305, 'Kenan e Kel S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205871.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48099, 3305, 'Kenan e Kel S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205872.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48100, 3305, 'Kenan e Kel S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205873.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48101, 3306, 'Kenan e Kel S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205874.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48102, 3306, 'Kenan e Kel S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205875.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48103, 3306, 'Kenan e Kel S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205876.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48104, 3306, 'Kenan e Kel S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205877.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48105, 3306, 'Kenan e Kel S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205878.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48106, 3306, 'Kenan e Kel S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205879.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48107, 3306, 'Kenan e Kel S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205880.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48108, 3306, 'Kenan e Kel S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205881.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48109, 3306, 'Kenan e Kel S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205882.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48110, 3306, 'Kenan e Kel S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205883.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48111, 3306, 'Kenan e Kel S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205884.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48112, 3306, 'Kenan e Kel S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205885.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48113, 3306, 'Kenan e Kel S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205886.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48114, 3306, 'Kenan e Kel S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/205887.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48115, 3306, 'Kenan e Kel S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/205888.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48116, 3306, 'Kenan e Kel S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/205889.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48117, 3306, 'Kenan e Kel S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/205890.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48118, 3306, 'Kenan e Kel S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/205891.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48119, 3306, 'Kenan e Kel S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/205892.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48120, 3306, 'Kenan e Kel S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/205893.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48121, 3306, 'Kenan e Kel S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/205894.mp4', 'http://gstaticontent.com/images/pOkJ92Kp0MW5BhnGbbH0p3Rn1J_big.jpg'),
(48122, 3307, 'Kenan e Kel S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zin07EwixDjBNvooFrGKNo9DN22.jpg'),
(48123, 3307, 'Kenan e Kel S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l0aUTJPh8pfNG6Tt4S1dpDlv45c.jpg'),
(48124, 3307, 'Kenan e Kel S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e5U7IBL2C0AYbS46OadmApKrLXw.jpg'),
(48125, 3307, 'Kenan e Kel S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dC6ozJhgPNa9kh50SjTq3zZ6Js7.jpg'),
(48126, 3307, 'Kenan e Kel S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iRg5VQdb02gDeOnXprJjUShQrLd.jpg'),
(48127, 3307, 'Kenan e Kel S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLTIma24DCSurvp2wafgOpMNaY7.jpg'),
(48128, 3307, 'Kenan e Kel S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bYJuL78hzyhkzPfS13B7Sf0yHK5.jpg'),
(48129, 3307, 'Kenan e Kel S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eBJ8tukRMPj72SZUoi9yAS0C5SG.jpg'),
(48130, 3307, 'Kenan e Kel S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhQlJ7EIbyWTdLnfXEkcFzTDFBO.jpg'),
(48131, 3307, 'Kenan e Kel S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtscFr0Pc0vx1B4Exa2NQBYEIts.jpg'),
(48132, 3307, 'Kenan e Kel S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cWSgwwUOGpKKdJ8hvuDO5UrVRGH.jpg'),
(48133, 3307, 'Kenan e Kel S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uXQTOBf62tRlcvqX2LpgvMIJCVr.jpg'),
(48134, 3308, 'Kick Buttowski: Um Projeto de Dublê S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139802.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48135, 3308, 'Kick Buttowski: Um Projeto de Dublê S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139803.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48136, 3308, 'Kick Buttowski: Um Projeto de Dublê S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139804.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48137, 3308, 'Kick Buttowski: Um Projeto de Dublê S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139805.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48138, 3308, 'Kick Buttowski: Um Projeto de Dublê S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139806.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48139, 3308, 'Kick Buttowski: Um Projeto de Dublê S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139807.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48140, 3308, 'Kick Buttowski: Um Projeto de Dublê S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139808.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48141, 3308, 'Kick Buttowski: Um Projeto de Dublê S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139809.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48142, 3308, 'Kick Buttowski: Um Projeto de Dublê S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139810.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48143, 3308, 'Kick Buttowski: Um Projeto de Dublê S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139811.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48144, 3308, 'Kick Buttowski: Um Projeto de Dublê S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139812.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48145, 3308, 'Kick Buttowski: Um Projeto de Dublê S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139813.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48146, 3308, 'Kick Buttowski: Um Projeto de Dublê S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139814.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48147, 3308, 'Kick Buttowski: Um Projeto de Dublê S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139815.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48148, 3308, 'Kick Buttowski: Um Projeto de Dublê S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139816.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48149, 3308, 'Kick Buttowski: Um Projeto de Dublê S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139817.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48150, 3308, 'Kick Buttowski: Um Projeto de Dublê S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/139818.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48151, 3308, 'Kick Buttowski: Um Projeto de Dublê S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/139819.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48152, 3308, 'Kick Buttowski: Um Projeto de Dublê S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/139820.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48153, 3308, 'Kick Buttowski: Um Projeto de Dublê S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/139821.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48154, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139822.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48155, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139823.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48156, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139824.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48157, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139825.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48158, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139826.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48159, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139827.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48160, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139828.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48161, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139829.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48162, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139830.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48163, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139831.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48164, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139832.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48165, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139833.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48166, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139834.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48167, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139835.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48168, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139836.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48169, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139837.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48170, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/139838.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48171, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/139839.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48172, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/139840.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48173, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/139841.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48174, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/139842.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48175, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/139843.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48176, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/139844.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48177, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/139845.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48178, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/139846.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48179, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/139847.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48180, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/139848.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48181, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/139849.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48182, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/139850.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48183, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/139851.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48184, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/139852.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48185, 3309, 'Kick Buttowski: Um Projeto de Dublê S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/139853.mp4', 'http://gstaticontent.com/images/fkkpMA6EBCxwVP7niDeJVlRACp3_big.jpg'),
(48186, 3310, 'Kim Possible S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139854.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48187, 3310, 'Kim Possible S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139855.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48188, 3310, 'Kim Possible S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139856.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48189, 3310, 'Kim Possible S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139857.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48190, 3310, 'Kim Possible S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139858.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48191, 3310, 'Kim Possible S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139859.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48192, 3310, 'Kim Possible S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139860.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48193, 3310, 'Kim Possible S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139861.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48194, 3310, 'Kim Possible S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139862.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48195, 3310, 'Kim Possible S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139863.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48196, 3310, 'Kim Possible S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139864.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48197, 3310, 'Kim Possible S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139865.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48198, 3310, 'Kim Possible S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139866.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48199, 3310, 'Kim Possible S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139867.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48200, 3310, 'Kim Possible S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139868.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48201, 3310, 'Kim Possible S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139869.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48202, 3310, 'Kim Possible S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/139870.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48203, 3310, 'Kim Possible S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/139871.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48204, 3310, 'Kim Possible S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/139872.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48205, 3310, 'Kim Possible S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/139873.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48206, 3310, 'Kim Possible S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/139874.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48207, 3311, 'Kim Possible S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139875.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48208, 3311, 'Kim Possible S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139876.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48209, 3311, 'Kim Possible S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139877.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48210, 3311, 'Kim Possible S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139878.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48211, 3311, 'Kim Possible S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139879.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48212, 3311, 'Kim Possible S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139880.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48213, 3311, 'Kim Possible S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139881.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48214, 3311, 'Kim Possible S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139882.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48215, 3311, 'Kim Possible S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139883.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48216, 3311, 'Kim Possible S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139884.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48217, 3311, 'Kim Possible S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139885.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48218, 3311, 'Kim Possible S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139886.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48219, 3311, 'Kim Possible S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139887.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48220, 3311, 'Kim Possible S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139888.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48221, 3311, 'Kim Possible S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139889.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48222, 3311, 'Kim Possible S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139890.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48223, 3311, 'Kim Possible S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/139891.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48224, 3311, 'Kim Possible S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/139892.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48225, 3311, 'Kim Possible S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/139893.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48226, 3311, 'Kim Possible S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/139894.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48227, 3311, 'Kim Possible S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/139895.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48228, 3311, 'Kim Possible S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/139896.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48229, 3311, 'Kim Possible S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/139897.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48230, 3311, 'Kim Possible S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/139898.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48231, 3311, 'Kim Possible S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/139899.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48232, 3311, 'Kim Possible S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/139900.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48233, 3311, 'Kim Possible S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/139901.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(48234, 3312, 'Kim Possible S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139902.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48235, 3312, 'Kim Possible S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139903.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48236, 3312, 'Kim Possible S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139904.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48237, 3312, 'Kim Possible S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139905.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48238, 3312, 'Kim Possible S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139906.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48239, 3312, 'Kim Possible S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139907.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48240, 3312, 'Kim Possible S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139908.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48241, 3312, 'Kim Possible S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139909.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48242, 3312, 'Kim Possible S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139910.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48243, 3312, 'Kim Possible S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139911.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48244, 3312, 'Kim Possible S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139912.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48245, 3313, 'Kim Possible S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139913.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48246, 3313, 'Kim Possible S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139914.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48247, 3313, 'Kim Possible S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139915.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48248, 3313, 'Kim Possible S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139916.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48249, 3313, 'Kim Possible S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139917.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48250, 3313, 'Kim Possible S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139918.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48251, 3313, 'Kim Possible S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139919.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48252, 3313, 'Kim Possible S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139920.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48253, 3313, 'Kim Possible S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139921.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48254, 3313, 'Kim Possible S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139922.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48255, 3313, 'Kim Possible S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139923.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48256, 3313, 'Kim Possible S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139924.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48257, 3313, 'Kim Possible S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139925.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48258, 3313, 'Kim Possible S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139926.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48259, 3313, 'Kim Possible S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139927.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48260, 3313, 'Kim Possible S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139928.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48261, 3313, 'Kim Possible S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/139929.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48262, 3313, 'Kim Possible S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/139930.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48263, 3313, 'Kim Possible S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/139931.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48264, 3313, 'Kim Possible S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/139932.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48265, 3313, 'Kim Possible S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/139933.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48266, 3313, 'Kim Possible S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/139934.mp4', 'http://gstaticontent.com/images/qpu7pwpafHh75bqW0driyihht4c_big.jpg'),
(48267, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139935.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48268, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139936.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48269, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139937.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48270, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139938.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48271, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139939.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48272, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139940.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48273, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139941.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48274, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139942.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48275, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139943.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48276, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139944.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48277, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139945.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48278, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139946.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48279, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139947.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48280, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139948.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48281, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139949.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48282, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139950.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48283, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/139951.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48284, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/139952.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48285, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/139953.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48286, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/139954.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48287, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/139955.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48288, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/139956.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48289, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/139957.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48290, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/139958.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48291, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/139959.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48292, 3314, 'Kung Fu Panda: Lendas do Dragão Guerreiro S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/139960.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48293, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139961.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48294, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139962.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48295, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139963.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48296, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139964.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48297, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139965.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48298, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139966.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48299, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139967.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48300, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139968.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48301, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139969.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48302, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139970.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48303, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139971.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48304, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139972.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48305, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139973.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48306, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139974.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48307, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139975.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48308, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139976.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48309, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/139977.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48310, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/139978.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48311, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/139979.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48312, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/139980.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48313, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/139981.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48314, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/139982.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48315, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/139983.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48316, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/139984.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48317, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/139985.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48318, 3315, 'Kung Fu Panda: Lendas do Dragão Guerreiro S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/139986.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48319, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139987.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48320, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139988.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48321, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139989.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48322, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139990.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48323, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139991.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48324, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139992.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48325, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139993.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48326, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139994.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48327, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139995.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48328, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139996.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48329, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139997.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48330, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139998.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48331, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139999.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48332, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/140000.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48333, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/140001.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48334, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/140002.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48335, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/140003.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48336, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/140004.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48337, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/140005.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48338, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/140006.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48339, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/140007.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48340, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/140008.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48341, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/140009.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48342, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/140010.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48343, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/140011.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48344, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/140012.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48345, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/140013.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48346, 3316, 'Kung Fu Panda: Lendas do Dragão Guerreiro S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/140014.mp4', 'http://gstaticontent.com/images/d5aLq6TJYNoEXsGEbGop0g0rFm0_big.jpg'),
(48347, 3317, 'Mucha Lucha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140015.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48348, 3317, 'Mucha Lucha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140016.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48349, 3317, 'Mucha Lucha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140017.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48350, 3317, 'Mucha Lucha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140018.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48351, 3317, 'Mucha Lucha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140019.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48352, 3317, 'Mucha Lucha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140020.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48353, 3317, 'Mucha Lucha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140021.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48354, 3317, 'Mucha Lucha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140022.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48355, 3317, 'Mucha Lucha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140023.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48356, 3317, 'Mucha Lucha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140024.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48357, 3317, 'Mucha Lucha S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140025.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48358, 3317, 'Mucha Lucha S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140026.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48359, 3317, 'Mucha Lucha S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140027.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48360, 3318, 'Mucha Lucha S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140028.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48361, 3318, 'Mucha Lucha S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140029.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48362, 3318, 'Mucha Lucha S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140030.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48363, 3318, 'Mucha Lucha S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140031.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48364, 3318, 'Mucha Lucha S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140032.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48365, 3318, 'Mucha Lucha S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140033.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48366, 3318, 'Mucha Lucha S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140034.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48367, 3318, 'Mucha Lucha S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140035.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48368, 3318, 'Mucha Lucha S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140036.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48369, 3318, 'Mucha Lucha S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140037.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48370, 3318, 'Mucha Lucha S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140038.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48371, 3318, 'Mucha Lucha S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140039.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48372, 3318, 'Mucha Lucha S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140040.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48373, 3318, 'Mucha Lucha S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/140041.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48374, 3318, 'Mucha Lucha S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/140042.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48375, 3318, 'Mucha Lucha S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/140043.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48376, 3318, 'Mucha Lucha S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/140044.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48377, 3318, 'Mucha Lucha S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/140045.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48378, 3318, 'Mucha Lucha S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/140046.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48379, 3318, 'Mucha Lucha S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/140047.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48380, 3318, 'Mucha Lucha S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/140048.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48381, 3318, 'Mucha Lucha S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/140049.mp4', 'http://gstaticontent.com/images/nr25FdNl4RGguNj57SW8vB7Eihy_big.jpg'),
(48382, 3319, 'O Reino Perdido dos Piratas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140050.mp4', 'http://gstaticontent.com/images/gQZpVysbT5FGYVYrsjuwQa2XIay_big.jpg'),
(48383, 3319, 'O Reino Perdido dos Piratas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140051.mp4', 'http://gstaticontent.com/images/gQZpVysbT5FGYVYrsjuwQa2XIay_big.jpg'),
(48384, 3319, 'O Reino Perdido dos Piratas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140052.mp4', 'http://gstaticontent.com/images/gQZpVysbT5FGYVYrsjuwQa2XIay_big.jpg'),
(48385, 3319, 'O Reino Perdido dos Piratas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140053.mp4', 'http://gstaticontent.com/images/gQZpVysbT5FGYVYrsjuwQa2XIay_big.jpg'),
(48386, 3319, 'O Reino Perdido dos Piratas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140054.mp4', 'http://gstaticontent.com/images/gQZpVysbT5FGYVYrsjuwQa2XIay_big.jpg'),
(48387, 3319, 'O Reino Perdido dos Piratas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140055.mp4', 'http://gstaticontent.com/images/gQZpVysbT5FGYVYrsjuwQa2XIay_big.jpg'),
(48388, 3320, 'O Último Cara da Terra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140056.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48389, 3320, 'O Último Cara da Terra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140057.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48390, 3320, 'O Último Cara da Terra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140058.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48391, 3320, 'O Último Cara da Terra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140059.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48392, 3320, 'O Último Cara da Terra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140060.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48393, 3320, 'O Último Cara da Terra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140061.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48394, 3320, 'O Último Cara da Terra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140062.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48395, 3320, 'O Último Cara da Terra S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140063.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48396, 3320, 'O Último Cara da Terra S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140064.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48397, 3320, 'O Último Cara da Terra S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140065.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48398, 3320, 'O Último Cara da Terra S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140066.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48399, 3320, 'O Último Cara da Terra S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140067.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48400, 3321, 'O Último Cara da Terra S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140068.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48401, 3321, 'O Último Cara da Terra S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140069.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48402, 3321, 'O Último Cara da Terra S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140070.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48403, 3321, 'O Último Cara da Terra S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140071.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48404, 3321, 'O Último Cara da Terra S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140072.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48405, 3321, 'O Último Cara da Terra S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140073.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48406, 3321, 'O Último Cara da Terra S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140074.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48407, 3321, 'O Último Cara da Terra S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140075.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48408, 3321, 'O Último Cara da Terra S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140076.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48409, 3321, 'O Último Cara da Terra S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140077.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48410, 3321, 'O Último Cara da Terra S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140078.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48411, 3321, 'O Último Cara da Terra S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140079.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48412, 3321, 'O Último Cara da Terra S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140080.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48413, 3321, 'O Último Cara da Terra S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/140081.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48414, 3321, 'O Último Cara da Terra S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/140082.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48415, 3321, 'O Último Cara da Terra S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/140083.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48416, 3321, 'O Último Cara da Terra S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/140084.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48417, 3321, 'O Último Cara da Terra S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/140085.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48418, 3322, 'O Último Cara da Terra S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140086.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48419, 3322, 'O Último Cara da Terra S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140087.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48420, 3322, 'O Último Cara da Terra S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140088.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48421, 3322, 'O Último Cara da Terra S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140089.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48422, 3322, 'O Último Cara da Terra S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140090.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48423, 3322, 'O Último Cara da Terra S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140091.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48424, 3322, 'O Último Cara da Terra S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140092.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48425, 3322, 'O Último Cara da Terra S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140093.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48426, 3322, 'O Último Cara da Terra S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140094.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48427, 3322, 'O Último Cara da Terra S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140095.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48428, 3322, 'O Último Cara da Terra S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140096.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48429, 3322, 'O Último Cara da Terra S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140097.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48430, 3322, 'O Último Cara da Terra S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140098.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48431, 3322, 'O Último Cara da Terra S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/140099.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48432, 3322, 'O Último Cara da Terra S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/140100.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48433, 3322, 'O Último Cara da Terra S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/140101.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48434, 3322, 'O Último Cara da Terra S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/140102.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48435, 3322, 'O Último Cara da Terra S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/140103.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48436, 3323, 'O Último Cara da Terra S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140104.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48437, 3323, 'O Último Cara da Terra S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140105.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48438, 3323, 'O Último Cara da Terra S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140106.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48439, 3323, 'O Último Cara da Terra S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140107.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48440, 3323, 'O Último Cara da Terra S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140108.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48441, 3323, 'O Último Cara da Terra S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140109.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48442, 3323, 'O Último Cara da Terra S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140110.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48443, 3323, 'O Último Cara da Terra S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140111.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48444, 3323, 'O Último Cara da Terra S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140112.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48445, 3323, 'O Último Cara da Terra S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140113.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48446, 3323, 'O Último Cara da Terra S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140114.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48447, 3323, 'O Último Cara da Terra S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140115.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48448, 3323, 'O Último Cara da Terra S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140116.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48449, 3323, 'O Último Cara da Terra S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/140117.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48450, 3323, 'O Último Cara da Terra S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/140118.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48451, 3323, 'O Último Cara da Terra S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/140119.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48452, 3323, 'O Último Cara da Terra S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/140120.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48453, 3323, 'O Último Cara da Terra S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/140121.mp4', 'http://gstaticontent.com/images/5my7rGdrjukKhsx5t32BRUBTTzt_big.jpg'),
(48454, 3324, 'Oz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140122.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48455, 3324, 'Oz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140123.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48456, 3324, 'Oz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140124.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48457, 3324, 'Oz S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140125.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48458, 3324, 'Oz S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140126.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48459, 3324, 'Oz S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140127.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48460, 3324, 'Oz S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140128.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48461, 3324, 'Oz S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140129.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48462, 3325, 'Oz S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140130.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48463, 3325, 'Oz S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140131.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48464, 3325, 'Oz S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140132.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48465, 3325, 'Oz S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140133.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48466, 3325, 'Oz S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140134.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48467, 3325, 'Oz S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140135.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48468, 3325, 'Oz S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140136.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48469, 3325, 'Oz S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140137.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48470, 3326, 'Oz S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140138.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48471, 3326, 'Oz S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140139.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48472, 3326, 'Oz S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140140.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48473, 3326, 'Oz S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140141.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48474, 3326, 'Oz S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140142.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48475, 3326, 'Oz S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140143.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48476, 3326, 'Oz S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140144.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48477, 3326, 'Oz S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140145.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48478, 3327, 'Oz S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140146.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48479, 3327, 'Oz S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140147.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48480, 3327, 'Oz S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140148.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48481, 3327, 'Oz S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140149.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48482, 3327, 'Oz S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140150.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48483, 3327, 'Oz S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140151.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48484, 3327, 'Oz S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140152.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48485, 3327, 'Oz S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140153.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48486, 3327, 'Oz S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140154.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48487, 3327, 'Oz S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140155.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48488, 3327, 'Oz S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140156.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48489, 3327, 'Oz S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140157.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48490, 3327, 'Oz S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140158.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48491, 3327, 'Oz S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/140159.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48492, 3327, 'Oz S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/140160.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48493, 3327, 'Oz S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/140161.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48494, 3328, 'Oz S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140162.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48495, 3328, 'Oz S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140163.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48496, 3328, 'Oz S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140164.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48497, 3328, 'Oz S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140165.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48498, 3328, 'Oz S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140166.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48499, 3328, 'Oz S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140167.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48500, 3328, 'Oz S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140168.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48501, 3328, 'Oz S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140169.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48502, 3329, 'Oz S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140170.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48503, 3329, 'Oz S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140171.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48504, 3329, 'Oz S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140172.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48505, 3329, 'Oz S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140173.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48506, 3329, 'Oz S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140174.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48507, 3329, 'Oz S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140175.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(48508, 3329, 'Oz S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140176.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48509, 3329, 'Oz S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140177.mp4', 'http://gstaticontent.com/images/CwqqwYWnMOLUwsqAqveHNnwTGC_big.jpg'),
(48510, 3330, 'Polos Opostos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140178.mp4', 'http://gstaticontent.com/images/rmPBtMPNBnvKacIb56LgMSdkhGM_big.jpg'),
(48511, 3330, 'Polos Opostos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140179.mp4', 'http://gstaticontent.com/images/rmPBtMPNBnvKacIb56LgMSdkhGM_big.jpg'),
(48512, 3330, 'Polos Opostos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140180.mp4', 'http://gstaticontent.com/images/rmPBtMPNBnvKacIb56LgMSdkhGM_big.jpg'),
(48513, 3330, 'Polos Opostos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140181.mp4', 'http://gstaticontent.com/images/rmPBtMPNBnvKacIb56LgMSdkhGM_big.jpg'),
(48514, 3330, 'Polos Opostos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140182.mp4', 'http://gstaticontent.com/images/rmPBtMPNBnvKacIb56LgMSdkhGM_big.jpg'),
(48515, 3330, 'Polos Opostos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140183.mp4', 'http://gstaticontent.com/images/rmPBtMPNBnvKacIb56LgMSdkhGM_big.jpg'),
(48516, 3330, 'Polos Opostos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140184.mp4', 'http://gstaticontent.com/images/rmPBtMPNBnvKacIb56LgMSdkhGM_big.jpg'),
(48517, 3330, 'Polos Opostos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140185.mp4', 'http://gstaticontent.com/images/rmPBtMPNBnvKacIb56LgMSdkhGM_big.jpg'),
(48518, 3330, 'Polos Opostos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140186.mp4', 'http://gstaticontent.com/images/rmPBtMPNBnvKacIb56LgMSdkhGM_big.jpg'),
(48519, 3330, 'Polos Opostos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140187.mp4', 'http://gstaticontent.com/images/rmPBtMPNBnvKacIb56LgMSdkhGM_big.jpg'),
(48520, 3331, 'The Closer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163649.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48521, 3331, 'The Closer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163650.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48522, 3331, 'The Closer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163651.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48523, 3331, 'The Closer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163652.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48524, 3331, 'The Closer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163653.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48525, 3331, 'The Closer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163654.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48526, 3331, 'The Closer S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163655.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48527, 3331, 'The Closer S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163656.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48528, 3331, 'The Closer S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163657.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48529, 3331, 'The Closer S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163658.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48530, 3331, 'The Closer S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163659.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48531, 3331, 'The Closer S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163660.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48532, 3331, 'The Closer S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163661.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48533, 3332, 'The Closer S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163662.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48534, 3332, 'The Closer S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163663.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48535, 3332, 'The Closer S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163664.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48536, 3332, 'The Closer S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163665.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48537, 3332, 'The Closer S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163666.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48538, 3332, 'The Closer S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163667.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48539, 3332, 'The Closer S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163668.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48540, 3332, 'The Closer S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163669.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48541, 3332, 'The Closer S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163670.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48542, 3332, 'The Closer S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163671.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48543, 3332, 'The Closer S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163672.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48544, 3332, 'The Closer S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163673.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48545, 3332, 'The Closer S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163674.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48546, 3332, 'The Closer S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163675.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48547, 3332, 'The Closer S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163676.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48548, 3333, 'The Closer S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163677.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48549, 3333, 'The Closer S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163678.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48550, 3333, 'The Closer S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163679.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48551, 3333, 'The Closer S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163680.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48552, 3333, 'The Closer S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163681.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48553, 3333, 'The Closer S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163682.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48554, 3333, 'The Closer S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163683.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48555, 3333, 'The Closer S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163684.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48556, 3333, 'The Closer S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163685.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48557, 3333, 'The Closer S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163686.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48558, 3333, 'The Closer S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163687.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48559, 3333, 'The Closer S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163688.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48560, 3333, 'The Closer S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163689.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48561, 3333, 'The Closer S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163690.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48562, 3333, 'The Closer S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163691.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48563, 3334, 'The Closer S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163692.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48564, 3334, 'The Closer S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163693.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48565, 3334, 'The Closer S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163694.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48566, 3334, 'The Closer S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163695.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48567, 3334, 'The Closer S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163696.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48568, 3334, 'The Closer S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163697.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48569, 3334, 'The Closer S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163698.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48570, 3334, 'The Closer S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163699.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48571, 3334, 'The Closer S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163700.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48572, 3334, 'The Closer S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163701.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48573, 3334, 'The Closer S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163702.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48574, 3334, 'The Closer S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163703.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48575, 3334, 'The Closer S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163704.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48576, 3334, 'The Closer S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163705.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48577, 3334, 'The Closer S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163706.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48578, 3335, 'The Closer S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163707.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48579, 3335, 'The Closer S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163708.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48580, 3335, 'The Closer S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163709.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48581, 3335, 'The Closer S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163710.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48582, 3335, 'The Closer S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163711.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48583, 3335, 'The Closer S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163712.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48584, 3335, 'The Closer S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163713.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48585, 3335, 'The Closer S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163714.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48586, 3335, 'The Closer S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163715.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48587, 3335, 'The Closer S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163716.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48588, 3335, 'The Closer S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163717.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48589, 3335, 'The Closer S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163718.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48590, 3335, 'The Closer S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163719.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48591, 3335, 'The Closer S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163720.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48592, 3335, 'The Closer S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163721.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48593, 3336, 'The Closer S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163722.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48594, 3336, 'The Closer S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163723.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48595, 3336, 'The Closer S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163724.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48596, 3336, 'The Closer S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163725.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48597, 3336, 'The Closer S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163726.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48598, 3336, 'The Closer S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163727.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48599, 3336, 'The Closer S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163728.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48600, 3336, 'The Closer S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163729.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48601, 3336, 'The Closer S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163730.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48602, 3336, 'The Closer S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163731.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48603, 3336, 'The Closer S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163732.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48604, 3336, 'The Closer S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163733.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48605, 3336, 'The Closer S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163734.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48606, 3336, 'The Closer S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163735.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48607, 3336, 'The Closer S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163736.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48608, 3337, 'The Closer S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4qIKStQfHQ3KnaqM6g4iGYlxMDK.jpg'),
(48609, 3337, 'The Closer S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ikjVCZq6bCEKDoGizVSDUYixBtl.jpg'),
(48610, 3337, 'The Closer S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163739.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48611, 3337, 'The Closer S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/atOSG1mo6xbm9XAWB8Zprtrp2e4.jpg'),
(48612, 3337, 'The Closer S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j0Y1Hsv3FpFlrXnwAwbXqGYesot.jpg'),
(48613, 3337, 'The Closer S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kAjj4x9DYP1LSb7SfQmkLGC37d7.jpg'),
(48614, 3337, 'The Closer S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kh0Dqab7pnB5f1AwtrmLQxIMGev.jpg'),
(48615, 3337, 'The Closer S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eWMJgX5BYyv1Jvp5wzkjxXccpT2.jpg'),
(48616, 3337, 'The Closer S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vm20c9UdHy8P84WhEfcrkKcFngo.jpg'),
(48617, 3337, 'The Closer S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ppaXsH2VbTQOhA2hJamRwlyN6be.jpg'),
(48618, 3337, 'The Closer S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163747.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48619, 3337, 'The Closer S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQBtEWHqMw1XZ1T1CFzCMFHR8BL.jpg'),
(48620, 3337, 'The Closer S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eXJi4D8zuAlaq7FgxF6yc3Zhn1K.jpg'),
(48621, 3337, 'The Closer S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qV3zFBjxLer3OCDoIDD7QbCrpjN.jpg'),
(48622, 3337, 'The Closer S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iC6xU71OggHBYhe8ooWFdJRriPm.jpg'),
(48623, 3337, 'The Closer S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yA78EBbHg7nyNZWHDXuPLP2k87p.jpg'),
(48624, 3337, 'The Closer S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5knr3vdXQTwmLHLAk6TKZVdWCLL.jpg'),
(48625, 3337, 'The Closer S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163754.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48626, 3337, 'The Closer S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u5gd7iyzT035GK9rNJGTPulKKdG.jpg'),
(48627, 3337, 'The Closer S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/li7yJGpf7gEU9eOcjKkaINEcjjy.jpg'),
(48628, 3337, 'The Closer S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/163757.mp4', 'http://gstaticontent.com/images/c5gkRTLbQnA9M2li2hDmXRfZ0g3_big.jpg'),
(48629, 3338, 'The Gifted S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140188.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48630, 3338, 'The Gifted S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140189.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48631, 3338, 'The Gifted S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140190.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48632, 3338, 'The Gifted S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140191.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48633, 3338, 'The Gifted S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140192.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48634, 3338, 'The Gifted S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140193.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48635, 3338, 'The Gifted S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140194.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48636, 3338, 'The Gifted S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140195.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48637, 3338, 'The Gifted S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140196.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48638, 3338, 'The Gifted S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140197.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48639, 3338, 'The Gifted S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140198.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48640, 3338, 'The Gifted S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140199.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48641, 3339, 'The Gifted S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140200.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48642, 3339, 'The Gifted S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140201.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48643, 3339, 'The Gifted S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140202.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48644, 3339, 'The Gifted S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140203.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48645, 3339, 'The Gifted S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140204.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48646, 3339, 'The Gifted S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140205.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48647, 3339, 'The Gifted S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140206.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48648, 3339, 'The Gifted S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140207.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48649, 3339, 'The Gifted S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/140208.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48650, 3339, 'The Gifted S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/140209.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48651, 3339, 'The Gifted S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/140210.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48652, 3339, 'The Gifted S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/140211.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48653, 3339, 'The Gifted S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/140212.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48654, 3339, 'The Gifted S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/140213.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48655, 3339, 'The Gifted S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/140214.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48656, 3339, 'The Gifted S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/140215.mp4', 'http://gstaticontent.com/images/uhzere8wpagFd6WJe5XaA3r7FVy_big.jpg'),
(48657, 3340, 'The Good Lord Bird S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140216.mp4', 'http://gstaticontent.com/images/2dOH8r77y4Ocj5ELj4LPwvrFR1e_big.jpg'),
(48658, 3340, 'The Good Lord Bird S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140217.mp4', 'http://gstaticontent.com/images/2dOH8r77y4Ocj5ELj4LPwvrFR1e_big.jpg'),
(48659, 3340, 'The Good Lord Bird S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140218.mp4', 'http://gstaticontent.com/images/2dOH8r77y4Ocj5ELj4LPwvrFR1e_big.jpg'),
(48660, 3340, 'The Good Lord Bird S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140219.mp4', 'http://gstaticontent.com/images/2dOH8r77y4Ocj5ELj4LPwvrFR1e_big.jpg'),
(48661, 3340, 'The Good Lord Bird S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140220.mp4', 'http://gstaticontent.com/images/2dOH8r77y4Ocj5ELj4LPwvrFR1e_big.jpg'),
(48662, 3340, 'The Good Lord Bird S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140221.mp4', 'http://gstaticontent.com/images/2dOH8r77y4Ocj5ELj4LPwvrFR1e_big.jpg'),
(48663, 3340, 'The Good Lord Bird S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140222.mp4', 'http://gstaticontent.com/images/2dOH8r77y4Ocj5ELj4LPwvrFR1e_big.jpg'),
(48664, 3341, 'The One S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/140223.mp4', 'http://gstaticontent.com/images/klL9vBIRdEeSLtjhn83pCNcVguZ_big.jpg'),
(48665, 3341, 'The One S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/140224.mp4', 'http://gstaticontent.com/images/klL9vBIRdEeSLtjhn83pCNcVguZ_big.jpg'),
(48666, 3341, 'The One S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/140225.mp4', 'http://gstaticontent.com/images/klL9vBIRdEeSLtjhn83pCNcVguZ_big.jpg'),
(48667, 3341, 'The One S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/140226.mp4', 'http://gstaticontent.com/images/klL9vBIRdEeSLtjhn83pCNcVguZ_big.jpg'),
(48668, 3341, 'The One S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/140227.mp4', 'http://gstaticontent.com/images/klL9vBIRdEeSLtjhn83pCNcVguZ_big.jpg'),
(48669, 3341, 'The One S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/140228.mp4', 'http://gstaticontent.com/images/klL9vBIRdEeSLtjhn83pCNcVguZ_big.jpg'),
(48670, 3341, 'The One S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/140229.mp4', 'http://gstaticontent.com/images/klL9vBIRdEeSLtjhn83pCNcVguZ_big.jpg'),
(48671, 3341, 'The One S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/140230.mp4', 'http://gstaticontent.com/images/klL9vBIRdEeSLtjhn83pCNcVguZ_big.jpg'),
(48672, 3342, 'Calls S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139628.mp4', 'http://gstaticontent.com/images/lzb4SwMTwNZPaifi0qDc9U0imzG_big.jpg'),
(48673, 3342, 'Calls S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139629.mp4', 'http://gstaticontent.com/images/lzb4SwMTwNZPaifi0qDc9U0imzG_big.jpg'),
(48674, 3342, 'Calls S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139630.mp4', 'http://gstaticontent.com/images/lzb4SwMTwNZPaifi0qDc9U0imzG_big.jpg'),
(48675, 3342, 'Calls S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139631.mp4', 'http://gstaticontent.com/images/lzb4SwMTwNZPaifi0qDc9U0imzG_big.jpg'),
(48676, 3342, 'Calls S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139632.mp4', 'http://gstaticontent.com/images/lzb4SwMTwNZPaifi0qDc9U0imzG_big.jpg'),
(48677, 3342, 'Calls S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139633.mp4', 'http://gstaticontent.com/images/lzb4SwMTwNZPaifi0qDc9U0imzG_big.jpg'),
(48678, 3342, 'Calls S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139634.mp4', 'http://gstaticontent.com/images/lzb4SwMTwNZPaifi0qDc9U0imzG_big.jpg'),
(48679, 3342, 'Calls S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139635.mp4', 'http://gstaticontent.com/images/lzb4SwMTwNZPaifi0qDc9U0imzG_big.jpg'),
(48680, 3343, 'Família em Concerto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139544.mp4', 'http://gstaticontent.com/images/jGqIt1x9PyGqwlurl2fA9V7uDmw_big.jpg'),
(48681, 3343, 'Família em Concerto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139545.mp4', 'http://gstaticontent.com/images/jGqIt1x9PyGqwlurl2fA9V7uDmw_big.jpg'),
(48682, 3343, 'Família em Concerto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139546.mp4', 'http://gstaticontent.com/images/jGqIt1x9PyGqwlurl2fA9V7uDmw_big.jpg'),
(48683, 3343, 'Família em Concerto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139547.mp4', 'http://gstaticontent.com/images/jGqIt1x9PyGqwlurl2fA9V7uDmw_big.jpg'),
(48684, 3343, 'Família em Concerto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139548.mp4', 'http://gstaticontent.com/images/jGqIt1x9PyGqwlurl2fA9V7uDmw_big.jpg'),
(48685, 3343, 'Família em Concerto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139549.mp4', 'http://gstaticontent.com/images/jGqIt1x9PyGqwlurl2fA9V7uDmw_big.jpg'),
(48686, 3343, 'Família em Concerto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139550.mp4', 'http://gstaticontent.com/images/jGqIt1x9PyGqwlurl2fA9V7uDmw_big.jpg'),
(48687, 3343, 'Família em Concerto S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139551.mp4', 'http://gstaticontent.com/images/jGqIt1x9PyGqwlurl2fA9V7uDmw_big.jpg'),
(48688, 3343, 'Família em Concerto S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139552.mp4', 'http://gstaticontent.com/images/jGqIt1x9PyGqwlurl2fA9V7uDmw_big.jpg'),
(48689, 3343, 'Família em Concerto S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139553.mp4', 'http://gstaticontent.com/images/jGqIt1x9PyGqwlurl2fA9V7uDmw_big.jpg'),
(48690, 3344, 'Hannibal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139505.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48691, 3344, 'Hannibal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139506.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48692, 3344, 'Hannibal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139507.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48693, 3344, 'Hannibal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139508.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48694, 3344, 'Hannibal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139509.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48695, 3344, 'Hannibal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139510.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48696, 3344, 'Hannibal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139511.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48697, 3344, 'Hannibal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139512.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48698, 3344, 'Hannibal S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139513.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48699, 3344, 'Hannibal S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139514.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48700, 3344, 'Hannibal S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139515.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48701, 3344, 'Hannibal S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139516.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48702, 3344, 'Hannibal S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139517.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48703, 3345, 'Hannibal S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139518.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48704, 3345, 'Hannibal S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139519.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48705, 3345, 'Hannibal S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139520.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48706, 3345, 'Hannibal S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139521.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48707, 3345, 'Hannibal S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139522.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48708, 3345, 'Hannibal S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139523.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48709, 3345, 'Hannibal S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139524.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48710, 3345, 'Hannibal S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139525.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48711, 3345, 'Hannibal S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139526.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48712, 3345, 'Hannibal S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139527.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48713, 3345, 'Hannibal S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139528.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48714, 3345, 'Hannibal S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139529.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48715, 3345, 'Hannibal S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139530.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48716, 3346, 'Hannibal S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139531.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48717, 3346, 'Hannibal S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139532.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48718, 3346, 'Hannibal S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139533.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48719, 3346, 'Hannibal S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139534.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48720, 3346, 'Hannibal S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139535.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48721, 3346, 'Hannibal S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139536.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48722, 3346, 'Hannibal S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139537.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48723, 3346, 'Hannibal S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139538.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48724, 3346, 'Hannibal S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139539.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48725, 3346, 'Hannibal S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139540.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48726, 3346, 'Hannibal S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139541.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48727, 3346, 'Hannibal S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139542.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48728, 3346, 'Hannibal S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139543.mp4', 'http://gstaticontent.com/images/4zcgbPOEyuxS44ilJh6FIEEqH9j_big.jpg'),
(48729, 3347, '100-man no Inochi no Ue ni Ore wa Tatte Iru S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139554.mp4', 'http://gstaticontent.com/images/oEWlre1wLWCPRT9l5wQl7qpo70e_big.jpg'),
(48730, 3347, '100-man no Inochi no Ue ni Ore wa Tatte Iru S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139555.mp4', 'http://gstaticontent.com/images/oEWlre1wLWCPRT9l5wQl7qpo70e_big.jpg'),
(48731, 3347, '100-man no Inochi no Ue ni Ore wa Tatte Iru S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139556.mp4', 'http://gstaticontent.com/images/oEWlre1wLWCPRT9l5wQl7qpo70e_big.jpg'),
(48732, 3347, '100-man no Inochi no Ue ni Ore wa Tatte Iru S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139557.mp4', 'http://gstaticontent.com/images/oEWlre1wLWCPRT9l5wQl7qpo70e_big.jpg'),
(48733, 3347, '100-man no Inochi no Ue ni Ore wa Tatte Iru S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139558.mp4', 'http://gstaticontent.com/images/oEWlre1wLWCPRT9l5wQl7qpo70e_big.jpg'),
(48734, 3347, '100-man no Inochi no Ue ni Ore wa Tatte Iru S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139559.mp4', 'http://gstaticontent.com/images/oEWlre1wLWCPRT9l5wQl7qpo70e_big.jpg'),
(48735, 3347, '100-man no Inochi no Ue ni Ore wa Tatte Iru S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139560.mp4', 'http://gstaticontent.com/images/oEWlre1wLWCPRT9l5wQl7qpo70e_big.jpg'),
(48736, 3347, '100-man no Inochi no Ue ni Ore wa Tatte Iru S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139561.mp4', 'http://gstaticontent.com/images/oEWlre1wLWCPRT9l5wQl7qpo70e_big.jpg'),
(48737, 3347, '100-man no Inochi no Ue ni Ore wa Tatte Iru S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139562.mp4', 'http://gstaticontent.com/images/oEWlre1wLWCPRT9l5wQl7qpo70e_big.jpg'),
(48738, 3347, '100-man no Inochi no Ue ni Ore wa Tatte Iru S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139563.mp4', 'http://gstaticontent.com/images/oEWlre1wLWCPRT9l5wQl7qpo70e_big.jpg'),
(48739, 3347, '100-man no Inochi no Ue ni Ore wa Tatte Iru S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139564.mp4', 'http://gstaticontent.com/images/oEWlre1wLWCPRT9l5wQl7qpo70e_big.jpg'),
(48740, 3347, '100-man no Inochi no Ue ni Ore wa Tatte Iru S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139565.mp4', 'http://gstaticontent.com/images/oEWlre1wLWCPRT9l5wQl7qpo70e_big.jpg'),
(48741, 3348, 'Little Birds S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139566.mp4', 'http://gstaticontent.com/images/d0qM3ABz3gdTyUViSm7zOjfsAqz_big.jpg'),
(48742, 3348, 'Little Birds S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139567.mp4', 'http://gstaticontent.com/images/d0qM3ABz3gdTyUViSm7zOjfsAqz_big.jpg'),
(48743, 3348, 'Little Birds S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139568.mp4', 'http://gstaticontent.com/images/d0qM3ABz3gdTyUViSm7zOjfsAqz_big.jpg'),
(48744, 3348, 'Little Birds S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139569.mp4', 'http://gstaticontent.com/images/d0qM3ABz3gdTyUViSm7zOjfsAqz_big.jpg'),
(48745, 3348, 'Little Birds S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139570.mp4', 'http://gstaticontent.com/images/d0qM3ABz3gdTyUViSm7zOjfsAqz_big.jpg'),
(48746, 3348, 'Little Birds S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139571.mp4', 'http://gstaticontent.com/images/d0qM3ABz3gdTyUViSm7zOjfsAqz_big.jpg'),
(48747, 3349, 'Os Guerreiros Wasabi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139420.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48748, 3349, 'Os Guerreiros Wasabi S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139421.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48749, 3349, 'Os Guerreiros Wasabi S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139422.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48750, 3349, 'Os Guerreiros Wasabi S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139423.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48751, 3349, 'Os Guerreiros Wasabi S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139424.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48752, 3349, 'Os Guerreiros Wasabi S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139425.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48753, 3349, 'Os Guerreiros Wasabi S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139426.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48754, 3349, 'Os Guerreiros Wasabi S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139427.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48755, 3349, 'Os Guerreiros Wasabi S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139428.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48756, 3349, 'Os Guerreiros Wasabi S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139429.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48757, 3349, 'Os Guerreiros Wasabi S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139430.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48758, 3349, 'Os Guerreiros Wasabi S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139431.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48759, 3349, 'Os Guerreiros Wasabi S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139432.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48760, 3349, 'Os Guerreiros Wasabi S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139433.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48761, 3349, 'Os Guerreiros Wasabi S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139434.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48762, 3349, 'Os Guerreiros Wasabi S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139435.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48763, 3349, 'Os Guerreiros Wasabi S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/139436.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48764, 3349, 'Os Guerreiros Wasabi S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/139437.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48765, 3349, 'Os Guerreiros Wasabi S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/139438.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48766, 3349, 'Os Guerreiros Wasabi S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/139439.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48767, 3349, 'Os Guerreiros Wasabi S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/139440.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48768, 3350, 'Os Guerreiros Wasabi S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139441.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48769, 3350, 'Os Guerreiros Wasabi S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139442.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48770, 3350, 'Os Guerreiros Wasabi S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139443.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48771, 3350, 'Os Guerreiros Wasabi S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139444.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48772, 3350, 'Os Guerreiros Wasabi S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139445.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48773, 3350, 'Os Guerreiros Wasabi S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139446.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48774, 3350, 'Os Guerreiros Wasabi S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139447.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48775, 3350, 'Os Guerreiros Wasabi S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139448.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48776, 3350, 'Os Guerreiros Wasabi S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139449.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48777, 3350, 'Os Guerreiros Wasabi S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139450.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48778, 3350, 'Os Guerreiros Wasabi S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139451.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48779, 3350, 'Os Guerreiros Wasabi S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139452.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48780, 3350, 'Os Guerreiros Wasabi S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139453.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48781, 3350, 'Os Guerreiros Wasabi S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139454.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48782, 3350, 'Os Guerreiros Wasabi S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139455.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48783, 3350, 'Os Guerreiros Wasabi S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139456.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48784, 3350, 'Os Guerreiros Wasabi S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/139457.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48785, 3350, 'Os Guerreiros Wasabi S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/139458.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48786, 3350, 'Os Guerreiros Wasabi S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/139459.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48787, 3350, 'Os Guerreiros Wasabi S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/139460.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48788, 3350, 'Os Guerreiros Wasabi S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/139461.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48789, 3350, 'Os Guerreiros Wasabi S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/139462.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48790, 3350, 'Os Guerreiros Wasabi S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/139463.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48791, 3350, 'Os Guerreiros Wasabi S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/139464.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48792, 3351, 'Os Guerreiros Wasabi S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139465.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(48793, 3351, 'Os Guerreiros Wasabi S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139466.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48794, 3351, 'Os Guerreiros Wasabi S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139467.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48795, 3351, 'Os Guerreiros Wasabi S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139468.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48796, 3351, 'Os Guerreiros Wasabi S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139469.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48797, 3351, 'Os Guerreiros Wasabi S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139470.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48798, 3351, 'Os Guerreiros Wasabi S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139471.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48799, 3351, 'Os Guerreiros Wasabi S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139472.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48800, 3351, 'Os Guerreiros Wasabi S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139473.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48801, 3351, 'Os Guerreiros Wasabi S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139474.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48802, 3351, 'Os Guerreiros Wasabi S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139475.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48803, 3351, 'Os Guerreiros Wasabi S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139476.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48804, 3351, 'Os Guerreiros Wasabi S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139477.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48805, 3351, 'Os Guerreiros Wasabi S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139478.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48806, 3351, 'Os Guerreiros Wasabi S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139479.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48807, 3351, 'Os Guerreiros Wasabi S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139480.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48808, 3351, 'Os Guerreiros Wasabi S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/139481.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48809, 3351, 'Os Guerreiros Wasabi S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/139482.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48810, 3351, 'Os Guerreiros Wasabi S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/139483.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48811, 3351, 'Os Guerreiros Wasabi S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/139484.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48812, 3351, 'Os Guerreiros Wasabi S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/139485.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48813, 3351, 'Os Guerreiros Wasabi S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/139486.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48814, 3352, 'Os Guerreiros Wasabi S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139487.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48815, 3352, 'Os Guerreiros Wasabi S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139488.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48816, 3352, 'Os Guerreiros Wasabi S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139489.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48817, 3352, 'Os Guerreiros Wasabi S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139490.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48818, 3352, 'Os Guerreiros Wasabi S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139491.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48819, 3352, 'Os Guerreiros Wasabi S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139492.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48820, 3352, 'Os Guerreiros Wasabi S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139493.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48821, 3352, 'Os Guerreiros Wasabi S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139494.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48822, 3352, 'Os Guerreiros Wasabi S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139495.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48823, 3352, 'Os Guerreiros Wasabi S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139496.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48824, 3352, 'Os Guerreiros Wasabi S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139497.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48825, 3352, 'Os Guerreiros Wasabi S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139498.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48826, 3352, 'Os Guerreiros Wasabi S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139499.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48827, 3352, 'Os Guerreiros Wasabi S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139500.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48828, 3352, 'Os Guerreiros Wasabi S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139501.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48829, 3352, 'Os Guerreiros Wasabi S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139502.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48830, 3352, 'Os Guerreiros Wasabi S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/139503.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48831, 3352, 'Os Guerreiros Wasabi S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/139504.mp4', 'http://gstaticontent.com/images/3C0CJVd55Wl8qVVJNQBF4WLuzLs_big.jpg'),
(48832, 3353, 'Passarela de Sonhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139572.mp4', 'http://gstaticontent.com/images/iuYfsWFLdrWhdIkkmbtFQDCf6e7_big.jpg'),
(48833, 3353, 'Passarela de Sonhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139573.mp4', 'http://gstaticontent.com/images/iuYfsWFLdrWhdIkkmbtFQDCf6e7_big.jpg'),
(48834, 3353, 'Passarela de Sonhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139574.mp4', 'http://gstaticontent.com/images/iuYfsWFLdrWhdIkkmbtFQDCf6e7_big.jpg'),
(48835, 3353, 'Passarela de Sonhos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139575.mp4', 'http://gstaticontent.com/images/iuYfsWFLdrWhdIkkmbtFQDCf6e7_big.jpg'),
(48836, 3353, 'Passarela de Sonhos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139576.mp4', 'http://gstaticontent.com/images/iuYfsWFLdrWhdIkkmbtFQDCf6e7_big.jpg'),
(48837, 3353, 'Passarela de Sonhos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139577.mp4', 'http://gstaticontent.com/images/iuYfsWFLdrWhdIkkmbtFQDCf6e7_big.jpg'),
(48838, 3353, 'Passarela de Sonhos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139578.mp4', 'http://gstaticontent.com/images/iuYfsWFLdrWhdIkkmbtFQDCf6e7_big.jpg'),
(48839, 3353, 'Passarela de Sonhos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139579.mp4', 'http://gstaticontent.com/images/iuYfsWFLdrWhdIkkmbtFQDCf6e7_big.jpg'),
(48840, 3353, 'Passarela de Sonhos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139580.mp4', 'http://gstaticontent.com/images/iuYfsWFLdrWhdIkkmbtFQDCf6e7_big.jpg'),
(48841, 3353, 'Passarela de Sonhos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139581.mp4', 'http://gstaticontent.com/images/iuYfsWFLdrWhdIkkmbtFQDCf6e7_big.jpg'),
(48842, 3353, 'Passarela de Sonhos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139582.mp4', 'http://gstaticontent.com/images/iuYfsWFLdrWhdIkkmbtFQDCf6e7_big.jpg'),
(48843, 3353, 'Passarela de Sonhos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139583.mp4', 'http://gstaticontent.com/images/iuYfsWFLdrWhdIkkmbtFQDCf6e7_big.jpg'),
(48844, 3353, 'Passarela de Sonhos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139584.mp4', 'http://gstaticontent.com/images/iuYfsWFLdrWhdIkkmbtFQDCf6e7_big.jpg'),
(48845, 3353, 'Passarela de Sonhos S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139585.mp4', 'http://gstaticontent.com/images/iuYfsWFLdrWhdIkkmbtFQDCf6e7_big.jpg'),
(48846, 3353, 'Passarela de Sonhos S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139586.mp4', 'http://gstaticontent.com/images/iuYfsWFLdrWhdIkkmbtFQDCf6e7_big.jpg'),
(48847, 3353, 'Passarela de Sonhos S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139587.mp4', 'http://gstaticontent.com/images/iuYfsWFLdrWhdIkkmbtFQDCf6e7_big.jpg'),
(48848, 3354, 'Waffles + Mochi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139588.mp4', 'http://gstaticontent.com/images/oPpA8DMcMThacHlAo5az83WxwBr_big.jpg'),
(48849, 3354, 'Waffles + Mochi S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139589.mp4', 'http://gstaticontent.com/images/oPpA8DMcMThacHlAo5az83WxwBr_big.jpg'),
(48850, 3354, 'Waffles + Mochi S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139590.mp4', 'http://gstaticontent.com/images/oPpA8DMcMThacHlAo5az83WxwBr_big.jpg'),
(48851, 3354, 'Waffles + Mochi S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139591.mp4', 'http://gstaticontent.com/images/oPpA8DMcMThacHlAo5az83WxwBr_big.jpg'),
(48852, 3354, 'Waffles + Mochi S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139592.mp4', 'http://gstaticontent.com/images/oPpA8DMcMThacHlAo5az83WxwBr_big.jpg'),
(48853, 3354, 'Waffles + Mochi S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139593.mp4', 'http://gstaticontent.com/images/oPpA8DMcMThacHlAo5az83WxwBr_big.jpg'),
(48854, 3354, 'Waffles + Mochi S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139594.mp4', 'http://gstaticontent.com/images/oPpA8DMcMThacHlAo5az83WxwBr_big.jpg'),
(48855, 3354, 'Waffles + Mochi S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139595.mp4', 'http://gstaticontent.com/images/oPpA8DMcMThacHlAo5az83WxwBr_big.jpg'),
(48856, 3354, 'Waffles + Mochi S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139596.mp4', 'http://gstaticontent.com/images/oPpA8DMcMThacHlAo5az83WxwBr_big.jpg'),
(48857, 3354, 'Waffles + Mochi S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139597.mp4', 'http://gstaticontent.com/images/oPpA8DMcMThacHlAo5az83WxwBr_big.jpg'),
(48858, 3355, 'Tokyo Ghoul S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139314.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48859, 3355, 'Tokyo Ghoul S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139315.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48860, 3355, 'Tokyo Ghoul S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139316.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48861, 3355, 'Tokyo Ghoul S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139317.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48862, 3355, 'Tokyo Ghoul S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139318.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48863, 3355, 'Tokyo Ghoul S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139319.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48864, 3355, 'Tokyo Ghoul S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139320.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48865, 3355, 'Tokyo Ghoul S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139321.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48866, 3355, 'Tokyo Ghoul S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139322.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48867, 3355, 'Tokyo Ghoul S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139323.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48868, 3355, 'Tokyo Ghoul S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139324.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48869, 3355, 'Tokyo Ghoul S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139325.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48870, 3356, 'Tokyo Ghoul S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139326.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48871, 3356, 'Tokyo Ghoul S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139327.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48872, 3356, 'Tokyo Ghoul S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139328.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48873, 3356, 'Tokyo Ghoul S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139329.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48874, 3356, 'Tokyo Ghoul S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139330.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48875, 3356, 'Tokyo Ghoul S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139331.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48876, 3356, 'Tokyo Ghoul S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139332.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48877, 3356, 'Tokyo Ghoul S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139333.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48878, 3356, 'Tokyo Ghoul S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139334.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48879, 3356, 'Tokyo Ghoul S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139335.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48880, 3356, 'Tokyo Ghoul S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139336.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48881, 3356, 'Tokyo Ghoul S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139337.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48882, 3357, 'Tokyo Ghoul S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139338.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48883, 3357, 'Tokyo Ghoul S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139339.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48884, 3357, 'Tokyo Ghoul S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139340.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48885, 3357, 'Tokyo Ghoul S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139341.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48886, 3357, 'Tokyo Ghoul S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139342.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48887, 3357, 'Tokyo Ghoul S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139343.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48888, 3357, 'Tokyo Ghoul S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139344.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48889, 3357, 'Tokyo Ghoul S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139345.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48890, 3357, 'Tokyo Ghoul S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139346.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48891, 3357, 'Tokyo Ghoul S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139347.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48892, 3357, 'Tokyo Ghoul S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139348.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48893, 3357, 'Tokyo Ghoul S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139349.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48894, 3358, 'Tokyo Ghoul S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139350.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48895, 3358, 'Tokyo Ghoul S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139351.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48896, 3358, 'Tokyo Ghoul S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139352.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48897, 3358, 'Tokyo Ghoul S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139353.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48898, 3358, 'Tokyo Ghoul S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139354.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48899, 3358, 'Tokyo Ghoul S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139355.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48900, 3358, 'Tokyo Ghoul S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139356.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48901, 3358, 'Tokyo Ghoul S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139357.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48902, 3358, 'Tokyo Ghoul S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139358.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48903, 3358, 'Tokyo Ghoul S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139359.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48904, 3358, 'Tokyo Ghoul S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139360.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48905, 3358, 'Tokyo Ghoul S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139361.mp4', 'http://gstaticontent.com/images/7Xl5CxMgHK0Eh6scuxCs3YYQcNQ_big.jpg'),
(48906, 3359, 'Quem Matou Sara? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181039.mp4', 'http://gstaticontent.com/images/jnit57q25N5VvVrK4pj4Uj8BLe7_big.jpg'),
(48907, 3359, 'Quem Matou Sara? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181040.mp4', 'http://gstaticontent.com/images/jnit57q25N5VvVrK4pj4Uj8BLe7_big.jpg'),
(48908, 3359, 'Quem Matou Sara? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181041.mp4', 'http://gstaticontent.com/images/jnit57q25N5VvVrK4pj4Uj8BLe7_big.jpg'),
(48909, 3359, 'Quem Matou Sara? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181042.mp4', 'http://gstaticontent.com/images/jnit57q25N5VvVrK4pj4Uj8BLe7_big.jpg'),
(48910, 3359, 'Quem Matou Sara? S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181043.mp4', 'http://gstaticontent.com/images/jnit57q25N5VvVrK4pj4Uj8BLe7_big.jpg'),
(48911, 3359, 'Quem Matou Sara? S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181044.mp4', 'http://gstaticontent.com/images/jnit57q25N5VvVrK4pj4Uj8BLe7_big.jpg'),
(48912, 3359, 'Quem Matou Sara? S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181045.mp4', 'http://gstaticontent.com/images/jnit57q25N5VvVrK4pj4Uj8BLe7_big.jpg'),
(48913, 3359, 'Quem Matou Sara? S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181046.mp4', 'http://gstaticontent.com/images/jnit57q25N5VvVrK4pj4Uj8BLe7_big.jpg'),
(48914, 3359, 'Quem Matou Sara? S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181047.mp4', 'http://gstaticontent.com/images/jnit57q25N5VvVrK4pj4Uj8BLe7_big.jpg'),
(48915, 3359, 'Quem Matou Sara? S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181048.mp4', 'http://gstaticontent.com/images/jnit57q25N5VvVrK4pj4Uj8BLe7_big.jpg'),
(48916, 3360, 'Quem Matou Sara? S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181049.mp4', 'http://gstaticontent.com/images/jnit57q25N5VvVrK4pj4Uj8BLe7_big.jpg'),
(48917, 3360, 'Quem Matou Sara? S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181050.mp4', 'http://gstaticontent.com/images/jnit57q25N5VvVrK4pj4Uj8BLe7_big.jpg'),
(48918, 3360, 'Quem Matou Sara? S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181051.mp4', 'http://gstaticontent.com/images/jnit57q25N5VvVrK4pj4Uj8BLe7_big.jpg'),
(48919, 3360, 'Quem Matou Sara? S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181052.mp4', 'http://gstaticontent.com/images/jnit57q25N5VvVrK4pj4Uj8BLe7_big.jpg'),
(48920, 3360, 'Quem Matou Sara? S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181053.mp4', 'http://gstaticontent.com/images/jnit57q25N5VvVrK4pj4Uj8BLe7_big.jpg'),
(48921, 3360, 'Quem Matou Sara? S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181054.mp4', 'http://gstaticontent.com/images/jnit57q25N5VvVrK4pj4Uj8BLe7_big.jpg'),
(48922, 3360, 'Quem Matou Sara? S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181055.mp4', 'http://gstaticontent.com/images/jnit57q25N5VvVrK4pj4Uj8BLe7_big.jpg'),
(48923, 3360, 'Quem Matou Sara? S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181056.mp4', 'http://gstaticontent.com/images/jnit57q25N5VvVrK4pj4Uj8BLe7_big.jpg'),
(48924, 3361, 'Quem Matou Sara? S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181057.mp4', 'http://timg.bdta.pro/images/00bed3fa240d9cd4e2aa819112647852.jpg'),
(48925, 3361, 'Quem Matou Sara? S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181058.mp4', 'http://timg.bdta.pro/images/76d539fa7bdda2b52e5e644dfcb0e9d7.jpg'),
(48926, 3361, 'Quem Matou Sara? S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181059.mp4', 'http://timg.bdta.pro/images/160b4ee27f948145d7aa0662e5927d06.jpg'),
(48927, 3361, 'Quem Matou Sara? S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181060.mp4', 'http://timg.bdta.pro/images/abd225fd14e2ef44359f60d4104dfcfc.jpg'),
(48928, 3361, 'Quem Matou Sara? S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181061.mp4', 'http://timg.bdta.pro/images/abea1858bf804c59459cd55882dd818d.jpg'),
(48929, 3361, 'Quem Matou Sara? S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181062.mp4', 'http://timg.bdta.pro/images/fabc98181fa25eec0547be85423de4cc.jpg'),
(48930, 3361, 'Quem Matou Sara? S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181063.mp4', 'http://timg.bdta.pro/images/e38fa4868c55c9aa47ab6a82e48b4d33.jpg'),
(48931, 3362, 'Enfermeira Exorcista S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139308.mp4', 'http://gstaticontent.com/images/cAVcP7S2L0XnO2YcohK2We8nMVz_big.jpg'),
(48932, 3362, 'Enfermeira Exorcista S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139309.mp4', 'http://gstaticontent.com/images/cAVcP7S2L0XnO2YcohK2We8nMVz_big.jpg'),
(48933, 3362, 'Enfermeira Exorcista S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139310.mp4', 'http://gstaticontent.com/images/cAVcP7S2L0XnO2YcohK2We8nMVz_big.jpg'),
(48934, 3362, 'Enfermeira Exorcista S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139311.mp4', 'http://gstaticontent.com/images/cAVcP7S2L0XnO2YcohK2We8nMVz_big.jpg'),
(48935, 3362, 'Enfermeira Exorcista S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139312.mp4', 'http://gstaticontent.com/images/cAVcP7S2L0XnO2YcohK2We8nMVz_big.jpg'),
(48936, 3362, 'Enfermeira Exorcista S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139313.mp4', 'http://gstaticontent.com/images/cAVcP7S2L0XnO2YcohK2We8nMVz_big.jpg'),
(48937, 3363, 'Primeiros Anos! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139302.mp4', 'http://gstaticontent.com/images/peZYB3aFOBoZbpFhOZogrTHVlqX_big.jpg'),
(48938, 3363, 'Primeiros Anos! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139303.mp4', 'http://gstaticontent.com/images/peZYB3aFOBoZbpFhOZogrTHVlqX_big.jpg'),
(48939, 3363, 'Primeiros Anos! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139304.mp4', 'http://gstaticontent.com/images/peZYB3aFOBoZbpFhOZogrTHVlqX_big.jpg'),
(48940, 3363, 'Primeiros Anos! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139305.mp4', 'http://gstaticontent.com/images/peZYB3aFOBoZbpFhOZogrTHVlqX_big.jpg'),
(48941, 3363, 'Primeiros Anos! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139306.mp4', 'http://gstaticontent.com/images/peZYB3aFOBoZbpFhOZogrTHVlqX_big.jpg'),
(48942, 3363, 'Primeiros Anos! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139307.mp4', 'http://gstaticontent.com/images/peZYB3aFOBoZbpFhOZogrTHVlqX_big.jpg'),
(48943, 3364, 'Andy Panda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139276.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48944, 3364, 'Andy Panda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139277.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48945, 3364, 'Andy Panda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139278.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48946, 3364, 'Andy Panda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139279.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48947, 3364, 'Andy Panda S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139280.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48948, 3364, 'Andy Panda S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139281.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48949, 3364, 'Andy Panda S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139282.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48950, 3364, 'Andy Panda S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139283.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48951, 3364, 'Andy Panda S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139284.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48952, 3364, 'Andy Panda S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139285.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48953, 3364, 'Andy Panda S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139286.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48954, 3364, 'Andy Panda S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139287.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48955, 3364, 'Andy Panda S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139288.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48956, 3364, 'Andy Panda S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139289.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48957, 3364, 'Andy Panda S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139290.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48958, 3364, 'Andy Panda S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139291.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48959, 3364, 'Andy Panda S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/139292.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48960, 3364, 'Andy Panda S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/139293.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48961, 3364, 'Andy Panda S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/139294.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48962, 3364, 'Andy Panda S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/139295.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48963, 3364, 'Andy Panda S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/139296.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48964, 3364, 'Andy Panda S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/139297.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48965, 3364, 'Andy Panda S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/139298.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48966, 3364, 'Andy Panda S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/139299.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48967, 3364, 'Andy Panda S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/139300.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48968, 3364, 'Andy Panda S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/139301.mp4', 'http://gstaticontent.com/images/xuvXmTXqev4D2ZU83LwLmS0n2d7_big.jpg'),
(48969, 3365, 'Os Irregulares de Baker Street S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139268.mp4', 'http://gstaticontent.com/images/qN6HCKR3ZRqbpGBWFctVlSTKR2k_big.jpg'),
(48970, 3365, 'Os Irregulares de Baker Street S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139269.mp4', 'http://gstaticontent.com/images/qN6HCKR3ZRqbpGBWFctVlSTKR2k_big.jpg'),
(48971, 3365, 'Os Irregulares de Baker Street S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139270.mp4', 'http://gstaticontent.com/images/qN6HCKR3ZRqbpGBWFctVlSTKR2k_big.jpg'),
(48972, 3365, 'Os Irregulares de Baker Street S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139271.mp4', 'http://gstaticontent.com/images/qN6HCKR3ZRqbpGBWFctVlSTKR2k_big.jpg'),
(48973, 3365, 'Os Irregulares de Baker Street S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139272.mp4', 'http://gstaticontent.com/images/qN6HCKR3ZRqbpGBWFctVlSTKR2k_big.jpg'),
(48974, 3365, 'Os Irregulares de Baker Street S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139273.mp4', 'http://gstaticontent.com/images/qN6HCKR3ZRqbpGBWFctVlSTKR2k_big.jpg'),
(48975, 3365, 'Os Irregulares de Baker Street S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139274.mp4', 'http://gstaticontent.com/images/qN6HCKR3ZRqbpGBWFctVlSTKR2k_big.jpg'),
(48976, 3365, 'Os Irregulares de Baker Street S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139275.mp4', 'http://gstaticontent.com/images/qN6HCKR3ZRqbpGBWFctVlSTKR2k_big.jpg'),
(48977, 3366, 'Destino La Templanza S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139258.mp4', 'http://gstaticontent.com/images/zOvYcAiWAHjWccXrRIlzFcra9HX_big.jpg'),
(48978, 3366, 'Destino La Templanza S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139259.mp4', 'http://gstaticontent.com/images/zOvYcAiWAHjWccXrRIlzFcra9HX_big.jpg'),
(48979, 3366, 'Destino La Templanza S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139260.mp4', 'http://gstaticontent.com/images/zOvYcAiWAHjWccXrRIlzFcra9HX_big.jpg'),
(48980, 3366, 'Destino La Templanza S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139261.mp4', 'http://gstaticontent.com/images/zOvYcAiWAHjWccXrRIlzFcra9HX_big.jpg'),
(48981, 3366, 'Destino La Templanza S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139262.mp4', 'http://gstaticontent.com/images/zOvYcAiWAHjWccXrRIlzFcra9HX_big.jpg'),
(48982, 3366, 'Destino La Templanza S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139263.mp4', 'http://gstaticontent.com/images/zOvYcAiWAHjWccXrRIlzFcra9HX_big.jpg'),
(48983, 3366, 'Destino La Templanza S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139264.mp4', 'http://gstaticontent.com/images/zOvYcAiWAHjWccXrRIlzFcra9HX_big.jpg'),
(48984, 3366, 'Destino La Templanza S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139265.mp4', 'http://gstaticontent.com/images/zOvYcAiWAHjWccXrRIlzFcra9HX_big.jpg'),
(48985, 3366, 'Destino La Templanza S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139266.mp4', 'http://gstaticontent.com/images/zOvYcAiWAHjWccXrRIlzFcra9HX_big.jpg'),
(48986, 3366, 'Destino La Templanza S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139267.mp4', 'http://gstaticontent.com/images/zOvYcAiWAHjWccXrRIlzFcra9HX_big.jpg'),
(48987, 3367, 'Alef [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144681.mp4', 'http://gstaticontent.com/images/6CyNjKgbgs6dTBKNkUJsEfMnX1B_big.jpg'),
(48988, 3367, 'Alef [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144682.mp4', 'http://gstaticontent.com/images/6CyNjKgbgs6dTBKNkUJsEfMnX1B_big.jpg'),
(48989, 3367, 'Alef [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144683.mp4', 'http://gstaticontent.com/images/6CyNjKgbgs6dTBKNkUJsEfMnX1B_big.jpg'),
(48990, 3367, 'Alef [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144684.mp4', 'http://gstaticontent.com/images/6CyNjKgbgs6dTBKNkUJsEfMnX1B_big.jpg'),
(48991, 3367, 'Alef [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144685.mp4', 'http://gstaticontent.com/images/6CyNjKgbgs6dTBKNkUJsEfMnX1B_big.jpg'),
(48992, 3367, 'Alef [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144686.mp4', 'http://gstaticontent.com/images/6CyNjKgbgs6dTBKNkUJsEfMnX1B_big.jpg'),
(48993, 3367, 'Alef [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144687.mp4', 'http://gstaticontent.com/images/6CyNjKgbgs6dTBKNkUJsEfMnX1B_big.jpg'),
(48994, 3367, 'Alef [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144688.mp4', 'http://gstaticontent.com/images/6CyNjKgbgs6dTBKNkUJsEfMnX1B_big.jpg'),
(48995, 3368, 'Atlântida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139232.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(48996, 3368, 'Atlântida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139233.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(48997, 3368, 'Atlântida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139234.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(48998, 3368, 'Atlântida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139235.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(48999, 3368, 'Atlântida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139236.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49000, 3368, 'Atlântida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139237.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49001, 3368, 'Atlântida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139238.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49002, 3368, 'Atlântida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139239.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49003, 3368, 'Atlântida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139240.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49004, 3368, 'Atlântida S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139241.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49005, 3368, 'Atlântida S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139242.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49006, 3368, 'Atlântida S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139243.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49007, 3368, 'Atlântida S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139244.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49008, 3369, 'Atlântida S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139245.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49009, 3369, 'Atlântida S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139246.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49010, 3369, 'Atlântida S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139247.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49011, 3369, 'Atlântida S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139248.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49012, 3369, 'Atlântida S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139249.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49013, 3369, 'Atlântida S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139250.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49014, 3369, 'Atlântida S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139251.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49015, 3369, 'Atlântida S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139252.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49016, 3369, 'Atlântida S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139253.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49017, 3369, 'Atlântida S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139254.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49018, 3369, 'Atlântida S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139255.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49019, 3369, 'Atlântida S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139256.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49020, 3369, 'Atlântida S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139257.mp4', 'http://gstaticontent.com/images/bmdlBu7y0pZq3KZwtFFHzWPEsbP_big.jpg'),
(49021, 3370, 'Carga Pesada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201986.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49022, 3370, 'Carga Pesada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201987.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49023, 3370, 'Carga Pesada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201988.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49024, 3370, 'Carga Pesada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201989.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49025, 3370, 'Carga Pesada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201990.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49026, 3370, 'Carga Pesada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201991.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49027, 3370, 'Carga Pesada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201992.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49028, 3370, 'Carga Pesada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201993.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49029, 3370, 'Carga Pesada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201994.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49030, 3370, 'Carga Pesada S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201995.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49031, 3370, 'Carga Pesada S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201996.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49032, 3370, 'Carga Pesada S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201997.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49033, 3371, 'Carga Pesada S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/coWVqGR0mheNYfhDgUwCvf6yAwg.jpg'),
(49034, 3371, 'Carga Pesada S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Qf4g2Xpj3ceBeYwDMS1woIt9Kd.jpg'),
(49035, 3371, 'Carga Pesada S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eTlGFvQWDZ4y2FC7bcqwaQn5ONR.jpg'),
(49036, 3371, 'Carga Pesada S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gl7ANWGugVdrLZD0yFQNPTA8icf.jpg'),
(49037, 3371, 'Carga Pesada S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iGPEKEceDIIOfRanpB0H2vobe6a.jpg'),
(49038, 3371, 'Carga Pesada S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rKOhRVEPlZIZFl7gHknqrlYR5mw.jpg'),
(49039, 3371, 'Carga Pesada S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1hufHYHxENCNaYYfNs0cDYV6gda.jpg'),
(49040, 3371, 'Carga Pesada S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iu8BOM4WmJPRsFXMvUa8q6rMG2B.jpg'),
(49041, 3371, 'Carga Pesada S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aFClQ8vBrRrIWgb4REgqTmkmjJJ.jpg'),
(49042, 3371, 'Carga Pesada S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/52ah31TctZa0e0yDGzgfdFV3Rs3.jpg'),
(49043, 3371, 'Carga Pesada S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g8gqFX3Pt0prKG0yTVJq0LvyZjC.jpg'),
(49044, 3371, 'Carga Pesada S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5i5zhdXpNIAbY6PZuGXebO4ZkLo.jpg'),
(49045, 3371, 'Carga Pesada S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/202010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lDKDBkw2uunXaXL8WcmGuuThfWK.jpg'),
(49046, 3372, 'Carga Pesada S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202011.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49047, 3372, 'Carga Pesada S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202012.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49048, 3372, 'Carga Pesada S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202013.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49049, 3372, 'Carga Pesada S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202014.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49050, 3372, 'Carga Pesada S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202015.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49051, 3372, 'Carga Pesada S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202016.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49052, 3372, 'Carga Pesada S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202017.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49053, 3372, 'Carga Pesada S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202018.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49054, 3372, 'Carga Pesada S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202019.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49055, 3372, 'Carga Pesada S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202020.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49056, 3372, 'Carga Pesada S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202021.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49057, 3372, 'Carga Pesada S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202022.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49058, 3372, 'Carga Pesada S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/202023.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49059, 3372, 'Carga Pesada S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/202024.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49060, 3372, 'Carga Pesada S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/202025.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49061, 3372, 'Carga Pesada S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/202026.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49062, 3372, 'Carga Pesada S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/202027.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49063, 3372, 'Carga Pesada S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/202028.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49064, 3372, 'Carga Pesada S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/202029.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49065, 3372, 'Carga Pesada S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/202030.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49066, 3373, 'Carga Pesada S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202031.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49067, 3373, 'Carga Pesada S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202032.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49068, 3373, 'Carga Pesada S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202033.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49069, 3373, 'Carga Pesada S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202034.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49070, 3373, 'Carga Pesada S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202035.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49071, 3373, 'Carga Pesada S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202036.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49072, 3373, 'Carga Pesada S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202037.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49073, 3373, 'Carga Pesada S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202038.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49074, 3373, 'Carga Pesada S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202039.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49075, 3373, 'Carga Pesada S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202040.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49076, 3374, 'Carga Pesada S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202041.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(49077, 3374, 'Carga Pesada S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202042.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49078, 3374, 'Carga Pesada S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202043.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49079, 3374, 'Carga Pesada S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202044.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49080, 3374, 'Carga Pesada S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202045.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49081, 3374, 'Carga Pesada S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202046.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49082, 3374, 'Carga Pesada S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202047.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49083, 3374, 'Carga Pesada S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202048.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49084, 3374, 'Carga Pesada S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202049.mp4', 'http://gstaticontent.com/images/hdOsXCUvlbRALoglf0adyxm1NRA_big.jpg'),
(49085, 3375, 'Eu Vi: América Latina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139227.mp4', 'http://gstaticontent.com/images/1EGKztiWu57fphI3uHdMHZkMzzd_big.jpg'),
(49086, 3375, 'Eu Vi: América Latina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139228.mp4', 'http://gstaticontent.com/images/1EGKztiWu57fphI3uHdMHZkMzzd_big.jpg'),
(49087, 3375, 'Eu Vi: América Latina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139229.mp4', 'http://gstaticontent.com/images/1EGKztiWu57fphI3uHdMHZkMzzd_big.jpg'),
(49088, 3375, 'Eu Vi: América Latina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139230.mp4', 'http://gstaticontent.com/images/1EGKztiWu57fphI3uHdMHZkMzzd_big.jpg'),
(49089, 3375, 'Eu Vi: América Latina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139231.mp4', 'http://gstaticontent.com/images/1EGKztiWu57fphI3uHdMHZkMzzd_big.jpg'),
(49090, 3376, 'Leonardo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144269.mp4', 'http://gstaticontent.com/images/lZSPtpb4QwfxDHpgbT7OJwDgjS2_big.jpg'),
(49091, 3376, 'Leonardo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144270.mp4', 'http://gstaticontent.com/images/lZSPtpb4QwfxDHpgbT7OJwDgjS2_big.jpg'),
(49092, 3376, 'Leonardo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144271.mp4', 'http://gstaticontent.com/images/lZSPtpb4QwfxDHpgbT7OJwDgjS2_big.jpg'),
(49093, 3376, 'Leonardo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144272.mp4', 'http://gstaticontent.com/images/lZSPtpb4QwfxDHpgbT7OJwDgjS2_big.jpg'),
(49094, 3376, 'Leonardo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144273.mp4', 'http://gstaticontent.com/images/lZSPtpb4QwfxDHpgbT7OJwDgjS2_big.jpg'),
(49095, 3376, 'Leonardo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144274.mp4', 'http://gstaticontent.com/images/lZSPtpb4QwfxDHpgbT7OJwDgjS2_big.jpg'),
(49096, 3376, 'Leonardo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144275.mp4', 'http://gstaticontent.com/images/lZSPtpb4QwfxDHpgbT7OJwDgjS2_big.jpg'),
(49097, 3376, 'Leonardo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144276.mp4', 'http://gstaticontent.com/images/lZSPtpb4QwfxDHpgbT7OJwDgjS2_big.jpg'),
(49098, 3377, 'Lovestruck in the City [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139210.mp4', 'http://gstaticontent.com/images/cv9gYI0XyLfNJzqJjMEc5lTyxVG_big.jpg'),
(49099, 3377, 'Lovestruck in the City [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139211.mp4', 'http://gstaticontent.com/images/cv9gYI0XyLfNJzqJjMEc5lTyxVG_big.jpg'),
(49100, 3377, 'Lovestruck in the City [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139212.mp4', 'http://gstaticontent.com/images/cv9gYI0XyLfNJzqJjMEc5lTyxVG_big.jpg'),
(49101, 3377, 'Lovestruck in the City [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139213.mp4', 'http://gstaticontent.com/images/cv9gYI0XyLfNJzqJjMEc5lTyxVG_big.jpg'),
(49102, 3377, 'Lovestruck in the City [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139214.mp4', 'http://gstaticontent.com/images/cv9gYI0XyLfNJzqJjMEc5lTyxVG_big.jpg'),
(49103, 3377, 'Lovestruck in the City [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139215.mp4', 'http://gstaticontent.com/images/cv9gYI0XyLfNJzqJjMEc5lTyxVG_big.jpg'),
(49104, 3377, 'Lovestruck in the City [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139216.mp4', 'http://gstaticontent.com/images/cv9gYI0XyLfNJzqJjMEc5lTyxVG_big.jpg'),
(49105, 3377, 'Lovestruck in the City [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139217.mp4', 'http://gstaticontent.com/images/cv9gYI0XyLfNJzqJjMEc5lTyxVG_big.jpg'),
(49106, 3377, 'Lovestruck in the City [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139218.mp4', 'http://gstaticontent.com/images/cv9gYI0XyLfNJzqJjMEc5lTyxVG_big.jpg'),
(49107, 3377, 'Lovestruck in the City [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139219.mp4', 'http://gstaticontent.com/images/cv9gYI0XyLfNJzqJjMEc5lTyxVG_big.jpg'),
(49108, 3377, 'Lovestruck in the City [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139220.mp4', 'http://gstaticontent.com/images/cv9gYI0XyLfNJzqJjMEc5lTyxVG_big.jpg'),
(49109, 3377, 'Lovestruck in the City [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139221.mp4', 'http://gstaticontent.com/images/cv9gYI0XyLfNJzqJjMEc5lTyxVG_big.jpg'),
(49110, 3377, 'Lovestruck in the City [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139222.mp4', 'http://gstaticontent.com/images/cv9gYI0XyLfNJzqJjMEc5lTyxVG_big.jpg'),
(49111, 3377, 'Lovestruck in the City [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139223.mp4', 'http://gstaticontent.com/images/cv9gYI0XyLfNJzqJjMEc5lTyxVG_big.jpg'),
(49112, 3377, 'Lovestruck in the City [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139224.mp4', 'http://gstaticontent.com/images/cv9gYI0XyLfNJzqJjMEc5lTyxVG_big.jpg'),
(49113, 3377, 'Lovestruck in the City [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139225.mp4', 'http://gstaticontent.com/images/cv9gYI0XyLfNJzqJjMEc5lTyxVG_big.jpg'),
(49114, 3377, 'Lovestruck in the City [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/139226.mp4', 'http://gstaticontent.com/images/cv9gYI0XyLfNJzqJjMEc5lTyxVG_big.jpg'),
(49115, 3378, 'Os Suburbanos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139080.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49116, 3378, 'Os Suburbanos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139081.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49117, 3378, 'Os Suburbanos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139082.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49118, 3378, 'Os Suburbanos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139083.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49119, 3378, 'Os Suburbanos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139084.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49120, 3378, 'Os Suburbanos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139085.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49121, 3378, 'Os Suburbanos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139086.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49122, 3378, 'Os Suburbanos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139087.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49123, 3378, 'Os Suburbanos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139088.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49124, 3378, 'Os Suburbanos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139089.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49125, 3378, 'Os Suburbanos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139090.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49126, 3378, 'Os Suburbanos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139091.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49127, 3378, 'Os Suburbanos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139092.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49128, 3378, 'Os Suburbanos S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139093.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49129, 3378, 'Os Suburbanos S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139094.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49130, 3378, 'Os Suburbanos S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139095.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49131, 3378, 'Os Suburbanos S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/139096.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49132, 3378, 'Os Suburbanos S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/139097.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49133, 3378, 'Os Suburbanos S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/139098.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49134, 3378, 'Os Suburbanos S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/139099.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49135, 3379, 'Os Suburbanos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139100.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49136, 3379, 'Os Suburbanos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139101.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49137, 3379, 'Os Suburbanos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139102.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49138, 3379, 'Os Suburbanos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139103.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49139, 3379, 'Os Suburbanos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139104.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49140, 3379, 'Os Suburbanos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139105.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49141, 3379, 'Os Suburbanos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139106.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49142, 3379, 'Os Suburbanos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139107.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49143, 3379, 'Os Suburbanos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139108.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49144, 3379, 'Os Suburbanos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139109.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49145, 3379, 'Os Suburbanos S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139110.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49146, 3379, 'Os Suburbanos S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139111.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49147, 3379, 'Os Suburbanos S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139112.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49148, 3379, 'Os Suburbanos S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139113.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49149, 3379, 'Os Suburbanos S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139114.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49150, 3379, 'Os Suburbanos S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139115.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49151, 3379, 'Os Suburbanos S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/139116.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49152, 3379, 'Os Suburbanos S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/139117.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49153, 3379, 'Os Suburbanos S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/139118.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49154, 3379, 'Os Suburbanos S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/139119.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49155, 3380, 'Os Suburbanos S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139120.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49156, 3380, 'Os Suburbanos S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139121.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49157, 3380, 'Os Suburbanos S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139122.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49158, 3380, 'Os Suburbanos S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139123.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49159, 3380, 'Os Suburbanos S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139124.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49160, 3380, 'Os Suburbanos S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139125.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49161, 3380, 'Os Suburbanos S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139126.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49162, 3380, 'Os Suburbanos S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139127.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49163, 3380, 'Os Suburbanos S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139128.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49164, 3380, 'Os Suburbanos S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139129.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49165, 3380, 'Os Suburbanos S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139130.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49166, 3380, 'Os Suburbanos S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139131.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49167, 3380, 'Os Suburbanos S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139132.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49168, 3380, 'Os Suburbanos S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139133.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49169, 3380, 'Os Suburbanos S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139134.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49170, 3380, 'Os Suburbanos S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139135.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49171, 3380, 'Os Suburbanos S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/139136.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49172, 3380, 'Os Suburbanos S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/139137.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49173, 3380, 'Os Suburbanos S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/139138.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49174, 3380, 'Os Suburbanos S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/139139.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49175, 3380, 'Os Suburbanos S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/139140.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49176, 3380, 'Os Suburbanos S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/139141.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49177, 3380, 'Os Suburbanos S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/139142.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49178, 3380, 'Os Suburbanos S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/139143.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49179, 3380, 'Os Suburbanos S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/139144.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49180, 3380, 'Os Suburbanos S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/139145.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49181, 3380, 'Os Suburbanos S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/139146.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49182, 3380, 'Os Suburbanos S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/139147.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49183, 3380, 'Os Suburbanos S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/139148.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49184, 3380, 'Os Suburbanos S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/139149.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49185, 3381, 'Os Suburbanos S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139150.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49186, 3381, 'Os Suburbanos S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139151.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49187, 3381, 'Os Suburbanos S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139152.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49188, 3381, 'Os Suburbanos S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139153.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49189, 3381, 'Os Suburbanos S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139154.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49190, 3381, 'Os Suburbanos S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139155.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49191, 3381, 'Os Suburbanos S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139156.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49192, 3381, 'Os Suburbanos S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139157.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49193, 3381, 'Os Suburbanos S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139158.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49194, 3381, 'Os Suburbanos S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139159.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49195, 3381, 'Os Suburbanos S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139160.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49196, 3381, 'Os Suburbanos S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139161.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49197, 3381, 'Os Suburbanos S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139162.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49198, 3381, 'Os Suburbanos S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139163.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49199, 3381, 'Os Suburbanos S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139164.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49200, 3381, 'Os Suburbanos S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139165.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49201, 3381, 'Os Suburbanos S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/139166.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49202, 3381, 'Os Suburbanos S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/139167.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49203, 3381, 'Os Suburbanos S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/139168.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49204, 3381, 'Os Suburbanos S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/139169.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49205, 3381, 'Os Suburbanos S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/139170.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49206, 3381, 'Os Suburbanos S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/139171.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49207, 3381, 'Os Suburbanos S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/139172.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49208, 3381, 'Os Suburbanos S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/139173.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49209, 3381, 'Os Suburbanos S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/139174.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49210, 3381, 'Os Suburbanos S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/139175.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49211, 3381, 'Os Suburbanos S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/139176.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49212, 3381, 'Os Suburbanos S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/139177.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49213, 3381, 'Os Suburbanos S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/139178.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49214, 3381, 'Os Suburbanos S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/139179.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49215, 3382, 'Os Suburbanos S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139180.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49216, 3382, 'Os Suburbanos S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139181.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49217, 3382, 'Os Suburbanos S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139182.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49218, 3382, 'Os Suburbanos S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139183.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49219, 3382, 'Os Suburbanos S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139184.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49220, 3382, 'Os Suburbanos S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139185.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49221, 3382, 'Os Suburbanos S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139186.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49222, 3382, 'Os Suburbanos S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139187.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49223, 3382, 'Os Suburbanos S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139188.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49224, 3382, 'Os Suburbanos S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139189.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49225, 3382, 'Os Suburbanos S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139190.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49226, 3382, 'Os Suburbanos S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/139191.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49227, 3382, 'Os Suburbanos S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/139192.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49228, 3382, 'Os Suburbanos S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/139193.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49229, 3382, 'Os Suburbanos S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/139194.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49230, 3382, 'Os Suburbanos S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/139195.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49231, 3382, 'Os Suburbanos S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/139196.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49232, 3382, 'Os Suburbanos S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/139197.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49233, 3382, 'Os Suburbanos S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/139198.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49234, 3382, 'Os Suburbanos S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/139199.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49235, 3382, 'Os Suburbanos S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/139200.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49236, 3382, 'Os Suburbanos S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/139201.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49237, 3382, 'Os Suburbanos S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/139202.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49238, 3382, 'Os Suburbanos S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/139203.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49239, 3382, 'Os Suburbanos S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/139204.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49240, 3382, 'Os Suburbanos S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/139205.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49241, 3382, 'Os Suburbanos S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/139206.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49242, 3382, 'Os Suburbanos S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/139207.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49243, 3382, 'Os Suburbanos S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/139208.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49244, 3382, 'Os Suburbanos S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/139209.mp4', 'http://gstaticontent.com/images/9hsq6C2BYFuvPI4Sy0dOxcmatVF_big.jpg'),
(49245, 3383, 'Eu Danço S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203168.mp4', 'http://gstaticontent.com/images/6db8cd9717defaaaed9adff27c87fccf.jpg'),
(49246, 3383, 'Eu Danço S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203169.mp4', 'http://gstaticontent.com/images/6db8cd9717defaaaed9adff27c87fccf.jpg'),
(49247, 3383, 'Eu Danço S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203170.mp4', 'http://gstaticontent.com/images/6db8cd9717defaaaed9adff27c87fccf.jpg'),
(49248, 3383, 'Eu Danço S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203171.mp4', 'http://gstaticontent.com/images/6db8cd9717defaaaed9adff27c87fccf.jpg'),
(49249, 3383, 'Eu Danço S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203172.mp4', 'http://gstaticontent.com/images/6db8cd9717defaaaed9adff27c87fccf.jpg'),
(49250, 3383, 'Eu Danço S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203173.mp4', 'http://gstaticontent.com/images/6db8cd9717defaaaed9adff27c87fccf.jpg'),
(49251, 3383, 'Eu Danço S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203174.mp4', 'http://gstaticontent.com/images/6db8cd9717defaaaed9adff27c87fccf.jpg'),
(49252, 3383, 'Eu Danço S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203175.mp4', 'http://gstaticontent.com/images/6db8cd9717defaaaed9adff27c87fccf.jpg'),
(49253, 3383, 'Eu Danço S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203176.mp4', 'http://gstaticontent.com/images/6db8cd9717defaaaed9adff27c87fccf.jpg'),
(49254, 3383, 'Eu Danço S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203177.mp4', 'http://gstaticontent.com/images/6db8cd9717defaaaed9adff27c87fccf.jpg'),
(49255, 3384, 'Eu Danço S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203178.mp4', 'http://gstaticontent.com/images/6db8cd9717defaaaed9adff27c87fccf.jpg'),
(49256, 3384, 'Eu Danço S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203179.mp4', 'http://gstaticontent.com/images/6db8cd9717defaaaed9adff27c87fccf.jpg'),
(49257, 3384, 'Eu Danço S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203180.mp4', 'http://gstaticontent.com/images/6db8cd9717defaaaed9adff27c87fccf.jpg'),
(49258, 3384, 'Eu Danço S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203181.mp4', 'http://gstaticontent.com/images/6db8cd9717defaaaed9adff27c87fccf.jpg'),
(49259, 3384, 'Eu Danço S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203182.mp4', 'http://gstaticontent.com/images/6db8cd9717defaaaed9adff27c87fccf.jpg'),
(49260, 3384, 'Eu Danço S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203183.mp4', 'http://gstaticontent.com/images/6db8cd9717defaaaed9adff27c87fccf.jpg'),
(49261, 3384, 'Eu Danço S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203184.mp4', 'http://gstaticontent.com/images/6db8cd9717defaaaed9adff27c87fccf.jpg'),
(49262, 3384, 'Eu Danço S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203185.mp4', 'http://gstaticontent.com/images/6db8cd9717defaaaed9adff27c87fccf.jpg'),
(49263, 3384, 'Eu Danço S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203186.mp4', 'http://gstaticontent.com/images/6db8cd9717defaaaed9adff27c87fccf.jpg'),
(49264, 3384, 'Eu Danço S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203187.mp4', 'http://gstaticontent.com/images/6db8cd9717defaaaed9adff27c87fccf.jpg'),
(49265, 3385, 'Eu Danço S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4T7rK1r9xyKrsECkhDOA1LYBgGD.jpg'),
(49266, 3385, 'Eu Danço S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tuzcvP6pBYYgqNga7dCFNrwD1xc.jpg'),
(49267, 3385, 'Eu Danço S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Ri8LP3UZNwVzgjaUEJ7JAmWVe5.jpg'),
(49268, 3385, 'Eu Danço S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l1sJUUmsy1qFKC5vvQ6UORwFpj.jpg'),
(49269, 3385, 'Eu Danço S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1yx0ieetOIlUe5rcXNoLvAD7ESp.jpg'),
(49270, 3385, 'Eu Danço S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mIblJeI7xuA2pxPpbI8546DawT2.jpg'),
(49271, 3385, 'Eu Danço S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sXN8dXhmkKaa0mblEiX3BwdHYjo.jpg'),
(49272, 3385, 'Eu Danço S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Z2FbVEe9aO35IcqsNzAyXczMD3.jpg'),
(49273, 3385, 'Eu Danço S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iM3cpcUOPetSPG2JUL5bASiLnxp.jpg'),
(49274, 3385, 'Eu Danço S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/soOrGOgaCOil35ochCoLSB9U2rN.jpg'),
(49275, 3386, 'The Drowning [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138783.mp4', 'http://gstaticontent.com/images/7jdOyS9OXbtobEYDl8Z4V4iWaH3_big.jpg'),
(49276, 3386, 'The Drowning [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138784.mp4', 'http://gstaticontent.com/images/7jdOyS9OXbtobEYDl8Z4V4iWaH3_big.jpg'),
(49277, 3386, 'The Drowning [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138785.mp4', 'http://gstaticontent.com/images/7jdOyS9OXbtobEYDl8Z4V4iWaH3_big.jpg'),
(49278, 3386, 'The Drowning [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138786.mp4', 'http://gstaticontent.com/images/7jdOyS9OXbtobEYDl8Z4V4iWaH3_big.jpg'),
(49279, 3387, 'TONIKAWA: Over The Moon For You S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219958.mp4', 'http://gstaticontent.com/images/oeBvxDQoYlw9c5Smt4kh4OAXHdg_big.jpg'),
(49280, 3387, 'TONIKAWA: Over The Moon For You S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219959.mp4', 'http://gstaticontent.com/images/oeBvxDQoYlw9c5Smt4kh4OAXHdg_big.jpg'),
(49281, 3387, 'TONIKAWA: Over The Moon For You S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219960.mp4', 'http://gstaticontent.com/images/oeBvxDQoYlw9c5Smt4kh4OAXHdg_big.jpg'),
(49282, 3387, 'TONIKAWA: Over The Moon For You S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219961.mp4', 'http://gstaticontent.com/images/oeBvxDQoYlw9c5Smt4kh4OAXHdg_big.jpg'),
(49283, 3387, 'TONIKAWA: Over The Moon For You S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219962.mp4', 'http://gstaticontent.com/images/oeBvxDQoYlw9c5Smt4kh4OAXHdg_big.jpg'),
(49284, 3387, 'TONIKAWA: Over The Moon For You S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219963.mp4', 'http://gstaticontent.com/images/oeBvxDQoYlw9c5Smt4kh4OAXHdg_big.jpg'),
(49285, 3387, 'TONIKAWA: Over The Moon For You S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219964.mp4', 'http://gstaticontent.com/images/oeBvxDQoYlw9c5Smt4kh4OAXHdg_big.jpg'),
(49286, 3387, 'TONIKAWA: Over The Moon For You S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219965.mp4', 'http://gstaticontent.com/images/oeBvxDQoYlw9c5Smt4kh4OAXHdg_big.jpg'),
(49287, 3387, 'TONIKAWA: Over The Moon For You S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219966.mp4', 'http://gstaticontent.com/images/oeBvxDQoYlw9c5Smt4kh4OAXHdg_big.jpg'),
(49288, 3387, 'TONIKAWA: Over The Moon For You S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219967.mp4', 'http://gstaticontent.com/images/oeBvxDQoYlw9c5Smt4kh4OAXHdg_big.jpg'),
(49289, 3387, 'TONIKAWA: Over The Moon For You S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219968.mp4', 'http://gstaticontent.com/images/oeBvxDQoYlw9c5Smt4kh4OAXHdg_big.jpg'),
(49290, 3387, 'TONIKAWA: Over The Moon For You S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219969.mp4', 'http://gstaticontent.com/images/oeBvxDQoYlw9c5Smt4kh4OAXHdg_big.jpg'),
(49291, 3388, 'TONIKAWA: Over The Moon For You S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219970.mp4', 'http://gstaticontent.com/images/oeBvxDQoYlw9c5Smt4kh4OAXHdg_big.jpg'),
(49292, 3388, 'TONIKAWA: Over The Moon For You S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l18nsW97uzjHkYh1BBW8tzAFaFZ.jpg'),
(49293, 3388, 'TONIKAWA: Over The Moon For You S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9RYPoBBQf7esuJfsMssiG07X0Zf.jpg'),
(49294, 3388, 'TONIKAWA: Over The Moon For You S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nhHtZaUBva55NOtlTwH2dvjupRu.jpg'),
(49295, 3388, 'TONIKAWA: Over The Moon For You S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v57aN1MpcZya8Gs5tx63aF8A1HY.jpg'),
(49296, 3388, 'TONIKAWA: Over The Moon For You S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r1QSFTj8jVkn0jIztxV1eNZ3kqH.jpg'),
(49297, 3388, 'TONIKAWA: Over The Moon For You S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4tSulsJBvOVVU1YsfcqEj5MifP1.jpg'),
(49298, 3388, 'TONIKAWA: Over The Moon For You S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n4RlY7xqOvGmd6PjCcXgJ7nesYt.jpg'),
(49299, 3388, 'TONIKAWA: Over The Moon For You S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219978.mp4', 'http://image.tmdb.org/t/p/w1280/t7muNDWJlITMf45mE0NDP6fWzY0.jpg'),
(49300, 3388, 'TONIKAWA: Over The Moon For You S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219979.mp4', 'http://image.tmdb.org/t/p/w1280/DdgjSEhEej3zALKOWv4SZSGatj.jpg'),
(49301, 3388, 'TONIKAWA: Over The Moon For You S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219980.mp4', 'http://image.tmdb.org/t/p/w1280/5L6kVKWwnY28ophQP5cTYI8KkR4.jpg'),
(49302, 3388, 'TONIKAWA: Over The Moon For You S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219981.mp4', 'http://gstaticontent.com/images/oeBvxDQoYlw9c5Smt4kh4OAXHdg_big.jpg'),
(49303, 3388, 'TONIKAWA: Over The Moon For You S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219982.mp4', 'http://image.tmdb.org/t/p/w1280/1xrv7yvfd629YLKYOTC8TeNTqUx.jpg'),
(49304, 3389, 'Histórias para Vestir S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139060.mp4', 'http://gstaticontent.com/images/mDwYQ4MJ92hWtk8lTurUnJHSAJs_big.jpg'),
(49305, 3389, 'Histórias para Vestir S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139061.mp4', 'http://gstaticontent.com/images/mDwYQ4MJ92hWtk8lTurUnJHSAJs_big.jpg'),
(49306, 3389, 'Histórias para Vestir S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139062.mp4', 'http://gstaticontent.com/images/mDwYQ4MJ92hWtk8lTurUnJHSAJs_big.jpg'),
(49307, 3389, 'Histórias para Vestir S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139063.mp4', 'http://gstaticontent.com/images/mDwYQ4MJ92hWtk8lTurUnJHSAJs_big.jpg'),
(49308, 3389, 'Histórias para Vestir S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139064.mp4', 'http://gstaticontent.com/images/mDwYQ4MJ92hWtk8lTurUnJHSAJs_big.jpg'),
(49309, 3389, 'Histórias para Vestir S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139065.mp4', 'http://gstaticontent.com/images/mDwYQ4MJ92hWtk8lTurUnJHSAJs_big.jpg'),
(49310, 3389, 'Histórias para Vestir S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139066.mp4', 'http://gstaticontent.com/images/mDwYQ4MJ92hWtk8lTurUnJHSAJs_big.jpg'),
(49311, 3389, 'Histórias para Vestir S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139067.mp4', 'http://gstaticontent.com/images/mDwYQ4MJ92hWtk8lTurUnJHSAJs_big.jpg'),
(49312, 3390, 'Quiz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139057.mp4', 'http://gstaticontent.com/images/yCHBUpRwtRpGuIRy0bMGSc5Xd1I_big.jpg'),
(49313, 3390, 'Quiz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139058.mp4', 'http://gstaticontent.com/images/yCHBUpRwtRpGuIRy0bMGSc5Xd1I_big.jpg'),
(49314, 3390, 'Quiz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139059.mp4', 'http://gstaticontent.com/images/yCHBUpRwtRpGuIRy0bMGSc5Xd1I_big.jpg'),
(49315, 3391, '5x Comédia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139052.mp4', 'http://gstaticontent.com/images/zQqES8kCd4p10bwIRL3E0m4HYei_big.jpg'),
(49316, 3391, '5x Comédia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139053.mp4', 'http://gstaticontent.com/images/zQqES8kCd4p10bwIRL3E0m4HYei_big.jpg'),
(49317, 3391, '5x Comédia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139054.mp4', 'http://gstaticontent.com/images/zQqES8kCd4p10bwIRL3E0m4HYei_big.jpg'),
(49318, 3391, '5x Comédia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139055.mp4', 'http://gstaticontent.com/images/zQqES8kCd4p10bwIRL3E0m4HYei_big.jpg'),
(49319, 3391, '5x Comédia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139056.mp4', 'http://gstaticontent.com/images/zQqES8kCd4p10bwIRL3E0m4HYei_big.jpg'),
(49320, 3392, '5x Comédia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/443188.mp4', 'http://gstaticontent.com/images/zQqES8kCd4p10bwIRL3E0m4HYei_big.jpg'),
(49321, 3392, '5x Comédia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/443189.mp4', 'http://gstaticontent.com/images/zQqES8kCd4p10bwIRL3E0m4HYei_big.jpg'),
(49322, 3392, '5x Comédia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/443190.mp4', 'http://gstaticontent.com/images/zQqES8kCd4p10bwIRL3E0m4HYei_big.jpg'),
(49323, 3392, '5x Comédia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/443191.mp4', 'http://gstaticontent.com/images/zQqES8kCd4p10bwIRL3E0m4HYei_big.jpg'),
(49324, 3392, '5x Comédia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/443192.mp4', 'http://gstaticontent.com/images/zQqES8kCd4p10bwIRL3E0m4HYei_big.jpg'),
(49325, 3393, 'Terapia de Casal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139042.mp4', 'http://gstaticontent.com/images/rYN2JRrfUZfxLhcQtQC0QTTLR3Q_big.jpg'),
(49326, 3393, 'Terapia de Casal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139043.mp4', 'http://gstaticontent.com/images/rYN2JRrfUZfxLhcQtQC0QTTLR3Q_big.jpg'),
(49327, 3393, 'Terapia de Casal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139044.mp4', 'http://gstaticontent.com/images/rYN2JRrfUZfxLhcQtQC0QTTLR3Q_big.jpg'),
(49328, 3393, 'Terapia de Casal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139045.mp4', 'http://gstaticontent.com/images/rYN2JRrfUZfxLhcQtQC0QTTLR3Q_big.jpg'),
(49329, 3393, 'Terapia de Casal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139046.mp4', 'http://gstaticontent.com/images/rYN2JRrfUZfxLhcQtQC0QTTLR3Q_big.jpg'),
(49330, 3393, 'Terapia de Casal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139047.mp4', 'http://gstaticontent.com/images/rYN2JRrfUZfxLhcQtQC0QTTLR3Q_big.jpg'),
(49331, 3393, 'Terapia de Casal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139048.mp4', 'http://gstaticontent.com/images/rYN2JRrfUZfxLhcQtQC0QTTLR3Q_big.jpg'),
(49332, 3393, 'Terapia de Casal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139049.mp4', 'http://gstaticontent.com/images/rYN2JRrfUZfxLhcQtQC0QTTLR3Q_big.jpg'),
(49333, 3393, 'Terapia de Casal S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139050.mp4', 'http://gstaticontent.com/images/rYN2JRrfUZfxLhcQtQC0QTTLR3Q_big.jpg'),
(49334, 3393, 'Terapia de Casal S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139051.mp4', 'http://gstaticontent.com/images/rYN2JRrfUZfxLhcQtQC0QTTLR3Q_big.jpg'),
(49335, 3394, 'O Paraíso e a Serpente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139034.mp4', 'http://gstaticontent.com/images/vbaen62LtRtEmrQjE7EkZ1pnQyI_big.jpg'),
(49336, 3394, 'O Paraíso e a Serpente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139035.mp4', 'http://gstaticontent.com/images/vbaen62LtRtEmrQjE7EkZ1pnQyI_big.jpg'),
(49337, 3394, 'O Paraíso e a Serpente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139036.mp4', 'http://gstaticontent.com/images/vbaen62LtRtEmrQjE7EkZ1pnQyI_big.jpg'),
(49338, 3394, 'O Paraíso e a Serpente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139037.mp4', 'http://gstaticontent.com/images/vbaen62LtRtEmrQjE7EkZ1pnQyI_big.jpg'),
(49339, 3394, 'O Paraíso e a Serpente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139038.mp4', 'http://gstaticontent.com/images/vbaen62LtRtEmrQjE7EkZ1pnQyI_big.jpg'),
(49340, 3394, 'O Paraíso e a Serpente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139039.mp4', 'http://gstaticontent.com/images/vbaen62LtRtEmrQjE7EkZ1pnQyI_big.jpg'),
(49341, 3394, 'O Paraíso e a Serpente S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139040.mp4', 'http://gstaticontent.com/images/vbaen62LtRtEmrQjE7EkZ1pnQyI_big.jpg'),
(49342, 3394, 'O Paraíso e a Serpente S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139041.mp4', 'http://gstaticontent.com/images/vbaen62LtRtEmrQjE7EkZ1pnQyI_big.jpg'),
(49343, 3395, 'American Crime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139005.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49344, 3395, 'American Crime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139006.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49345, 3395, 'American Crime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139007.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49346, 3395, 'American Crime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139008.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49347, 3395, 'American Crime S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139009.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49348, 3395, 'American Crime S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139010.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49349, 3395, 'American Crime S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139011.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49350, 3395, 'American Crime S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139012.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49351, 3395, 'American Crime S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139013.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49352, 3395, 'American Crime S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139014.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49353, 3395, 'American Crime S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/139015.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49354, 3396, 'American Crime S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139016.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49355, 3396, 'American Crime S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139017.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49356, 3396, 'American Crime S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139018.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49357, 3396, 'American Crime S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139019.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(49358, 3396, 'American Crime S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139020.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49359, 3396, 'American Crime S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139021.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49360, 3396, 'American Crime S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139022.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49361, 3396, 'American Crime S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139023.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49362, 3396, 'American Crime S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/139024.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49363, 3396, 'American Crime S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/139025.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49364, 3397, 'American Crime S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/139026.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49365, 3397, 'American Crime S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/139027.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49366, 3397, 'American Crime S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/139028.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49367, 3397, 'American Crime S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139029.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49368, 3397, 'American Crime S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139030.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49369, 3397, 'American Crime S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139031.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49370, 3397, 'American Crime S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139032.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49371, 3397, 'American Crime S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139033.mp4', 'http://gstaticontent.com/images/6jmWZxDTyVr51sHZUlTjvzhFEzt_big.jpg'),
(49372, 3398, 'Cinquentinha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138997.mp4', 'https://i.bj-share.info/61f3cd932677cdbbf0d0b7651452ce66.jpg'),
(49373, 3398, 'Cinquentinha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138998.mp4', 'https://i.bj-share.info/61f3cd932677cdbbf0d0b7651452ce66.jpg'),
(49374, 3398, 'Cinquentinha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138999.mp4', 'https://i.bj-share.info/61f3cd932677cdbbf0d0b7651452ce66.jpg'),
(49375, 3398, 'Cinquentinha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/139000.mp4', 'https://i.bj-share.info/61f3cd932677cdbbf0d0b7651452ce66.jpg'),
(49376, 3398, 'Cinquentinha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/139001.mp4', 'https://i.bj-share.info/61f3cd932677cdbbf0d0b7651452ce66.jpg'),
(49377, 3398, 'Cinquentinha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/139002.mp4', 'https://i.bj-share.info/61f3cd932677cdbbf0d0b7651452ce66.jpg'),
(49378, 3398, 'Cinquentinha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/139003.mp4', 'https://i.bj-share.info/61f3cd932677cdbbf0d0b7651452ce66.jpg'),
(49379, 3398, 'Cinquentinha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/139004.mp4', 'https://i.bj-share.info/61f3cd932677cdbbf0d0b7651452ce66.jpg'),
(49380, 3399, 'Foodie Love S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138989.mp4', 'http://gstaticontent.com/images/eJkekj427HeYuUYPU90wRhbWB01_big.jpg'),
(49381, 3399, 'Foodie Love S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138990.mp4', 'http://gstaticontent.com/images/eJkekj427HeYuUYPU90wRhbWB01_big.jpg'),
(49382, 3399, 'Foodie Love S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138991.mp4', 'http://gstaticontent.com/images/eJkekj427HeYuUYPU90wRhbWB01_big.jpg'),
(49383, 3399, 'Foodie Love S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138992.mp4', 'http://gstaticontent.com/images/eJkekj427HeYuUYPU90wRhbWB01_big.jpg'),
(49384, 3399, 'Foodie Love S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138993.mp4', 'http://gstaticontent.com/images/eJkekj427HeYuUYPU90wRhbWB01_big.jpg'),
(49385, 3399, 'Foodie Love S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138994.mp4', 'http://gstaticontent.com/images/eJkekj427HeYuUYPU90wRhbWB01_big.jpg'),
(49386, 3399, 'Foodie Love S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138995.mp4', 'http://gstaticontent.com/images/eJkekj427HeYuUYPU90wRhbWB01_big.jpg'),
(49387, 3399, 'Foodie Love S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138996.mp4', 'http://gstaticontent.com/images/eJkekj427HeYuUYPU90wRhbWB01_big.jpg'),
(49388, 3400, 'Gravity Falls: Um Verão de Mistérios S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138948.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49389, 3400, 'Gravity Falls: Um Verão de Mistérios S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138949.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49390, 3400, 'Gravity Falls: Um Verão de Mistérios S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138950.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49391, 3400, 'Gravity Falls: Um Verão de Mistérios S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138951.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49392, 3400, 'Gravity Falls: Um Verão de Mistérios S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138952.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49393, 3400, 'Gravity Falls: Um Verão de Mistérios S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138953.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49394, 3400, 'Gravity Falls: Um Verão de Mistérios S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138954.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49395, 3400, 'Gravity Falls: Um Verão de Mistérios S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138955.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49396, 3400, 'Gravity Falls: Um Verão de Mistérios S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138956.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49397, 3400, 'Gravity Falls: Um Verão de Mistérios S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138957.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49398, 3400, 'Gravity Falls: Um Verão de Mistérios S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138958.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49399, 3400, 'Gravity Falls: Um Verão de Mistérios S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138959.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49400, 3400, 'Gravity Falls: Um Verão de Mistérios S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/138960.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49401, 3400, 'Gravity Falls: Um Verão de Mistérios S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/138961.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49402, 3400, 'Gravity Falls: Um Verão de Mistérios S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/138962.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49403, 3400, 'Gravity Falls: Um Verão de Mistérios S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/138963.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49404, 3400, 'Gravity Falls: Um Verão de Mistérios S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/138964.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49405, 3400, 'Gravity Falls: Um Verão de Mistérios S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/138965.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49406, 3400, 'Gravity Falls: Um Verão de Mistérios S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/138966.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49407, 3400, 'Gravity Falls: Um Verão de Mistérios S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/138967.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49408, 3401, 'Gravity Falls: Um Verão de Mistérios S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138968.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49409, 3401, 'Gravity Falls: Um Verão de Mistérios S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138969.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49410, 3401, 'Gravity Falls: Um Verão de Mistérios S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138970.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49411, 3401, 'Gravity Falls: Um Verão de Mistérios S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138971.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49412, 3401, 'Gravity Falls: Um Verão de Mistérios S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138972.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49413, 3401, 'Gravity Falls: Um Verão de Mistérios S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138973.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49414, 3401, 'Gravity Falls: Um Verão de Mistérios S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138974.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49415, 3401, 'Gravity Falls: Um Verão de Mistérios S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138975.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49416, 3401, 'Gravity Falls: Um Verão de Mistérios S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138976.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49417, 3401, 'Gravity Falls: Um Verão de Mistérios S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138977.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49418, 3401, 'Gravity Falls: Um Verão de Mistérios S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138978.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49419, 3401, 'Gravity Falls: Um Verão de Mistérios S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138979.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49420, 3401, 'Gravity Falls: Um Verão de Mistérios S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/138980.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49421, 3401, 'Gravity Falls: Um Verão de Mistérios S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/138981.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49422, 3401, 'Gravity Falls: Um Verão de Mistérios S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/138982.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49423, 3401, 'Gravity Falls: Um Verão de Mistérios S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/138983.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49424, 3401, 'Gravity Falls: Um Verão de Mistérios S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/138984.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49425, 3401, 'Gravity Falls: Um Verão de Mistérios S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/138985.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49426, 3401, 'Gravity Falls: Um Verão de Mistérios S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/138986.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49427, 3401, 'Gravity Falls: Um Verão de Mistérios S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/138987.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49428, 3401, 'Gravity Falls: Um Verão de Mistérios S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/138988.mp4', 'http://gstaticontent.com/images/skWAvD7EnS8gpek3AwOHwzhYxN1_big.jpg'),
(49429, 3402, 'Invencível S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250538.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49430, 3402, 'Invencível S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250539.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49431, 3402, 'Invencível S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250540.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49432, 3402, 'Invencível S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250541.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49433, 3402, 'Invencível S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250542.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49434, 3402, 'Invencível S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250543.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49435, 3402, 'Invencível S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250544.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49436, 3402, 'Invencível S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250545.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49437, 3403, 'Invencível S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250546.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49438, 3403, 'Invencível S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250547.mp4', 'http://image.tmdb.org/t/p/w1280/u4DNejee7zd9UJBMj6eqHocyykP.jpg'),
(49439, 3403, 'Invencível S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250548.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49440, 3403, 'Invencível S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250549.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49441, 3403, 'Invencível S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250550.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49442, 3403, 'Invencível S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/299940.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49443, 3403, 'Invencível S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/304596.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49444, 3403, 'Invencível S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/313295.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49445, 3403, 'Invencível S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/319593.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49446, 3404, 'Invencível S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/687390.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49447, 3404, 'Invencível S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/687391.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49448, 3404, 'Invencível S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/687392.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49449, 3404, 'Invencível S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/695896.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49450, 3404, 'Invencível S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/701676.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49451, 3404, 'Invencível S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/714677.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49452, 3404, 'Invencível S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/718079.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49453, 3404, 'Invencível S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/724552.mp4', 'http://gstaticontent.com/images/yDWJYRAwMNKbIYT8ZB33qy84uzO_big.jpg'),
(49454, 3405, 'O Dentista Mascarado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138936.mp4', 'http://gstaticontent.com/images/xVpb7cl3MKrjwRx68I8kS5Lz9VP_big.jpg'),
(49455, 3405, 'O Dentista Mascarado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138937.mp4', 'http://gstaticontent.com/images/xVpb7cl3MKrjwRx68I8kS5Lz9VP_big.jpg'),
(49456, 3405, 'O Dentista Mascarado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138938.mp4', 'http://gstaticontent.com/images/xVpb7cl3MKrjwRx68I8kS5Lz9VP_big.jpg'),
(49457, 3405, 'O Dentista Mascarado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138939.mp4', 'http://gstaticontent.com/images/xVpb7cl3MKrjwRx68I8kS5Lz9VP_big.jpg'),
(49458, 3405, 'O Dentista Mascarado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138940.mp4', 'http://gstaticontent.com/images/xVpb7cl3MKrjwRx68I8kS5Lz9VP_big.jpg'),
(49459, 3405, 'O Dentista Mascarado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138941.mp4', 'http://gstaticontent.com/images/xVpb7cl3MKrjwRx68I8kS5Lz9VP_big.jpg'),
(49460, 3405, 'O Dentista Mascarado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138942.mp4', 'http://gstaticontent.com/images/xVpb7cl3MKrjwRx68I8kS5Lz9VP_big.jpg'),
(49461, 3405, 'O Dentista Mascarado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138943.mp4', 'http://gstaticontent.com/images/xVpb7cl3MKrjwRx68I8kS5Lz9VP_big.jpg'),
(49462, 3405, 'O Dentista Mascarado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138944.mp4', 'http://gstaticontent.com/images/xVpb7cl3MKrjwRx68I8kS5Lz9VP_big.jpg'),
(49463, 3405, 'O Dentista Mascarado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138945.mp4', 'http://gstaticontent.com/images/xVpb7cl3MKrjwRx68I8kS5Lz9VP_big.jpg'),
(49464, 3405, 'O Dentista Mascarado S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138946.mp4', 'http://gstaticontent.com/images/xVpb7cl3MKrjwRx68I8kS5Lz9VP_big.jpg'),
(49465, 3405, 'O Dentista Mascarado S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138947.mp4', 'http://gstaticontent.com/images/xVpb7cl3MKrjwRx68I8kS5Lz9VP_big.jpg'),
(49466, 3406, 'Sanditon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213703.mp4', 'http://gstaticontent.com/images/iHavixVXjEHNy3fWyVtiE3bN4NK_big.jpg'),
(49467, 3406, 'Sanditon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213704.mp4', 'http://gstaticontent.com/images/iHavixVXjEHNy3fWyVtiE3bN4NK_big.jpg'),
(49468, 3406, 'Sanditon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213705.mp4', 'http://gstaticontent.com/images/iHavixVXjEHNy3fWyVtiE3bN4NK_big.jpg'),
(49469, 3406, 'Sanditon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213706.mp4', 'http://gstaticontent.com/images/iHavixVXjEHNy3fWyVtiE3bN4NK_big.jpg'),
(49470, 3406, 'Sanditon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213707.mp4', 'http://gstaticontent.com/images/iHavixVXjEHNy3fWyVtiE3bN4NK_big.jpg'),
(49471, 3406, 'Sanditon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213708.mp4', 'http://gstaticontent.com/images/iHavixVXjEHNy3fWyVtiE3bN4NK_big.jpg'),
(49472, 3406, 'Sanditon S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213709.mp4', 'http://gstaticontent.com/images/iHavixVXjEHNy3fWyVtiE3bN4NK_big.jpg'),
(49473, 3406, 'Sanditon S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213710.mp4', 'http://gstaticontent.com/images/iHavixVXjEHNy3fWyVtiE3bN4NK_big.jpg'),
(49474, 3407, 'Sanditon S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i4pHpq8Rw3jxQynixTXKWPiGAKF.jpg'),
(49475, 3407, 'Sanditon S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2rNgeuBrPc1rYcDEa5fT3ZDg2SN.jpg'),
(49476, 3407, 'Sanditon S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAv5AsD1w2CVhMJxzSuYSfgtEe7.jpg'),
(49477, 3407, 'Sanditon S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n4Uns9IQ7EvRsLfrzN9r3biW8EL.jpg'),
(49478, 3407, 'Sanditon S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xCPU6r8XIux3tUOkQwUkeyodKVh.jpg'),
(49479, 3407, 'Sanditon S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rSHzvEgD9DZY1zF8mU7H0IXRfn3.jpg'),
(49480, 3408, 'Sanditon S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6PIKaFPwqvDLaupMssoTxnuzeF5.jpg'),
(49481, 3408, 'Sanditon S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mUIgtAolLle1Y0NxNTiT1uQDonO.jpg'),
(49482, 3408, 'Sanditon S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xLNWXGjdhVYR68quufLgCTqV51p.jpg'),
(49483, 3408, 'Sanditon S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/avoXwFd965UKWjxi5euccIJ5qMJ.jpg'),
(49484, 3408, 'Sanditon S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x6E4WZtGEMkbs0w2rVuwPrClrQN.jpg'),
(49485, 3408, 'Sanditon S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ce64yFlj0bm5v22wlBDZZPPKP6.jpg'),
(49486, 3409, 'Sky Rojo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207859.mp4', 'http://gstaticontent.com/images/uTFX9V2dct1nKjG6zhNiThPm8Tp_big.jpg'),
(49487, 3409, 'Sky Rojo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207860.mp4', 'http://gstaticontent.com/images/uTFX9V2dct1nKjG6zhNiThPm8Tp_big.jpg'),
(49488, 3409, 'Sky Rojo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207861.mp4', 'http://gstaticontent.com/images/uTFX9V2dct1nKjG6zhNiThPm8Tp_big.jpg'),
(49489, 3409, 'Sky Rojo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207862.mp4', 'http://gstaticontent.com/images/uTFX9V2dct1nKjG6zhNiThPm8Tp_big.jpg'),
(49490, 3409, 'Sky Rojo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207863.mp4', 'http://gstaticontent.com/images/uTFX9V2dct1nKjG6zhNiThPm8Tp_big.jpg'),
(49491, 3409, 'Sky Rojo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207864.mp4', 'http://gstaticontent.com/images/uTFX9V2dct1nKjG6zhNiThPm8Tp_big.jpg'),
(49492, 3409, 'Sky Rojo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207865.mp4', 'http://gstaticontent.com/images/uTFX9V2dct1nKjG6zhNiThPm8Tp_big.jpg'),
(49493, 3409, 'Sky Rojo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207866.mp4', 'http://gstaticontent.com/images/uTFX9V2dct1nKjG6zhNiThPm8Tp_big.jpg'),
(49494, 3410, 'Sky Rojo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207867.mp4', 'http://timg.bdta.pro/images/e445768f6fd6d4aea5d5c9d766cfcf78.jpg'),
(49495, 3410, 'Sky Rojo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207868.mp4', 'http://timg.bdta.pro/images/e3b8f33913a87e72072bd3e645fb267c.jpg'),
(49496, 3410, 'Sky Rojo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207869.mp4', 'http://timg.bdta.pro/images/53b3c9c9080e0ba5ab95dab91b829f99.jpg'),
(49497, 3410, 'Sky Rojo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207870.mp4', 'http://timg.bdta.pro/images/f385401a930af8f0053502a41ae59481.jpg'),
(49498, 3410, 'Sky Rojo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207871.mp4', 'http://timg.bdta.pro/images/663115467c0d2d12b05a03d65759c24b.jpg'),
(49499, 3410, 'Sky Rojo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207872.mp4', 'http://timg.bdta.pro/images/2655168c2f4f370344fc4af209eec4f7.jpg'),
(49500, 3410, 'Sky Rojo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207873.mp4', 'http://timg.bdta.pro/images/1fedf7eae63fcfcb2e68139097e118bb.jpg'),
(49501, 3410, 'Sky Rojo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207874.mp4', 'http://timg.bdta.pro/images/2522ce2dab9df343faed638a7495cf06.jpg'),
(49502, 3411, 'Sky Rojo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vYPbSsnEenh5n23B4vj9bA01GAn.jpg'),
(49503, 3411, 'Sky Rojo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cu6rfyoDz8xXw7uOafEDDsR9FnL.jpg'),
(49504, 3411, 'Sky Rojo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBN7XzZ98sVFpGUbZHLEwSAh8Rf.jpg'),
(49505, 3411, 'Sky Rojo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oPSByp6dvlTszpRJogNhPajXKKI.jpg'),
(49506, 3411, 'Sky Rojo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Ej9FPAB3ZOVXfAQ3lHSEUJorMB.jpg'),
(49507, 3411, 'Sky Rojo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nXYCVOo99FSDWHMgieDE1FbrMij.jpg'),
(49508, 3411, 'Sky Rojo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9vAYp6ZmcQUjt5h0KgpoFNpjBL3.jpg'),
(49509, 3411, 'Sky Rojo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/16VoRPwC197IJ3iupLloSDNX3fo.jpg'),
(49510, 3412, 'Atlanta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138903.mp4', 'http://gstaticontent.com/images/lXMmcrGK5QL7Xc1SjmzutIQoA1I_big.jpg'),
(49511, 3412, 'Atlanta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138904.mp4', 'http://gstaticontent.com/images/lXMmcrGK5QL7Xc1SjmzutIQoA1I_big.jpg'),
(49512, 3412, 'Atlanta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138905.mp4', 'http://gstaticontent.com/images/lXMmcrGK5QL7Xc1SjmzutIQoA1I_big.jpg'),
(49513, 3412, 'Atlanta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138906.mp4', 'http://gstaticontent.com/images/lXMmcrGK5QL7Xc1SjmzutIQoA1I_big.jpg'),
(49514, 3412, 'Atlanta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138907.mp4', 'http://gstaticontent.com/images/lXMmcrGK5QL7Xc1SjmzutIQoA1I_big.jpg'),
(49515, 3412, 'Atlanta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138908.mp4', 'http://gstaticontent.com/images/lXMmcrGK5QL7Xc1SjmzutIQoA1I_big.jpg'),
(49516, 3412, 'Atlanta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138909.mp4', 'http://gstaticontent.com/images/lXMmcrGK5QL7Xc1SjmzutIQoA1I_big.jpg'),
(49517, 3412, 'Atlanta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138910.mp4', 'http://gstaticontent.com/images/lXMmcrGK5QL7Xc1SjmzutIQoA1I_big.jpg'),
(49518, 3412, 'Atlanta S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138911.mp4', 'http://gstaticontent.com/images/lXMmcrGK5QL7Xc1SjmzutIQoA1I_big.jpg'),
(49519, 3412, 'Atlanta S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138912.mp4', 'http://gstaticontent.com/images/lXMmcrGK5QL7Xc1SjmzutIQoA1I_big.jpg'),
(49520, 3413, 'Atlanta S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138913.mp4', 'http://gstaticontent.com/images/lXMmcrGK5QL7Xc1SjmzutIQoA1I_big.jpg'),
(49521, 3413, 'Atlanta S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138914.mp4', 'http://gstaticontent.com/images/lXMmcrGK5QL7Xc1SjmzutIQoA1I_big.jpg'),
(49522, 3413, 'Atlanta S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138915.mp4', 'http://gstaticontent.com/images/lXMmcrGK5QL7Xc1SjmzutIQoA1I_big.jpg'),
(49523, 3413, 'Atlanta S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138916.mp4', 'http://gstaticontent.com/images/lXMmcrGK5QL7Xc1SjmzutIQoA1I_big.jpg'),
(49524, 3413, 'Atlanta S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138917.mp4', 'http://gstaticontent.com/images/lXMmcrGK5QL7Xc1SjmzutIQoA1I_big.jpg'),
(49525, 3413, 'Atlanta S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138918.mp4', 'http://gstaticontent.com/images/lXMmcrGK5QL7Xc1SjmzutIQoA1I_big.jpg'),
(49526, 3413, 'Atlanta S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138919.mp4', 'http://gstaticontent.com/images/lXMmcrGK5QL7Xc1SjmzutIQoA1I_big.jpg'),
(49527, 3413, 'Atlanta S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138920.mp4', 'http://gstaticontent.com/images/lXMmcrGK5QL7Xc1SjmzutIQoA1I_big.jpg'),
(49528, 3413, 'Atlanta S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138921.mp4', 'http://gstaticontent.com/images/lXMmcrGK5QL7Xc1SjmzutIQoA1I_big.jpg'),
(49529, 3413, 'Atlanta S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138922.mp4', 'http://gstaticontent.com/images/lXMmcrGK5QL7Xc1SjmzutIQoA1I_big.jpg'),
(49530, 3413, 'Atlanta S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138923.mp4', 'http://gstaticontent.com/images/lXMmcrGK5QL7Xc1SjmzutIQoA1I_big.jpg'),
(49531, 3414, 'Atlanta S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/398380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3vIaGFPsSfPBLN2eMnHE9Ka32VY.jpg'),
(49532, 3414, 'Atlanta S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/398381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDT384XhZzkHqPI6BIFsA4nGsNi.jpg'),
(49533, 3414, 'Atlanta S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/398382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eNupVO6nxWHwOqojqQqq3zu3aGQ.jpg'),
(49534, 3414, 'Atlanta S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/398383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bfvIIEpw8BkKVt8uhw99wGVZvcc.jpg'),
(49535, 3414, 'Atlanta S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/398384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bofH7oPCszxRRFvcu7wMsNZd9sX.jpg'),
(49536, 3414, 'Atlanta S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/398385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gHochwrEWzyAs64eMZlQZ13mufP.jpg'),
(49537, 3414, 'Atlanta S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/398386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/txw1asrYmGadFQkJge850xsYL8i.jpg'),
(49538, 3414, 'Atlanta S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/398387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3XUwXPViKgAp1LZKuhWKPPsW2jx.jpg'),
(49539, 3414, 'Atlanta S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/398388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uFSIN5TdOSYMw2frUYjzzeT6kQ0.jpg'),
(49540, 3414, 'Atlanta S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/398389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eC2tUit9W7eaTuRla2nxvNKIKDv.jpg'),
(49541, 3415, 'Atlanta S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/398390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2GYeJvyiwIGgydHdRumRTDPLxH5.jpg'),
(49542, 3415, 'Atlanta S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/398391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cjvKB2Allf458Coc5Xbt95ED2j4.jpg'),
(49543, 3415, 'Atlanta S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/398392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mBzLxA6yl6HaFvrtOaOsAChR5nW.jpg'),
(49544, 3415, 'Atlanta S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/398393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3wFKvAipvKowCCwHEy9QhV02b6D.jpg'),
(49545, 3415, 'Atlanta S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/398394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yIQjARc1JTSRcc26fQbxoJfqKv2.jpg'),
(49546, 3415, 'Atlanta S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/398395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fd7KsJ0QDVbIr7mOXrKeuTh8JCd.jpg'),
(49547, 3415, 'Atlanta S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/398396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pa4R0QOOpHawgNlZOQtJgF4oeot.jpg'),
(49548, 3415, 'Atlanta S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/398397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jVb54MwmMQT2AzlJsm3LCl4U12J.jpg'),
(49549, 3415, 'Atlanta S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/398398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/94ASpvDR2QvkSpJVMyJYgkkOhiG.jpg'),
(49550, 3415, 'Atlanta S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/398399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ilBSQUXU8kPMn7uLlfQbL35XBlZ.jpg'),
(49551, 3416, 'Fleming S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138899.mp4', 'http://gstaticontent.com/images/rFI3PuocaH5L6fqM4PaTo7GVu4n_big.jpg'),
(49552, 3416, 'Fleming S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138900.mp4', 'http://gstaticontent.com/images/rFI3PuocaH5L6fqM4PaTo7GVu4n_big.jpg'),
(49553, 3416, 'Fleming S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138901.mp4', 'http://gstaticontent.com/images/rFI3PuocaH5L6fqM4PaTo7GVu4n_big.jpg'),
(49554, 3416, 'Fleming S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138902.mp4', 'http://gstaticontent.com/images/rFI3PuocaH5L6fqM4PaTo7GVu4n_big.jpg'),
(49555, 3417, 'Dinheiro Fácil: A Série S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198118.mp4', 'http://gstaticontent.com/images/nR52E9DXyeXFKZKmDTxyWI9kFbh_big.jpg'),
(49556, 3417, 'Dinheiro Fácil: A Série S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198119.mp4', 'http://gstaticontent.com/images/nR52E9DXyeXFKZKmDTxyWI9kFbh_big.jpg'),
(49557, 3417, 'Dinheiro Fácil: A Série S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198120.mp4', 'http://gstaticontent.com/images/nR52E9DXyeXFKZKmDTxyWI9kFbh_big.jpg'),
(49558, 3417, 'Dinheiro Fácil: A Série S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198121.mp4', 'http://gstaticontent.com/images/nR52E9DXyeXFKZKmDTxyWI9kFbh_big.jpg'),
(49559, 3417, 'Dinheiro Fácil: A Série S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198122.mp4', 'http://gstaticontent.com/images/nR52E9DXyeXFKZKmDTxyWI9kFbh_big.jpg'),
(49560, 3417, 'Dinheiro Fácil: A Série S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198123.mp4', 'http://gstaticontent.com/images/nR52E9DXyeXFKZKmDTxyWI9kFbh_big.jpg'),
(49561, 3418, 'Dinheiro Fácil: A Série S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198124.mp4', 'http://timg.bdta.pro/images/3642b372856d6cc6814ae4bea970828e.jpg'),
(49562, 3418, 'Dinheiro Fácil: A Série S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198125.mp4', 'http://timg.bdta.pro/images/fbcfe0364503327b4bc3d8a3a8e14195.jpg'),
(49563, 3418, 'Dinheiro Fácil: A Série S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198126.mp4', 'http://timg.bdta.pro/images/2604671fdedd089a0907ce7982814df8.jpg'),
(49564, 3418, 'Dinheiro Fácil: A Série S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198127.mp4', 'http://timg.bdta.pro/images/5cb13ac6326a5f96366f1a5200074920.jpg'),
(49565, 3418, 'Dinheiro Fácil: A Série S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198128.mp4', 'http://timg.bdta.pro/images/1543c4ee1e599ab6ad569f8853695589.jpg'),
(49566, 3418, 'Dinheiro Fácil: A Série S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198129.mp4', 'http://timg.bdta.pro/images/1c609d2efd8c5c5c5a68b194fa2bdc5d.jpg'),
(49567, 3419, 'Virando o Jogo dos Campeões S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200646.mp4', 'http://gstaticontent.com/images/mrjfmtXFTv20xh9BANFNzAb9llP_big.jpg'),
(49568, 3419, 'Virando o Jogo dos Campeões S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200647.mp4', 'http://gstaticontent.com/images/mrjfmtXFTv20xh9BANFNzAb9llP_big.jpg'),
(49569, 3419, 'Virando o Jogo dos Campeões S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200648.mp4', 'http://gstaticontent.com/images/mrjfmtXFTv20xh9BANFNzAb9llP_big.jpg'),
(49570, 3419, 'Virando o Jogo dos Campeões S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200649.mp4', 'http://gstaticontent.com/images/mrjfmtXFTv20xh9BANFNzAb9llP_big.jpg'),
(49571, 3419, 'Virando o Jogo dos Campeões S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200650.mp4', 'http://gstaticontent.com/images/mrjfmtXFTv20xh9BANFNzAb9llP_big.jpg'),
(49572, 3419, 'Virando o Jogo dos Campeões S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200651.mp4', 'http://gstaticontent.com/images/mrjfmtXFTv20xh9BANFNzAb9llP_big.jpg'),
(49573, 3419, 'Virando o Jogo dos Campeões S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200652.mp4', 'http://gstaticontent.com/images/mrjfmtXFTv20xh9BANFNzAb9llP_big.jpg'),
(49574, 3419, 'Virando o Jogo dos Campeões S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200653.mp4', 'http://gstaticontent.com/images/mrjfmtXFTv20xh9BANFNzAb9llP_big.jpg'),
(49575, 3419, 'Virando o Jogo dos Campeões S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200654.mp4', 'http://gstaticontent.com/images/mrjfmtXFTv20xh9BANFNzAb9llP_big.jpg'),
(49576, 3419, 'Virando o Jogo dos Campeões S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200655.mp4', 'http://gstaticontent.com/images/mrjfmtXFTv20xh9BANFNzAb9llP_big.jpg'),
(49577, 3420, 'Virando o Jogo dos Campeões S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200656.mp4', 'http://timg.bdta.pro/images/2987661b14c222eacc107cc910e46bee.jpg'),
(49578, 3420, 'Virando o Jogo dos Campeões S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200657.mp4', 'http://timg.bdta.pro/images/eb19a913ee40456596cf8af9f517cdca.jpg'),
(49579, 3420, 'Virando o Jogo dos Campeões S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200658.mp4', 'http://timg.bdta.pro/images/2dbb649f32891724636f6338d1f07ae1.jpg'),
(49580, 3420, 'Virando o Jogo dos Campeões S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200659.mp4', 'http://timg.bdta.pro/images/6918e96019e70c925dfbd860b409f245.jpg'),
(49581, 3420, 'Virando o Jogo dos Campeões S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kHHEPaKndSmwutJLxSo8wsj5dGq.jpg'),
(49582, 3420, 'Virando o Jogo dos Campeões S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tI1IRpR0XOTC8FLX2H0Xdi9lwxt.jpg'),
(49583, 3420, 'Virando o Jogo dos Campeões S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200662.mp4', 'http://gstaticontent.com/images/mrjfmtXFTv20xh9BANFNzAb9llP_big.jpg'),
(49584, 3420, 'Virando o Jogo dos Campeões S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200663.mp4', 'http://image.tmdb.org/t/p/w1280/vDSY9xpsAqGEArcyycyz0QyxyH3.jpg'),
(49585, 3420, 'Virando o Jogo dos Campeões S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gNXTzAO28XQTP0LOPYux1OFVzJT.jpg'),
(49586, 3420, 'Virando o Jogo dos Campeões S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hrjaSNvFF2OBNVnTjExjw1IYAKy.jpg'),
(49587, 3421, 'Casamento sem Filtro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138893.mp4', 'http://gstaticontent.com/images/evQbhMe2QGgsAzcIjao0Uvm2Xsa_big.jpg'),
(49588, 3421, 'Casamento sem Filtro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138894.mp4', 'http://gstaticontent.com/images/evQbhMe2QGgsAzcIjao0Uvm2Xsa_big.jpg'),
(49589, 3421, 'Casamento sem Filtro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138895.mp4', 'http://gstaticontent.com/images/evQbhMe2QGgsAzcIjao0Uvm2Xsa_big.jpg'),
(49590, 3421, 'Casamento sem Filtro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138896.mp4', 'http://gstaticontent.com/images/evQbhMe2QGgsAzcIjao0Uvm2Xsa_big.jpg'),
(49591, 3421, 'Casamento sem Filtro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138897.mp4', 'http://gstaticontent.com/images/evQbhMe2QGgsAzcIjao0Uvm2Xsa_big.jpg'),
(49592, 3421, 'Casamento sem Filtro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138898.mp4', 'http://gstaticontent.com/images/evQbhMe2QGgsAzcIjao0Uvm2Xsa_big.jpg'),
(49593, 3422, 'O Maior Roubo de Arte de Todos os Tempos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138889.mp4', 'http://gstaticontent.com/images/ncDBeRjalCMwmPs9yBv4KfNZrEo_big.jpg'),
(49594, 3422, 'O Maior Roubo de Arte de Todos os Tempos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138890.mp4', 'http://gstaticontent.com/images/ncDBeRjalCMwmPs9yBv4KfNZrEo_big.jpg'),
(49595, 3422, 'O Maior Roubo de Arte de Todos os Tempos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138891.mp4', 'http://gstaticontent.com/images/ncDBeRjalCMwmPs9yBv4KfNZrEo_big.jpg'),
(49596, 3422, 'O Maior Roubo de Arte de Todos os Tempos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138892.mp4', 'http://gstaticontent.com/images/ncDBeRjalCMwmPs9yBv4KfNZrEo_big.jpg'),
(49597, 3423, 'Empire: Fama e Poder S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138787.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49598, 3423, 'Empire: Fama e Poder S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138788.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49599, 3423, 'Empire: Fama e Poder S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138789.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49600, 3423, 'Empire: Fama e Poder S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138790.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49601, 3423, 'Empire: Fama e Poder S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138791.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49602, 3423, 'Empire: Fama e Poder S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138792.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49603, 3423, 'Empire: Fama e Poder S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138793.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49604, 3423, 'Empire: Fama e Poder S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138794.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49605, 3423, 'Empire: Fama e Poder S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138795.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49606, 3423, 'Empire: Fama e Poder S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138796.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49607, 3423, 'Empire: Fama e Poder S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138797.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49608, 3423, 'Empire: Fama e Poder S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138798.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49609, 3424, 'Empire: Fama e Poder S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138799.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49610, 3424, 'Empire: Fama e Poder S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138800.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49611, 3424, 'Empire: Fama e Poder S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138801.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49612, 3424, 'Empire: Fama e Poder S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138802.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49613, 3424, 'Empire: Fama e Poder S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138803.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49614, 3424, 'Empire: Fama e Poder S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138804.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49615, 3424, 'Empire: Fama e Poder S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138805.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49616, 3424, 'Empire: Fama e Poder S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138806.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49617, 3424, 'Empire: Fama e Poder S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138807.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49618, 3424, 'Empire: Fama e Poder S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138808.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49619, 3424, 'Empire: Fama e Poder S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138809.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49620, 3424, 'Empire: Fama e Poder S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138810.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49621, 3424, 'Empire: Fama e Poder S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/138811.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49622, 3424, 'Empire: Fama e Poder S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/138812.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49623, 3424, 'Empire: Fama e Poder S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/138813.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49624, 3424, 'Empire: Fama e Poder S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/138814.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49625, 3424, 'Empire: Fama e Poder S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/138815.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49626, 3424, 'Empire: Fama e Poder S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/138816.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49627, 3425, 'Empire: Fama e Poder S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138817.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49628, 3425, 'Empire: Fama e Poder S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138818.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49629, 3425, 'Empire: Fama e Poder S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138819.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49630, 3425, 'Empire: Fama e Poder S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138820.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49631, 3425, 'Empire: Fama e Poder S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138821.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49632, 3425, 'Empire: Fama e Poder S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138822.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49633, 3425, 'Empire: Fama e Poder S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138823.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49634, 3425, 'Empire: Fama e Poder S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138824.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(49635, 3425, 'Empire: Fama e Poder S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138825.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49636, 3425, 'Empire: Fama e Poder S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138826.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49637, 3425, 'Empire: Fama e Poder S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138827.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49638, 3425, 'Empire: Fama e Poder S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138828.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49639, 3425, 'Empire: Fama e Poder S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/138829.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49640, 3425, 'Empire: Fama e Poder S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/138830.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49641, 3425, 'Empire: Fama e Poder S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/138831.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49642, 3425, 'Empire: Fama e Poder S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/138832.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49643, 3425, 'Empire: Fama e Poder S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/138833.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49644, 3425, 'Empire: Fama e Poder S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/138834.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49645, 3426, 'Empire: Fama e Poder S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138835.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49646, 3426, 'Empire: Fama e Poder S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138836.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49647, 3426, 'Empire: Fama e Poder S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138837.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49648, 3426, 'Empire: Fama e Poder S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138838.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49649, 3426, 'Empire: Fama e Poder S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138839.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49650, 3426, 'Empire: Fama e Poder S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138840.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49651, 3426, 'Empire: Fama e Poder S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138841.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49652, 3426, 'Empire: Fama e Poder S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138842.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49653, 3426, 'Empire: Fama e Poder S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138843.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49654, 3426, 'Empire: Fama e Poder S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138844.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49655, 3426, 'Empire: Fama e Poder S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138845.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49656, 3426, 'Empire: Fama e Poder S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138846.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49657, 3426, 'Empire: Fama e Poder S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/138847.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49658, 3426, 'Empire: Fama e Poder S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/138848.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49659, 3426, 'Empire: Fama e Poder S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/138849.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49660, 3426, 'Empire: Fama e Poder S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/138850.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49661, 3426, 'Empire: Fama e Poder S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/138851.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49662, 3426, 'Empire: Fama e Poder S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/138852.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49663, 3427, 'Empire: Fama e Poder S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138853.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49664, 3427, 'Empire: Fama e Poder S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138854.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49665, 3427, 'Empire: Fama e Poder S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138855.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49666, 3427, 'Empire: Fama e Poder S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138856.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49667, 3427, 'Empire: Fama e Poder S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138857.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49668, 3427, 'Empire: Fama e Poder S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138858.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49669, 3427, 'Empire: Fama e Poder S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138859.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49670, 3427, 'Empire: Fama e Poder S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138860.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49671, 3427, 'Empire: Fama e Poder S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138861.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49672, 3427, 'Empire: Fama e Poder S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138862.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49673, 3427, 'Empire: Fama e Poder S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138863.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49674, 3427, 'Empire: Fama e Poder S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138864.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49675, 3427, 'Empire: Fama e Poder S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/138865.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49676, 3427, 'Empire: Fama e Poder S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/138866.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49677, 3427, 'Empire: Fama e Poder S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/138867.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49678, 3427, 'Empire: Fama e Poder S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/138868.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49679, 3427, 'Empire: Fama e Poder S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/138869.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49680, 3427, 'Empire: Fama e Poder S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/138870.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49681, 3428, 'Empire: Fama e Poder S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138871.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49682, 3428, 'Empire: Fama e Poder S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138872.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49683, 3428, 'Empire: Fama e Poder S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138873.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49684, 3428, 'Empire: Fama e Poder S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138874.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49685, 3428, 'Empire: Fama e Poder S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138875.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49686, 3428, 'Empire: Fama e Poder S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138876.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49687, 3428, 'Empire: Fama e Poder S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138877.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49688, 3428, 'Empire: Fama e Poder S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138878.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49689, 3428, 'Empire: Fama e Poder S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138879.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49690, 3428, 'Empire: Fama e Poder S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138880.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49691, 3428, 'Empire: Fama e Poder S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138881.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49692, 3428, 'Empire: Fama e Poder S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138882.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49693, 3428, 'Empire: Fama e Poder S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/138883.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49694, 3428, 'Empire: Fama e Poder S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/138884.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49695, 3428, 'Empire: Fama e Poder S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/138885.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49696, 3428, 'Empire: Fama e Poder S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/138886.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49697, 3428, 'Empire: Fama e Poder S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/138887.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49698, 3428, 'Empire: Fama e Poder S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/138888.mp4', 'http://gstaticontent.com/images/8Uz4oB6Sa84AZEFif2ZOg2m6K0k_big.jpg'),
(49699, 3429, 'Hemlock Grove S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138750.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49700, 3429, 'Hemlock Grove S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138751.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49701, 3429, 'Hemlock Grove S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138752.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49702, 3429, 'Hemlock Grove S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138753.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49703, 3429, 'Hemlock Grove S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138754.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49704, 3429, 'Hemlock Grove S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138755.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49705, 3429, 'Hemlock Grove S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138756.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49706, 3429, 'Hemlock Grove S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138757.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49707, 3429, 'Hemlock Grove S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138758.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49708, 3429, 'Hemlock Grove S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138759.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49709, 3429, 'Hemlock Grove S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138760.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49710, 3429, 'Hemlock Grove S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138761.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49711, 3429, 'Hemlock Grove S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/138762.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49712, 3430, 'Hemlock Grove S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138763.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49713, 3430, 'Hemlock Grove S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138764.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49714, 3430, 'Hemlock Grove S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138765.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49715, 3430, 'Hemlock Grove S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138766.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49716, 3430, 'Hemlock Grove S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138767.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49717, 3430, 'Hemlock Grove S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138768.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49718, 3430, 'Hemlock Grove S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138769.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49719, 3430, 'Hemlock Grove S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138770.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49720, 3430, 'Hemlock Grove S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138771.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49721, 3430, 'Hemlock Grove S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138772.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49722, 3431, 'Hemlock Grove S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138773.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49723, 3431, 'Hemlock Grove S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138774.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49724, 3431, 'Hemlock Grove S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138775.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49725, 3431, 'Hemlock Grove S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138776.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49726, 3431, 'Hemlock Grove S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138777.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49727, 3431, 'Hemlock Grove S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138778.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49728, 3431, 'Hemlock Grove S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138779.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49729, 3431, 'Hemlock Grove S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138780.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49730, 3431, 'Hemlock Grove S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138781.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49731, 3431, 'Hemlock Grove S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138782.mp4', 'http://gstaticontent.com/images/1598zHh8eTryXqUzKH2vrnJZbYb_big.jpg'),
(49732, 3432, 'Pretty Hard Cases S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148751.mp4', 'http://gstaticontent.com/images/6Dph48dcMQSpJmXftSeQPaWYjEL_big.jpg'),
(49733, 3432, 'Pretty Hard Cases S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148752.mp4', 'http://gstaticontent.com/images/6Dph48dcMQSpJmXftSeQPaWYjEL_big.jpg'),
(49734, 3432, 'Pretty Hard Cases S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148753.mp4', 'http://gstaticontent.com/images/6Dph48dcMQSpJmXftSeQPaWYjEL_big.jpg'),
(49735, 3432, 'Pretty Hard Cases S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148754.mp4', 'http://gstaticontent.com/images/6Dph48dcMQSpJmXftSeQPaWYjEL_big.jpg'),
(49736, 3432, 'Pretty Hard Cases S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148755.mp4', 'http://gstaticontent.com/images/6Dph48dcMQSpJmXftSeQPaWYjEL_big.jpg'),
(49737, 3432, 'Pretty Hard Cases S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148756.mp4', 'http://gstaticontent.com/images/6Dph48dcMQSpJmXftSeQPaWYjEL_big.jpg'),
(49738, 3433, 'A Vila S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/549294.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49739, 3433, 'A Vila S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/549296.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49740, 3433, 'A Vila S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/549298.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49741, 3433, 'A Vila S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/549300.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49742, 3433, 'A Vila S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/549302.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49743, 3433, 'A Vila S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/549304.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49744, 3433, 'A Vila S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/549306.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49745, 3433, 'A Vila S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/549308.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49746, 3433, 'A Vila S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/549310.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49747, 3433, 'A Vila S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/549312.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49748, 3433, 'A Vila S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/549314.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49749, 3433, 'A Vila S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/549316.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49750, 3433, 'A Vila S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/549318.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49751, 3433, 'A Vila S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/549320.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49752, 3433, 'A Vila S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/549322.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49753, 3433, 'A Vila S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/549324.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49754, 3433, 'A Vila S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/549326.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49755, 3433, 'A Vila S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/549328.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49756, 3433, 'A Vila S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/549330.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49757, 3433, 'A Vila S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/549332.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49758, 3433, 'A Vila S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/549334.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49759, 3433, 'A Vila S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/549336.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49760, 3433, 'A Vila S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/549338.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49761, 3433, 'A Vila S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/549340.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49762, 3433, 'A Vila S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/549342.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49763, 3434, 'A Vila S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142433.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49764, 3434, 'A Vila S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142434.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49765, 3434, 'A Vila S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142435.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49766, 3434, 'A Vila S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142436.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49767, 3434, 'A Vila S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142437.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49768, 3434, 'A Vila S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142438.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49769, 3434, 'A Vila S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142439.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49770, 3434, 'A Vila S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142440.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49771, 3434, 'A Vila S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142441.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49772, 3434, 'A Vila S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142442.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49773, 3434, 'A Vila S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142443.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49774, 3434, 'A Vila S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142444.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49775, 3434, 'A Vila S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142445.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49776, 3434, 'A Vila S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/142446.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49777, 3434, 'A Vila S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142447.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49778, 3434, 'A Vila S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/142448.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49779, 3434, 'A Vila S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/142449.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49780, 3434, 'A Vila S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/142450.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49781, 3434, 'A Vila S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/142451.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49782, 3434, 'A Vila S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/142452.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49783, 3435, 'A Vila S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142453.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49784, 3435, 'A Vila S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142454.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49785, 3435, 'A Vila S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142455.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49786, 3435, 'A Vila S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142456.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49787, 3435, 'A Vila S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142457.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49788, 3435, 'A Vila S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142458.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49789, 3435, 'A Vila S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142459.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49790, 3435, 'A Vila S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142460.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49791, 3435, 'A Vila S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142461.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49792, 3435, 'A Vila S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142462.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49793, 3435, 'A Vila S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142463.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49794, 3435, 'A Vila S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142464.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49795, 3435, 'A Vila S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142465.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49796, 3435, 'A Vila S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/142466.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49797, 3435, 'A Vila S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142467.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49798, 3436, 'A Vila S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142468.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49799, 3436, 'A Vila S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142469.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49800, 3436, 'A Vila S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142470.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49801, 3436, 'A Vila S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142471.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49802, 3436, 'A Vila S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142472.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49803, 3436, 'A Vila S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142473.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49804, 3436, 'A Vila S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142474.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49805, 3436, 'A Vila S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142475.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49806, 3436, 'A Vila S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142476.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49807, 3436, 'A Vila S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142477.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49808, 3436, 'A Vila S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142478.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49809, 3436, 'A Vila S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142479.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49810, 3436, 'A Vila S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142480.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49811, 3436, 'A Vila S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/142481.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49812, 3436, 'A Vila S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142482.mp4', 'http://gstaticontent.com/images/jEiqhviTe1FjexWUr2npxiJuYmV_big.jpg'),
(49813, 3437, 'Silicon Valley S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138697.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49814, 3437, 'Silicon Valley S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138698.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49815, 3437, 'Silicon Valley S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138699.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49816, 3437, 'Silicon Valley S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138700.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49817, 3437, 'Silicon Valley S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138701.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49818, 3437, 'Silicon Valley S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138702.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49819, 3437, 'Silicon Valley S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138703.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49820, 3437, 'Silicon Valley S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138704.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49821, 3438, 'Silicon Valley S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138705.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49822, 3438, 'Silicon Valley S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138706.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49823, 3438, 'Silicon Valley S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138707.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49824, 3438, 'Silicon Valley S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138708.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49825, 3438, 'Silicon Valley S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138709.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49826, 3438, 'Silicon Valley S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138710.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49827, 3438, 'Silicon Valley S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138711.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49828, 3438, 'Silicon Valley S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138712.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49829, 3438, 'Silicon Valley S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138713.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49830, 3438, 'Silicon Valley S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138714.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49831, 3439, 'Silicon Valley S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138715.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49832, 3439, 'Silicon Valley S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138716.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49833, 3439, 'Silicon Valley S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138717.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49834, 3439, 'Silicon Valley S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138718.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49835, 3439, 'Silicon Valley S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138719.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49836, 3439, 'Silicon Valley S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138720.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49837, 3439, 'Silicon Valley S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138721.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49838, 3439, 'Silicon Valley S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138722.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49839, 3439, 'Silicon Valley S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138723.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49840, 3439, 'Silicon Valley S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138724.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49841, 3440, 'Silicon Valley S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138725.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49842, 3440, 'Silicon Valley S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138726.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49843, 3440, 'Silicon Valley S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138727.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49844, 3440, 'Silicon Valley S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138728.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49845, 3440, 'Silicon Valley S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138729.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49846, 3440, 'Silicon Valley S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138730.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49847, 3440, 'Silicon Valley S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138731.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49848, 3440, 'Silicon Valley S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138732.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49849, 3440, 'Silicon Valley S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138733.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49850, 3440, 'Silicon Valley S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138734.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49851, 3441, 'Silicon Valley S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138735.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49852, 3441, 'Silicon Valley S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138736.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49853, 3441, 'Silicon Valley S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138737.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49854, 3441, 'Silicon Valley S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138738.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49855, 3441, 'Silicon Valley S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138739.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49856, 3441, 'Silicon Valley S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138740.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49857, 3441, 'Silicon Valley S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138741.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49858, 3441, 'Silicon Valley S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138742.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49859, 3442, 'Silicon Valley S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138743.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49860, 3442, 'Silicon Valley S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138744.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49861, 3442, 'Silicon Valley S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138745.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49862, 3442, 'Silicon Valley S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138746.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49863, 3442, 'Silicon Valley S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138747.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49864, 3442, 'Silicon Valley S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138748.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49865, 3442, 'Silicon Valley S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138749.mp4', 'http://gstaticontent.com/images/dc5r71XI1gD4YwIUoEYCLiVvtss_big.jpg'),
(49866, 3443, 'Lost S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138578.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49867, 3443, 'Lost S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138579.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49868, 3443, 'Lost S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138580.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49869, 3443, 'Lost S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138581.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49870, 3443, 'Lost S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138582.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49871, 3443, 'Lost S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138583.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49872, 3443, 'Lost S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138584.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49873, 3443, 'Lost S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138585.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49874, 3443, 'Lost S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138586.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49875, 3443, 'Lost S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138587.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49876, 3443, 'Lost S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138588.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49877, 3443, 'Lost S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138589.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49878, 3443, 'Lost S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/138590.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49879, 3443, 'Lost S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/138591.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49880, 3443, 'Lost S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/138592.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49881, 3443, 'Lost S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/138593.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49882, 3443, 'Lost S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/138594.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49883, 3443, 'Lost S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/138595.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49884, 3443, 'Lost S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/138596.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49885, 3443, 'Lost S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/138597.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49886, 3443, 'Lost S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/138598.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49887, 3443, 'Lost S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/138599.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49888, 3443, 'Lost S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/138600.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49889, 3443, 'Lost S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/138601.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49890, 3443, 'Lost S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/138602.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49891, 3444, 'Lost S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138603.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49892, 3444, 'Lost S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138604.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49893, 3444, 'Lost S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138605.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49894, 3444, 'Lost S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138606.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49895, 3444, 'Lost S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138607.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49896, 3444, 'Lost S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138608.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49897, 3444, 'Lost S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138609.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49898, 3444, 'Lost S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138610.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49899, 3444, 'Lost S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138611.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49900, 3444, 'Lost S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138612.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49901, 3444, 'Lost S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138613.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49902, 3444, 'Lost S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138614.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49903, 3444, 'Lost S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/138615.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49904, 3444, 'Lost S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/138616.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49905, 3444, 'Lost S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/138617.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49906, 3444, 'Lost S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/138618.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49907, 3444, 'Lost S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/138619.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49908, 3444, 'Lost S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/138620.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49909, 3444, 'Lost S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/138621.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49910, 3444, 'Lost S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/138622.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49911, 3444, 'Lost S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/138623.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49912, 3444, 'Lost S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/138624.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49913, 3444, 'Lost S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/138625.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49914, 3444, 'Lost S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/138626.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49915, 3445, 'Lost S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138627.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49916, 3445, 'Lost S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138628.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49917, 3445, 'Lost S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138629.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49918, 3445, 'Lost S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138630.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49919, 3445, 'Lost S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138631.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49920, 3445, 'Lost S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138632.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49921, 3445, 'Lost S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138633.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49922, 3445, 'Lost S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138634.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49923, 3445, 'Lost S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138635.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(49924, 3445, 'Lost S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138636.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49925, 3445, 'Lost S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138637.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49926, 3445, 'Lost S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138638.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49927, 3445, 'Lost S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/138639.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49928, 3445, 'Lost S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/138640.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49929, 3445, 'Lost S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/138641.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49930, 3445, 'Lost S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/138642.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49931, 3445, 'Lost S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/138643.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49932, 3445, 'Lost S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/138644.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49933, 3445, 'Lost S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/138645.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49934, 3445, 'Lost S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/138646.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49935, 3445, 'Lost S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/138647.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49936, 3445, 'Lost S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/138648.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49937, 3445, 'Lost S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/138649.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49938, 3446, 'Lost S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138650.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49939, 3446, 'Lost S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138651.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49940, 3446, 'Lost S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138652.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49941, 3446, 'Lost S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138653.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49942, 3446, 'Lost S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138654.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49943, 3446, 'Lost S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138655.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49944, 3446, 'Lost S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138656.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49945, 3446, 'Lost S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138657.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49946, 3446, 'Lost S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138658.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49947, 3446, 'Lost S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138659.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49948, 3446, 'Lost S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138660.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49949, 3446, 'Lost S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138661.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49950, 3446, 'Lost S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/138662.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49951, 3446, 'Lost S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/138663.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49952, 3447, 'Lost S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138664.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49953, 3447, 'Lost S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138665.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49954, 3447, 'Lost S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138666.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49955, 3447, 'Lost S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138667.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49956, 3447, 'Lost S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138668.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49957, 3447, 'Lost S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138669.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49958, 3447, 'Lost S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138670.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49959, 3447, 'Lost S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138671.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49960, 3447, 'Lost S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138672.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49961, 3447, 'Lost S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138673.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49962, 3447, 'Lost S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138674.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49963, 3447, 'Lost S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138675.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49964, 3447, 'Lost S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/138676.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49965, 3447, 'Lost S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/138677.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49966, 3447, 'Lost S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/138678.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49967, 3447, 'Lost S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/138679.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49968, 3447, 'Lost S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/138680.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49969, 3448, 'Lost S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138681.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49970, 3448, 'Lost S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138682.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49971, 3448, 'Lost S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138683.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49972, 3448, 'Lost S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138684.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49973, 3448, 'Lost S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138685.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49974, 3448, 'Lost S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138686.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49975, 3448, 'Lost S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138687.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49976, 3448, 'Lost S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138688.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49977, 3448, 'Lost S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138689.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49978, 3448, 'Lost S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138690.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49979, 3448, 'Lost S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138691.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49980, 3448, 'Lost S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138692.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49981, 3448, 'Lost S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/138693.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49982, 3448, 'Lost S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/138694.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49983, 3448, 'Lost S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/138695.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49984, 3448, 'Lost S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/138696.mp4', 'http://gstaticontent.com/images/47RazdqbtMmDxKHskObbHkc2D3o_big.jpg'),
(49985, 3449, 'Gomorra [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138405.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(49986, 3449, 'Gomorra [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138406.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(49987, 3449, 'Gomorra [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138407.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(49988, 3449, 'Gomorra [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138408.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(49989, 3449, 'Gomorra [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138409.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(49990, 3449, 'Gomorra [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138410.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(49991, 3449, 'Gomorra [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138411.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(49992, 3449, 'Gomorra [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138412.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(49993, 3449, 'Gomorra [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138413.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(49994, 3449, 'Gomorra [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138414.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(49995, 3449, 'Gomorra [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138415.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(49996, 3449, 'Gomorra [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138416.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(49997, 3450, 'Gomorra [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138417.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(49998, 3450, 'Gomorra [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138418.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(49999, 3450, 'Gomorra [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138419.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50000, 3450, 'Gomorra [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138420.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50001, 3450, 'Gomorra [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138421.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50002, 3450, 'Gomorra [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138422.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50003, 3450, 'Gomorra [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138423.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50004, 3450, 'Gomorra [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138424.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50005, 3450, 'Gomorra [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138425.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50006, 3450, 'Gomorra [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138426.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50007, 3450, 'Gomorra [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138427.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50008, 3450, 'Gomorra [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138428.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50009, 3451, 'Gomorra [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138429.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50010, 3451, 'Gomorra [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138430.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50011, 3451, 'Gomorra [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138431.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50012, 3451, 'Gomorra [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138432.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50013, 3451, 'Gomorra [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138433.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50014, 3451, 'Gomorra [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138434.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50015, 3451, 'Gomorra [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138435.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50016, 3451, 'Gomorra [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138436.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50017, 3451, 'Gomorra [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138437.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50018, 3451, 'Gomorra [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138438.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50019, 3451, 'Gomorra [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138439.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50020, 3451, 'Gomorra [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138440.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50021, 3452, 'Gomorra [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138441.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50022, 3452, 'Gomorra [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138442.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50023, 3452, 'Gomorra [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138443.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50024, 3452, 'Gomorra [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138444.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50025, 3452, 'Gomorra [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138445.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50026, 3452, 'Gomorra [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138446.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50027, 3452, 'Gomorra [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138447.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50028, 3452, 'Gomorra [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138448.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50029, 3452, 'Gomorra [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138449.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50030, 3452, 'Gomorra [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138450.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50031, 3452, 'Gomorra [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138451.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50032, 3452, 'Gomorra [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138452.mp4', 'http://gstaticontent.com/images/cXsagSyQQki9vTbV3TTxRCGIIlQ_big.jpg'),
(50033, 3453, 'Home Economics [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142312.mp4', 'http://gstaticontent.com/images/gKWspCQFvUoLGgaitR0XN8ccT2u_big.jpg'),
(50034, 3453, 'Home Economics [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142313.mp4', 'http://gstaticontent.com/images/gKWspCQFvUoLGgaitR0XN8ccT2u_big.jpg'),
(50035, 3453, 'Home Economics [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142314.mp4', 'http://gstaticontent.com/images/gKWspCQFvUoLGgaitR0XN8ccT2u_big.jpg'),
(50036, 3453, 'Home Economics [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142315.mp4', 'http://gstaticontent.com/images/gKWspCQFvUoLGgaitR0XN8ccT2u_big.jpg'),
(50037, 3454, 'Os Normais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138334.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50038, 3454, 'Os Normais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138335.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50039, 3454, 'Os Normais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138336.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50040, 3454, 'Os Normais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138337.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50041, 3454, 'Os Normais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138338.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50042, 3454, 'Os Normais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138339.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50043, 3454, 'Os Normais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138340.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50044, 3454, 'Os Normais S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138341.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50045, 3454, 'Os Normais S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138342.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50046, 3454, 'Os Normais S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138343.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50047, 3454, 'Os Normais S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138344.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50048, 3454, 'Os Normais S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138345.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50049, 3454, 'Os Normais S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/138346.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50050, 3454, 'Os Normais S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/138347.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50051, 3454, 'Os Normais S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/138348.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50052, 3454, 'Os Normais S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/138349.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50053, 3454, 'Os Normais S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/138350.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50054, 3454, 'Os Normais S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/138351.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50055, 3454, 'Os Normais S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/138352.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50056, 3454, 'Os Normais S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/138353.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50057, 3454, 'Os Normais S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/138354.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50058, 3454, 'Os Normais S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/138355.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50059, 3454, 'Os Normais S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/138356.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50060, 3454, 'Os Normais S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/138357.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50061, 3454, 'Os Normais S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/138358.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50062, 3454, 'Os Normais S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/138359.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50063, 3455, 'Os Normais S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138360.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50064, 3455, 'Os Normais S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138361.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50065, 3455, 'Os Normais S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138362.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50066, 3455, 'Os Normais S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138363.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50067, 3455, 'Os Normais S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138364.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50068, 3455, 'Os Normais S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138365.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50069, 3455, 'Os Normais S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138366.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50070, 3455, 'Os Normais S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138367.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50071, 3455, 'Os Normais S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138368.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50072, 3455, 'Os Normais S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138369.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50073, 3455, 'Os Normais S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138370.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50074, 3455, 'Os Normais S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138371.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50075, 3455, 'Os Normais S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/138372.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50076, 3455, 'Os Normais S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/138373.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50077, 3455, 'Os Normais S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/138374.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50078, 3455, 'Os Normais S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/138375.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50079, 3455, 'Os Normais S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/138376.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50080, 3455, 'Os Normais S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/138377.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50081, 3455, 'Os Normais S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/138378.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50082, 3455, 'Os Normais S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/138379.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50083, 3455, 'Os Normais S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/138380.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50084, 3455, 'Os Normais S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/138381.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50085, 3455, 'Os Normais S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/138382.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50086, 3455, 'Os Normais S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/138383.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50087, 3455, 'Os Normais S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/138384.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50088, 3455, 'Os Normais S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/138385.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50089, 3455, 'Os Normais S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/138386.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50090, 3455, 'Os Normais S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/138387.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50091, 3456, 'Os Normais S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138388.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50092, 3456, 'Os Normais S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138389.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50093, 3456, 'Os Normais S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138390.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50094, 3456, 'Os Normais S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138391.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50095, 3456, 'Os Normais S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138392.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50096, 3456, 'Os Normais S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138393.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50097, 3456, 'Os Normais S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138394.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50098, 3456, 'Os Normais S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138395.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50099, 3456, 'Os Normais S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138396.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50100, 3456, 'Os Normais S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138397.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50101, 3456, 'Os Normais S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138398.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50102, 3456, 'Os Normais S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138399.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50103, 3456, 'Os Normais S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/138400.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50104, 3456, 'Os Normais S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/138401.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50105, 3456, 'Os Normais S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/138402.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50106, 3456, 'Os Normais S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/138403.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50107, 3456, 'Os Normais S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/138404.mp4', 'http://gstaticontent.com/images/cjqoVe9Y1QwGxTmVFBhiHf9WCgM_big.jpg'),
(50108, 3457, 'The Nevers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148745.mp4', 'https://image.tmdb.org/t/p/original/cZn3wN4zbEjH7Lv2xt2LxwT4TII.jpg'),
(50109, 3457, 'The Nevers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148746.mp4', 'https://image.tmdb.org/t/p/original/cZn3wN4zbEjH7Lv2xt2LxwT4TII.jpg'),
(50110, 3457, 'The Nevers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148747.mp4', 'https://image.tmdb.org/t/p/original/cZn3wN4zbEjH7Lv2xt2LxwT4TII.jpg'),
(50111, 3457, 'The Nevers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148748.mp4', 'https://image.tmdb.org/t/p/original/cZn3wN4zbEjH7Lv2xt2LxwT4TII.jpg'),
(50112, 3457, 'The Nevers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148749.mp4', 'https://image.tmdb.org/t/p/original/cZn3wN4zbEjH7Lv2xt2LxwT4TII.jpg'),
(50113, 3457, 'The Nevers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148750.mp4', 'https://image.tmdb.org/t/p/original/cZn3wN4zbEjH7Lv2xt2LxwT4TII.jpg'),
(50114, 3458, 'Flesh and Blood S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138097.mp4', 'http://gstaticontent.com/images/3MZv8kEMPWkpjECLbg5S1dQzYnE_big.jpg'),
(50115, 3458, 'Flesh and Blood S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138098.mp4', 'http://gstaticontent.com/images/3MZv8kEMPWkpjECLbg5S1dQzYnE_big.jpg'),
(50116, 3458, 'Flesh and Blood S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138099.mp4', 'http://gstaticontent.com/images/3MZv8kEMPWkpjECLbg5S1dQzYnE_big.jpg'),
(50117, 3458, 'Flesh and Blood S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138100.mp4', 'http://gstaticontent.com/images/3MZv8kEMPWkpjECLbg5S1dQzYnE_big.jpg'),
(50118, 3459, 'How I Met Your Mother S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137889.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50119, 3459, 'How I Met Your Mother S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137890.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50120, 3459, 'How I Met Your Mother S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137891.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50121, 3459, 'How I Met Your Mother S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137892.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50122, 3459, 'How I Met Your Mother S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137893.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50123, 3459, 'How I Met Your Mother S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137894.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50124, 3459, 'How I Met Your Mother S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137895.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50125, 3459, 'How I Met Your Mother S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137896.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50126, 3459, 'How I Met Your Mother S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137897.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50127, 3459, 'How I Met Your Mother S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137898.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50128, 3459, 'How I Met Your Mother S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137899.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50129, 3459, 'How I Met Your Mother S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137900.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50130, 3459, 'How I Met Your Mother S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137901.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50131, 3459, 'How I Met Your Mother S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137902.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50132, 3459, 'How I Met Your Mother S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137903.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50133, 3459, 'How I Met Your Mother S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137904.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50134, 3459, 'How I Met Your Mother S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137905.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50135, 3459, 'How I Met Your Mother S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137906.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50136, 3459, 'How I Met Your Mother S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137907.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50137, 3459, 'How I Met Your Mother S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137908.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50138, 3459, 'How I Met Your Mother S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/137909.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50139, 3459, 'How I Met Your Mother S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/137910.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50140, 3460, 'How I Met Your Mother S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137911.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50141, 3460, 'How I Met Your Mother S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137912.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50142, 3460, 'How I Met Your Mother S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137913.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50143, 3460, 'How I Met Your Mother S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137914.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50144, 3460, 'How I Met Your Mother S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137915.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50145, 3460, 'How I Met Your Mother S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137916.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50146, 3460, 'How I Met Your Mother S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137917.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50147, 3460, 'How I Met Your Mother S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137918.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50148, 3460, 'How I Met Your Mother S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137919.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50149, 3460, 'How I Met Your Mother S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137920.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50150, 3460, 'How I Met Your Mother S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137921.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50151, 3460, 'How I Met Your Mother S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137922.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50152, 3460, 'How I Met Your Mother S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137923.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50153, 3460, 'How I Met Your Mother S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137924.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50154, 3460, 'How I Met Your Mother S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137925.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50155, 3460, 'How I Met Your Mother S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137926.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50156, 3460, 'How I Met Your Mother S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137927.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50157, 3460, 'How I Met Your Mother S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137928.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50158, 3460, 'How I Met Your Mother S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137929.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50159, 3460, 'How I Met Your Mother S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137930.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50160, 3460, 'How I Met Your Mother S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/137931.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50161, 3460, 'How I Met Your Mother S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/137932.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50162, 3461, 'How I Met Your Mother S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137933.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50163, 3461, 'How I Met Your Mother S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137934.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50164, 3461, 'How I Met Your Mother S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137935.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50165, 3461, 'How I Met Your Mother S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137936.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50166, 3461, 'How I Met Your Mother S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137937.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50167, 3461, 'How I Met Your Mother S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137938.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50168, 3461, 'How I Met Your Mother S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137939.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50169, 3461, 'How I Met Your Mother S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137940.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50170, 3461, 'How I Met Your Mother S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137941.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50171, 3461, 'How I Met Your Mother S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137942.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50172, 3461, 'How I Met Your Mother S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137943.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50173, 3461, 'How I Met Your Mother S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137944.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50174, 3461, 'How I Met Your Mother S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137945.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50175, 3461, 'How I Met Your Mother S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137946.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50176, 3461, 'How I Met Your Mother S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137947.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50177, 3461, 'How I Met Your Mother S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137948.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50178, 3461, 'How I Met Your Mother S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137949.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50179, 3461, 'How I Met Your Mother S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137950.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50180, 3461, 'How I Met Your Mother S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137951.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50181, 3461, 'How I Met Your Mother S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137952.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50182, 3462, 'How I Met Your Mother S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137953.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50183, 3462, 'How I Met Your Mother S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137954.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50184, 3462, 'How I Met Your Mother S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137955.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50185, 3462, 'How I Met Your Mother S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137956.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50186, 3462, 'How I Met Your Mother S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137957.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50187, 3462, 'How I Met Your Mother S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137958.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50188, 3462, 'How I Met Your Mother S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137959.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50189, 3462, 'How I Met Your Mother S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137960.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50190, 3462, 'How I Met Your Mother S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137961.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50191, 3462, 'How I Met Your Mother S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137962.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50192, 3462, 'How I Met Your Mother S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137963.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50193, 3462, 'How I Met Your Mother S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137964.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50194, 3462, 'How I Met Your Mother S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137965.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50195, 3462, 'How I Met Your Mother S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137966.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50196, 3462, 'How I Met Your Mother S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137967.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50197, 3462, 'How I Met Your Mother S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137968.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50198, 3462, 'How I Met Your Mother S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137969.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50199, 3462, 'How I Met Your Mother S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137970.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50200, 3462, 'How I Met Your Mother S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137971.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50201, 3462, 'How I Met Your Mother S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137972.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50202, 3462, 'How I Met Your Mother S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/137973.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50203, 3462, 'How I Met Your Mother S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/137974.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50204, 3462, 'How I Met Your Mother S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/137975.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50205, 3462, 'How I Met Your Mother S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/137976.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50206, 3463, 'How I Met Your Mother S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/137977.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50207, 3463, 'How I Met Your Mother S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/137978.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50208, 3463, 'How I Met Your Mother S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/137979.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50209, 3463, 'How I Met Your Mother S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/137980.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50210, 3463, 'How I Met Your Mother S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/137981.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(50211, 3463, 'How I Met Your Mother S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/137982.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50212, 3463, 'How I Met Your Mother S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/137983.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50213, 3463, 'How I Met Your Mother S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/137984.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50214, 3463, 'How I Met Your Mother S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/137985.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50215, 3463, 'How I Met Your Mother S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/137986.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50216, 3463, 'How I Met Your Mother S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/137987.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50217, 3463, 'How I Met Your Mother S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/137988.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50218, 3463, 'How I Met Your Mother S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/137989.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50219, 3463, 'How I Met Your Mother S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/137990.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50220, 3463, 'How I Met Your Mother S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/137991.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50221, 3463, 'How I Met Your Mother S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/137992.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50222, 3463, 'How I Met Your Mother S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/137993.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50223, 3463, 'How I Met Your Mother S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/137994.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50224, 3463, 'How I Met Your Mother S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/137995.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50225, 3463, 'How I Met Your Mother S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/137996.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50226, 3463, 'How I Met Your Mother S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/137997.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50227, 3463, 'How I Met Your Mother S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/137998.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50228, 3463, 'How I Met Your Mother S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/137999.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50229, 3463, 'How I Met Your Mother S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/138000.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50230, 3464, 'How I Met Your Mother S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138001.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50231, 3464, 'How I Met Your Mother S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138002.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50232, 3464, 'How I Met Your Mother S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138003.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50233, 3464, 'How I Met Your Mother S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138004.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50234, 3464, 'How I Met Your Mother S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138005.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50235, 3464, 'How I Met Your Mother S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138006.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50236, 3464, 'How I Met Your Mother S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138007.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50237, 3464, 'How I Met Your Mother S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138008.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50238, 3464, 'How I Met Your Mother S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138009.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50239, 3464, 'How I Met Your Mother S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138010.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50240, 3464, 'How I Met Your Mother S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138011.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50241, 3464, 'How I Met Your Mother S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138012.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50242, 3464, 'How I Met Your Mother S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/138013.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50243, 3464, 'How I Met Your Mother S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/138014.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50244, 3464, 'How I Met Your Mother S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/138015.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50245, 3464, 'How I Met Your Mother S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/138016.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50246, 3464, 'How I Met Your Mother S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/138017.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50247, 3464, 'How I Met Your Mother S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/138018.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50248, 3464, 'How I Met Your Mother S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/138019.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50249, 3464, 'How I Met Your Mother S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/138020.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50250, 3464, 'How I Met Your Mother S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/138021.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50251, 3464, 'How I Met Your Mother S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/138022.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50252, 3464, 'How I Met Your Mother S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/138023.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50253, 3464, 'How I Met Your Mother S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/138024.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50254, 3465, 'How I Met Your Mother S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138025.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50255, 3465, 'How I Met Your Mother S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138026.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50256, 3465, 'How I Met Your Mother S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138027.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50257, 3465, 'How I Met Your Mother S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138028.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50258, 3465, 'How I Met Your Mother S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138029.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50259, 3465, 'How I Met Your Mother S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138030.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50260, 3465, 'How I Met Your Mother S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138031.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50261, 3465, 'How I Met Your Mother S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138032.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50262, 3465, 'How I Met Your Mother S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138033.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50263, 3465, 'How I Met Your Mother S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138034.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50264, 3465, 'How I Met Your Mother S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138035.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50265, 3465, 'How I Met Your Mother S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138036.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50266, 3465, 'How I Met Your Mother S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/138037.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50267, 3465, 'How I Met Your Mother S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/138038.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50268, 3465, 'How I Met Your Mother S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/138039.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50269, 3465, 'How I Met Your Mother S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/138040.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50270, 3465, 'How I Met Your Mother S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/138041.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50271, 3465, 'How I Met Your Mother S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/138042.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50272, 3465, 'How I Met Your Mother S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/138043.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50273, 3465, 'How I Met Your Mother S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/138044.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50274, 3465, 'How I Met Your Mother S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/138045.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50275, 3465, 'How I Met Your Mother S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/138046.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50276, 3465, 'How I Met Your Mother S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/138047.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50277, 3465, 'How I Met Your Mother S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/138048.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50278, 3466, 'How I Met Your Mother S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138049.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50279, 3466, 'How I Met Your Mother S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138050.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50280, 3466, 'How I Met Your Mother S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138051.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50281, 3466, 'How I Met Your Mother S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138052.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50282, 3466, 'How I Met Your Mother S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138053.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50283, 3466, 'How I Met Your Mother S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138054.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50284, 3466, 'How I Met Your Mother S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138055.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50285, 3466, 'How I Met Your Mother S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138056.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50286, 3466, 'How I Met Your Mother S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138057.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50287, 3466, 'How I Met Your Mother S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138058.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50288, 3466, 'How I Met Your Mother S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138059.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50289, 3466, 'How I Met Your Mother S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138060.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50290, 3466, 'How I Met Your Mother S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/138061.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50291, 3466, 'How I Met Your Mother S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/138062.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50292, 3466, 'How I Met Your Mother S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/138063.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50293, 3466, 'How I Met Your Mother S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/138064.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50294, 3466, 'How I Met Your Mother S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/138065.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50295, 3466, 'How I Met Your Mother S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/138066.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50296, 3466, 'How I Met Your Mother S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/138067.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50297, 3466, 'How I Met Your Mother S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/138068.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50298, 3466, 'How I Met Your Mother S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/138069.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50299, 3466, 'How I Met Your Mother S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/138070.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50300, 3466, 'How I Met Your Mother S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/138071.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50301, 3466, 'How I Met Your Mother S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/138072.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50302, 3467, 'How I Met Your Mother S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/138073.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50303, 3467, 'How I Met Your Mother S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/138074.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50304, 3467, 'How I Met Your Mother S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/138075.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50305, 3467, 'How I Met Your Mother S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/138076.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50306, 3467, 'How I Met Your Mother S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/138077.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50307, 3467, 'How I Met Your Mother S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/138078.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50308, 3467, 'How I Met Your Mother S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/138079.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50309, 3467, 'How I Met Your Mother S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/138080.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50310, 3467, 'How I Met Your Mother S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/138081.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50311, 3467, 'How I Met Your Mother S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/138082.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50312, 3467, 'How I Met Your Mother S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/138083.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50313, 3467, 'How I Met Your Mother S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/138084.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50314, 3467, 'How I Met Your Mother S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/138085.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50315, 3467, 'How I Met Your Mother S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/138086.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50316, 3467, 'How I Met Your Mother S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/138087.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50317, 3467, 'How I Met Your Mother S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/138088.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50318, 3467, 'How I Met Your Mother S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/138089.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50319, 3467, 'How I Met Your Mother S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/138090.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50320, 3467, 'How I Met Your Mother S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/138091.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50321, 3467, 'How I Met Your Mother S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/138092.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50322, 3467, 'How I Met Your Mother S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/138093.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50323, 3467, 'How I Met Your Mother S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/138094.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50324, 3467, 'How I Met Your Mother S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/138095.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50325, 3467, 'How I Met Your Mother S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/138096.mp4', 'http://gstaticontent.com/images/578tlvbrpFwc959bQTT93W2RYA_big.jpg'),
(50326, 3468, 'Outlander S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230125.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50327, 3468, 'Outlander S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230126.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50328, 3468, 'Outlander S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230127.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50329, 3468, 'Outlander S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230128.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50330, 3468, 'Outlander S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230129.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50331, 3468, 'Outlander S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230130.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50332, 3468, 'Outlander S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230131.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50333, 3468, 'Outlander S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230132.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50334, 3468, 'Outlander S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230133.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50335, 3468, 'Outlander S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230134.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50336, 3468, 'Outlander S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230135.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50337, 3468, 'Outlander S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230136.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50338, 3468, 'Outlander S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230137.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50339, 3468, 'Outlander S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/230138.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50340, 3468, 'Outlander S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/230139.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50341, 3468, 'Outlander S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/230140.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50342, 3469, 'Outlander S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230141.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50343, 3469, 'Outlander S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230142.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50344, 3469, 'Outlander S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230143.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50345, 3469, 'Outlander S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230144.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50346, 3469, 'Outlander S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230145.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50347, 3469, 'Outlander S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230146.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50348, 3469, 'Outlander S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230147.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50349, 3469, 'Outlander S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230148.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50350, 3469, 'Outlander S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230149.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50351, 3469, 'Outlander S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230150.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50352, 3469, 'Outlander S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230151.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50353, 3469, 'Outlander S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230152.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50354, 3469, 'Outlander S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230153.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50355, 3470, 'Outlander S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230154.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50356, 3470, 'Outlander S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230155.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50357, 3470, 'Outlander S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230156.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50358, 3470, 'Outlander S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230157.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50359, 3470, 'Outlander S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230158.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50360, 3470, 'Outlander S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230159.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50361, 3470, 'Outlander S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230160.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50362, 3470, 'Outlander S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230161.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50363, 3470, 'Outlander S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230162.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50364, 3470, 'Outlander S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230163.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50365, 3470, 'Outlander S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230164.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50366, 3470, 'Outlander S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230165.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50367, 3470, 'Outlander S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230166.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50368, 3471, 'Outlander S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230167.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50369, 3471, 'Outlander S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230168.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50370, 3471, 'Outlander S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230169.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50371, 3471, 'Outlander S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230170.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50372, 3471, 'Outlander S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230171.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50373, 3471, 'Outlander S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230172.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50374, 3471, 'Outlander S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230173.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50375, 3471, 'Outlander S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230174.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50376, 3471, 'Outlander S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230175.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50377, 3471, 'Outlander S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230176.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50378, 3471, 'Outlander S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230177.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50379, 3471, 'Outlander S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230178.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50380, 3471, 'Outlander S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230179.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50381, 3472, 'Outlander S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230180.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50382, 3472, 'Outlander S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230181.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50383, 3472, 'Outlander S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230182.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50384, 3472, 'Outlander S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230183.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50385, 3472, 'Outlander S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230184.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50386, 3472, 'Outlander S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230185.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50387, 3472, 'Outlander S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230186.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50388, 3472, 'Outlander S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230187.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50389, 3472, 'Outlander S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230188.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50390, 3472, 'Outlander S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230189.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50391, 3472, 'Outlander S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230190.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50392, 3472, 'Outlander S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230191.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50393, 3473, 'Outlander S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230192.mp4', 'http://timg.bdta.pro/images/b2e0110e430313aa87a8dff3939b677e.jpg'),
(50394, 3473, 'Outlander S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230193.mp4', 'http://timg.bdta.pro/images/33e2966c4fb9204c2c444868fa07b7a8.jpg'),
(50395, 3473, 'Outlander S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230194.mp4', 'http://timg.bdta.pro/images/625dec7cad61fcf08914107e51a64905.jpg'),
(50396, 3473, 'Outlander S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230195.mp4', 'http://timg.bdta.pro/images/175bb196dbfd93eb792cd4cbe38c150e.jpg'),
(50397, 3473, 'Outlander S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230196.mp4', 'http://timg.bdta.pro/images/e30d3b34cb2e1a24d1c30c90640e8999.jpg'),
(50398, 3473, 'Outlander S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230197.mp4', 'http://timg.bdta.pro/images/ace37164ccdb8db63f8cbf6b62ca5930.jpg'),
(50399, 3473, 'Outlander S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230198.mp4', 'http://timg.bdta.pro/images/50d7f005f148338594e6fc875c0b9f00.jpg'),
(50400, 3473, 'Outlander S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230199.mp4', 'http://timg.bdta.pro/images/bce8d2fae2d0fe4f55cf997cf979e51d.jpg'),
(50401, 3474, 'Outlander S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230200.mp4', 'http://image.tmdb.org/t/p/w1280/cAEuXKzZmANg6cnlg2l1FWtniJc.jpg'),
(50402, 3474, 'Outlander S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230201.mp4', 'http://image.tmdb.org/t/p/w1280/mElPSv4xawD24X9pr99h1L4SRUR.jpg'),
(50403, 3474, 'Outlander S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230202.mp4', 'http://image.tmdb.org/t/p/w1280/e7GnShMtnZgFTUwG7TuFZV8TZye.jpg'),
(50404, 3474, 'Outlander S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230203.mp4', 'http://image.tmdb.org/t/p/w1280/lNF5TVS0a6dZJwlHKaY9fnJCBS3.jpg'),
(50405, 3474, 'Outlander S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230204.mp4', 'http://image.tmdb.org/t/p/w1280/edWHjFQpyyQ9e4ULzkXGu9SBr5q.jpg'),
(50406, 3474, 'Outlander S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230205.mp4', 'http://image.tmdb.org/t/p/w1280/dzlMa5tM0bk4xHWoanBdnU2P1sR.jpg'),
(50407, 3474, 'Outlander S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230206.mp4', 'http://image.tmdb.org/t/p/w1280/wAhOdDdKfYFNM6Uh8ARIy3R6oM.jpg'),
(50408, 3474, 'Outlander S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230207.mp4', 'http://image.tmdb.org/t/p/w1280/7vZD4D3qCbmgIbrhHMnciiyPhwJ.jpg'),
(50409, 3474, 'Outlander S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/511372.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50410, 3474, 'Outlander S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/514205.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50411, 3474, 'Outlander S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/517674.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50412, 3474, 'Outlander S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/525115.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50413, 3474, 'Outlander S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/638351.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50414, 3474, 'Outlander S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/658040.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50415, 3474, 'Outlander S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/658041.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50416, 3474, 'Outlander S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/667870.mp4', 'http://gstaticontent.com/images/ioQ0o7dOU6AD8gKIHHPX0czqgSw_big.jpg'),
(50417, 3475, 'Apostando Alto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145659.mp4', 'http://gstaticontent.com/images/7k9fFAIDGREJnGupxAfR3VFPVUc_big.jpg'),
(50418, 3475, 'Apostando Alto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145660.mp4', 'http://gstaticontent.com/images/7k9fFAIDGREJnGupxAfR3VFPVUc_big.jpg'),
(50419, 3475, 'Apostando Alto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145661.mp4', 'http://gstaticontent.com/images/7k9fFAIDGREJnGupxAfR3VFPVUc_big.jpg'),
(50420, 3475, 'Apostando Alto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145662.mp4', 'http://gstaticontent.com/images/7k9fFAIDGREJnGupxAfR3VFPVUc_big.jpg'),
(50421, 3475, 'Apostando Alto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145663.mp4', 'http://gstaticontent.com/images/7k9fFAIDGREJnGupxAfR3VFPVUc_big.jpg'),
(50422, 3475, 'Apostando Alto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145664.mp4', 'http://gstaticontent.com/images/7k9fFAIDGREJnGupxAfR3VFPVUc_big.jpg'),
(50423, 3475, 'Apostando Alto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145665.mp4', 'http://gstaticontent.com/images/7k9fFAIDGREJnGupxAfR3VFPVUc_big.jpg'),
(50424, 3475, 'Apostando Alto S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145666.mp4', 'http://gstaticontent.com/images/7k9fFAIDGREJnGupxAfR3VFPVUc_big.jpg'),
(50425, 3475, 'Apostando Alto S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145667.mp4', 'http://gstaticontent.com/images/7k9fFAIDGREJnGupxAfR3VFPVUc_big.jpg'),
(50426, 3475, 'Apostando Alto S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145668.mp4', 'http://gstaticontent.com/images/7k9fFAIDGREJnGupxAfR3VFPVUc_big.jpg'),
(50427, 3475, 'Apostando Alto S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145669.mp4', 'http://gstaticontent.com/images/7k9fFAIDGREJnGupxAfR3VFPVUc_big.jpg'),
(50428, 3475, 'Apostando Alto S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145670.mp4', 'http://gstaticontent.com/images/7k9fFAIDGREJnGupxAfR3VFPVUc_big.jpg'),
(50429, 3475, 'Apostando Alto S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145671.mp4', 'http://gstaticontent.com/images/7k9fFAIDGREJnGupxAfR3VFPVUc_big.jpg'),
(50430, 3475, 'Apostando Alto S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145672.mp4', 'http://gstaticontent.com/images/7k9fFAIDGREJnGupxAfR3VFPVUc_big.jpg'),
(50431, 3475, 'Apostando Alto S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145673.mp4', 'http://gstaticontent.com/images/7k9fFAIDGREJnGupxAfR3VFPVUc_big.jpg'),
(50432, 3475, 'Apostando Alto S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145674.mp4', 'http://gstaticontent.com/images/7k9fFAIDGREJnGupxAfR3VFPVUc_big.jpg'),
(50433, 3476, 'Caçadora de Relíquias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145615.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50434, 3476, 'Caçadora de Relíquias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145616.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50435, 3476, 'Caçadora de Relíquias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145617.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50436, 3476, 'Caçadora de Relíquias S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145618.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50437, 3476, 'Caçadora de Relíquias S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145619.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50438, 3476, 'Caçadora de Relíquias S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145620.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50439, 3476, 'Caçadora de Relíquias S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145621.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50440, 3476, 'Caçadora de Relíquias S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145622.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50441, 3476, 'Caçadora de Relíquias S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145623.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50442, 3476, 'Caçadora de Relíquias S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145624.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50443, 3476, 'Caçadora de Relíquias S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145625.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50444, 3476, 'Caçadora de Relíquias S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145626.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50445, 3476, 'Caçadora de Relíquias S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145627.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50446, 3476, 'Caçadora de Relíquias S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145628.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50447, 3476, 'Caçadora de Relíquias S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145629.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50448, 3476, 'Caçadora de Relíquias S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145630.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50449, 3476, 'Caçadora de Relíquias S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145631.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50450, 3476, 'Caçadora de Relíquias S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/145632.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50451, 3476, 'Caçadora de Relíquias S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/145633.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50452, 3476, 'Caçadora de Relíquias S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/145634.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50453, 3476, 'Caçadora de Relíquias S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/145635.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50454, 3476, 'Caçadora de Relíquias S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/145636.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50455, 3477, 'Caçadora de Relíquias S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145637.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50456, 3477, 'Caçadora de Relíquias S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145638.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50457, 3477, 'Caçadora de Relíquias S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145639.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50458, 3477, 'Caçadora de Relíquias S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145640.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50459, 3477, 'Caçadora de Relíquias S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145641.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50460, 3477, 'Caçadora de Relíquias S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145642.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50461, 3477, 'Caçadora de Relíquias S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145643.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50462, 3477, 'Caçadora de Relíquias S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145644.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50463, 3477, 'Caçadora de Relíquias S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145645.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50464, 3477, 'Caçadora de Relíquias S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145646.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50465, 3477, 'Caçadora de Relíquias S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145647.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50466, 3477, 'Caçadora de Relíquias S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145648.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50467, 3477, 'Caçadora de Relíquias S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145649.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50468, 3477, 'Caçadora de Relíquias S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145650.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50469, 3477, 'Caçadora de Relíquias S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145651.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50470, 3477, 'Caçadora de Relíquias S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145652.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50471, 3477, 'Caçadora de Relíquias S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145653.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50472, 3477, 'Caçadora de Relíquias S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/145654.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50473, 3477, 'Caçadora de Relíquias S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/145655.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50474, 3477, 'Caçadora de Relíquias S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/145656.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50475, 3477, 'Caçadora de Relíquias S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/145657.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50476, 3477, 'Caçadora de Relíquias S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/145658.mp4', 'http://gstaticontent.com/images/5Z8RlbA4imquYf0vJmkAoLyzY0n_big.jpg'),
(50477, 3478, 'Meu Amor: Seis Histórias de Amor Verdadeiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145609.mp4', 'http://gstaticontent.com/images/lzWNo5qRRvZ0SkmoFgnJ62EtMk_big.jpg'),
(50478, 3478, 'Meu Amor: Seis Histórias de Amor Verdadeiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145610.mp4', 'http://gstaticontent.com/images/lzWNo5qRRvZ0SkmoFgnJ62EtMk_big.jpg'),
(50479, 3478, 'Meu Amor: Seis Histórias de Amor Verdadeiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145611.mp4', 'http://gstaticontent.com/images/lzWNo5qRRvZ0SkmoFgnJ62EtMk_big.jpg'),
(50480, 3478, 'Meu Amor: Seis Histórias de Amor Verdadeiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145612.mp4', 'http://gstaticontent.com/images/lzWNo5qRRvZ0SkmoFgnJ62EtMk_big.jpg'),
(50481, 3478, 'Meu Amor: Seis Histórias de Amor Verdadeiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145613.mp4', 'http://gstaticontent.com/images/lzWNo5qRRvZ0SkmoFgnJ62EtMk_big.jpg'),
(50482, 3478, 'Meu Amor: Seis Histórias de Amor Verdadeiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145614.mp4', 'http://gstaticontent.com/images/lzWNo5qRRvZ0SkmoFgnJ62EtMk_big.jpg'),
(50483, 3479, 'Na Direção do Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145593.mp4', 'http://gstaticontent.com/images/lS4cOR2WxHs2h4pegNUaZVVIyNA_big.jpg'),
(50484, 3479, 'Na Direção do Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145594.mp4', 'http://gstaticontent.com/images/lS4cOR2WxHs2h4pegNUaZVVIyNA_big.jpg'),
(50485, 3479, 'Na Direção do Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145595.mp4', 'http://gstaticontent.com/images/lS4cOR2WxHs2h4pegNUaZVVIyNA_big.jpg'),
(50486, 3479, 'Na Direção do Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145596.mp4', 'http://gstaticontent.com/images/lS4cOR2WxHs2h4pegNUaZVVIyNA_big.jpg'),
(50487, 3479, 'Na Direção do Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145597.mp4', 'http://gstaticontent.com/images/lS4cOR2WxHs2h4pegNUaZVVIyNA_big.jpg'),
(50488, 3479, 'Na Direção do Amor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145598.mp4', 'http://gstaticontent.com/images/lS4cOR2WxHs2h4pegNUaZVVIyNA_big.jpg'),
(50489, 3479, 'Na Direção do Amor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145599.mp4', 'http://gstaticontent.com/images/lS4cOR2WxHs2h4pegNUaZVVIyNA_big.jpg'),
(50490, 3479, 'Na Direção do Amor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145600.mp4', 'http://gstaticontent.com/images/lS4cOR2WxHs2h4pegNUaZVVIyNA_big.jpg'),
(50491, 3479, 'Na Direção do Amor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145601.mp4', 'http://gstaticontent.com/images/lS4cOR2WxHs2h4pegNUaZVVIyNA_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(50492, 3479, 'Na Direção do Amor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145602.mp4', 'http://gstaticontent.com/images/lS4cOR2WxHs2h4pegNUaZVVIyNA_big.jpg'),
(50493, 3479, 'Na Direção do Amor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145603.mp4', 'http://gstaticontent.com/images/lS4cOR2WxHs2h4pegNUaZVVIyNA_big.jpg'),
(50494, 3479, 'Na Direção do Amor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145604.mp4', 'http://gstaticontent.com/images/lS4cOR2WxHs2h4pegNUaZVVIyNA_big.jpg'),
(50495, 3479, 'Na Direção do Amor S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145605.mp4', 'http://gstaticontent.com/images/lS4cOR2WxHs2h4pegNUaZVVIyNA_big.jpg'),
(50496, 3479, 'Na Direção do Amor S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145606.mp4', 'http://gstaticontent.com/images/lS4cOR2WxHs2h4pegNUaZVVIyNA_big.jpg'),
(50497, 3479, 'Na Direção do Amor S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145607.mp4', 'http://gstaticontent.com/images/lS4cOR2WxHs2h4pegNUaZVVIyNA_big.jpg'),
(50498, 3479, 'Na Direção do Amor S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145608.mp4', 'http://gstaticontent.com/images/lS4cOR2WxHs2h4pegNUaZVVIyNA_big.jpg'),
(50499, 3480, 'Mister Brau S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163937.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50500, 3480, 'Mister Brau S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163938.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50501, 3480, 'Mister Brau S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163939.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50502, 3480, 'Mister Brau S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163940.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50503, 3480, 'Mister Brau S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163941.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50504, 3480, 'Mister Brau S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163942.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50505, 3480, 'Mister Brau S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163943.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50506, 3480, 'Mister Brau S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163944.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50507, 3480, 'Mister Brau S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163945.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50508, 3480, 'Mister Brau S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163946.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50509, 3480, 'Mister Brau S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163947.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50510, 3480, 'Mister Brau S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163948.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50511, 3480, 'Mister Brau S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163949.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50512, 3481, 'Mister Brau S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163950.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50513, 3481, 'Mister Brau S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163951.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50514, 3481, 'Mister Brau S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163952.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50515, 3481, 'Mister Brau S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163953.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50516, 3481, 'Mister Brau S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163954.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50517, 3481, 'Mister Brau S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163955.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50518, 3481, 'Mister Brau S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163956.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50519, 3481, 'Mister Brau S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163957.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50520, 3481, 'Mister Brau S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163958.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50521, 3481, 'Mister Brau S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163959.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50522, 3481, 'Mister Brau S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163960.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50523, 3481, 'Mister Brau S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163961.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50524, 3481, 'Mister Brau S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163962.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50525, 3481, 'Mister Brau S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163963.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50526, 3481, 'Mister Brau S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163964.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50527, 3481, 'Mister Brau S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163965.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50528, 3481, 'Mister Brau S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163966.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50529, 3481, 'Mister Brau S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163967.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50530, 3482, 'Mister Brau S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163968.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50531, 3482, 'Mister Brau S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163969.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50532, 3482, 'Mister Brau S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163970.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50533, 3482, 'Mister Brau S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163971.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50534, 3482, 'Mister Brau S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163972.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50535, 3482, 'Mister Brau S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163973.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50536, 3482, 'Mister Brau S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163974.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50537, 3482, 'Mister Brau S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163975.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50538, 3482, 'Mister Brau S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163976.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50539, 3482, 'Mister Brau S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163977.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50540, 3482, 'Mister Brau S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163978.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50541, 3482, 'Mister Brau S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163979.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50542, 3482, 'Mister Brau S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163980.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50543, 3482, 'Mister Brau S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163981.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50544, 3483, 'Mister Brau S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/goo5nimjgt9iwMzZMhqsrTmWEeg.jpg'),
(50545, 3483, 'Mister Brau S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wjiPLV167BxinFojrBeQYoihtU6.jpg'),
(50546, 3483, 'Mister Brau S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i2fvQCEOleiIhzeLk5n3KBGbp3G.jpg'),
(50547, 3483, 'Mister Brau S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pgtmHOJlputklivD9EmtECbdAuB.jpg'),
(50548, 3483, 'Mister Brau S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/siSkSLSAHhwbSOOVsf5GXZH2zUU.jpg'),
(50549, 3483, 'Mister Brau S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bDtUOPR8xbcN5dKCOPoK7WI9wws.jpg'),
(50550, 3483, 'Mister Brau S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lvw8OjdsQq2IEpfMwc8OSyxH2Ed.jpg'),
(50551, 3483, 'Mister Brau S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163989.mp4', 'http://gstaticontent.com/images/uZM9lTmirwYqRPxr56SzrhemYWn_big.jpg'),
(50552, 3484, 'Meu Pai e Outros Vexames S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145585.mp4', 'http://gstaticontent.com/images/yGz6d9wdK3zndUmrivt3E2JLmop_big.jpg'),
(50553, 3484, 'Meu Pai e Outros Vexames S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145586.mp4', 'http://gstaticontent.com/images/yGz6d9wdK3zndUmrivt3E2JLmop_big.jpg'),
(50554, 3484, 'Meu Pai e Outros Vexames S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145587.mp4', 'http://gstaticontent.com/images/yGz6d9wdK3zndUmrivt3E2JLmop_big.jpg'),
(50555, 3484, 'Meu Pai e Outros Vexames S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145588.mp4', 'http://gstaticontent.com/images/yGz6d9wdK3zndUmrivt3E2JLmop_big.jpg'),
(50556, 3484, 'Meu Pai e Outros Vexames S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145589.mp4', 'http://gstaticontent.com/images/yGz6d9wdK3zndUmrivt3E2JLmop_big.jpg'),
(50557, 3484, 'Meu Pai e Outros Vexames S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145590.mp4', 'http://gstaticontent.com/images/yGz6d9wdK3zndUmrivt3E2JLmop_big.jpg'),
(50558, 3484, 'Meu Pai e Outros Vexames S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145591.mp4', 'http://gstaticontent.com/images/yGz6d9wdK3zndUmrivt3E2JLmop_big.jpg'),
(50559, 3484, 'Meu Pai e Outros Vexames S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145592.mp4', 'http://gstaticontent.com/images/yGz6d9wdK3zndUmrivt3E2JLmop_big.jpg'),
(50560, 3485, 'A Corrida das Vacinas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143438.mp4', 'http://gstaticontent.com/images/kY1AV20yhrcwZko6yEt7DLbK8DC_big.jpg'),
(50561, 3485, 'A Corrida das Vacinas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143439.mp4', 'http://gstaticontent.com/images/kY1AV20yhrcwZko6yEt7DLbK8DC_big.jpg'),
(50562, 3485, 'A Corrida das Vacinas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143440.mp4', 'http://gstaticontent.com/images/kY1AV20yhrcwZko6yEt7DLbK8DC_big.jpg'),
(50563, 3485, 'A Corrida das Vacinas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143441.mp4', 'http://gstaticontent.com/images/kY1AV20yhrcwZko6yEt7DLbK8DC_big.jpg'),
(50564, 3485, 'A Corrida das Vacinas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143442.mp4', 'http://gstaticontent.com/images/kY1AV20yhrcwZko6yEt7DLbK8DC_big.jpg'),
(50565, 3486, 'A Love So Beautiful S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145358.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50566, 3486, 'A Love So Beautiful S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145359.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50567, 3486, 'A Love So Beautiful S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145360.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50568, 3486, 'A Love So Beautiful S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145361.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50569, 3486, 'A Love So Beautiful S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145362.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50570, 3486, 'A Love So Beautiful S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145363.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50571, 3486, 'A Love So Beautiful S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145364.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50572, 3486, 'A Love So Beautiful S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145365.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50573, 3486, 'A Love So Beautiful S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145366.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50574, 3486, 'A Love So Beautiful S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145367.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50575, 3486, 'A Love So Beautiful S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145368.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50576, 3486, 'A Love So Beautiful S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145369.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50577, 3486, 'A Love So Beautiful S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145370.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50578, 3486, 'A Love So Beautiful S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145371.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50579, 3486, 'A Love So Beautiful S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145372.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50580, 3486, 'A Love So Beautiful S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145373.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50581, 3486, 'A Love So Beautiful S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145374.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50582, 3486, 'A Love So Beautiful S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/145375.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50583, 3486, 'A Love So Beautiful S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/145376.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50584, 3486, 'A Love So Beautiful S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/145377.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50585, 3486, 'A Love So Beautiful S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/145378.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50586, 3486, 'A Love So Beautiful S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/145379.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50587, 3486, 'A Love So Beautiful S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/145380.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50588, 3486, 'A Love So Beautiful S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/145381.mp4', 'http://gstaticontent.com/images/vm88IHZvnZAW1fVTdbEVj7T4vz4_big.jpg'),
(50589, 3487, 'Bem Juntinhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179358.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50590, 3487, 'Bem Juntinhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179359.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50591, 3487, 'Bem Juntinhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179360.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50592, 3487, 'Bem Juntinhos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179361.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50593, 3487, 'Bem Juntinhos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179362.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50594, 3487, 'Bem Juntinhos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179363.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50595, 3487, 'Bem Juntinhos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179364.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50596, 3487, 'Bem Juntinhos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179365.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50597, 3487, 'Bem Juntinhos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179366.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50598, 3487, 'Bem Juntinhos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179367.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50599, 3487, 'Bem Juntinhos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179368.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50600, 3487, 'Bem Juntinhos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179369.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50601, 3487, 'Bem Juntinhos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/179370.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50602, 3488, 'Bem Juntinhos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179371.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50603, 3488, 'Bem Juntinhos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179372.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50604, 3488, 'Bem Juntinhos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179373.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50605, 3488, 'Bem Juntinhos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179374.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50606, 3488, 'Bem Juntinhos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179375.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50607, 3488, 'Bem Juntinhos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179376.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50608, 3488, 'Bem Juntinhos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179377.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50609, 3488, 'Bem Juntinhos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179378.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50610, 3488, 'Bem Juntinhos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179379.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50611, 3488, 'Bem Juntinhos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179380.mp4', 'https://i.bj-share.info/b55f815d5f4e239fbd94e43565bec3c3.jpg'),
(50612, 3489, 'Big Shot: Treinador de Elite S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195823.mp4', 'http://gstaticontent.com/images/AuRTQIvSYffeKNZIrw3EXwBALd0_big.jpg'),
(50613, 3489, 'Big Shot: Treinador de Elite S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195824.mp4', 'http://gstaticontent.com/images/AuRTQIvSYffeKNZIrw3EXwBALd0_big.jpg'),
(50614, 3489, 'Big Shot: Treinador de Elite S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195825.mp4', 'http://gstaticontent.com/images/AuRTQIvSYffeKNZIrw3EXwBALd0_big.jpg'),
(50615, 3489, 'Big Shot: Treinador de Elite S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195826.mp4', 'http://gstaticontent.com/images/AuRTQIvSYffeKNZIrw3EXwBALd0_big.jpg'),
(50616, 3489, 'Big Shot: Treinador de Elite S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195827.mp4', 'http://gstaticontent.com/images/AuRTQIvSYffeKNZIrw3EXwBALd0_big.jpg'),
(50617, 3489, 'Big Shot: Treinador de Elite S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195828.mp4', 'http://gstaticontent.com/images/AuRTQIvSYffeKNZIrw3EXwBALd0_big.jpg'),
(50618, 3489, 'Big Shot: Treinador de Elite S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195829.mp4', 'http://gstaticontent.com/images/AuRTQIvSYffeKNZIrw3EXwBALd0_big.jpg'),
(50619, 3489, 'Big Shot: Treinador de Elite S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195830.mp4', 'http://gstaticontent.com/images/AuRTQIvSYffeKNZIrw3EXwBALd0_big.jpg'),
(50620, 3489, 'Big Shot: Treinador de Elite S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195831.mp4', 'http://gstaticontent.com/images/AuRTQIvSYffeKNZIrw3EXwBALd0_big.jpg'),
(50621, 3489, 'Big Shot: Treinador de Elite S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195832.mp4', 'http://gstaticontent.com/images/AuRTQIvSYffeKNZIrw3EXwBALd0_big.jpg'),
(50622, 3490, 'Big Shot: Treinador de Elite S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195833.mp4', 'http://timg.bdta.pro/images/f9d666c51b4a8ec86edcb61a4ab14d51.jpg'),
(50623, 3490, 'Big Shot: Treinador de Elite S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195834.mp4', 'http://timg.bdta.pro/images/f16d583e076a75bde0f888e30308aaf2.jpg'),
(50624, 3490, 'Big Shot: Treinador de Elite S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195835.mp4', 'http://timg.bdta.pro/images/3541218d440c7b5d11299d1d795a6ae4.jpg'),
(50625, 3490, 'Big Shot: Treinador de Elite S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195836.mp4', 'http://timg.bdta.pro/images/263a5e095e37cd92590252dfdee9e935.jpg'),
(50626, 3490, 'Big Shot: Treinador de Elite S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195837.mp4', 'http://timg.bdta.pro/images/1f0445f061c664de605f78ad58199483.jpg'),
(50627, 3490, 'Big Shot: Treinador de Elite S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195838.mp4', 'http://timg.bdta.pro/images/3928940940e15f53e05424db5f937425.jpg'),
(50628, 3490, 'Big Shot: Treinador de Elite S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195839.mp4', 'http://timg.bdta.pro/images/a4c013901d90615782e6e6c0e1d0187f.jpg'),
(50629, 3490, 'Big Shot: Treinador de Elite S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195840.mp4', 'http://timg.bdta.pro/images/a2955123855e02531a59c97bc40364ce.jpg'),
(50630, 3490, 'Big Shot: Treinador de Elite S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195841.mp4', 'http://timg.bdta.pro/images/7b7c10fa54ed109d80c3972d50d1eceb.jpg'),
(50631, 3490, 'Big Shot: Treinador de Elite S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195842.mp4', 'http://timg.bdta.pro/images/f32535153aadf68633ddea00b4dedb8c.jpg'),
(50632, 3491, 'Victor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179330.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50633, 3491, 'Victor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179331.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50634, 3491, 'Victor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179332.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50635, 3491, 'Victor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179333.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50636, 3491, 'Victor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179334.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50637, 3491, 'Victor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179335.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50638, 3491, 'Victor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179336.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50639, 3491, 'Victor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179337.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50640, 3491, 'Victor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179338.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50641, 3491, 'Victor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179339.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50642, 3492, 'Victor S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179340.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50643, 3492, 'Victor S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179341.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50644, 3492, 'Victor S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179342.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50645, 3492, 'Victor S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179343.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50646, 3492, 'Victor S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179344.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50647, 3492, 'Victor S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179345.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50648, 3492, 'Victor S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179346.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50649, 3492, 'Victor S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179347.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50650, 3492, 'Victor S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179348.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50651, 3492, 'Victor S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179349.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50652, 3493, 'Victor S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179350.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50653, 3493, 'Victor S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179351.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50654, 3493, 'Victor S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179352.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50655, 3493, 'Victor S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179353.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50656, 3493, 'Victor S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179354.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50657, 3493, 'Victor S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179355.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50658, 3493, 'Victor S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179356.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50659, 3493, 'Victor S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179357.mp4', 'http://gstaticontent.com/images/mdzn5PtLDtKRj1vd7MLFwkemcTv_big.jpg'),
(50660, 3494, 'CSI: Investigação Criminal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50661, 3494, 'CSI: Investigação Criminal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50662, 3494, 'CSI: Investigação Criminal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50663, 3494, 'CSI: Investigação Criminal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50664, 3494, 'CSI: Investigação Criminal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50665, 3494, 'CSI: Investigação Criminal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50666, 3494, 'CSI: Investigação Criminal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50667, 3494, 'CSI: Investigação Criminal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50668, 3494, 'CSI: Investigação Criminal S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50669, 3494, 'CSI: Investigação Criminal S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50670, 3494, 'CSI: Investigação Criminal S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50671, 3494, 'CSI: Investigação Criminal S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50672, 3494, 'CSI: Investigação Criminal S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50673, 3494, 'CSI: Investigação Criminal S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50674, 3494, 'CSI: Investigação Criminal S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50675, 3494, 'CSI: Investigação Criminal S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50676, 3494, 'CSI: Investigação Criminal S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50677, 3494, 'CSI: Investigação Criminal S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/144986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50678, 3494, 'CSI: Investigação Criminal S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/144987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50679, 3494, 'CSI: Investigação Criminal S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50680, 3494, 'CSI: Investigação Criminal S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/144989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50681, 3494, 'CSI: Investigação Criminal S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/144990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50682, 3494, 'CSI: Investigação Criminal S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/144991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50683, 3495, 'CSI: Investigação Criminal S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50684, 3495, 'CSI: Investigação Criminal S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50685, 3495, 'CSI: Investigação Criminal S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50686, 3495, 'CSI: Investigação Criminal S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50687, 3495, 'CSI: Investigação Criminal S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50688, 3495, 'CSI: Investigação Criminal S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50689, 3495, 'CSI: Investigação Criminal S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50690, 3495, 'CSI: Investigação Criminal S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50691, 3495, 'CSI: Investigação Criminal S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50692, 3495, 'CSI: Investigação Criminal S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50693, 3495, 'CSI: Investigação Criminal S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50694, 3495, 'CSI: Investigação Criminal S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50695, 3495, 'CSI: Investigação Criminal S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50696, 3495, 'CSI: Investigação Criminal S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50697, 3495, 'CSI: Investigação Criminal S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50698, 3495, 'CSI: Investigação Criminal S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50699, 3495, 'CSI: Investigação Criminal S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50700, 3495, 'CSI: Investigação Criminal S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/145009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50701, 3495, 'CSI: Investigação Criminal S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/145010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50702, 3495, 'CSI: Investigação Criminal S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/145011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50703, 3495, 'CSI: Investigação Criminal S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/145012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50704, 3495, 'CSI: Investigação Criminal S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/145013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50705, 3495, 'CSI: Investigação Criminal S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/145014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50706, 3496, 'CSI: Investigação Criminal S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50707, 3496, 'CSI: Investigação Criminal S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50708, 3496, 'CSI: Investigação Criminal S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50709, 3496, 'CSI: Investigação Criminal S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50710, 3496, 'CSI: Investigação Criminal S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50711, 3496, 'CSI: Investigação Criminal S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50712, 3496, 'CSI: Investigação Criminal S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50713, 3496, 'CSI: Investigação Criminal S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50714, 3496, 'CSI: Investigação Criminal S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50715, 3496, 'CSI: Investigação Criminal S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50716, 3496, 'CSI: Investigação Criminal S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50717, 3496, 'CSI: Investigação Criminal S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50718, 3496, 'CSI: Investigação Criminal S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50719, 3496, 'CSI: Investigação Criminal S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50720, 3496, 'CSI: Investigação Criminal S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50721, 3496, 'CSI: Investigação Criminal S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50722, 3496, 'CSI: Investigação Criminal S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50723, 3496, 'CSI: Investigação Criminal S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/145032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50724, 3496, 'CSI: Investigação Criminal S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/145033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50725, 3496, 'CSI: Investigação Criminal S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/145034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50726, 3496, 'CSI: Investigação Criminal S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/145035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50727, 3496, 'CSI: Investigação Criminal S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/145036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50728, 3496, 'CSI: Investigação Criminal S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/145037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50729, 3497, 'CSI: Investigação Criminal S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50730, 3497, 'CSI: Investigação Criminal S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50731, 3497, 'CSI: Investigação Criminal S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50732, 3497, 'CSI: Investigação Criminal S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50733, 3497, 'CSI: Investigação Criminal S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50734, 3497, 'CSI: Investigação Criminal S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50735, 3497, 'CSI: Investigação Criminal S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50736, 3497, 'CSI: Investigação Criminal S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50737, 3497, 'CSI: Investigação Criminal S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50738, 3497, 'CSI: Investigação Criminal S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50739, 3497, 'CSI: Investigação Criminal S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50740, 3497, 'CSI: Investigação Criminal S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50741, 3497, 'CSI: Investigação Criminal S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50742, 3497, 'CSI: Investigação Criminal S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50743, 3497, 'CSI: Investigação Criminal S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50744, 3497, 'CSI: Investigação Criminal S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50745, 3497, 'CSI: Investigação Criminal S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50746, 3497, 'CSI: Investigação Criminal S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/145055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50747, 3497, 'CSI: Investigação Criminal S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/145056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50748, 3497, 'CSI: Investigação Criminal S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/145057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50749, 3497, 'CSI: Investigação Criminal S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/145058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50750, 3497, 'CSI: Investigação Criminal S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/145059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50751, 3497, 'CSI: Investigação Criminal S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/145060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50752, 3498, 'CSI: Investigação Criminal S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50753, 3498, 'CSI: Investigação Criminal S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50754, 3498, 'CSI: Investigação Criminal S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50755, 3498, 'CSI: Investigação Criminal S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50756, 3498, 'CSI: Investigação Criminal S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50757, 3498, 'CSI: Investigação Criminal S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50758, 3498, 'CSI: Investigação Criminal S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50759, 3498, 'CSI: Investigação Criminal S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50760, 3498, 'CSI: Investigação Criminal S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50761, 3498, 'CSI: Investigação Criminal S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(50762, 3498, 'CSI: Investigação Criminal S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50763, 3498, 'CSI: Investigação Criminal S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50764, 3498, 'CSI: Investigação Criminal S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50765, 3498, 'CSI: Investigação Criminal S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50766, 3498, 'CSI: Investigação Criminal S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50767, 3498, 'CSI: Investigação Criminal S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50768, 3498, 'CSI: Investigação Criminal S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50769, 3498, 'CSI: Investigação Criminal S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/880917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sGUR9m7w7vMPTPZDYTBFNG59YIB.jpg'),
(50770, 3498, 'CSI: Investigação Criminal S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/880918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/slsVrCmdnCWSYGXJpLBEScnMtmb.jpg'),
(50771, 3498, 'CSI: Investigação Criminal S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/880919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kZuPMjvxcgm5CNTwnVg0NQ3pb.jpg'),
(50772, 3498, 'CSI: Investigação Criminal S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/880920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ziwXee6kTmqSSBYECsfeF2SFr0M.jpg'),
(50773, 3498, 'CSI: Investigação Criminal S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/880921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9tLm9W26pPaKYeoUCtiTfsZrICR.jpg'),
(50774, 3498, 'CSI: Investigação Criminal S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/880922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a6rJxIaKgVQ4mPekfsKvCMIKQrR.jpg'),
(50775, 3498, 'CSI: Investigação Criminal S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/880923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A416w3yOXJaTOHNtlHpJbLqSUd.jpg'),
(50776, 3499, 'CSI: Investigação Criminal S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50777, 3499, 'CSI: Investigação Criminal S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50778, 3499, 'CSI: Investigação Criminal S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50779, 3499, 'CSI: Investigação Criminal S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50780, 3499, 'CSI: Investigação Criminal S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50781, 3499, 'CSI: Investigação Criminal S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50782, 3499, 'CSI: Investigação Criminal S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50783, 3499, 'CSI: Investigação Criminal S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50784, 3499, 'CSI: Investigação Criminal S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50785, 3499, 'CSI: Investigação Criminal S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50786, 3499, 'CSI: Investigação Criminal S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50787, 3499, 'CSI: Investigação Criminal S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50788, 3499, 'CSI: Investigação Criminal S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50789, 3499, 'CSI: Investigação Criminal S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50790, 3499, 'CSI: Investigação Criminal S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50791, 3499, 'CSI: Investigação Criminal S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50792, 3499, 'CSI: Investigação Criminal S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50793, 3499, 'CSI: Investigação Criminal S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/145095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50794, 3499, 'CSI: Investigação Criminal S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/145096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50795, 3499, 'CSI: Investigação Criminal S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/145097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50796, 3499, 'CSI: Investigação Criminal S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/145098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50797, 3499, 'CSI: Investigação Criminal S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/145099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50798, 3499, 'CSI: Investigação Criminal S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/145100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50799, 3499, 'CSI: Investigação Criminal S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/145101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50800, 3500, 'CSI: Investigação Criminal S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50801, 3500, 'CSI: Investigação Criminal S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50802, 3500, 'CSI: Investigação Criminal S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50803, 3500, 'CSI: Investigação Criminal S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50804, 3500, 'CSI: Investigação Criminal S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50805, 3500, 'CSI: Investigação Criminal S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50806, 3500, 'CSI: Investigação Criminal S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50807, 3500, 'CSI: Investigação Criminal S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50808, 3500, 'CSI: Investigação Criminal S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50809, 3500, 'CSI: Investigação Criminal S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50810, 3500, 'CSI: Investigação Criminal S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50811, 3500, 'CSI: Investigação Criminal S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50812, 3500, 'CSI: Investigação Criminal S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50813, 3500, 'CSI: Investigação Criminal S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50814, 3500, 'CSI: Investigação Criminal S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50815, 3500, 'CSI: Investigação Criminal S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50816, 3500, 'CSI: Investigação Criminal S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50817, 3500, 'CSI: Investigação Criminal S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/145119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50818, 3500, 'CSI: Investigação Criminal S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/145120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50819, 3500, 'CSI: Investigação Criminal S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/145121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50820, 3500, 'CSI: Investigação Criminal S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/145122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50821, 3500, 'CSI: Investigação Criminal S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/145123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50822, 3500, 'CSI: Investigação Criminal S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/145124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50823, 3501, 'CSI: Investigação Criminal S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50824, 3501, 'CSI: Investigação Criminal S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50825, 3501, 'CSI: Investigação Criminal S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50826, 3501, 'CSI: Investigação Criminal S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50827, 3501, 'CSI: Investigação Criminal S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50828, 3501, 'CSI: Investigação Criminal S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50829, 3501, 'CSI: Investigação Criminal S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50830, 3501, 'CSI: Investigação Criminal S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50831, 3501, 'CSI: Investigação Criminal S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50832, 3501, 'CSI: Investigação Criminal S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50833, 3501, 'CSI: Investigação Criminal S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50834, 3501, 'CSI: Investigação Criminal S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50835, 3501, 'CSI: Investigação Criminal S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50836, 3501, 'CSI: Investigação Criminal S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50837, 3501, 'CSI: Investigação Criminal S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50838, 3501, 'CSI: Investigação Criminal S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50839, 3501, 'CSI: Investigação Criminal S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50840, 3502, 'CSI: Investigação Criminal S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50841, 3502, 'CSI: Investigação Criminal S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50842, 3502, 'CSI: Investigação Criminal S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50843, 3502, 'CSI: Investigação Criminal S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50844, 3502, 'CSI: Investigação Criminal S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50845, 3502, 'CSI: Investigação Criminal S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50846, 3502, 'CSI: Investigação Criminal S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50847, 3502, 'CSI: Investigação Criminal S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50848, 3502, 'CSI: Investigação Criminal S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50849, 3502, 'CSI: Investigação Criminal S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50850, 3502, 'CSI: Investigação Criminal S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50851, 3502, 'CSI: Investigação Criminal S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50852, 3502, 'CSI: Investigação Criminal S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50853, 3502, 'CSI: Investigação Criminal S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50854, 3502, 'CSI: Investigação Criminal S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50855, 3502, 'CSI: Investigação Criminal S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50856, 3502, 'CSI: Investigação Criminal S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50857, 3502, 'CSI: Investigação Criminal S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/145159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50858, 3502, 'CSI: Investigação Criminal S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/145160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50859, 3502, 'CSI: Investigação Criminal S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/145161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50860, 3502, 'CSI: Investigação Criminal S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/145162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50861, 3502, 'CSI: Investigação Criminal S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/145163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50862, 3502, 'CSI: Investigação Criminal S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/145164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50863, 3502, 'CSI: Investigação Criminal S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/145165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50864, 3503, 'CSI: Investigação Criminal S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50865, 3503, 'CSI: Investigação Criminal S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50866, 3503, 'CSI: Investigação Criminal S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50867, 3503, 'CSI: Investigação Criminal S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50868, 3503, 'CSI: Investigação Criminal S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50869, 3503, 'CSI: Investigação Criminal S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50870, 3503, 'CSI: Investigação Criminal S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50871, 3503, 'CSI: Investigação Criminal S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50872, 3503, 'CSI: Investigação Criminal S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50873, 3503, 'CSI: Investigação Criminal S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50874, 3503, 'CSI: Investigação Criminal S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50875, 3503, 'CSI: Investigação Criminal S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50876, 3503, 'CSI: Investigação Criminal S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50877, 3503, 'CSI: Investigação Criminal S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50878, 3503, 'CSI: Investigação Criminal S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50879, 3503, 'CSI: Investigação Criminal S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50880, 3503, 'CSI: Investigação Criminal S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50881, 3503, 'CSI: Investigação Criminal S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/145183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50882, 3503, 'CSI: Investigação Criminal S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/145184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50883, 3503, 'CSI: Investigação Criminal S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/145185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50884, 3503, 'CSI: Investigação Criminal S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/145186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50885, 3503, 'CSI: Investigação Criminal S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/145187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50886, 3503, 'CSI: Investigação Criminal S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/145188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50887, 3504, 'CSI: Investigação Criminal S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50888, 3504, 'CSI: Investigação Criminal S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50889, 3504, 'CSI: Investigação Criminal S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50890, 3504, 'CSI: Investigação Criminal S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50891, 3504, 'CSI: Investigação Criminal S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50892, 3504, 'CSI: Investigação Criminal S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50893, 3504, 'CSI: Investigação Criminal S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50894, 3504, 'CSI: Investigação Criminal S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50895, 3504, 'CSI: Investigação Criminal S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50896, 3504, 'CSI: Investigação Criminal S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50897, 3504, 'CSI: Investigação Criminal S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50898, 3504, 'CSI: Investigação Criminal S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50899, 3504, 'CSI: Investigação Criminal S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50900, 3504, 'CSI: Investigação Criminal S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50901, 3504, 'CSI: Investigação Criminal S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50902, 3504, 'CSI: Investigação Criminal S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50903, 3504, 'CSI: Investigação Criminal S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50904, 3504, 'CSI: Investigação Criminal S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/145206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50905, 3504, 'CSI: Investigação Criminal S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/145207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50906, 3504, 'CSI: Investigação Criminal S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/145208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50907, 3504, 'CSI: Investigação Criminal S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/145209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50908, 3504, 'CSI: Investigação Criminal S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/145210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50909, 3505, 'CSI: Investigação Criminal S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50910, 3505, 'CSI: Investigação Criminal S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50911, 3505, 'CSI: Investigação Criminal S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50912, 3505, 'CSI: Investigação Criminal S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50913, 3505, 'CSI: Investigação Criminal S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50914, 3505, 'CSI: Investigação Criminal S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50915, 3505, 'CSI: Investigação Criminal S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50916, 3505, 'CSI: Investigação Criminal S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50917, 3505, 'CSI: Investigação Criminal S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50918, 3505, 'CSI: Investigação Criminal S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50919, 3505, 'CSI: Investigação Criminal S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50920, 3505, 'CSI: Investigação Criminal S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50921, 3505, 'CSI: Investigação Criminal S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50922, 3505, 'CSI: Investigação Criminal S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50923, 3505, 'CSI: Investigação Criminal S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50924, 3505, 'CSI: Investigação Criminal S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50925, 3505, 'CSI: Investigação Criminal S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50926, 3505, 'CSI: Investigação Criminal S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/145228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50927, 3505, 'CSI: Investigação Criminal S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/145229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50928, 3505, 'CSI: Investigação Criminal S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/145230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50929, 3505, 'CSI: Investigação Criminal S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/145231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50930, 3505, 'CSI: Investigação Criminal S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/145232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50931, 3506, 'CSI: Investigação Criminal S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50932, 3506, 'CSI: Investigação Criminal S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50933, 3506, 'CSI: Investigação Criminal S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50934, 3506, 'CSI: Investigação Criminal S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50935, 3506, 'CSI: Investigação Criminal S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50936, 3506, 'CSI: Investigação Criminal S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50937, 3506, 'CSI: Investigação Criminal S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50938, 3506, 'CSI: Investigação Criminal S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50939, 3506, 'CSI: Investigação Criminal S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50940, 3506, 'CSI: Investigação Criminal S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50941, 3506, 'CSI: Investigação Criminal S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50942, 3506, 'CSI: Investigação Criminal S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50943, 3506, 'CSI: Investigação Criminal S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50944, 3506, 'CSI: Investigação Criminal S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50945, 3506, 'CSI: Investigação Criminal S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50946, 3506, 'CSI: Investigação Criminal S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50947, 3506, 'CSI: Investigação Criminal S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50948, 3506, 'CSI: Investigação Criminal S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/145250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50949, 3506, 'CSI: Investigação Criminal S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/145251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50950, 3506, 'CSI: Investigação Criminal S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/145252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50951, 3506, 'CSI: Investigação Criminal S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/145253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50952, 3506, 'CSI: Investigação Criminal S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/145254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50953, 3507, 'CSI: Investigação Criminal S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50954, 3507, 'CSI: Investigação Criminal S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50955, 3507, 'CSI: Investigação Criminal S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50956, 3507, 'CSI: Investigação Criminal S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50957, 3507, 'CSI: Investigação Criminal S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50958, 3507, 'CSI: Investigação Criminal S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50959, 3507, 'CSI: Investigação Criminal S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50960, 3507, 'CSI: Investigação Criminal S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50961, 3507, 'CSI: Investigação Criminal S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50962, 3507, 'CSI: Investigação Criminal S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50963, 3507, 'CSI: Investigação Criminal S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50964, 3507, 'CSI: Investigação Criminal S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50965, 3507, 'CSI: Investigação Criminal S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50966, 3507, 'CSI: Investigação Criminal S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50967, 3507, 'CSI: Investigação Criminal S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50968, 3507, 'CSI: Investigação Criminal S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50969, 3507, 'CSI: Investigação Criminal S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50970, 3507, 'CSI: Investigação Criminal S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/145272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50971, 3507, 'CSI: Investigação Criminal S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/145273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50972, 3507, 'CSI: Investigação Criminal S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/145274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50973, 3507, 'CSI: Investigação Criminal S14 E21', 'http://sinalprivado.info:80/series/1533784/1533784/145275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50974, 3507, 'CSI: Investigação Criminal S14 E22', 'http://sinalprivado.info:80/series/1533784/1533784/145276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50975, 3508, 'CSI: Investigação Criminal S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50976, 3508, 'CSI: Investigação Criminal S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50977, 3508, 'CSI: Investigação Criminal S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50978, 3508, 'CSI: Investigação Criminal S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50979, 3508, 'CSI: Investigação Criminal S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50980, 3508, 'CSI: Investigação Criminal S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50981, 3508, 'CSI: Investigação Criminal S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50982, 3508, 'CSI: Investigação Criminal S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50983, 3508, 'CSI: Investigação Criminal S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50984, 3508, 'CSI: Investigação Criminal S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50985, 3508, 'CSI: Investigação Criminal S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50986, 3508, 'CSI: Investigação Criminal S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50987, 3508, 'CSI: Investigação Criminal S15 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50988, 3508, 'CSI: Investigação Criminal S15 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50989, 3508, 'CSI: Investigação Criminal S15 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50990, 3508, 'CSI: Investigação Criminal S15 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50991, 3508, 'CSI: Investigação Criminal S15 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50992, 3508, 'CSI: Investigação Criminal S15 E18', 'http://sinalprivado.info:80/series/1533784/1533784/145294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50993, 3509, 'CSI: Investigação Criminal S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50994, 3509, 'CSI: Investigação Criminal S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OOXYxrLLupCiUP78fDVGwaq0As.jpg'),
(50995, 3510, 'Felizes para Sempre: Contos para Todas as Crianças S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145319.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(50996, 3510, 'Felizes para Sempre: Contos para Todas as Crianças S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145320.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(50997, 3510, 'Felizes para Sempre: Contos para Todas as Crianças S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145321.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(50998, 3510, 'Felizes para Sempre: Contos para Todas as Crianças S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145322.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(50999, 3510, 'Felizes para Sempre: Contos para Todas as Crianças S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145323.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51000, 3510, 'Felizes para Sempre: Contos para Todas as Crianças S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145324.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51001, 3510, 'Felizes para Sempre: Contos para Todas as Crianças S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145325.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51002, 3510, 'Felizes para Sempre: Contos para Todas as Crianças S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145326.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51003, 3510, 'Felizes para Sempre: Contos para Todas as Crianças S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145327.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51004, 3510, 'Felizes para Sempre: Contos para Todas as Crianças S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145328.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51005, 3510, 'Felizes para Sempre: Contos para Todas as Crianças S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145329.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51006, 3510, 'Felizes para Sempre: Contos para Todas as Crianças S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145330.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51007, 3510, 'Felizes para Sempre: Contos para Todas as Crianças S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145331.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51008, 3511, 'Felizes para Sempre: Contos para Todas as Crianças S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145332.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51009, 3511, 'Felizes para Sempre: Contos para Todas as Crianças S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145333.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(51010, 3511, 'Felizes para Sempre: Contos para Todas as Crianças S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145334.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51011, 3511, 'Felizes para Sempre: Contos para Todas as Crianças S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145335.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51012, 3511, 'Felizes para Sempre: Contos para Todas as Crianças S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145336.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51013, 3511, 'Felizes para Sempre: Contos para Todas as Crianças S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145337.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51014, 3511, 'Felizes para Sempre: Contos para Todas as Crianças S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145338.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51015, 3511, 'Felizes para Sempre: Contos para Todas as Crianças S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145339.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51016, 3511, 'Felizes para Sempre: Contos para Todas as Crianças S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145340.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51017, 3511, 'Felizes para Sempre: Contos para Todas as Crianças S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145341.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51018, 3511, 'Felizes para Sempre: Contos para Todas as Crianças S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145342.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51019, 3511, 'Felizes para Sempre: Contos para Todas as Crianças S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145343.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51020, 3511, 'Felizes para Sempre: Contos para Todas as Crianças S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145344.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51021, 3512, 'Felizes para Sempre: Contos para Todas as Crianças S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145345.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51022, 3512, 'Felizes para Sempre: Contos para Todas as Crianças S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145346.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51023, 3512, 'Felizes para Sempre: Contos para Todas as Crianças S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145347.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51024, 3512, 'Felizes para Sempre: Contos para Todas as Crianças S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145348.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51025, 3512, 'Felizes para Sempre: Contos para Todas as Crianças S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145349.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51026, 3512, 'Felizes para Sempre: Contos para Todas as Crianças S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145350.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51027, 3512, 'Felizes para Sempre: Contos para Todas as Crianças S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145351.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51028, 3512, 'Felizes para Sempre: Contos para Todas as Crianças S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145352.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51029, 3512, 'Felizes para Sempre: Contos para Todas as Crianças S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145353.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51030, 3512, 'Felizes para Sempre: Contos para Todas as Crianças S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145354.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51031, 3512, 'Felizes para Sempre: Contos para Todas as Crianças S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145355.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51032, 3512, 'Felizes para Sempre: Contos para Todas as Crianças S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145356.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51033, 3512, 'Felizes para Sempre: Contos para Todas as Crianças S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145357.mp4', 'http://gstaticontent.com/images/FNAxRybck4FYMCrkCuBsbZs2at_big.jpg'),
(51034, 3513, 'Goliath S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212727.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51035, 3513, 'Goliath S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212728.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51036, 3513, 'Goliath S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212729.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51037, 3513, 'Goliath S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212730.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51038, 3513, 'Goliath S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212731.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51039, 3513, 'Goliath S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212732.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51040, 3513, 'Goliath S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212733.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51041, 3513, 'Goliath S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212734.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51042, 3514, 'Goliath S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212735.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51043, 3514, 'Goliath S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212736.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51044, 3514, 'Goliath S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212737.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51045, 3514, 'Goliath S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212738.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51046, 3514, 'Goliath S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212739.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51047, 3514, 'Goliath S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212740.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51048, 3514, 'Goliath S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212741.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51049, 3514, 'Goliath S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212742.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51050, 3515, 'Goliath S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212743.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51051, 3515, 'Goliath S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212744.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51052, 3515, 'Goliath S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212745.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51053, 3515, 'Goliath S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212746.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51054, 3515, 'Goliath S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212747.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51055, 3515, 'Goliath S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212748.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51056, 3515, 'Goliath S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212749.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51057, 3515, 'Goliath S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212750.mp4', 'http://gstaticontent.com/images/AmiS3gGH5ybEnmnPRNzQdsLQHD5_big.jpg'),
(51058, 3516, 'Goliath S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nSrk6UTwLyqBpZYbayV2rKmpYmY.jpg'),
(51059, 3516, 'Goliath S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aXynF21O1a1BCZO7QlbuLdvFsny.jpg'),
(51060, 3516, 'Goliath S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnskiuvWZodjhIdq8S3GApPevk9.jpg'),
(51061, 3516, 'Goliath S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yBGBG1r4sdUXOPjXw2DddGDjZvl.jpg'),
(51062, 3516, 'Goliath S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qLFL8M4kh5NZhT6WQvhmy3IPZuu.jpg'),
(51063, 3516, 'Goliath S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Ie59Y321vTrFA5Nzs72U0u1zOK.jpg'),
(51064, 3516, 'Goliath S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uaumd1mJGMclmbhwNDVO0WnVaby.jpg'),
(51065, 3516, 'Goliath S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vqXVAh3y98mhDy2Z93Zz4zs6DNs.jpg'),
(51066, 3517, 'Labirinto do Medo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145311.mp4', 'http://gstaticontent.com/images/7rK54N2syAPP7iVpDFuO3NMnqoQ_big.jpg'),
(51067, 3517, 'Labirinto do Medo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145312.mp4', 'http://gstaticontent.com/images/7rK54N2syAPP7iVpDFuO3NMnqoQ_big.jpg'),
(51068, 3517, 'Labirinto do Medo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145313.mp4', 'http://gstaticontent.com/images/7rK54N2syAPP7iVpDFuO3NMnqoQ_big.jpg'),
(51069, 3517, 'Labirinto do Medo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145314.mp4', 'http://gstaticontent.com/images/7rK54N2syAPP7iVpDFuO3NMnqoQ_big.jpg'),
(51070, 3517, 'Labirinto do Medo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145315.mp4', 'http://gstaticontent.com/images/7rK54N2syAPP7iVpDFuO3NMnqoQ_big.jpg'),
(51071, 3517, 'Labirinto do Medo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145316.mp4', 'http://gstaticontent.com/images/7rK54N2syAPP7iVpDFuO3NMnqoQ_big.jpg'),
(51072, 3517, 'Labirinto do Medo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145317.mp4', 'http://gstaticontent.com/images/7rK54N2syAPP7iVpDFuO3NMnqoQ_big.jpg'),
(51073, 3517, 'Labirinto do Medo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145318.mp4', 'http://gstaticontent.com/images/7rK54N2syAPP7iVpDFuO3NMnqoQ_big.jpg'),
(51074, 3518, 'O Método Kominsky S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145303.mp4', 'http://gstaticontent.com/images/vnK8b6bNl1koSthTGbzgMPnh7Ky_big.jpg'),
(51075, 3518, 'O Método Kominsky S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145304.mp4', 'http://gstaticontent.com/images/vnK8b6bNl1koSthTGbzgMPnh7Ky_big.jpg'),
(51076, 3518, 'O Método Kominsky S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145305.mp4', 'http://gstaticontent.com/images/vnK8b6bNl1koSthTGbzgMPnh7Ky_big.jpg'),
(51077, 3518, 'O Método Kominsky S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145306.mp4', 'http://gstaticontent.com/images/vnK8b6bNl1koSthTGbzgMPnh7Ky_big.jpg'),
(51078, 3518, 'O Método Kominsky S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145307.mp4', 'http://gstaticontent.com/images/vnK8b6bNl1koSthTGbzgMPnh7Ky_big.jpg'),
(51079, 3518, 'O Método Kominsky S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145308.mp4', 'http://gstaticontent.com/images/vnK8b6bNl1koSthTGbzgMPnh7Ky_big.jpg'),
(51080, 3518, 'O Método Kominsky S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145309.mp4', 'http://gstaticontent.com/images/vnK8b6bNl1koSthTGbzgMPnh7Ky_big.jpg'),
(51081, 3518, 'O Método Kominsky S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145310.mp4', 'http://gstaticontent.com/images/vnK8b6bNl1koSthTGbzgMPnh7Ky_big.jpg'),
(51082, 3519, 'Por Que Voce E Assim S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145297.mp4', 'http://gstaticontent.com/images/cf9db7e4f78bbdfd3ecefbdf1dcd306a.jpg'),
(51083, 3519, 'Por Que Voce E Assim S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145298.mp4', 'http://gstaticontent.com/images/cf9db7e4f78bbdfd3ecefbdf1dcd306a.jpg'),
(51084, 3519, 'Por Que Voce E Assim S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145299.mp4', 'http://gstaticontent.com/images/cf9db7e4f78bbdfd3ecefbdf1dcd306a.jpg'),
(51085, 3519, 'Por Que Voce E Assim S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145300.mp4', 'http://gstaticontent.com/images/cf9db7e4f78bbdfd3ecefbdf1dcd306a.jpg'),
(51086, 3519, 'Por Que Voce E Assim S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145301.mp4', 'http://gstaticontent.com/images/cf9db7e4f78bbdfd3ecefbdf1dcd306a.jpg'),
(51087, 3519, 'Por Que Voce E Assim S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145302.mp4', 'http://gstaticontent.com/images/cf9db7e4f78bbdfd3ecefbdf1dcd306a.jpg'),
(51088, 3520, 'Rebel [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146589.mp4', 'http://gstaticontent.com/images/hyHAr6lk3EW2krnUp5RFkK6ouwB_big.jpg'),
(51089, 3520, 'Rebel [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146590.mp4', 'http://gstaticontent.com/images/hyHAr6lk3EW2krnUp5RFkK6ouwB_big.jpg'),
(51090, 3520, 'Rebel [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146591.mp4', 'http://gstaticontent.com/images/hyHAr6lk3EW2krnUp5RFkK6ouwB_big.jpg'),
(51091, 3520, 'Rebel [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146592.mp4', 'http://gstaticontent.com/images/hyHAr6lk3EW2krnUp5RFkK6ouwB_big.jpg'),
(51092, 3520, 'Rebel [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146593.mp4', 'http://gstaticontent.com/images/hyHAr6lk3EW2krnUp5RFkK6ouwB_big.jpg'),
(51093, 3520, 'Rebel [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146594.mp4', 'http://gstaticontent.com/images/hyHAr6lk3EW2krnUp5RFkK6ouwB_big.jpg'),
(51094, 3520, 'Rebel [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146595.mp4', 'http://gstaticontent.com/images/hyHAr6lk3EW2krnUp5RFkK6ouwB_big.jpg'),
(51095, 3520, 'Rebel [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146596.mp4', 'http://gstaticontent.com/images/hyHAr6lk3EW2krnUp5RFkK6ouwB_big.jpg'),
(51096, 3520, 'Rebel [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146597.mp4', 'http://gstaticontent.com/images/hyHAr6lk3EW2krnUp5RFkK6ouwB_big.jpg'),
(51097, 3520, 'Rebel [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146598.mp4', 'http://gstaticontent.com/images/hyHAr6lk3EW2krnUp5RFkK6ouwB_big.jpg'),
(51098, 799, 'O Pacífico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144959.mp4', 'http://gstaticontent.com/images/f9um5c8iIvw0JOzkvwfLNB6MOW6_big.jpg'),
(51099, 799, 'O Pacífico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144960.mp4', 'http://gstaticontent.com/images/f9um5c8iIvw0JOzkvwfLNB6MOW6_big.jpg'),
(51100, 799, 'O Pacífico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144961.mp4', 'http://gstaticontent.com/images/f9um5c8iIvw0JOzkvwfLNB6MOW6_big.jpg'),
(51101, 799, 'O Pacífico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144962.mp4', 'http://gstaticontent.com/images/f9um5c8iIvw0JOzkvwfLNB6MOW6_big.jpg'),
(51102, 799, 'O Pacífico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144963.mp4', 'http://gstaticontent.com/images/f9um5c8iIvw0JOzkvwfLNB6MOW6_big.jpg'),
(51103, 799, 'O Pacífico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144964.mp4', 'http://gstaticontent.com/images/f9um5c8iIvw0JOzkvwfLNB6MOW6_big.jpg'),
(51104, 799, 'O Pacífico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144965.mp4', 'http://gstaticontent.com/images/f9um5c8iIvw0JOzkvwfLNB6MOW6_big.jpg'),
(51105, 799, 'O Pacífico S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144966.mp4', 'http://gstaticontent.com/images/f9um5c8iIvw0JOzkvwfLNB6MOW6_big.jpg'),
(51106, 799, 'O Pacífico S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144967.mp4', 'http://gstaticontent.com/images/f9um5c8iIvw0JOzkvwfLNB6MOW6_big.jpg'),
(51107, 799, 'O Pacífico S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144968.mp4', 'http://gstaticontent.com/images/f9um5c8iIvw0JOzkvwfLNB6MOW6_big.jpg'),
(51108, 3521, 'Favela Gay: Periferias LGBTQI+ S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144949.mp4', 'https://i.bj-share.info/4e233025ae0ef572d5859b5201cebb77.jpg'),
(51109, 3521, 'Favela Gay: Periferias LGBTQI+ S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144950.mp4', 'https://i.bj-share.info/4e233025ae0ef572d5859b5201cebb77.jpg'),
(51110, 3521, 'Favela Gay: Periferias LGBTQI+ S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144951.mp4', 'https://i.bj-share.info/4e233025ae0ef572d5859b5201cebb77.jpg'),
(51111, 3521, 'Favela Gay: Periferias LGBTQI+ S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144952.mp4', 'https://i.bj-share.info/4e233025ae0ef572d5859b5201cebb77.jpg'),
(51112, 3521, 'Favela Gay: Periferias LGBTQI+ S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144953.mp4', 'https://i.bj-share.info/4e233025ae0ef572d5859b5201cebb77.jpg'),
(51113, 3521, 'Favela Gay: Periferias LGBTQI+ S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144954.mp4', 'https://i.bj-share.info/4e233025ae0ef572d5859b5201cebb77.jpg'),
(51114, 3521, 'Favela Gay: Periferias LGBTQI+ S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144955.mp4', 'https://i.bj-share.info/4e233025ae0ef572d5859b5201cebb77.jpg'),
(51115, 3521, 'Favela Gay: Periferias LGBTQI+ S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144956.mp4', 'https://i.bj-share.info/4e233025ae0ef572d5859b5201cebb77.jpg'),
(51116, 3521, 'Favela Gay: Periferias LGBTQI+ S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144957.mp4', 'https://i.bj-share.info/4e233025ae0ef572d5859b5201cebb77.jpg'),
(51117, 3521, 'Favela Gay: Periferias LGBTQI+ S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144958.mp4', 'https://i.bj-share.info/4e233025ae0ef572d5859b5201cebb77.jpg'),
(51118, 3522, 'Law School [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147524.mp4', 'http://gstaticontent.com/images/epxYmFG584Bqyy0gkV9Y0cNh6Wh_big.jpg'),
(51119, 3522, 'Law School [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147525.mp4', 'http://gstaticontent.com/images/epxYmFG584Bqyy0gkV9Y0cNh6Wh_big.jpg'),
(51120, 3522, 'Law School [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147526.mp4', 'http://gstaticontent.com/images/epxYmFG584Bqyy0gkV9Y0cNh6Wh_big.jpg'),
(51121, 3522, 'Law School [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147527.mp4', 'http://gstaticontent.com/images/epxYmFG584Bqyy0gkV9Y0cNh6Wh_big.jpg'),
(51122, 3522, 'Law School [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147528.mp4', 'http://gstaticontent.com/images/epxYmFG584Bqyy0gkV9Y0cNh6Wh_big.jpg'),
(51123, 3522, 'Law School [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147529.mp4', 'http://gstaticontent.com/images/epxYmFG584Bqyy0gkV9Y0cNh6Wh_big.jpg'),
(51124, 3522, 'Law School [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147530.mp4', 'http://gstaticontent.com/images/epxYmFG584Bqyy0gkV9Y0cNh6Wh_big.jpg'),
(51125, 3522, 'Law School [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147531.mp4', 'http://gstaticontent.com/images/epxYmFG584Bqyy0gkV9Y0cNh6Wh_big.jpg'),
(51126, 3522, 'Law School [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147532.mp4', 'http://gstaticontent.com/images/epxYmFG584Bqyy0gkV9Y0cNh6Wh_big.jpg'),
(51127, 3522, 'Law School [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147533.mp4', 'http://gstaticontent.com/images/epxYmFG584Bqyy0gkV9Y0cNh6Wh_big.jpg'),
(51128, 3522, 'Law School [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147534.mp4', 'http://gstaticontent.com/images/epxYmFG584Bqyy0gkV9Y0cNh6Wh_big.jpg'),
(51129, 3522, 'Law School [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147535.mp4', 'http://gstaticontent.com/images/epxYmFG584Bqyy0gkV9Y0cNh6Wh_big.jpg'),
(51130, 3522, 'Law School [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147536.mp4', 'http://gstaticontent.com/images/epxYmFG584Bqyy0gkV9Y0cNh6Wh_big.jpg'),
(51131, 3522, 'Law School [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147537.mp4', 'http://gstaticontent.com/images/epxYmFG584Bqyy0gkV9Y0cNh6Wh_big.jpg'),
(51132, 3522, 'Law School [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147538.mp4', 'http://gstaticontent.com/images/epxYmFG584Bqyy0gkV9Y0cNh6Wh_big.jpg'),
(51133, 3522, 'Law School [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147539.mp4', 'http://gstaticontent.com/images/epxYmFG584Bqyy0gkV9Y0cNh6Wh_big.jpg'),
(51134, 3523, 'Young Rock [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142186.mp4', 'http://gstaticontent.com/images/hUmSMg5KHJkgeOk9AvbTINYOuEf_big.jpg'),
(51135, 3523, 'Young Rock [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142187.mp4', 'http://gstaticontent.com/images/hUmSMg5KHJkgeOk9AvbTINYOuEf_big.jpg'),
(51136, 3523, 'Young Rock [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142188.mp4', 'http://gstaticontent.com/images/hUmSMg5KHJkgeOk9AvbTINYOuEf_big.jpg'),
(51137, 3523, 'Young Rock [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142189.mp4', 'http://gstaticontent.com/images/hUmSMg5KHJkgeOk9AvbTINYOuEf_big.jpg'),
(51138, 3523, 'Young Rock [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142190.mp4', 'http://gstaticontent.com/images/hUmSMg5KHJkgeOk9AvbTINYOuEf_big.jpg'),
(51139, 3523, 'Young Rock [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142191.mp4', 'http://gstaticontent.com/images/hUmSMg5KHJkgeOk9AvbTINYOuEf_big.jpg'),
(51140, 3523, 'Young Rock [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142192.mp4', 'http://gstaticontent.com/images/hUmSMg5KHJkgeOk9AvbTINYOuEf_big.jpg'),
(51141, 3523, 'Young Rock [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142193.mp4', 'http://gstaticontent.com/images/hUmSMg5KHJkgeOk9AvbTINYOuEf_big.jpg'),
(51142, 3523, 'Young Rock [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142194.mp4', 'http://gstaticontent.com/images/hUmSMg5KHJkgeOk9AvbTINYOuEf_big.jpg'),
(51143, 3523, 'Young Rock [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142195.mp4', 'http://gstaticontent.com/images/hUmSMg5KHJkgeOk9AvbTINYOuEf_big.jpg'),
(51144, 3523, 'Young Rock [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142196.mp4', 'http://gstaticontent.com/images/hUmSMg5KHJkgeOk9AvbTINYOuEf_big.jpg'),
(51145, 3524, 'NeXt S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144939.mp4', 'http://gstaticontent.com/images/u9bJd2cx2I3xfJqHKVVSAOCmdyL_big.jpg'),
(51146, 3524, 'NeXt S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144940.mp4', 'http://gstaticontent.com/images/u9bJd2cx2I3xfJqHKVVSAOCmdyL_big.jpg'),
(51147, 3524, 'NeXt S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144941.mp4', 'http://gstaticontent.com/images/u9bJd2cx2I3xfJqHKVVSAOCmdyL_big.jpg'),
(51148, 3524, 'NeXt S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144942.mp4', 'http://gstaticontent.com/images/u9bJd2cx2I3xfJqHKVVSAOCmdyL_big.jpg'),
(51149, 3524, 'NeXt S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144943.mp4', 'http://gstaticontent.com/images/u9bJd2cx2I3xfJqHKVVSAOCmdyL_big.jpg'),
(51150, 3524, 'NeXt S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144944.mp4', 'http://gstaticontent.com/images/u9bJd2cx2I3xfJqHKVVSAOCmdyL_big.jpg'),
(51151, 3524, 'NeXt S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144945.mp4', 'http://gstaticontent.com/images/u9bJd2cx2I3xfJqHKVVSAOCmdyL_big.jpg'),
(51152, 3524, 'NeXt S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144946.mp4', 'http://gstaticontent.com/images/u9bJd2cx2I3xfJqHKVVSAOCmdyL_big.jpg'),
(51153, 3524, 'NeXt S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144947.mp4', 'http://gstaticontent.com/images/u9bJd2cx2I3xfJqHKVVSAOCmdyL_big.jpg'),
(51154, 3524, 'NeXt S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144948.mp4', 'http://gstaticontent.com/images/u9bJd2cx2I3xfJqHKVVSAOCmdyL_big.jpg'),
(51155, 3525, 'A Vida em Cores com David Attenborough S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144881.mp4', 'http://gstaticontent.com/images/v9j9FnYk6qHsdSLCoeD9dnkR6R0_big.jpg'),
(51156, 3525, 'A Vida em Cores com David Attenborough S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144882.mp4', 'http://gstaticontent.com/images/v9j9FnYk6qHsdSLCoeD9dnkR6R0_big.jpg'),
(51157, 3525, 'A Vida em Cores com David Attenborough S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144883.mp4', 'http://gstaticontent.com/images/v9j9FnYk6qHsdSLCoeD9dnkR6R0_big.jpg'),
(51158, 3526, 'Call DiCaprio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144884.mp4', 'http://gstaticontent.com/images/sLqNqAt9sLg3llcJ5YitKZDLlix_big.jpg'),
(51159, 3527, 'Grachi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144689.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51160, 3527, 'Grachi S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144690.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51161, 3527, 'Grachi S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144691.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51162, 3527, 'Grachi S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144692.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51163, 3527, 'Grachi S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144693.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51164, 3527, 'Grachi S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144694.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51165, 3527, 'Grachi S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144695.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51166, 3527, 'Grachi S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144696.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51167, 3527, 'Grachi S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144697.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51168, 3527, 'Grachi S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144698.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51169, 3527, 'Grachi S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144699.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51170, 3527, 'Grachi S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144700.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51171, 3527, 'Grachi S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144701.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51172, 3527, 'Grachi S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144702.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51173, 3527, 'Grachi S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144703.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51174, 3527, 'Grachi S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144704.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51175, 3527, 'Grachi S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144705.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51176, 3527, 'Grachi S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/144706.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51177, 3527, 'Grachi S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/144707.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51178, 3527, 'Grachi S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144708.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51179, 3527, 'Grachi S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/144709.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51180, 3527, 'Grachi S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/144710.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51181, 3527, 'Grachi S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/144711.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51182, 3527, 'Grachi S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/144712.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51183, 3527, 'Grachi S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/144713.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51184, 3527, 'Grachi S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/144714.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51185, 3527, 'Grachi S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/144715.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51186, 3527, 'Grachi S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/144716.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51187, 3527, 'Grachi S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/144717.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51188, 3527, 'Grachi S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/144718.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51189, 3527, 'Grachi S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/144719.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51190, 3527, 'Grachi S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/144720.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51191, 3527, 'Grachi S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/144721.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51192, 3527, 'Grachi S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/144722.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51193, 3527, 'Grachi S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/144723.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51194, 3527, 'Grachi S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/144724.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51195, 3527, 'Grachi S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/144725.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51196, 3527, 'Grachi S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/144726.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51197, 3527, 'Grachi S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/144727.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51198, 3527, 'Grachi S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/144728.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51199, 3527, 'Grachi S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/144729.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51200, 3527, 'Grachi S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/144730.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51201, 3527, 'Grachi S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/144731.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51202, 3527, 'Grachi S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/144732.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51203, 3527, 'Grachi S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/144733.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51204, 3527, 'Grachi S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/144734.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51205, 3527, 'Grachi S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/144735.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51206, 3527, 'Grachi S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/144736.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51207, 3527, 'Grachi S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/144737.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51208, 3527, 'Grachi S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/144738.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51209, 3527, 'Grachi S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/144739.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51210, 3527, 'Grachi S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/144740.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51211, 3527, 'Grachi S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/144741.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51212, 3527, 'Grachi S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/144742.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51213, 3527, 'Grachi S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/144743.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51214, 3527, 'Grachi S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/144744.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51215, 3527, 'Grachi S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/144745.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51216, 3527, 'Grachi S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/144746.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51217, 3527, 'Grachi S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/144747.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51218, 3527, 'Grachi S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/144748.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51219, 3527, 'Grachi S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/144749.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51220, 3527, 'Grachi S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/144750.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51221, 3527, 'Grachi S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/144751.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51222, 3527, 'Grachi S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/144752.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51223, 3527, 'Grachi S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/144753.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51224, 3527, 'Grachi S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/144754.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51225, 3527, 'Grachi S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/144755.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51226, 3527, 'Grachi S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/144756.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51227, 3527, 'Grachi S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/144757.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51228, 3527, 'Grachi S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/144758.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51229, 3527, 'Grachi S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/144759.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51230, 3527, 'Grachi S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/144760.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51231, 3527, 'Grachi S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/144761.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51232, 3527, 'Grachi S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/144762.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51233, 3527, 'Grachi S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/144763.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51234, 3528, 'Grachi S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144764.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51235, 3528, 'Grachi S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144765.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51236, 3528, 'Grachi S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144766.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51237, 3528, 'Grachi S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144767.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51238, 3528, 'Grachi S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144768.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51239, 3528, 'Grachi S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144769.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51240, 3528, 'Grachi S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144770.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51241, 3528, 'Grachi S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144771.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51242, 3528, 'Grachi S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144772.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51243, 3528, 'Grachi S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144773.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51244, 3528, 'Grachi S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144774.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51245, 3528, 'Grachi S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144775.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51246, 3528, 'Grachi S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144776.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51247, 3528, 'Grachi S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144777.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51248, 3528, 'Grachi S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144778.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51249, 3528, 'Grachi S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144779.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51250, 3528, 'Grachi S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144780.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51251, 3528, 'Grachi S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/144781.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51252, 3528, 'Grachi S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/144782.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51253, 3528, 'Grachi S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144783.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51254, 3528, 'Grachi S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/144784.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51255, 3528, 'Grachi S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/144785.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51256, 3528, 'Grachi S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/144786.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51257, 3528, 'Grachi S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/144787.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51258, 3528, 'Grachi S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/144788.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51259, 3528, 'Grachi S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/144789.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51260, 3528, 'Grachi S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/144790.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51261, 3528, 'Grachi S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/144791.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51262, 3528, 'Grachi S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/144792.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51263, 3528, 'Grachi S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/144793.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51264, 3528, 'Grachi S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/144794.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51265, 3528, 'Grachi S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/144795.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51266, 3528, 'Grachi S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/144796.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51267, 3528, 'Grachi S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/144797.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51268, 3528, 'Grachi S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/144798.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51269, 3528, 'Grachi S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/144799.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51270, 3528, 'Grachi S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/144800.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51271, 3528, 'Grachi S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/144801.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51272, 3528, 'Grachi S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/144802.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51273, 3528, 'Grachi S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/144803.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51274, 3528, 'Grachi S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/144804.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51275, 3528, 'Grachi S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/144805.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51276, 3528, 'Grachi S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/144806.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51277, 3528, 'Grachi S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/144807.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51278, 3528, 'Grachi S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/144808.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51279, 3528, 'Grachi S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/144809.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51280, 3528, 'Grachi S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/144810.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51281, 3528, 'Grachi S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/144811.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51282, 3528, 'Grachi S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/144812.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51283, 3528, 'Grachi S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/144813.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51284, 3528, 'Grachi S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/144814.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51285, 3528, 'Grachi S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/144815.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51286, 3528, 'Grachi S02 E53', 'http://sinalprivado.info:80/series/1533784/1533784/144816.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51287, 3528, 'Grachi S02 E54', 'http://sinalprivado.info:80/series/1533784/1533784/144817.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51288, 3528, 'Grachi S02 E55', 'http://sinalprivado.info:80/series/1533784/1533784/144818.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51289, 3528, 'Grachi S02 E56', 'http://sinalprivado.info:80/series/1533784/1533784/144819.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51290, 3528, 'Grachi S02 E57', 'http://sinalprivado.info:80/series/1533784/1533784/144820.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51291, 3528, 'Grachi S02 E58', 'http://sinalprivado.info:80/series/1533784/1533784/144821.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51292, 3528, 'Grachi S02 E59', 'http://sinalprivado.info:80/series/1533784/1533784/144822.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51293, 3528, 'Grachi S02 E60', 'http://sinalprivado.info:80/series/1533784/1533784/144823.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51294, 3528, 'Grachi S02 E61', 'http://sinalprivado.info:80/series/1533784/1533784/144824.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51295, 3528, 'Grachi S02 E62', 'http://sinalprivado.info:80/series/1533784/1533784/144825.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51296, 3528, 'Grachi S02 E63', 'http://sinalprivado.info:80/series/1533784/1533784/144826.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(51297, 3528, 'Grachi S02 E64', 'http://sinalprivado.info:80/series/1533784/1533784/144827.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51298, 3528, 'Grachi S02 E65', 'http://sinalprivado.info:80/series/1533784/1533784/144828.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51299, 3528, 'Grachi S02 E66', 'http://sinalprivado.info:80/series/1533784/1533784/144829.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51300, 3528, 'Grachi S02 E67', 'http://sinalprivado.info:80/series/1533784/1533784/144830.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51301, 3528, 'Grachi S02 E68', 'http://sinalprivado.info:80/series/1533784/1533784/144831.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51302, 3528, 'Grachi S02 E69', 'http://sinalprivado.info:80/series/1533784/1533784/144832.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51303, 3528, 'Grachi S02 E70', 'http://sinalprivado.info:80/series/1533784/1533784/144833.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51304, 3528, 'Grachi S02 E71', 'http://sinalprivado.info:80/series/1533784/1533784/144834.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51305, 3528, 'Grachi S02 E72', 'http://sinalprivado.info:80/series/1533784/1533784/144835.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51306, 3528, 'Grachi S02 E73', 'http://sinalprivado.info:80/series/1533784/1533784/144836.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51307, 3528, 'Grachi S02 E74', 'http://sinalprivado.info:80/series/1533784/1533784/144837.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51308, 3528, 'Grachi S02 E75', 'http://sinalprivado.info:80/series/1533784/1533784/144838.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51309, 3528, 'Grachi S02 E76', 'http://sinalprivado.info:80/series/1533784/1533784/144839.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51310, 3528, 'Grachi S02 E77', 'http://sinalprivado.info:80/series/1533784/1533784/144840.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51311, 3528, 'Grachi S02 E78', 'http://sinalprivado.info:80/series/1533784/1533784/144841.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51312, 3528, 'Grachi S02 E79', 'http://sinalprivado.info:80/series/1533784/1533784/144842.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51313, 3528, 'Grachi S02 E80', 'http://sinalprivado.info:80/series/1533784/1533784/144843.mp4', 'http://gstaticontent.com/images/rccg23g7tjIHGYkdRckaHmUQEmX_big.jpg'),
(51314, 3529, 'O Golpe do Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144885.mp4', 'http://gstaticontent.com/images/rA1aAgvhHFREN52pI0BQmQHQZaA_big.jpg'),
(51315, 3529, 'O Golpe do Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144886.mp4', 'http://gstaticontent.com/images/rA1aAgvhHFREN52pI0BQmQHQZaA_big.jpg'),
(51316, 3529, 'O Golpe do Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144887.mp4', 'http://gstaticontent.com/images/rA1aAgvhHFREN52pI0BQmQHQZaA_big.jpg'),
(51317, 3529, 'O Golpe do Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144888.mp4', 'http://gstaticontent.com/images/rA1aAgvhHFREN52pI0BQmQHQZaA_big.jpg'),
(51318, 3529, 'O Golpe do Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144889.mp4', 'http://gstaticontent.com/images/rA1aAgvhHFREN52pI0BQmQHQZaA_big.jpg'),
(51319, 3529, 'O Golpe do Amor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144890.mp4', 'http://gstaticontent.com/images/rA1aAgvhHFREN52pI0BQmQHQZaA_big.jpg'),
(51320, 3530, 'O Mundo de Beakman S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144891.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51321, 3530, 'O Mundo de Beakman S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144892.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51322, 3530, 'O Mundo de Beakman S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144893.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51323, 3530, 'O Mundo de Beakman S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144894.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51324, 3530, 'O Mundo de Beakman S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144895.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51325, 3530, 'O Mundo de Beakman S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144896.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51326, 3530, 'O Mundo de Beakman S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144897.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51327, 3530, 'O Mundo de Beakman S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144898.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51328, 3530, 'O Mundo de Beakman S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144899.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51329, 3530, 'O Mundo de Beakman S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144900.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51330, 3530, 'O Mundo de Beakman S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144901.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51331, 3530, 'O Mundo de Beakman S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144902.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51332, 3530, 'O Mundo de Beakman S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144903.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51333, 3530, 'O Mundo de Beakman S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144904.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51334, 3530, 'O Mundo de Beakman S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144905.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51335, 3530, 'O Mundo de Beakman S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144906.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51336, 3530, 'O Mundo de Beakman S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/144907.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51337, 3530, 'O Mundo de Beakman S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/144908.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51338, 3530, 'O Mundo de Beakman S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/144909.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51339, 3530, 'O Mundo de Beakman S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/144910.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51340, 3530, 'O Mundo de Beakman S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/144911.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51341, 3530, 'O Mundo de Beakman S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/144912.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51342, 3530, 'O Mundo de Beakman S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/144913.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51343, 3530, 'O Mundo de Beakman S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/144914.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51344, 3530, 'O Mundo de Beakman S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/144915.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51345, 3530, 'O Mundo de Beakman S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/144916.mp4', 'http://gstaticontent.com/images/x6wXEkbyhwh98kFWPtfjn5EdVHu_big.jpg'),
(51346, 3531, 'Topi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144917.mp4', 'http://gstaticontent.com/images/7N5D6ustyMteA9Oeh0O5Ouy9kYN_big.jpg'),
(51347, 3532, 'Um Anjo dos Infernos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144918.mp4', 'http://gstaticontent.com/images/wDisTsrsZwGAnFZcQtXUsaRNFYU_big.jpg'),
(51348, 3532, 'Um Anjo dos Infernos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144919.mp4', 'http://gstaticontent.com/images/wDisTsrsZwGAnFZcQtXUsaRNFYU_big.jpg'),
(51349, 3532, 'Um Anjo dos Infernos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144920.mp4', 'http://gstaticontent.com/images/wDisTsrsZwGAnFZcQtXUsaRNFYU_big.jpg'),
(51350, 3532, 'Um Anjo dos Infernos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144921.mp4', 'http://gstaticontent.com/images/wDisTsrsZwGAnFZcQtXUsaRNFYU_big.jpg'),
(51351, 3532, 'Um Anjo dos Infernos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144922.mp4', 'http://gstaticontent.com/images/wDisTsrsZwGAnFZcQtXUsaRNFYU_big.jpg'),
(51352, 3532, 'Um Anjo dos Infernos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144923.mp4', 'http://gstaticontent.com/images/wDisTsrsZwGAnFZcQtXUsaRNFYU_big.jpg'),
(51353, 3532, 'Um Anjo dos Infernos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144924.mp4', 'http://gstaticontent.com/images/wDisTsrsZwGAnFZcQtXUsaRNFYU_big.jpg'),
(51354, 3532, 'Um Anjo dos Infernos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144925.mp4', 'http://gstaticontent.com/images/wDisTsrsZwGAnFZcQtXUsaRNFYU_big.jpg'),
(51355, 3532, 'Um Anjo dos Infernos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144926.mp4', 'http://gstaticontent.com/images/wDisTsrsZwGAnFZcQtXUsaRNFYU_big.jpg'),
(51356, 3532, 'Um Anjo dos Infernos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144927.mp4', 'http://gstaticontent.com/images/wDisTsrsZwGAnFZcQtXUsaRNFYU_big.jpg'),
(51357, 3532, 'Um Anjo dos Infernos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144928.mp4', 'http://gstaticontent.com/images/wDisTsrsZwGAnFZcQtXUsaRNFYU_big.jpg'),
(51358, 3532, 'Um Anjo dos Infernos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144929.mp4', 'http://gstaticontent.com/images/wDisTsrsZwGAnFZcQtXUsaRNFYU_big.jpg'),
(51359, 3532, 'Um Anjo dos Infernos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144930.mp4', 'http://gstaticontent.com/images/wDisTsrsZwGAnFZcQtXUsaRNFYU_big.jpg'),
(51360, 3533, 'Zero S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144931.mp4', 'http://gstaticontent.com/images/wuSYYEDo4qZCWXZT0eKFO2vjERp_big.jpg'),
(51361, 3533, 'Zero S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144932.mp4', 'http://gstaticontent.com/images/wuSYYEDo4qZCWXZT0eKFO2vjERp_big.jpg'),
(51362, 3533, 'Zero S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144933.mp4', 'http://gstaticontent.com/images/wuSYYEDo4qZCWXZT0eKFO2vjERp_big.jpg'),
(51363, 3533, 'Zero S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144934.mp4', 'http://gstaticontent.com/images/wuSYYEDo4qZCWXZT0eKFO2vjERp_big.jpg'),
(51364, 3533, 'Zero S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144935.mp4', 'http://gstaticontent.com/images/wuSYYEDo4qZCWXZT0eKFO2vjERp_big.jpg'),
(51365, 3533, 'Zero S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144936.mp4', 'http://gstaticontent.com/images/wuSYYEDo4qZCWXZT0eKFO2vjERp_big.jpg'),
(51366, 3533, 'Zero S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144937.mp4', 'http://gstaticontent.com/images/wuSYYEDo4qZCWXZT0eKFO2vjERp_big.jpg'),
(51367, 3533, 'Zero S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144938.mp4', 'http://gstaticontent.com/images/wuSYYEDo4qZCWXZT0eKFO2vjERp_big.jpg'),
(51368, 3534, 'Chosen S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144844.mp4', 'http://gstaticontent.com/images/4tLOlMF7YMwsnm4qkhnkOEArZfB_big.jpg'),
(51369, 3534, 'Chosen S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144845.mp4', 'http://gstaticontent.com/images/4tLOlMF7YMwsnm4qkhnkOEArZfB_big.jpg'),
(51370, 3534, 'Chosen S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144846.mp4', 'http://gstaticontent.com/images/4tLOlMF7YMwsnm4qkhnkOEArZfB_big.jpg'),
(51371, 3534, 'Chosen S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144847.mp4', 'http://gstaticontent.com/images/4tLOlMF7YMwsnm4qkhnkOEArZfB_big.jpg'),
(51372, 3534, 'Chosen S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144848.mp4', 'http://gstaticontent.com/images/4tLOlMF7YMwsnm4qkhnkOEArZfB_big.jpg'),
(51373, 3534, 'Chosen S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144849.mp4', 'http://gstaticontent.com/images/4tLOlMF7YMwsnm4qkhnkOEArZfB_big.jpg'),
(51374, 3535, 'Chosen S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144850.mp4', 'http://gstaticontent.com/images/4tLOlMF7YMwsnm4qkhnkOEArZfB_big.jpg'),
(51375, 3535, 'Chosen S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144851.mp4', 'http://gstaticontent.com/images/4tLOlMF7YMwsnm4qkhnkOEArZfB_big.jpg'),
(51376, 3535, 'Chosen S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144852.mp4', 'http://gstaticontent.com/images/4tLOlMF7YMwsnm4qkhnkOEArZfB_big.jpg'),
(51377, 3535, 'Chosen S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144853.mp4', 'http://gstaticontent.com/images/4tLOlMF7YMwsnm4qkhnkOEArZfB_big.jpg'),
(51378, 3535, 'Chosen S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144854.mp4', 'http://gstaticontent.com/images/4tLOlMF7YMwsnm4qkhnkOEArZfB_big.jpg'),
(51379, 3535, 'Chosen S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144855.mp4', 'http://gstaticontent.com/images/4tLOlMF7YMwsnm4qkhnkOEArZfB_big.jpg'),
(51380, 3536, 'Chosen S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144856.mp4', 'http://gstaticontent.com/images/4tLOlMF7YMwsnm4qkhnkOEArZfB_big.jpg'),
(51381, 3536, 'Chosen S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144857.mp4', 'http://gstaticontent.com/images/4tLOlMF7YMwsnm4qkhnkOEArZfB_big.jpg'),
(51382, 3536, 'Chosen S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144858.mp4', 'http://gstaticontent.com/images/4tLOlMF7YMwsnm4qkhnkOEArZfB_big.jpg'),
(51383, 3536, 'Chosen S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144859.mp4', 'http://gstaticontent.com/images/4tLOlMF7YMwsnm4qkhnkOEArZfB_big.jpg'),
(51384, 3536, 'Chosen S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144860.mp4', 'http://gstaticontent.com/images/4tLOlMF7YMwsnm4qkhnkOEArZfB_big.jpg'),
(51385, 3536, 'Chosen S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144861.mp4', 'http://gstaticontent.com/images/4tLOlMF7YMwsnm4qkhnkOEArZfB_big.jpg'),
(51386, 3537, 'Crossbones [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144862.mp4', 'http://gstaticontent.com/images/l1FvNiEC61VvuNPkaKMseDXnDGc_big.jpg'),
(51387, 3537, 'Crossbones [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144863.mp4', 'http://gstaticontent.com/images/l1FvNiEC61VvuNPkaKMseDXnDGc_big.jpg'),
(51388, 3537, 'Crossbones [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144864.mp4', 'http://gstaticontent.com/images/l1FvNiEC61VvuNPkaKMseDXnDGc_big.jpg'),
(51389, 3537, 'Crossbones [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144865.mp4', 'http://gstaticontent.com/images/l1FvNiEC61VvuNPkaKMseDXnDGc_big.jpg'),
(51390, 3537, 'Crossbones [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144866.mp4', 'http://gstaticontent.com/images/l1FvNiEC61VvuNPkaKMseDXnDGc_big.jpg'),
(51391, 3537, 'Crossbones [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144867.mp4', 'http://gstaticontent.com/images/l1FvNiEC61VvuNPkaKMseDXnDGc_big.jpg'),
(51392, 3537, 'Crossbones [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144868.mp4', 'http://gstaticontent.com/images/l1FvNiEC61VvuNPkaKMseDXnDGc_big.jpg'),
(51393, 3537, 'Crossbones [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144869.mp4', 'http://gstaticontent.com/images/l1FvNiEC61VvuNPkaKMseDXnDGc_big.jpg'),
(51394, 3537, 'Crossbones [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144870.mp4', 'http://gstaticontent.com/images/l1FvNiEC61VvuNPkaKMseDXnDGc_big.jpg'),
(51395, 3538, 'Mare of Easttown S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147753.mp4', 'http://gstaticontent.com/images/4oVWbd2NKglFG9UO46VhW4v6nFD_big.jpg'),
(51396, 3538, 'Mare of Easttown S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147754.mp4', 'http://gstaticontent.com/images/4oVWbd2NKglFG9UO46VhW4v6nFD_big.jpg'),
(51397, 3538, 'Mare of Easttown S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147755.mp4', 'http://gstaticontent.com/images/4oVWbd2NKglFG9UO46VhW4v6nFD_big.jpg'),
(51398, 3538, 'Mare of Easttown S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147756.mp4', 'http://gstaticontent.com/images/4oVWbd2NKglFG9UO46VhW4v6nFD_big.jpg'),
(51399, 3538, 'Mare of Easttown S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147757.mp4', 'http://gstaticontent.com/images/4oVWbd2NKglFG9UO46VhW4v6nFD_big.jpg'),
(51400, 3538, 'Mare of Easttown S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147758.mp4', 'http://gstaticontent.com/images/4oVWbd2NKglFG9UO46VhW4v6nFD_big.jpg'),
(51401, 3538, 'Mare of Easttown S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147759.mp4', 'http://gstaticontent.com/images/4oVWbd2NKglFG9UO46VhW4v6nFD_big.jpg'),
(51402, 3539, 'O Segredo das Baleias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144871.mp4', 'http://gstaticontent.com/images/cX8AuzY7xhWnFAROk28FuwVicJr_big.jpg'),
(51403, 3539, 'O Segredo das Baleias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144872.mp4', 'http://gstaticontent.com/images/cX8AuzY7xhWnFAROk28FuwVicJr_big.jpg'),
(51404, 3539, 'O Segredo das Baleias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144873.mp4', 'http://gstaticontent.com/images/cX8AuzY7xhWnFAROk28FuwVicJr_big.jpg'),
(51405, 3539, 'O Segredo das Baleias S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144874.mp4', 'http://gstaticontent.com/images/cX8AuzY7xhWnFAROk28FuwVicJr_big.jpg'),
(51406, 3540, 'Sombra e Ossos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209422.mp4', 'http://gstaticontent.com/images/vzKboKry7jmH17GgHnexcWX9HiQ_big.jpg'),
(51407, 3540, 'Sombra e Ossos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209423.mp4', 'http://gstaticontent.com/images/vzKboKry7jmH17GgHnexcWX9HiQ_big.jpg'),
(51408, 3540, 'Sombra e Ossos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209424.mp4', 'http://gstaticontent.com/images/vzKboKry7jmH17GgHnexcWX9HiQ_big.jpg'),
(51409, 3540, 'Sombra e Ossos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209425.mp4', 'http://gstaticontent.com/images/vzKboKry7jmH17GgHnexcWX9HiQ_big.jpg'),
(51410, 3540, 'Sombra e Ossos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209426.mp4', 'http://gstaticontent.com/images/vzKboKry7jmH17GgHnexcWX9HiQ_big.jpg'),
(51411, 3540, 'Sombra e Ossos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209427.mp4', 'http://gstaticontent.com/images/vzKboKry7jmH17GgHnexcWX9HiQ_big.jpg'),
(51412, 3540, 'Sombra e Ossos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209428.mp4', 'http://gstaticontent.com/images/vzKboKry7jmH17GgHnexcWX9HiQ_big.jpg'),
(51413, 3540, 'Sombra e Ossos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209429.mp4', 'http://gstaticontent.com/images/vzKboKry7jmH17GgHnexcWX9HiQ_big.jpg'),
(51414, 3541, 'Sombra e Ossos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lUXwabvy32cxMZ4b0Hz7Yz36BYe.jpg'),
(51415, 3541, 'Sombra e Ossos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ipalCrt0YFknvjsLklUTnqeFolh.jpg'),
(51416, 3541, 'Sombra e Ossos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2iPlnUjPVK69uee6nXcKBhCeIM.jpg'),
(51417, 3541, 'Sombra e Ossos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ZBjA5XM68g5XtSl7PruY8lBLF9.jpg'),
(51418, 3541, 'Sombra e Ossos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fECZSvQu2gpjaDB3B0pafNyVSB8.jpg'),
(51419, 3541, 'Sombra e Ossos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5jyOp8JXlki5CC5IAF7jVCsakbp.jpg'),
(51420, 3541, 'Sombra e Ossos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7fx5pGFfImojPFDaBCwO3Dpz3Rp.jpg'),
(51421, 3541, 'Sombra e Ossos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b3iizV97RyteB2lkrt1bAYE43EQ.jpg'),
(51422, 3542, 'Headspace - Guia para Dormir Melhor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144300.mp4', 'http://gstaticontent.com/images/smMONDVSiUZswZoPPVEhbPdKlDG_big.jpg'),
(51423, 3542, 'Headspace - Guia para Dormir Melhor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144301.mp4', 'http://gstaticontent.com/images/smMONDVSiUZswZoPPVEhbPdKlDG_big.jpg'),
(51424, 3542, 'Headspace - Guia para Dormir Melhor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144302.mp4', 'http://gstaticontent.com/images/smMONDVSiUZswZoPPVEhbPdKlDG_big.jpg'),
(51425, 3542, 'Headspace - Guia para Dormir Melhor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144303.mp4', 'http://gstaticontent.com/images/smMONDVSiUZswZoPPVEhbPdKlDG_big.jpg'),
(51426, 3542, 'Headspace - Guia para Dormir Melhor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144304.mp4', 'http://gstaticontent.com/images/smMONDVSiUZswZoPPVEhbPdKlDG_big.jpg'),
(51427, 3542, 'Headspace - Guia para Dormir Melhor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144305.mp4', 'http://gstaticontent.com/images/smMONDVSiUZswZoPPVEhbPdKlDG_big.jpg'),
(51428, 3542, 'Headspace - Guia para Dormir Melhor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144306.mp4', 'http://gstaticontent.com/images/smMONDVSiUZswZoPPVEhbPdKlDG_big.jpg'),
(51429, 3543, 'A Vida Depois do Tombo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144265.mp4', 'http://gstaticontent.com/images/gB9GFXArA5xpkpMpavPVwemd6F0_big.jpg'),
(51430, 3543, 'A Vida Depois do Tombo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144266.mp4', 'http://gstaticontent.com/images/gB9GFXArA5xpkpMpavPVwemd6F0_big.jpg'),
(51431, 3543, 'A Vida Depois do Tombo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144267.mp4', 'http://gstaticontent.com/images/gB9GFXArA5xpkpMpavPVwemd6F0_big.jpg'),
(51432, 3543, 'A Vida Depois do Tombo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144268.mp4', 'http://gstaticontent.com/images/gB9GFXArA5xpkpMpavPVwemd6F0_big.jpg'),
(51433, 3544, 'Fatma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144259.mp4', 'http://gstaticontent.com/images/efAH3wdr1ZuqK0sBmBdqvAZG7PT_big.jpg'),
(51434, 3544, 'Fatma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144260.mp4', 'http://gstaticontent.com/images/efAH3wdr1ZuqK0sBmBdqvAZG7PT_big.jpg'),
(51435, 3544, 'Fatma S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144261.mp4', 'http://gstaticontent.com/images/efAH3wdr1ZuqK0sBmBdqvAZG7PT_big.jpg'),
(51436, 3544, 'Fatma S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144262.mp4', 'http://gstaticontent.com/images/efAH3wdr1ZuqK0sBmBdqvAZG7PT_big.jpg'),
(51437, 3544, 'Fatma S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144263.mp4', 'http://gstaticontent.com/images/efAH3wdr1ZuqK0sBmBdqvAZG7PT_big.jpg'),
(51438, 3544, 'Fatma S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144264.mp4', 'http://gstaticontent.com/images/efAH3wdr1ZuqK0sBmBdqvAZG7PT_big.jpg'),
(51439, 3545, 'Sexify S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205489.mp4', 'http://gstaticontent.com/images/3mIrH23ar0lr8rj4SAW4kM6nJg6_big.jpg'),
(51440, 3545, 'Sexify S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205490.mp4', 'http://gstaticontent.com/images/3mIrH23ar0lr8rj4SAW4kM6nJg6_big.jpg'),
(51441, 3545, 'Sexify S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205491.mp4', 'http://gstaticontent.com/images/3mIrH23ar0lr8rj4SAW4kM6nJg6_big.jpg'),
(51442, 3545, 'Sexify S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205492.mp4', 'http://gstaticontent.com/images/3mIrH23ar0lr8rj4SAW4kM6nJg6_big.jpg'),
(51443, 3545, 'Sexify S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205493.mp4', 'http://gstaticontent.com/images/3mIrH23ar0lr8rj4SAW4kM6nJg6_big.jpg'),
(51444, 3545, 'Sexify S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205494.mp4', 'http://gstaticontent.com/images/3mIrH23ar0lr8rj4SAW4kM6nJg6_big.jpg'),
(51445, 3545, 'Sexify S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205495.mp4', 'http://gstaticontent.com/images/3mIrH23ar0lr8rj4SAW4kM6nJg6_big.jpg'),
(51446, 3545, 'Sexify S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205496.mp4', 'http://gstaticontent.com/images/3mIrH23ar0lr8rj4SAW4kM6nJg6_big.jpg'),
(51447, 3546, 'Sexify S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bzjRxwunup8aLdS6ukQaz97rPcL.jpg'),
(51448, 3546, 'Sexify S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jD6exWjbrS1WGrm0YMH4FObjqoP.jpg'),
(51449, 3546, 'Sexify S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4pqESqPthZpDrXbpuP1I8A88cu.jpg'),
(51450, 3546, 'Sexify S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zr2w8vl7aOIP7iQ76IDjwGoRPha.jpg'),
(51451, 3546, 'Sexify S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mPl0lp9TxKUiUE0edNIj42OwDhB.jpg'),
(51452, 3546, 'Sexify S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97olxkyE05hK29QH5xWePKKCx0V.jpg'),
(51453, 3546, 'Sexify S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u0QwsbVbkgNa1yTMFhbkvl3t0SE.jpg'),
(51454, 3546, 'Sexify S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7IeU5p2gqOrLyJZ6URHxr8J8Lh1.jpg'),
(51455, 3547, 'Yasuke S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144253.mp4', 'http://gstaticontent.com/images/EyrE3HJsMArVSORCnP0ooiAd9T_big.jpg'),
(51456, 3547, 'Yasuke S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144254.mp4', 'http://gstaticontent.com/images/EyrE3HJsMArVSORCnP0ooiAd9T_big.jpg'),
(51457, 3547, 'Yasuke S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144255.mp4', 'http://gstaticontent.com/images/EyrE3HJsMArVSORCnP0ooiAd9T_big.jpg'),
(51458, 3547, 'Yasuke S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144256.mp4', 'http://gstaticontent.com/images/EyrE3HJsMArVSORCnP0ooiAd9T_big.jpg'),
(51459, 3547, 'Yasuke S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144257.mp4', 'http://gstaticontent.com/images/EyrE3HJsMArVSORCnP0ooiAd9T_big.jpg'),
(51460, 3547, 'Yasuke S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144258.mp4', 'http://gstaticontent.com/images/EyrE3HJsMArVSORCnP0ooiAd9T_big.jpg'),
(51461, 3548, 'Anota Ai S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/549227.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51462, 3548, 'Anota Ai S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/549229.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51463, 3548, 'Anota Ai S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/549231.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51464, 3548, 'Anota Ai S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/549233.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51465, 3548, 'Anota Ai S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/549235.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51466, 3548, 'Anota Ai S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/549237.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51467, 3548, 'Anota Ai S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/549239.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51468, 3548, 'Anota Ai S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/549241.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51469, 3548, 'Anota Ai S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/549243.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51470, 3548, 'Anota Ai S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/549245.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51471, 3548, 'Anota Ai S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/549247.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51472, 3548, 'Anota Ai S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/549249.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51473, 3548, 'Anota Ai S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/549251.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51474, 3548, 'Anota Ai S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/549253.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51475, 3549, 'Anota Ai S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142344.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51476, 3549, 'Anota Ai S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142345.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51477, 3549, 'Anota Ai S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142346.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51478, 3549, 'Anota Ai S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142347.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51479, 3549, 'Anota Ai S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142348.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51480, 3549, 'Anota Ai S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142349.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51481, 3549, 'Anota Ai S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142350.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51482, 3549, 'Anota Ai S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142351.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51483, 3549, 'Anota Ai S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142352.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51484, 3549, 'Anota Ai S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142353.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51485, 3549, 'Anota Ai S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142354.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51486, 3549, 'Anota Ai S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142355.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51487, 3549, 'Anota Ai S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142356.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51488, 3550, 'Anota Ai S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142357.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51489, 3550, 'Anota Ai S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142358.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51490, 3550, 'Anota Ai S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142359.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51491, 3550, 'Anota Ai S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142360.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51492, 3550, 'Anota Ai S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142361.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51493, 3550, 'Anota Ai S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142362.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51494, 3550, 'Anota Ai S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142363.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51495, 3550, 'Anota Ai S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142364.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51496, 3550, 'Anota Ai S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142365.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51497, 3550, 'Anota Ai S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142366.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51498, 3550, 'Anota Ai S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142367.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51499, 3550, 'Anota Ai S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142368.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51500, 3550, 'Anota Ai S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142369.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51501, 3551, 'Anota Ai S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142370.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51502, 3551, 'Anota Ai S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142371.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51503, 3551, 'Anota Ai S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142372.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51504, 3551, 'Anota Ai S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142373.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51505, 3551, 'Anota Ai S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142374.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51506, 3551, 'Anota Ai S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142375.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51507, 3551, 'Anota Ai S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142376.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51508, 3551, 'Anota Ai S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142377.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51509, 3551, 'Anota Ai S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142378.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51510, 3551, 'Anota Ai S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142379.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51511, 3551, 'Anota Ai S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142380.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51512, 3551, 'Anota Ai S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142381.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51513, 3551, 'Anota Ai S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142382.mp4', 'https://i.bj-share.info/973576ae3d89b2cea451f31d3c02e29e.jpg'),
(51514, 3552, 'Os 100 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143982.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51515, 3552, 'Os 100 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143983.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51516, 3552, 'Os 100 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143984.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51517, 3552, 'Os 100 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143985.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51518, 3552, 'Os 100 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143986.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51519, 3552, 'Os 100 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143987.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51520, 3552, 'Os 100 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143988.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51521, 3552, 'Os 100 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143989.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51522, 3552, 'Os 100 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143990.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51523, 3552, 'Os 100 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143991.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51524, 3552, 'Os 100 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143992.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51525, 3552, 'Os 100 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143993.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51526, 3552, 'Os 100 S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143994.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51527, 3553, 'Os 100 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143995.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51528, 3553, 'Os 100 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143996.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51529, 3553, 'Os 100 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143997.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51530, 3553, 'Os 100 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143998.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51531, 3553, 'Os 100 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143999.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51532, 3553, 'Os 100 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144000.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51533, 3553, 'Os 100 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144001.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51534, 3553, 'Os 100 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144002.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51535, 3553, 'Os 100 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144003.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51536, 3553, 'Os 100 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144004.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51537, 3553, 'Os 100 S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144005.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51538, 3553, 'Os 100 S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144006.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51539, 3553, 'Os 100 S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144007.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51540, 3553, 'Os 100 S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144008.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51541, 3553, 'Os 100 S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144009.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51542, 3553, 'Os 100 S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144010.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51543, 3554, 'Os 100 S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144011.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51544, 3554, 'Os 100 S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144012.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51545, 3554, 'Os 100 S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144013.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51546, 3554, 'Os 100 S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144014.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51547, 3554, 'Os 100 S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144015.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51548, 3554, 'Os 100 S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144016.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51549, 3554, 'Os 100 S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144017.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51550, 3554, 'Os 100 S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144018.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51551, 3554, 'Os 100 S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144019.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51552, 3554, 'Os 100 S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144020.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51553, 3554, 'Os 100 S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144021.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51554, 3554, 'Os 100 S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144022.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51555, 3554, 'Os 100 S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144023.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51556, 3554, 'Os 100 S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144024.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51557, 3554, 'Os 100 S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144025.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51558, 3554, 'Os 100 S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144026.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51559, 3555, 'Os 100 S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144027.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51560, 3555, 'Os 100 S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144028.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51561, 3555, 'Os 100 S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144029.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51562, 3555, 'Os 100 S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144030.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51563, 3555, 'Os 100 S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144031.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51564, 3555, 'Os 100 S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144032.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51565, 3555, 'Os 100 S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144033.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51566, 3555, 'Os 100 S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144034.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51567, 3555, 'Os 100 S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144035.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51568, 3555, 'Os 100 S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144036.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51569, 3555, 'Os 100 S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144037.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51570, 3555, 'Os 100 S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144038.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51571, 3555, 'Os 100 S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144039.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51572, 3556, 'Os 100 S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144040.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51573, 3556, 'Os 100 S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144041.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51574, 3556, 'Os 100 S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144042.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51575, 3556, 'Os 100 S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144043.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51576, 3556, 'Os 100 S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144044.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51577, 3556, 'Os 100 S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144045.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51578, 3556, 'Os 100 S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144046.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51579, 3556, 'Os 100 S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144047.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51580, 3556, 'Os 100 S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144048.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51581, 3556, 'Os 100 S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144049.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51582, 3556, 'Os 100 S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144050.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51583, 3556, 'Os 100 S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144051.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51584, 3556, 'Os 100 S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144052.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51585, 3557, 'Os 100 S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144053.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51586, 3557, 'Os 100 S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144054.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51587, 3557, 'Os 100 S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144055.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51588, 3557, 'Os 100 S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144056.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(51589, 3557, 'Os 100 S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144057.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51590, 3557, 'Os 100 S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144058.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51591, 3557, 'Os 100 S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144059.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51592, 3557, 'Os 100 S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144060.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51593, 3557, 'Os 100 S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144061.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51594, 3557, 'Os 100 S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144062.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51595, 3557, 'Os 100 S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144063.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51596, 3557, 'Os 100 S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144064.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51597, 3557, 'Os 100 S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144065.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51598, 3558, 'Os 100 S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/144066.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51599, 3558, 'Os 100 S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/144067.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51600, 3558, 'Os 100 S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/144068.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51601, 3558, 'Os 100 S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/144069.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51602, 3558, 'Os 100 S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/144070.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51603, 3558, 'Os 100 S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/144071.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51604, 3558, 'Os 100 S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/144072.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51605, 3558, 'Os 100 S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/144073.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51606, 3558, 'Os 100 S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/144074.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51607, 3558, 'Os 100 S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/144075.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51608, 3558, 'Os 100 S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/144076.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51609, 3558, 'Os 100 S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/144077.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51610, 3558, 'Os 100 S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/144078.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51611, 3558, 'Os 100 S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/144079.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51612, 3558, 'Os 100 S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/144080.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51613, 3558, 'Os 100 S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/144081.mp4', 'http://gstaticontent.com/images/cfhfcEt4bOXuVZkTC0nNBpqqiWb_big.jpg'),
(51614, 3559, 'A Costa do Mosquito S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202050.mp4', 'http://gstaticontent.com/images/j2wKFCP4nPL0wpjb4sjeYW6tLWz_big.jpg'),
(51615, 3559, 'A Costa do Mosquito S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202051.mp4', 'http://gstaticontent.com/images/j2wKFCP4nPL0wpjb4sjeYW6tLWz_big.jpg'),
(51616, 3559, 'A Costa do Mosquito S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202052.mp4', 'http://gstaticontent.com/images/j2wKFCP4nPL0wpjb4sjeYW6tLWz_big.jpg'),
(51617, 3559, 'A Costa do Mosquito S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202053.mp4', 'http://gstaticontent.com/images/j2wKFCP4nPL0wpjb4sjeYW6tLWz_big.jpg'),
(51618, 3559, 'A Costa do Mosquito S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202054.mp4', 'http://gstaticontent.com/images/j2wKFCP4nPL0wpjb4sjeYW6tLWz_big.jpg'),
(51619, 3559, 'A Costa do Mosquito S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202055.mp4', 'http://gstaticontent.com/images/j2wKFCP4nPL0wpjb4sjeYW6tLWz_big.jpg'),
(51620, 3559, 'A Costa do Mosquito S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202056.mp4', 'http://timg.bdta.pro/images/078383f38f214f1f5adec8b8f7662dfe.jpg'),
(51621, 3560, 'A Costa do Mosquito S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202057.mp4', 'http://image.tmdb.org/t/p/w1280/pI4TkSzmGDk2m82NKmemtkfO0YO.jpg'),
(51622, 3560, 'A Costa do Mosquito S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202058.mp4', 'http://image.tmdb.org/t/p/w1280/h0ztoNMfbhrwBDWnmp4wyvmxFM5.jpg'),
(51623, 3560, 'A Costa do Mosquito S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJxNmA4AHlqbIVdgzJ58q4WRhSW.jpg'),
(51624, 3560, 'A Costa do Mosquito S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oseLALU542meZfKP8svuxCopgGs.jpg'),
(51625, 3560, 'A Costa do Mosquito S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202061.mp4', 'http://image.tmdb.org/t/p/w1280/bKsbF4xgIzdafjIuaHBowG54dt7.jpg'),
(51626, 3560, 'A Costa do Mosquito S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202062.mp4', 'http://image.tmdb.org/t/p/w1280/r7EzTx1GiWhI78KmDeE0tLPfcEM.jpg'),
(51627, 3560, 'A Costa do Mosquito S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202063.mp4', 'http://image.tmdb.org/t/p/w1280/4mqnrupStzvPIz59VsLS6r5VbJB.jpg'),
(51628, 3560, 'A Costa do Mosquito S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202064.mp4', 'http://image.tmdb.org/t/p/w1280/aPgQSCBxi1pJ5vfVqXBcmjJL2x0.jpg'),
(51629, 3560, 'A Costa do Mosquito S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202065.mp4', 'http://image.tmdb.org/t/p/w1280/aqFx9HY9LP8AWsAC18fJJiLkyvT.jpg'),
(51630, 3560, 'A Costa do Mosquito S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202066.mp4', 'http://image.tmdb.org/t/p/w1280/A5bll57wI93VC8yskB9Efo4cybt.jpg'),
(51631, 3561, 'Alien TV S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143898.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51632, 3561, 'Alien TV S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143899.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51633, 3561, 'Alien TV S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143900.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51634, 3561, 'Alien TV S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143901.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51635, 3561, 'Alien TV S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143902.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51636, 3561, 'Alien TV S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143903.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51637, 3561, 'Alien TV S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143904.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51638, 3561, 'Alien TV S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143905.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51639, 3561, 'Alien TV S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143906.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51640, 3561, 'Alien TV S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143907.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51641, 3561, 'Alien TV S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143908.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51642, 3561, 'Alien TV S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143909.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51643, 3561, 'Alien TV S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143910.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51644, 3562, 'Alien TV S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143911.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51645, 3562, 'Alien TV S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143912.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51646, 3562, 'Alien TV S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143913.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51647, 3562, 'Alien TV S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143914.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51648, 3562, 'Alien TV S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143915.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51649, 3562, 'Alien TV S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143916.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51650, 3562, 'Alien TV S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143917.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51651, 3562, 'Alien TV S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143918.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51652, 3562, 'Alien TV S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143919.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51653, 3562, 'Alien TV S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143920.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51654, 3562, 'Alien TV S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143921.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51655, 3562, 'Alien TV S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143922.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51656, 3562, 'Alien TV S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143923.mp4', 'http://gstaticontent.com/images/a6yQFzk86cLgUfuTvjobMc3TL17_big.jpg'),
(51657, 3563, 'Meu Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143886.mp4', 'http://gstaticontent.com/images/lVBwQpgNItuUySXJoUg9B0VZxOL_big.jpg'),
(51658, 3563, 'Meu Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143887.mp4', 'http://gstaticontent.com/images/lVBwQpgNItuUySXJoUg9B0VZxOL_big.jpg'),
(51659, 3563, 'Meu Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143888.mp4', 'http://gstaticontent.com/images/lVBwQpgNItuUySXJoUg9B0VZxOL_big.jpg'),
(51660, 3563, 'Meu Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143889.mp4', 'http://gstaticontent.com/images/lVBwQpgNItuUySXJoUg9B0VZxOL_big.jpg'),
(51661, 3563, 'Meu Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143890.mp4', 'http://gstaticontent.com/images/lVBwQpgNItuUySXJoUg9B0VZxOL_big.jpg'),
(51662, 3563, 'Meu Amor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143891.mp4', 'http://gstaticontent.com/images/lVBwQpgNItuUySXJoUg9B0VZxOL_big.jpg'),
(51663, 3563, 'Meu Amor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143892.mp4', 'http://gstaticontent.com/images/lVBwQpgNItuUySXJoUg9B0VZxOL_big.jpg'),
(51664, 3563, 'Meu Amor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143893.mp4', 'http://gstaticontent.com/images/lVBwQpgNItuUySXJoUg9B0VZxOL_big.jpg'),
(51665, 3563, 'Meu Amor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143894.mp4', 'http://gstaticontent.com/images/lVBwQpgNItuUySXJoUg9B0VZxOL_big.jpg'),
(51666, 3563, 'Meu Amor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143895.mp4', 'http://gstaticontent.com/images/lVBwQpgNItuUySXJoUg9B0VZxOL_big.jpg'),
(51667, 3563, 'Meu Amor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143896.mp4', 'http://gstaticontent.com/images/lVBwQpgNItuUySXJoUg9B0VZxOL_big.jpg'),
(51668, 3563, 'Meu Amor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143897.mp4', 'http://gstaticontent.com/images/lVBwQpgNItuUySXJoUg9B0VZxOL_big.jpg'),
(51669, 3564, 'O Inocente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143878.mp4', 'http://gstaticontent.com/images/1u6MAHNAgheFMxTt9YF9bz9KHQH_big.jpg'),
(51670, 3564, 'O Inocente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143879.mp4', 'http://gstaticontent.com/images/1u6MAHNAgheFMxTt9YF9bz9KHQH_big.jpg'),
(51671, 3564, 'O Inocente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143880.mp4', 'http://gstaticontent.com/images/1u6MAHNAgheFMxTt9YF9bz9KHQH_big.jpg'),
(51672, 3564, 'O Inocente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143881.mp4', 'http://gstaticontent.com/images/1u6MAHNAgheFMxTt9YF9bz9KHQH_big.jpg'),
(51673, 3564, 'O Inocente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143882.mp4', 'http://gstaticontent.com/images/1u6MAHNAgheFMxTt9YF9bz9KHQH_big.jpg'),
(51674, 3564, 'O Inocente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143883.mp4', 'http://gstaticontent.com/images/1u6MAHNAgheFMxTt9YF9bz9KHQH_big.jpg'),
(51675, 3564, 'O Inocente S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143884.mp4', 'http://gstaticontent.com/images/1u6MAHNAgheFMxTt9YF9bz9KHQH_big.jpg'),
(51676, 3564, 'O Inocente S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143885.mp4', 'http://gstaticontent.com/images/1u6MAHNAgheFMxTt9YF9bz9KHQH_big.jpg'),
(51677, 3565, 'Onde Está Meu Coração S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143868.mp4', 'http://gstaticontent.com/images/fYXdYXpKdHj6hqlrOHKUdy9VbxQ_big.jpg'),
(51678, 3565, 'Onde Está Meu Coração S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143869.mp4', 'http://gstaticontent.com/images/fYXdYXpKdHj6hqlrOHKUdy9VbxQ_big.jpg'),
(51679, 3565, 'Onde Está Meu Coração S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143870.mp4', 'http://gstaticontent.com/images/fYXdYXpKdHj6hqlrOHKUdy9VbxQ_big.jpg'),
(51680, 3565, 'Onde Está Meu Coração S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143871.mp4', 'http://gstaticontent.com/images/fYXdYXpKdHj6hqlrOHKUdy9VbxQ_big.jpg'),
(51681, 3565, 'Onde Está Meu Coração S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143872.mp4', 'http://gstaticontent.com/images/fYXdYXpKdHj6hqlrOHKUdy9VbxQ_big.jpg'),
(51682, 3565, 'Onde Está Meu Coração S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143873.mp4', 'http://gstaticontent.com/images/fYXdYXpKdHj6hqlrOHKUdy9VbxQ_big.jpg'),
(51683, 3565, 'Onde Está Meu Coração S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143874.mp4', 'http://gstaticontent.com/images/fYXdYXpKdHj6hqlrOHKUdy9VbxQ_big.jpg'),
(51684, 3565, 'Onde Está Meu Coração S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143875.mp4', 'http://gstaticontent.com/images/fYXdYXpKdHj6hqlrOHKUdy9VbxQ_big.jpg'),
(51685, 3565, 'Onde Está Meu Coração S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143876.mp4', 'http://gstaticontent.com/images/fYXdYXpKdHj6hqlrOHKUdy9VbxQ_big.jpg'),
(51686, 3565, 'Onde Está Meu Coração S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143877.mp4', 'http://gstaticontent.com/images/fYXdYXpKdHj6hqlrOHKUdy9VbxQ_big.jpg'),
(51687, 3566, 'One Spring Night [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143852.mp4', 'http://gstaticontent.com/images/urxYgfofFH2ZRl8DoUve2YipPFi_big.jpg'),
(51688, 3566, 'One Spring Night [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143853.mp4', 'http://gstaticontent.com/images/urxYgfofFH2ZRl8DoUve2YipPFi_big.jpg'),
(51689, 3566, 'One Spring Night [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143854.mp4', 'http://gstaticontent.com/images/urxYgfofFH2ZRl8DoUve2YipPFi_big.jpg'),
(51690, 3566, 'One Spring Night [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143855.mp4', 'http://gstaticontent.com/images/urxYgfofFH2ZRl8DoUve2YipPFi_big.jpg'),
(51691, 3566, 'One Spring Night [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143856.mp4', 'http://gstaticontent.com/images/urxYgfofFH2ZRl8DoUve2YipPFi_big.jpg'),
(51692, 3566, 'One Spring Night [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143857.mp4', 'http://gstaticontent.com/images/urxYgfofFH2ZRl8DoUve2YipPFi_big.jpg'),
(51693, 3566, 'One Spring Night [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143858.mp4', 'http://gstaticontent.com/images/urxYgfofFH2ZRl8DoUve2YipPFi_big.jpg'),
(51694, 3566, 'One Spring Night [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143859.mp4', 'http://gstaticontent.com/images/urxYgfofFH2ZRl8DoUve2YipPFi_big.jpg'),
(51695, 3566, 'One Spring Night [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143860.mp4', 'http://gstaticontent.com/images/urxYgfofFH2ZRl8DoUve2YipPFi_big.jpg'),
(51696, 3566, 'One Spring Night [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143861.mp4', 'http://gstaticontent.com/images/urxYgfofFH2ZRl8DoUve2YipPFi_big.jpg'),
(51697, 3566, 'One Spring Night [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143862.mp4', 'http://gstaticontent.com/images/urxYgfofFH2ZRl8DoUve2YipPFi_big.jpg'),
(51698, 3566, 'One Spring Night [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143863.mp4', 'http://gstaticontent.com/images/urxYgfofFH2ZRl8DoUve2YipPFi_big.jpg'),
(51699, 3566, 'One Spring Night [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143864.mp4', 'http://gstaticontent.com/images/urxYgfofFH2ZRl8DoUve2YipPFi_big.jpg'),
(51700, 3566, 'One Spring Night [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143865.mp4', 'http://gstaticontent.com/images/urxYgfofFH2ZRl8DoUve2YipPFi_big.jpg'),
(51701, 3566, 'One Spring Night [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143866.mp4', 'http://gstaticontent.com/images/urxYgfofFH2ZRl8DoUve2YipPFi_big.jpg'),
(51702, 3566, 'One Spring Night [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143867.mp4', 'http://gstaticontent.com/images/urxYgfofFH2ZRl8DoUve2YipPFi_big.jpg'),
(51703, 3567, 'Pet Stars S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143847.mp4', 'http://gstaticontent.com/images/lnQq2dXQGqen58jBTkrT4z40Erk_big.jpg'),
(51704, 3567, 'Pet Stars S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143848.mp4', 'http://gstaticontent.com/images/lnQq2dXQGqen58jBTkrT4z40Erk_big.jpg'),
(51705, 3567, 'Pet Stars S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143849.mp4', 'http://gstaticontent.com/images/lnQq2dXQGqen58jBTkrT4z40Erk_big.jpg'),
(51706, 3567, 'Pet Stars S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143850.mp4', 'http://gstaticontent.com/images/lnQq2dXQGqen58jBTkrT4z40Erk_big.jpg'),
(51707, 3567, 'Pet Stars S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143851.mp4', 'http://gstaticontent.com/images/lnQq2dXQGqen58jBTkrT4z40Erk_big.jpg'),
(51708, 3568, 'Primeira Vez Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143831.mp4', 'http://gstaticontent.com/images/8L31SajpGAdWeOdr23jlY5ELngQ_big.jpg'),
(51709, 3568, 'Primeira Vez Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143832.mp4', 'http://gstaticontent.com/images/8L31SajpGAdWeOdr23jlY5ELngQ_big.jpg'),
(51710, 3568, 'Primeira Vez Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143833.mp4', 'http://gstaticontent.com/images/8L31SajpGAdWeOdr23jlY5ELngQ_big.jpg'),
(51711, 3568, 'Primeira Vez Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143834.mp4', 'http://gstaticontent.com/images/8L31SajpGAdWeOdr23jlY5ELngQ_big.jpg'),
(51712, 3568, 'Primeira Vez Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143835.mp4', 'http://gstaticontent.com/images/8L31SajpGAdWeOdr23jlY5ELngQ_big.jpg'),
(51713, 3568, 'Primeira Vez Amor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143836.mp4', 'http://gstaticontent.com/images/8L31SajpGAdWeOdr23jlY5ELngQ_big.jpg'),
(51714, 3568, 'Primeira Vez Amor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143837.mp4', 'http://gstaticontent.com/images/8L31SajpGAdWeOdr23jlY5ELngQ_big.jpg'),
(51715, 3568, 'Primeira Vez Amor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143838.mp4', 'http://gstaticontent.com/images/8L31SajpGAdWeOdr23jlY5ELngQ_big.jpg'),
(51716, 3569, 'Primeira Vez Amor S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143839.mp4', 'http://gstaticontent.com/images/8L31SajpGAdWeOdr23jlY5ELngQ_big.jpg'),
(51717, 3569, 'Primeira Vez Amor S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143840.mp4', 'http://gstaticontent.com/images/8L31SajpGAdWeOdr23jlY5ELngQ_big.jpg'),
(51718, 3569, 'Primeira Vez Amor S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143841.mp4', 'http://gstaticontent.com/images/8L31SajpGAdWeOdr23jlY5ELngQ_big.jpg'),
(51719, 3569, 'Primeira Vez Amor S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143842.mp4', 'http://gstaticontent.com/images/8L31SajpGAdWeOdr23jlY5ELngQ_big.jpg'),
(51720, 3569, 'Primeira Vez Amor S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143843.mp4', 'http://gstaticontent.com/images/8L31SajpGAdWeOdr23jlY5ELngQ_big.jpg'),
(51721, 3569, 'Primeira Vez Amor S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143844.mp4', 'http://gstaticontent.com/images/8L31SajpGAdWeOdr23jlY5ELngQ_big.jpg'),
(51722, 3569, 'Primeira Vez Amor S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143845.mp4', 'http://gstaticontent.com/images/8L31SajpGAdWeOdr23jlY5ELngQ_big.jpg'),
(51723, 3569, 'Primeira Vez Amor S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143846.mp4', 'http://gstaticontent.com/images/8L31SajpGAdWeOdr23jlY5ELngQ_big.jpg'),
(51724, 3570, 'Selena: A Série S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143822.mp4', 'http://gstaticontent.com/images/j4e3yAAc2sCtK9liKmHNsXVsgoF_big.jpg'),
(51725, 3570, 'Selena: A Série S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143823.mp4', 'http://gstaticontent.com/images/j4e3yAAc2sCtK9liKmHNsXVsgoF_big.jpg'),
(51726, 3570, 'Selena: A Série S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143824.mp4', 'http://gstaticontent.com/images/j4e3yAAc2sCtK9liKmHNsXVsgoF_big.jpg'),
(51727, 3570, 'Selena: A Série S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143825.mp4', 'http://gstaticontent.com/images/j4e3yAAc2sCtK9liKmHNsXVsgoF_big.jpg'),
(51728, 3570, 'Selena: A Série S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143826.mp4', 'http://gstaticontent.com/images/j4e3yAAc2sCtK9liKmHNsXVsgoF_big.jpg'),
(51729, 3570, 'Selena: A Série S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143827.mp4', 'http://gstaticontent.com/images/j4e3yAAc2sCtK9liKmHNsXVsgoF_big.jpg'),
(51730, 3570, 'Selena: A Série S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143828.mp4', 'http://gstaticontent.com/images/j4e3yAAc2sCtK9liKmHNsXVsgoF_big.jpg'),
(51731, 3570, 'Selena: A Série S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143829.mp4', 'http://gstaticontent.com/images/j4e3yAAc2sCtK9liKmHNsXVsgoF_big.jpg'),
(51732, 3570, 'Selena: A Série S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143830.mp4', 'http://gstaticontent.com/images/j4e3yAAc2sCtK9liKmHNsXVsgoF_big.jpg'),
(51733, 3571, 'Star Wars: The Bad Batch S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208478.mp4', 'http://timg.bdta.pro/images/c27184ee8fec5a577bdfef277d319ee8.jpg'),
(51734, 3571, 'Star Wars: The Bad Batch S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208479.mp4', 'http://timg.bdta.pro/images/07bd075c212e1243bef07bcc410d86c4.jpg'),
(51735, 3571, 'Star Wars: The Bad Batch S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208480.mp4', 'http://timg.bdta.pro/images/e66946edb42173d16e2b8523f721e34a.jpg'),
(51736, 3571, 'Star Wars: The Bad Batch S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208481.mp4', 'http://timg.bdta.pro/images/d3511e16c237f016b6a8d06d278b6d45.jpg'),
(51737, 3571, 'Star Wars: The Bad Batch S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208482.mp4', 'http://timg.bdta.pro/images/7b0b78ba683f221878ebc400d3fdffc6.jpg'),
(51738, 3571, 'Star Wars: The Bad Batch S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208483.mp4', 'http://timg.bdta.pro/images/2e9e990a0abc01827533d0d2a544bd85.jpg'),
(51739, 3571, 'Star Wars: The Bad Batch S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208484.mp4', 'http://timg.bdta.pro/images/65a17df99f8b92b9f0885b36ba97ae7f.jpg'),
(51740, 3571, 'Star Wars: The Bad Batch S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208485.mp4', 'http://timg.bdta.pro/images/15371f7d99089f5ea962847c396d2842.jpg'),
(51741, 3571, 'Star Wars: The Bad Batch S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208486.mp4', 'http://timg.bdta.pro/images/3e6d1f27b943d78a4feda890f19173b6.jpg'),
(51742, 3571, 'Star Wars: The Bad Batch S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208487.mp4', 'http://timg.bdta.pro/images/726a1ad2360fc008639875614cbe0ba8.jpg'),
(51743, 3571, 'Star Wars: The Bad Batch S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208488.mp4', 'http://timg.bdta.pro/images/a88c4d41b923e87dae006fd88c6ef05e.jpg'),
(51744, 3571, 'Star Wars: The Bad Batch S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208489.mp4', 'http://timg.bdta.pro/images/260351cd315a7f658fbe965f1579027f.jpg'),
(51745, 3571, 'Star Wars: The Bad Batch S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/208490.mp4', 'http://timg.bdta.pro/images/d168c4ee5f76f7d8ff143863aadb9e3e.jpg'),
(51746, 3571, 'Star Wars: The Bad Batch S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/208491.mp4', 'http://timg.bdta.pro/images/fa9d1451e2dbab5c00e0fb67c1391fc9.jpg'),
(51747, 3571, 'Star Wars: The Bad Batch S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/208492.mp4', 'http://timg.bdta.pro/images/757538013600650a860a04469bd94cea.jpg'),
(51748, 3571, 'Star Wars: The Bad Batch S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/208493.mp4', 'http://timg.bdta.pro/images/e81f267e6886444f448d4db22e7aef47.jpg'),
(51749, 3572, 'Star Wars: The Bad Batch S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sun5Xq2ua746j3kb5Fsf1zTk6X3.jpg'),
(51750, 3572, 'Star Wars: The Bad Batch S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qOrjrR9KWJ1fsbG68gpAgySI17.jpg'),
(51751, 3572, 'Star Wars: The Bad Batch S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208496.mp4', 'http://image.tmdb.org/t/p/w1280/VO0sRZ11sTrFwN8EOs9Ik1dFYd.jpg'),
(51752, 3572, 'Star Wars: The Bad Batch S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208497.mp4', 'http://image.tmdb.org/t/p/w1280/nLyeXY7ThsFCweBUOtnsB5HeAwc.jpg'),
(51753, 3572, 'Star Wars: The Bad Batch S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208498.mp4', 'http://image.tmdb.org/t/p/w1280/fMG4478ksDN9qgxUWKhU3orlSsH.jpg'),
(51754, 3572, 'Star Wars: The Bad Batch S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208499.mp4', 'http://image.tmdb.org/t/p/w1280/qWUcjmP34UUcEhJhqg83O50YVzH.jpg'),
(51755, 3572, 'Star Wars: The Bad Batch S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208500.mp4', 'http://image.tmdb.org/t/p/w1280/m3NldEIQOTMshnZ2iLDPNr96fZO.jpg'),
(51756, 3572, 'Star Wars: The Bad Batch S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208501.mp4', 'http://image.tmdb.org/t/p/w1280/33LrnynpiluXVoaOZqQA93lmZMN.jpg'),
(51757, 3572, 'Star Wars: The Bad Batch S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208502.mp4', 'http://image.tmdb.org/t/p/w1280/hX7JAwHXdWfOLhjl1KlYokrZsm7.jpg'),
(51758, 3572, 'Star Wars: The Bad Batch S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208503.mp4', 'http://image.tmdb.org/t/p/w1280/9ZdpX6fjKyw5nRoAbYrT74Uuf7R.jpg'),
(51759, 3572, 'Star Wars: The Bad Batch S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208504.mp4', 'http://image.tmdb.org/t/p/w1280/xxcDjC2FaLPXahAlk1WhQnoEg3B.jpg'),
(51760, 3572, 'Star Wars: The Bad Batch S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208505.mp4', 'http://image.tmdb.org/t/p/w1280/8PFfg5lOdx8P976WP0ZymdCBQje.jpg'),
(51761, 3572, 'Star Wars: The Bad Batch S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/208506.mp4', 'http://image.tmdb.org/t/p/w1280/h4oPRSyjZlRBHttKpXwoIUURoVo.jpg'),
(51762, 3572, 'Star Wars: The Bad Batch S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/208507.mp4', 'http://image.tmdb.org/t/p/w1280/dLa82VP14X7kThMWEyuWKtvFVz7.jpg'),
(51763, 3572, 'Star Wars: The Bad Batch S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/208508.mp4', 'http://image.tmdb.org/t/p/w1280/1LIfLH1fQLsGb6bjghs7K3QfzX.jpg'),
(51764, 3572, 'Star Wars: The Bad Batch S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/208509.mp4', 'http://image.tmdb.org/t/p/w1280/vmo7U9cac9IJmkoztGTZRaqvy3Q.jpg'),
(51765, 3573, 'Star Wars: The Bad Batch S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/277585.mp4', 'http://gstaticontent.com/images/8e27ba2c513901153c92ad77b6ba839d.jpg'),
(51766, 3573, 'Star Wars: The Bad Batch S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/277586.mp4', 'http://gstaticontent.com/images/8e27ba2c513901153c92ad77b6ba839d.jpg'),
(51767, 3573, 'Star Wars: The Bad Batch S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/277587.mp4', 'http://gstaticontent.com/images/8e27ba2c513901153c92ad77b6ba839d.jpg'),
(51768, 3573, 'Star Wars: The Bad Batch S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/288579.mp4', 'http://gstaticontent.com/images/8e27ba2c513901153c92ad77b6ba839d.jpg'),
(51769, 3573, 'Star Wars: The Bad Batch S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294032.mp4', 'http://gstaticontent.com/images/8e27ba2c513901153c92ad77b6ba839d.jpg'),
(51770, 3573, 'Star Wars: The Bad Batch S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/299799.mp4', 'http://gstaticontent.com/images/8e27ba2c513901153c92ad77b6ba839d.jpg'),
(51771, 3573, 'Star Wars: The Bad Batch S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/299800.mp4', 'http://gstaticontent.com/images/8e27ba2c513901153c92ad77b6ba839d.jpg'),
(51772, 3573, 'Star Wars: The Bad Batch S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/303992.mp4', 'http://gstaticontent.com/images/8e27ba2c513901153c92ad77b6ba839d.jpg'),
(51773, 3573, 'Star Wars: The Bad Batch S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/309690.mp4', 'http://gstaticontent.com/images/8e27ba2c513901153c92ad77b6ba839d.jpg'),
(51774, 3573, 'Star Wars: The Bad Batch S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/317204.mp4', 'http://gstaticontent.com/images/8e27ba2c513901153c92ad77b6ba839d.jpg'),
(51775, 3573, 'Star Wars: The Bad Batch S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/317205.mp4', 'http://gstaticontent.com/images/8e27ba2c513901153c92ad77b6ba839d.jpg'),
(51776, 3573, 'Star Wars: The Bad Batch S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/323568.mp4', 'http://gstaticontent.com/images/8e27ba2c513901153c92ad77b6ba839d.jpg'),
(51777, 3573, 'Star Wars: The Bad Batch S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/327592.mp4', 'http://gstaticontent.com/images/8e27ba2c513901153c92ad77b6ba839d.jpg'),
(51778, 3573, 'Star Wars: The Bad Batch S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/335891.mp4', 'http://gstaticontent.com/images/8e27ba2c513901153c92ad77b6ba839d.jpg'),
(51779, 3573, 'Star Wars: The Bad Batch S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/340046.mp4', 'http://gstaticontent.com/images/8e27ba2c513901153c92ad77b6ba839d.jpg'),
(51780, 3574, 'Star Wars: Rebels S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143750.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51781, 3574, 'Star Wars: Rebels S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143751.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51782, 3574, 'Star Wars: Rebels S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143752.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51783, 3574, 'Star Wars: Rebels S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143753.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51784, 3574, 'Star Wars: Rebels S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143754.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51785, 3574, 'Star Wars: Rebels S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143755.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51786, 3574, 'Star Wars: Rebels S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143756.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51787, 3574, 'Star Wars: Rebels S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143757.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51788, 3574, 'Star Wars: Rebels S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143758.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51789, 3574, 'Star Wars: Rebels S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143759.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51790, 3574, 'Star Wars: Rebels S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143760.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51791, 3574, 'Star Wars: Rebels S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143761.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51792, 3574, 'Star Wars: Rebels S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143762.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51793, 3574, 'Star Wars: Rebels S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143763.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51794, 3574, 'Star Wars: Rebels S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143764.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51795, 3575, 'Star Wars: Rebels S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143765.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51796, 3575, 'Star Wars: Rebels S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143766.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51797, 3575, 'Star Wars: Rebels S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143767.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51798, 3575, 'Star Wars: Rebels S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143768.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51799, 3575, 'Star Wars: Rebels S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143769.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51800, 3575, 'Star Wars: Rebels S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143770.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51801, 3575, 'Star Wars: Rebels S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143771.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51802, 3575, 'Star Wars: Rebels S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143772.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51803, 3575, 'Star Wars: Rebels S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143773.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51804, 3575, 'Star Wars: Rebels S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143774.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51805, 3575, 'Star Wars: Rebels S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143775.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51806, 3575, 'Star Wars: Rebels S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143776.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51807, 3575, 'Star Wars: Rebels S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143777.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51808, 3575, 'Star Wars: Rebels S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143778.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51809, 3575, 'Star Wars: Rebels S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143779.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51810, 3575, 'Star Wars: Rebels S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143780.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51811, 3575, 'Star Wars: Rebels S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/143781.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51812, 3575, 'Star Wars: Rebels S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/143782.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51813, 3575, 'Star Wars: Rebels S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/143783.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51814, 3575, 'Star Wars: Rebels S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/143784.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51815, 3576, 'Star Wars: Rebels S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143785.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51816, 3576, 'Star Wars: Rebels S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143786.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51817, 3576, 'Star Wars: Rebels S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143787.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51818, 3576, 'Star Wars: Rebels S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143788.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51819, 3576, 'Star Wars: Rebels S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143789.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51820, 3576, 'Star Wars: Rebels S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143790.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51821, 3576, 'Star Wars: Rebels S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143791.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51822, 3576, 'Star Wars: Rebels S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143792.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51823, 3576, 'Star Wars: Rebels S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143793.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51824, 3576, 'Star Wars: Rebels S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143794.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51825, 3576, 'Star Wars: Rebels S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143795.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51826, 3576, 'Star Wars: Rebels S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143796.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51827, 3576, 'Star Wars: Rebels S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143797.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51828, 3576, 'Star Wars: Rebels S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143798.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51829, 3576, 'Star Wars: Rebels S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143799.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51830, 3576, 'Star Wars: Rebels S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143800.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51831, 3576, 'Star Wars: Rebels S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/143801.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51832, 3576, 'Star Wars: Rebels S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/143802.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51833, 3576, 'Star Wars: Rebels S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/143803.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51834, 3576, 'Star Wars: Rebels S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/143804.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51835, 3576, 'Star Wars: Rebels S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/143805.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51836, 3576, 'Star Wars: Rebels S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/143806.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51837, 3577, 'Star Wars: Rebels S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143807.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51838, 3577, 'Star Wars: Rebels S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143808.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51839, 3577, 'Star Wars: Rebels S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143809.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51840, 3577, 'Star Wars: Rebels S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143810.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51841, 3577, 'Star Wars: Rebels S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143811.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51842, 3577, 'Star Wars: Rebels S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143812.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51843, 3577, 'Star Wars: Rebels S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143813.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51844, 3577, 'Star Wars: Rebels S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143814.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51845, 3577, 'Star Wars: Rebels S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143815.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51846, 3577, 'Star Wars: Rebels S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143816.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51847, 3577, 'Star Wars: Rebels S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143817.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51848, 3577, 'Star Wars: Rebels S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143818.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51849, 3577, 'Star Wars: Rebels S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143819.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51850, 3577, 'Star Wars: Rebels S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143820.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51851, 3577, 'Star Wars: Rebels S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143821.mp4', 'http://gstaticontent.com/images/oPti8Yf7ryQb6bQZfZlYgeCZkm3_big.jpg'),
(51852, 3578, 'The Long Road Home [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143739.mp4', 'http://gstaticontent.com/images/4dZvU5wdODUVVbAPtSUfWLLUe03_big.jpg'),
(51853, 3578, 'The Long Road Home [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143740.mp4', 'http://gstaticontent.com/images/4dZvU5wdODUVVbAPtSUfWLLUe03_big.jpg'),
(51854, 3578, 'The Long Road Home [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143741.mp4', 'http://gstaticontent.com/images/4dZvU5wdODUVVbAPtSUfWLLUe03_big.jpg'),
(51855, 3578, 'The Long Road Home [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143742.mp4', 'http://gstaticontent.com/images/4dZvU5wdODUVVbAPtSUfWLLUe03_big.jpg'),
(51856, 3578, 'The Long Road Home [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143743.mp4', 'http://gstaticontent.com/images/4dZvU5wdODUVVbAPtSUfWLLUe03_big.jpg'),
(51857, 3578, 'The Long Road Home [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143744.mp4', 'http://gstaticontent.com/images/4dZvU5wdODUVVbAPtSUfWLLUe03_big.jpg'),
(51858, 3578, 'The Long Road Home [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143745.mp4', 'http://gstaticontent.com/images/4dZvU5wdODUVVbAPtSUfWLLUe03_big.jpg'),
(51859, 3579, 'Them [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143729.mp4', 'http://gstaticontent.com/images/bJw1VZ4ACt5TnAvJbHcprzgYc1E_big.jpg'),
(51860, 3579, 'Them [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143730.mp4', 'http://gstaticontent.com/images/bJw1VZ4ACt5TnAvJbHcprzgYc1E_big.jpg'),
(51861, 3579, 'Them [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143731.mp4', 'http://gstaticontent.com/images/bJw1VZ4ACt5TnAvJbHcprzgYc1E_big.jpg'),
(51862, 3579, 'Them [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143732.mp4', 'http://gstaticontent.com/images/bJw1VZ4ACt5TnAvJbHcprzgYc1E_big.jpg'),
(51863, 3579, 'Them [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143733.mp4', 'http://gstaticontent.com/images/bJw1VZ4ACt5TnAvJbHcprzgYc1E_big.jpg'),
(51864, 3579, 'Them [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143734.mp4', 'http://gstaticontent.com/images/bJw1VZ4ACt5TnAvJbHcprzgYc1E_big.jpg'),
(51865, 3579, 'Them [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143735.mp4', 'http://gstaticontent.com/images/bJw1VZ4ACt5TnAvJbHcprzgYc1E_big.jpg'),
(51866, 3579, 'Them [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143736.mp4', 'http://gstaticontent.com/images/bJw1VZ4ACt5TnAvJbHcprzgYc1E_big.jpg'),
(51867, 3579, 'Them [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143737.mp4', 'http://gstaticontent.com/images/bJw1VZ4ACt5TnAvJbHcprzgYc1E_big.jpg'),
(51868, 3579, 'Them [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143738.mp4', 'http://gstaticontent.com/images/bJw1VZ4ACt5TnAvJbHcprzgYc1E_big.jpg'),
(51869, 3580, 'Os Filhos de Sam: Loucura e Conspiração S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143746.mp4', 'http://gstaticontent.com/images/qpu7dSBQtTZv3FrdnoBnkraimPU_big.jpg'),
(51870, 3580, 'Os Filhos de Sam: Loucura e Conspiração S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143747.mp4', 'http://gstaticontent.com/images/qpu7dSBQtTZv3FrdnoBnkraimPU_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(51871, 3580, 'Os Filhos de Sam: Loucura e Conspiração S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143748.mp4', 'http://gstaticontent.com/images/qpu7dSBQtTZv3FrdnoBnkraimPU_big.jpg'),
(51872, 3580, 'Os Filhos de Sam: Loucura e Conspiração S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143749.mp4', 'http://gstaticontent.com/images/qpu7dSBQtTZv3FrdnoBnkraimPU_big.jpg'),
(51873, 3581, 'Garota de Fora S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176112.mp4', 'http://gstaticontent.com/images/7s1VshVFh7zbN5pcBJRXvcxF04l_big.jpg'),
(51874, 3581, 'Garota de Fora S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176113.mp4', 'http://gstaticontent.com/images/7s1VshVFh7zbN5pcBJRXvcxF04l_big.jpg'),
(51875, 3581, 'Garota de Fora S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176114.mp4', 'http://gstaticontent.com/images/7s1VshVFh7zbN5pcBJRXvcxF04l_big.jpg'),
(51876, 3581, 'Garota de Fora S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176115.mp4', 'http://gstaticontent.com/images/7s1VshVFh7zbN5pcBJRXvcxF04l_big.jpg'),
(51877, 3581, 'Garota de Fora S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176116.mp4', 'http://gstaticontent.com/images/7s1VshVFh7zbN5pcBJRXvcxF04l_big.jpg'),
(51878, 3581, 'Garota de Fora S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176117.mp4', 'http://gstaticontent.com/images/7s1VshVFh7zbN5pcBJRXvcxF04l_big.jpg'),
(51879, 3581, 'Garota de Fora S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176118.mp4', 'http://gstaticontent.com/images/7s1VshVFh7zbN5pcBJRXvcxF04l_big.jpg'),
(51880, 3581, 'Garota de Fora S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176119.mp4', 'http://gstaticontent.com/images/7s1VshVFh7zbN5pcBJRXvcxF04l_big.jpg'),
(51881, 3581, 'Garota de Fora S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176120.mp4', 'http://gstaticontent.com/images/7s1VshVFh7zbN5pcBJRXvcxF04l_big.jpg'),
(51882, 3581, 'Garota de Fora S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176121.mp4', 'http://gstaticontent.com/images/7s1VshVFh7zbN5pcBJRXvcxF04l_big.jpg'),
(51883, 3581, 'Garota de Fora S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/176122.mp4', 'http://gstaticontent.com/images/7s1VshVFh7zbN5pcBJRXvcxF04l_big.jpg'),
(51884, 3581, 'Garota de Fora S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/176123.mp4', 'http://gstaticontent.com/images/7s1VshVFh7zbN5pcBJRXvcxF04l_big.jpg'),
(51885, 3581, 'Garota de Fora S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/176124.mp4', 'http://gstaticontent.com/images/7s1VshVFh7zbN5pcBJRXvcxF04l_big.jpg'),
(51886, 3582, 'Garota de Fora S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176125.mp4', 'http://timg.bdta.pro/images/f56cf45f0ea1c1b4cc7db6bb3c873293.jpg'),
(51887, 3582, 'Garota de Fora S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176126.mp4', 'http://timg.bdta.pro/images/c281ac974d04de20fa2be943d8abaeca.jpg'),
(51888, 3582, 'Garota de Fora S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176127.mp4', 'http://timg.bdta.pro/images/c805937e0a69174637ef4d1119b919f1.jpg'),
(51889, 3582, 'Garota de Fora S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176128.mp4', 'http://timg.bdta.pro/images/ded6b8aed5d55b4030bd8d06ac3b8cb7.jpg'),
(51890, 3582, 'Garota de Fora S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176129.mp4', 'http://timg.bdta.pro/images/34c2bda68fa5055e7c831eac8488fda7.jpg'),
(51891, 3582, 'Garota de Fora S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176130.mp4', 'http://timg.bdta.pro/images/5ddfdab77020992cbd69969653e53c41.jpg'),
(51892, 3582, 'Garota de Fora S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176131.mp4', 'http://timg.bdta.pro/images/8d406b6081f3ae22ec568b237f384af2.jpg'),
(51893, 3582, 'Garota de Fora S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176132.mp4', 'http://timg.bdta.pro/images/59e0bacde2c69914a83d685e8f5b448e.jpg'),
(51894, 3583, 'Memories Of The Alhambra [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143713.mp4', 'http://gstaticontent.com/images/kb3dXkZsqJ6nXuD20y5NUGx0wqB_big.jpg'),
(51895, 3583, 'Memories Of The Alhambra [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143714.mp4', 'http://gstaticontent.com/images/kb3dXkZsqJ6nXuD20y5NUGx0wqB_big.jpg'),
(51896, 3583, 'Memories Of The Alhambra [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143715.mp4', 'http://gstaticontent.com/images/kb3dXkZsqJ6nXuD20y5NUGx0wqB_big.jpg'),
(51897, 3583, 'Memories Of The Alhambra [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143716.mp4', 'http://gstaticontent.com/images/kb3dXkZsqJ6nXuD20y5NUGx0wqB_big.jpg'),
(51898, 3583, 'Memories Of The Alhambra [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143717.mp4', 'http://gstaticontent.com/images/kb3dXkZsqJ6nXuD20y5NUGx0wqB_big.jpg'),
(51899, 3583, 'Memories Of The Alhambra [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143718.mp4', 'http://gstaticontent.com/images/kb3dXkZsqJ6nXuD20y5NUGx0wqB_big.jpg'),
(51900, 3583, 'Memories Of The Alhambra [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143719.mp4', 'http://gstaticontent.com/images/kb3dXkZsqJ6nXuD20y5NUGx0wqB_big.jpg'),
(51901, 3583, 'Memories Of The Alhambra [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143720.mp4', 'http://gstaticontent.com/images/kb3dXkZsqJ6nXuD20y5NUGx0wqB_big.jpg'),
(51902, 3583, 'Memories Of The Alhambra [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143721.mp4', 'http://gstaticontent.com/images/kb3dXkZsqJ6nXuD20y5NUGx0wqB_big.jpg'),
(51903, 3583, 'Memories Of The Alhambra [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143722.mp4', 'http://gstaticontent.com/images/kb3dXkZsqJ6nXuD20y5NUGx0wqB_big.jpg'),
(51904, 3583, 'Memories Of The Alhambra [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143723.mp4', 'http://gstaticontent.com/images/kb3dXkZsqJ6nXuD20y5NUGx0wqB_big.jpg'),
(51905, 3583, 'Memories Of The Alhambra [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143724.mp4', 'http://gstaticontent.com/images/kb3dXkZsqJ6nXuD20y5NUGx0wqB_big.jpg'),
(51906, 3583, 'Memories Of The Alhambra [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143725.mp4', 'http://gstaticontent.com/images/kb3dXkZsqJ6nXuD20y5NUGx0wqB_big.jpg'),
(51907, 3583, 'Memories Of The Alhambra [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143726.mp4', 'http://gstaticontent.com/images/kb3dXkZsqJ6nXuD20y5NUGx0wqB_big.jpg'),
(51908, 3583, 'Memories Of The Alhambra [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143727.mp4', 'http://gstaticontent.com/images/kb3dXkZsqJ6nXuD20y5NUGx0wqB_big.jpg'),
(51909, 3583, 'Memories Of The Alhambra [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143728.mp4', 'http://gstaticontent.com/images/kb3dXkZsqJ6nXuD20y5NUGx0wqB_big.jpg'),
(51910, 3584, 'Mystic Pop Up Bar [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143701.mp4', 'http://gstaticontent.com/images/4xjtsQgxLkVKfkig5p6MoVoz6PH_big.jpg'),
(51911, 3584, 'Mystic Pop Up Bar [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143702.mp4', 'http://gstaticontent.com/images/4xjtsQgxLkVKfkig5p6MoVoz6PH_big.jpg'),
(51912, 3584, 'Mystic Pop Up Bar [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143703.mp4', 'http://gstaticontent.com/images/4xjtsQgxLkVKfkig5p6MoVoz6PH_big.jpg'),
(51913, 3584, 'Mystic Pop Up Bar [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143704.mp4', 'http://gstaticontent.com/images/4xjtsQgxLkVKfkig5p6MoVoz6PH_big.jpg'),
(51914, 3584, 'Mystic Pop Up Bar [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143705.mp4', 'http://gstaticontent.com/images/4xjtsQgxLkVKfkig5p6MoVoz6PH_big.jpg'),
(51915, 3584, 'Mystic Pop Up Bar [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143706.mp4', 'http://gstaticontent.com/images/4xjtsQgxLkVKfkig5p6MoVoz6PH_big.jpg'),
(51916, 3584, 'Mystic Pop Up Bar [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143707.mp4', 'http://gstaticontent.com/images/4xjtsQgxLkVKfkig5p6MoVoz6PH_big.jpg'),
(51917, 3584, 'Mystic Pop Up Bar [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143708.mp4', 'http://gstaticontent.com/images/4xjtsQgxLkVKfkig5p6MoVoz6PH_big.jpg'),
(51918, 3584, 'Mystic Pop Up Bar [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143709.mp4', 'http://gstaticontent.com/images/4xjtsQgxLkVKfkig5p6MoVoz6PH_big.jpg'),
(51919, 3584, 'Mystic Pop Up Bar [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143710.mp4', 'http://gstaticontent.com/images/4xjtsQgxLkVKfkig5p6MoVoz6PH_big.jpg'),
(51920, 3584, 'Mystic Pop Up Bar [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143711.mp4', 'http://gstaticontent.com/images/4xjtsQgxLkVKfkig5p6MoVoz6PH_big.jpg'),
(51921, 3584, 'Mystic Pop Up Bar [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143712.mp4', 'http://gstaticontent.com/images/4xjtsQgxLkVKfkig5p6MoVoz6PH_big.jpg'),
(51922, 3585, 'Os Astronautas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143691.mp4', 'http://gstaticontent.com/images/5byDyeVYxUQTm5fqcE4pQedyPJ3_big.jpg'),
(51923, 3585, 'Os Astronautas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143692.mp4', 'http://gstaticontent.com/images/5byDyeVYxUQTm5fqcE4pQedyPJ3_big.jpg'),
(51924, 3585, 'Os Astronautas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143693.mp4', 'http://gstaticontent.com/images/5byDyeVYxUQTm5fqcE4pQedyPJ3_big.jpg'),
(51925, 3585, 'Os Astronautas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143694.mp4', 'http://gstaticontent.com/images/5byDyeVYxUQTm5fqcE4pQedyPJ3_big.jpg'),
(51926, 3585, 'Os Astronautas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143695.mp4', 'http://gstaticontent.com/images/5byDyeVYxUQTm5fqcE4pQedyPJ3_big.jpg'),
(51927, 3585, 'Os Astronautas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143696.mp4', 'http://gstaticontent.com/images/5byDyeVYxUQTm5fqcE4pQedyPJ3_big.jpg'),
(51928, 3585, 'Os Astronautas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143697.mp4', 'http://gstaticontent.com/images/5byDyeVYxUQTm5fqcE4pQedyPJ3_big.jpg'),
(51929, 3585, 'Os Astronautas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143698.mp4', 'http://gstaticontent.com/images/5byDyeVYxUQTm5fqcE4pQedyPJ3_big.jpg'),
(51930, 3585, 'Os Astronautas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143699.mp4', 'http://gstaticontent.com/images/5byDyeVYxUQTm5fqcE4pQedyPJ3_big.jpg'),
(51931, 3585, 'Os Astronautas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143700.mp4', 'http://gstaticontent.com/images/5byDyeVYxUQTm5fqcE4pQedyPJ3_big.jpg'),
(51932, 3586, 'Prison Playbook [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143675.mp4', 'http://gstaticontent.com/images/2kK5H4k8qJDS0SSqQ25xKV3DZvB_big.jpg'),
(51933, 3586, 'Prison Playbook [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143676.mp4', 'http://gstaticontent.com/images/2kK5H4k8qJDS0SSqQ25xKV3DZvB_big.jpg'),
(51934, 3586, 'Prison Playbook [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143677.mp4', 'http://gstaticontent.com/images/2kK5H4k8qJDS0SSqQ25xKV3DZvB_big.jpg'),
(51935, 3586, 'Prison Playbook [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143678.mp4', 'http://gstaticontent.com/images/2kK5H4k8qJDS0SSqQ25xKV3DZvB_big.jpg'),
(51936, 3586, 'Prison Playbook [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143679.mp4', 'http://gstaticontent.com/images/2kK5H4k8qJDS0SSqQ25xKV3DZvB_big.jpg'),
(51937, 3586, 'Prison Playbook [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143680.mp4', 'http://gstaticontent.com/images/2kK5H4k8qJDS0SSqQ25xKV3DZvB_big.jpg'),
(51938, 3586, 'Prison Playbook [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143681.mp4', 'http://gstaticontent.com/images/2kK5H4k8qJDS0SSqQ25xKV3DZvB_big.jpg'),
(51939, 3586, 'Prison Playbook [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143682.mp4', 'http://gstaticontent.com/images/2kK5H4k8qJDS0SSqQ25xKV3DZvB_big.jpg'),
(51940, 3586, 'Prison Playbook [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143683.mp4', 'http://gstaticontent.com/images/2kK5H4k8qJDS0SSqQ25xKV3DZvB_big.jpg'),
(51941, 3586, 'Prison Playbook [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143684.mp4', 'http://gstaticontent.com/images/2kK5H4k8qJDS0SSqQ25xKV3DZvB_big.jpg'),
(51942, 3586, 'Prison Playbook [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143685.mp4', 'http://gstaticontent.com/images/2kK5H4k8qJDS0SSqQ25xKV3DZvB_big.jpg'),
(51943, 3586, 'Prison Playbook [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143686.mp4', 'http://gstaticontent.com/images/2kK5H4k8qJDS0SSqQ25xKV3DZvB_big.jpg'),
(51944, 3586, 'Prison Playbook [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143687.mp4', 'http://gstaticontent.com/images/2kK5H4k8qJDS0SSqQ25xKV3DZvB_big.jpg'),
(51945, 3586, 'Prison Playbook [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143688.mp4', 'http://gstaticontent.com/images/2kK5H4k8qJDS0SSqQ25xKV3DZvB_big.jpg'),
(51946, 3586, 'Prison Playbook [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143689.mp4', 'http://gstaticontent.com/images/2kK5H4k8qJDS0SSqQ25xKV3DZvB_big.jpg'),
(51947, 3586, 'Prison Playbook [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143690.mp4', 'http://gstaticontent.com/images/2kK5H4k8qJDS0SSqQ25xKV3DZvB_big.jpg'),
(51948, 3587, 'Romance Is A Bonus Book [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143659.mp4', 'http://gstaticontent.com/images/bVB0SVTNeYJgg4XTXZVrheJZCA3_big.jpg'),
(51949, 3587, 'Romance Is A Bonus Book [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143660.mp4', 'http://gstaticontent.com/images/bVB0SVTNeYJgg4XTXZVrheJZCA3_big.jpg'),
(51950, 3587, 'Romance Is A Bonus Book [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143661.mp4', 'http://gstaticontent.com/images/bVB0SVTNeYJgg4XTXZVrheJZCA3_big.jpg'),
(51951, 3587, 'Romance Is A Bonus Book [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143662.mp4', 'http://gstaticontent.com/images/bVB0SVTNeYJgg4XTXZVrheJZCA3_big.jpg'),
(51952, 3587, 'Romance Is A Bonus Book [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143663.mp4', 'http://gstaticontent.com/images/bVB0SVTNeYJgg4XTXZVrheJZCA3_big.jpg'),
(51953, 3587, 'Romance Is A Bonus Book [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143664.mp4', 'http://gstaticontent.com/images/bVB0SVTNeYJgg4XTXZVrheJZCA3_big.jpg'),
(51954, 3587, 'Romance Is A Bonus Book [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143665.mp4', 'http://gstaticontent.com/images/bVB0SVTNeYJgg4XTXZVrheJZCA3_big.jpg'),
(51955, 3587, 'Romance Is A Bonus Book [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143666.mp4', 'http://gstaticontent.com/images/bVB0SVTNeYJgg4XTXZVrheJZCA3_big.jpg'),
(51956, 3587, 'Romance Is A Bonus Book [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143667.mp4', 'http://gstaticontent.com/images/bVB0SVTNeYJgg4XTXZVrheJZCA3_big.jpg'),
(51957, 3587, 'Romance Is A Bonus Book [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143668.mp4', 'http://gstaticontent.com/images/bVB0SVTNeYJgg4XTXZVrheJZCA3_big.jpg'),
(51958, 3587, 'Romance Is A Bonus Book [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143669.mp4', 'http://gstaticontent.com/images/bVB0SVTNeYJgg4XTXZVrheJZCA3_big.jpg'),
(51959, 3587, 'Romance Is A Bonus Book [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143670.mp4', 'http://gstaticontent.com/images/bVB0SVTNeYJgg4XTXZVrheJZCA3_big.jpg'),
(51960, 3587, 'Romance Is A Bonus Book [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143671.mp4', 'http://gstaticontent.com/images/bVB0SVTNeYJgg4XTXZVrheJZCA3_big.jpg'),
(51961, 3587, 'Romance Is A Bonus Book [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143672.mp4', 'http://gstaticontent.com/images/bVB0SVTNeYJgg4XTXZVrheJZCA3_big.jpg'),
(51962, 3587, 'Romance Is A Bonus Book [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143673.mp4', 'http://gstaticontent.com/images/bVB0SVTNeYJgg4XTXZVrheJZCA3_big.jpg'),
(51963, 3587, 'Romance Is A Bonus Book [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143674.mp4', 'http://gstaticontent.com/images/bVB0SVTNeYJgg4XTXZVrheJZCA3_big.jpg'),
(51964, 3588, 'Aaahh!!! Monstros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143511.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51965, 3588, 'Aaahh!!! Monstros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143512.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51966, 3588, 'Aaahh!!! Monstros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143513.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51967, 3588, 'Aaahh!!! Monstros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143514.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51968, 3588, 'Aaahh!!! Monstros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143515.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51969, 3588, 'Aaahh!!! Monstros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143516.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51970, 3588, 'Aaahh!!! Monstros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143517.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51971, 3588, 'Aaahh!!! Monstros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143518.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51972, 3588, 'Aaahh!!! Monstros S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143519.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51973, 3588, 'Aaahh!!! Monstros S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143520.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51974, 3588, 'Aaahh!!! Monstros S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143521.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51975, 3588, 'Aaahh!!! Monstros S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143522.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51976, 3588, 'Aaahh!!! Monstros S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143523.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51977, 3589, 'Aaahh!!! Monstros S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143524.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51978, 3589, 'Aaahh!!! Monstros S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143525.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51979, 3589, 'Aaahh!!! Monstros S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143526.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51980, 3589, 'Aaahh!!! Monstros S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143527.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51981, 3589, 'Aaahh!!! Monstros S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143528.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51982, 3589, 'Aaahh!!! Monstros S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143529.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51983, 3589, 'Aaahh!!! Monstros S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143530.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51984, 3589, 'Aaahh!!! Monstros S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143531.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51985, 3589, 'Aaahh!!! Monstros S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143532.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51986, 3589, 'Aaahh!!! Monstros S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143533.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51987, 3589, 'Aaahh!!! Monstros S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143534.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51988, 3589, 'Aaahh!!! Monstros S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143535.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51989, 3589, 'Aaahh!!! Monstros S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143536.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51990, 3590, 'Aaahh!!! Monstros S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143537.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51991, 3590, 'Aaahh!!! Monstros S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143538.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51992, 3590, 'Aaahh!!! Monstros S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143539.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51993, 3590, 'Aaahh!!! Monstros S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143540.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51994, 3590, 'Aaahh!!! Monstros S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143541.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51995, 3590, 'Aaahh!!! Monstros S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143542.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51996, 3590, 'Aaahh!!! Monstros S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143543.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51997, 3590, 'Aaahh!!! Monstros S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143544.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51998, 3590, 'Aaahh!!! Monstros S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143545.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(51999, 3590, 'Aaahh!!! Monstros S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143546.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(52000, 3590, 'Aaahh!!! Monstros S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143547.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(52001, 3590, 'Aaahh!!! Monstros S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143548.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(52002, 3590, 'Aaahh!!! Monstros S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143549.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(52003, 3591, 'Aaahh!!! Monstros S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143550.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(52004, 3591, 'Aaahh!!! Monstros S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143551.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(52005, 3591, 'Aaahh!!! Monstros S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143552.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(52006, 3591, 'Aaahh!!! Monstros S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143553.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(52007, 3591, 'Aaahh!!! Monstros S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143554.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(52008, 3591, 'Aaahh!!! Monstros S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143555.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(52009, 3591, 'Aaahh!!! Monstros S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143556.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(52010, 3591, 'Aaahh!!! Monstros S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143557.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(52011, 3591, 'Aaahh!!! Monstros S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143558.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(52012, 3591, 'Aaahh!!! Monstros S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143559.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(52013, 3591, 'Aaahh!!! Monstros S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143560.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(52014, 3591, 'Aaahh!!! Monstros S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143561.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(52015, 3591, 'Aaahh!!! Monstros S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143562.mp4', 'http://gstaticontent.com/images/fnh1Mi108eNKayutKLSqesFgaRv_big.jpg'),
(52016, 3592, 'Crash Landing On You [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143495.mp4', 'http://gstaticontent.com/images/4qGJJR6RIEa6SDQ3jIMQk3AN9uv_big.jpg'),
(52017, 3592, 'Crash Landing On You [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143496.mp4', 'http://gstaticontent.com/images/4qGJJR6RIEa6SDQ3jIMQk3AN9uv_big.jpg'),
(52018, 3592, 'Crash Landing On You [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143497.mp4', 'http://gstaticontent.com/images/4qGJJR6RIEa6SDQ3jIMQk3AN9uv_big.jpg'),
(52019, 3592, 'Crash Landing On You [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143498.mp4', 'http://gstaticontent.com/images/4qGJJR6RIEa6SDQ3jIMQk3AN9uv_big.jpg'),
(52020, 3592, 'Crash Landing On You [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143499.mp4', 'http://gstaticontent.com/images/4qGJJR6RIEa6SDQ3jIMQk3AN9uv_big.jpg'),
(52021, 3592, 'Crash Landing On You [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143500.mp4', 'http://gstaticontent.com/images/4qGJJR6RIEa6SDQ3jIMQk3AN9uv_big.jpg'),
(52022, 3592, 'Crash Landing On You [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143501.mp4', 'http://gstaticontent.com/images/4qGJJR6RIEa6SDQ3jIMQk3AN9uv_big.jpg'),
(52023, 3592, 'Crash Landing On You [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143502.mp4', 'http://gstaticontent.com/images/4qGJJR6RIEa6SDQ3jIMQk3AN9uv_big.jpg'),
(52024, 3592, 'Crash Landing On You [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143503.mp4', 'http://gstaticontent.com/images/4qGJJR6RIEa6SDQ3jIMQk3AN9uv_big.jpg'),
(52025, 3592, 'Crash Landing On You [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143504.mp4', 'http://gstaticontent.com/images/4qGJJR6RIEa6SDQ3jIMQk3AN9uv_big.jpg'),
(52026, 3592, 'Crash Landing On You [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143505.mp4', 'http://gstaticontent.com/images/4qGJJR6RIEa6SDQ3jIMQk3AN9uv_big.jpg'),
(52027, 3592, 'Crash Landing On You [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143506.mp4', 'http://gstaticontent.com/images/4qGJJR6RIEa6SDQ3jIMQk3AN9uv_big.jpg'),
(52028, 3592, 'Crash Landing On You [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143507.mp4', 'http://gstaticontent.com/images/4qGJJR6RIEa6SDQ3jIMQk3AN9uv_big.jpg'),
(52029, 3592, 'Crash Landing On You [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143508.mp4', 'http://gstaticontent.com/images/4qGJJR6RIEa6SDQ3jIMQk3AN9uv_big.jpg'),
(52030, 3592, 'Crash Landing On You [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143509.mp4', 'http://gstaticontent.com/images/4qGJJR6RIEa6SDQ3jIMQk3AN9uv_big.jpg'),
(52031, 3592, 'Crash Landing On You [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143510.mp4', 'http://gstaticontent.com/images/4qGJJR6RIEa6SDQ3jIMQk3AN9uv_big.jpg'),
(52032, 3593, 'Something In The Rain [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143479.mp4', 'http://gstaticontent.com/images/tiYbWPfkJPbUOZpHbJXkwcKvRtO_big.jpg'),
(52033, 3593, 'Something In The Rain [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143480.mp4', 'http://gstaticontent.com/images/tiYbWPfkJPbUOZpHbJXkwcKvRtO_big.jpg'),
(52034, 3593, 'Something In The Rain [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143481.mp4', 'http://gstaticontent.com/images/tiYbWPfkJPbUOZpHbJXkwcKvRtO_big.jpg'),
(52035, 3593, 'Something In The Rain [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143482.mp4', 'http://gstaticontent.com/images/tiYbWPfkJPbUOZpHbJXkwcKvRtO_big.jpg'),
(52036, 3593, 'Something In The Rain [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143483.mp4', 'http://gstaticontent.com/images/tiYbWPfkJPbUOZpHbJXkwcKvRtO_big.jpg'),
(52037, 3593, 'Something In The Rain [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143484.mp4', 'http://gstaticontent.com/images/tiYbWPfkJPbUOZpHbJXkwcKvRtO_big.jpg'),
(52038, 3593, 'Something In The Rain [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143485.mp4', 'http://gstaticontent.com/images/tiYbWPfkJPbUOZpHbJXkwcKvRtO_big.jpg'),
(52039, 3593, 'Something In The Rain [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143486.mp4', 'http://gstaticontent.com/images/tiYbWPfkJPbUOZpHbJXkwcKvRtO_big.jpg'),
(52040, 3593, 'Something In The Rain [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143487.mp4', 'http://gstaticontent.com/images/tiYbWPfkJPbUOZpHbJXkwcKvRtO_big.jpg'),
(52041, 3593, 'Something In The Rain [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143488.mp4', 'http://gstaticontent.com/images/tiYbWPfkJPbUOZpHbJXkwcKvRtO_big.jpg'),
(52042, 3593, 'Something In The Rain [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143489.mp4', 'http://gstaticontent.com/images/tiYbWPfkJPbUOZpHbJXkwcKvRtO_big.jpg'),
(52043, 3593, 'Something In The Rain [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143490.mp4', 'http://gstaticontent.com/images/tiYbWPfkJPbUOZpHbJXkwcKvRtO_big.jpg'),
(52044, 3593, 'Something In The Rain [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143491.mp4', 'http://gstaticontent.com/images/tiYbWPfkJPbUOZpHbJXkwcKvRtO_big.jpg'),
(52045, 3593, 'Something In The Rain [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143492.mp4', 'http://gstaticontent.com/images/tiYbWPfkJPbUOZpHbJXkwcKvRtO_big.jpg'),
(52046, 3593, 'Something In The Rain [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143493.mp4', 'http://gstaticontent.com/images/tiYbWPfkJPbUOZpHbJXkwcKvRtO_big.jpg'),
(52047, 3593, 'Something In The Rain [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143494.mp4', 'http://gstaticontent.com/images/tiYbWPfkJPbUOZpHbJXkwcKvRtO_big.jpg'),
(52048, 3594, 'The King Eternal Monarch [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143463.mp4', 'http://gstaticontent.com/images/e4pg1vXbl0eKZULqGPItoo29wUF_big.jpg'),
(52049, 3594, 'The King Eternal Monarch [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143464.mp4', 'http://gstaticontent.com/images/e4pg1vXbl0eKZULqGPItoo29wUF_big.jpg'),
(52050, 3594, 'The King Eternal Monarch [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143465.mp4', 'http://gstaticontent.com/images/e4pg1vXbl0eKZULqGPItoo29wUF_big.jpg'),
(52051, 3594, 'The King Eternal Monarch [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143466.mp4', 'http://gstaticontent.com/images/e4pg1vXbl0eKZULqGPItoo29wUF_big.jpg'),
(52052, 3594, 'The King Eternal Monarch [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143467.mp4', 'http://gstaticontent.com/images/e4pg1vXbl0eKZULqGPItoo29wUF_big.jpg'),
(52053, 3594, 'The King Eternal Monarch [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143468.mp4', 'http://gstaticontent.com/images/e4pg1vXbl0eKZULqGPItoo29wUF_big.jpg'),
(52054, 3594, 'The King Eternal Monarch [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143469.mp4', 'http://gstaticontent.com/images/e4pg1vXbl0eKZULqGPItoo29wUF_big.jpg'),
(52055, 3594, 'The King Eternal Monarch [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143470.mp4', 'http://gstaticontent.com/images/e4pg1vXbl0eKZULqGPItoo29wUF_big.jpg'),
(52056, 3594, 'The King Eternal Monarch [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143471.mp4', 'http://gstaticontent.com/images/e4pg1vXbl0eKZULqGPItoo29wUF_big.jpg'),
(52057, 3594, 'The King Eternal Monarch [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143472.mp4', 'http://gstaticontent.com/images/e4pg1vXbl0eKZULqGPItoo29wUF_big.jpg'),
(52058, 3594, 'The King Eternal Monarch [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143473.mp4', 'http://gstaticontent.com/images/e4pg1vXbl0eKZULqGPItoo29wUF_big.jpg'),
(52059, 3594, 'The King Eternal Monarch [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143474.mp4', 'http://gstaticontent.com/images/e4pg1vXbl0eKZULqGPItoo29wUF_big.jpg'),
(52060, 3594, 'The King Eternal Monarch [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143475.mp4', 'http://gstaticontent.com/images/e4pg1vXbl0eKZULqGPItoo29wUF_big.jpg'),
(52061, 3594, 'The King Eternal Monarch [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143476.mp4', 'http://gstaticontent.com/images/e4pg1vXbl0eKZULqGPItoo29wUF_big.jpg'),
(52062, 3594, 'The King Eternal Monarch [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143477.mp4', 'http://gstaticontent.com/images/e4pg1vXbl0eKZULqGPItoo29wUF_big.jpg'),
(52063, 3594, 'The King Eternal Monarch [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143478.mp4', 'http://gstaticontent.com/images/e4pg1vXbl0eKZULqGPItoo29wUF_big.jpg'),
(52064, 3595, 'When The Camellia Blooms [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143443.mp4', 'http://gstaticontent.com/images/q4nZ8lRaFTEg30pVLmBloGVU9zV_big.jpg'),
(52065, 3595, 'When The Camellia Blooms [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143444.mp4', 'http://gstaticontent.com/images/q4nZ8lRaFTEg30pVLmBloGVU9zV_big.jpg'),
(52066, 3595, 'When The Camellia Blooms [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143445.mp4', 'http://gstaticontent.com/images/q4nZ8lRaFTEg30pVLmBloGVU9zV_big.jpg'),
(52067, 3595, 'When The Camellia Blooms [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143446.mp4', 'http://gstaticontent.com/images/q4nZ8lRaFTEg30pVLmBloGVU9zV_big.jpg'),
(52068, 3595, 'When The Camellia Blooms [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143447.mp4', 'http://gstaticontent.com/images/q4nZ8lRaFTEg30pVLmBloGVU9zV_big.jpg'),
(52069, 3595, 'When The Camellia Blooms [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143448.mp4', 'http://gstaticontent.com/images/q4nZ8lRaFTEg30pVLmBloGVU9zV_big.jpg'),
(52070, 3595, 'When The Camellia Blooms [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143449.mp4', 'http://gstaticontent.com/images/q4nZ8lRaFTEg30pVLmBloGVU9zV_big.jpg'),
(52071, 3595, 'When The Camellia Blooms [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143450.mp4', 'http://gstaticontent.com/images/q4nZ8lRaFTEg30pVLmBloGVU9zV_big.jpg'),
(52072, 3595, 'When The Camellia Blooms [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143451.mp4', 'http://gstaticontent.com/images/q4nZ8lRaFTEg30pVLmBloGVU9zV_big.jpg'),
(52073, 3595, 'When The Camellia Blooms [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143452.mp4', 'http://gstaticontent.com/images/q4nZ8lRaFTEg30pVLmBloGVU9zV_big.jpg'),
(52074, 3595, 'When The Camellia Blooms [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143453.mp4', 'http://gstaticontent.com/images/q4nZ8lRaFTEg30pVLmBloGVU9zV_big.jpg'),
(52075, 3595, 'When The Camellia Blooms [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143454.mp4', 'http://gstaticontent.com/images/q4nZ8lRaFTEg30pVLmBloGVU9zV_big.jpg'),
(52076, 3595, 'When The Camellia Blooms [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143455.mp4', 'http://gstaticontent.com/images/q4nZ8lRaFTEg30pVLmBloGVU9zV_big.jpg'),
(52077, 3595, 'When The Camellia Blooms [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143456.mp4', 'http://gstaticontent.com/images/q4nZ8lRaFTEg30pVLmBloGVU9zV_big.jpg'),
(52078, 3595, 'When The Camellia Blooms [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143457.mp4', 'http://gstaticontent.com/images/q4nZ8lRaFTEg30pVLmBloGVU9zV_big.jpg'),
(52079, 3595, 'When The Camellia Blooms [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143458.mp4', 'http://gstaticontent.com/images/q4nZ8lRaFTEg30pVLmBloGVU9zV_big.jpg'),
(52080, 3595, 'When The Camellia Blooms [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/143459.mp4', 'http://gstaticontent.com/images/q4nZ8lRaFTEg30pVLmBloGVU9zV_big.jpg'),
(52081, 3595, 'When The Camellia Blooms [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/143460.mp4', 'http://gstaticontent.com/images/q4nZ8lRaFTEg30pVLmBloGVU9zV_big.jpg'),
(52082, 3595, 'When The Camellia Blooms [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/143461.mp4', 'http://gstaticontent.com/images/q4nZ8lRaFTEg30pVLmBloGVU9zV_big.jpg'),
(52083, 3595, 'When The Camellia Blooms [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/143462.mp4', 'http://gstaticontent.com/images/q4nZ8lRaFTEg30pVLmBloGVU9zV_big.jpg'),
(52084, 3596, 'O Legado de Júpiter S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143430.mp4', 'http://gstaticontent.com/images/1RFKW55GHQShX07TdXFHvGFjZKI_big.jpg'),
(52085, 3596, 'O Legado de Júpiter S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143431.mp4', 'http://gstaticontent.com/images/1RFKW55GHQShX07TdXFHvGFjZKI_big.jpg'),
(52086, 3596, 'O Legado de Júpiter S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143432.mp4', 'http://gstaticontent.com/images/1RFKW55GHQShX07TdXFHvGFjZKI_big.jpg'),
(52087, 3596, 'O Legado de Júpiter S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143433.mp4', 'http://gstaticontent.com/images/1RFKW55GHQShX07TdXFHvGFjZKI_big.jpg'),
(52088, 3596, 'O Legado de Júpiter S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143434.mp4', 'http://gstaticontent.com/images/1RFKW55GHQShX07TdXFHvGFjZKI_big.jpg'),
(52089, 3596, 'O Legado de Júpiter S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143435.mp4', 'http://gstaticontent.com/images/1RFKW55GHQShX07TdXFHvGFjZKI_big.jpg'),
(52090, 3596, 'O Legado de Júpiter S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143436.mp4', 'http://gstaticontent.com/images/1RFKW55GHQShX07TdXFHvGFjZKI_big.jpg'),
(52091, 3596, 'O Legado de Júpiter S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143437.mp4', 'http://gstaticontent.com/images/1RFKW55GHQShX07TdXFHvGFjZKI_big.jpg'),
(52092, 3597, 'Lendas da Marvel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200906.mp4', 'http://timg.bdta.pro/images/f0eb106b931ae2c8717b1da084e2306f.jpg'),
(52093, 3597, 'Lendas da Marvel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200907.mp4', 'http://timg.bdta.pro/images/ac3eb9cf99d0515928db522488791f08.jpg'),
(52094, 3597, 'Lendas da Marvel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200908.mp4', 'http://timg.bdta.pro/images/448532310a231a1ffc03ad48d48fa3c1.jpg'),
(52095, 3597, 'Lendas da Marvel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200909.mp4', 'http://timg.bdta.pro/images/b37681184b404280b98ae5cf9dd1a97e.jpg'),
(52096, 3597, 'Lendas da Marvel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200910.mp4', 'http://timg.bdta.pro/images/0680d8397654f33db722ece5f9cf3f91.jpg'),
(52097, 3597, 'Lendas da Marvel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200911.mp4', 'http://timg.bdta.pro/images/51f6176da67dc21a9600fd74ad1d0dd0.jpg'),
(52098, 3597, 'Lendas da Marvel S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200912.mp4', 'http://timg.bdta.pro/images/4d42c4904581fd4d4dbdd3bdd6ec7c52.jpg'),
(52099, 3597, 'Lendas da Marvel S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200913.mp4', 'http://timg.bdta.pro/images/ffe6a856b63d5517d9bba57e4f1559c5.jpg'),
(52100, 3597, 'Lendas da Marvel S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200914.mp4', 'http://timg.bdta.pro/images/b79c61d7c0cef67595fe65bddc95d7d6.jpg'),
(52101, 3597, 'Lendas da Marvel S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200915.mp4', 'http://timg.bdta.pro/images/1271dddd05ce6fe9c0e81f75c7b895cb.jpg'),
(52102, 3597, 'Lendas da Marvel S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200916.mp4', 'http://timg.bdta.pro/images/2b570ef117938dfd2f219fcf640d58d8.jpg'),
(52103, 3597, 'Lendas da Marvel S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200917.mp4', 'http://timg.bdta.pro/images/dd0a4b08929ac7b4d7bd9a5ad0be2254.jpg'),
(52104, 3597, 'Lendas da Marvel S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200918.mp4', 'http://timg.bdta.pro/images/5ff154d8ab0d91b0ceffe3b005a76658.jpg'),
(52105, 3597, 'Lendas da Marvel S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/200919.mp4', 'http://image.tmdb.org/t/p/w1280/qdfT222SZEI7zLotSshmTk8W6di.jpg'),
(52106, 3597, 'Lendas da Marvel S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/200920.mp4', 'http://timg.bdta.pro/images/2f242eda10187937c3d0994b46b37e5b.jpg'),
(52107, 3597, 'Lendas da Marvel S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/200921.mp4', 'http://timg.bdta.pro/images/acd3988f1003170835daba257f6103cf.jpg'),
(52108, 3597, 'Lendas da Marvel S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/200922.mp4', 'http://timg.bdta.pro/images/8363936d609955b685f1b439ad3f81c7.jpg'),
(52109, 3597, 'Lendas da Marvel S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/200923.mp4', 'http://timg.bdta.pro/images/f8c713234d9fc45c884e82deb13b894f.jpg'),
(52110, 3597, 'Lendas da Marvel S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/200924.mp4', 'http://timg.bdta.pro/images/1a25f1f81c7db3028f2a202eca93ecf1.jpg'),
(52111, 3597, 'Lendas da Marvel S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/200925.mp4', 'http://timg.bdta.pro/images/2262873514473e181381f8889768545d.jpg'),
(52112, 3597, 'Lendas da Marvel S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/200926.mp4', 'http://timg.bdta.pro/images/3d97ced353d73c5ce06e319f86ef1246.jpg'),
(52113, 3597, 'Lendas da Marvel S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/200927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aOgJEsJmS9cMS17WFtbBxAbveGn.jpg'),
(52114, 3597, 'Lendas da Marvel S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/200928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mc37erxiCnHvxnZbDCr0SChgRbr.jpg'),
(52115, 3597, 'Lendas da Marvel S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/200929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hk1QEQtv43aFIvitmgfbKG2kJLd.jpg'),
(52116, 3598, 'The Girlfriend Experience S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152139.mp4', 'http://timg.bdta.pro/images/4e1b8a4307e7a67ff611a8231075a6df.jpg'),
(52117, 3598, 'The Girlfriend Experience S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152140.mp4', 'http://timg.bdta.pro/images/92850be52484d46bdb09b3444ba38d02.jpg'),
(52118, 3598, 'The Girlfriend Experience S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152141.mp4', 'http://timg.bdta.pro/images/aef5748c5edd423eff6856173c209375.jpg'),
(52119, 3598, 'The Girlfriend Experience S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152142.mp4', 'http://timg.bdta.pro/images/97941355ae12812c5d2875e962209152.jpg'),
(52120, 3598, 'The Girlfriend Experience S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152143.mp4', 'http://timg.bdta.pro/images/98da459fcbc69ce4369ef1c3eaf85ace.jpg'),
(52121, 3598, 'The Girlfriend Experience S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152144.mp4', 'http://timg.bdta.pro/images/603f92c39d2058a9ccd621cc2087cc07.jpg'),
(52122, 3598, 'The Girlfriend Experience S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152145.mp4', 'http://timg.bdta.pro/images/67d1c19a2b51796428010f64d25c9ffe.jpg'),
(52123, 3598, 'The Girlfriend Experience S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152146.mp4', 'http://timg.bdta.pro/images/67a533528406abcafa7883d022cf08a7.jpg'),
(52124, 3598, 'The Girlfriend Experience S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152147.mp4', 'http://timg.bdta.pro/images/4f1a007808918a0bd8513f02a1113980.jpg'),
(52125, 3598, 'The Girlfriend Experience S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152148.mp4', 'http://timg.bdta.pro/images/2c11e58ea5e52dd26cb7abe55b198a67.jpg'),
(52126, 3598, 'The Girlfriend Experience S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152149.mp4', 'http://timg.bdta.pro/images/284a5756af1b332b5195cf9988827749.jpg'),
(52127, 3598, 'The Girlfriend Experience S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152150.mp4', 'http://timg.bdta.pro/images/c3a38e2aa4e727635cf333c37a41150a.jpg'),
(52128, 3598, 'The Girlfriend Experience S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152151.mp4', 'http://timg.bdta.pro/images/b454328071b31e0174c52a85ccc816af.jpg'),
(52129, 3599, 'The Girlfriend Experience S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152152.mp4', 'http://timg.bdta.pro/images/c75dab167df3422bd46a7a958cb2bb98.jpg'),
(52130, 3599, 'The Girlfriend Experience S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152153.mp4', 'http://timg.bdta.pro/images/7c8365e56e834743c12402e1032ddd04.jpg'),
(52131, 3599, 'The Girlfriend Experience S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152154.mp4', 'http://timg.bdta.pro/images/904deb51dd2c7f730de83d107327a313.jpg'),
(52132, 3599, 'The Girlfriend Experience S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152155.mp4', 'http://timg.bdta.pro/images/7bf4aa367f0aa6480b91417d90c8b762.jpg'),
(52133, 3599, 'The Girlfriend Experience S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152156.mp4', 'http://timg.bdta.pro/images/f472803c31f429ef9f2a20dac9ee7d79.jpg'),
(52134, 3599, 'The Girlfriend Experience S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152157.mp4', 'http://timg.bdta.pro/images/9fa2648e9e793e6e4a60710eb0dfbb2c.jpg'),
(52135, 3599, 'The Girlfriend Experience S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152158.mp4', 'http://timg.bdta.pro/images/d7b6c1cfc471b2bb0ea1fb10bc0621bd.jpg'),
(52136, 3599, 'The Girlfriend Experience S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152159.mp4', 'http://timg.bdta.pro/images/1bda660b5f7f05af2a5b6a657cce45ab.jpg'),
(52137, 3599, 'The Girlfriend Experience S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152160.mp4', 'http://timg.bdta.pro/images/8c358672a51f0ab7f567117f5b4f25e6.jpg'),
(52138, 3599, 'The Girlfriend Experience S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152161.mp4', 'http://timg.bdta.pro/images/33edc08e60970995c3c18c3961252af5.jpg'),
(52139, 3599, 'The Girlfriend Experience S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152162.mp4', 'http://timg.bdta.pro/images/c94eedd46c4d891f0b646eb3279cb0fc.jpg'),
(52140, 3599, 'The Girlfriend Experience S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152163.mp4', 'http://timg.bdta.pro/images/39b05ecbe29c65f5fd529f15c552fae9.jpg'),
(52141, 3599, 'The Girlfriend Experience S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152164.mp4', 'http://timg.bdta.pro/images/974f714daad692a2a9024f26e3f40a5f.jpg'),
(52142, 3599, 'The Girlfriend Experience S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152165.mp4', 'http://timg.bdta.pro/images/19d592df8c1056b2fa74354ea78a1c04.jpg'),
(52143, 3600, 'The Girlfriend Experience S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152166.mp4', 'http://timg.bdta.pro/images/7367c34ad3dbdfc4e4f23c74ecc46fee.jpg'),
(52144, 3600, 'The Girlfriend Experience S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152167.mp4', 'http://timg.bdta.pro/images/c41a055c70be7cb95e6f99af30d0b83a.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(52145, 3600, 'The Girlfriend Experience S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152168.mp4', 'http://timg.bdta.pro/images/b3e9dcce26d82fd8d238999bce6e19d7.jpg'),
(52146, 3600, 'The Girlfriend Experience S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152169.mp4', 'http://timg.bdta.pro/images/a39983dd0114bfc4aff6c96b57a5b50d.jpg'),
(52147, 3600, 'The Girlfriend Experience S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152170.mp4', 'http://timg.bdta.pro/images/c11f58c8079032d47fdf9acb5c12b47e.jpg'),
(52148, 3600, 'The Girlfriend Experience S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152171.mp4', 'http://timg.bdta.pro/images/38287c9cc6514df20557311102ae30ca.jpg'),
(52149, 3600, 'The Girlfriend Experience S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152172.mp4', 'http://timg.bdta.pro/images/f571d40e0fe28d584900c3a8b18d6a12.jpg'),
(52150, 3600, 'The Girlfriend Experience S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152173.mp4', 'http://timg.bdta.pro/images/079700fe4299820ea77c31f5a51c79a5.jpg'),
(52151, 3600, 'The Girlfriend Experience S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152174.mp4', 'http://timg.bdta.pro/images/fa31f82cbe2333909aed40e78777aac1.jpg'),
(52152, 3600, 'The Girlfriend Experience S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152175.mp4', 'http://timg.bdta.pro/images/2736298a6d9436109711c40de244c265.jpg'),
(52153, 3601, 'Dani Se S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164006.mp4', 'https://i.bj-share.info/8a4d00eb30eadf06bf1cb2c297dc3ba4.jpg'),
(52154, 3601, 'Dani Se S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164007.mp4', 'https://i.bj-share.info/8a4d00eb30eadf06bf1cb2c297dc3ba4.jpg'),
(52155, 3601, 'Dani Se S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164008.mp4', 'https://i.bj-share.info/8a4d00eb30eadf06bf1cb2c297dc3ba4.jpg'),
(52156, 3601, 'Dani Se S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164009.mp4', 'https://i.bj-share.info/8a4d00eb30eadf06bf1cb2c297dc3ba4.jpg'),
(52157, 3601, 'Dani Se S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164010.mp4', 'https://i.bj-share.info/8a4d00eb30eadf06bf1cb2c297dc3ba4.jpg'),
(52158, 3601, 'Dani Se S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164011.mp4', 'https://i.bj-share.info/8a4d00eb30eadf06bf1cb2c297dc3ba4.jpg'),
(52159, 3601, 'Dani Se S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164012.mp4', 'https://i.bj-share.info/8a4d00eb30eadf06bf1cb2c297dc3ba4.jpg'),
(52160, 3601, 'Dani Se S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164013.mp4', 'https://i.bj-share.info/8a4d00eb30eadf06bf1cb2c297dc3ba4.jpg'),
(52161, 3601, 'Dani Se S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164014.mp4', 'https://i.bj-share.info/8a4d00eb30eadf06bf1cb2c297dc3ba4.jpg'),
(52162, 3601, 'Dani Se S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164015.mp4', 'https://i.bj-share.info/8a4d00eb30eadf06bf1cb2c297dc3ba4.jpg'),
(52163, 3602, 'Dani Se S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164016.mp4', 'https://i.bj-share.info/8a4d00eb30eadf06bf1cb2c297dc3ba4.jpg'),
(52164, 3602, 'Dani Se S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164017.mp4', 'https://i.bj-share.info/8a4d00eb30eadf06bf1cb2c297dc3ba4.jpg'),
(52165, 3602, 'Dani Se S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164018.mp4', 'https://i.bj-share.info/8a4d00eb30eadf06bf1cb2c297dc3ba4.jpg'),
(52166, 3602, 'Dani Se S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164019.mp4', 'https://i.bj-share.info/8a4d00eb30eadf06bf1cb2c297dc3ba4.jpg'),
(52167, 3602, 'Dani Se S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164020.mp4', 'https://i.bj-share.info/8a4d00eb30eadf06bf1cb2c297dc3ba4.jpg'),
(52168, 3602, 'Dani Se S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164021.mp4', 'https://i.bj-share.info/8a4d00eb30eadf06bf1cb2c297dc3ba4.jpg'),
(52169, 3602, 'Dani Se S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164022.mp4', 'https://i.bj-share.info/8a4d00eb30eadf06bf1cb2c297dc3ba4.jpg'),
(52170, 3602, 'Dani Se S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164023.mp4', 'https://i.bj-share.info/8a4d00eb30eadf06bf1cb2c297dc3ba4.jpg'),
(52171, 3602, 'Dani Se S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164024.mp4', 'https://i.bj-share.info/8a4d00eb30eadf06bf1cb2c297dc3ba4.jpg'),
(52172, 3602, 'Dani Se S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164025.mp4', 'https://i.bj-share.info/8a4d00eb30eadf06bf1cb2c297dc3ba4.jpg'),
(52173, 3603, 'As Aventuras de Merlin S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143365.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52174, 3603, 'As Aventuras de Merlin S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143366.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52175, 3603, 'As Aventuras de Merlin S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143367.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52176, 3603, 'As Aventuras de Merlin S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143368.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52177, 3603, 'As Aventuras de Merlin S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143369.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52178, 3603, 'As Aventuras de Merlin S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143370.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52179, 3603, 'As Aventuras de Merlin S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143371.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52180, 3603, 'As Aventuras de Merlin S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143372.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52181, 3603, 'As Aventuras de Merlin S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143373.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52182, 3603, 'As Aventuras de Merlin S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143374.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52183, 3603, 'As Aventuras de Merlin S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143375.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52184, 3603, 'As Aventuras de Merlin S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143376.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52185, 3603, 'As Aventuras de Merlin S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143377.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52186, 3604, 'As Aventuras de Merlin S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143378.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52187, 3604, 'As Aventuras de Merlin S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143379.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52188, 3604, 'As Aventuras de Merlin S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143380.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52189, 3604, 'As Aventuras de Merlin S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143381.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52190, 3604, 'As Aventuras de Merlin S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143382.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52191, 3604, 'As Aventuras de Merlin S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143383.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52192, 3604, 'As Aventuras de Merlin S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143384.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52193, 3604, 'As Aventuras de Merlin S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143385.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52194, 3604, 'As Aventuras de Merlin S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143386.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52195, 3604, 'As Aventuras de Merlin S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143387.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52196, 3604, 'As Aventuras de Merlin S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143388.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52197, 3604, 'As Aventuras de Merlin S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143389.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52198, 3604, 'As Aventuras de Merlin S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143390.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52199, 3605, 'As Aventuras de Merlin S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143391.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52200, 3605, 'As Aventuras de Merlin S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143392.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52201, 3605, 'As Aventuras de Merlin S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143393.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52202, 3605, 'As Aventuras de Merlin S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143394.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52203, 3605, 'As Aventuras de Merlin S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143395.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52204, 3605, 'As Aventuras de Merlin S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143396.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52205, 3605, 'As Aventuras de Merlin S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143397.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52206, 3605, 'As Aventuras de Merlin S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143398.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52207, 3605, 'As Aventuras de Merlin S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143399.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52208, 3605, 'As Aventuras de Merlin S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143400.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52209, 3605, 'As Aventuras de Merlin S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143401.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52210, 3605, 'As Aventuras de Merlin S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143402.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52211, 3605, 'As Aventuras de Merlin S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143403.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52212, 3606, 'As Aventuras de Merlin S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143404.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52213, 3606, 'As Aventuras de Merlin S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143405.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52214, 3606, 'As Aventuras de Merlin S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143406.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52215, 3606, 'As Aventuras de Merlin S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143407.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52216, 3606, 'As Aventuras de Merlin S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143408.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52217, 3606, 'As Aventuras de Merlin S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143409.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52218, 3606, 'As Aventuras de Merlin S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143410.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52219, 3606, 'As Aventuras de Merlin S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143411.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52220, 3606, 'As Aventuras de Merlin S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143412.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52221, 3606, 'As Aventuras de Merlin S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143413.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52222, 3606, 'As Aventuras de Merlin S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143414.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52223, 3606, 'As Aventuras de Merlin S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143415.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52224, 3606, 'As Aventuras de Merlin S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143416.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52225, 3607, 'As Aventuras de Merlin S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143417.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52226, 3607, 'As Aventuras de Merlin S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143418.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52227, 3607, 'As Aventuras de Merlin S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143419.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52228, 3607, 'As Aventuras de Merlin S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143420.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52229, 3607, 'As Aventuras de Merlin S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143421.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52230, 3607, 'As Aventuras de Merlin S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143422.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52231, 3607, 'As Aventuras de Merlin S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143423.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52232, 3607, 'As Aventuras de Merlin S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143424.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52233, 3607, 'As Aventuras de Merlin S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143425.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52234, 3607, 'As Aventuras de Merlin S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143426.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52235, 3607, 'As Aventuras de Merlin S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143427.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52236, 3607, 'As Aventuras de Merlin S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143428.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52237, 3607, 'As Aventuras de Merlin S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143429.mp4', 'http://gstaticontent.com/images/tZJqE7mIr6OsHbu0UEHbTbNDwro_big.jpg'),
(52238, 3608, 'Acesso Total Corinthians S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143204.mp4', 'https://cdn.mitvstatic.com/programs/br_documentary-acesso-total-corinthians_p_m.jpg'),
(52239, 3608, 'Acesso Total Corinthians S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143205.mp4', 'https://cdn.mitvstatic.com/programs/br_documentary-acesso-total-corinthians_p_m.jpg'),
(52240, 3608, 'Acesso Total Corinthians S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143206.mp4', 'https://cdn.mitvstatic.com/programs/br_documentary-acesso-total-corinthians_p_m.jpg'),
(52241, 3608, 'Acesso Total Corinthians S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143207.mp4', 'https://cdn.mitvstatic.com/programs/br_documentary-acesso-total-corinthians_p_m.jpg'),
(52242, 3608, 'Acesso Total Corinthians S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143208.mp4', 'https://cdn.mitvstatic.com/programs/br_documentary-acesso-total-corinthians_p_m.jpg'),
(52243, 3609, 'De Volta Aos Anos 70 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142926.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52244, 3609, 'De Volta Aos Anos 70 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142927.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52245, 3609, 'De Volta Aos Anos 70 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142928.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52246, 3609, 'De Volta Aos Anos 70 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142929.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52247, 3609, 'De Volta Aos Anos 70 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142930.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52248, 3609, 'De Volta Aos Anos 70 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142931.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52249, 3609, 'De Volta Aos Anos 70 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142932.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52250, 3609, 'De Volta Aos Anos 70 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142933.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52251, 3609, 'De Volta Aos Anos 70 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142934.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52252, 3609, 'De Volta Aos Anos 70 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142935.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52253, 3609, 'De Volta Aos Anos 70 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142936.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52254, 3609, 'De Volta Aos Anos 70 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142937.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52255, 3609, 'De Volta Aos Anos 70 S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142938.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52256, 3609, 'De Volta Aos Anos 70 S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/142939.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52257, 3609, 'De Volta Aos Anos 70 S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142940.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52258, 3609, 'De Volta Aos Anos 70 S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/142941.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52259, 3609, 'De Volta Aos Anos 70 S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/142942.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52260, 3609, 'De Volta Aos Anos 70 S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/142943.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52261, 3609, 'De Volta Aos Anos 70 S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/142944.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52262, 3609, 'De Volta Aos Anos 70 S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/142945.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52263, 3609, 'De Volta Aos Anos 70 S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/142946.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52264, 3609, 'De Volta Aos Anos 70 S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/142947.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52265, 3609, 'De Volta Aos Anos 70 S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/142948.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52266, 3609, 'De Volta Aos Anos 70 S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/142949.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52267, 3609, 'De Volta Aos Anos 70 S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/142950.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52268, 3610, 'De Volta Aos Anos 70 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142951.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52269, 3610, 'De Volta Aos Anos 70 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142952.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52270, 3610, 'De Volta Aos Anos 70 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142953.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52271, 3610, 'De Volta Aos Anos 70 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142954.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52272, 3610, 'De Volta Aos Anos 70 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142955.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52273, 3610, 'De Volta Aos Anos 70 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142956.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52274, 3610, 'De Volta Aos Anos 70 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142957.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52275, 3610, 'De Volta Aos Anos 70 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142958.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52276, 3610, 'De Volta Aos Anos 70 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142959.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52277, 3610, 'De Volta Aos Anos 70 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142960.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52278, 3610, 'De Volta Aos Anos 70 S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142961.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52279, 3610, 'De Volta Aos Anos 70 S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142962.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52280, 3610, 'De Volta Aos Anos 70 S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142963.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52281, 3610, 'De Volta Aos Anos 70 S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/142964.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52282, 3610, 'De Volta Aos Anos 70 S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142965.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52283, 3610, 'De Volta Aos Anos 70 S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/142966.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52284, 3610, 'De Volta Aos Anos 70 S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/142967.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52285, 3610, 'De Volta Aos Anos 70 S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/142968.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52286, 3610, 'De Volta Aos Anos 70 S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/142969.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52287, 3610, 'De Volta Aos Anos 70 S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/142970.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52288, 3610, 'De Volta Aos Anos 70 S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/142971.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52289, 3610, 'De Volta Aos Anos 70 S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/142972.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52290, 3610, 'De Volta Aos Anos 70 S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/142973.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52291, 3610, 'De Volta Aos Anos 70 S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/142974.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52292, 3610, 'De Volta Aos Anos 70 S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/142975.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52293, 3610, 'De Volta Aos Anos 70 S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/142976.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52294, 3611, 'De Volta Aos Anos 70 S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142977.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52295, 3611, 'De Volta Aos Anos 70 S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142978.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52296, 3611, 'De Volta Aos Anos 70 S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142979.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52297, 3611, 'De Volta Aos Anos 70 S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142980.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52298, 3611, 'De Volta Aos Anos 70 S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142981.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52299, 3611, 'De Volta Aos Anos 70 S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142982.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52300, 3611, 'De Volta Aos Anos 70 S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142983.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52301, 3611, 'De Volta Aos Anos 70 S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142984.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52302, 3611, 'De Volta Aos Anos 70 S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142985.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52303, 3611, 'De Volta Aos Anos 70 S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142986.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52304, 3611, 'De Volta Aos Anos 70 S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142987.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52305, 3611, 'De Volta Aos Anos 70 S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142988.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52306, 3611, 'De Volta Aos Anos 70 S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142989.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52307, 3611, 'De Volta Aos Anos 70 S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/142990.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52308, 3611, 'De Volta Aos Anos 70 S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142991.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52309, 3611, 'De Volta Aos Anos 70 S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/142992.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52310, 3611, 'De Volta Aos Anos 70 S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/142993.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52311, 3611, 'De Volta Aos Anos 70 S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/142994.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52312, 3611, 'De Volta Aos Anos 70 S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/142995.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52313, 3611, 'De Volta Aos Anos 70 S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/142996.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52314, 3611, 'De Volta Aos Anos 70 S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/142997.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52315, 3611, 'De Volta Aos Anos 70 S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/142998.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52316, 3611, 'De Volta Aos Anos 70 S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/142999.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52317, 3611, 'De Volta Aos Anos 70 S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/143000.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52318, 3611, 'De Volta Aos Anos 70 S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/143001.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52319, 3612, 'De Volta Aos Anos 70 S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143002.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52320, 3612, 'De Volta Aos Anos 70 S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143003.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52321, 3612, 'De Volta Aos Anos 70 S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143004.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52322, 3612, 'De Volta Aos Anos 70 S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143005.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52323, 3612, 'De Volta Aos Anos 70 S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143006.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52324, 3612, 'De Volta Aos Anos 70 S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143007.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52325, 3612, 'De Volta Aos Anos 70 S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143008.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52326, 3612, 'De Volta Aos Anos 70 S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143009.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52327, 3612, 'De Volta Aos Anos 70 S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143010.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52328, 3612, 'De Volta Aos Anos 70 S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143011.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52329, 3612, 'De Volta Aos Anos 70 S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143012.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52330, 3612, 'De Volta Aos Anos 70 S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143013.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52331, 3612, 'De Volta Aos Anos 70 S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143014.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52332, 3612, 'De Volta Aos Anos 70 S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143015.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52333, 3612, 'De Volta Aos Anos 70 S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143016.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52334, 3612, 'De Volta Aos Anos 70 S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143017.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52335, 3612, 'De Volta Aos Anos 70 S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/143018.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52336, 3612, 'De Volta Aos Anos 70 S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/143019.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52337, 3612, 'De Volta Aos Anos 70 S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/143020.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52338, 3612, 'De Volta Aos Anos 70 S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/143021.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52339, 3612, 'De Volta Aos Anos 70 S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/143022.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52340, 3612, 'De Volta Aos Anos 70 S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/143023.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52341, 3612, 'De Volta Aos Anos 70 S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/143024.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52342, 3612, 'De Volta Aos Anos 70 S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/143025.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52343, 3612, 'De Volta Aos Anos 70 S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/143026.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52344, 3612, 'De Volta Aos Anos 70 S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/143027.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52345, 3612, 'De Volta Aos Anos 70 S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/143028.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52346, 3613, 'De Volta Aos Anos 70 S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143029.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52347, 3613, 'De Volta Aos Anos 70 S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143030.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52348, 3613, 'De Volta Aos Anos 70 S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143031.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52349, 3613, 'De Volta Aos Anos 70 S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143032.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52350, 3613, 'De Volta Aos Anos 70 S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143033.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52351, 3613, 'De Volta Aos Anos 70 S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143034.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52352, 3613, 'De Volta Aos Anos 70 S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143035.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52353, 3613, 'De Volta Aos Anos 70 S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143036.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52354, 3613, 'De Volta Aos Anos 70 S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143037.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52355, 3613, 'De Volta Aos Anos 70 S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143038.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52356, 3613, 'De Volta Aos Anos 70 S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143039.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52357, 3613, 'De Volta Aos Anos 70 S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143040.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52358, 3613, 'De Volta Aos Anos 70 S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143041.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52359, 3613, 'De Volta Aos Anos 70 S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143042.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52360, 3613, 'De Volta Aos Anos 70 S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143043.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52361, 3613, 'De Volta Aos Anos 70 S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143044.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52362, 3613, 'De Volta Aos Anos 70 S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/143045.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52363, 3613, 'De Volta Aos Anos 70 S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/143046.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52364, 3613, 'De Volta Aos Anos 70 S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/143047.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52365, 3613, 'De Volta Aos Anos 70 S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/143048.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52366, 3613, 'De Volta Aos Anos 70 S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/143049.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52367, 3613, 'De Volta Aos Anos 70 S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/143050.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52368, 3613, 'De Volta Aos Anos 70 S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/143051.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52369, 3613, 'De Volta Aos Anos 70 S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/143052.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52370, 3613, 'De Volta Aos Anos 70 S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/143053.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52371, 3614, 'De Volta Aos Anos 70 S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143054.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52372, 3614, 'De Volta Aos Anos 70 S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143055.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52373, 3614, 'De Volta Aos Anos 70 S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143056.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52374, 3614, 'De Volta Aos Anos 70 S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143057.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52375, 3614, 'De Volta Aos Anos 70 S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143058.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52376, 3614, 'De Volta Aos Anos 70 S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143059.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52377, 3614, 'De Volta Aos Anos 70 S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143060.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52378, 3614, 'De Volta Aos Anos 70 S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143061.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52379, 3614, 'De Volta Aos Anos 70 S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143062.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52380, 3614, 'De Volta Aos Anos 70 S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143063.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52381, 3614, 'De Volta Aos Anos 70 S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143064.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52382, 3614, 'De Volta Aos Anos 70 S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143065.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52383, 3614, 'De Volta Aos Anos 70 S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143066.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52384, 3614, 'De Volta Aos Anos 70 S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143067.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52385, 3614, 'De Volta Aos Anos 70 S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143068.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52386, 3614, 'De Volta Aos Anos 70 S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143069.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52387, 3614, 'De Volta Aos Anos 70 S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/143070.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52388, 3614, 'De Volta Aos Anos 70 S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/143071.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52389, 3614, 'De Volta Aos Anos 70 S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/143072.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52390, 3614, 'De Volta Aos Anos 70 S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/143073.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52391, 3614, 'De Volta Aos Anos 70 S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/143074.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52392, 3614, 'De Volta Aos Anos 70 S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/143075.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52393, 3614, 'De Volta Aos Anos 70 S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/143076.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52394, 3614, 'De Volta Aos Anos 70 S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/143077.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52395, 3614, 'De Volta Aos Anos 70 S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/143078.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52396, 3615, 'De Volta Aos Anos 70 S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143079.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52397, 3615, 'De Volta Aos Anos 70 S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143080.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52398, 3615, 'De Volta Aos Anos 70 S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143081.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52399, 3615, 'De Volta Aos Anos 70 S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143082.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52400, 3615, 'De Volta Aos Anos 70 S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143083.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52401, 3615, 'De Volta Aos Anos 70 S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143084.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52402, 3615, 'De Volta Aos Anos 70 S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143085.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52403, 3615, 'De Volta Aos Anos 70 S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143086.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52404, 3615, 'De Volta Aos Anos 70 S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143087.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52405, 3615, 'De Volta Aos Anos 70 S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143088.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52406, 3615, 'De Volta Aos Anos 70 S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143089.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52407, 3615, 'De Volta Aos Anos 70 S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143090.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52408, 3615, 'De Volta Aos Anos 70 S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143091.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52409, 3615, 'De Volta Aos Anos 70 S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143092.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52410, 3615, 'De Volta Aos Anos 70 S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143093.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52411, 3615, 'De Volta Aos Anos 70 S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143094.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52412, 3615, 'De Volta Aos Anos 70 S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/143095.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52413, 3615, 'De Volta Aos Anos 70 S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/143096.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52414, 3615, 'De Volta Aos Anos 70 S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/143097.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52415, 3615, 'De Volta Aos Anos 70 S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/143098.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52416, 3615, 'De Volta Aos Anos 70 S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/143099.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52417, 3615, 'De Volta Aos Anos 70 S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/143100.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52418, 3615, 'De Volta Aos Anos 70 S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/143101.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52419, 3615, 'De Volta Aos Anos 70 S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/143102.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52420, 3615, 'De Volta Aos Anos 70 S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/143103.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(52421, 3616, 'De Volta Aos Anos 70 S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/143104.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52422, 3616, 'De Volta Aos Anos 70 S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/143105.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52423, 3616, 'De Volta Aos Anos 70 S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/143106.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52424, 3616, 'De Volta Aos Anos 70 S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/143107.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52425, 3616, 'De Volta Aos Anos 70 S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/143108.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52426, 3616, 'De Volta Aos Anos 70 S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/143109.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52427, 3616, 'De Volta Aos Anos 70 S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/143110.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52428, 3616, 'De Volta Aos Anos 70 S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/143111.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52429, 3616, 'De Volta Aos Anos 70 S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/143112.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52430, 3616, 'De Volta Aos Anos 70 S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/143113.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52431, 3616, 'De Volta Aos Anos 70 S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/143114.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52432, 3616, 'De Volta Aos Anos 70 S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/143115.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52433, 3616, 'De Volta Aos Anos 70 S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/143116.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52434, 3616, 'De Volta Aos Anos 70 S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/143117.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52435, 3616, 'De Volta Aos Anos 70 S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/143118.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52436, 3616, 'De Volta Aos Anos 70 S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/143119.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52437, 3616, 'De Volta Aos Anos 70 S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/143120.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52438, 3616, 'De Volta Aos Anos 70 S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/143121.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52439, 3616, 'De Volta Aos Anos 70 S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/143122.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52440, 3616, 'De Volta Aos Anos 70 S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/143123.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52441, 3616, 'De Volta Aos Anos 70 S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/143124.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52442, 3616, 'De Volta Aos Anos 70 S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/143125.mp4', 'http://gstaticontent.com/images/7Ei9tVnuHNELBLW3thfV3RndZl2_big.jpg'),
(52443, 3617, 'Phineas e Ferb S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142900.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52444, 3617, 'Phineas e Ferb S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142901.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52445, 3617, 'Phineas e Ferb S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142902.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52446, 3617, 'Phineas e Ferb S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142903.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52447, 3617, 'Phineas e Ferb S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142904.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52448, 3617, 'Phineas e Ferb S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142905.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52449, 3617, 'Phineas e Ferb S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142906.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52450, 3617, 'Phineas e Ferb S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142907.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52451, 3617, 'Phineas e Ferb S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142908.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52452, 3617, 'Phineas e Ferb S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142909.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52453, 3617, 'Phineas e Ferb S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142910.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52454, 3617, 'Phineas e Ferb S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142911.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52455, 3617, 'Phineas e Ferb S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142912.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52456, 3617, 'Phineas e Ferb S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/142913.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52457, 3617, 'Phineas e Ferb S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142914.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52458, 3617, 'Phineas e Ferb S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/142915.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52459, 3617, 'Phineas e Ferb S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/142916.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52460, 3617, 'Phineas e Ferb S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/142917.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52461, 3617, 'Phineas e Ferb S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/142918.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52462, 3617, 'Phineas e Ferb S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/142919.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52463, 3617, 'Phineas e Ferb S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/142920.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52464, 3617, 'Phineas e Ferb S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/142921.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52465, 3617, 'Phineas e Ferb S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/142922.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52466, 3617, 'Phineas e Ferb S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/142923.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52467, 3617, 'Phineas e Ferb S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/142924.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52468, 3617, 'Phineas e Ferb S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/142925.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52469, 3618, 'Phineas e Ferb S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/674788.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52470, 3618, 'Phineas e Ferb S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/674789.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52471, 3618, 'Phineas e Ferb S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/674790.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52472, 3618, 'Phineas e Ferb S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/674791.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52473, 3618, 'Phineas e Ferb S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/674792.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52474, 3618, 'Phineas e Ferb S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/674793.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52475, 3618, 'Phineas e Ferb S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/674794.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52476, 3618, 'Phineas e Ferb S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/674795.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52477, 3618, 'Phineas e Ferb S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/674796.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52478, 3618, 'Phineas e Ferb S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/674797.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52479, 3618, 'Phineas e Ferb S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/674798.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52480, 3618, 'Phineas e Ferb S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/674799.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52481, 3618, 'Phineas e Ferb S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/674800.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52482, 3618, 'Phineas e Ferb S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/674801.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52483, 3618, 'Phineas e Ferb S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/674802.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52484, 3618, 'Phineas e Ferb S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/674803.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52485, 3618, 'Phineas e Ferb S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/674804.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52486, 3618, 'Phineas e Ferb S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/674805.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52487, 3618, 'Phineas e Ferb S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/674806.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52488, 3618, 'Phineas e Ferb S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/674807.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52489, 3618, 'Phineas e Ferb S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/674808.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52490, 3618, 'Phineas e Ferb S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/674809.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52491, 3618, 'Phineas e Ferb S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/674810.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52492, 3618, 'Phineas e Ferb S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/674811.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52493, 3618, 'Phineas e Ferb S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/674812.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52494, 3618, 'Phineas e Ferb S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/674813.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52495, 3618, 'Phineas e Ferb S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/674814.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52496, 3618, 'Phineas e Ferb S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/674815.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52497, 3618, 'Phineas e Ferb S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/674816.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52498, 3618, 'Phineas e Ferb S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/674817.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52499, 3618, 'Phineas e Ferb S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/674818.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52500, 3618, 'Phineas e Ferb S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/674819.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52501, 3618, 'Phineas e Ferb S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/674820.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52502, 3618, 'Phineas e Ferb S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/674821.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52503, 3618, 'Phineas e Ferb S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/674822.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52504, 3618, 'Phineas e Ferb S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/674823.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52505, 3618, 'Phineas e Ferb S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/674824.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52506, 3618, 'Phineas e Ferb S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/674825.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52507, 3618, 'Phineas e Ferb S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/674826.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52508, 3619, 'Phineas e Ferb S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/674827.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52509, 3619, 'Phineas e Ferb S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/674828.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52510, 3619, 'Phineas e Ferb S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/674829.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52511, 3619, 'Phineas e Ferb S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/674830.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52512, 3619, 'Phineas e Ferb S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/674831.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52513, 3619, 'Phineas e Ferb S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/674832.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52514, 3619, 'Phineas e Ferb S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/674833.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52515, 3619, 'Phineas e Ferb S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/674834.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52516, 3619, 'Phineas e Ferb S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/674835.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52517, 3619, 'Phineas e Ferb S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/674836.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52518, 3619, 'Phineas e Ferb S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/674837.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52519, 3619, 'Phineas e Ferb S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/674838.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52520, 3619, 'Phineas e Ferb S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/674839.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52521, 3619, 'Phineas e Ferb S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/674840.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52522, 3619, 'Phineas e Ferb S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/674841.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52523, 3619, 'Phineas e Ferb S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/674842.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52524, 3619, 'Phineas e Ferb S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/674843.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52525, 3619, 'Phineas e Ferb S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/674844.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52526, 3619, 'Phineas e Ferb S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/674845.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52527, 3619, 'Phineas e Ferb S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/674846.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52528, 3619, 'Phineas e Ferb S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/674847.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52529, 3619, 'Phineas e Ferb S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/674848.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52530, 3619, 'Phineas e Ferb S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/674849.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52531, 3619, 'Phineas e Ferb S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/674850.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52532, 3619, 'Phineas e Ferb S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/674851.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52533, 3619, 'Phineas e Ferb S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/674852.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52534, 3619, 'Phineas e Ferb S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/674853.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52535, 3619, 'Phineas e Ferb S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/674854.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52536, 3619, 'Phineas e Ferb S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/674855.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52537, 3619, 'Phineas e Ferb S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/674856.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52538, 3619, 'Phineas e Ferb S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/674857.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52539, 3619, 'Phineas e Ferb S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/674858.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52540, 3619, 'Phineas e Ferb S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/674859.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52541, 3619, 'Phineas e Ferb S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/674860.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52542, 3619, 'Phineas e Ferb S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/674861.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52543, 3620, 'Phineas e Ferb S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/674862.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52544, 3620, 'Phineas e Ferb S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/674863.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52545, 3620, 'Phineas e Ferb S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/674864.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52546, 3620, 'Phineas e Ferb S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/674865.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52547, 3620, 'Phineas e Ferb S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/674866.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52548, 3620, 'Phineas e Ferb S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/674867.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52549, 3620, 'Phineas e Ferb S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/674868.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52550, 3620, 'Phineas e Ferb S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/674869.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52551, 3620, 'Phineas e Ferb S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/674870.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52552, 3620, 'Phineas e Ferb S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/674871.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52553, 3620, 'Phineas e Ferb S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/674872.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52554, 3620, 'Phineas e Ferb S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/674873.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52555, 3620, 'Phineas e Ferb S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/674874.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52556, 3620, 'Phineas e Ferb S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/674875.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52557, 3620, 'Phineas e Ferb S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/674876.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52558, 3620, 'Phineas e Ferb S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/674877.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52559, 3620, 'Phineas e Ferb S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/674878.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52560, 3620, 'Phineas e Ferb S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/674879.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52561, 3620, 'Phineas e Ferb S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/674880.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52562, 3620, 'Phineas e Ferb S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/674881.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52563, 3620, 'Phineas e Ferb S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/674882.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52564, 3620, 'Phineas e Ferb S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/674883.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52565, 3620, 'Phineas e Ferb S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/674884.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52566, 3620, 'Phineas e Ferb S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/674885.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52567, 3620, 'Phineas e Ferb S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/674886.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52568, 3620, 'Phineas e Ferb S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/674887.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52569, 3620, 'Phineas e Ferb S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/674888.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52570, 3620, 'Phineas e Ferb S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/674889.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52571, 3620, 'Phineas e Ferb S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/674890.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52572, 3620, 'Phineas e Ferb S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/674891.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52573, 3620, 'Phineas e Ferb S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/674892.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52574, 3620, 'Phineas e Ferb S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/674893.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52575, 3620, 'Phineas e Ferb S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/674894.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52576, 3620, 'Phineas e Ferb S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/674895.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52577, 3620, 'Phineas e Ferb S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/674896.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52578, 3620, 'Phineas e Ferb S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/674897.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52579, 3621, 'Phineas e Ferb S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/827270.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52580, 3621, 'Phineas e Ferb S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/827271.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52581, 3621, 'Phineas e Ferb S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/827272.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52582, 3621, 'Phineas e Ferb S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/835700.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52583, 3621, 'Phineas e Ferb S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/853349.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52584, 3621, 'Phineas e Ferb S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/853351.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52585, 3621, 'Phineas e Ferb S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/853352.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52586, 3621, 'Phineas e Ferb S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/874123.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52587, 3621, 'Phineas e Ferb S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/874124.mp4', 'http://gstaticontent.com/images/nXfACDDBNAuNNEpgytPMvxw3YFU_big.jpg'),
(52588, 3622, 'Salem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142864.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52589, 3622, 'Salem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142865.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52590, 3622, 'Salem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142866.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52591, 3622, 'Salem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142867.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52592, 3622, 'Salem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142868.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52593, 3622, 'Salem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142869.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52594, 3622, 'Salem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142870.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52595, 3622, 'Salem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142871.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52596, 3622, 'Salem S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142872.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52597, 3622, 'Salem S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142873.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52598, 3622, 'Salem S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142874.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52599, 3622, 'Salem S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142875.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52600, 3622, 'Salem S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142876.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52601, 3623, 'Salem S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142877.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52602, 3623, 'Salem S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142878.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52603, 3623, 'Salem S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142879.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52604, 3623, 'Salem S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142880.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52605, 3623, 'Salem S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142881.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52606, 3623, 'Salem S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142882.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52607, 3623, 'Salem S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142883.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52608, 3623, 'Salem S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142884.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52609, 3623, 'Salem S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142885.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52610, 3623, 'Salem S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142886.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52611, 3623, 'Salem S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142887.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52612, 3623, 'Salem S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142888.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52613, 3623, 'Salem S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142889.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52614, 3624, 'Salem S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142890.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52615, 3624, 'Salem S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142891.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52616, 3624, 'Salem S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142892.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52617, 3624, 'Salem S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142893.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52618, 3624, 'Salem S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142894.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52619, 3624, 'Salem S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142895.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52620, 3624, 'Salem S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142896.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52621, 3624, 'Salem S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142897.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52622, 3624, 'Salem S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142898.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52623, 3624, 'Salem S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142899.mp4', 'http://gstaticontent.com/images/nBSBXMKnu01H29vDrorTn3PR1zJ_big.jpg'),
(52624, 3625, 'Família Upshaw S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228649.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52625, 3625, 'Família Upshaw S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228650.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52626, 3625, 'Família Upshaw S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228651.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52627, 3625, 'Família Upshaw S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228652.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52628, 3625, 'Família Upshaw S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228653.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52629, 3625, 'Família Upshaw S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228654.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52630, 3625, 'Família Upshaw S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228655.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52631, 3625, 'Família Upshaw S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228656.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52632, 3625, 'Família Upshaw S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228657.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52633, 3625, 'Família Upshaw S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228658.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52634, 3626, 'Família Upshaw S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228659.mp4', 'http://timg.bdta.pro/images/2c597baae938556b764fb55b9017cb40.jpg'),
(52635, 3626, 'Família Upshaw S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228660.mp4', 'http://timg.bdta.pro/images/46d0713e035e8d2d2e8da5728de274f3.jpg'),
(52636, 3626, 'Família Upshaw S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228661.mp4', 'http://timg.bdta.pro/images/80ae197116b86202156843bd08e2ea51.jpg'),
(52637, 3626, 'Família Upshaw S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228662.mp4', 'http://timg.bdta.pro/images/bf393bad0902ebce4416641722d785ca.jpg'),
(52638, 3626, 'Família Upshaw S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228663.mp4', 'http://timg.bdta.pro/images/45abe6f7d352661622b0f2b737352ac3.jpg'),
(52639, 3626, 'Família Upshaw S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228664.mp4', 'http://timg.bdta.pro/images/f7804e76132ce0068cd2587aa2893d6f.jpg'),
(52640, 3626, 'Família Upshaw S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228665.mp4', 'http://timg.bdta.pro/images/5f7b2865fe04b4d9c201e220b2cfbd4b.jpg'),
(52641, 3626, 'Família Upshaw S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228666.mp4', 'http://timg.bdta.pro/images/0a6229bee924f203e6020d4397fb24e2.jpg'),
(52642, 3627, 'Família Upshaw S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/70EwzvY7R2ZXDkEKrzUqacc42Rv.jpg'),
(52643, 3627, 'Família Upshaw S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pTMtUTy9HvR04rezzB1wDldEyPE.jpg'),
(52644, 3627, 'Família Upshaw S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uERoxLxWu9zkES81WDDScpWrRT.jpg'),
(52645, 3627, 'Família Upshaw S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hRtrH4LmRnmYaZVKfl0mYK30oXY.jpg'),
(52646, 3627, 'Família Upshaw S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tPhJqtVtk35CGJCmq1LPGUoKNdL.jpg'),
(52647, 3627, 'Família Upshaw S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l1FwrDqYIHKgdi3qrXEVkAlsDSg.jpg'),
(52648, 3627, 'Família Upshaw S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8HRD290oeNmCw7yDdTsn2LSBOqh.jpg'),
(52649, 3627, 'Família Upshaw S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/roLxSzRUhczW1ZXGjmoeUf9rgYp.jpg'),
(52650, 3628, 'Família Upshaw S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tHxYQMmbRuR4aEGv0NZTCIh2kEq.jpg'),
(52651, 3628, 'Família Upshaw S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l2bRrkQYUpbCHY6yvLLh0bb3QT3.jpg'),
(52652, 3628, 'Família Upshaw S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/YUIjoovTY97QhGm9sI5Cq0omil.jpg'),
(52653, 3628, 'Família Upshaw S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l1pkl4dqAoxkqXcOY2B1eh8Tlh6.jpg'),
(52654, 3628, 'Família Upshaw S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/inxHIFhUFROGVq9e38t3N8LfYEP.jpg'),
(52655, 3628, 'Família Upshaw S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvPjNZNqfLqx1u5bhmFNy6GKigh.jpg'),
(52656, 3629, 'Família Upshaw S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664754.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52657, 3629, 'Família Upshaw S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664755.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52658, 3629, 'Família Upshaw S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664756.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52659, 3629, 'Família Upshaw S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/664757.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52660, 3629, 'Família Upshaw S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/664758.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52661, 3629, 'Família Upshaw S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/664759.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52662, 3630, 'Família Upshaw S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664760.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52663, 3630, 'Família Upshaw S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664761.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52664, 3630, 'Família Upshaw S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664762.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52665, 3630, 'Família Upshaw S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/664763.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52666, 3630, 'Família Upshaw S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/664764.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52667, 3630, 'Família Upshaw S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/664765.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52668, 3630, 'Família Upshaw S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/664766.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52669, 3630, 'Família Upshaw S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/664767.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52670, 3630, 'Família Upshaw S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/664768.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52671, 3630, 'Família Upshaw S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/664769.mp4', 'http://gstaticontent.com/images/bgtpwAsKNfqJmgp3zBxuSHMBAaW_big.jpg'),
(52672, 3631, 'Tainá e os Guardiões da Amazônia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142160.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52673, 3631, 'Tainá e os Guardiões da Amazônia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142161.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52674, 3631, 'Tainá e os Guardiões da Amazônia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142162.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52675, 3631, 'Tainá e os Guardiões da Amazônia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142163.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52676, 3631, 'Tainá e os Guardiões da Amazônia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142164.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52677, 3631, 'Tainá e os Guardiões da Amazônia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142165.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52678, 3631, 'Tainá e os Guardiões da Amazônia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142166.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52679, 3631, 'Tainá e os Guardiões da Amazônia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142167.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52680, 3631, 'Tainá e os Guardiões da Amazônia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142168.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52681, 3631, 'Tainá e os Guardiões da Amazônia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142169.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52682, 3631, 'Tainá e os Guardiões da Amazônia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142170.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52683, 3631, 'Tainá e os Guardiões da Amazônia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142171.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52684, 3631, 'Tainá e os Guardiões da Amazônia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142172.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52685, 3631, 'Tainá e os Guardiões da Amazônia S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/142173.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52686, 3631, 'Tainá e os Guardiões da Amazônia S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142174.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52687, 3631, 'Tainá e os Guardiões da Amazônia S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/142175.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52688, 3631, 'Tainá e os Guardiões da Amazônia S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/142176.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52689, 3631, 'Tainá e os Guardiões da Amazônia S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/142177.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52690, 3631, 'Tainá e os Guardiões da Amazônia S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/142178.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52691, 3631, 'Tainá e os Guardiões da Amazônia S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/142179.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52692, 3631, 'Tainá e os Guardiões da Amazônia S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/142180.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52693, 3631, 'Tainá e os Guardiões da Amazônia S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/142181.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52694, 3631, 'Tainá e os Guardiões da Amazônia S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/142182.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52695, 3631, 'Tainá e os Guardiões da Amazônia S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/142183.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52696, 3631, 'Tainá e os Guardiões da Amazônia S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/142184.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52697, 3631, 'Tainá e os Guardiões da Amazônia S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/142185.mp4', 'http://gstaticontent.com/images/yaS8O0lPxKA4l8YkvMWdRMVIgPd_big.jpg'),
(52698, 3632, 'Take Dois com Phineas e Ferb S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142150.mp4', 'http://gstaticontent.com/images/bx23xAiqdN8kLGt6HgUz4QW0p7Q_big.jpg'),
(52699, 3632, 'Take Dois com Phineas e Ferb S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142151.mp4', 'http://gstaticontent.com/images/bx23xAiqdN8kLGt6HgUz4QW0p7Q_big.jpg'),
(52700, 3632, 'Take Dois com Phineas e Ferb S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142152.mp4', 'http://gstaticontent.com/images/bx23xAiqdN8kLGt6HgUz4QW0p7Q_big.jpg'),
(52701, 3632, 'Take Dois com Phineas e Ferb S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142153.mp4', 'http://gstaticontent.com/images/bx23xAiqdN8kLGt6HgUz4QW0p7Q_big.jpg'),
(52702, 3632, 'Take Dois com Phineas e Ferb S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142154.mp4', 'http://gstaticontent.com/images/bx23xAiqdN8kLGt6HgUz4QW0p7Q_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(52703, 3632, 'Take Dois com Phineas e Ferb S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142155.mp4', 'http://gstaticontent.com/images/bx23xAiqdN8kLGt6HgUz4QW0p7Q_big.jpg'),
(52704, 3632, 'Take Dois com Phineas e Ferb S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142156.mp4', 'http://gstaticontent.com/images/bx23xAiqdN8kLGt6HgUz4QW0p7Q_big.jpg'),
(52705, 3632, 'Take Dois com Phineas e Ferb S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142157.mp4', 'http://gstaticontent.com/images/bx23xAiqdN8kLGt6HgUz4QW0p7Q_big.jpg'),
(52706, 3632, 'Take Dois com Phineas e Ferb S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142158.mp4', 'http://gstaticontent.com/images/bx23xAiqdN8kLGt6HgUz4QW0p7Q_big.jpg'),
(52707, 3632, 'Take Dois com Phineas e Ferb S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142159.mp4', 'http://gstaticontent.com/images/bx23xAiqdN8kLGt6HgUz4QW0p7Q_big.jpg'),
(52708, 3633, 'Poder Feminino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52709, 3633, 'Poder Feminino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52710, 3633, 'Poder Feminino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52711, 3633, 'Poder Feminino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52712, 3633, 'Poder Feminino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52713, 3633, 'Poder Feminino S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52714, 3633, 'Poder Feminino S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52715, 3633, 'Poder Feminino S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52716, 3633, 'Poder Feminino S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52717, 3633, 'Poder Feminino S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52718, 3634, 'Poder Feminino S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52719, 3634, 'Poder Feminino S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52720, 3634, 'Poder Feminino S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52721, 3634, 'Poder Feminino S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52722, 3634, 'Poder Feminino S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52723, 3634, 'Poder Feminino S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52724, 3634, 'Poder Feminino S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52725, 3634, 'Poder Feminino S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52726, 3634, 'Poder Feminino S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52727, 3634, 'Poder Feminino S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52728, 3635, 'Poder Feminino S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52729, 3635, 'Poder Feminino S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52730, 3635, 'Poder Feminino S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52731, 3635, 'Poder Feminino S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52732, 3635, 'Poder Feminino S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52733, 3635, 'Poder Feminino S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52734, 3635, 'Poder Feminino S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52735, 3635, 'Poder Feminino S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52736, 3635, 'Poder Feminino S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52737, 3635, 'Poder Feminino S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52738, 3636, 'Poder Feminino S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52739, 3636, 'Poder Feminino S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52740, 3636, 'Poder Feminino S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52741, 3636, 'Poder Feminino S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52742, 3636, 'Poder Feminino S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52743, 3636, 'Poder Feminino S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52744, 3636, 'Poder Feminino S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52745, 3636, 'Poder Feminino S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52746, 3636, 'Poder Feminino S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52747, 3636, 'Poder Feminino S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52748, 3636, 'Poder Feminino S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52749, 3636, 'Poder Feminino S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52750, 3636, 'Poder Feminino S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/142146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52751, 3636, 'Poder Feminino S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/142147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52752, 3636, 'Poder Feminino S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/142148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52753, 3636, 'Poder Feminino S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/142149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52754, 3637, 'Poder Feminino S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/309962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52755, 3637, 'Poder Feminino S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/309963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52756, 3637, 'Poder Feminino S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/309964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52757, 3637, 'Poder Feminino S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/309965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52758, 3637, 'Poder Feminino S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/309966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52759, 3637, 'Poder Feminino S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/309967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKloQpl6zE7kdFf8SUeYU2qPT9H.jpg'),
(52760, 3638, 'Ore dake Haireru Kakushi Dungeon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142092.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(52761, 3638, 'Ore dake Haireru Kakushi Dungeon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142093.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(52762, 3638, 'Ore dake Haireru Kakushi Dungeon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142094.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(52763, 3638, 'Ore dake Haireru Kakushi Dungeon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142095.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(52764, 3638, 'Ore dake Haireru Kakushi Dungeon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142096.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(52765, 3638, 'Ore dake Haireru Kakushi Dungeon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142097.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(52766, 3638, 'Ore dake Haireru Kakushi Dungeon S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142098.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(52767, 3638, 'Ore dake Haireru Kakushi Dungeon S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142099.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(52768, 3638, 'Ore dake Haireru Kakushi Dungeon S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142100.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(52769, 3638, 'Ore dake Haireru Kakushi Dungeon S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142101.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(52770, 3638, 'Ore dake Haireru Kakushi Dungeon S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/142102.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(52771, 3638, 'Ore dake Haireru Kakushi Dungeon S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/142103.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(52772, 3639, 'The Underground Railroad: Os Caminhos para a Liberdade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/142082.mp4', 'http://gstaticontent.com/images/CrrTqw7LHafnbdH9UcK60aOZSm_big.jpg'),
(52773, 3639, 'The Underground Railroad: Os Caminhos para a Liberdade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/142083.mp4', 'http://gstaticontent.com/images/CrrTqw7LHafnbdH9UcK60aOZSm_big.jpg'),
(52774, 3639, 'The Underground Railroad: Os Caminhos para a Liberdade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/142084.mp4', 'http://gstaticontent.com/images/CrrTqw7LHafnbdH9UcK60aOZSm_big.jpg'),
(52775, 3639, 'The Underground Railroad: Os Caminhos para a Liberdade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/142085.mp4', 'http://gstaticontent.com/images/CrrTqw7LHafnbdH9UcK60aOZSm_big.jpg'),
(52776, 3639, 'The Underground Railroad: Os Caminhos para a Liberdade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/142086.mp4', 'http://gstaticontent.com/images/CrrTqw7LHafnbdH9UcK60aOZSm_big.jpg'),
(52777, 3639, 'The Underground Railroad: Os Caminhos para a Liberdade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/142087.mp4', 'http://gstaticontent.com/images/CrrTqw7LHafnbdH9UcK60aOZSm_big.jpg'),
(52778, 3639, 'The Underground Railroad: Os Caminhos para a Liberdade S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/142088.mp4', 'http://gstaticontent.com/images/CrrTqw7LHafnbdH9UcK60aOZSm_big.jpg'),
(52779, 3639, 'The Underground Railroad: Os Caminhos para a Liberdade S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/142089.mp4', 'http://gstaticontent.com/images/CrrTqw7LHafnbdH9UcK60aOZSm_big.jpg'),
(52780, 3639, 'The Underground Railroad: Os Caminhos para a Liberdade S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/142090.mp4', 'http://gstaticontent.com/images/CrrTqw7LHafnbdH9UcK60aOZSm_big.jpg'),
(52781, 3639, 'The Underground Railroad: Os Caminhos para a Liberdade S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/142091.mp4', 'http://gstaticontent.com/images/CrrTqw7LHafnbdH9UcK60aOZSm_big.jpg'),
(52782, 3640, 'HALSTON S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141806.mp4', 'http://gstaticontent.com/images/jtrNfY3sbPV1Y6I49FQ77o226if_big.jpg'),
(52783, 3640, 'HALSTON S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141807.mp4', 'http://gstaticontent.com/images/jtrNfY3sbPV1Y6I49FQ77o226if_big.jpg'),
(52784, 3640, 'HALSTON S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141808.mp4', 'http://gstaticontent.com/images/jtrNfY3sbPV1Y6I49FQ77o226if_big.jpg'),
(52785, 3640, 'HALSTON S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141809.mp4', 'http://gstaticontent.com/images/jtrNfY3sbPV1Y6I49FQ77o226if_big.jpg'),
(52786, 3640, 'HALSTON S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141810.mp4', 'http://gstaticontent.com/images/jtrNfY3sbPV1Y6I49FQ77o226if_big.jpg'),
(52787, 3641, 'McMillion$ S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141811.mp4', 'http://gstaticontent.com/images/xyUciqZC5hGYJqefmbGbTy5fxYh_big.jpg'),
(52788, 3641, 'McMillion$ S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141812.mp4', 'http://gstaticontent.com/images/xyUciqZC5hGYJqefmbGbTy5fxYh_big.jpg'),
(52789, 3641, 'McMillion$ S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141813.mp4', 'http://gstaticontent.com/images/xyUciqZC5hGYJqefmbGbTy5fxYh_big.jpg'),
(52790, 3641, 'McMillion$ S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141814.mp4', 'http://gstaticontent.com/images/xyUciqZC5hGYJqefmbGbTy5fxYh_big.jpg'),
(52791, 3641, 'McMillion$ S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141815.mp4', 'http://gstaticontent.com/images/xyUciqZC5hGYJqefmbGbTy5fxYh_big.jpg'),
(52792, 3641, 'McMillion$ S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141816.mp4', 'http://gstaticontent.com/images/xyUciqZC5hGYJqefmbGbTy5fxYh_big.jpg'),
(52793, 3642, 'A Caminho do Céu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141796.mp4', 'http://gstaticontent.com/images/fhfXsPou90rCy1Nw4oyP28jyPVl_big.jpg'),
(52794, 3642, 'A Caminho do Céu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141797.mp4', 'http://gstaticontent.com/images/fhfXsPou90rCy1Nw4oyP28jyPVl_big.jpg'),
(52795, 3642, 'A Caminho do Céu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141798.mp4', 'http://gstaticontent.com/images/fhfXsPou90rCy1Nw4oyP28jyPVl_big.jpg'),
(52796, 3642, 'A Caminho do Céu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141799.mp4', 'http://gstaticontent.com/images/fhfXsPou90rCy1Nw4oyP28jyPVl_big.jpg'),
(52797, 3642, 'A Caminho do Céu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141800.mp4', 'http://gstaticontent.com/images/fhfXsPou90rCy1Nw4oyP28jyPVl_big.jpg'),
(52798, 3642, 'A Caminho do Céu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141801.mp4', 'http://gstaticontent.com/images/fhfXsPou90rCy1Nw4oyP28jyPVl_big.jpg'),
(52799, 3642, 'A Caminho do Céu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141802.mp4', 'http://gstaticontent.com/images/fhfXsPou90rCy1Nw4oyP28jyPVl_big.jpg'),
(52800, 3642, 'A Caminho do Céu S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141803.mp4', 'http://gstaticontent.com/images/fhfXsPou90rCy1Nw4oyP28jyPVl_big.jpg'),
(52801, 3642, 'A Caminho do Céu S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141804.mp4', 'http://gstaticontent.com/images/fhfXsPou90rCy1Nw4oyP28jyPVl_big.jpg'),
(52802, 3642, 'A Caminho do Céu S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141805.mp4', 'http://gstaticontent.com/images/fhfXsPou90rCy1Nw4oyP28jyPVl_big.jpg'),
(52803, 3643, 'Chame a Parteira S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149141.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52804, 3643, 'Chame a Parteira S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149142.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52805, 3643, 'Chame a Parteira S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149143.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52806, 3643, 'Chame a Parteira S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149144.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52807, 3643, 'Chame a Parteira S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149145.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52808, 3643, 'Chame a Parteira S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149146.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52809, 3644, 'Chame a Parteira S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149147.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52810, 3644, 'Chame a Parteira S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149148.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52811, 3644, 'Chame a Parteira S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149149.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52812, 3644, 'Chame a Parteira S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149150.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52813, 3644, 'Chame a Parteira S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149151.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52814, 3644, 'Chame a Parteira S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149152.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52815, 3644, 'Chame a Parteira S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149153.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52816, 3644, 'Chame a Parteira S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149154.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52817, 3644, 'Chame a Parteira S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149155.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52818, 3644, 'Chame a Parteira S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149156.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52819, 3645, 'Chame a Parteira S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149157.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52820, 3645, 'Chame a Parteira S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149158.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52821, 3645, 'Chame a Parteira S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149159.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52822, 3645, 'Chame a Parteira S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149160.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52823, 3645, 'Chame a Parteira S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149161.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52824, 3645, 'Chame a Parteira S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149162.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52825, 3645, 'Chame a Parteira S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149163.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52826, 3645, 'Chame a Parteira S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149164.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52827, 3645, 'Chame a Parteira S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149165.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52828, 3646, 'Chame a Parteira S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149166.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52829, 3646, 'Chame a Parteira S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149167.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52830, 3646, 'Chame a Parteira S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149168.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52831, 3646, 'Chame a Parteira S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149169.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52832, 3646, 'Chame a Parteira S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149170.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52833, 3646, 'Chame a Parteira S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149171.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52834, 3646, 'Chame a Parteira S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149172.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52835, 3646, 'Chame a Parteira S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149173.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52836, 3646, 'Chame a Parteira S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149174.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52837, 3647, 'Chame a Parteira S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149175.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52838, 3647, 'Chame a Parteira S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149176.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52839, 3647, 'Chame a Parteira S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149177.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52840, 3647, 'Chame a Parteira S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149178.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52841, 3647, 'Chame a Parteira S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149179.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52842, 3647, 'Chame a Parteira S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149180.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52843, 3647, 'Chame a Parteira S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149181.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52844, 3647, 'Chame a Parteira S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149182.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52845, 3647, 'Chame a Parteira S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149183.mp4', 'http://gstaticontent.com/images/b1p0nL00x563ACkcmGNIRP4ZnkA_big.jpg'),
(52846, 3648, 'Confrontando um Serial Killer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141791.mp4', 'http://gstaticontent.com/images/anNvtOpnOqBDaJPWqHKFdSbe0Qk_big.jpg'),
(52847, 3648, 'Confrontando um Serial Killer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141792.mp4', 'http://gstaticontent.com/images/anNvtOpnOqBDaJPWqHKFdSbe0Qk_big.jpg'),
(52848, 3648, 'Confrontando um Serial Killer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141793.mp4', 'http://gstaticontent.com/images/anNvtOpnOqBDaJPWqHKFdSbe0Qk_big.jpg'),
(52849, 3648, 'Confrontando um Serial Killer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141794.mp4', 'http://gstaticontent.com/images/anNvtOpnOqBDaJPWqHKFdSbe0Qk_big.jpg'),
(52850, 3648, 'Confrontando um Serial Killer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141795.mp4', 'http://gstaticontent.com/images/anNvtOpnOqBDaJPWqHKFdSbe0Qk_big.jpg'),
(52851, 3649, 'Falling Skies S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141739.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52852, 3649, 'Falling Skies S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141740.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52853, 3649, 'Falling Skies S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141741.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52854, 3649, 'Falling Skies S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141742.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52855, 3649, 'Falling Skies S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141743.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52856, 3649, 'Falling Skies S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141744.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52857, 3649, 'Falling Skies S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141745.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52858, 3649, 'Falling Skies S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141746.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52859, 3649, 'Falling Skies S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141747.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52860, 3649, 'Falling Skies S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141748.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52861, 3650, 'Falling Skies S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141749.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52862, 3650, 'Falling Skies S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141750.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52863, 3650, 'Falling Skies S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141751.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52864, 3650, 'Falling Skies S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141752.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52865, 3650, 'Falling Skies S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141753.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52866, 3650, 'Falling Skies S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141754.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52867, 3650, 'Falling Skies S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141755.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52868, 3650, 'Falling Skies S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141756.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52869, 3650, 'Falling Skies S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141757.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52870, 3650, 'Falling Skies S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141758.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52871, 3651, 'Falling Skies S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141759.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52872, 3651, 'Falling Skies S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141760.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52873, 3651, 'Falling Skies S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141761.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52874, 3651, 'Falling Skies S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141762.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52875, 3651, 'Falling Skies S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141763.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52876, 3651, 'Falling Skies S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141764.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52877, 3651, 'Falling Skies S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141765.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52878, 3651, 'Falling Skies S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141766.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52879, 3651, 'Falling Skies S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141767.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52880, 3651, 'Falling Skies S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141768.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52881, 3652, 'Falling Skies S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141769.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52882, 3652, 'Falling Skies S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141770.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52883, 3652, 'Falling Skies S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141771.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52884, 3652, 'Falling Skies S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141772.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52885, 3652, 'Falling Skies S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141773.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52886, 3652, 'Falling Skies S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141774.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52887, 3652, 'Falling Skies S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141775.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52888, 3652, 'Falling Skies S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141776.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52889, 3652, 'Falling Skies S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141777.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52890, 3652, 'Falling Skies S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141778.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52891, 3652, 'Falling Skies S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/141779.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52892, 3652, 'Falling Skies S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/141780.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52893, 3653, 'Falling Skies S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141781.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52894, 3653, 'Falling Skies S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141782.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52895, 3653, 'Falling Skies S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141783.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52896, 3653, 'Falling Skies S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141784.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52897, 3653, 'Falling Skies S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141785.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52898, 3653, 'Falling Skies S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141786.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52899, 3653, 'Falling Skies S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141787.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52900, 3653, 'Falling Skies S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141788.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52901, 3653, 'Falling Skies S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/141789.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52902, 3653, 'Falling Skies S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/141790.mp4', 'http://gstaticontent.com/images/i2ctkUM209mRyvWRrERXCbSarKr_big.jpg'),
(52903, 3654, 'Frontera Verde [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/141731.mp4', 'http://gstaticontent.com/images/b9NxdzOyv7iVGS4VpvXC2pDYSDa_big.jpg'),
(52904, 3654, 'Frontera Verde [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/141732.mp4', 'http://gstaticontent.com/images/b9NxdzOyv7iVGS4VpvXC2pDYSDa_big.jpg'),
(52905, 3654, 'Frontera Verde [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/141733.mp4', 'http://gstaticontent.com/images/b9NxdzOyv7iVGS4VpvXC2pDYSDa_big.jpg'),
(52906, 3654, 'Frontera Verde [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/141734.mp4', 'http://gstaticontent.com/images/b9NxdzOyv7iVGS4VpvXC2pDYSDa_big.jpg'),
(52907, 3654, 'Frontera Verde [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/141735.mp4', 'http://gstaticontent.com/images/b9NxdzOyv7iVGS4VpvXC2pDYSDa_big.jpg'),
(52908, 3654, 'Frontera Verde [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/141736.mp4', 'http://gstaticontent.com/images/b9NxdzOyv7iVGS4VpvXC2pDYSDa_big.jpg'),
(52909, 3654, 'Frontera Verde [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/141737.mp4', 'http://gstaticontent.com/images/b9NxdzOyv7iVGS4VpvXC2pDYSDa_big.jpg'),
(52910, 3654, 'Frontera Verde [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/141738.mp4', 'http://gstaticontent.com/images/b9NxdzOyv7iVGS4VpvXC2pDYSDa_big.jpg'),
(52911, 3655, 'Jujutsu Kaisen S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261410.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52912, 3655, 'Jujutsu Kaisen S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261411.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52913, 3655, 'Jujutsu Kaisen S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261412.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52914, 3655, 'Jujutsu Kaisen S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261413.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52915, 3655, 'Jujutsu Kaisen S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261414.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52916, 3655, 'Jujutsu Kaisen S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261415.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52917, 3655, 'Jujutsu Kaisen S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261416.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52918, 3655, 'Jujutsu Kaisen S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261417.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52919, 3655, 'Jujutsu Kaisen S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261418.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52920, 3655, 'Jujutsu Kaisen S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261419.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52921, 3655, 'Jujutsu Kaisen S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/261420.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52922, 3655, 'Jujutsu Kaisen S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/261421.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52923, 3655, 'Jujutsu Kaisen S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/261422.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52924, 3655, 'Jujutsu Kaisen S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/261423.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52925, 3655, 'Jujutsu Kaisen S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/261424.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52926, 3655, 'Jujutsu Kaisen S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/261425.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52927, 3655, 'Jujutsu Kaisen S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/261426.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52928, 3655, 'Jujutsu Kaisen S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/261427.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52929, 3655, 'Jujutsu Kaisen S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/261428.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52930, 3655, 'Jujutsu Kaisen S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/261429.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52931, 3655, 'Jujutsu Kaisen S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/261430.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52932, 3655, 'Jujutsu Kaisen S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/261431.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52933, 3655, 'Jujutsu Kaisen S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/261432.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52934, 3655, 'Jujutsu Kaisen S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/261433.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52935, 3656, 'Jujutsu Kaisen S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261434.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52936, 3656, 'Jujutsu Kaisen S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261435.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52937, 3656, 'Jujutsu Kaisen S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261436.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52938, 3656, 'Jujutsu Kaisen S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261437.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52939, 3656, 'Jujutsu Kaisen S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261438.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52940, 3656, 'Jujutsu Kaisen S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261439.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52941, 3656, 'Jujutsu Kaisen S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261440.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52942, 3656, 'Jujutsu Kaisen S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261441.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52943, 3656, 'Jujutsu Kaisen S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261442.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52944, 3656, 'Jujutsu Kaisen S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261443.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52945, 3656, 'Jujutsu Kaisen S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/261444.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52946, 3656, 'Jujutsu Kaisen S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/261445.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52947, 3656, 'Jujutsu Kaisen S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/261446.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52948, 3656, 'Jujutsu Kaisen S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/261447.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52949, 3656, 'Jujutsu Kaisen S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/261448.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52950, 3656, 'Jujutsu Kaisen S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/261449.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52951, 3656, 'Jujutsu Kaisen S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/261450.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52952, 3656, 'Jujutsu Kaisen S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/261451.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52953, 3656, 'Jujutsu Kaisen S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/261452.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52954, 3656, 'Jujutsu Kaisen S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/261453.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52955, 3656, 'Jujutsu Kaisen S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/261454.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52956, 3656, 'Jujutsu Kaisen S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/261455.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52957, 3656, 'Jujutsu Kaisen S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/590081.mp4', 'http://gstaticontent.com/images/9MSNijZyyUGoRv01aUKkEYxccWB_big.jpg'),
(52958, 3657, 'O Caso Evandro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152102.mp4', 'http://timg.bdta.pro/images/0759cc544640651e6e241acf442e7f37.jpg'),
(52959, 3657, 'O Caso Evandro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152103.mp4', 'http://timg.bdta.pro/images/6d891529cf2aea4077292c5b077299ef.jpg'),
(52960, 3657, 'O Caso Evandro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152104.mp4', 'http://timg.bdta.pro/images/c02e682543527da875626d8e1d1f2eca.jpg'),
(52961, 3657, 'O Caso Evandro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152105.mp4', 'http://timg.bdta.pro/images/cfade662fa01fc058a3a6da3aa4e209a.jpg'),
(52962, 3657, 'O Caso Evandro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152106.mp4', 'http://timg.bdta.pro/images/197e0ce8f098fc0396c9ed71159c6196.jpg'),
(52963, 3657, 'O Caso Evandro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152107.mp4', 'http://timg.bdta.pro/images/71ce6192f702a047848a021e6d04c4f3.jpg'),
(52964, 3657, 'O Caso Evandro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152108.mp4', 'http://timg.bdta.pro/images/67b67ce885f5be4584bb251db8c88782.jpg'),
(52965, 3657, 'O Caso Evandro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152109.mp4', 'http://timg.bdta.pro/images/8dcb04d0d015478d3eee8b057438734d.jpg'),
(52966, 3657, 'O Caso Evandro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152110.mp4', 'http://timg.bdta.pro/images/7eaa545924fd3a2c05083b4e0eb272cd.jpg'),
(52967, 3658, 'Ressurreição S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149184.mp4', 'http://gstaticontent.com/images/2bs5QoJwZmew05052jST9vgIEJc_big.jpg'),
(52968, 3658, 'Ressurreição S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149185.mp4', 'http://gstaticontent.com/images/2bs5QoJwZmew05052jST9vgIEJc_big.jpg'),
(52969, 3658, 'Ressurreição S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149186.mp4', 'http://gstaticontent.com/images/2bs5QoJwZmew05052jST9vgIEJc_big.jpg'),
(52970, 3658, 'Ressurreição S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149187.mp4', 'http://gstaticontent.com/images/2bs5QoJwZmew05052jST9vgIEJc_big.jpg'),
(52971, 3658, 'Ressurreição S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149188.mp4', 'http://gstaticontent.com/images/2bs5QoJwZmew05052jST9vgIEJc_big.jpg'),
(52972, 3658, 'Ressurreição S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149189.mp4', 'http://gstaticontent.com/images/2bs5QoJwZmew05052jST9vgIEJc_big.jpg'),
(52973, 3658, 'Ressurreição S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149190.mp4', 'http://gstaticontent.com/images/2bs5QoJwZmew05052jST9vgIEJc_big.jpg'),
(52974, 3658, 'Ressurreição S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149191.mp4', 'http://gstaticontent.com/images/2bs5QoJwZmew05052jST9vgIEJc_big.jpg'),
(52975, 3659, 'Ressurreição S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149192.mp4', 'http://gstaticontent.com/images/2bs5QoJwZmew05052jST9vgIEJc_big.jpg'),
(52976, 3659, 'Ressurreição S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149193.mp4', 'http://gstaticontent.com/images/2bs5QoJwZmew05052jST9vgIEJc_big.jpg'),
(52977, 3659, 'Ressurreição S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149194.mp4', 'http://gstaticontent.com/images/2bs5QoJwZmew05052jST9vgIEJc_big.jpg'),
(52978, 3659, 'Ressurreição S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149195.mp4', 'http://gstaticontent.com/images/2bs5QoJwZmew05052jST9vgIEJc_big.jpg'),
(52979, 3659, 'Ressurreição S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149196.mp4', 'http://gstaticontent.com/images/2bs5QoJwZmew05052jST9vgIEJc_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(52980, 3659, 'Ressurreição S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149197.mp4', 'http://gstaticontent.com/images/2bs5QoJwZmew05052jST9vgIEJc_big.jpg'),
(52981, 3659, 'Ressurreição S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149198.mp4', 'http://gstaticontent.com/images/2bs5QoJwZmew05052jST9vgIEJc_big.jpg'),
(52982, 3659, 'Ressurreição S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149199.mp4', 'http://gstaticontent.com/images/2bs5QoJwZmew05052jST9vgIEJc_big.jpg'),
(52983, 3659, 'Ressurreição S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149200.mp4', 'http://gstaticontent.com/images/2bs5QoJwZmew05052jST9vgIEJc_big.jpg'),
(52984, 3659, 'Ressurreição S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149201.mp4', 'http://gstaticontent.com/images/2bs5QoJwZmew05052jST9vgIEJc_big.jpg'),
(52985, 3659, 'Ressurreição S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149202.mp4', 'http://gstaticontent.com/images/2bs5QoJwZmew05052jST9vgIEJc_big.jpg'),
(52986, 3659, 'Ressurreição S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149203.mp4', 'http://gstaticontent.com/images/2bs5QoJwZmew05052jST9vgIEJc_big.jpg'),
(52987, 3659, 'Ressurreição S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/149204.mp4', 'http://gstaticontent.com/images/2bs5QoJwZmew05052jST9vgIEJc_big.jpg'),
(52988, 3660, 'Acampados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172461.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(52989, 3660, 'Acampados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172462.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(52990, 3660, 'Acampados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172463.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(52991, 3660, 'Acampados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172464.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(52992, 3660, 'Acampados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172465.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(52993, 3660, 'Acampados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172466.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(52994, 3660, 'Acampados S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172467.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(52995, 3660, 'Acampados S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172468.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(52996, 3660, 'Acampados S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172469.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(52997, 3660, 'Acampados S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172470.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(52998, 3660, 'Acampados S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172471.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(52999, 3660, 'Acampados S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172472.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53000, 3660, 'Acampados S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172473.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53001, 3660, 'Acampados S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172474.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53002, 3660, 'Acampados S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/172475.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53003, 3660, 'Acampados S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/172476.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53004, 3660, 'Acampados S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/172477.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53005, 3660, 'Acampados S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/172478.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53006, 3660, 'Acampados S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/172479.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53007, 3660, 'Acampados S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/172480.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53008, 3660, 'Acampados S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/172481.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53009, 3661, 'Acampados S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172482.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53010, 3661, 'Acampados S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172483.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53011, 3661, 'Acampados S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172484.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53012, 3661, 'Acampados S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172485.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53013, 3661, 'Acampados S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172486.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53014, 3661, 'Acampados S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172487.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53015, 3661, 'Acampados S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172488.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53016, 3661, 'Acampados S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172489.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53017, 3661, 'Acampados S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172490.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53018, 3661, 'Acampados S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172491.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53019, 3661, 'Acampados S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172492.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53020, 3661, 'Acampados S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172493.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53021, 3661, 'Acampados S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172494.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53022, 3661, 'Acampados S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172495.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53023, 3661, 'Acampados S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/172496.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53024, 3661, 'Acampados S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/172497.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53025, 3661, 'Acampados S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/172498.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53026, 3661, 'Acampados S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/172499.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53027, 3661, 'Acampados S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/172500.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53028, 3661, 'Acampados S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/172501.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53029, 3661, 'Acampados S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/172502.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53030, 3662, 'Acampados S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172503.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53031, 3662, 'Acampados S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172504.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53032, 3662, 'Acampados S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172505.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53033, 3662, 'Acampados S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172506.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53034, 3662, 'Acampados S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172507.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53035, 3662, 'Acampados S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172508.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53036, 3662, 'Acampados S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172509.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53037, 3662, 'Acampados S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172510.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53038, 3662, 'Acampados S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172511.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53039, 3662, 'Acampados S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172512.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53040, 3662, 'Acampados S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172513.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53041, 3662, 'Acampados S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172514.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53042, 3662, 'Acampados S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172515.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53043, 3662, 'Acampados S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172516.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53044, 3662, 'Acampados S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/172517.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53045, 3662, 'Acampados S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/172518.mp4', 'http://gstaticontent.com/images/ofUYkBo09ncADFi7CpNIDmSl4pq_big.jpg'),
(53046, 3663, 'Acampados S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172519.mp4', 'http://timg.bdta.pro/images/ebed7ed07a0d24e6b14f8e92d96ab2a2.jpg'),
(53047, 3663, 'Acampados S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172520.mp4', 'http://timg.bdta.pro/images/49c4fc5fb70b160f00213ebe634043b2.jpg'),
(53048, 3663, 'Acampados S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172521.mp4', 'http://timg.bdta.pro/images/8b7adc27efd1e4e744938fbad8d9ad77.jpg'),
(53049, 3663, 'Acampados S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172522.mp4', 'http://timg.bdta.pro/images/f2db25ffb1310a8a1813f44fa78b5c19.jpg'),
(53050, 3663, 'Acampados S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172523.mp4', 'http://timg.bdta.pro/images/5906223ce0c94f80f038955ad0d5c2fe.jpg'),
(53051, 3663, 'Acampados S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172524.mp4', 'http://timg.bdta.pro/images/a56f56d030d15827917475e4d8c8ba3a.jpg'),
(53052, 3663, 'Acampados S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172525.mp4', 'http://timg.bdta.pro/images/537e567486a440afebfe0a1607150153.jpg'),
(53053, 3663, 'Acampados S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172526.mp4', 'http://timg.bdta.pro/images/0cc269a4d21cd627809fc70f9bb98b8e.jpg'),
(53054, 3663, 'Acampados S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172527.mp4', 'http://timg.bdta.pro/images/0d35f9072d252620573d26d1804822f5.jpg'),
(53055, 3663, 'Acampados S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172528.mp4', 'http://timg.bdta.pro/images/85a42d148a64d79533b51ddd1d26d181.jpg'),
(53056, 3663, 'Acampados S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172529.mp4', 'http://timg.bdta.pro/images/7732302089b54c48f79c2b24cd2057fe.jpg'),
(53057, 3663, 'Acampados S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172530.mp4', 'http://timg.bdta.pro/images/6111ccce707ce7e823b26bde4bd0dae7.jpg'),
(53058, 3663, 'Acampados S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172531.mp4', 'http://timg.bdta.pro/images/5292f57b8626026610f0dfa651776028.jpg'),
(53059, 3663, 'Acampados S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172532.mp4', 'http://timg.bdta.pro/images/f33e0870d5fe1990589c94e009dbbb7e.jpg'),
(53060, 3663, 'Acampados S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/172533.mp4', 'http://timg.bdta.pro/images/de05aa910760ff7ec89dd0eed11638fd.jpg'),
(53061, 3663, 'Acampados S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/172534.mp4', 'http://timg.bdta.pro/images/aec50cbf4acff303428632c0af6ae22a.jpg'),
(53062, 3663, 'Acampados S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/172535.mp4', 'http://timg.bdta.pro/images/2fea58a7a86725077d535dd6d439f4ad.jpg'),
(53063, 3663, 'Acampados S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/172536.mp4', 'http://timg.bdta.pro/images/d6f969974172351dbda5413ef4b66ddb.jpg'),
(53064, 3663, 'Acampados S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/172537.mp4', 'http://timg.bdta.pro/images/66c481524a798543e4292b67a6537f6a.jpg'),
(53065, 3663, 'Acampados S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/172538.mp4', 'http://timg.bdta.pro/images/1ff38a2a1cbd68b60786f6b1cc310ccd.jpg'),
(53066, 3663, 'Acampados S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/172539.mp4', 'http://timg.bdta.pro/images/7f718eec959454326ad8c82316ee0c22.jpg'),
(53067, 3663, 'Acampados S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/172540.mp4', 'http://timg.bdta.pro/images/cc8b3a349c94a62ba6df177e04a7671a.jpg'),
(53068, 3663, 'Acampados S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/172541.mp4', 'http://timg.bdta.pro/images/d0b71f4b3716604f80b15d5e827f4ca7.jpg'),
(53069, 3663, 'Acampados S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/172542.mp4', 'http://timg.bdta.pro/images/ebfb0471913853b0c4ff9975dcc0e09e.jpg'),
(53070, 3663, 'Acampados S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/172543.mp4', 'http://timg.bdta.pro/images/84c8e982668e8e9b8c720b5483e7df1c.jpg'),
(53071, 3663, 'Acampados S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/172544.mp4', 'http://timg.bdta.pro/images/5cda83ef6e6faf049f4e1559c848a860.jpg'),
(53072, 3663, 'Acampados S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/172545.mp4', 'http://timg.bdta.pro/images/8403d76f18cb92ab55fe9bead0846e23.jpg'),
(53073, 3663, 'Acampados S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/172546.mp4', 'http://timg.bdta.pro/images/bf9545e7d2932586e4f62f4de803b51b.jpg'),
(53074, 3663, 'Acampados S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/172547.mp4', 'http://timg.bdta.pro/images/92689cf0ced02164192ad7e6179c234d.jpg'),
(53075, 3663, 'Acampados S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/172548.mp4', 'http://timg.bdta.pro/images/be98286327ffb80d5faa8b7bc0df09bd.jpg'),
(53076, 3664, 'Acampados S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172549.mp4', 'http://timg.bdta.pro/images/8156eb4044f68dfdbec484a81436c32c.jpg'),
(53077, 3664, 'Acampados S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172550.mp4', 'http://timg.bdta.pro/images/59709fd657d491109e5de3b06afb4a46.jpg'),
(53078, 3664, 'Acampados S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172551.mp4', 'http://timg.bdta.pro/images/74f703058d83cb7413c0c19af49761d4.jpg'),
(53079, 3664, 'Acampados S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172552.mp4', 'http://timg.bdta.pro/images/79b09e896ef9391000d6264e4026a916.jpg'),
(53080, 3664, 'Acampados S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172553.mp4', 'http://timg.bdta.pro/images/25d98a1a5318b9bb08d02226e0b3fa66.jpg'),
(53081, 3664, 'Acampados S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172554.mp4', 'http://timg.bdta.pro/images/a89727b55e3c5fe6bd1668fb8ce5b6fd.jpg'),
(53082, 3664, 'Acampados S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172555.mp4', 'http://timg.bdta.pro/images/041f0a15e51595fbe757646c5732b5e1.jpg'),
(53083, 3664, 'Acampados S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172556.mp4', 'http://timg.bdta.pro/images/b681bafb567dca03165d2336054900c0.jpg'),
(53084, 3664, 'Acampados S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172557.mp4', 'http://timg.bdta.pro/images/4543a42ef1d6a92fddc3eddbfaf97239.jpg'),
(53085, 3664, 'Acampados S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172558.mp4', 'http://timg.bdta.pro/images/79a5c6e42deae29379b1a348bb6a3933.jpg'),
(53086, 3664, 'Acampados S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172559.mp4', 'http://timg.bdta.pro/images/f529d3d7b98aaf0b36ed514327ef9504.jpg'),
(53087, 3664, 'Acampados S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172560.mp4', 'http://timg.bdta.pro/images/f49e72c4982de575fadd8301d883efa1.jpg'),
(53088, 3664, 'Acampados S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172561.mp4', 'http://timg.bdta.pro/images/eced25ae97905b6e59310b7325401fab.jpg'),
(53089, 3664, 'Acampados S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172562.mp4', 'http://timg.bdta.pro/images/e82448381d43281f386f127eb4d4b1cd.jpg'),
(53090, 3664, 'Acampados S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/172563.mp4', 'http://timg.bdta.pro/images/547a30db0f4f66ece24ddc1cca322345.jpg'),
(53091, 3664, 'Acampados S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/172564.mp4', 'http://timg.bdta.pro/images/428c27e459e69f9f936d6b4bbfab4788.jpg'),
(53092, 3664, 'Acampados S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/172565.mp4', 'http://timg.bdta.pro/images/14f81cd98dd4c3d87dfedae376ba4897.jpg'),
(53093, 3664, 'Acampados S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/172566.mp4', 'http://timg.bdta.pro/images/f0eb29b897c47795b598c838281f1326.jpg'),
(53094, 3664, 'Acampados S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/172567.mp4', 'http://timg.bdta.pro/images/93be059dea023df087163a27cca3da09.jpg'),
(53095, 3664, 'Acampados S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/172568.mp4', 'http://timg.bdta.pro/images/e6cacf5753f51f88bfe54917a30e3855.jpg'),
(53096, 3664, 'Acampados S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/172569.mp4', 'http://timg.bdta.pro/images/8e47edd0369a9721f20b5b377ae61f9d.jpg'),
(53097, 3665, 'Casamento e Divórcio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162070.mp4', 'http://gstaticontent.com/images/gyqkFhriSoWVsMTdH03XrXg6JR6_big.jpg'),
(53098, 3665, 'Casamento e Divórcio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162071.mp4', 'http://gstaticontent.com/images/gyqkFhriSoWVsMTdH03XrXg6JR6_big.jpg'),
(53099, 3665, 'Casamento e Divórcio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162072.mp4', 'http://gstaticontent.com/images/gyqkFhriSoWVsMTdH03XrXg6JR6_big.jpg'),
(53100, 3665, 'Casamento e Divórcio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162073.mp4', 'http://gstaticontent.com/images/gyqkFhriSoWVsMTdH03XrXg6JR6_big.jpg'),
(53101, 3665, 'Casamento e Divórcio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162074.mp4', 'http://gstaticontent.com/images/gyqkFhriSoWVsMTdH03XrXg6JR6_big.jpg'),
(53102, 3665, 'Casamento e Divórcio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162075.mp4', 'http://gstaticontent.com/images/gyqkFhriSoWVsMTdH03XrXg6JR6_big.jpg'),
(53103, 3665, 'Casamento e Divórcio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/162076.mp4', 'http://gstaticontent.com/images/gyqkFhriSoWVsMTdH03XrXg6JR6_big.jpg'),
(53104, 3665, 'Casamento e Divórcio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/162077.mp4', 'http://gstaticontent.com/images/gyqkFhriSoWVsMTdH03XrXg6JR6_big.jpg'),
(53105, 3665, 'Casamento e Divórcio S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/162078.mp4', 'http://gstaticontent.com/images/gyqkFhriSoWVsMTdH03XrXg6JR6_big.jpg'),
(53106, 3665, 'Casamento e Divórcio S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/162079.mp4', 'http://gstaticontent.com/images/gyqkFhriSoWVsMTdH03XrXg6JR6_big.jpg'),
(53107, 3665, 'Casamento e Divórcio S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/162080.mp4', 'http://gstaticontent.com/images/gyqkFhriSoWVsMTdH03XrXg6JR6_big.jpg'),
(53108, 3665, 'Casamento e Divórcio S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/162081.mp4', 'http://gstaticontent.com/images/gyqkFhriSoWVsMTdH03XrXg6JR6_big.jpg'),
(53109, 3665, 'Casamento e Divórcio S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/162082.mp4', 'http://gstaticontent.com/images/gyqkFhriSoWVsMTdH03XrXg6JR6_big.jpg'),
(53110, 3665, 'Casamento e Divórcio S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/162083.mp4', 'http://gstaticontent.com/images/gyqkFhriSoWVsMTdH03XrXg6JR6_big.jpg'),
(53111, 3665, 'Casamento e Divórcio S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/162084.mp4', 'http://gstaticontent.com/images/gyqkFhriSoWVsMTdH03XrXg6JR6_big.jpg'),
(53112, 3665, 'Casamento e Divórcio S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/162085.mp4', 'http://gstaticontent.com/images/gyqkFhriSoWVsMTdH03XrXg6JR6_big.jpg'),
(53113, 3666, 'Casamento e Divórcio S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rd2E1DReSb3enZ6ZGjMyuWrqJA.jpg'),
(53114, 3666, 'Casamento e Divórcio S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qYiY2mgPf8zb5udJbYAXgojkM45.jpg'),
(53115, 3666, 'Casamento e Divórcio S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Z5xSHSIihAQnDuSD8BNOzrL9Hw.jpg'),
(53116, 3666, 'Casamento e Divórcio S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7S3DQ29erehQJD6FjZqqGFM0DSO.jpg'),
(53117, 3666, 'Casamento e Divórcio S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wCdCDKXRXmzAEAyFEJb1qm8vspy.jpg'),
(53118, 3666, 'Casamento e Divórcio S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o561dOW7GtImXmmoz6hsT5MsJx4.jpg'),
(53119, 3666, 'Casamento e Divórcio S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/162092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x6PxiCONttLMpkrdVZ1q3I34aCz.jpg'),
(53120, 3666, 'Casamento e Divórcio S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/162093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2k4UtSPjtmJnhAgThMuD8RSrNfX.jpg'),
(53121, 3666, 'Casamento e Divórcio S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/162094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/diDsuhkpA77YHBJl0vCpTbG8ubA.jpg'),
(53122, 3666, 'Casamento e Divórcio S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/162095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rvTI7cwia52cWFFHAJrvkREaKwN.jpg'),
(53123, 3666, 'Casamento e Divórcio S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/162096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pCBI0HQUUODTgYiDHGYrtHUeRd3.jpg'),
(53124, 3666, 'Casamento e Divórcio S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/162097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o4eV0D9H6Fyr9CCXDt2kvCU4evK.jpg'),
(53125, 3666, 'Casamento e Divórcio S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/162098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vqj77WYn4AeXYMQyHTl9JpLLfIJ.jpg'),
(53126, 3666, 'Casamento e Divórcio S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/162099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sJFi9gqu8gx04kajum7Vcd926nI.jpg'),
(53127, 3666, 'Casamento e Divórcio S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/162100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i3PmaVZX6JG7mG23NaPQWeZVPpQ.jpg'),
(53128, 3666, 'Casamento e Divórcio S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/162101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/adEfoSKJxDThvEThCTCCfmJ9lDJ.jpg'),
(53129, 3667, 'Casa Kalimann S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152176.mp4', 'http://timg.bdta.pro/images/60fcfecefe8055a2768ffe56ca9aadda.jpg'),
(53130, 3667, 'Casa Kalimann S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152177.mp4', 'http://timg.bdta.pro/images/58da3eae699ebd7a6ee6e44d2e869a59.jpg'),
(53131, 3667, 'Casa Kalimann S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152178.mp4', 'http://timg.bdta.pro/images/57687a45afc96fc8626fb30b61609016.jpg'),
(53132, 3667, 'Casa Kalimann S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152179.mp4', 'http://timg.bdta.pro/images/c3833805df4a314b620d2d12ad2490b5.jpg'),
(53133, 3667, 'Casa Kalimann S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152180.mp4', 'http://timg.bdta.pro/images/55402c8ba0291813c613a49521cd11b8.jpg'),
(53134, 3667, 'Casa Kalimann S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152181.mp4', 'http://timg.bdta.pro/images/7292c56487c03254ed49c3d4b97ce824.jpg'),
(53135, 3667, 'Casa Kalimann S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152182.mp4', 'http://timg.bdta.pro/images/7e8ef2f359cd89f2d3632dab26282e90.jpg'),
(53136, 3667, 'Casa Kalimann S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152183.mp4', 'http://gstaticontent.com/images/yzNk2CnAfu4oCmI7s5rsKhp8ann_big.jpg'),
(53137, 3667, 'Casa Kalimann S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152184.mp4', 'http://gstaticontent.com/images/yzNk2CnAfu4oCmI7s5rsKhp8ann_big.jpg'),
(53138, 3667, 'Casa Kalimann S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152185.mp4', 'http://gstaticontent.com/images/yzNk2CnAfu4oCmI7s5rsKhp8ann_big.jpg'),
(53139, 3667, 'Casa Kalimann S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152186.mp4', 'http://gstaticontent.com/images/yzNk2CnAfu4oCmI7s5rsKhp8ann_big.jpg'),
(53140, 3667, 'Casa Kalimann S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152187.mp4', 'http://gstaticontent.com/images/yzNk2CnAfu4oCmI7s5rsKhp8ann_big.jpg'),
(53141, 3667, 'Casa Kalimann S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152188.mp4', 'http://gstaticontent.com/images/yzNk2CnAfu4oCmI7s5rsKhp8ann_big.jpg'),
(53142, 3668, 'Os Bibliotecários S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149099.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53143, 3668, 'Os Bibliotecários S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149100.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53144, 3668, 'Os Bibliotecários S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149101.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53145, 3668, 'Os Bibliotecários S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149102.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53146, 3668, 'Os Bibliotecários S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149103.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53147, 3668, 'Os Bibliotecários S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149104.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53148, 3668, 'Os Bibliotecários S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149105.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53149, 3668, 'Os Bibliotecários S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149106.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53150, 3668, 'Os Bibliotecários S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149107.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53151, 3668, 'Os Bibliotecários S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149108.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53152, 3669, 'Os Bibliotecários S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149109.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53153, 3669, 'Os Bibliotecários S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149110.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53154, 3669, 'Os Bibliotecários S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149111.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53155, 3669, 'Os Bibliotecários S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149112.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53156, 3669, 'Os Bibliotecários S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149113.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53157, 3669, 'Os Bibliotecários S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149114.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53158, 3669, 'Os Bibliotecários S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149115.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53159, 3669, 'Os Bibliotecários S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149116.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53160, 3669, 'Os Bibliotecários S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149117.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53161, 3669, 'Os Bibliotecários S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149118.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53162, 3670, 'Os Bibliotecários S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149119.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53163, 3670, 'Os Bibliotecários S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149120.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53164, 3670, 'Os Bibliotecários S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149121.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53165, 3670, 'Os Bibliotecários S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149122.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53166, 3670, 'Os Bibliotecários S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149123.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53167, 3670, 'Os Bibliotecários S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149124.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53168, 3670, 'Os Bibliotecários S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149125.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53169, 3670, 'Os Bibliotecários S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149126.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53170, 3670, 'Os Bibliotecários S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149127.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53171, 3670, 'Os Bibliotecários S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149128.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53172, 3671, 'Os Bibliotecários S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149129.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53173, 3671, 'Os Bibliotecários S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149130.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53174, 3671, 'Os Bibliotecários S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149131.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53175, 3671, 'Os Bibliotecários S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149132.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53176, 3671, 'Os Bibliotecários S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149133.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53177, 3671, 'Os Bibliotecários S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149134.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53178, 3671, 'Os Bibliotecários S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149135.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53179, 3671, 'Os Bibliotecários S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149136.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53180, 3671, 'Os Bibliotecários S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149137.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53181, 3671, 'Os Bibliotecários S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149138.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53182, 3671, 'Os Bibliotecários S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149139.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53183, 3671, 'Os Bibliotecários S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149140.mp4', 'http://gstaticontent.com/images/aEAKIqNsdU1cWUmQagPwpS1cvBv_big.jpg'),
(53184, 3672, 'A Dança da Morte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149095.mp4', 'http://gstaticontent.com/images/kHV7sGzzpFMb2SypKpLUwNC10sN_big.jpg'),
(53185, 3672, 'A Dança da Morte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149096.mp4', 'http://gstaticontent.com/images/kHV7sGzzpFMb2SypKpLUwNC10sN_big.jpg'),
(53186, 3672, 'A Dança da Morte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149097.mp4', 'http://gstaticontent.com/images/kHV7sGzzpFMb2SypKpLUwNC10sN_big.jpg'),
(53187, 3672, 'A Dança da Morte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149098.mp4', 'http://gstaticontent.com/images/kHV7sGzzpFMb2SypKpLUwNC10sN_big.jpg'),
(53188, 3673, 'Solar Opposites S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53189, 3673, 'Solar Opposites S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53190, 3673, 'Solar Opposites S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53191, 3673, 'Solar Opposites S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53192, 3673, 'Solar Opposites S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53193, 3673, 'Solar Opposites S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53194, 3673, 'Solar Opposites S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53195, 3673, 'Solar Opposites S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53196, 3674, 'Solar Opposites S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53197, 3674, 'Solar Opposites S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53198, 3674, 'Solar Opposites S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53199, 3674, 'Solar Opposites S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53200, 3674, 'Solar Opposites S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53201, 3674, 'Solar Opposites S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53202, 3674, 'Solar Opposites S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53203, 3674, 'Solar Opposites S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53204, 3674, 'Solar Opposites S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53205, 3675, 'Solar Opposites S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53206, 3675, 'Solar Opposites S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53207, 3675, 'Solar Opposites S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53208, 3675, 'Solar Opposites S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53209, 3675, 'Solar Opposites S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53210, 3675, 'Solar Opposites S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53211, 3675, 'Solar Opposites S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53212, 3675, 'Solar Opposites S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53213, 3675, 'Solar Opposites S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53214, 3675, 'Solar Opposites S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53215, 3675, 'Solar Opposites S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/242206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53216, 3675, 'Solar Opposites S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/242207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53217, 3676, 'Solar Opposites S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53218, 3676, 'Solar Opposites S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53219, 3676, 'Solar Opposites S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53220, 3676, 'Solar Opposites S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sgC5ttZZBbOctTdt5wAFKf8IK63.jpg'),
(53221, 3676, 'Solar Opposites S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jKse28D7ivDnLp90nQPorbQQn7V.jpg'),
(53222, 3676, 'Solar Opposites S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yaNaAZREN966xQmjXhx6jBzD3Ar.jpg'),
(53223, 3676, 'Solar Opposites S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53224, 3676, 'Solar Opposites S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/624986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53225, 3676, 'Solar Opposites S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53226, 3676, 'Solar Opposites S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53227, 3676, 'Solar Opposites S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/242219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53228, 3676, 'Solar Opposites S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/430827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53229, 3677, 'Solar Opposites S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/430828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53230, 3677, 'Solar Opposites S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/430829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53231, 3677, 'Solar Opposites S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/430830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53232, 3677, 'Solar Opposites S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/430831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53233, 3677, 'Solar Opposites S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/430832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53234, 3677, 'Solar Opposites S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/430833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53235, 3677, 'Solar Opposites S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/430834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53236, 3677, 'Solar Opposites S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/430835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53237, 3677, 'Solar Opposites S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/430836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53238, 3677, 'Solar Opposites S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/430837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53239, 3677, 'Solar Opposites S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/430838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53240, 3677, 'Solar Opposites S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/471947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPClRec0BXzWG7B9jsTdimoeJpM.jpg'),
(53241, 3678, 'The Night Of S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149087.mp4', 'http://gstaticontent.com/images/kO6vgNAZdntdoJ8KH9YOXzwFfSC_big.jpg'),
(53242, 3678, 'The Night Of S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149088.mp4', 'http://gstaticontent.com/images/kO6vgNAZdntdoJ8KH9YOXzwFfSC_big.jpg'),
(53243, 3678, 'The Night Of S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149089.mp4', 'http://gstaticontent.com/images/kO6vgNAZdntdoJ8KH9YOXzwFfSC_big.jpg'),
(53244, 3678, 'The Night Of S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149090.mp4', 'http://gstaticontent.com/images/kO6vgNAZdntdoJ8KH9YOXzwFfSC_big.jpg'),
(53245, 3678, 'The Night Of S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149091.mp4', 'http://gstaticontent.com/images/kO6vgNAZdntdoJ8KH9YOXzwFfSC_big.jpg'),
(53246, 3678, 'The Night Of S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149092.mp4', 'http://gstaticontent.com/images/kO6vgNAZdntdoJ8KH9YOXzwFfSC_big.jpg'),
(53247, 3678, 'The Night Of S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149093.mp4', 'http://gstaticontent.com/images/kO6vgNAZdntdoJ8KH9YOXzwFfSC_big.jpg'),
(53248, 3678, 'The Night Of S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149094.mp4', 'http://gstaticontent.com/images/kO6vgNAZdntdoJ8KH9YOXzwFfSC_big.jpg'),
(53249, 3679, 'Chuteira Preta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149074.mp4', 'http://gstaticontent.com/images/wo30ISxCwLUF97aWaMrI6ZaH27w_big.jpg'),
(53250, 3679, 'Chuteira Preta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149075.mp4', 'http://gstaticontent.com/images/wo30ISxCwLUF97aWaMrI6ZaH27w_big.jpg'),
(53251, 3679, 'Chuteira Preta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149076.mp4', 'http://gstaticontent.com/images/wo30ISxCwLUF97aWaMrI6ZaH27w_big.jpg'),
(53252, 3679, 'Chuteira Preta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149077.mp4', 'http://gstaticontent.com/images/wo30ISxCwLUF97aWaMrI6ZaH27w_big.jpg'),
(53253, 3679, 'Chuteira Preta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149078.mp4', 'http://gstaticontent.com/images/wo30ISxCwLUF97aWaMrI6ZaH27w_big.jpg'),
(53254, 3679, 'Chuteira Preta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149079.mp4', 'http://gstaticontent.com/images/wo30ISxCwLUF97aWaMrI6ZaH27w_big.jpg'),
(53255, 3679, 'Chuteira Preta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149080.mp4', 'http://gstaticontent.com/images/wo30ISxCwLUF97aWaMrI6ZaH27w_big.jpg'),
(53256, 3679, 'Chuteira Preta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149081.mp4', 'http://gstaticontent.com/images/wo30ISxCwLUF97aWaMrI6ZaH27w_big.jpg'),
(53257, 3679, 'Chuteira Preta S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149082.mp4', 'http://gstaticontent.com/images/wo30ISxCwLUF97aWaMrI6ZaH27w_big.jpg'),
(53258, 3679, 'Chuteira Preta S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149083.mp4', 'http://gstaticontent.com/images/wo30ISxCwLUF97aWaMrI6ZaH27w_big.jpg'),
(53259, 3679, 'Chuteira Preta S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149084.mp4', 'http://gstaticontent.com/images/wo30ISxCwLUF97aWaMrI6ZaH27w_big.jpg'),
(53260, 3679, 'Chuteira Preta S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149085.mp4', 'http://gstaticontent.com/images/wo30ISxCwLUF97aWaMrI6ZaH27w_big.jpg'),
(53261, 3679, 'Chuteira Preta S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/149086.mp4', 'http://gstaticontent.com/images/wo30ISxCwLUF97aWaMrI6ZaH27w_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(53262, 3680, 'Dawson\'s Creek S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148946.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53263, 3680, 'Dawson\'s Creek S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148947.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53264, 3680, 'Dawson\'s Creek S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148948.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53265, 3680, 'Dawson\'s Creek S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148949.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53266, 3680, 'Dawson\'s Creek S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148950.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53267, 3680, 'Dawson\'s Creek S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148951.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53268, 3680, 'Dawson\'s Creek S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148952.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53269, 3680, 'Dawson\'s Creek S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148953.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53270, 3680, 'Dawson\'s Creek S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148954.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53271, 3680, 'Dawson\'s Creek S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148955.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53272, 3680, 'Dawson\'s Creek S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148956.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53273, 3680, 'Dawson\'s Creek S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148957.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53274, 3680, 'Dawson\'s Creek S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148958.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53275, 3681, 'Dawson\'s Creek S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148959.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53276, 3681, 'Dawson\'s Creek S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148960.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53277, 3681, 'Dawson\'s Creek S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148961.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53278, 3681, 'Dawson\'s Creek S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148962.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53279, 3681, 'Dawson\'s Creek S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148963.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53280, 3681, 'Dawson\'s Creek S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148964.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53281, 3681, 'Dawson\'s Creek S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148965.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53282, 3681, 'Dawson\'s Creek S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148966.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53283, 3681, 'Dawson\'s Creek S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148967.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53284, 3681, 'Dawson\'s Creek S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148968.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53285, 3681, 'Dawson\'s Creek S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148969.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53286, 3681, 'Dawson\'s Creek S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148970.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53287, 3681, 'Dawson\'s Creek S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148971.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53288, 3681, 'Dawson\'s Creek S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148972.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53289, 3681, 'Dawson\'s Creek S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148973.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53290, 3681, 'Dawson\'s Creek S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148974.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53291, 3681, 'Dawson\'s Creek S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/148975.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53292, 3681, 'Dawson\'s Creek S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/148976.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53293, 3681, 'Dawson\'s Creek S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/148977.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53294, 3681, 'Dawson\'s Creek S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/148978.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53295, 3681, 'Dawson\'s Creek S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/148979.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53296, 3681, 'Dawson\'s Creek S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/148980.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53297, 3682, 'Dawson\'s Creek S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148981.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53298, 3682, 'Dawson\'s Creek S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148982.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53299, 3682, 'Dawson\'s Creek S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148983.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53300, 3682, 'Dawson\'s Creek S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148984.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53301, 3682, 'Dawson\'s Creek S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148985.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53302, 3682, 'Dawson\'s Creek S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148986.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53303, 3682, 'Dawson\'s Creek S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148987.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53304, 3682, 'Dawson\'s Creek S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148988.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53305, 3682, 'Dawson\'s Creek S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148989.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53306, 3682, 'Dawson\'s Creek S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148990.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53307, 3682, 'Dawson\'s Creek S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148991.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53308, 3682, 'Dawson\'s Creek S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148992.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53309, 3682, 'Dawson\'s Creek S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148993.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53310, 3682, 'Dawson\'s Creek S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148994.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53311, 3682, 'Dawson\'s Creek S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148995.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53312, 3682, 'Dawson\'s Creek S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148996.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53313, 3682, 'Dawson\'s Creek S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/148997.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53314, 3682, 'Dawson\'s Creek S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/148998.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53315, 3682, 'Dawson\'s Creek S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/148999.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53316, 3682, 'Dawson\'s Creek S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/149000.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53317, 3682, 'Dawson\'s Creek S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/149001.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53318, 3682, 'Dawson\'s Creek S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/149002.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53319, 3682, 'Dawson\'s Creek S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/149003.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53320, 3683, 'Dawson\'s Creek S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149004.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53321, 3683, 'Dawson\'s Creek S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149005.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53322, 3683, 'Dawson\'s Creek S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149006.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53323, 3683, 'Dawson\'s Creek S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149007.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53324, 3683, 'Dawson\'s Creek S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149008.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53325, 3683, 'Dawson\'s Creek S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149009.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53326, 3683, 'Dawson\'s Creek S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149010.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53327, 3683, 'Dawson\'s Creek S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149011.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53328, 3683, 'Dawson\'s Creek S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149012.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53329, 3683, 'Dawson\'s Creek S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149013.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53330, 3683, 'Dawson\'s Creek S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149014.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53331, 3683, 'Dawson\'s Creek S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149015.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53332, 3683, 'Dawson\'s Creek S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/149016.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53333, 3683, 'Dawson\'s Creek S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/149017.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53334, 3683, 'Dawson\'s Creek S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/149018.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53335, 3683, 'Dawson\'s Creek S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/149019.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53336, 3683, 'Dawson\'s Creek S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/149020.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53337, 3683, 'Dawson\'s Creek S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/149021.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53338, 3683, 'Dawson\'s Creek S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/149022.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53339, 3683, 'Dawson\'s Creek S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/149023.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53340, 3683, 'Dawson\'s Creek S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/149024.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53341, 3683, 'Dawson\'s Creek S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/149025.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53342, 3683, 'Dawson\'s Creek S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/149026.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53343, 3684, 'Dawson\'s Creek S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149027.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53344, 3684, 'Dawson\'s Creek S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149028.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53345, 3684, 'Dawson\'s Creek S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149029.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53346, 3684, 'Dawson\'s Creek S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149030.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53347, 3684, 'Dawson\'s Creek S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149031.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53348, 3684, 'Dawson\'s Creek S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149032.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53349, 3684, 'Dawson\'s Creek S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149033.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53350, 3684, 'Dawson\'s Creek S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149034.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53351, 3684, 'Dawson\'s Creek S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149035.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53352, 3684, 'Dawson\'s Creek S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149036.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53353, 3684, 'Dawson\'s Creek S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149037.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53354, 3684, 'Dawson\'s Creek S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149038.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53355, 3684, 'Dawson\'s Creek S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/149039.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53356, 3684, 'Dawson\'s Creek S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/149040.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53357, 3684, 'Dawson\'s Creek S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/149041.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53358, 3684, 'Dawson\'s Creek S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/149042.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53359, 3684, 'Dawson\'s Creek S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/149043.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53360, 3684, 'Dawson\'s Creek S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/149044.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53361, 3684, 'Dawson\'s Creek S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/149045.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53362, 3684, 'Dawson\'s Creek S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/149046.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53363, 3684, 'Dawson\'s Creek S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/149047.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53364, 3684, 'Dawson\'s Creek S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/149048.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53365, 3684, 'Dawson\'s Creek S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/149049.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53366, 3685, 'Dawson\'s Creek S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149050.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53367, 3685, 'Dawson\'s Creek S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149051.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53368, 3685, 'Dawson\'s Creek S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149052.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53369, 3685, 'Dawson\'s Creek S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149053.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53370, 3685, 'Dawson\'s Creek S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149054.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53371, 3685, 'Dawson\'s Creek S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149055.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53372, 3685, 'Dawson\'s Creek S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149056.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53373, 3685, 'Dawson\'s Creek S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149057.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53374, 3685, 'Dawson\'s Creek S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149058.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53375, 3685, 'Dawson\'s Creek S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149059.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53376, 3685, 'Dawson\'s Creek S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149060.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53377, 3685, 'Dawson\'s Creek S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149061.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53378, 3685, 'Dawson\'s Creek S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/149062.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53379, 3685, 'Dawson\'s Creek S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/149063.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53380, 3685, 'Dawson\'s Creek S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/149064.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53381, 3685, 'Dawson\'s Creek S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/149065.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53382, 3685, 'Dawson\'s Creek S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/149066.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53383, 3685, 'Dawson\'s Creek S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/149067.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53384, 3685, 'Dawson\'s Creek S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/149068.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53385, 3685, 'Dawson\'s Creek S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/149069.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53386, 3685, 'Dawson\'s Creek S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/149070.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53387, 3685, 'Dawson\'s Creek S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/149071.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53388, 3685, 'Dawson\'s Creek S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/149072.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53389, 3685, 'Dawson\'s Creek S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/149073.mp4', 'http://gstaticontent.com/images/dmUJgcexAi235vXwDmYdLQFunbR_big.jpg'),
(53390, 3686, 'Minha Receita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152111.mp4', 'http://gstaticontent.com/images/xoljCDsIZMvVe3HzPcZHM5kDGy3_big.jpg'),
(53391, 3686, 'Minha Receita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152112.mp4', 'http://gstaticontent.com/images/xoljCDsIZMvVe3HzPcZHM5kDGy3_big.jpg'),
(53392, 3686, 'Minha Receita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152113.mp4', 'http://gstaticontent.com/images/xoljCDsIZMvVe3HzPcZHM5kDGy3_big.jpg'),
(53393, 3686, 'Minha Receita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152114.mp4', 'http://gstaticontent.com/images/xoljCDsIZMvVe3HzPcZHM5kDGy3_big.jpg'),
(53394, 3686, 'Minha Receita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152115.mp4', 'http://gstaticontent.com/images/xoljCDsIZMvVe3HzPcZHM5kDGy3_big.jpg'),
(53395, 3686, 'Minha Receita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152116.mp4', 'http://gstaticontent.com/images/xoljCDsIZMvVe3HzPcZHM5kDGy3_big.jpg'),
(53396, 3686, 'Minha Receita S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152117.mp4', 'http://gstaticontent.com/images/xoljCDsIZMvVe3HzPcZHM5kDGy3_big.jpg'),
(53397, 3686, 'Minha Receita S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152118.mp4', 'http://gstaticontent.com/images/xoljCDsIZMvVe3HzPcZHM5kDGy3_big.jpg'),
(53398, 3686, 'Minha Receita S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152119.mp4', 'http://gstaticontent.com/images/xoljCDsIZMvVe3HzPcZHM5kDGy3_big.jpg'),
(53399, 3686, 'Minha Receita S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152120.mp4', 'http://gstaticontent.com/images/xoljCDsIZMvVe3HzPcZHM5kDGy3_big.jpg'),
(53400, 3687, 'Minha Receita S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152121.mp4', 'http://gstaticontent.com/images/xoljCDsIZMvVe3HzPcZHM5kDGy3_big.jpg'),
(53401, 3687, 'Minha Receita S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152122.mp4', 'http://gstaticontent.com/images/xoljCDsIZMvVe3HzPcZHM5kDGy3_big.jpg'),
(53402, 3687, 'Minha Receita S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152123.mp4', 'http://gstaticontent.com/images/xoljCDsIZMvVe3HzPcZHM5kDGy3_big.jpg'),
(53403, 3687, 'Minha Receita S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152124.mp4', 'http://gstaticontent.com/images/xoljCDsIZMvVe3HzPcZHM5kDGy3_big.jpg'),
(53404, 3687, 'Minha Receita S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152125.mp4', 'http://gstaticontent.com/images/xoljCDsIZMvVe3HzPcZHM5kDGy3_big.jpg'),
(53405, 3687, 'Minha Receita S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152126.mp4', 'http://gstaticontent.com/images/xoljCDsIZMvVe3HzPcZHM5kDGy3_big.jpg'),
(53406, 3687, 'Minha Receita S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152127.mp4', 'http://gstaticontent.com/images/xoljCDsIZMvVe3HzPcZHM5kDGy3_big.jpg'),
(53407, 3687, 'Minha Receita S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152128.mp4', 'http://gstaticontent.com/images/xoljCDsIZMvVe3HzPcZHM5kDGy3_big.jpg'),
(53408, 3687, 'Minha Receita S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152129.mp4', 'http://gstaticontent.com/images/xoljCDsIZMvVe3HzPcZHM5kDGy3_big.jpg'),
(53409, 3687, 'Minha Receita S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152130.mp4', 'http://gstaticontent.com/images/xoljCDsIZMvVe3HzPcZHM5kDGy3_big.jpg'),
(53410, 3688, 'Miraculous: As Aventuras de LadyBug S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221513.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53411, 3688, 'Miraculous: As Aventuras de LadyBug S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221514.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53412, 3688, 'Miraculous: As Aventuras de LadyBug S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221515.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53413, 3688, 'Miraculous: As Aventuras de LadyBug S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221516.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53414, 3688, 'Miraculous: As Aventuras de LadyBug S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221517.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53415, 3688, 'Miraculous: As Aventuras de LadyBug S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221518.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53416, 3688, 'Miraculous: As Aventuras de LadyBug S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221519.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53417, 3688, 'Miraculous: As Aventuras de LadyBug S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221520.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53418, 3688, 'Miraculous: As Aventuras de LadyBug S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221521.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53419, 3688, 'Miraculous: As Aventuras de LadyBug S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221522.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53420, 3688, 'Miraculous: As Aventuras de LadyBug S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221523.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53421, 3688, 'Miraculous: As Aventuras de LadyBug S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221524.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53422, 3688, 'Miraculous: As Aventuras de LadyBug S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221525.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53423, 3688, 'Miraculous: As Aventuras de LadyBug S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/221526.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53424, 3688, 'Miraculous: As Aventuras de LadyBug S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/221527.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53425, 3688, 'Miraculous: As Aventuras de LadyBug S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/221528.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53426, 3688, 'Miraculous: As Aventuras de LadyBug S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/221529.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53427, 3688, 'Miraculous: As Aventuras de LadyBug S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/221530.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53428, 3688, 'Miraculous: As Aventuras de LadyBug S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/221531.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53429, 3688, 'Miraculous: As Aventuras de LadyBug S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/221532.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53430, 3688, 'Miraculous: As Aventuras de LadyBug S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/221533.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53431, 3688, 'Miraculous: As Aventuras de LadyBug S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/221534.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53432, 3688, 'Miraculous: As Aventuras de LadyBug S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/221535.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53433, 3688, 'Miraculous: As Aventuras de LadyBug S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/221536.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53434, 3688, 'Miraculous: As Aventuras de LadyBug S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/221537.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53435, 3688, 'Miraculous: As Aventuras de LadyBug S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/221538.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53436, 3689, 'Miraculous: As Aventuras de LadyBug S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/569460.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53437, 3689, 'Miraculous: As Aventuras de LadyBug S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221541.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53438, 3689, 'Miraculous: As Aventuras de LadyBug S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221542.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53439, 3689, 'Miraculous: As Aventuras de LadyBug S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221543.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53440, 3689, 'Miraculous: As Aventuras de LadyBug S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221544.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53441, 3689, 'Miraculous: As Aventuras de LadyBug S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221545.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53442, 3689, 'Miraculous: As Aventuras de LadyBug S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221546.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53443, 3689, 'Miraculous: As Aventuras de LadyBug S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221547.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53444, 3689, 'Miraculous: As Aventuras de LadyBug S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221548.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53445, 3689, 'Miraculous: As Aventuras de LadyBug S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221549.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53446, 3689, 'Miraculous: As Aventuras de LadyBug S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221550.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53447, 3689, 'Miraculous: As Aventuras de LadyBug S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221551.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53448, 3689, 'Miraculous: As Aventuras de LadyBug S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221552.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53449, 3689, 'Miraculous: As Aventuras de LadyBug S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/221553.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53450, 3689, 'Miraculous: As Aventuras de LadyBug S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/221554.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53451, 3689, 'Miraculous: As Aventuras de LadyBug S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/221555.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53452, 3689, 'Miraculous: As Aventuras de LadyBug S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/221556.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53453, 3689, 'Miraculous: As Aventuras de LadyBug S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/221557.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53454, 3689, 'Miraculous: As Aventuras de LadyBug S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/221558.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53455, 3689, 'Miraculous: As Aventuras de LadyBug S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/221559.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53456, 3689, 'Miraculous: As Aventuras de LadyBug S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/221560.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53457, 3689, 'Miraculous: As Aventuras de LadyBug S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/221561.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53458, 3689, 'Miraculous: As Aventuras de LadyBug S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/221562.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53459, 3689, 'Miraculous: As Aventuras de LadyBug S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/221563.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53460, 3689, 'Miraculous: As Aventuras de LadyBug S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/221564.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53461, 3690, 'Miraculous: As Aventuras de LadyBug S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221565.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53462, 3690, 'Miraculous: As Aventuras de LadyBug S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221566.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53463, 3690, 'Miraculous: As Aventuras de LadyBug S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221567.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53464, 3690, 'Miraculous: As Aventuras de LadyBug S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221568.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53465, 3690, 'Miraculous: As Aventuras de LadyBug S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221569.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53466, 3690, 'Miraculous: As Aventuras de LadyBug S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221570.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53467, 3690, 'Miraculous: As Aventuras de LadyBug S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221571.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53468, 3690, 'Miraculous: As Aventuras de LadyBug S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221572.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53469, 3690, 'Miraculous: As Aventuras de LadyBug S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221573.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53470, 3690, 'Miraculous: As Aventuras de LadyBug S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221574.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53471, 3690, 'Miraculous: As Aventuras de LadyBug S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221575.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53472, 3690, 'Miraculous: As Aventuras de LadyBug S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221576.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53473, 3690, 'Miraculous: As Aventuras de LadyBug S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221577.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53474, 3690, 'Miraculous: As Aventuras de LadyBug S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/221578.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53475, 3690, 'Miraculous: As Aventuras de LadyBug S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/221579.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53476, 3690, 'Miraculous: As Aventuras de LadyBug S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/221580.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53477, 3690, 'Miraculous: As Aventuras de LadyBug S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/221581.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53478, 3690, 'Miraculous: As Aventuras de LadyBug S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/221582.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53479, 3690, 'Miraculous: As Aventuras de LadyBug S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/221583.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53480, 3690, 'Miraculous: As Aventuras de LadyBug S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/221584.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53481, 3690, 'Miraculous: As Aventuras de LadyBug S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/221585.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53482, 3690, 'Miraculous: As Aventuras de LadyBug S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/221586.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53483, 3690, 'Miraculous: As Aventuras de LadyBug S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/221587.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53484, 3690, 'Miraculous: As Aventuras de LadyBug S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/221588.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53485, 3690, 'Miraculous: As Aventuras de LadyBug S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/221589.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53486, 3690, 'Miraculous: As Aventuras de LadyBug S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/221590.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53487, 3691, 'Miraculous: As Aventuras de LadyBug S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221591.mp4', 'http://timg.bdta.pro/images/193e8dc8fe740a3c96d87c8288355922.jpg'),
(53488, 3691, 'Miraculous: As Aventuras de LadyBug S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221592.mp4', 'http://timg.bdta.pro/images/d1a5b685b567322393820a0106ce8fd5.jpg'),
(53489, 3691, 'Miraculous: As Aventuras de LadyBug S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221593.mp4', 'http://timg.bdta.pro/images/18625c10ca28dcab13b7cff0b25b3f03.jpg'),
(53490, 3691, 'Miraculous: As Aventuras de LadyBug S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221594.mp4', 'http://timg.bdta.pro/images/54461e6d5850a64c340f7cef5d4e0b4e.jpg'),
(53491, 3691, 'Miraculous: As Aventuras de LadyBug S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221595.mp4', 'http://timg.bdta.pro/images/240310a988910589833bbf63e1015e0c.jpg'),
(53492, 3691, 'Miraculous: As Aventuras de LadyBug S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221596.mp4', 'http://timg.bdta.pro/images/96357b9c2ff191683d1fd9cff0e6b92f.jpg'),
(53493, 3691, 'Miraculous: As Aventuras de LadyBug S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221597.mp4', 'http://timg.bdta.pro/images/041e3b9d4fbc7dedb0e76627f161c043.jpg'),
(53494, 3691, 'Miraculous: As Aventuras de LadyBug S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221598.mp4', 'http://timg.bdta.pro/images/765cf4b5689eec4091cb4801ed77fe56.jpg'),
(53495, 3691, 'Miraculous: As Aventuras de LadyBug S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221599.mp4', 'http://timg.bdta.pro/images/891d1bbd05df88ec8ed082f143027728.jpg'),
(53496, 3691, 'Miraculous: As Aventuras de LadyBug S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221600.mp4', 'http://timg.bdta.pro/images/a4f5cd0436d10d9fade36812ce603624.jpg'),
(53497, 3691, 'Miraculous: As Aventuras de LadyBug S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221601.mp4', 'http://timg.bdta.pro/images/f2c21cbaf38e0d57cc3c5365550f5905.jpg'),
(53498, 3691, 'Miraculous: As Aventuras de LadyBug S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221602.mp4', 'http://timg.bdta.pro/images/f9f03e5458b1f0715223387cfed43d4a.jpg'),
(53499, 3691, 'Miraculous: As Aventuras de LadyBug S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221603.mp4', 'http://timg.bdta.pro/images/a4487d6feb9b87c212a1af08d0c36bf5.jpg'),
(53500, 3691, 'Miraculous: As Aventuras de LadyBug S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/221604.mp4', 'http://timg.bdta.pro/images/3c2c1c2292127dcf5a14b928a739efdc.jpg'),
(53501, 3691, 'Miraculous: As Aventuras de LadyBug S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/221605.mp4', 'http://timg.bdta.pro/images/9ebe6ef02a74ea4da60d15d437b732ca.jpg'),
(53502, 3691, 'Miraculous: As Aventuras de LadyBug S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/221606.mp4', 'http://timg.bdta.pro/images/8f23aeacdfe1a4bde43bea069c7445df.jpg'),
(53503, 3691, 'Miraculous: As Aventuras de LadyBug S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/221607.mp4', 'http://timg.bdta.pro/images/b2c54d3a3ad474db227f59ee9782a8e7.jpg'),
(53504, 3691, 'Miraculous: As Aventuras de LadyBug S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/221608.mp4', 'http://timg.bdta.pro/images/f655f2e0b927ab240d3da0b067ed99e8.jpg'),
(53505, 3691, 'Miraculous: As Aventuras de LadyBug S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/221609.mp4', 'http://timg.bdta.pro/images/293b921acffd647ef17f1960fac49296.jpg'),
(53506, 3691, 'Miraculous: As Aventuras de LadyBug S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/221610.mp4', 'http://timg.bdta.pro/images/372a07c7efd6ab60d88812b67bac1203.jpg'),
(53507, 3691, 'Miraculous: As Aventuras de LadyBug S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/221611.mp4', 'http://timg.bdta.pro/images/c0b191b6aa0acd838dbd344b0803ec08.jpg'),
(53508, 3691, 'Miraculous: As Aventuras de LadyBug S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/221612.mp4', 'http://timg.bdta.pro/images/9c5f59c7e29a16982cbc76372b54ab6f.jpg'),
(53509, 3691, 'Miraculous: As Aventuras de LadyBug S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/221613.mp4', 'http://timg.bdta.pro/images/25392735425f80d0649a40cd6bd096a0.jpg'),
(53510, 3691, 'Miraculous: As Aventuras de LadyBug S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/221614.mp4', 'http://timg.bdta.pro/images/5a16ae9abc88d0274d75cc6981ccfa36.jpg'),
(53511, 3691, 'Miraculous: As Aventuras de LadyBug S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/221615.mp4', 'http://timg.bdta.pro/images/499348ec34d78267d5cb6c345ef337b5.jpg'),
(53512, 3691, 'Miraculous: As Aventuras de LadyBug S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/221616.mp4', 'http://timg.bdta.pro/images/7ee111c79064c6f2b95abe4099dd7216.jpg'),
(53513, 3692, 'Miraculous: As Aventuras de LadyBug S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JGVCyrB2bBbbB2zCO6lETmcEt4.jpg'),
(53514, 3692, 'Miraculous: As Aventuras de LadyBug S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ffDqfsC12rWbg4gNFwIVHRePZtz.jpg'),
(53515, 3692, 'Miraculous: As Aventuras de LadyBug S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJ4VlZrzsstFrxeqT6e9mCNEZiP.jpg'),
(53516, 3692, 'Miraculous: As Aventuras de LadyBug S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xUghyDup3Ll6Eiy1FGTsyX5zaMH.jpg'),
(53517, 3692, 'Miraculous: As Aventuras de LadyBug S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q39RLcsyHN6zYKAPsyhJxEqEPZZ.jpg'),
(53518, 3692, 'Miraculous: As Aventuras de LadyBug S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/voB93keQJgYMmqLauHIgTFn6RLV.jpg'),
(53519, 3692, 'Miraculous: As Aventuras de LadyBug S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nqUGM0XLfac0UFp9Fm6moVbgtpc.jpg'),
(53520, 3692, 'Miraculous: As Aventuras de LadyBug S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/irHXOSXeV9CKTvj4UOLNIfEkEtr.jpg'),
(53521, 3692, 'Miraculous: As Aventuras de LadyBug S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mShB21QPIuEGqoKWoLDMjMsQ4hT.jpg'),
(53522, 3692, 'Miraculous: As Aventuras de LadyBug S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/78hrI0LMXWvdJc53eMjM84Bxu8P.jpg'),
(53523, 3692, 'Miraculous: As Aventuras de LadyBug S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/587gUFHu1Xe5XSg49NnMNAatZio.jpg'),
(53524, 3692, 'Miraculous: As Aventuras de LadyBug S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/G3VGTYKPZ4X6aFSxAMu7eznxFn.jpg'),
(53525, 3692, 'Miraculous: As Aventuras de LadyBug S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r6kZQREjqii5yIxM6Q42KzEfjxT.jpg'),
(53526, 3692, 'Miraculous: As Aventuras de LadyBug S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/221630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rZKXyDa2aPVT3IKDAJwMW3ZHUnX.jpg'),
(53527, 3692, 'Miraculous: As Aventuras de LadyBug S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/221631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9eE6QwEDzVI42Rc0WjTgzTlL78c.jpg'),
(53528, 3692, 'Miraculous: As Aventuras de LadyBug S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/221632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9U5UpyeVtasiGDjeRRq4F0hvO76.jpg'),
(53529, 3692, 'Miraculous: As Aventuras de LadyBug S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/221633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/44PEqH5Y1TkCYQm2IhQYtDYapG3.jpg'),
(53530, 3692, 'Miraculous: As Aventuras de LadyBug S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/221634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hNiGoj9HNLI0ONQuQsEQiET38vC.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(53531, 3692, 'Miraculous: As Aventuras de LadyBug S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/221635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gNjCYJlvppHzDeGjgEEtJkvvD8b.jpg'),
(53532, 3692, 'Miraculous: As Aventuras de LadyBug S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/221636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wvPwIfxsQKXiDYH6X1fyf41iBjf.jpg'),
(53533, 3692, 'Miraculous: As Aventuras de LadyBug S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/221637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJc5R5Bhe6ABhV2V3qh3vOvif8H.jpg'),
(53534, 3692, 'Miraculous: As Aventuras de LadyBug S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/221638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgH7tOx2bcXgm9mH0NUrbpbMrO4.jpg'),
(53535, 3692, 'Miraculous: As Aventuras de LadyBug S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/221639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bUl7VpZgm9zYE77jGUFI8F4rIBQ.jpg'),
(53536, 3693, 'Miraculous: As Aventuras de LadyBug S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/712734.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53537, 3693, 'Miraculous: As Aventuras de LadyBug S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/712735.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53538, 3693, 'Miraculous: As Aventuras de LadyBug S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/712736.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53539, 3693, 'Miraculous: As Aventuras de LadyBug S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/712737.mp4', 'http://gstaticontent.com/images/aNioAFrdtbKNrdcE1jAXuINxdwF_big.jpg'),
(53540, 3694, 'The Red Line: Vidas Cruzadas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148938.mp4', 'http://gstaticontent.com/images/r6EYUEOBHu2haKq5q6KE1bsXgIU_big.jpg'),
(53541, 3694, 'The Red Line: Vidas Cruzadas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148939.mp4', 'http://gstaticontent.com/images/r6EYUEOBHu2haKq5q6KE1bsXgIU_big.jpg'),
(53542, 3694, 'The Red Line: Vidas Cruzadas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148940.mp4', 'http://gstaticontent.com/images/r6EYUEOBHu2haKq5q6KE1bsXgIU_big.jpg'),
(53543, 3694, 'The Red Line: Vidas Cruzadas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148941.mp4', 'http://gstaticontent.com/images/r6EYUEOBHu2haKq5q6KE1bsXgIU_big.jpg'),
(53544, 3694, 'The Red Line: Vidas Cruzadas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148942.mp4', 'http://gstaticontent.com/images/r6EYUEOBHu2haKq5q6KE1bsXgIU_big.jpg'),
(53545, 3694, 'The Red Line: Vidas Cruzadas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148943.mp4', 'http://gstaticontent.com/images/r6EYUEOBHu2haKq5q6KE1bsXgIU_big.jpg'),
(53546, 3694, 'The Red Line: Vidas Cruzadas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148944.mp4', 'http://gstaticontent.com/images/r6EYUEOBHu2haKq5q6KE1bsXgIU_big.jpg'),
(53547, 3694, 'The Red Line: Vidas Cruzadas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148945.mp4', 'http://gstaticontent.com/images/r6EYUEOBHu2haKq5q6KE1bsXgIU_big.jpg'),
(53548, 3695, 'Admirável Mundo Novo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148929.mp4', 'http://gstaticontent.com/images/vPl7hAY0vt0OPhIflRb5IXrssBv_big.jpg'),
(53549, 3695, 'Admirável Mundo Novo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148930.mp4', 'http://gstaticontent.com/images/vPl7hAY0vt0OPhIflRb5IXrssBv_big.jpg'),
(53550, 3695, 'Admirável Mundo Novo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148931.mp4', 'http://gstaticontent.com/images/vPl7hAY0vt0OPhIflRb5IXrssBv_big.jpg'),
(53551, 3695, 'Admirável Mundo Novo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148932.mp4', 'http://gstaticontent.com/images/vPl7hAY0vt0OPhIflRb5IXrssBv_big.jpg'),
(53552, 3695, 'Admirável Mundo Novo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148933.mp4', 'http://gstaticontent.com/images/vPl7hAY0vt0OPhIflRb5IXrssBv_big.jpg'),
(53553, 3695, 'Admirável Mundo Novo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148934.mp4', 'http://gstaticontent.com/images/vPl7hAY0vt0OPhIflRb5IXrssBv_big.jpg'),
(53554, 3695, 'Admirável Mundo Novo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148935.mp4', 'http://gstaticontent.com/images/vPl7hAY0vt0OPhIflRb5IXrssBv_big.jpg'),
(53555, 3695, 'Admirável Mundo Novo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148936.mp4', 'http://gstaticontent.com/images/vPl7hAY0vt0OPhIflRb5IXrssBv_big.jpg'),
(53556, 3695, 'Admirável Mundo Novo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148937.mp4', 'http://gstaticontent.com/images/vPl7hAY0vt0OPhIflRb5IXrssBv_big.jpg'),
(53557, 3696, 'Dr. Stone S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53558, 3696, 'Dr. Stone S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53559, 3696, 'Dr. Stone S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53560, 3696, 'Dr. Stone S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53561, 3696, 'Dr. Stone S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53562, 3696, 'Dr. Stone S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53563, 3696, 'Dr. Stone S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53564, 3696, 'Dr. Stone S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53565, 3696, 'Dr. Stone S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53566, 3696, 'Dr. Stone S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53567, 3696, 'Dr. Stone S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53568, 3696, 'Dr. Stone S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53569, 3696, 'Dr. Stone S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53570, 3696, 'Dr. Stone S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53571, 3696, 'Dr. Stone S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53572, 3696, 'Dr. Stone S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/251477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53573, 3696, 'Dr. Stone S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/251478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53574, 3696, 'Dr. Stone S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/251479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53575, 3696, 'Dr. Stone S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/251480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53576, 3696, 'Dr. Stone S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/251481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53577, 3696, 'Dr. Stone S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/251482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53578, 3696, 'Dr. Stone S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/251483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53579, 3696, 'Dr. Stone S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/251484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53580, 3696, 'Dr. Stone S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/251485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53581, 3697, 'Dr. Stone S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53582, 3697, 'Dr. Stone S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53583, 3697, 'Dr. Stone S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53584, 3697, 'Dr. Stone S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53585, 3697, 'Dr. Stone S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53586, 3697, 'Dr. Stone S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53587, 3697, 'Dr. Stone S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53588, 3697, 'Dr. Stone S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53589, 3697, 'Dr. Stone S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53590, 3697, 'Dr. Stone S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53591, 3697, 'Dr. Stone S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53592, 3698, 'Dr. Stone S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x3hrsz8A6WX1crKV5WLiMkvUuvo.jpg'),
(53593, 3698, 'Dr. Stone S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o15nnT0jmjhMfxLPn00PgkSisR7.jpg'),
(53594, 3698, 'Dr. Stone S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7uRDjro0Z42MHQFT5AyFaUxvY6M.jpg'),
(53595, 3698, 'Dr. Stone S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251500.mp4', 'http://image.tmdb.org/t/p/w1280/aVA397LlFUhOTIrEt9k3F7OKk6M.jpg'),
(53596, 3698, 'Dr. Stone S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251501.mp4', 'http://image.tmdb.org/t/p/w1280/3IjMInLbkq1mygdPzWSmj6Mrdp8.jpg'),
(53597, 3698, 'Dr. Stone S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251502.mp4', 'http://image.tmdb.org/t/p/w1280/v8hh3pmeXKH4MtPFajLqOQ3Hvqr.jpg'),
(53598, 3698, 'Dr. Stone S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251503.mp4', 'http://image.tmdb.org/t/p/w1280/4fgL5cLY8SqjUOyO3KC1ycPSBaB.jpg'),
(53599, 3698, 'Dr. Stone S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53600, 3698, 'Dr. Stone S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251505.mp4', 'http://image.tmdb.org/t/p/w1280/7LhbWIVc3mJf0cjshNwpVWJDLAQ.jpg'),
(53601, 3698, 'Dr. Stone S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251506.mp4', 'http://image.tmdb.org/t/p/w1280/7OeCecH8SqkaKXDV9aS9vyMyKQz.jpg'),
(53602, 3698, 'Dr. Stone S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251507.mp4', 'http://image.tmdb.org/t/p/w1280/b577K4Y15J2zop96edjtQRjeG5S.jpg'),
(53603, 3698, 'Dr. Stone S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53604, 3698, 'Dr. Stone S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53605, 3698, 'Dr. Stone S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53606, 3698, 'Dr. Stone S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53607, 3698, 'Dr. Stone S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/251512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53608, 3698, 'Dr. Stone S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/251513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53609, 3698, 'Dr. Stone S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/251514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53610, 3698, 'Dr. Stone S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/251515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53611, 3698, 'Dr. Stone S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/251516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53612, 3698, 'Dr. Stone S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/251517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53613, 3698, 'Dr. Stone S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/251518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53614, 3699, 'Dr. Stone S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/663067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53615, 3699, 'Dr. Stone S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/665185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53616, 3699, 'Dr. Stone S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/673089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53617, 3699, 'Dr. Stone S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/679900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53618, 3699, 'Dr. Stone S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/687764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53619, 3699, 'Dr. Stone S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/698278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53620, 3699, 'Dr. Stone S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/702121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53621, 3699, 'Dr. Stone S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/707968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53622, 3699, 'Dr. Stone S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/718690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53623, 3699, 'Dr. Stone S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/724178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53624, 3699, 'Dr. Stone S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/730630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53625, 3699, 'Dr. Stone S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/742855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53626, 3699, 'Dr. Stone S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/865625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53627, 3699, 'Dr. Stone S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/870735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53628, 3699, 'Dr. Stone S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/878314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53629, 3699, 'Dr. Stone S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/879425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53630, 3699, 'Dr. Stone S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/879888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53631, 3699, 'Dr. Stone S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/880591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53632, 3699, 'Dr. Stone S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/881228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53633, 3699, 'Dr. Stone S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/881341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53634, 3699, 'Dr. Stone S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/883030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53635, 3699, 'Dr. Stone S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/883808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53636, 3699, 'Dr. Stone S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/885331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53637, 3699, 'Dr. Stone S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/886096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dLlnzbDCblBXcJqFLXyvN43NIwp.jpg'),
(53638, 3700, 'Special S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148913.mp4', 'http://gstaticontent.com/images/5irp9x6zoX5CErNNryXtUXB8OwS_big.jpg'),
(53639, 3700, 'Special S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148914.mp4', 'http://gstaticontent.com/images/5irp9x6zoX5CErNNryXtUXB8OwS_big.jpg'),
(53640, 3700, 'Special S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148915.mp4', 'http://gstaticontent.com/images/5irp9x6zoX5CErNNryXtUXB8OwS_big.jpg'),
(53641, 3700, 'Special S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148916.mp4', 'http://gstaticontent.com/images/5irp9x6zoX5CErNNryXtUXB8OwS_big.jpg'),
(53642, 3700, 'Special S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148917.mp4', 'http://gstaticontent.com/images/5irp9x6zoX5CErNNryXtUXB8OwS_big.jpg'),
(53643, 3700, 'Special S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148918.mp4', 'http://gstaticontent.com/images/5irp9x6zoX5CErNNryXtUXB8OwS_big.jpg'),
(53644, 3700, 'Special S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148919.mp4', 'http://gstaticontent.com/images/5irp9x6zoX5CErNNryXtUXB8OwS_big.jpg'),
(53645, 3700, 'Special S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148920.mp4', 'http://gstaticontent.com/images/5irp9x6zoX5CErNNryXtUXB8OwS_big.jpg'),
(53646, 3701, 'Special S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148921.mp4', 'http://gstaticontent.com/images/5irp9x6zoX5CErNNryXtUXB8OwS_big.jpg'),
(53647, 3701, 'Special S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148922.mp4', 'http://gstaticontent.com/images/5irp9x6zoX5CErNNryXtUXB8OwS_big.jpg'),
(53648, 3701, 'Special S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148923.mp4', 'http://gstaticontent.com/images/5irp9x6zoX5CErNNryXtUXB8OwS_big.jpg'),
(53649, 3701, 'Special S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148924.mp4', 'http://gstaticontent.com/images/5irp9x6zoX5CErNNryXtUXB8OwS_big.jpg'),
(53650, 3701, 'Special S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148925.mp4', 'http://gstaticontent.com/images/5irp9x6zoX5CErNNryXtUXB8OwS_big.jpg'),
(53651, 3701, 'Special S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148926.mp4', 'http://gstaticontent.com/images/5irp9x6zoX5CErNNryXtUXB8OwS_big.jpg'),
(53652, 3701, 'Special S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148927.mp4', 'http://gstaticontent.com/images/5irp9x6zoX5CErNNryXtUXB8OwS_big.jpg'),
(53653, 3701, 'Special S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148928.mp4', 'http://gstaticontent.com/images/5irp9x6zoX5CErNNryXtUXB8OwS_big.jpg'),
(53654, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148757.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53655, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148758.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53656, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148759.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53657, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148760.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53658, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148761.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53659, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148762.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53660, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148763.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53661, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148764.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53662, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148765.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53663, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148766.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53664, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148767.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53665, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148768.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53666, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148769.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53667, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148770.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53668, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148771.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53669, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148772.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53670, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/148773.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53671, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/148774.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53672, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/148775.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53673, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/148776.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53674, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/148777.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53675, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/148778.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53676, 3702, 'The Good Wife - Pelo Direito de Recomeçar S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/148779.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53677, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148780.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53678, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148781.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53679, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148782.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53680, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148783.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53681, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148784.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53682, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148785.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53683, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148786.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53684, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148787.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53685, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148788.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53686, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148789.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53687, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148790.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53688, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148791.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53689, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148792.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53690, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148793.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53691, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148794.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53692, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148795.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53693, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/148796.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53694, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/148797.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53695, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/148798.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53696, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/148799.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53697, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/148800.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53698, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/148801.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53699, 3703, 'The Good Wife - Pelo Direito de Recomeçar S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/148802.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53700, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148803.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53701, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148804.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53702, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148805.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53703, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148806.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53704, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148807.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53705, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148808.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53706, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148809.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53707, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148810.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53708, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148811.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53709, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148812.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53710, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148813.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53711, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148814.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53712, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148815.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53713, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148816.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53714, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148817.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53715, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148818.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53716, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/148819.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53717, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/148820.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53718, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/148821.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53719, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/148822.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53720, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/148823.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53721, 3704, 'The Good Wife - Pelo Direito de Recomeçar S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/148824.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53722, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148825.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53723, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148826.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53724, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148827.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53725, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148828.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53726, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148829.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53727, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148830.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53728, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148831.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53729, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148832.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53730, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148833.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53731, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148834.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53732, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148835.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53733, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148836.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53734, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148837.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53735, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148838.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53736, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148839.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53737, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148840.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53738, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/148841.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53739, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/148842.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53740, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/148843.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53741, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/148844.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53742, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/148845.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53743, 3705, 'The Good Wife - Pelo Direito de Recomeçar S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/148846.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53744, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148847.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53745, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148848.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53746, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148849.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53747, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148850.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53748, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148851.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53749, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148852.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53750, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148853.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53751, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148854.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53752, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148855.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53753, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148856.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53754, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148857.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53755, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148858.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53756, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148859.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53757, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148860.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53758, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148861.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53759, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148862.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53760, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/148863.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53761, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/148864.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53762, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/148865.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53763, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/148866.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53764, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/148867.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53765, 3706, 'The Good Wife - Pelo Direito de Recomeçar S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/148868.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53766, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148869.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53767, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148870.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53768, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148871.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53769, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148872.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53770, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148873.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53771, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148874.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53772, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148875.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53773, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148876.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53774, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148877.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53775, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148878.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53776, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148879.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53777, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148880.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53778, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148881.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53779, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148882.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53780, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148883.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53781, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148884.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53782, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/148885.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53783, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/148886.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53784, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/148887.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53785, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/148888.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53786, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/148889.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53787, 3707, 'The Good Wife - Pelo Direito de Recomeçar S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/148890.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53788, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148891.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53789, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148892.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(53790, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148893.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53791, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148894.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53792, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148895.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53793, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148896.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53794, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148897.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53795, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148898.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53796, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148899.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53797, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148900.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53798, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148901.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53799, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148902.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53800, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148903.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53801, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148904.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53802, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148905.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53803, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148906.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53804, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/148907.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53805, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/148908.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53806, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/148909.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53807, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/148910.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53808, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/148911.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53809, 3708, 'The Good Wife - Pelo Direito de Recomeçar S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/148912.mp4', 'http://gstaticontent.com/images/d2kFoQpYTFMp5OI55OIwi7cn4Qe_big.jpg'),
(53810, 3709, 'Dois Homens e Meio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148484.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53811, 3709, 'Dois Homens e Meio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148485.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53812, 3709, 'Dois Homens e Meio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148486.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53813, 3709, 'Dois Homens e Meio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148487.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53814, 3709, 'Dois Homens e Meio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148488.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53815, 3709, 'Dois Homens e Meio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148489.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53816, 3709, 'Dois Homens e Meio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148490.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53817, 3709, 'Dois Homens e Meio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148491.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53818, 3709, 'Dois Homens e Meio S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148492.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53819, 3709, 'Dois Homens e Meio S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148493.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53820, 3709, 'Dois Homens e Meio S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148494.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53821, 3709, 'Dois Homens e Meio S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148495.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53822, 3709, 'Dois Homens e Meio S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148496.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53823, 3709, 'Dois Homens e Meio S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148497.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53824, 3709, 'Dois Homens e Meio S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148498.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53825, 3709, 'Dois Homens e Meio S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148499.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53826, 3709, 'Dois Homens e Meio S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/148500.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53827, 3709, 'Dois Homens e Meio S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/148501.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53828, 3709, 'Dois Homens e Meio S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/148502.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53829, 3709, 'Dois Homens e Meio S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/148503.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53830, 3709, 'Dois Homens e Meio S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/148504.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53831, 3709, 'Dois Homens e Meio S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/148505.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53832, 3709, 'Dois Homens e Meio S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/148506.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53833, 3709, 'Dois Homens e Meio S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/148507.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53834, 3710, 'Dois Homens e Meio S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148508.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53835, 3710, 'Dois Homens e Meio S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148509.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53836, 3710, 'Dois Homens e Meio S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148510.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53837, 3710, 'Dois Homens e Meio S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148511.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53838, 3710, 'Dois Homens e Meio S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148512.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53839, 3710, 'Dois Homens e Meio S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148513.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53840, 3710, 'Dois Homens e Meio S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148514.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53841, 3710, 'Dois Homens e Meio S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148515.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53842, 3710, 'Dois Homens e Meio S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148516.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53843, 3710, 'Dois Homens e Meio S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148517.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53844, 3710, 'Dois Homens e Meio S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148518.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53845, 3710, 'Dois Homens e Meio S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148519.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53846, 3710, 'Dois Homens e Meio S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148520.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53847, 3710, 'Dois Homens e Meio S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148521.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53848, 3710, 'Dois Homens e Meio S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148522.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53849, 3710, 'Dois Homens e Meio S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148523.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53850, 3710, 'Dois Homens e Meio S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/148524.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53851, 3710, 'Dois Homens e Meio S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/148525.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53852, 3710, 'Dois Homens e Meio S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/148526.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53853, 3710, 'Dois Homens e Meio S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/148527.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53854, 3710, 'Dois Homens e Meio S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/148528.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53855, 3710, 'Dois Homens e Meio S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/148529.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53856, 3710, 'Dois Homens e Meio S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/148530.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53857, 3710, 'Dois Homens e Meio S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/148531.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53858, 3711, 'Dois Homens e Meio S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148532.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53859, 3711, 'Dois Homens e Meio S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148533.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53860, 3711, 'Dois Homens e Meio S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148534.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53861, 3711, 'Dois Homens e Meio S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148535.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53862, 3711, 'Dois Homens e Meio S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148536.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53863, 3711, 'Dois Homens e Meio S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148537.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53864, 3711, 'Dois Homens e Meio S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148538.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53865, 3711, 'Dois Homens e Meio S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148539.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53866, 3711, 'Dois Homens e Meio S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148540.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53867, 3711, 'Dois Homens e Meio S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148541.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53868, 3711, 'Dois Homens e Meio S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148542.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53869, 3711, 'Dois Homens e Meio S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148543.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53870, 3711, 'Dois Homens e Meio S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148544.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53871, 3711, 'Dois Homens e Meio S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148545.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53872, 3711, 'Dois Homens e Meio S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148546.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53873, 3711, 'Dois Homens e Meio S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148547.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53874, 3711, 'Dois Homens e Meio S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/148548.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53875, 3711, 'Dois Homens e Meio S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/148549.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53876, 3711, 'Dois Homens e Meio S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/148550.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53877, 3711, 'Dois Homens e Meio S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/148551.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53878, 3711, 'Dois Homens e Meio S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/148552.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53879, 3711, 'Dois Homens e Meio S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/148553.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53880, 3711, 'Dois Homens e Meio S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/148554.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53881, 3711, 'Dois Homens e Meio S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/148555.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53882, 3712, 'Dois Homens e Meio S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148556.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53883, 3712, 'Dois Homens e Meio S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148557.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53884, 3712, 'Dois Homens e Meio S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148558.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53885, 3712, 'Dois Homens e Meio S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148559.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53886, 3712, 'Dois Homens e Meio S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148560.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53887, 3712, 'Dois Homens e Meio S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148561.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53888, 3712, 'Dois Homens e Meio S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148562.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53889, 3712, 'Dois Homens e Meio S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148563.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53890, 3712, 'Dois Homens e Meio S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148564.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53891, 3712, 'Dois Homens e Meio S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148565.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53892, 3712, 'Dois Homens e Meio S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148566.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53893, 3712, 'Dois Homens e Meio S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148567.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53894, 3712, 'Dois Homens e Meio S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148568.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53895, 3712, 'Dois Homens e Meio S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148569.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53896, 3712, 'Dois Homens e Meio S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148570.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53897, 3712, 'Dois Homens e Meio S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148571.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53898, 3712, 'Dois Homens e Meio S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/148572.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53899, 3712, 'Dois Homens e Meio S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/148573.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53900, 3712, 'Dois Homens e Meio S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/148574.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53901, 3712, 'Dois Homens e Meio S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/148575.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53902, 3712, 'Dois Homens e Meio S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/148576.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53903, 3712, 'Dois Homens e Meio S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/148577.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53904, 3712, 'Dois Homens e Meio S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/148578.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53905, 3712, 'Dois Homens e Meio S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/148579.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53906, 3713, 'Dois Homens e Meio S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148580.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53907, 3713, 'Dois Homens e Meio S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148581.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53908, 3713, 'Dois Homens e Meio S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148582.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53909, 3713, 'Dois Homens e Meio S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148583.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53910, 3713, 'Dois Homens e Meio S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148584.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53911, 3713, 'Dois Homens e Meio S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148585.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53912, 3713, 'Dois Homens e Meio S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148586.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53913, 3713, 'Dois Homens e Meio S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148587.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53914, 3713, 'Dois Homens e Meio S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148588.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53915, 3713, 'Dois Homens e Meio S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148589.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53916, 3713, 'Dois Homens e Meio S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148590.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53917, 3713, 'Dois Homens e Meio S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148591.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53918, 3713, 'Dois Homens e Meio S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148592.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53919, 3713, 'Dois Homens e Meio S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148593.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53920, 3713, 'Dois Homens e Meio S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148594.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53921, 3713, 'Dois Homens e Meio S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148595.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53922, 3713, 'Dois Homens e Meio S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/148596.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53923, 3713, 'Dois Homens e Meio S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/148597.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53924, 3713, 'Dois Homens e Meio S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/148598.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53925, 3714, 'Dois Homens e Meio S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148599.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53926, 3714, 'Dois Homens e Meio S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148600.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53927, 3714, 'Dois Homens e Meio S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148601.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53928, 3714, 'Dois Homens e Meio S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148602.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53929, 3714, 'Dois Homens e Meio S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148603.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53930, 3714, 'Dois Homens e Meio S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148604.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53931, 3714, 'Dois Homens e Meio S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148605.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53932, 3714, 'Dois Homens e Meio S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148606.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53933, 3714, 'Dois Homens e Meio S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148607.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53934, 3714, 'Dois Homens e Meio S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148608.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53935, 3714, 'Dois Homens e Meio S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148609.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53936, 3714, 'Dois Homens e Meio S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148610.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53937, 3714, 'Dois Homens e Meio S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148611.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53938, 3714, 'Dois Homens e Meio S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148612.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53939, 3714, 'Dois Homens e Meio S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148613.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53940, 3714, 'Dois Homens e Meio S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148614.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53941, 3714, 'Dois Homens e Meio S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/148615.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53942, 3714, 'Dois Homens e Meio S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/148616.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53943, 3714, 'Dois Homens e Meio S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/148617.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53944, 3714, 'Dois Homens e Meio S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/148618.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53945, 3714, 'Dois Homens e Meio S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/148619.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53946, 3714, 'Dois Homens e Meio S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/148620.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53947, 3714, 'Dois Homens e Meio S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/148621.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53948, 3714, 'Dois Homens e Meio S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/148622.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53949, 3715, 'Dois Homens e Meio S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148623.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53950, 3715, 'Dois Homens e Meio S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148624.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53951, 3715, 'Dois Homens e Meio S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148625.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53952, 3715, 'Dois Homens e Meio S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148626.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53953, 3715, 'Dois Homens e Meio S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148627.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53954, 3715, 'Dois Homens e Meio S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148628.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53955, 3715, 'Dois Homens e Meio S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148629.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53956, 3715, 'Dois Homens e Meio S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148630.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53957, 3715, 'Dois Homens e Meio S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148631.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53958, 3715, 'Dois Homens e Meio S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148632.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53959, 3715, 'Dois Homens e Meio S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148633.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53960, 3715, 'Dois Homens e Meio S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148634.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53961, 3715, 'Dois Homens e Meio S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148635.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53962, 3715, 'Dois Homens e Meio S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148636.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53963, 3715, 'Dois Homens e Meio S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148637.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53964, 3715, 'Dois Homens e Meio S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148638.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53965, 3715, 'Dois Homens e Meio S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/148639.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53966, 3715, 'Dois Homens e Meio S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/148640.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53967, 3715, 'Dois Homens e Meio S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/148641.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53968, 3715, 'Dois Homens e Meio S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/148642.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53969, 3715, 'Dois Homens e Meio S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/148643.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53970, 3715, 'Dois Homens e Meio S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/148644.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53971, 3716, 'Dois Homens e Meio S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148645.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53972, 3716, 'Dois Homens e Meio S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148646.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53973, 3716, 'Dois Homens e Meio S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148647.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53974, 3716, 'Dois Homens e Meio S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148648.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53975, 3716, 'Dois Homens e Meio S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148649.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53976, 3716, 'Dois Homens e Meio S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148650.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53977, 3716, 'Dois Homens e Meio S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148651.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53978, 3716, 'Dois Homens e Meio S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148652.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53979, 3716, 'Dois Homens e Meio S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148653.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53980, 3716, 'Dois Homens e Meio S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148654.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53981, 3716, 'Dois Homens e Meio S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148655.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53982, 3716, 'Dois Homens e Meio S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148656.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53983, 3716, 'Dois Homens e Meio S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148657.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53984, 3716, 'Dois Homens e Meio S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148658.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53985, 3716, 'Dois Homens e Meio S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148659.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53986, 3716, 'Dois Homens e Meio S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148660.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53987, 3717, 'Dois Homens e Meio S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148661.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53988, 3717, 'Dois Homens e Meio S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148662.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53989, 3717, 'Dois Homens e Meio S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148663.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53990, 3717, 'Dois Homens e Meio S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148664.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53991, 3717, 'Dois Homens e Meio S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148665.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53992, 3717, 'Dois Homens e Meio S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148666.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53993, 3717, 'Dois Homens e Meio S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148667.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53994, 3717, 'Dois Homens e Meio S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148668.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53995, 3717, 'Dois Homens e Meio S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148669.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53996, 3717, 'Dois Homens e Meio S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148670.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53997, 3717, 'Dois Homens e Meio S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148671.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53998, 3717, 'Dois Homens e Meio S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148672.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(53999, 3717, 'Dois Homens e Meio S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148673.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54000, 3717, 'Dois Homens e Meio S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148674.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54001, 3717, 'Dois Homens e Meio S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148675.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54002, 3717, 'Dois Homens e Meio S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148676.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54003, 3717, 'Dois Homens e Meio S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/148677.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54004, 3717, 'Dois Homens e Meio S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/148678.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54005, 3717, 'Dois Homens e Meio S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/148679.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54006, 3717, 'Dois Homens e Meio S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/148680.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54007, 3717, 'Dois Homens e Meio S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/148681.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54008, 3717, 'Dois Homens e Meio S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/148682.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54009, 3717, 'Dois Homens e Meio S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/148683.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54010, 3717, 'Dois Homens e Meio S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/148684.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54011, 3718, 'Dois Homens e Meio S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148685.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54012, 3718, 'Dois Homens e Meio S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148686.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54013, 3718, 'Dois Homens e Meio S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148687.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54014, 3718, 'Dois Homens e Meio S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148688.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54015, 3718, 'Dois Homens e Meio S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148689.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54016, 3718, 'Dois Homens e Meio S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148690.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54017, 3718, 'Dois Homens e Meio S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148691.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54018, 3718, 'Dois Homens e Meio S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148692.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54019, 3718, 'Dois Homens e Meio S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148693.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54020, 3718, 'Dois Homens e Meio S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148694.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54021, 3718, 'Dois Homens e Meio S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148695.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54022, 3718, 'Dois Homens e Meio S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148696.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54023, 3718, 'Dois Homens e Meio S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148697.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54024, 3718, 'Dois Homens e Meio S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148698.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54025, 3718, 'Dois Homens e Meio S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148699.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54026, 3718, 'Dois Homens e Meio S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148700.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54027, 3718, 'Dois Homens e Meio S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/148701.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54028, 3718, 'Dois Homens e Meio S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/148702.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54029, 3718, 'Dois Homens e Meio S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/148703.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54030, 3718, 'Dois Homens e Meio S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/148704.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54031, 3718, 'Dois Homens e Meio S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/148705.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54032, 3718, 'Dois Homens e Meio S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/148706.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54033, 3718, 'Dois Homens e Meio S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/148707.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54034, 3719, 'Dois Homens e Meio S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148708.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54035, 3719, 'Dois Homens e Meio S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148709.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54036, 3719, 'Dois Homens e Meio S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148710.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54037, 3719, 'Dois Homens e Meio S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148711.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54038, 3719, 'Dois Homens e Meio S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148712.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54039, 3719, 'Dois Homens e Meio S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148713.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54040, 3719, 'Dois Homens e Meio S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148714.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54041, 3719, 'Dois Homens e Meio S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148715.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54042, 3719, 'Dois Homens e Meio S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148716.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54043, 3719, 'Dois Homens e Meio S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148717.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54044, 3719, 'Dois Homens e Meio S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148718.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54045, 3719, 'Dois Homens e Meio S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148719.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54046, 3719, 'Dois Homens e Meio S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148720.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54047, 3719, 'Dois Homens e Meio S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148721.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54048, 3719, 'Dois Homens e Meio S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148722.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54049, 3719, 'Dois Homens e Meio S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148723.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54050, 3719, 'Dois Homens e Meio S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/148724.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54051, 3719, 'Dois Homens e Meio S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/148725.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54052, 3719, 'Dois Homens e Meio S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/148726.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54053, 3719, 'Dois Homens e Meio S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/148727.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54054, 3719, 'Dois Homens e Meio S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/148728.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54055, 3719, 'Dois Homens e Meio S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/148729.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54056, 3720, 'Dois Homens e Meio S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148730.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54057, 3720, 'Dois Homens e Meio S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148731.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54058, 3720, 'Dois Homens e Meio S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148732.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54059, 3720, 'Dois Homens e Meio S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148733.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54060, 3720, 'Dois Homens e Meio S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148734.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54061, 3720, 'Dois Homens e Meio S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148735.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54062, 3720, 'Dois Homens e Meio S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148736.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54063, 3720, 'Dois Homens e Meio S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148737.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54064, 3720, 'Dois Homens e Meio S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148738.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54065, 3720, 'Dois Homens e Meio S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148739.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(54066, 3720, 'Dois Homens e Meio S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148740.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54067, 3720, 'Dois Homens e Meio S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148741.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54068, 3720, 'Dois Homens e Meio S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148742.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54069, 3720, 'Dois Homens e Meio S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148743.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54070, 3720, 'Dois Homens e Meio S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148744.mp4', 'http://gstaticontent.com/images/sWvCCYAByXLMJ4JPHPsBcgIbm8S_big.jpg'),
(54071, 3721, '1983 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148476.mp4', 'http://timg.bdta.pro/images/85bY4VBeJyXSuxSy14kUdg0KLGF_small.jpg'),
(54072, 3721, '1983 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148477.mp4', 'http://timg.bdta.pro/images/apnRyrOahNrKTwP6uCKgF0bXpnS_small.jpg'),
(54073, 3721, '1983 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148478.mp4', 'http://timg.bdta.pro/images/lAa6Ez8XoCcWPSE95NSHm74lDRo_small.jpg'),
(54074, 3721, '1983 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148479.mp4', 'http://timg.bdta.pro/images/eajuZTi3wgsNFgEnFwN3M1ettcf_small.jpg'),
(54075, 3721, '1983 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148480.mp4', 'http://timg.bdta.pro/images/nIAH6oYdjUnZjW0X2Ie6XpefKwC_small.jpg'),
(54076, 3721, '1983 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148481.mp4', 'http://timg.bdta.pro/images/AvbcOspZ708gSJY3bDzQCXhr3sC_small.jpg'),
(54077, 3721, '1983 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148482.mp4', 'http://timg.bdta.pro/images/fqNqSVh3IEiITvCWlwz3docpFCZ_small.jpg'),
(54078, 3721, '1983 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148483.mp4', 'http://timg.bdta.pro/images/oLTpBky9vaNUrb7BPbPBi2cl0LD_small.jpg'),
(54079, 3722, 'Guga Guns S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164326.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54080, 3722, 'Guga Guns S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164327.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54081, 3722, 'Guga Guns S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164328.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54082, 3722, 'Guga Guns S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164329.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54083, 3722, 'Guga Guns S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164330.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54084, 3722, 'Guga Guns S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164331.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54085, 3722, 'Guga Guns S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164332.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54086, 3722, 'Guga Guns S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164333.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54087, 3722, 'Guga Guns S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164334.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54088, 3722, 'Guga Guns S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164335.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54089, 3722, 'Guga Guns S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164336.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54090, 3722, 'Guga Guns S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164337.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54091, 3722, 'Guga Guns S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/164338.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54092, 3722, 'Guga Guns S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/164339.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54093, 3722, 'Guga Guns S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/164340.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54094, 3722, 'Guga Guns S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/164341.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54095, 3722, 'Guga Guns S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/164342.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54096, 3722, 'Guga Guns S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/164343.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54097, 3722, 'Guga Guns S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/164344.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54098, 3722, 'Guga Guns S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/164345.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54099, 3722, 'Guga Guns S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/164346.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54100, 3722, 'Guga Guns S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/164347.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54101, 3722, 'Guga Guns S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/164348.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54102, 3722, 'Guga Guns S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/164349.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54103, 3722, 'Guga Guns S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/164350.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54104, 3722, 'Guga Guns S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/164351.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54105, 3722, 'Guga Guns S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/164352.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54106, 3722, 'Guga Guns S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/164353.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54107, 3722, 'Guga Guns S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/164354.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54108, 3722, 'Guga Guns S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/164355.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54109, 3722, 'Guga Guns S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/164356.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54110, 3722, 'Guga Guns S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/164357.mp4', 'https://i.bj-share.info/a4d1cb0d03540f71aca12e5cc4ff790f.jpg'),
(54111, 3723, 'Californication S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148398.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54112, 3723, 'Californication S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148399.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54113, 3723, 'Californication S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148400.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54114, 3723, 'Californication S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148401.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54115, 3723, 'Californication S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148402.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54116, 3723, 'Californication S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148403.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54117, 3723, 'Californication S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148404.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54118, 3723, 'Californication S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148405.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54119, 3723, 'Californication S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148406.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54120, 3723, 'Californication S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148407.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54121, 3723, 'Californication S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148408.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54122, 3723, 'Californication S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148409.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54123, 3724, 'Californication S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148410.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54124, 3724, 'Californication S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148411.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54125, 3724, 'Californication S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148412.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54126, 3724, 'Californication S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148413.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54127, 3724, 'Californication S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148414.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54128, 3724, 'Californication S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148415.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54129, 3724, 'Californication S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148416.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54130, 3724, 'Californication S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148417.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54131, 3724, 'Californication S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148418.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54132, 3724, 'Californication S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148419.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54133, 3724, 'Californication S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148420.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54134, 3724, 'Californication S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148421.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54135, 3725, 'Californication S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148422.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54136, 3725, 'Californication S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148423.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54137, 3725, 'Californication S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148424.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54138, 3725, 'Californication S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148425.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54139, 3725, 'Californication S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148426.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54140, 3725, 'Californication S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148427.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54141, 3725, 'Californication S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148428.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54142, 3725, 'Californication S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148429.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54143, 3725, 'Californication S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148430.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54144, 3725, 'Californication S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148431.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54145, 3725, 'Californication S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148432.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54146, 3725, 'Californication S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148433.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54147, 3726, 'Californication S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148434.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54148, 3726, 'Californication S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148435.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54149, 3726, 'Californication S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148436.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54150, 3726, 'Californication S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148437.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54151, 3726, 'Californication S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148438.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54152, 3726, 'Californication S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148439.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54153, 3726, 'Californication S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148440.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54154, 3726, 'Californication S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148441.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54155, 3726, 'Californication S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148442.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54156, 3726, 'Californication S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148443.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54157, 3726, 'Californication S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148444.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54158, 3726, 'Californication S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148445.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54159, 3727, 'Californication S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148446.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54160, 3727, 'Californication S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148447.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54161, 3727, 'Californication S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148448.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54162, 3727, 'Californication S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148449.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54163, 3727, 'Californication S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148450.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54164, 3727, 'Californication S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148451.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54165, 3727, 'Californication S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148452.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54166, 3727, 'Californication S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148453.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54167, 3727, 'Californication S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148454.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54168, 3727, 'Californication S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148455.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54169, 3727, 'Californication S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148456.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54170, 3727, 'Californication S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148457.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54171, 3728, 'Californication S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264836.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54172, 3728, 'Californication S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264837.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54173, 3728, 'Californication S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264838.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54174, 3728, 'Californication S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264839.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54175, 3728, 'Californication S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264840.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54176, 3728, 'Californication S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264841.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54177, 3728, 'Californication S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264842.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54178, 3728, 'Californication S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264843.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54179, 3728, 'Californication S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264844.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54180, 3728, 'Californication S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264845.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54181, 3728, 'Californication S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264846.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54182, 3728, 'Californication S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264847.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54183, 3729, 'Californication S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264848.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54184, 3729, 'Californication S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264849.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54185, 3729, 'Californication S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264850.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54186, 3729, 'Californication S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264851.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54187, 3729, 'Californication S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264852.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54188, 3729, 'Californication S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264853.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54189, 3729, 'Californication S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264854.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54190, 3729, 'Californication S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264855.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54191, 3729, 'Californication S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264856.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54192, 3729, 'Californication S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264857.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54193, 3729, 'Californication S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264858.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54194, 3729, 'Californication S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264859.mp4', 'http://gstaticontent.com/images/jPqOY8cq9KXQN4bD7zJGHCNvcb4_big.jpg'),
(54195, 3730, 'Ferias em Familia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148378.mp4', 'https://i.bj-share.info/1dc9cc2b2f2ca5d2580c1af068167dba.jpg'),
(54196, 3730, 'Ferias em Familia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148379.mp4', 'https://i.bj-share.info/1dc9cc2b2f2ca5d2580c1af068167dba.jpg'),
(54197, 3730, 'Ferias em Familia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148380.mp4', 'https://i.bj-share.info/1dc9cc2b2f2ca5d2580c1af068167dba.jpg'),
(54198, 3730, 'Ferias em Familia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148381.mp4', 'https://i.bj-share.info/1dc9cc2b2f2ca5d2580c1af068167dba.jpg'),
(54199, 3730, 'Ferias em Familia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148382.mp4', 'https://i.bj-share.info/1dc9cc2b2f2ca5d2580c1af068167dba.jpg'),
(54200, 3730, 'Ferias em Familia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148383.mp4', 'https://i.bj-share.info/1dc9cc2b2f2ca5d2580c1af068167dba.jpg'),
(54201, 3730, 'Ferias em Familia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148384.mp4', 'https://i.bj-share.info/1dc9cc2b2f2ca5d2580c1af068167dba.jpg'),
(54202, 3730, 'Ferias em Familia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148385.mp4', 'https://i.bj-share.info/1dc9cc2b2f2ca5d2580c1af068167dba.jpg'),
(54203, 3730, 'Ferias em Familia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148386.mp4', 'https://i.bj-share.info/1dc9cc2b2f2ca5d2580c1af068167dba.jpg'),
(54204, 3730, 'Ferias em Familia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148387.mp4', 'https://i.bj-share.info/1dc9cc2b2f2ca5d2580c1af068167dba.jpg'),
(54205, 3731, 'Ferias em Familia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148388.mp4', 'https://i.bj-share.info/1dc9cc2b2f2ca5d2580c1af068167dba.jpg'),
(54206, 3731, 'Ferias em Familia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148389.mp4', 'https://i.bj-share.info/1dc9cc2b2f2ca5d2580c1af068167dba.jpg'),
(54207, 3731, 'Ferias em Familia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148390.mp4', 'https://i.bj-share.info/1dc9cc2b2f2ca5d2580c1af068167dba.jpg'),
(54208, 3731, 'Ferias em Familia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148391.mp4', 'https://i.bj-share.info/1dc9cc2b2f2ca5d2580c1af068167dba.jpg'),
(54209, 3731, 'Ferias em Familia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148392.mp4', 'https://i.bj-share.info/1dc9cc2b2f2ca5d2580c1af068167dba.jpg'),
(54210, 3731, 'Ferias em Familia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148393.mp4', 'https://i.bj-share.info/1dc9cc2b2f2ca5d2580c1af068167dba.jpg'),
(54211, 3731, 'Ferias em Familia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148394.mp4', 'https://i.bj-share.info/1dc9cc2b2f2ca5d2580c1af068167dba.jpg'),
(54212, 3731, 'Ferias em Familia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148395.mp4', 'https://i.bj-share.info/1dc9cc2b2f2ca5d2580c1af068167dba.jpg'),
(54213, 3731, 'Ferias em Familia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148396.mp4', 'https://i.bj-share.info/1dc9cc2b2f2ca5d2580c1af068167dba.jpg'),
(54214, 3731, 'Ferias em Familia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148397.mp4', 'https://i.bj-share.info/1dc9cc2b2f2ca5d2580c1af068167dba.jpg'),
(54215, 3732, 'Friends with Better Lives S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148365.mp4', 'http://gstaticontent.com/images/amSUQrW7siuXgjINMajG3klqV1h_big.jpg'),
(54216, 3732, 'Friends with Better Lives S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148366.mp4', 'http://gstaticontent.com/images/amSUQrW7siuXgjINMajG3klqV1h_big.jpg'),
(54217, 3732, 'Friends with Better Lives S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148367.mp4', 'http://gstaticontent.com/images/amSUQrW7siuXgjINMajG3klqV1h_big.jpg'),
(54218, 3732, 'Friends with Better Lives S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148368.mp4', 'http://gstaticontent.com/images/amSUQrW7siuXgjINMajG3klqV1h_big.jpg'),
(54219, 3732, 'Friends with Better Lives S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148369.mp4', 'http://gstaticontent.com/images/amSUQrW7siuXgjINMajG3klqV1h_big.jpg'),
(54220, 3732, 'Friends with Better Lives S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148370.mp4', 'http://gstaticontent.com/images/amSUQrW7siuXgjINMajG3klqV1h_big.jpg'),
(54221, 3732, 'Friends with Better Lives S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148371.mp4', 'http://gstaticontent.com/images/amSUQrW7siuXgjINMajG3klqV1h_big.jpg'),
(54222, 3732, 'Friends with Better Lives S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148372.mp4', 'http://gstaticontent.com/images/amSUQrW7siuXgjINMajG3klqV1h_big.jpg'),
(54223, 3732, 'Friends with Better Lives S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148373.mp4', 'http://gstaticontent.com/images/amSUQrW7siuXgjINMajG3klqV1h_big.jpg'),
(54224, 3732, 'Friends with Better Lives S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148374.mp4', 'http://gstaticontent.com/images/amSUQrW7siuXgjINMajG3klqV1h_big.jpg'),
(54225, 3732, 'Friends with Better Lives S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148375.mp4', 'http://gstaticontent.com/images/amSUQrW7siuXgjINMajG3klqV1h_big.jpg'),
(54226, 3732, 'Friends with Better Lives S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148376.mp4', 'http://gstaticontent.com/images/amSUQrW7siuXgjINMajG3klqV1h_big.jpg'),
(54227, 3732, 'Friends with Better Lives S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148377.mp4', 'http://gstaticontent.com/images/amSUQrW7siuXgjINMajG3klqV1h_big.jpg'),
(54228, 3733, 'Mães: Amor e Vida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181528.mp4', 'http://gstaticontent.com/images/ae7674c7e37784fa0069ca2912b645d4.jpg'),
(54229, 3733, 'Mães: Amor e Vida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181529.mp4', 'http://gstaticontent.com/images/ae7674c7e37784fa0069ca2912b645d4.jpg'),
(54230, 3733, 'Mães: Amor e Vida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181530.mp4', 'http://gstaticontent.com/images/ae7674c7e37784fa0069ca2912b645d4.jpg'),
(54231, 3733, 'Mães: Amor e Vida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181531.mp4', 'http://gstaticontent.com/images/ae7674c7e37784fa0069ca2912b645d4.jpg'),
(54232, 3733, 'Mães: Amor e Vida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181532.mp4', 'http://gstaticontent.com/images/ae7674c7e37784fa0069ca2912b645d4.jpg'),
(54233, 3733, 'Mães: Amor e Vida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181533.mp4', 'http://gstaticontent.com/images/ae7674c7e37784fa0069ca2912b645d4.jpg'),
(54234, 3733, 'Mães: Amor e Vida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181534.mp4', 'http://gstaticontent.com/images/ae7674c7e37784fa0069ca2912b645d4.jpg'),
(54235, 3733, 'Mães: Amor e Vida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181535.mp4', 'http://gstaticontent.com/images/ae7674c7e37784fa0069ca2912b645d4.jpg'),
(54236, 3733, 'Mães: Amor e Vida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181536.mp4', 'http://gstaticontent.com/images/ae7674c7e37784fa0069ca2912b645d4.jpg'),
(54237, 3733, 'Mães: Amor e Vida S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181537.mp4', 'http://gstaticontent.com/images/ae7674c7e37784fa0069ca2912b645d4.jpg'),
(54238, 3733, 'Mães: Amor e Vida S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/181538.mp4', 'http://gstaticontent.com/images/ae7674c7e37784fa0069ca2912b645d4.jpg'),
(54239, 3733, 'Mães: Amor e Vida S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/181539.mp4', 'http://gstaticontent.com/images/ae7674c7e37784fa0069ca2912b645d4.jpg'),
(54240, 3733, 'Mães: Amor e Vida S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/181540.mp4', 'http://gstaticontent.com/images/ae7674c7e37784fa0069ca2912b645d4.jpg'),
(54241, 3734, 'Mães: Amor e Vida S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181541.mp4', 'http://timg.bdta.pro/images/d362e909f7f776978ad786670e4fa49f.jpg'),
(54242, 3734, 'Mães: Amor e Vida S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181542.mp4', 'http://timg.bdta.pro/images/8cfd9a2570ccfa5ad880a8d0d2eb3cd3.jpg'),
(54243, 3734, 'Mães: Amor e Vida S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181543.mp4', 'http://timg.bdta.pro/images/a57a6eea7df2c3d33dea62c318d4bb2e.jpg'),
(54244, 3734, 'Mães: Amor e Vida S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181544.mp4', 'http://timg.bdta.pro/images/7bcfb0075fce49114a70be4f75e7f805.jpg'),
(54245, 3734, 'Mães: Amor e Vida S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181545.mp4', 'http://timg.bdta.pro/images/f1c96430c98b2296434fe04a8bf7d3f0.jpg'),
(54246, 3734, 'Mães: Amor e Vida S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181546.mp4', 'http://timg.bdta.pro/images/bd81e792daaa0695f5be55c0c3edbd31.jpg'),
(54247, 3734, 'Mães: Amor e Vida S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181547.mp4', 'http://timg.bdta.pro/images/4157fe98bc54140d6c4be9b7f011122e.jpg'),
(54248, 3734, 'Mães: Amor e Vida S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181548.mp4', 'http://timg.bdta.pro/images/a473fa893843f9a4ecd5a0cac9c5cf42.jpg'),
(54249, 3734, 'Mães: Amor e Vida S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181549.mp4', 'http://timg.bdta.pro/images/7aabde58812addbad2f1768bacee88c5.jpg'),
(54250, 3734, 'Mães: Amor e Vida S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181550.mp4', 'http://timg.bdta.pro/images/1ae3fbecc41d9ffb2c73f53d181e547e.jpg'),
(54251, 3734, 'Mães: Amor e Vida S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/181551.mp4', 'http://timg.bdta.pro/images/c2d5718e09fd73e6cdf44ce8d21731d0.jpg'),
(54252, 3734, 'Mães: Amor e Vida S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/181552.mp4', 'http://timg.bdta.pro/images/3ae1ce6fde6790d62a4e341ba3c4756a.jpg'),
(54253, 3734, 'Mães: Amor e Vida S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/181553.mp4', 'http://timg.bdta.pro/images/5da66f9148016966834bf2f010e74a02.jpg'),
(54254, 3735, 'Doug S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148273.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54255, 3735, 'Doug S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148274.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54256, 3735, 'Doug S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148275.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54257, 3735, 'Doug S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148276.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54258, 3735, 'Doug S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148277.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54259, 3735, 'Doug S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148278.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54260, 3735, 'Doug S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148279.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54261, 3735, 'Doug S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148280.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54262, 3735, 'Doug S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148281.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54263, 3735, 'Doug S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148282.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54264, 3735, 'Doug S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148283.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54265, 3735, 'Doug S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148284.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54266, 3735, 'Doug S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148285.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54267, 3735, 'Doug S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148286.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54268, 3735, 'Doug S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148287.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54269, 3735, 'Doug S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148288.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54270, 3735, 'Doug S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/148289.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54271, 3735, 'Doug S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/148290.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54272, 3735, 'Doug S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/148291.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54273, 3735, 'Doug S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/148292.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54274, 3735, 'Doug S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/148293.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54275, 3735, 'Doug S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/148294.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54276, 3735, 'Doug S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/148295.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54277, 3735, 'Doug S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/148296.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54278, 3735, 'Doug S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/148297.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54279, 3735, 'Doug S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/148298.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54280, 3736, 'Doug S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148299.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54281, 3736, 'Doug S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148300.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54282, 3736, 'Doug S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148301.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54283, 3736, 'Doug S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148302.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54284, 3736, 'Doug S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148303.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54285, 3736, 'Doug S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148304.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54286, 3736, 'Doug S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148305.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54287, 3736, 'Doug S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148306.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54288, 3737, 'Doug S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148307.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54289, 3737, 'Doug S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148308.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54290, 3737, 'Doug S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148309.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54291, 3737, 'Doug S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148310.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54292, 3737, 'Doug S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148311.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54293, 3737, 'Doug S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148312.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54294, 3737, 'Doug S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148313.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54295, 3737, 'Doug S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148314.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54296, 3737, 'Doug S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148315.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54297, 3737, 'Doug S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148316.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54298, 3737, 'Doug S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/148317.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54299, 3737, 'Doug S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/148318.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54300, 3737, 'Doug S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/148319.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54301, 3737, 'Doug S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/148320.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54302, 3737, 'Doug S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/148321.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54303, 3737, 'Doug S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/148322.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54304, 3737, 'Doug S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/148323.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54305, 3737, 'Doug S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/148324.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54306, 3737, 'Doug S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/148325.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54307, 3737, 'Doug S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/148326.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54308, 3737, 'Doug S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/148327.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54309, 3737, 'Doug S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/148328.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54310, 3737, 'Doug S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/148329.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54311, 3737, 'Doug S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/148330.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54312, 3737, 'Doug S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/148331.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54313, 3737, 'Doug S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/148332.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54314, 3737, 'Doug S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/148333.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54315, 3737, 'Doug S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/148334.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54316, 3737, 'Doug S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/148335.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54317, 3737, 'Doug S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/148336.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54318, 3737, 'Doug S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/148337.mp4', 'http://gstaticontent.com/images/wje8TypwzatJaazNd1zsb9Tttuj_big.jpg'),
(54319, 3738, 'Run the World S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152020.mp4', 'http://timg.bdta.pro/images/07183ee22241c8f44aa4058b7996f169.jpg'),
(54320, 3738, 'Run the World S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152021.mp4', 'http://timg.bdta.pro/images/d92d9526672d70733504fe3e500761e8.jpg'),
(54321, 3738, 'Run the World S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152022.mp4', 'http://timg.bdta.pro/images/1be0fc21b42763e41a5898384c46f9e5.jpg'),
(54322, 3738, 'Run the World S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152023.mp4', 'http://timg.bdta.pro/images/92ab87457db5b933930a706eb6cce7ed.jpg'),
(54323, 3738, 'Run the World S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152024.mp4', 'http://timg.bdta.pro/images/288149e0c55b47624a2b400cabe346c7.jpg'),
(54324, 3738, 'Run the World S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152025.mp4', 'http://timg.bdta.pro/images/de7b91e52605b13556f210bd01b09153.jpg'),
(54325, 3738, 'Run the World S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152026.mp4', 'http://timg.bdta.pro/images/f09b4d0cdfd71f246ed8a235f5375e1d.jpg'),
(54326, 3739, 'Run the World S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290632.mp4', 'http://gstaticontent.com/images/bsMOr1rfG0Vk5sneiWQVegYHfSv_big.jpg'),
(54327, 3739, 'Run the World S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290633.mp4', 'http://gstaticontent.com/images/bsMOr1rfG0Vk5sneiWQVegYHfSv_big.jpg'),
(54328, 3739, 'Run the World S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290634.mp4', 'http://gstaticontent.com/images/bsMOr1rfG0Vk5sneiWQVegYHfSv_big.jpg'),
(54329, 3739, 'Run the World S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290635.mp4', 'http://gstaticontent.com/images/bsMOr1rfG0Vk5sneiWQVegYHfSv_big.jpg'),
(54330, 3739, 'Run the World S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/290636.mp4', 'http://gstaticontent.com/images/bsMOr1rfG0Vk5sneiWQVegYHfSv_big.jpg'),
(54331, 3739, 'Run the World S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/290637.mp4', 'http://gstaticontent.com/images/bsMOr1rfG0Vk5sneiWQVegYHfSv_big.jpg'),
(54332, 3739, 'Run the World S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/290638.mp4', 'http://gstaticontent.com/images/bsMOr1rfG0Vk5sneiWQVegYHfSv_big.jpg'),
(54333, 3739, 'Run the World S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/290639.mp4', 'http://gstaticontent.com/images/bsMOr1rfG0Vk5sneiWQVegYHfSv_big.jpg'),
(54334, 3740, 'Sessão de Terapia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151835.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54335, 3740, 'Sessão de Terapia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151836.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54336, 3740, 'Sessão de Terapia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151837.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54337, 3740, 'Sessão de Terapia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151838.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54338, 3740, 'Sessão de Terapia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151839.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54339, 3740, 'Sessão de Terapia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151840.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54340, 3740, 'Sessão de Terapia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151841.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54341, 3740, 'Sessão de Terapia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151842.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54342, 3740, 'Sessão de Terapia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151843.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54343, 3740, 'Sessão de Terapia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151844.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54344, 3740, 'Sessão de Terapia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151845.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54345, 3740, 'Sessão de Terapia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151846.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54346, 3740, 'Sessão de Terapia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151847.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54347, 3740, 'Sessão de Terapia S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151848.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54348, 3740, 'Sessão de Terapia S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/151849.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54349, 3740, 'Sessão de Terapia S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/151850.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54350, 3740, 'Sessão de Terapia S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/151851.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54351, 3740, 'Sessão de Terapia S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/151852.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54352, 3740, 'Sessão de Terapia S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/151853.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54353, 3740, 'Sessão de Terapia S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/151854.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54354, 3740, 'Sessão de Terapia S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/151855.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54355, 3740, 'Sessão de Terapia S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/151856.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(54356, 3740, 'Sessão de Terapia S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/151857.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54357, 3740, 'Sessão de Terapia S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/151858.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54358, 3740, 'Sessão de Terapia S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/151859.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54359, 3740, 'Sessão de Terapia S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/151860.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54360, 3740, 'Sessão de Terapia S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/151861.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54361, 3740, 'Sessão de Terapia S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/151862.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54362, 3740, 'Sessão de Terapia S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/151863.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54363, 3740, 'Sessão de Terapia S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/151864.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54364, 3740, 'Sessão de Terapia S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/151865.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54365, 3740, 'Sessão de Terapia S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/151866.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54366, 3740, 'Sessão de Terapia S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/151867.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54367, 3740, 'Sessão de Terapia S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/151868.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54368, 3740, 'Sessão de Terapia S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/151869.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54369, 3740, 'Sessão de Terapia S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/151870.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54370, 3740, 'Sessão de Terapia S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/151871.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54371, 3740, 'Sessão de Terapia S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/151872.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54372, 3740, 'Sessão de Terapia S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/151873.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54373, 3740, 'Sessão de Terapia S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/151874.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54374, 3740, 'Sessão de Terapia S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/151875.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54375, 3740, 'Sessão de Terapia S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/151876.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54376, 3740, 'Sessão de Terapia S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/151877.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54377, 3740, 'Sessão de Terapia S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/151878.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54378, 3740, 'Sessão de Terapia S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/151879.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54379, 3741, 'Sessão de Terapia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151880.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54380, 3741, 'Sessão de Terapia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151881.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54381, 3741, 'Sessão de Terapia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151882.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54382, 3741, 'Sessão de Terapia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151883.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54383, 3741, 'Sessão de Terapia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151884.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54384, 3741, 'Sessão de Terapia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151885.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54385, 3741, 'Sessão de Terapia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151886.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54386, 3741, 'Sessão de Terapia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151887.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54387, 3741, 'Sessão de Terapia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151888.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54388, 3741, 'Sessão de Terapia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151889.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54389, 3741, 'Sessão de Terapia S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151890.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54390, 3741, 'Sessão de Terapia S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151891.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54391, 3741, 'Sessão de Terapia S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151892.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54392, 3741, 'Sessão de Terapia S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151893.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54393, 3741, 'Sessão de Terapia S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/151894.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54394, 3741, 'Sessão de Terapia S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/151895.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54395, 3741, 'Sessão de Terapia S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/151896.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54396, 3741, 'Sessão de Terapia S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/151897.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54397, 3741, 'Sessão de Terapia S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/151898.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54398, 3741, 'Sessão de Terapia S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/151899.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54399, 3741, 'Sessão de Terapia S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/151900.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54400, 3741, 'Sessão de Terapia S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/151901.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54401, 3741, 'Sessão de Terapia S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/151902.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54402, 3741, 'Sessão de Terapia S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/151903.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54403, 3741, 'Sessão de Terapia S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/151904.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54404, 3741, 'Sessão de Terapia S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/151905.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54405, 3741, 'Sessão de Terapia S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/151906.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54406, 3741, 'Sessão de Terapia S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/151907.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54407, 3741, 'Sessão de Terapia S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/151908.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54408, 3741, 'Sessão de Terapia S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/151909.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54409, 3741, 'Sessão de Terapia S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/151910.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54410, 3741, 'Sessão de Terapia S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/151911.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54411, 3741, 'Sessão de Terapia S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/151912.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54412, 3741, 'Sessão de Terapia S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/151913.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54413, 3741, 'Sessão de Terapia S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/151914.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54414, 3742, 'Sessão de Terapia S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151915.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54415, 3742, 'Sessão de Terapia S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151916.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54416, 3742, 'Sessão de Terapia S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151917.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54417, 3742, 'Sessão de Terapia S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151918.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54418, 3742, 'Sessão de Terapia S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151919.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54419, 3742, 'Sessão de Terapia S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151920.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54420, 3742, 'Sessão de Terapia S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151921.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54421, 3742, 'Sessão de Terapia S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151922.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54422, 3742, 'Sessão de Terapia S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151923.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54423, 3742, 'Sessão de Terapia S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151924.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54424, 3742, 'Sessão de Terapia S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151925.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54425, 3742, 'Sessão de Terapia S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151926.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54426, 3742, 'Sessão de Terapia S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151927.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54427, 3742, 'Sessão de Terapia S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151928.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54428, 3742, 'Sessão de Terapia S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/151929.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54429, 3742, 'Sessão de Terapia S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/151930.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54430, 3742, 'Sessão de Terapia S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/151931.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54431, 3742, 'Sessão de Terapia S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/151932.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54432, 3742, 'Sessão de Terapia S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/151933.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54433, 3742, 'Sessão de Terapia S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/151934.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54434, 3742, 'Sessão de Terapia S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/151935.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54435, 3742, 'Sessão de Terapia S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/151936.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54436, 3742, 'Sessão de Terapia S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/151937.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54437, 3742, 'Sessão de Terapia S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/151938.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54438, 3742, 'Sessão de Terapia S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/151939.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54439, 3742, 'Sessão de Terapia S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/151940.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54440, 3742, 'Sessão de Terapia S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/151941.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54441, 3742, 'Sessão de Terapia S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/151942.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54442, 3742, 'Sessão de Terapia S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/151943.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54443, 3742, 'Sessão de Terapia S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/151944.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54444, 3742, 'Sessão de Terapia S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/151945.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54445, 3742, 'Sessão de Terapia S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/151946.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54446, 3742, 'Sessão de Terapia S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/151947.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54447, 3742, 'Sessão de Terapia S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/151948.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54448, 3742, 'Sessão de Terapia S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/151949.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54449, 3743, 'Sessão de Terapia S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151950.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54450, 3743, 'Sessão de Terapia S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151951.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54451, 3743, 'Sessão de Terapia S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151952.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54452, 3743, 'Sessão de Terapia S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151953.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54453, 3743, 'Sessão de Terapia S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151954.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54454, 3743, 'Sessão de Terapia S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151955.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54455, 3743, 'Sessão de Terapia S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151956.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54456, 3743, 'Sessão de Terapia S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151957.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54457, 3743, 'Sessão de Terapia S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151958.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54458, 3743, 'Sessão de Terapia S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151959.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54459, 3743, 'Sessão de Terapia S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151960.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54460, 3743, 'Sessão de Terapia S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151961.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54461, 3743, 'Sessão de Terapia S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151962.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54462, 3743, 'Sessão de Terapia S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151963.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54463, 3743, 'Sessão de Terapia S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/151964.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54464, 3743, 'Sessão de Terapia S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/151965.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54465, 3743, 'Sessão de Terapia S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/151966.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54466, 3743, 'Sessão de Terapia S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/151967.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54467, 3743, 'Sessão de Terapia S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/151968.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54468, 3743, 'Sessão de Terapia S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/151969.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54469, 3743, 'Sessão de Terapia S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/151970.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54470, 3743, 'Sessão de Terapia S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/151971.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54471, 3743, 'Sessão de Terapia S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/151972.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54472, 3743, 'Sessão de Terapia S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/151973.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54473, 3743, 'Sessão de Terapia S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/151974.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54474, 3743, 'Sessão de Terapia S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/151975.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54475, 3743, 'Sessão de Terapia S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/151976.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54476, 3743, 'Sessão de Terapia S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/151977.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54477, 3743, 'Sessão de Terapia S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/151978.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54478, 3743, 'Sessão de Terapia S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/151979.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54479, 3743, 'Sessão de Terapia S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/151980.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54480, 3743, 'Sessão de Terapia S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/151981.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54481, 3743, 'Sessão de Terapia S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/151982.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54482, 3743, 'Sessão de Terapia S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/151983.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54483, 3743, 'Sessão de Terapia S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/151984.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54484, 3744, 'Sessão de Terapia S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151985.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54485, 3744, 'Sessão de Terapia S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151986.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54486, 3744, 'Sessão de Terapia S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151987.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54487, 3744, 'Sessão de Terapia S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151988.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54488, 3744, 'Sessão de Terapia S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151989.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54489, 3744, 'Sessão de Terapia S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151990.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54490, 3744, 'Sessão de Terapia S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151991.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54491, 3744, 'Sessão de Terapia S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151992.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54492, 3744, 'Sessão de Terapia S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151993.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54493, 3744, 'Sessão de Terapia S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151994.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54494, 3744, 'Sessão de Terapia S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151995.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54495, 3744, 'Sessão de Terapia S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151996.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54496, 3744, 'Sessão de Terapia S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151997.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54497, 3744, 'Sessão de Terapia S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151998.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54498, 3744, 'Sessão de Terapia S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/151999.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54499, 3744, 'Sessão de Terapia S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152000.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54500, 3744, 'Sessão de Terapia S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152001.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54501, 3744, 'Sessão de Terapia S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152002.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54502, 3744, 'Sessão de Terapia S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152003.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54503, 3744, 'Sessão de Terapia S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/152004.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54504, 3744, 'Sessão de Terapia S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/152005.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54505, 3744, 'Sessão de Terapia S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/152006.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54506, 3744, 'Sessão de Terapia S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/152007.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54507, 3744, 'Sessão de Terapia S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/152008.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54508, 3744, 'Sessão de Terapia S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/152009.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54509, 3744, 'Sessão de Terapia S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/152010.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54510, 3744, 'Sessão de Terapia S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/152011.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54511, 3744, 'Sessão de Terapia S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/152012.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54512, 3744, 'Sessão de Terapia S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/152013.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54513, 3744, 'Sessão de Terapia S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/152014.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54514, 3744, 'Sessão de Terapia S05 E31', 'http://sinalprivado.info:80/series/1533784/1533784/152015.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54515, 3744, 'Sessão de Terapia S05 E32', 'http://sinalprivado.info:80/series/1533784/1533784/152016.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54516, 3744, 'Sessão de Terapia S05 E33', 'http://sinalprivado.info:80/series/1533784/1533784/152017.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54517, 3744, 'Sessão de Terapia S05 E34', 'http://sinalprivado.info:80/series/1533784/1533784/152018.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54518, 3744, 'Sessão de Terapia S05 E35', 'http://sinalprivado.info:80/series/1533784/1533784/152019.mp4', 'http://gstaticontent.com/images/fNRaIpSOIEKYqc8cSCH5W8rMAVi_big.jpg'),
(54519, 3745, 'Eden S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172958.mp4', 'http://timg.bdta.pro/images/7f71675e073dc5dcf95a800c393e4551.jpg'),
(54520, 3745, 'Eden S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172959.mp4', 'http://timg.bdta.pro/images/99a9d402eb13a695f5a58fc503cfbbf6.jpg'),
(54521, 3745, 'Eden S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172960.mp4', 'http://timg.bdta.pro/images/f8f1ae65ac211ee1862df1999aeb1926.jpg'),
(54522, 3745, 'Eden S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172961.mp4', 'http://timg.bdta.pro/images/67ff091e7c9b79dea8532b02a5f6bbda.jpg'),
(54523, 3745, 'Eden S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172962.mp4', 'http://gstaticontent.com/images/z0KzC5YgYssfa6cqNRkN4MrSkIq_big.jpg'),
(54524, 3745, 'Eden S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172963.mp4', 'http://gstaticontent.com/images/z0KzC5YgYssfa6cqNRkN4MrSkIq_big.jpg'),
(54525, 3745, 'Eden S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172964.mp4', 'http://gstaticontent.com/images/z0KzC5YgYssfa6cqNRkN4MrSkIq_big.jpg'),
(54526, 3745, 'Eden S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172965.mp4', 'http://gstaticontent.com/images/z0KzC5YgYssfa6cqNRkN4MrSkIq_big.jpg'),
(54527, 3746, 'Helstrom S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148035.mp4', 'http://gstaticontent.com/images/8fPIcaRIZgsoBcgA5yAm3GNz61M_big.jpg'),
(54528, 3746, 'Helstrom S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148036.mp4', 'http://gstaticontent.com/images/8fPIcaRIZgsoBcgA5yAm3GNz61M_big.jpg'),
(54529, 3746, 'Helstrom S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148037.mp4', 'http://gstaticontent.com/images/8fPIcaRIZgsoBcgA5yAm3GNz61M_big.jpg'),
(54530, 3746, 'Helstrom S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148038.mp4', 'http://gstaticontent.com/images/8fPIcaRIZgsoBcgA5yAm3GNz61M_big.jpg'),
(54531, 3746, 'Helstrom S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148039.mp4', 'http://gstaticontent.com/images/8fPIcaRIZgsoBcgA5yAm3GNz61M_big.jpg'),
(54532, 3746, 'Helstrom S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148040.mp4', 'http://gstaticontent.com/images/8fPIcaRIZgsoBcgA5yAm3GNz61M_big.jpg'),
(54533, 3746, 'Helstrom S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148041.mp4', 'http://gstaticontent.com/images/8fPIcaRIZgsoBcgA5yAm3GNz61M_big.jpg'),
(54534, 3746, 'Helstrom S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148042.mp4', 'http://gstaticontent.com/images/8fPIcaRIZgsoBcgA5yAm3GNz61M_big.jpg'),
(54535, 3746, 'Helstrom S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148043.mp4', 'http://gstaticontent.com/images/8fPIcaRIZgsoBcgA5yAm3GNz61M_big.jpg'),
(54536, 3746, 'Helstrom S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148044.mp4', 'http://gstaticontent.com/images/8fPIcaRIZgsoBcgA5yAm3GNz61M_big.jpg'),
(54537, 3747, 'Da África aos EUA: Uma Jornada Gastronômica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148031.mp4', 'http://gstaticontent.com/images/pwJbPIJ9SvOtxBg4TACxD0fMaUC_big.jpg'),
(54538, 3747, 'Da África aos EUA: Uma Jornada Gastronômica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148032.mp4', 'http://gstaticontent.com/images/pwJbPIJ9SvOtxBg4TACxD0fMaUC_big.jpg'),
(54539, 3747, 'Da África aos EUA: Uma Jornada Gastronômica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148033.mp4', 'http://gstaticontent.com/images/pwJbPIJ9SvOtxBg4TACxD0fMaUC_big.jpg'),
(54540, 3747, 'Da África aos EUA: Uma Jornada Gastronômica S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148034.mp4', 'http://gstaticontent.com/images/pwJbPIJ9SvOtxBg4TACxD0fMaUC_big.jpg'),
(54541, 3748, 'Loucos Um Pelo Outro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146714.mp4', 'http://gstaticontent.com/images/sMQu6bLdSj3rjKg18zCdnNcHXLX_big.jpg'),
(54542, 3748, 'Loucos Um Pelo Outro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146715.mp4', 'http://gstaticontent.com/images/sMQu6bLdSj3rjKg18zCdnNcHXLX_big.jpg'),
(54543, 3748, 'Loucos Um Pelo Outro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146716.mp4', 'http://gstaticontent.com/images/sMQu6bLdSj3rjKg18zCdnNcHXLX_big.jpg'),
(54544, 3748, 'Loucos Um Pelo Outro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146717.mp4', 'http://gstaticontent.com/images/sMQu6bLdSj3rjKg18zCdnNcHXLX_big.jpg'),
(54545, 3748, 'Loucos Um Pelo Outro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146718.mp4', 'http://gstaticontent.com/images/sMQu6bLdSj3rjKg18zCdnNcHXLX_big.jpg'),
(54546, 3748, 'Loucos Um Pelo Outro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146719.mp4', 'http://gstaticontent.com/images/sMQu6bLdSj3rjKg18zCdnNcHXLX_big.jpg'),
(54547, 3748, 'Loucos Um Pelo Outro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146720.mp4', 'http://gstaticontent.com/images/sMQu6bLdSj3rjKg18zCdnNcHXLX_big.jpg'),
(54548, 3748, 'Loucos Um Pelo Outro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146721.mp4', 'http://gstaticontent.com/images/sMQu6bLdSj3rjKg18zCdnNcHXLX_big.jpg'),
(54549, 3748, 'Loucos Um Pelo Outro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146722.mp4', 'http://gstaticontent.com/images/sMQu6bLdSj3rjKg18zCdnNcHXLX_big.jpg'),
(54550, 3748, 'Loucos Um Pelo Outro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146723.mp4', 'http://gstaticontent.com/images/sMQu6bLdSj3rjKg18zCdnNcHXLX_big.jpg'),
(54551, 3748, 'Loucos Um Pelo Outro S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146724.mp4', 'http://gstaticontent.com/images/sMQu6bLdSj3rjKg18zCdnNcHXLX_big.jpg'),
(54552, 3748, 'Loucos Um Pelo Outro S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146725.mp4', 'http://gstaticontent.com/images/sMQu6bLdSj3rjKg18zCdnNcHXLX_big.jpg'),
(54553, 3749, 'Just a Little Game: Os Bastidores da LOUD S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148027.mp4', 'http://gstaticontent.com/images/lMCSktxVOhvvTqInq6jGdngyK7_big.jpg'),
(54554, 3749, 'Just a Little Game: Os Bastidores da LOUD S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148028.mp4', 'http://gstaticontent.com/images/lMCSktxVOhvvTqInq6jGdngyK7_big.jpg'),
(54555, 3749, 'Just a Little Game: Os Bastidores da LOUD S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148029.mp4', 'http://gstaticontent.com/images/lMCSktxVOhvvTqInq6jGdngyK7_big.jpg'),
(54556, 3749, 'Just a Little Game: Os Bastidores da LOUD S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148030.mp4', 'http://gstaticontent.com/images/lMCSktxVOhvvTqInq6jGdngyK7_big.jpg'),
(54557, 3750, 'Miami Vice S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171119.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54558, 3750, 'Miami Vice S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171120.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54559, 3750, 'Miami Vice S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171121.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54560, 3750, 'Miami Vice S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171122.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54561, 3750, 'Miami Vice S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171123.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54562, 3750, 'Miami Vice S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171124.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54563, 3750, 'Miami Vice S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171125.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54564, 3750, 'Miami Vice S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171126.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54565, 3750, 'Miami Vice S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171127.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54566, 3750, 'Miami Vice S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171128.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54567, 3750, 'Miami Vice S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171129.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54568, 3750, 'Miami Vice S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171130.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54569, 3750, 'Miami Vice S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171131.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54570, 3750, 'Miami Vice S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171132.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54571, 3750, 'Miami Vice S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171133.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54572, 3750, 'Miami Vice S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171134.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54573, 3750, 'Miami Vice S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171135.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54574, 3750, 'Miami Vice S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171136.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54575, 3750, 'Miami Vice S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/171137.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54576, 3750, 'Miami Vice S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/171138.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54577, 3750, 'Miami Vice S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/171139.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54578, 3750, 'Miami Vice S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/171140.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54579, 3751, 'Miami Vice S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171141.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54580, 3751, 'Miami Vice S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171142.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54581, 3751, 'Miami Vice S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171143.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54582, 3751, 'Miami Vice S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171144.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54583, 3751, 'Miami Vice S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171145.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54584, 3751, 'Miami Vice S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171146.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54585, 3751, 'Miami Vice S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171147.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54586, 3751, 'Miami Vice S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171148.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54587, 3751, 'Miami Vice S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171149.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54588, 3751, 'Miami Vice S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171150.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54589, 3751, 'Miami Vice S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171151.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54590, 3751, 'Miami Vice S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171152.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54591, 3751, 'Miami Vice S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171153.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54592, 3751, 'Miami Vice S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171154.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54593, 3751, 'Miami Vice S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171155.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54594, 3751, 'Miami Vice S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171156.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54595, 3751, 'Miami Vice S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171157.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54596, 3751, 'Miami Vice S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171158.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54597, 3751, 'Miami Vice S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/171159.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54598, 3751, 'Miami Vice S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/171160.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54599, 3751, 'Miami Vice S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/171161.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54600, 3751, 'Miami Vice S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/171162.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54601, 3752, 'Miami Vice S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xF1BiO9WlwAbz0KUiOvPCFJ6koc.jpg'),
(54602, 3752, 'Miami Vice S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9MnYDkDQagrPAyD7xVb7uXBVspx.jpg'),
(54603, 3752, 'Miami Vice S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QXRYSMfKNlKHznMlhD9NC6TusY.jpg'),
(54604, 3752, 'Miami Vice S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lTiTvs9sug6sYouM5GKDpcZR7Uj.jpg'),
(54605, 3752, 'Miami Vice S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nW98mWV7gvhNgIoTnIQVhgMAknf.jpg'),
(54606, 3752, 'Miami Vice S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cfxD2q3XXaHEpzfXaXl5xENDt3j.jpg'),
(54607, 3752, 'Miami Vice S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zlDWOpZluSODczIXgtfipZ4NlKY.jpg'),
(54608, 3752, 'Miami Vice S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/osqNV8xYR7KK5aNHXhXP89hhptV.jpg'),
(54609, 3752, 'Miami Vice S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g0XYQl5coe4jg976wByIMoErPnZ.jpg'),
(54610, 3752, 'Miami Vice S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4oBvLp6ONzqLPiZhzCPQhTdBHBL.jpg'),
(54611, 3752, 'Miami Vice S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xzajV9bWnDJKFamr5tAUYndVvo6.jpg'),
(54612, 3752, 'Miami Vice S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LB0q5sOf3QYAES0ztfYYi6H8lT.jpg'),
(54613, 3752, 'Miami Vice S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jsBRdTDiZaaKSqFKFXQETktcztp.jpg'),
(54614, 3752, 'Miami Vice S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bnDFh0CszwBj0SJ3L5xKqpS41ND.jpg'),
(54615, 3752, 'Miami Vice S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w9hjGTz4ECUGg2Z9ZuXUl8BvWdV.jpg'),
(54616, 3752, 'Miami Vice S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n5UM3HCxJ8PQDwLGYUcNhTB0CQo.jpg'),
(54617, 3752, 'Miami Vice S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/owlqidXZ6lilYPLYVIoV5eTtmvL.jpg'),
(54618, 3752, 'Miami Vice S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/BAI0xPE1BXZ8z0dKjwRd7aVHJX.jpg'),
(54619, 3752, 'Miami Vice S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/171181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eyExQmJxY23M19ctczwurrU8u7Q.jpg'),
(54620, 3752, 'Miami Vice S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/171182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFOrBqwCUSfzGFv160s8UaoerP4.jpg'),
(54621, 3752, 'Miami Vice S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/171183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wVtvWsfLAog0rAeoSSuDpRfdFYB.jpg'),
(54622, 3752, 'Miami Vice S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/171184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hFpknWWcX2GuWwBNuHt8V75kZxv.jpg'),
(54623, 3752, 'Miami Vice S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/171185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vv2EGw89e3rMFuuvOFBwDEIj5DD.jpg'),
(54624, 3752, 'Miami Vice S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/171186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwHyfCh77cpllrPKKFUziBpbJIN.jpg'),
(54625, 3753, 'Miami Vice S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/srBX1XcOH0Yx5xx5VYhSP1fkFSO.jpg'),
(54626, 3753, 'Miami Vice S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6NXByoQ40zg4UpQ63Vo9jEQmmN.jpg'),
(54627, 3753, 'Miami Vice S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mJxRYQyjLpsQPbC2e1nRnUVb952.jpg'),
(54628, 3753, 'Miami Vice S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/diXONhoBayhi7q3pZJchRoyRr18.jpg'),
(54629, 3753, 'Miami Vice S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6TPSD8PHVrCX0BuEeu8JSKMNrcC.jpg'),
(54630, 3753, 'Miami Vice S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/brppXoHnr7Qta9r7xen1lGKFpOT.jpg'),
(54631, 3753, 'Miami Vice S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ozOnlFCb12YT4iBGIc8I77NoAiq.jpg'),
(54632, 3753, 'Miami Vice S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wAEYDdcrY8oyRFlRZwFq6q7Oonm.jpg'),
(54633, 3753, 'Miami Vice S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c7IhgA6GfAu1zKqtKda499jgfsA.jpg'),
(54634, 3753, 'Miami Vice S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bieAtsZv99Ih92mWG2rmr14y2Ct.jpg'),
(54635, 3753, 'Miami Vice S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b4QVHKzsb1kpiEmnyKG9vTeme8W.jpg'),
(54636, 3753, 'Miami Vice S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9WYPucMpp65wCpcsIEZqqDNMOEm.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(54637, 3753, 'Miami Vice S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jmuiygjhDfBlkhVdS1DllaPd34a.jpg'),
(54638, 3753, 'Miami Vice S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mJsLHWWPRsyHt8oEd0BI7nZWXc7.jpg'),
(54639, 3753, 'Miami Vice S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wRu8lWQR9u7G2kCgnRwteZ1CkcU.jpg'),
(54640, 3753, 'Miami Vice S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nY7UU3znlh5D9UZiD5J7z1deicz.jpg'),
(54641, 3753, 'Miami Vice S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jCFBbUOIri9Umn4ob5tJIDC3UAX.jpg'),
(54642, 3753, 'Miami Vice S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6cMu4FTm1q918HcseySv7p5GPXs.jpg'),
(54643, 3753, 'Miami Vice S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/171205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgiJ2eJuZeKKCN5N9bylmde5Foe.jpg'),
(54644, 3753, 'Miami Vice S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/171206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tvxgKCwEGtDaB8amNyaM8OfTwzi.jpg'),
(54645, 3753, 'Miami Vice S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/171207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jg4MGn8tyWmce7wWzbeWRwzZGBS.jpg'),
(54646, 3753, 'Miami Vice S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/171208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/FXW000BXk2YFo53CIttUKPha7Z.jpg'),
(54647, 3754, 'Miami Vice S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cMvayuVkpFMkO8IipszPSZLuqZm.jpg'),
(54648, 3754, 'Miami Vice S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zk6sMsoas1X69qJhq7GTHlOVJ6E.jpg'),
(54649, 3754, 'Miami Vice S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1rggOnaM2uOGfci9jWth5O1DYlm.jpg'),
(54650, 3754, 'Miami Vice S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cvJ5TmsFAvEjg57yuVEgnBWty2h.jpg'),
(54651, 3754, 'Miami Vice S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/12ZEH40sDkO4NviXFvnpn6VPAiJ.jpg'),
(54652, 3754, 'Miami Vice S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xdN2GifGlZ50Az297HV1l9CNUxm.jpg'),
(54653, 3754, 'Miami Vice S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/QgoDbtlLoGMM1vVvSeuV47lgcm.jpg'),
(54654, 3754, 'Miami Vice S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m8ym6EstxB0qPpZSUet0bKM1Azi.jpg'),
(54655, 3754, 'Miami Vice S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/98qckBVTcbEuDoVuwNW2QudvelF.jpg'),
(54656, 3754, 'Miami Vice S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oMol2p05wZjq4gI757av6iWqBED.jpg'),
(54657, 3754, 'Miami Vice S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b6hjdQruSGOG10ctuuRYO9DTYLz.jpg'),
(54658, 3754, 'Miami Vice S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ZGlniG3CVPfwpzexTJEzVzYMr0.jpg'),
(54659, 3754, 'Miami Vice S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Zok7y1X3mwF5faDF2F3gwUBVYY.jpg'),
(54660, 3754, 'Miami Vice S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9T3quP2YkBAjuvi8pFZHcmRcOSX.jpg'),
(54661, 3754, 'Miami Vice S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f5iqgXzUgbcCTFEfJh7MYwWVK0Z.jpg'),
(54662, 3754, 'Miami Vice S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zknIuK2pJyRIuzSwLgySwYBSFHg.jpg'),
(54663, 3754, 'Miami Vice S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qQYfyiHigQDozm7VgHmRziCEa3S.jpg'),
(54664, 3754, 'Miami Vice S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7chAXRcQQ352dmhyExAlRCBFftV.jpg'),
(54665, 3754, 'Miami Vice S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/171227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1nhIWXSsX4XOToaKuIimQOxqwVc.jpg'),
(54666, 3754, 'Miami Vice S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/171228.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54667, 3754, 'Miami Vice S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/171229.mp4', 'http://gstaticontent.com/images/6psPEKu03UCiLqBxzeSy7wRQOVN_big.jpg'),
(54668, 3755, 'Panico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/148004.mp4', 'http://gstaticontent.com/images/ca18f95ffcc3ba19f05c52611dd4d867.jpg'),
(54669, 3755, 'Panico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/148005.mp4', 'http://gstaticontent.com/images/ca18f95ffcc3ba19f05c52611dd4d867.jpg'),
(54670, 3755, 'Panico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/148006.mp4', 'http://gstaticontent.com/images/ca18f95ffcc3ba19f05c52611dd4d867.jpg'),
(54671, 3755, 'Panico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/148007.mp4', 'http://gstaticontent.com/images/ca18f95ffcc3ba19f05c52611dd4d867.jpg'),
(54672, 3755, 'Panico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/148008.mp4', 'http://gstaticontent.com/images/ca18f95ffcc3ba19f05c52611dd4d867.jpg'),
(54673, 3755, 'Panico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/148009.mp4', 'http://gstaticontent.com/images/ca18f95ffcc3ba19f05c52611dd4d867.jpg'),
(54674, 3755, 'Panico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/148010.mp4', 'http://gstaticontent.com/images/ca18f95ffcc3ba19f05c52611dd4d867.jpg'),
(54675, 3755, 'Panico S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/148011.mp4', 'http://gstaticontent.com/images/ca18f95ffcc3ba19f05c52611dd4d867.jpg'),
(54676, 3755, 'Panico S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/148012.mp4', 'http://gstaticontent.com/images/ca18f95ffcc3ba19f05c52611dd4d867.jpg'),
(54677, 3755, 'Panico S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/148013.mp4', 'http://gstaticontent.com/images/ca18f95ffcc3ba19f05c52611dd4d867.jpg'),
(54678, 3756, 'Jovem Sheldon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216758.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54679, 3756, 'Jovem Sheldon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216759.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54680, 3756, 'Jovem Sheldon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216760.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54681, 3756, 'Jovem Sheldon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216761.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54682, 3756, 'Jovem Sheldon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216762.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54683, 3756, 'Jovem Sheldon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216763.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54684, 3756, 'Jovem Sheldon S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216764.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54685, 3756, 'Jovem Sheldon S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216765.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54686, 3756, 'Jovem Sheldon S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216766.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54687, 3756, 'Jovem Sheldon S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216767.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54688, 3756, 'Jovem Sheldon S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216768.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54689, 3756, 'Jovem Sheldon S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216769.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54690, 3756, 'Jovem Sheldon S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216770.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54691, 3756, 'Jovem Sheldon S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216771.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54692, 3756, 'Jovem Sheldon S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/216772.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54693, 3756, 'Jovem Sheldon S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/216773.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54694, 3756, 'Jovem Sheldon S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/216774.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54695, 3756, 'Jovem Sheldon S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/216775.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54696, 3756, 'Jovem Sheldon S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/216776.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54697, 3756, 'Jovem Sheldon S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/216777.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54698, 3756, 'Jovem Sheldon S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/216778.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54699, 3756, 'Jovem Sheldon S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/216779.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54700, 3757, 'Jovem Sheldon S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216780.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54701, 3757, 'Jovem Sheldon S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216781.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54702, 3757, 'Jovem Sheldon S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216782.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54703, 3757, 'Jovem Sheldon S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216783.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54704, 3757, 'Jovem Sheldon S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216784.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54705, 3757, 'Jovem Sheldon S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216785.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54706, 3757, 'Jovem Sheldon S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216786.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54707, 3757, 'Jovem Sheldon S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216787.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54708, 3757, 'Jovem Sheldon S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216788.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54709, 3757, 'Jovem Sheldon S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216789.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54710, 3757, 'Jovem Sheldon S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216790.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54711, 3757, 'Jovem Sheldon S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216791.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54712, 3757, 'Jovem Sheldon S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216792.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54713, 3757, 'Jovem Sheldon S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216793.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54714, 3757, 'Jovem Sheldon S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/216794.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54715, 3757, 'Jovem Sheldon S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/216795.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54716, 3757, 'Jovem Sheldon S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/216796.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54717, 3757, 'Jovem Sheldon S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/216797.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54718, 3757, 'Jovem Sheldon S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/216798.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54719, 3757, 'Jovem Sheldon S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/216799.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54720, 3757, 'Jovem Sheldon S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/216800.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54721, 3757, 'Jovem Sheldon S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/216801.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54722, 3758, 'Jovem Sheldon S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216802.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54723, 3758, 'Jovem Sheldon S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216803.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54724, 3758, 'Jovem Sheldon S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216804.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54725, 3758, 'Jovem Sheldon S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216805.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54726, 3758, 'Jovem Sheldon S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216806.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54727, 3758, 'Jovem Sheldon S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216807.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54728, 3758, 'Jovem Sheldon S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216808.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54729, 3758, 'Jovem Sheldon S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216809.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54730, 3758, 'Jovem Sheldon S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216810.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54731, 3758, 'Jovem Sheldon S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216811.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54732, 3758, 'Jovem Sheldon S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216812.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54733, 3758, 'Jovem Sheldon S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216813.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54734, 3758, 'Jovem Sheldon S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216814.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54735, 3758, 'Jovem Sheldon S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216815.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54736, 3758, 'Jovem Sheldon S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/216816.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54737, 3758, 'Jovem Sheldon S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/216817.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54738, 3758, 'Jovem Sheldon S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/216818.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54739, 3758, 'Jovem Sheldon S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/216819.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54740, 3758, 'Jovem Sheldon S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/216820.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54741, 3758, 'Jovem Sheldon S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/216821.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54742, 3758, 'Jovem Sheldon S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/216822.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54743, 3759, 'Jovem Sheldon S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216823.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54744, 3759, 'Jovem Sheldon S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216824.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54745, 3759, 'Jovem Sheldon S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216825.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54746, 3759, 'Jovem Sheldon S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216826.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54747, 3759, 'Jovem Sheldon S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216827.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54748, 3759, 'Jovem Sheldon S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216828.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54749, 3759, 'Jovem Sheldon S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216829.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54750, 3759, 'Jovem Sheldon S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216830.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54751, 3759, 'Jovem Sheldon S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216831.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54752, 3759, 'Jovem Sheldon S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216832.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54753, 3759, 'Jovem Sheldon S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216833.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54754, 3759, 'Jovem Sheldon S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216834.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54755, 3759, 'Jovem Sheldon S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216835.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54756, 3759, 'Jovem Sheldon S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216836.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54757, 3759, 'Jovem Sheldon S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/216837.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54758, 3759, 'Jovem Sheldon S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/216838.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54759, 3759, 'Jovem Sheldon S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/216839.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54760, 3759, 'Jovem Sheldon S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/216840.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54761, 3760, 'Jovem Sheldon S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216841.mp4', 'http://image.tmdb.org/t/p/w1280/gG5LaaxH0uZUWIZUWnKLNsNqmye.jpg'),
(54762, 3760, 'Jovem Sheldon S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5wyW5bhCMLjgSIzRS4JTOR4a7Ak.jpg'),
(54763, 3760, 'Jovem Sheldon S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uMPNSoA5bKLPkyIOG8KWVitz4Fz.jpg'),
(54764, 3760, 'Jovem Sheldon S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216844.mp4', 'http://image.tmdb.org/t/p/w1280/8YL0EF1nSHHkeoJPaDoOJuHME3d.jpg'),
(54765, 3760, 'Jovem Sheldon S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216845.mp4', 'http://image.tmdb.org/t/p/w1280/iWwUiQL1aUvjegT5GEb9SDK3T2t.jpg'),
(54766, 3760, 'Jovem Sheldon S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216846.mp4', 'http://image.tmdb.org/t/p/w1280/cviIge26xfT7ZdC80tD744SedmK.jpg'),
(54767, 3760, 'Jovem Sheldon S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216847.mp4', 'http://image.tmdb.org/t/p/w1280/n4uSGuTgk98c4llSOmRsxuUXzGF.jpg'),
(54768, 3760, 'Jovem Sheldon S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216848.mp4', 'http://image.tmdb.org/t/p/w1280/lq7pxjxi9aBpl75IWpesQTSfinQ.jpg'),
(54769, 3760, 'Jovem Sheldon S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216849.mp4', 'http://timg.bdta.pro/images/3ab6d3a4a6282d7e4763745d73c1b50b.jpg'),
(54770, 3760, 'Jovem Sheldon S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216850.mp4', 'http://timg.bdta.pro/images/322c24c89af7471cc04dbd4a897d35d2.jpg'),
(54771, 3760, 'Jovem Sheldon S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216851.mp4', 'http://timg.bdta.pro/images/0cce1885a5ca993cf54c2382d38935cf.jpg'),
(54772, 3760, 'Jovem Sheldon S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216852.mp4', 'http://timg.bdta.pro/images/fe47e82dd0d82232a09f7d0c7f707d99.jpg'),
(54773, 3760, 'Jovem Sheldon S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216853.mp4', 'http://timg.bdta.pro/images/c0dd407478d7b1f63760e4dad7ce111e.jpg'),
(54774, 3760, 'Jovem Sheldon S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216854.mp4', 'http://timg.bdta.pro/images/f8b56be81fb4ce169c39ef4bb7c62840.jpg'),
(54775, 3760, 'Jovem Sheldon S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/216855.mp4', 'http://timg.bdta.pro/images/deb7f34e38da5ab2458decea1aaa1e8f.jpg'),
(54776, 3760, 'Jovem Sheldon S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/216856.mp4', 'http://timg.bdta.pro/images/f3d5272de2369af0020a9d03bc9e9dee.jpg'),
(54777, 3760, 'Jovem Sheldon S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/216857.mp4', 'http://timg.bdta.pro/images/0f4290217c973748ecf95925db7fe877.jpg'),
(54778, 3760, 'Jovem Sheldon S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/216858.mp4', 'http://timg.bdta.pro/images/1f443ab8a5a4811921f144da865b3d50.jpg'),
(54779, 3760, 'Jovem Sheldon S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/216859.mp4', 'http://timg.bdta.pro/images/eb5eb442c7bc0e609051325cd7096a7f.jpg'),
(54780, 3760, 'Jovem Sheldon S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/216860.mp4', 'http://timg.bdta.pro/images/f21452ad15ed81ed5b3503cb9aef4bd3.jpg'),
(54781, 3760, 'Jovem Sheldon S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/216861.mp4', 'http://timg.bdta.pro/images/e0fa0beb157617748e830141a4cecaa3.jpg'),
(54782, 3760, 'Jovem Sheldon S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/216862.mp4', 'http://timg.bdta.pro/images/790aa457ccad32a84c04f7074277ff8e.jpg'),
(54783, 3761, 'Jovem Sheldon S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216863.mp4', 'http://timg.bdta.pro/images/b7ac0ed7e80631b5397c5fa0abe777cf.jpg'),
(54784, 3761, 'Jovem Sheldon S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216864.mp4', 'http://timg.bdta.pro/images/e03880f1216790f2321e4f2a9d936762.jpg'),
(54785, 3761, 'Jovem Sheldon S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u3IOqCoq8cabk1x2AVU5auRGToP.jpg'),
(54786, 3761, 'Jovem Sheldon S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aNEEmmjNhbhZzomJnjzsCdHi4VV.jpg'),
(54787, 3761, 'Jovem Sheldon S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216867.mp4', 'http://image.tmdb.org/t/p/w1280/qlQD3Sztrv0C3QgiZEgAnVcyhTZ.jpg'),
(54788, 3761, 'Jovem Sheldon S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mzUQnRmSTwpRXwS4ir8K8SwF0me.jpg'),
(54789, 3761, 'Jovem Sheldon S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZJLi6QxqSMZDIJiLOSyqBu8Xmj.jpg'),
(54790, 3761, 'Jovem Sheldon S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216870.mp4', 'http://image.tmdb.org/t/p/w1280/eA3L4JjohZQ3SUWsthJPhD8M9Xc.jpg'),
(54791, 3761, 'Jovem Sheldon S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216871.mp4', 'http://image.tmdb.org/t/p/w1280/m1oJhHrr8STFggTO8pL11tv3J23.jpg'),
(54792, 3761, 'Jovem Sheldon S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216872.mp4', 'http://image.tmdb.org/t/p/w1280/g5LmrOYGuWh9YNAGWN5JGdwz93w.jpg'),
(54793, 3761, 'Jovem Sheldon S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216873.mp4', 'http://image.tmdb.org/t/p/w1280/snBaRTSYkWglHBpSi51Om10ADOm.jpg'),
(54794, 3761, 'Jovem Sheldon S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216874.mp4', 'http://image.tmdb.org/t/p/w1280/lGwTCqFCKbvqLnQRzTjuQ8hY6Md.jpg'),
(54795, 3761, 'Jovem Sheldon S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216875.mp4', 'http://image.tmdb.org/t/p/w1280/cPA8ZkRH5XGu43gzDt7gsYsXGi1.jpg'),
(54796, 3761, 'Jovem Sheldon S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216876.mp4', 'http://image.tmdb.org/t/p/w1280/7tvyDOU9il87vcYDpcr0jqYvVFd.jpg'),
(54797, 3761, 'Jovem Sheldon S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/216877.mp4', 'http://image.tmdb.org/t/p/w1280/A84jd0hy2HknvhedvANm39NMiPZ.jpg'),
(54798, 3761, 'Jovem Sheldon S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/216878.mp4', 'http://image.tmdb.org/t/p/w1280/yrKOxPKm4gbx2jxRT4MfeEJApyt.jpg'),
(54799, 3761, 'Jovem Sheldon S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/216879.mp4', 'http://image.tmdb.org/t/p/w1280/n8jKdyadKzMxgcs2vVYdOeB09Te.jpg'),
(54800, 3761, 'Jovem Sheldon S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/216880.mp4', 'http://image.tmdb.org/t/p/w1280/8c7ATGdluYgGVuThzipAHJnq9Gt.jpg'),
(54801, 3761, 'Jovem Sheldon S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/216881.mp4', 'http://image.tmdb.org/t/p/w1280/zXrtCtXysMFZRxEdUm6gWgKZULR.jpg'),
(54802, 3761, 'Jovem Sheldon S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/216882.mp4', 'http://image.tmdb.org/t/p/w1280/owDGDWt7lymFbWxmPIBAR7c6q39.jpg'),
(54803, 3761, 'Jovem Sheldon S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/216883.mp4', 'http://image.tmdb.org/t/p/w1280/iIsAhVXpjLfxBSuNv6smxxIFGX9.jpg'),
(54804, 3761, 'Jovem Sheldon S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/216884.mp4', 'http://image.tmdb.org/t/p/w1280/75uR97IR3wNViz9P61j2NYPFzKc.jpg'),
(54805, 3762, 'Jovem Sheldon S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/288126.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54806, 3762, 'Jovem Sheldon S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/296610.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54807, 3762, 'Jovem Sheldon S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/299656.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54808, 3762, 'Jovem Sheldon S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/303686.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54809, 3762, 'Jovem Sheldon S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/313062.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54810, 3762, 'Jovem Sheldon S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/330944.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54811, 3762, 'Jovem Sheldon S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/335175.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54812, 3762, 'Jovem Sheldon S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/350909.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54813, 3762, 'Jovem Sheldon S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/350910.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54814, 3762, 'Jovem Sheldon S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/350911.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54815, 3762, 'Jovem Sheldon S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/350912.mp4', 'http://gstaticontent.com/images/22WUYECiv0phV61rBbfS7DvS6kT_big.jpg'),
(54816, 3762, 'Jovem Sheldon S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/371877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ldeIgW8FeWCxyolFFSHGlJc48gT.jpg'),
(54817, 3762, 'Jovem Sheldon S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/371878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iNN6HkE2lPx7dKiXSH3K6cbuxcT.jpg'),
(54818, 3762, 'Jovem Sheldon S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/371879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8WpVoP3kCYzWJq6oLqictXolheL.jpg'),
(54819, 3763, 'Escola de Magia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147760.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54820, 3763, 'Escola de Magia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147761.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54821, 3763, 'Escola de Magia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147762.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54822, 3763, 'Escola de Magia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147763.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54823, 3763, 'Escola de Magia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147764.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54824, 3763, 'Escola de Magia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147765.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54825, 3763, 'Escola de Magia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147766.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54826, 3763, 'Escola de Magia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147767.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54827, 3763, 'Escola de Magia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147768.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54828, 3763, 'Escola de Magia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147769.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54829, 3763, 'Escola de Magia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147770.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54830, 3763, 'Escola de Magia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147771.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54831, 3763, 'Escola de Magia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147772.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54832, 3764, 'Escola de Magia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147773.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54833, 3764, 'Escola de Magia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147774.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54834, 3764, 'Escola de Magia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147775.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54835, 3764, 'Escola de Magia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147776.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54836, 3764, 'Escola de Magia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147777.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54837, 3764, 'Escola de Magia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147778.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54838, 3764, 'Escola de Magia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147779.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54839, 3764, 'Escola de Magia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147780.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54840, 3764, 'Escola de Magia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147781.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54841, 3764, 'Escola de Magia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147782.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54842, 3764, 'Escola de Magia S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147783.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54843, 3764, 'Escola de Magia S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147784.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54844, 3764, 'Escola de Magia S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147785.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54845, 3765, 'Escola de Magia S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147786.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54846, 3765, 'Escola de Magia S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147787.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54847, 3765, 'Escola de Magia S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147788.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54848, 3765, 'Escola de Magia S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147789.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54849, 3765, 'Escola de Magia S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147790.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54850, 3765, 'Escola de Magia S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147791.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54851, 3765, 'Escola de Magia S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147792.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54852, 3765, 'Escola de Magia S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147793.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54853, 3765, 'Escola de Magia S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147794.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54854, 3765, 'Escola de Magia S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147795.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54855, 3765, 'Escola de Magia S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147796.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54856, 3765, 'Escola de Magia S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147797.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54857, 3765, 'Escola de Magia S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147798.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54858, 3766, 'Escola de Magia S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147799.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54859, 3766, 'Escola de Magia S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147800.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54860, 3766, 'Escola de Magia S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147801.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54861, 3766, 'Escola de Magia S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147802.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54862, 3766, 'Escola de Magia S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147803.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54863, 3766, 'Escola de Magia S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147804.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54864, 3766, 'Escola de Magia S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147805.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54865, 3766, 'Escola de Magia S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147806.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54866, 3766, 'Escola de Magia S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147807.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54867, 3766, 'Escola de Magia S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147808.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54868, 3766, 'Escola de Magia S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147809.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54869, 3766, 'Escola de Magia S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147810.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54870, 3766, 'Escola de Magia S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147811.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54871, 3767, 'Escola de Magia S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147812.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54872, 3767, 'Escola de Magia S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147813.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54873, 3767, 'Escola de Magia S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147814.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54874, 3767, 'Escola de Magia S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147815.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54875, 3767, 'Escola de Magia S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147816.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54876, 3767, 'Escola de Magia S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147817.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54877, 3767, 'Escola de Magia S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147818.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54878, 3767, 'Escola de Magia S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147819.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54879, 3767, 'Escola de Magia S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147820.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54880, 3767, 'Escola de Magia S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147821.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54881, 3767, 'Escola de Magia S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147822.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54882, 3767, 'Escola de Magia S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147823.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54883, 3767, 'Escola de Magia S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147824.mp4', 'http://gstaticontent.com/images/A66dZN98BPEYeFQAhNdNCIXa57d_big.jpg'),
(54884, 3768, 'Arremesso Final S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147743.mp4', 'http://gstaticontent.com/images/3a50zkySihNjgRfhLl2qIdhie7p_big.jpg'),
(54885, 3768, 'Arremesso Final S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147744.mp4', 'http://gstaticontent.com/images/3a50zkySihNjgRfhLl2qIdhie7p_big.jpg'),
(54886, 3768, 'Arremesso Final S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147745.mp4', 'http://gstaticontent.com/images/3a50zkySihNjgRfhLl2qIdhie7p_big.jpg'),
(54887, 3768, 'Arremesso Final S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147746.mp4', 'http://gstaticontent.com/images/3a50zkySihNjgRfhLl2qIdhie7p_big.jpg'),
(54888, 3768, 'Arremesso Final S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147747.mp4', 'http://gstaticontent.com/images/3a50zkySihNjgRfhLl2qIdhie7p_big.jpg'),
(54889, 3768, 'Arremesso Final S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147748.mp4', 'http://gstaticontent.com/images/3a50zkySihNjgRfhLl2qIdhie7p_big.jpg'),
(54890, 3768, 'Arremesso Final S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147749.mp4', 'http://gstaticontent.com/images/3a50zkySihNjgRfhLl2qIdhie7p_big.jpg'),
(54891, 3768, 'Arremesso Final S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147750.mp4', 'http://gstaticontent.com/images/3a50zkySihNjgRfhLl2qIdhie7p_big.jpg'),
(54892, 3768, 'Arremesso Final S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147751.mp4', 'http://gstaticontent.com/images/3a50zkySihNjgRfhLl2qIdhie7p_big.jpg'),
(54893, 3768, 'Arremesso Final S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147752.mp4', 'http://gstaticontent.com/images/3a50zkySihNjgRfhLl2qIdhie7p_big.jpg'),
(54894, 3769, 'Assassinato em Middle Beach S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147739.mp4', 'http://gstaticontent.com/images/j1VQYGEK8GZgqgGT0RrHTjk8NpG_big.jpg'),
(54895, 3769, 'Assassinato em Middle Beach S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147740.mp4', 'http://gstaticontent.com/images/j1VQYGEK8GZgqgGT0RrHTjk8NpG_big.jpg'),
(54896, 3769, 'Assassinato em Middle Beach S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147741.mp4', 'http://gstaticontent.com/images/j1VQYGEK8GZgqgGT0RrHTjk8NpG_big.jpg'),
(54897, 3769, 'Assassinato em Middle Beach S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147742.mp4', 'http://gstaticontent.com/images/j1VQYGEK8GZgqgGT0RrHTjk8NpG_big.jpg'),
(54898, 3770, 'Interrogation S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147729.mp4', 'http://gstaticontent.com/images/oJAvkzejtQzqwsDjkd8Y0m2oDL9_big.jpg'),
(54899, 3770, 'Interrogation S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147730.mp4', 'http://gstaticontent.com/images/oJAvkzejtQzqwsDjkd8Y0m2oDL9_big.jpg'),
(54900, 3770, 'Interrogation S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147731.mp4', 'http://gstaticontent.com/images/oJAvkzejtQzqwsDjkd8Y0m2oDL9_big.jpg'),
(54901, 3770, 'Interrogation S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147732.mp4', 'http://gstaticontent.com/images/oJAvkzejtQzqwsDjkd8Y0m2oDL9_big.jpg'),
(54902, 3770, 'Interrogation S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147733.mp4', 'http://gstaticontent.com/images/oJAvkzejtQzqwsDjkd8Y0m2oDL9_big.jpg'),
(54903, 3770, 'Interrogation S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147734.mp4', 'http://gstaticontent.com/images/oJAvkzejtQzqwsDjkd8Y0m2oDL9_big.jpg'),
(54904, 3770, 'Interrogation S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147735.mp4', 'http://gstaticontent.com/images/oJAvkzejtQzqwsDjkd8Y0m2oDL9_big.jpg'),
(54905, 3770, 'Interrogation S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147736.mp4', 'http://gstaticontent.com/images/oJAvkzejtQzqwsDjkd8Y0m2oDL9_big.jpg'),
(54906, 3770, 'Interrogation S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147737.mp4', 'http://gstaticontent.com/images/oJAvkzejtQzqwsDjkd8Y0m2oDL9_big.jpg'),
(54907, 3770, 'Interrogation S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147738.mp4', 'http://gstaticontent.com/images/oJAvkzejtQzqwsDjkd8Y0m2oDL9_big.jpg'),
(54908, 3771, 'Jessie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147628.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54909, 3771, 'Jessie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147629.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54910, 3771, 'Jessie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147630.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54911, 3771, 'Jessie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147631.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54912, 3771, 'Jessie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147632.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54913, 3771, 'Jessie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147633.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54914, 3771, 'Jessie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147634.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54915, 3771, 'Jessie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147635.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54916, 3771, 'Jessie S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147636.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54917, 3771, 'Jessie S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147637.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54918, 3771, 'Jessie S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147638.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54919, 3771, 'Jessie S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147639.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54920, 3771, 'Jessie S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147640.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54921, 3771, 'Jessie S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147641.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(54922, 3771, 'Jessie S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147642.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54923, 3771, 'Jessie S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147643.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54924, 3771, 'Jessie S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/147644.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54925, 3771, 'Jessie S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/147645.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54926, 3771, 'Jessie S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/147646.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54927, 3771, 'Jessie S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/147647.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54928, 3771, 'Jessie S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/147648.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54929, 3771, 'Jessie S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/147649.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54930, 3771, 'Jessie S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/147650.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54931, 3771, 'Jessie S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/147651.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54932, 3771, 'Jessie S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/147652.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54933, 3771, 'Jessie S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/147653.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54934, 3772, 'Jessie S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147654.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54935, 3772, 'Jessie S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147655.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54936, 3772, 'Jessie S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147656.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54937, 3772, 'Jessie S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147657.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54938, 3772, 'Jessie S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147658.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54939, 3772, 'Jessie S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147659.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54940, 3772, 'Jessie S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147660.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54941, 3772, 'Jessie S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147661.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54942, 3772, 'Jessie S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147662.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54943, 3772, 'Jessie S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147663.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54944, 3772, 'Jessie S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147664.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54945, 3772, 'Jessie S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147665.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54946, 3772, 'Jessie S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147666.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54947, 3772, 'Jessie S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147667.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54948, 3772, 'Jessie S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147668.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54949, 3772, 'Jessie S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147669.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54950, 3772, 'Jessie S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/147670.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54951, 3772, 'Jessie S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/147671.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54952, 3772, 'Jessie S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/147672.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54953, 3772, 'Jessie S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/147673.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54954, 3772, 'Jessie S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/147674.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54955, 3772, 'Jessie S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/147675.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54956, 3772, 'Jessie S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/147676.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54957, 3772, 'Jessie S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/147677.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54958, 3772, 'Jessie S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/147678.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54959, 3772, 'Jessie S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/147679.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54960, 3772, 'Jessie S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/147680.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54961, 3772, 'Jessie S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/147681.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54962, 3773, 'Jessie S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147682.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54963, 3773, 'Jessie S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147683.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54964, 3773, 'Jessie S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147684.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54965, 3773, 'Jessie S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147685.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54966, 3773, 'Jessie S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147686.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54967, 3773, 'Jessie S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147687.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54968, 3773, 'Jessie S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147688.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54969, 3773, 'Jessie S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147689.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54970, 3773, 'Jessie S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147690.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54971, 3773, 'Jessie S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147691.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54972, 3773, 'Jessie S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147692.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54973, 3773, 'Jessie S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147693.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54974, 3773, 'Jessie S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147694.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54975, 3773, 'Jessie S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147695.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54976, 3773, 'Jessie S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147696.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54977, 3773, 'Jessie S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147697.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54978, 3773, 'Jessie S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/147698.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54979, 3773, 'Jessie S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/147699.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54980, 3773, 'Jessie S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/147700.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54981, 3773, 'Jessie S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/147701.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54982, 3773, 'Jessie S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/147702.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54983, 3773, 'Jessie S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/147703.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54984, 3773, 'Jessie S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/147704.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54985, 3773, 'Jessie S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/147705.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54986, 3773, 'Jessie S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/147706.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54987, 3773, 'Jessie S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/147707.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54988, 3773, 'Jessie S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/147708.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54989, 3774, 'Jessie S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147709.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54990, 3774, 'Jessie S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147710.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54991, 3774, 'Jessie S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147711.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54992, 3774, 'Jessie S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147712.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54993, 3774, 'Jessie S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147713.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54994, 3774, 'Jessie S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147714.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54995, 3774, 'Jessie S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147715.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54996, 3774, 'Jessie S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147716.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54997, 3774, 'Jessie S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147717.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54998, 3774, 'Jessie S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147718.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(54999, 3774, 'Jessie S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147719.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(55000, 3774, 'Jessie S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147720.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(55001, 3774, 'Jessie S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147721.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(55002, 3774, 'Jessie S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147722.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(55003, 3774, 'Jessie S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147723.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(55004, 3774, 'Jessie S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147724.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(55005, 3774, 'Jessie S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/147725.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(55006, 3774, 'Jessie S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/147726.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(55007, 3774, 'Jessie S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/147727.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(55008, 3774, 'Jessie S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/147728.mp4', 'http://gstaticontent.com/images/tspQe0FuiaUj0U1R1norNbiYTe4_big.jpg'),
(55009, 3775, 'Mães A(r)madas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147615.mp4', 'http://gstaticontent.com/images/5HA8IEofJfxGsCoE9gMSPBNZW9E_big.jpg'),
(55010, 3775, 'Mães A(r)madas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147616.mp4', 'http://gstaticontent.com/images/5HA8IEofJfxGsCoE9gMSPBNZW9E_big.jpg'),
(55011, 3775, 'Mães A(r)madas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147617.mp4', 'http://gstaticontent.com/images/5HA8IEofJfxGsCoE9gMSPBNZW9E_big.jpg'),
(55012, 3775, 'Mães A(r)madas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147618.mp4', 'http://gstaticontent.com/images/5HA8IEofJfxGsCoE9gMSPBNZW9E_big.jpg'),
(55013, 3775, 'Mães A(r)madas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147619.mp4', 'http://gstaticontent.com/images/5HA8IEofJfxGsCoE9gMSPBNZW9E_big.jpg'),
(55014, 3775, 'Mães A(r)madas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147620.mp4', 'http://gstaticontent.com/images/5HA8IEofJfxGsCoE9gMSPBNZW9E_big.jpg'),
(55015, 3775, 'Mães A(r)madas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147621.mp4', 'http://gstaticontent.com/images/5HA8IEofJfxGsCoE9gMSPBNZW9E_big.jpg'),
(55016, 3775, 'Mães A(r)madas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147622.mp4', 'http://gstaticontent.com/images/5HA8IEofJfxGsCoE9gMSPBNZW9E_big.jpg'),
(55017, 3775, 'Mães A(r)madas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147623.mp4', 'http://gstaticontent.com/images/5HA8IEofJfxGsCoE9gMSPBNZW9E_big.jpg'),
(55018, 3775, 'Mães A(r)madas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147624.mp4', 'http://gstaticontent.com/images/5HA8IEofJfxGsCoE9gMSPBNZW9E_big.jpg'),
(55019, 3775, 'Mães A(r)madas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147625.mp4', 'http://gstaticontent.com/images/5HA8IEofJfxGsCoE9gMSPBNZW9E_big.jpg'),
(55020, 3775, 'Mães A(r)madas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147626.mp4', 'http://gstaticontent.com/images/5HA8IEofJfxGsCoE9gMSPBNZW9E_big.jpg'),
(55021, 3775, 'Mães A(r)madas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147627.mp4', 'http://gstaticontent.com/images/5HA8IEofJfxGsCoE9gMSPBNZW9E_big.jpg'),
(55022, 3776, 'Clube do Terror (1992) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147589.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55023, 3776, 'Clube do Terror (1992) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147590.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55024, 3776, 'Clube do Terror (1992) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147591.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55025, 3776, 'Clube do Terror (1992) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147592.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55026, 3776, 'Clube do Terror (1992) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147593.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55027, 3776, 'Clube do Terror (1992) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147594.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55028, 3776, 'Clube do Terror (1992) S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147595.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55029, 3776, 'Clube do Terror (1992) S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147596.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55030, 3776, 'Clube do Terror (1992) S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147597.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55031, 3776, 'Clube do Terror (1992) S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147598.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55032, 3776, 'Clube do Terror (1992) S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147599.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55033, 3776, 'Clube do Terror (1992) S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147600.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55034, 3776, 'Clube do Terror (1992) S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147601.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55035, 3777, 'Clube do Terror (1992) S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147602.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55036, 3777, 'Clube do Terror (1992) S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147603.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55037, 3777, 'Clube do Terror (1992) S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147604.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55038, 3777, 'Clube do Terror (1992) S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147605.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55039, 3777, 'Clube do Terror (1992) S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147606.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55040, 3777, 'Clube do Terror (1992) S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147607.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55041, 3777, 'Clube do Terror (1992) S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147608.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55042, 3777, 'Clube do Terror (1992) S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147609.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55043, 3777, 'Clube do Terror (1992) S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147610.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55044, 3777, 'Clube do Terror (1992) S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147611.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55045, 3777, 'Clube do Terror (1992) S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147612.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55046, 3777, 'Clube do Terror (1992) S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147613.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55047, 3777, 'Clube do Terror (1992) S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147614.mp4', 'http://gstaticontent.com/images/5BO6UporfDKmCD5DhE4P8Msi5yH_big.jpg'),
(55048, 3778, 'The Hidden Dungeon Only I Can Enter S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147577.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(55049, 3778, 'The Hidden Dungeon Only I Can Enter S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147578.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(55050, 3778, 'The Hidden Dungeon Only I Can Enter S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147579.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(55051, 3778, 'The Hidden Dungeon Only I Can Enter S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147580.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(55052, 3778, 'The Hidden Dungeon Only I Can Enter S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147581.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(55053, 3778, 'The Hidden Dungeon Only I Can Enter S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147582.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(55054, 3778, 'The Hidden Dungeon Only I Can Enter S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147583.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(55055, 3778, 'The Hidden Dungeon Only I Can Enter S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147584.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(55056, 3778, 'The Hidden Dungeon Only I Can Enter S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147585.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(55057, 3778, 'The Hidden Dungeon Only I Can Enter S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147586.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(55058, 3778, 'The Hidden Dungeon Only I Can Enter S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147587.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(55059, 3778, 'The Hidden Dungeon Only I Can Enter S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147588.mp4', 'http://gstaticontent.com/images/58YKpuGSk8hj4cmThJpUT8Vt1mG_big.jpg'),
(55060, 3779, 'Trying S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194523.mp4', 'http://gstaticontent.com/images/hF3twh1IzZYPoagGVJyI5gOxMuE_big.jpg'),
(55061, 3779, 'Trying S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194524.mp4', 'http://gstaticontent.com/images/hF3twh1IzZYPoagGVJyI5gOxMuE_big.jpg'),
(55062, 3779, 'Trying S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194525.mp4', 'http://gstaticontent.com/images/hF3twh1IzZYPoagGVJyI5gOxMuE_big.jpg'),
(55063, 3779, 'Trying S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194526.mp4', 'http://gstaticontent.com/images/hF3twh1IzZYPoagGVJyI5gOxMuE_big.jpg'),
(55064, 3779, 'Trying S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194527.mp4', 'http://gstaticontent.com/images/hF3twh1IzZYPoagGVJyI5gOxMuE_big.jpg'),
(55065, 3779, 'Trying S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194528.mp4', 'http://gstaticontent.com/images/hF3twh1IzZYPoagGVJyI5gOxMuE_big.jpg'),
(55066, 3779, 'Trying S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194529.mp4', 'http://gstaticontent.com/images/hF3twh1IzZYPoagGVJyI5gOxMuE_big.jpg'),
(55067, 3779, 'Trying S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194530.mp4', 'http://gstaticontent.com/images/hF3twh1IzZYPoagGVJyI5gOxMuE_big.jpg'),
(55068, 3780, 'Trying S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194531.mp4', 'http://timg.bdta.pro/images/f4c208863e65c81e52d41859a9cafff5.jpg'),
(55069, 3780, 'Trying S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194532.mp4', 'http://timg.bdta.pro/images/fc641a8b5a55cea298f90f731138e52d.jpg'),
(55070, 3780, 'Trying S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194533.mp4', 'http://timg.bdta.pro/images/43fbc8ccab584d9dc0e4bc16b16acfd4.jpg'),
(55071, 3780, 'Trying S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194534.mp4', 'http://timg.bdta.pro/images/ea9ecdd313d7b90ef395c8aa751e8f3b.jpg'),
(55072, 3780, 'Trying S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194535.mp4', 'http://timg.bdta.pro/images/04ed89709dc43d31eefc917e2bc2bdb5.jpg'),
(55073, 3780, 'Trying S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194536.mp4', 'http://timg.bdta.pro/images/02ea4c3a7a90267a942e8512c15206a4.jpg'),
(55074, 3780, 'Trying S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194537.mp4', 'http://timg.bdta.pro/images/6feae6d16a8e5e766525b33e3797bf3c.jpg'),
(55075, 3780, 'Trying S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194538.mp4', 'http://timg.bdta.pro/images/1678fa3cc025fcf69d97906c0a899ba5.jpg'),
(55076, 3781, 'Trying S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194539.mp4', 'http://timg.bdta.pro/images/f7362bc96177295a588530bf3a59373e.jpg'),
(55077, 3781, 'Trying S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194540.mp4', 'http://timg.bdta.pro/images/ea11605abdb9159f604ef6bff99ac66c.jpg'),
(55078, 3781, 'Trying S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194541.mp4', 'http://timg.bdta.pro/images/5a4e86c532aada445ba9a134ad78da22.jpg'),
(55079, 3781, 'Trying S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194542.mp4', 'http://timg.bdta.pro/images/817585a905e769bb11d61c4740401d3f.jpg'),
(55080, 3781, 'Trying S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194543.mp4', 'http://timg.bdta.pro/images/e60d61788e25981f486e44645bb88dc3.jpg'),
(55081, 3781, 'Trying S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194544.mp4', 'http://timg.bdta.pro/images/2780727ffa4c058ef7b11b614b179122.jpg'),
(55082, 3781, 'Trying S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194545.mp4', 'http://timg.bdta.pro/images/9e362266bdd0e3e2eab7fa95ef8a070f.jpg'),
(55083, 3781, 'Trying S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194546.mp4', 'http://timg.bdta.pro/images/d9dc15cf97d36eea6063618ad36d83f7.jpg'),
(55084, 3782, 'Trying S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/358252.mp4', 'http://gstaticontent.com/images/hF3twh1IzZYPoagGVJyI5gOxMuE_big.jpg'),
(55085, 3782, 'Trying S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/358253.mp4', 'http://gstaticontent.com/images/hF3twh1IzZYPoagGVJyI5gOxMuE_big.jpg'),
(55086, 3782, 'Trying S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/608572.mp4', 'http://gstaticontent.com/images/hF3twh1IzZYPoagGVJyI5gOxMuE_big.jpg'),
(55087, 3782, 'Trying S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/372758.mp4', 'http://gstaticontent.com/images/hF3twh1IzZYPoagGVJyI5gOxMuE_big.jpg'),
(55088, 3782, 'Trying S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/383840.mp4', 'http://gstaticontent.com/images/hF3twh1IzZYPoagGVJyI5gOxMuE_big.jpg'),
(55089, 3782, 'Trying S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/388311.mp4', 'http://gstaticontent.com/images/hF3twh1IzZYPoagGVJyI5gOxMuE_big.jpg'),
(55090, 3782, 'Trying S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/393978.mp4', 'http://gstaticontent.com/images/hF3twh1IzZYPoagGVJyI5gOxMuE_big.jpg'),
(55091, 3782, 'Trying S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/400052.mp4', 'http://gstaticontent.com/images/hF3twh1IzZYPoagGVJyI5gOxMuE_big.jpg'),
(55092, 3783, 'Departure: A Investigação S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204253.mp4', 'http://gstaticontent.com/images/tbzWZIpLTI9QL91VvwljKuXhLUc_big.jpg'),
(55093, 3783, 'Departure: A Investigação S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204254.mp4', 'http://gstaticontent.com/images/tbzWZIpLTI9QL91VvwljKuXhLUc_big.jpg'),
(55094, 3783, 'Departure: A Investigação S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204255.mp4', 'http://gstaticontent.com/images/tbzWZIpLTI9QL91VvwljKuXhLUc_big.jpg'),
(55095, 3783, 'Departure: A Investigação S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204256.mp4', 'http://gstaticontent.com/images/tbzWZIpLTI9QL91VvwljKuXhLUc_big.jpg'),
(55096, 3783, 'Departure: A Investigação S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204257.mp4', 'http://gstaticontent.com/images/tbzWZIpLTI9QL91VvwljKuXhLUc_big.jpg'),
(55097, 3783, 'Departure: A Investigação S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204258.mp4', 'http://gstaticontent.com/images/tbzWZIpLTI9QL91VvwljKuXhLUc_big.jpg'),
(55098, 3784, 'Departure: A Investigação S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qMySIsxcUuz7pOaH0mDCwEF10i8.jpg'),
(55099, 3784, 'Departure: A Investigação S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gc1kvgr4XAjO7cM4LMGJqNQpMC2.jpg'),
(55100, 3784, 'Departure: A Investigação S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mfie3TJrKd6ml3VxojIpnt3jrQF.jpg'),
(55101, 3784, 'Departure: A Investigação S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3vfJq7rmbbyD01UA36X3aGD81LS.jpg'),
(55102, 3784, 'Departure: A Investigação S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7uZSykS9EHJwgGCVMdVFk9kxBtV.jpg'),
(55103, 3784, 'Departure: A Investigação S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/65xctJ5DuAtEh4NS28bIUx3M1hE.jpg'),
(55104, 3785, 'Departure: A Investigação S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Ek9dKeCaQdDgOVCoptXypMxMfu.jpg'),
(55105, 3785, 'Departure: A Investigação S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dITqxQUgdPS3eNpPXlm1F4Epz5r.jpg'),
(55106, 3785, 'Departure: A Investigação S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wk9ivtnIb5pp1VI5TBlBXcS8lS7.jpg'),
(55107, 3785, 'Departure: A Investigação S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5KsyGMT4DHVqDjx4gsljjC2hgPs.jpg'),
(55108, 3785, 'Departure: A Investigação S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1M3wF5Q7nDEVK8LHPb7NdHJuFmi.jpg'),
(55109, 3785, 'Departure: A Investigação S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iHVgVFchmnGmkAZSsuXLdSvfKLB.jpg'),
(55110, 3786, 'DOM S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212168.mp4', 'http://gstaticontent.com/images/9KlPkK0cLSpIzrAlD7TqInsZSFn_big.jpg'),
(55111, 3786, 'DOM S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212169.mp4', 'http://gstaticontent.com/images/9KlPkK0cLSpIzrAlD7TqInsZSFn_big.jpg'),
(55112, 3786, 'DOM S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212170.mp4', 'http://gstaticontent.com/images/9KlPkK0cLSpIzrAlD7TqInsZSFn_big.jpg'),
(55113, 3786, 'DOM S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212171.mp4', 'http://gstaticontent.com/images/9KlPkK0cLSpIzrAlD7TqInsZSFn_big.jpg'),
(55114, 3786, 'DOM S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212172.mp4', 'http://gstaticontent.com/images/9KlPkK0cLSpIzrAlD7TqInsZSFn_big.jpg'),
(55115, 3786, 'DOM S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212173.mp4', 'http://gstaticontent.com/images/9KlPkK0cLSpIzrAlD7TqInsZSFn_big.jpg'),
(55116, 3786, 'DOM S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212174.mp4', 'http://gstaticontent.com/images/9KlPkK0cLSpIzrAlD7TqInsZSFn_big.jpg'),
(55117, 3786, 'DOM S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212175.mp4', 'http://gstaticontent.com/images/9KlPkK0cLSpIzrAlD7TqInsZSFn_big.jpg'),
(55118, 3787, 'DOM S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vAno2isu1I7PVIujHnRso8FyuKu.jpg'),
(55119, 3787, 'DOM S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g3jDBlJjuhQ2FUJP6kSvKZt6uWk.jpg'),
(55120, 3787, 'DOM S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aie554zv2jgcNBMJX0SkP501mDp.jpg'),
(55121, 3787, 'DOM S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212179.mp4', 'http://image.tmdb.org/t/p/w1280/aWJP6qUCEQOAoE2o50vllsgWpZ1.jpg'),
(55122, 3787, 'DOM S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212180.mp4', 'http://image.tmdb.org/t/p/w1280/amphZUsoQh9yQ7hxJG9kCTaAxJY.jpg'),
(55123, 3787, 'DOM S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212181.mp4', 'http://image.tmdb.org/t/p/w1280/5Ur9FV6QDpGNKA7FswP77HrMsHK.jpg'),
(55124, 3787, 'DOM S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212182.mp4', 'http://image.tmdb.org/t/p/w1280/exxMXKz4EGzk5OfRUePgcSriFqR.jpg'),
(55125, 3787, 'DOM S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212183.mp4', 'http://image.tmdb.org/t/p/w1280/jXJVPRM4g3C7da69a9wFjjtTik6.jpg'),
(55126, 3788, 'DOM S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/359694.mp4', 'http://gstaticontent.com/images/9KlPkK0cLSpIzrAlD7TqInsZSFn_big.jpg'),
(55127, 3788, 'DOM S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/359695.mp4', 'http://gstaticontent.com/images/9KlPkK0cLSpIzrAlD7TqInsZSFn_big.jpg'),
(55128, 3788, 'DOM S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/359696.mp4', 'http://gstaticontent.com/images/9KlPkK0cLSpIzrAlD7TqInsZSFn_big.jpg'),
(55129, 3788, 'DOM S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/359697.mp4', 'http://gstaticontent.com/images/9KlPkK0cLSpIzrAlD7TqInsZSFn_big.jpg'),
(55130, 3788, 'DOM S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/359698.mp4', 'http://gstaticontent.com/images/9KlPkK0cLSpIzrAlD7TqInsZSFn_big.jpg'),
(55131, 3789, 'Sweet Tooth S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210788.mp4', 'http://gstaticontent.com/images/rgMfhcrVZjuy5b7Pn0KzCRCEnMX_big.jpg'),
(55132, 3789, 'Sweet Tooth S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210789.mp4', 'http://gstaticontent.com/images/rgMfhcrVZjuy5b7Pn0KzCRCEnMX_big.jpg'),
(55133, 3789, 'Sweet Tooth S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210790.mp4', 'http://gstaticontent.com/images/rgMfhcrVZjuy5b7Pn0KzCRCEnMX_big.jpg'),
(55134, 3789, 'Sweet Tooth S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210791.mp4', 'http://gstaticontent.com/images/rgMfhcrVZjuy5b7Pn0KzCRCEnMX_big.jpg'),
(55135, 3789, 'Sweet Tooth S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210792.mp4', 'http://gstaticontent.com/images/rgMfhcrVZjuy5b7Pn0KzCRCEnMX_big.jpg'),
(55136, 3789, 'Sweet Tooth S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210793.mp4', 'http://gstaticontent.com/images/rgMfhcrVZjuy5b7Pn0KzCRCEnMX_big.jpg'),
(55137, 3789, 'Sweet Tooth S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210794.mp4', 'http://gstaticontent.com/images/rgMfhcrVZjuy5b7Pn0KzCRCEnMX_big.jpg'),
(55138, 3789, 'Sweet Tooth S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210795.mp4', 'http://gstaticontent.com/images/rgMfhcrVZjuy5b7Pn0KzCRCEnMX_big.jpg'),
(55139, 3790, 'Sweet Tooth S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fLyUrBv0cEKoqK7L29S8fmUinjb.jpg'),
(55140, 3790, 'Sweet Tooth S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hBnLZf4ja7ymDSOYFk5mHWPbhEt.jpg'),
(55141, 3790, 'Sweet Tooth S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/scKTlP9X7NVxoS2dz2Ybb1uLYI6.jpg'),
(55142, 3790, 'Sweet Tooth S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rVuONtuFA34xdzbGeb13g2GPYjD.jpg'),
(55143, 3790, 'Sweet Tooth S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zaz3ryYmREBRh8Ir2lgaRRPjlzX.jpg'),
(55144, 3790, 'Sweet Tooth S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f6pk4txw53uMfO5kBbp8RLJXCcv.jpg'),
(55145, 3790, 'Sweet Tooth S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1eZjGJ4spC1BVyfwD5NM8BTgKI1.jpg'),
(55146, 3790, 'Sweet Tooth S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rcPevc4p8oNQmSpgXBO4Ky6DGs.jpg'),
(55147, 3791, 'Sweet Tooth S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/388548.mp4', 'http://gstaticontent.com/images/rgMfhcrVZjuy5b7Pn0KzCRCEnMX_big.jpg'),
(55148, 3791, 'Sweet Tooth S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/388549.mp4', 'http://gstaticontent.com/images/rgMfhcrVZjuy5b7Pn0KzCRCEnMX_big.jpg'),
(55149, 3791, 'Sweet Tooth S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/388550.mp4', 'http://gstaticontent.com/images/rgMfhcrVZjuy5b7Pn0KzCRCEnMX_big.jpg'),
(55150, 3791, 'Sweet Tooth S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/388551.mp4', 'http://gstaticontent.com/images/rgMfhcrVZjuy5b7Pn0KzCRCEnMX_big.jpg'),
(55151, 3791, 'Sweet Tooth S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/388552.mp4', 'http://gstaticontent.com/images/rgMfhcrVZjuy5b7Pn0KzCRCEnMX_big.jpg'),
(55152, 3791, 'Sweet Tooth S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/388553.mp4', 'http://gstaticontent.com/images/rgMfhcrVZjuy5b7Pn0KzCRCEnMX_big.jpg'),
(55153, 3791, 'Sweet Tooth S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/388554.mp4', 'http://gstaticontent.com/images/rgMfhcrVZjuy5b7Pn0KzCRCEnMX_big.jpg'),
(55154, 3791, 'Sweet Tooth S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/388555.mp4', 'http://gstaticontent.com/images/rgMfhcrVZjuy5b7Pn0KzCRCEnMX_big.jpg'),
(55155, 3792, 'Corpo Humano: Nosso Mundo Interior S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147571.mp4', 'http://gstaticontent.com/images/7pbpMy3KQ5VT6Yp4SPdPxcuBmrH_big.jpg'),
(55156, 3792, 'Corpo Humano: Nosso Mundo Interior S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147572.mp4', 'http://gstaticontent.com/images/7pbpMy3KQ5VT6Yp4SPdPxcuBmrH_big.jpg'),
(55157, 3792, 'Corpo Humano: Nosso Mundo Interior S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147573.mp4', 'http://gstaticontent.com/images/7pbpMy3KQ5VT6Yp4SPdPxcuBmrH_big.jpg'),
(55158, 3792, 'Corpo Humano: Nosso Mundo Interior S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147574.mp4', 'http://gstaticontent.com/images/7pbpMy3KQ5VT6Yp4SPdPxcuBmrH_big.jpg'),
(55159, 3792, 'Corpo Humano: Nosso Mundo Interior S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147575.mp4', 'http://gstaticontent.com/images/7pbpMy3KQ5VT6Yp4SPdPxcuBmrH_big.jpg'),
(55160, 3792, 'Corpo Humano: Nosso Mundo Interior S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147576.mp4', 'http://gstaticontent.com/images/7pbpMy3KQ5VT6Yp4SPdPxcuBmrH_big.jpg'),
(55161, 3793, 'Loki S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238871.mp4', 'http://gstaticontent.com/images/ukR0MkCQE6IylzBPd61txJi1L3E_big.jpg'),
(55162, 3793, 'Loki S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238872.mp4', 'http://gstaticontent.com/images/ukR0MkCQE6IylzBPd61txJi1L3E_big.jpg'),
(55163, 3793, 'Loki S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238873.mp4', 'http://gstaticontent.com/images/ukR0MkCQE6IylzBPd61txJi1L3E_big.jpg'),
(55164, 3793, 'Loki S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238874.mp4', 'http://gstaticontent.com/images/ukR0MkCQE6IylzBPd61txJi1L3E_big.jpg'),
(55165, 3793, 'Loki S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238875.mp4', 'http://timg.bdta.pro/images/eddd859cb054c9fc86c050f11dfd7e73.jpg'),
(55166, 3793, 'Loki S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238876.mp4', 'http://timg.bdta.pro/images/c5954afd6f53d7677b50a4b03d37c376.jpg'),
(55167, 3794, 'Loki S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238877.mp4', 'http://gstaticontent.com/images/ukR0MkCQE6IylzBPd61txJi1L3E_big.jpg'),
(55168, 3794, 'Loki S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238878.mp4', 'http://gstaticontent.com/images/ukR0MkCQE6IylzBPd61txJi1L3E_big.jpg'),
(55169, 3794, 'Loki S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238879.mp4', 'http://gstaticontent.com/images/ukR0MkCQE6IylzBPd61txJi1L3E_big.jpg'),
(55170, 3794, 'Loki S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238880.mp4', 'http://gstaticontent.com/images/ukR0MkCQE6IylzBPd61txJi1L3E_big.jpg'),
(55171, 3794, 'Loki S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238881.mp4', 'http://gstaticontent.com/images/ukR0MkCQE6IylzBPd61txJi1L3E_big.jpg'),
(55172, 3794, 'Loki S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238882.mp4', 'http://gstaticontent.com/images/ukR0MkCQE6IylzBPd61txJi1L3E_big.jpg'),
(55173, 3795, 'One Piece [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/292827.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55174, 3795, 'One Piece [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/292828.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55175, 3795, 'One Piece [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/292829.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55176, 3795, 'One Piece [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/292830.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55177, 3795, 'One Piece [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/292831.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55178, 3795, 'One Piece [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/292832.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55179, 3795, 'One Piece [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/292833.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55180, 3795, 'One Piece [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/292834.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55181, 3795, 'One Piece [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/292835.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55182, 3795, 'One Piece [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/292836.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55183, 3795, 'One Piece [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/292837.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55184, 3795, 'One Piece [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/292838.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55185, 3795, 'One Piece [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/292839.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55186, 3795, 'One Piece [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/292840.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55187, 3795, 'One Piece [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/292841.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55188, 3795, 'One Piece [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/292842.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55189, 3795, 'One Piece [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/292843.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55190, 3795, 'One Piece [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/292844.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55191, 3795, 'One Piece [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/292845.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55192, 3795, 'One Piece [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/292846.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55193, 3795, 'One Piece [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/292847.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55194, 3795, 'One Piece [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/292848.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55195, 3795, 'One Piece [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/292849.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55196, 3795, 'One Piece [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/292850.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55197, 3795, 'One Piece [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/292851.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55198, 3795, 'One Piece [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/292852.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55199, 3795, 'One Piece [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/292853.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55200, 3795, 'One Piece [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/292854.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55201, 3795, 'One Piece [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/292855.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55202, 3795, 'One Piece [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/292856.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55203, 3795, 'One Piece [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/292857.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55204, 3795, 'One Piece [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/292858.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55205, 3795, 'One Piece [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/292859.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55206, 3795, 'One Piece [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/292860.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55207, 3795, 'One Piece [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/292861.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55208, 3795, 'One Piece [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/292862.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(55209, 3795, 'One Piece [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/292863.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55210, 3795, 'One Piece [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/292864.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55211, 3795, 'One Piece [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/292865.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55212, 3795, 'One Piece [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/292866.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55213, 3795, 'One Piece [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/292867.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55214, 3795, 'One Piece [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/292868.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55215, 3795, 'One Piece [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/292869.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55216, 3795, 'One Piece [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/292870.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55217, 3795, 'One Piece [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/292871.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55218, 3795, 'One Piece [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/292872.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55219, 3795, 'One Piece [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/292873.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55220, 3795, 'One Piece [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/292874.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55221, 3795, 'One Piece [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/292875.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55222, 3795, 'One Piece [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/292876.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55223, 3795, 'One Piece [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/292877.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55224, 3795, 'One Piece [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/292878.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55225, 3795, 'One Piece [L] S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/292879.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55226, 3795, 'One Piece [L] S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/292880.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55227, 3795, 'One Piece [L] S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/292881.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55228, 3795, 'One Piece [L] S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/292882.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55229, 3795, 'One Piece [L] S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/292883.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55230, 3795, 'One Piece [L] S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/292884.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55231, 3795, 'One Piece [L] S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/292885.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55232, 3795, 'One Piece [L] S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/292886.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55233, 3795, 'One Piece [L] S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/292887.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55234, 3795, 'One Piece [L] S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/292888.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55235, 3795, 'One Piece [L] S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/292889.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55236, 3796, 'One Piece [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/292890.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55237, 3796, 'One Piece [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/292891.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55238, 3796, 'One Piece [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/292892.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55239, 3796, 'One Piece [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/292893.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55240, 3796, 'One Piece [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/292894.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55241, 3796, 'One Piece [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/292895.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55242, 3796, 'One Piece [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/292896.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55243, 3796, 'One Piece [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/292897.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55244, 3796, 'One Piece [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/292898.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55245, 3796, 'One Piece [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/292899.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55246, 3796, 'One Piece [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/292900.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55247, 3796, 'One Piece [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/292901.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55248, 3796, 'One Piece [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/292902.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55249, 3796, 'One Piece [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/292903.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55250, 3796, 'One Piece [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/292904.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55251, 3796, 'One Piece [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/292905.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55252, 3797, 'One Piece [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/292906.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55253, 3797, 'One Piece [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/292907.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55254, 3797, 'One Piece [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/292908.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55255, 3797, 'One Piece [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/292909.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55256, 3797, 'One Piece [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/292910.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55257, 3797, 'One Piece [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/292911.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55258, 3797, 'One Piece [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/292912.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55259, 3797, 'One Piece [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/292913.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55260, 3797, 'One Piece [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/292914.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55261, 3797, 'One Piece [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/292915.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55262, 3797, 'One Piece [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/292916.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55263, 3797, 'One Piece [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/292917.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55264, 3797, 'One Piece [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/292918.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55265, 3797, 'One Piece [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/292919.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55266, 3798, 'One Piece [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/292920.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55267, 3798, 'One Piece [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/292921.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55268, 3798, 'One Piece [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/292922.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55269, 3798, 'One Piece [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/292923.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55270, 3798, 'One Piece [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/292924.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55271, 3798, 'One Piece [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/292925.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55272, 3798, 'One Piece [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/292926.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55273, 3798, 'One Piece [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/292927.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55274, 3798, 'One Piece [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/292928.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55275, 3798, 'One Piece [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/292929.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55276, 3798, 'One Piece [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/292930.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55277, 3798, 'One Piece [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/292931.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55278, 3798, 'One Piece [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/292932.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55279, 3798, 'One Piece [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/292933.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55280, 3798, 'One Piece [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/292934.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55281, 3798, 'One Piece [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/292935.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55282, 3798, 'One Piece [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/292936.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55283, 3798, 'One Piece [L] S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/292937.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55284, 3798, 'One Piece [L] S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/292938.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55285, 3798, 'One Piece [L] S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/292939.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55286, 3798, 'One Piece [L] S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/292940.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55287, 3798, 'One Piece [L] S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/292941.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55288, 3798, 'One Piece [L] S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/292942.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55289, 3798, 'One Piece [L] S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/292943.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55290, 3798, 'One Piece [L] S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/292944.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55291, 3798, 'One Piece [L] S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/292945.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55292, 3798, 'One Piece [L] S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/292946.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55293, 3798, 'One Piece [L] S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/292947.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55294, 3798, 'One Piece [L] S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/292948.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55295, 3798, 'One Piece [L] S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/292949.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55296, 3798, 'One Piece [L] S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/292950.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55297, 3798, 'One Piece [L] S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/292951.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55298, 3798, 'One Piece [L] S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/292952.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55299, 3798, 'One Piece [L] S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/292953.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55300, 3798, 'One Piece [L] S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/292954.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55301, 3798, 'One Piece [L] S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/292955.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55302, 3798, 'One Piece [L] S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/292956.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55303, 3798, 'One Piece [L] S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/292957.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55304, 3798, 'One Piece [L] S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/292958.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55305, 3799, 'One Piece [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/292959.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55306, 3799, 'One Piece [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/292960.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55307, 3799, 'One Piece [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/292961.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55308, 3799, 'One Piece [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/292962.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55309, 3799, 'One Piece [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/292963.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55310, 3799, 'One Piece [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/292964.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55311, 3799, 'One Piece [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/292965.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55312, 3799, 'One Piece [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/292966.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55313, 3799, 'One Piece [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/292967.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55314, 3799, 'One Piece [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/292968.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55315, 3799, 'One Piece [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/292969.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55316, 3799, 'One Piece [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/292970.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55317, 3799, 'One Piece [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/292971.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55318, 3800, 'One Piece [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/292972.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55319, 3800, 'One Piece [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/292973.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55320, 3800, 'One Piece [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/292974.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55321, 3800, 'One Piece [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/292975.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55322, 3800, 'One Piece [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/292976.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55323, 3800, 'One Piece [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/292977.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55324, 3800, 'One Piece [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/292978.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55325, 3800, 'One Piece [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/292979.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55326, 3800, 'One Piece [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/292980.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55327, 3800, 'One Piece [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/292981.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55328, 3800, 'One Piece [L] S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/292982.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55329, 3800, 'One Piece [L] S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/292983.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55330, 3800, 'One Piece [L] S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/292984.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55331, 3800, 'One Piece [L] S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/292985.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55332, 3800, 'One Piece [L] S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/292986.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55333, 3800, 'One Piece [L] S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/292987.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55334, 3800, 'One Piece [L] S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/292988.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55335, 3800, 'One Piece [L] S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/292989.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55336, 3800, 'One Piece [L] S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/292990.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55337, 3800, 'One Piece [L] S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/292991.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55338, 3800, 'One Piece [L] S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/292992.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55339, 3800, 'One Piece [L] S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/292993.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55340, 3800, 'One Piece [L] S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/292994.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55341, 3800, 'One Piece [L] S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/292995.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55342, 3800, 'One Piece [L] S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/292996.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55343, 3800, 'One Piece [L] S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/292997.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55344, 3800, 'One Piece [L] S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/292998.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55345, 3800, 'One Piece [L] S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/292999.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55346, 3800, 'One Piece [L] S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/293000.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55347, 3800, 'One Piece [L] S06 E30', 'http://sinalprivado.info:80/series/1533784/1533784/293001.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55348, 3800, 'One Piece [L] S06 E31', 'http://sinalprivado.info:80/series/1533784/1533784/293002.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55349, 3800, 'One Piece [L] S06 E32', 'http://sinalprivado.info:80/series/1533784/1533784/293003.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55350, 3800, 'One Piece [L] S06 E33', 'http://sinalprivado.info:80/series/1533784/1533784/293004.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55351, 3800, 'One Piece [L] S06 E34', 'http://sinalprivado.info:80/series/1533784/1533784/293005.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55352, 3800, 'One Piece [L] S06 E35', 'http://sinalprivado.info:80/series/1533784/1533784/293006.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55353, 3800, 'One Piece [L] S06 E36', 'http://sinalprivado.info:80/series/1533784/1533784/293007.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55354, 3800, 'One Piece [L] S06 E37', 'http://sinalprivado.info:80/series/1533784/1533784/293008.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55355, 3800, 'One Piece [L] S06 E38', 'http://sinalprivado.info:80/series/1533784/1533784/293009.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55356, 3800, 'One Piece [L] S06 E39', 'http://sinalprivado.info:80/series/1533784/1533784/293010.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55357, 3800, 'One Piece [L] S06 E40', 'http://sinalprivado.info:80/series/1533784/1533784/293011.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55358, 3800, 'One Piece [L] S06 E41', 'http://sinalprivado.info:80/series/1533784/1533784/293012.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55359, 3800, 'One Piece [L] S06 E42', 'http://sinalprivado.info:80/series/1533784/1533784/293013.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55360, 3800, 'One Piece [L] S06 E43', 'http://sinalprivado.info:80/series/1533784/1533784/293014.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55361, 3800, 'One Piece [L] S06 E44', 'http://sinalprivado.info:80/series/1533784/1533784/293015.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55362, 3800, 'One Piece [L] S06 E45', 'http://sinalprivado.info:80/series/1533784/1533784/293016.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55363, 3800, 'One Piece [L] S06 E46', 'http://sinalprivado.info:80/series/1533784/1533784/293017.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55364, 3800, 'One Piece [L] S06 E47', 'http://sinalprivado.info:80/series/1533784/1533784/293018.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55365, 3800, 'One Piece [L] S06 E48', 'http://sinalprivado.info:80/series/1533784/1533784/293019.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55366, 3800, 'One Piece [L] S06 E49', 'http://sinalprivado.info:80/series/1533784/1533784/293020.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55367, 3800, 'One Piece [L] S06 E50', 'http://sinalprivado.info:80/series/1533784/1533784/293021.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55368, 3800, 'One Piece [L] S06 E51', 'http://sinalprivado.info:80/series/1533784/1533784/293022.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55369, 3800, 'One Piece [L] S06 E52', 'http://sinalprivado.info:80/series/1533784/1533784/293023.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55370, 3801, 'One Piece [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/293024.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55371, 3801, 'One Piece [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/293025.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55372, 3801, 'One Piece [L] S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/293026.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55373, 3801, 'One Piece [L] S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/293027.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55374, 3801, 'One Piece [L] S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/293028.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55375, 3801, 'One Piece [L] S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/293029.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55376, 3801, 'One Piece [L] S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/293030.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55377, 3801, 'One Piece [L] S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/293031.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55378, 3801, 'One Piece [L] S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/293032.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55379, 3801, 'One Piece [L] S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/293033.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55380, 3801, 'One Piece [L] S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/293034.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55381, 3801, 'One Piece [L] S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/293035.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55382, 3801, 'One Piece [L] S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/293036.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55383, 3801, 'One Piece [L] S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/293037.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55384, 3801, 'One Piece [L] S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/293038.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55385, 3801, 'One Piece [L] S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/293039.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55386, 3801, 'One Piece [L] S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/293040.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55387, 3801, 'One Piece [L] S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/293041.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55388, 3801, 'One Piece [L] S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/293042.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55389, 3801, 'One Piece [L] S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/293043.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55390, 3801, 'One Piece [L] S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/293044.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55391, 3801, 'One Piece [L] S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/293045.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55392, 3801, 'One Piece [L] S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/293046.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55393, 3801, 'One Piece [L] S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/293047.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55394, 3801, 'One Piece [L] S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/293048.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55395, 3801, 'One Piece [L] S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/293049.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55396, 3801, 'One Piece [L] S07 E27', 'http://sinalprivado.info:80/series/1533784/1533784/293050.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55397, 3801, 'One Piece [L] S07 E28', 'http://sinalprivado.info:80/series/1533784/1533784/293051.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55398, 3801, 'One Piece [L] S07 E29', 'http://sinalprivado.info:80/series/1533784/1533784/293052.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55399, 3801, 'One Piece [L] S07 E30', 'http://sinalprivado.info:80/series/1533784/1533784/293053.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55400, 3801, 'One Piece [L] S07 E31', 'http://sinalprivado.info:80/series/1533784/1533784/293054.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55401, 3801, 'One Piece [L] S07 E32', 'http://sinalprivado.info:80/series/1533784/1533784/293055.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55402, 3801, 'One Piece [L] S07 E33', 'http://sinalprivado.info:80/series/1533784/1533784/293056.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55403, 3802, 'One Piece [L] S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/293057.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55404, 3802, 'One Piece [L] S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/293058.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55405, 3802, 'One Piece [L] S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/293059.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55406, 3802, 'One Piece [L] S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/293060.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55407, 3802, 'One Piece [L] S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/293061.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55408, 3802, 'One Piece [L] S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/293062.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55409, 3802, 'One Piece [L] S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/293063.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55410, 3802, 'One Piece [L] S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/293064.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55411, 3802, 'One Piece [L] S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/293065.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55412, 3802, 'One Piece [L] S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/293066.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55413, 3802, 'One Piece [L] S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/293067.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55414, 3802, 'One Piece [L] S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/293068.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55415, 3802, 'One Piece [L] S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/293069.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55416, 3802, 'One Piece [L] S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/293070.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55417, 3802, 'One Piece [L] S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/293071.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55418, 3802, 'One Piece [L] S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/293072.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55419, 3802, 'One Piece [L] S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/293073.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55420, 3802, 'One Piece [L] S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/293074.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55421, 3802, 'One Piece [L] S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/293075.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55422, 3802, 'One Piece [L] S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/293076.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55423, 3802, 'One Piece [L] S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/293077.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55424, 3802, 'One Piece [L] S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/293078.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55425, 3802, 'One Piece [L] S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/293079.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55426, 3802, 'One Piece [L] S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/293080.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55427, 3802, 'One Piece [L] S08 E25', 'http://sinalprivado.info:80/series/1533784/1533784/293081.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55428, 3802, 'One Piece [L] S08 E26', 'http://sinalprivado.info:80/series/1533784/1533784/293082.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55429, 3802, 'One Piece [L] S08 E27', 'http://sinalprivado.info:80/series/1533784/1533784/293083.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55430, 3802, 'One Piece [L] S08 E28', 'http://sinalprivado.info:80/series/1533784/1533784/293084.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55431, 3802, 'One Piece [L] S08 E29', 'http://sinalprivado.info:80/series/1533784/1533784/293085.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55432, 3802, 'One Piece [L] S08 E30', 'http://sinalprivado.info:80/series/1533784/1533784/293086.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55433, 3802, 'One Piece [L] S08 E31', 'http://sinalprivado.info:80/series/1533784/1533784/293087.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55434, 3802, 'One Piece [L] S08 E32', 'http://sinalprivado.info:80/series/1533784/1533784/293088.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55435, 3802, 'One Piece [L] S08 E33', 'http://sinalprivado.info:80/series/1533784/1533784/293089.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55436, 3802, 'One Piece [L] S08 E34', 'http://sinalprivado.info:80/series/1533784/1533784/293090.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55437, 3802, 'One Piece [L] S08 E35', 'http://sinalprivado.info:80/series/1533784/1533784/293091.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55438, 3803, 'One Piece [L] S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/293092.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55439, 3803, 'One Piece [L] S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/293093.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55440, 3803, 'One Piece [L] S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/293094.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55441, 3803, 'One Piece [L] S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/293095.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55442, 3803, 'One Piece [L] S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/293096.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55443, 3803, 'One Piece [L] S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/293097.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55444, 3803, 'One Piece [L] S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/293098.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55445, 3803, 'One Piece [L] S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/293099.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55446, 3803, 'One Piece [L] S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/293100.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55447, 3803, 'One Piece [L] S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/293101.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55448, 3803, 'One Piece [L] S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/293102.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55449, 3803, 'One Piece [L] S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/293103.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55450, 3803, 'One Piece [L] S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/293104.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55451, 3803, 'One Piece [L] S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/293105.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55452, 3803, 'One Piece [L] S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/293106.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55453, 3803, 'One Piece [L] S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/293107.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55454, 3803, 'One Piece [L] S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/293108.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55455, 3803, 'One Piece [L] S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/293109.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55456, 3803, 'One Piece [L] S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/293110.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55457, 3803, 'One Piece [L] S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/293111.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55458, 3803, 'One Piece [L] S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/293112.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55459, 3803, 'One Piece [L] S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/293113.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55460, 3803, 'One Piece [L] S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/293114.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55461, 3803, 'One Piece [L] S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/293115.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55462, 3803, 'One Piece [L] S09 E25', 'http://sinalprivado.info:80/series/1533784/1533784/293116.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55463, 3803, 'One Piece [L] S09 E26', 'http://sinalprivado.info:80/series/1533784/1533784/293117.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55464, 3803, 'One Piece [L] S09 E27', 'http://sinalprivado.info:80/series/1533784/1533784/293118.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55465, 3803, 'One Piece [L] S09 E28', 'http://sinalprivado.info:80/series/1533784/1533784/293119.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55466, 3803, 'One Piece [L] S09 E29', 'http://sinalprivado.info:80/series/1533784/1533784/293120.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55467, 3803, 'One Piece [L] S09 E30', 'http://sinalprivado.info:80/series/1533784/1533784/293121.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55468, 3803, 'One Piece [L] S09 E31', 'http://sinalprivado.info:80/series/1533784/1533784/293122.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55469, 3803, 'One Piece [L] S09 E32', 'http://sinalprivado.info:80/series/1533784/1533784/293123.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55470, 3803, 'One Piece [L] S09 E33', 'http://sinalprivado.info:80/series/1533784/1533784/293124.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55471, 3803, 'One Piece [L] S09 E34', 'http://sinalprivado.info:80/series/1533784/1533784/293125.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55472, 3803, 'One Piece [L] S09 E35', 'http://sinalprivado.info:80/series/1533784/1533784/293126.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55473, 3803, 'One Piece [L] S09 E36', 'http://sinalprivado.info:80/series/1533784/1533784/293127.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55474, 3803, 'One Piece [L] S09 E37', 'http://sinalprivado.info:80/series/1533784/1533784/293128.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55475, 3803, 'One Piece [L] S09 E38', 'http://sinalprivado.info:80/series/1533784/1533784/293129.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55476, 3803, 'One Piece [L] S09 E39', 'http://sinalprivado.info:80/series/1533784/1533784/293130.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55477, 3803, 'One Piece [L] S09 E40', 'http://sinalprivado.info:80/series/1533784/1533784/293131.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55478, 3803, 'One Piece [L] S09 E41', 'http://sinalprivado.info:80/series/1533784/1533784/293132.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55479, 3803, 'One Piece [L] S09 E42', 'http://sinalprivado.info:80/series/1533784/1533784/293133.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55480, 3803, 'One Piece [L] S09 E43', 'http://sinalprivado.info:80/series/1533784/1533784/293134.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55481, 3803, 'One Piece [L] S09 E44', 'http://sinalprivado.info:80/series/1533784/1533784/293135.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55482, 3803, 'One Piece [L] S09 E45', 'http://sinalprivado.info:80/series/1533784/1533784/293136.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55483, 3803, 'One Piece [L] S09 E46', 'http://sinalprivado.info:80/series/1533784/1533784/293137.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55484, 3803, 'One Piece [L] S09 E47', 'http://sinalprivado.info:80/series/1533784/1533784/293138.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55485, 3803, 'One Piece [L] S09 E48', 'http://sinalprivado.info:80/series/1533784/1533784/293139.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55486, 3803, 'One Piece [L] S09 E49', 'http://sinalprivado.info:80/series/1533784/1533784/293140.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55487, 3803, 'One Piece [L] S09 E50', 'http://sinalprivado.info:80/series/1533784/1533784/293141.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55488, 3803, 'One Piece [L] S09 E51', 'http://sinalprivado.info:80/series/1533784/1533784/293142.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55489, 3803, 'One Piece [L] S09 E52', 'http://sinalprivado.info:80/series/1533784/1533784/293143.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55490, 3803, 'One Piece [L] S09 E53', 'http://sinalprivado.info:80/series/1533784/1533784/293144.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55491, 3803, 'One Piece [L] S09 E54', 'http://sinalprivado.info:80/series/1533784/1533784/293145.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55492, 3803, 'One Piece [L] S09 E55', 'http://sinalprivado.info:80/series/1533784/1533784/293146.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55493, 3803, 'One Piece [L] S09 E56', 'http://sinalprivado.info:80/series/1533784/1533784/293147.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55494, 3803, 'One Piece [L] S09 E57', 'http://sinalprivado.info:80/series/1533784/1533784/293148.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(55495, 3803, 'One Piece [L] S09 E58', 'http://sinalprivado.info:80/series/1533784/1533784/293149.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55496, 3803, 'One Piece [L] S09 E59', 'http://sinalprivado.info:80/series/1533784/1533784/293150.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55497, 3803, 'One Piece [L] S09 E60', 'http://sinalprivado.info:80/series/1533784/1533784/293151.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55498, 3803, 'One Piece [L] S09 E61', 'http://sinalprivado.info:80/series/1533784/1533784/293152.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55499, 3803, 'One Piece [L] S09 E62', 'http://sinalprivado.info:80/series/1533784/1533784/293153.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55500, 3803, 'One Piece [L] S09 E63', 'http://sinalprivado.info:80/series/1533784/1533784/293154.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55501, 3803, 'One Piece [L] S09 E64', 'http://sinalprivado.info:80/series/1533784/1533784/293155.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55502, 3803, 'One Piece [L] S09 E65', 'http://sinalprivado.info:80/series/1533784/1533784/293156.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55503, 3803, 'One Piece [L] S09 E66', 'http://sinalprivado.info:80/series/1533784/1533784/293157.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55504, 3803, 'One Piece [L] S09 E67', 'http://sinalprivado.info:80/series/1533784/1533784/293158.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55505, 3803, 'One Piece [L] S09 E68', 'http://sinalprivado.info:80/series/1533784/1533784/293159.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55506, 3803, 'One Piece [L] S09 E69', 'http://sinalprivado.info:80/series/1533784/1533784/293160.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55507, 3803, 'One Piece [L] S09 E70', 'http://sinalprivado.info:80/series/1533784/1533784/293161.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55508, 3803, 'One Piece [L] S09 E71', 'http://sinalprivado.info:80/series/1533784/1533784/293162.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55509, 3803, 'One Piece [L] S09 E72', 'http://sinalprivado.info:80/series/1533784/1533784/293163.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55510, 3803, 'One Piece [L] S09 E73', 'http://sinalprivado.info:80/series/1533784/1533784/293164.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55511, 3804, 'One Piece [L] S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/293165.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55512, 3804, 'One Piece [L] S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/293166.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55513, 3804, 'One Piece [L] S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/293167.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55514, 3804, 'One Piece [L] S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/293168.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55515, 3804, 'One Piece [L] S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/293169.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55516, 3804, 'One Piece [L] S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/293170.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55517, 3804, 'One Piece [L] S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/293171.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55518, 3804, 'One Piece [L] S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/293172.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55519, 3804, 'One Piece [L] S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/293173.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55520, 3804, 'One Piece [L] S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/293174.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55521, 3804, 'One Piece [L] S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/293175.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55522, 3804, 'One Piece [L] S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/293176.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55523, 3804, 'One Piece [L] S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/293177.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55524, 3804, 'One Piece [L] S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/293178.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55525, 3804, 'One Piece [L] S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/293179.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55526, 3804, 'One Piece [L] S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/293180.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55527, 3804, 'One Piece [L] S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/293181.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55528, 3804, 'One Piece [L] S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/293182.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55529, 3804, 'One Piece [L] S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/293183.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55530, 3804, 'One Piece [L] S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/293184.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55531, 3804, 'One Piece [L] S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/293185.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55532, 3804, 'One Piece [L] S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/293186.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55533, 3804, 'One Piece [L] S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/293187.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55534, 3804, 'One Piece [L] S10 E24', 'http://sinalprivado.info:80/series/1533784/1533784/293188.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55535, 3804, 'One Piece [L] S10 E25', 'http://sinalprivado.info:80/series/1533784/1533784/293189.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55536, 3804, 'One Piece [L] S10 E26', 'http://sinalprivado.info:80/series/1533784/1533784/293190.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55537, 3804, 'One Piece [L] S10 E27', 'http://sinalprivado.info:80/series/1533784/1533784/293191.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55538, 3804, 'One Piece [L] S10 E28', 'http://sinalprivado.info:80/series/1533784/1533784/293192.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55539, 3804, 'One Piece [L] S10 E29', 'http://sinalprivado.info:80/series/1533784/1533784/293193.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55540, 3804, 'One Piece [L] S10 E30', 'http://sinalprivado.info:80/series/1533784/1533784/293194.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55541, 3804, 'One Piece [L] S10 E31', 'http://sinalprivado.info:80/series/1533784/1533784/293195.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55542, 3804, 'One Piece [L] S10 E32', 'http://sinalprivado.info:80/series/1533784/1533784/293196.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55543, 3804, 'One Piece [L] S10 E33', 'http://sinalprivado.info:80/series/1533784/1533784/293197.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55544, 3804, 'One Piece [L] S10 E34', 'http://sinalprivado.info:80/series/1533784/1533784/293198.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55545, 3804, 'One Piece [L] S10 E35', 'http://sinalprivado.info:80/series/1533784/1533784/293199.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55546, 3804, 'One Piece [L] S10 E36', 'http://sinalprivado.info:80/series/1533784/1533784/293200.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55547, 3804, 'One Piece [L] S10 E37', 'http://sinalprivado.info:80/series/1533784/1533784/293201.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55548, 3804, 'One Piece [L] S10 E38', 'http://sinalprivado.info:80/series/1533784/1533784/293202.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55549, 3804, 'One Piece [L] S10 E39', 'http://sinalprivado.info:80/series/1533784/1533784/293203.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55550, 3804, 'One Piece [L] S10 E40', 'http://sinalprivado.info:80/series/1533784/1533784/293204.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55551, 3804, 'One Piece [L] S10 E41', 'http://sinalprivado.info:80/series/1533784/1533784/293205.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55552, 3804, 'One Piece [L] S10 E42', 'http://sinalprivado.info:80/series/1533784/1533784/293206.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55553, 3804, 'One Piece [L] S10 E43', 'http://sinalprivado.info:80/series/1533784/1533784/293207.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55554, 3804, 'One Piece [L] S10 E44', 'http://sinalprivado.info:80/series/1533784/1533784/293208.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55555, 3804, 'One Piece [L] S10 E45', 'http://sinalprivado.info:80/series/1533784/1533784/293209.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55556, 3805, 'One Piece [L] S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/293210.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55557, 3805, 'One Piece [L] S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/293211.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55558, 3805, 'One Piece [L] S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/293212.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55559, 3805, 'One Piece [L] S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/293213.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55560, 3805, 'One Piece [L] S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/293214.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55561, 3805, 'One Piece [L] S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/293215.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55562, 3805, 'One Piece [L] S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/293216.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55563, 3805, 'One Piece [L] S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/293217.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55564, 3805, 'One Piece [L] S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/293218.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55565, 3805, 'One Piece [L] S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/293219.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55566, 3805, 'One Piece [L] S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/293220.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55567, 3805, 'One Piece [L] S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/293221.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55568, 3805, 'One Piece [L] S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/293222.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55569, 3805, 'One Piece [L] S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/293223.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55570, 3805, 'One Piece [L] S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/293224.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55571, 3805, 'One Piece [L] S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/293225.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55572, 3805, 'One Piece [L] S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/293226.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55573, 3805, 'One Piece [L] S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/293227.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55574, 3805, 'One Piece [L] S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/293228.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55575, 3805, 'One Piece [L] S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/293229.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55576, 3805, 'One Piece [L] S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/293230.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55577, 3805, 'One Piece [L] S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/293231.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55578, 3805, 'One Piece [L] S11 E23', 'http://sinalprivado.info:80/series/1533784/1533784/293232.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55579, 3805, 'One Piece [L] S11 E24', 'http://sinalprivado.info:80/series/1533784/1533784/293233.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55580, 3805, 'One Piece [L] S11 E25', 'http://sinalprivado.info:80/series/1533784/1533784/293234.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55581, 3805, 'One Piece [L] S11 E26', 'http://sinalprivado.info:80/series/1533784/1533784/293235.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55582, 3806, 'One Piece [L] S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/293236.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55583, 3806, 'One Piece [L] S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/293237.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55584, 3806, 'One Piece [L] S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/293238.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55585, 3806, 'One Piece [L] S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/293239.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55586, 3806, 'One Piece [L] S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/293240.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55587, 3806, 'One Piece [L] S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/293241.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55588, 3806, 'One Piece [L] S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/293242.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55589, 3806, 'One Piece [L] S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/293243.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55590, 3806, 'One Piece [L] S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/293244.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55591, 3806, 'One Piece [L] S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/293245.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55592, 3806, 'One Piece [L] S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/293246.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55593, 3806, 'One Piece [L] S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/293247.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55594, 3806, 'One Piece [L] S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/293248.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55595, 3806, 'One Piece [L] S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/293249.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55596, 3807, 'One Piece [L] S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/293250.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55597, 3807, 'One Piece [L] S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/293251.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55598, 3807, 'One Piece [L] S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/293252.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55599, 3807, 'One Piece [L] S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/293253.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55600, 3807, 'One Piece [L] S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/293254.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55601, 3807, 'One Piece [L] S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/293255.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55602, 3807, 'One Piece [L] S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/293256.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55603, 3807, 'One Piece [L] S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/293257.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55604, 3807, 'One Piece [L] S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/293258.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55605, 3807, 'One Piece [L] S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/293259.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55606, 3807, 'One Piece [L] S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/293260.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55607, 3807, 'One Piece [L] S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/293261.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55608, 3807, 'One Piece [L] S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/293262.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55609, 3807, 'One Piece [L] S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/293263.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55610, 3807, 'One Piece [L] S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/293264.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55611, 3807, 'One Piece [L] S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/293265.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55612, 3807, 'One Piece [L] S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/293266.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55613, 3807, 'One Piece [L] S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/293267.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55614, 3807, 'One Piece [L] S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/293268.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55615, 3807, 'One Piece [L] S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/293269.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55616, 3807, 'One Piece [L] S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/293270.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55617, 3807, 'One Piece [L] S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/293271.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55618, 3807, 'One Piece [L] S13 E23', 'http://sinalprivado.info:80/series/1533784/1533784/293272.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55619, 3807, 'One Piece [L] S13 E24', 'http://sinalprivado.info:80/series/1533784/1533784/293273.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55620, 3807, 'One Piece [L] S13 E25', 'http://sinalprivado.info:80/series/1533784/1533784/293274.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55621, 3807, 'One Piece [L] S13 E26', 'http://sinalprivado.info:80/series/1533784/1533784/293275.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55622, 3807, 'One Piece [L] S13 E27', 'http://sinalprivado.info:80/series/1533784/1533784/293276.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55623, 3807, 'One Piece [L] S13 E28', 'http://sinalprivado.info:80/series/1533784/1533784/293277.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55624, 3807, 'One Piece [L] S13 E29', 'http://sinalprivado.info:80/series/1533784/1533784/293278.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55625, 3807, 'One Piece [L] S13 E30', 'http://sinalprivado.info:80/series/1533784/1533784/293279.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55626, 3807, 'One Piece [L] S13 E31', 'http://sinalprivado.info:80/series/1533784/1533784/293280.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55627, 3807, 'One Piece [L] S13 E32', 'http://sinalprivado.info:80/series/1533784/1533784/293281.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55628, 3807, 'One Piece [L] S13 E33', 'http://sinalprivado.info:80/series/1533784/1533784/293282.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55629, 3807, 'One Piece [L] S13 E34', 'http://sinalprivado.info:80/series/1533784/1533784/293283.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55630, 3807, 'One Piece [L] S13 E35', 'http://sinalprivado.info:80/series/1533784/1533784/293284.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55631, 3807, 'One Piece [L] S13 E36', 'http://sinalprivado.info:80/series/1533784/1533784/293285.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55632, 3807, 'One Piece [L] S13 E37', 'http://sinalprivado.info:80/series/1533784/1533784/293286.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55633, 3807, 'One Piece [L] S13 E38', 'http://sinalprivado.info:80/series/1533784/1533784/293287.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55634, 3807, 'One Piece [L] S13 E39', 'http://sinalprivado.info:80/series/1533784/1533784/293288.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55635, 3807, 'One Piece [L] S13 E40', 'http://sinalprivado.info:80/series/1533784/1533784/293289.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55636, 3807, 'One Piece [L] S13 E41', 'http://sinalprivado.info:80/series/1533784/1533784/293290.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55637, 3807, 'One Piece [L] S13 E42', 'http://sinalprivado.info:80/series/1533784/1533784/293291.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55638, 3807, 'One Piece [L] S13 E43', 'http://sinalprivado.info:80/series/1533784/1533784/293292.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55639, 3807, 'One Piece [L] S13 E44', 'http://sinalprivado.info:80/series/1533784/1533784/293293.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55640, 3807, 'One Piece [L] S13 E45', 'http://sinalprivado.info:80/series/1533784/1533784/293294.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55641, 3807, 'One Piece [L] S13 E46', 'http://sinalprivado.info:80/series/1533784/1533784/293295.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55642, 3807, 'One Piece [L] S13 E47', 'http://sinalprivado.info:80/series/1533784/1533784/293296.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55643, 3807, 'One Piece [L] S13 E48', 'http://sinalprivado.info:80/series/1533784/1533784/293297.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55644, 3807, 'One Piece [L] S13 E49', 'http://sinalprivado.info:80/series/1533784/1533784/293298.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55645, 3807, 'One Piece [L] S13 E50', 'http://sinalprivado.info:80/series/1533784/1533784/293299.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55646, 3807, 'One Piece [L] S13 E51', 'http://sinalprivado.info:80/series/1533784/1533784/293300.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55647, 3807, 'One Piece [L] S13 E52', 'http://sinalprivado.info:80/series/1533784/1533784/293301.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55648, 3807, 'One Piece [L] S13 E53', 'http://sinalprivado.info:80/series/1533784/1533784/293302.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55649, 3807, 'One Piece [L] S13 E54', 'http://sinalprivado.info:80/series/1533784/1533784/293303.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55650, 3807, 'One Piece [L] S13 E55', 'http://sinalprivado.info:80/series/1533784/1533784/293304.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55651, 3807, 'One Piece [L] S13 E56', 'http://sinalprivado.info:80/series/1533784/1533784/293305.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55652, 3807, 'One Piece [L] S13 E57', 'http://sinalprivado.info:80/series/1533784/1533784/293306.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55653, 3807, 'One Piece [L] S13 E58', 'http://sinalprivado.info:80/series/1533784/1533784/293307.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55654, 3807, 'One Piece [L] S13 E59', 'http://sinalprivado.info:80/series/1533784/1533784/293308.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55655, 3807, 'One Piece [L] S13 E60', 'http://sinalprivado.info:80/series/1533784/1533784/293309.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55656, 3807, 'One Piece [L] S13 E61', 'http://sinalprivado.info:80/series/1533784/1533784/293310.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55657, 3807, 'One Piece [L] S13 E62', 'http://sinalprivado.info:80/series/1533784/1533784/293311.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55658, 3807, 'One Piece [L] S13 E63', 'http://sinalprivado.info:80/series/1533784/1533784/293312.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55659, 3807, 'One Piece [L] S13 E64', 'http://sinalprivado.info:80/series/1533784/1533784/293313.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55660, 3807, 'One Piece [L] S13 E65', 'http://sinalprivado.info:80/series/1533784/1533784/293314.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55661, 3807, 'One Piece [L] S13 E66', 'http://sinalprivado.info:80/series/1533784/1533784/293315.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55662, 3807, 'One Piece [L] S13 E67', 'http://sinalprivado.info:80/series/1533784/1533784/293316.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55663, 3807, 'One Piece [L] S13 E68', 'http://sinalprivado.info:80/series/1533784/1533784/293317.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55664, 3807, 'One Piece [L] S13 E69', 'http://sinalprivado.info:80/series/1533784/1533784/293318.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55665, 3807, 'One Piece [L] S13 E70', 'http://sinalprivado.info:80/series/1533784/1533784/293319.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55666, 3807, 'One Piece [L] S13 E71', 'http://sinalprivado.info:80/series/1533784/1533784/293320.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55667, 3807, 'One Piece [L] S13 E72', 'http://sinalprivado.info:80/series/1533784/1533784/293321.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55668, 3807, 'One Piece [L] S13 E73', 'http://sinalprivado.info:80/series/1533784/1533784/293322.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55669, 3807, 'One Piece [L] S13 E74', 'http://sinalprivado.info:80/series/1533784/1533784/293323.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55670, 3807, 'One Piece [L] S13 E75', 'http://sinalprivado.info:80/series/1533784/1533784/293324.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55671, 3807, 'One Piece [L] S13 E76', 'http://sinalprivado.info:80/series/1533784/1533784/293325.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55672, 3807, 'One Piece [L] S13 E77', 'http://sinalprivado.info:80/series/1533784/1533784/293326.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55673, 3807, 'One Piece [L] S13 E78', 'http://sinalprivado.info:80/series/1533784/1533784/293327.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55674, 3807, 'One Piece [L] S13 E79', 'http://sinalprivado.info:80/series/1533784/1533784/293328.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55675, 3807, 'One Piece [L] S13 E80', 'http://sinalprivado.info:80/series/1533784/1533784/293329.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55676, 3807, 'One Piece [L] S13 E81', 'http://sinalprivado.info:80/series/1533784/1533784/293330.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55677, 3807, 'One Piece [L] S13 E82', 'http://sinalprivado.info:80/series/1533784/1533784/293331.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55678, 3807, 'One Piece [L] S13 E83', 'http://sinalprivado.info:80/series/1533784/1533784/293332.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55679, 3807, 'One Piece [L] S13 E84', 'http://sinalprivado.info:80/series/1533784/1533784/293333.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55680, 3807, 'One Piece [L] S13 E85', 'http://sinalprivado.info:80/series/1533784/1533784/293334.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55681, 3807, 'One Piece [L] S13 E86', 'http://sinalprivado.info:80/series/1533784/1533784/293335.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55682, 3807, 'One Piece [L] S13 E87', 'http://sinalprivado.info:80/series/1533784/1533784/293336.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55683, 3807, 'One Piece [L] S13 E88', 'http://sinalprivado.info:80/series/1533784/1533784/293337.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55684, 3807, 'One Piece [L] S13 E89', 'http://sinalprivado.info:80/series/1533784/1533784/293338.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55685, 3807, 'One Piece [L] S13 E90', 'http://sinalprivado.info:80/series/1533784/1533784/293339.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55686, 3807, 'One Piece [L] S13 E91', 'http://sinalprivado.info:80/series/1533784/1533784/293340.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55687, 3807, 'One Piece [L] S13 E92', 'http://sinalprivado.info:80/series/1533784/1533784/293341.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55688, 3807, 'One Piece [L] S13 E93', 'http://sinalprivado.info:80/series/1533784/1533784/293342.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55689, 3807, 'One Piece [L] S13 E94', 'http://sinalprivado.info:80/series/1533784/1533784/293343.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55690, 3807, 'One Piece [L] S13 E95', 'http://sinalprivado.info:80/series/1533784/1533784/293344.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55691, 3807, 'One Piece [L] S13 E96', 'http://sinalprivado.info:80/series/1533784/1533784/293345.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55692, 3807, 'One Piece [L] S13 E97', 'http://sinalprivado.info:80/series/1533784/1533784/293346.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55693, 3807, 'One Piece [L] S13 E98', 'http://sinalprivado.info:80/series/1533784/1533784/293347.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55694, 3807, 'One Piece [L] S13 E99', 'http://sinalprivado.info:80/series/1533784/1533784/293348.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55695, 3807, 'One Piece [L] S13 E100', 'http://sinalprivado.info:80/series/1533784/1533784/293349.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55696, 3807, 'One Piece [L] S13 E101', 'http://sinalprivado.info:80/series/1533784/1533784/293350.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55697, 3808, 'One Piece [L] S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/293351.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55698, 3808, 'One Piece [L] S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/293352.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55699, 3808, 'One Piece [L] S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/293353.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55700, 3808, 'One Piece [L] S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/293354.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55701, 3808, 'One Piece [L] S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/293355.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55702, 3808, 'One Piece [L] S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/293356.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55703, 3808, 'One Piece [L] S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/293357.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55704, 3808, 'One Piece [L] S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/293358.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55705, 3808, 'One Piece [L] S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/293359.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55706, 3808, 'One Piece [L] S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/293360.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55707, 3808, 'One Piece [L] S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/293361.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55708, 3808, 'One Piece [L] S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/293362.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55709, 3808, 'One Piece [L] S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/293363.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55710, 3808, 'One Piece [L] S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/293364.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55711, 3808, 'One Piece [L] S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/293365.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55712, 3808, 'One Piece [L] S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/293366.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55713, 3808, 'One Piece [L] S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/293367.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55714, 3808, 'One Piece [L] S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/293368.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55715, 3808, 'One Piece [L] S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/293369.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55716, 3808, 'One Piece [L] S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/293370.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55717, 3808, 'One Piece [L] S14 E21', 'http://sinalprivado.info:80/series/1533784/1533784/293371.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55718, 3808, 'One Piece [L] S14 E22', 'http://sinalprivado.info:80/series/1533784/1533784/293372.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55719, 3808, 'One Piece [L] S14 E23', 'http://sinalprivado.info:80/series/1533784/1533784/293373.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55720, 3808, 'One Piece [L] S14 E24', 'http://sinalprivado.info:80/series/1533784/1533784/293374.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55721, 3808, 'One Piece [L] S14 E25', 'http://sinalprivado.info:80/series/1533784/1533784/293375.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55722, 3808, 'One Piece [L] S14 E26', 'http://sinalprivado.info:80/series/1533784/1533784/293376.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55723, 3808, 'One Piece [L] S14 E27', 'http://sinalprivado.info:80/series/1533784/1533784/293377.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55724, 3808, 'One Piece [L] S14 E28', 'http://sinalprivado.info:80/series/1533784/1533784/293378.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55725, 3808, 'One Piece [L] S14 E29', 'http://sinalprivado.info:80/series/1533784/1533784/293379.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55726, 3808, 'One Piece [L] S14 E30', 'http://sinalprivado.info:80/series/1533784/1533784/293380.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55727, 3808, 'One Piece [L] S14 E31', 'http://sinalprivado.info:80/series/1533784/1533784/293381.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55728, 3808, 'One Piece [L] S14 E32', 'http://sinalprivado.info:80/series/1533784/1533784/293382.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55729, 3808, 'One Piece [L] S14 E33', 'http://sinalprivado.info:80/series/1533784/1533784/293383.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55730, 3808, 'One Piece [L] S14 E34', 'http://sinalprivado.info:80/series/1533784/1533784/293384.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55731, 3808, 'One Piece [L] S14 E35', 'http://sinalprivado.info:80/series/1533784/1533784/293385.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55732, 3808, 'One Piece [L] S14 E36', 'http://sinalprivado.info:80/series/1533784/1533784/293386.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55733, 3808, 'One Piece [L] S14 E37', 'http://sinalprivado.info:80/series/1533784/1533784/293387.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55734, 3808, 'One Piece [L] S14 E38', 'http://sinalprivado.info:80/series/1533784/1533784/293388.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55735, 3808, 'One Piece [L] S14 E39', 'http://sinalprivado.info:80/series/1533784/1533784/293389.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55736, 3808, 'One Piece [L] S14 E40', 'http://sinalprivado.info:80/series/1533784/1533784/293390.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55737, 3808, 'One Piece [L] S14 E41', 'http://sinalprivado.info:80/series/1533784/1533784/293391.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55738, 3808, 'One Piece [L] S14 E42', 'http://sinalprivado.info:80/series/1533784/1533784/293392.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55739, 3808, 'One Piece [L] S14 E43', 'http://sinalprivado.info:80/series/1533784/1533784/293393.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55740, 3808, 'One Piece [L] S14 E44', 'http://sinalprivado.info:80/series/1533784/1533784/293394.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55741, 3808, 'One Piece [L] S14 E45', 'http://sinalprivado.info:80/series/1533784/1533784/293395.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55742, 3808, 'One Piece [L] S14 E46', 'http://sinalprivado.info:80/series/1533784/1533784/293396.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55743, 3808, 'One Piece [L] S14 E47', 'http://sinalprivado.info:80/series/1533784/1533784/293397.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55744, 3808, 'One Piece [L] S14 E48', 'http://sinalprivado.info:80/series/1533784/1533784/293398.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55745, 3808, 'One Piece [L] S14 E49', 'http://sinalprivado.info:80/series/1533784/1533784/293399.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55746, 3808, 'One Piece [L] S14 E50', 'http://sinalprivado.info:80/series/1533784/1533784/293400.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55747, 3808, 'One Piece [L] S14 E51', 'http://sinalprivado.info:80/series/1533784/1533784/293401.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55748, 3808, 'One Piece [L] S14 E52', 'http://sinalprivado.info:80/series/1533784/1533784/293402.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55749, 3808, 'One Piece [L] S14 E53', 'http://sinalprivado.info:80/series/1533784/1533784/293403.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55750, 3808, 'One Piece [L] S14 E54', 'http://sinalprivado.info:80/series/1533784/1533784/293404.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55751, 3808, 'One Piece [L] S14 E55', 'http://sinalprivado.info:80/series/1533784/1533784/293405.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55752, 3808, 'One Piece [L] S14 E56', 'http://sinalprivado.info:80/series/1533784/1533784/293406.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55753, 3808, 'One Piece [L] S14 E57', 'http://sinalprivado.info:80/series/1533784/1533784/293407.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55754, 3808, 'One Piece [L] S14 E58', 'http://sinalprivado.info:80/series/1533784/1533784/293408.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55755, 3809, 'One Piece [L] S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/293409.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55756, 3809, 'One Piece [L] S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/293410.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55757, 3809, 'One Piece [L] S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/293411.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55758, 3809, 'One Piece [L] S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/293412.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55759, 3809, 'One Piece [L] S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/293413.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55760, 3809, 'One Piece [L] S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/293414.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55761, 3809, 'One Piece [L] S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/293415.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55762, 3809, 'One Piece [L] S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/293416.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55763, 3809, 'One Piece [L] S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/293417.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55764, 3809, 'One Piece [L] S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/293418.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55765, 3809, 'One Piece [L] S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/293419.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55766, 3809, 'One Piece [L] S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/293420.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55767, 3809, 'One Piece [L] S15 E13', 'http://sinalprivado.info:80/series/1533784/1533784/293421.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55768, 3809, 'One Piece [L] S15 E14', 'http://sinalprivado.info:80/series/1533784/1533784/293422.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55769, 3809, 'One Piece [L] S15 E15', 'http://sinalprivado.info:80/series/1533784/1533784/293423.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55770, 3809, 'One Piece [L] S15 E16', 'http://sinalprivado.info:80/series/1533784/1533784/293424.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55771, 3809, 'One Piece [L] S15 E17', 'http://sinalprivado.info:80/series/1533784/1533784/293425.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55772, 3809, 'One Piece [L] S15 E18', 'http://sinalprivado.info:80/series/1533784/1533784/293426.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55773, 3809, 'One Piece [L] S15 E19', 'http://sinalprivado.info:80/series/1533784/1533784/293427.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55774, 3809, 'One Piece [L] S15 E20', 'http://sinalprivado.info:80/series/1533784/1533784/293428.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55775, 3809, 'One Piece [L] S15 E21', 'http://sinalprivado.info:80/series/1533784/1533784/293429.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55776, 3809, 'One Piece [L] S15 E22', 'http://sinalprivado.info:80/series/1533784/1533784/293430.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55777, 3809, 'One Piece [L] S15 E23', 'http://sinalprivado.info:80/series/1533784/1533784/293431.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55778, 3809, 'One Piece [L] S15 E24', 'http://sinalprivado.info:80/series/1533784/1533784/293432.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55779, 3809, 'One Piece [L] S15 E25', 'http://sinalprivado.info:80/series/1533784/1533784/293433.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55780, 3809, 'One Piece [L] S15 E26', 'http://sinalprivado.info:80/series/1533784/1533784/293434.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(55781, 3809, 'One Piece [L] S15 E27', 'http://sinalprivado.info:80/series/1533784/1533784/293435.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55782, 3809, 'One Piece [L] S15 E28', 'http://sinalprivado.info:80/series/1533784/1533784/293436.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55783, 3809, 'One Piece [L] S15 E29', 'http://sinalprivado.info:80/series/1533784/1533784/293437.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55784, 3809, 'One Piece [L] S15 E30', 'http://sinalprivado.info:80/series/1533784/1533784/293438.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55785, 3809, 'One Piece [L] S15 E31', 'http://sinalprivado.info:80/series/1533784/1533784/293439.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55786, 3809, 'One Piece [L] S15 E32', 'http://sinalprivado.info:80/series/1533784/1533784/293440.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55787, 3809, 'One Piece [L] S15 E33', 'http://sinalprivado.info:80/series/1533784/1533784/293441.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55788, 3809, 'One Piece [L] S15 E34', 'http://sinalprivado.info:80/series/1533784/1533784/293442.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55789, 3809, 'One Piece [L] S15 E35', 'http://sinalprivado.info:80/series/1533784/1533784/293443.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55790, 3809, 'One Piece [L] S15 E36', 'http://sinalprivado.info:80/series/1533784/1533784/293444.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55791, 3809, 'One Piece [L] S15 E37', 'http://sinalprivado.info:80/series/1533784/1533784/293445.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55792, 3809, 'One Piece [L] S15 E38', 'http://sinalprivado.info:80/series/1533784/1533784/293446.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55793, 3809, 'One Piece [L] S15 E39', 'http://sinalprivado.info:80/series/1533784/1533784/293447.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55794, 3809, 'One Piece [L] S15 E40', 'http://sinalprivado.info:80/series/1533784/1533784/293448.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55795, 3809, 'One Piece [L] S15 E41', 'http://sinalprivado.info:80/series/1533784/1533784/293449.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55796, 3809, 'One Piece [L] S15 E42', 'http://sinalprivado.info:80/series/1533784/1533784/293450.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55797, 3809, 'One Piece [L] S15 E43', 'http://sinalprivado.info:80/series/1533784/1533784/293451.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55798, 3809, 'One Piece [L] S15 E44', 'http://sinalprivado.info:80/series/1533784/1533784/293452.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55799, 3809, 'One Piece [L] S15 E45', 'http://sinalprivado.info:80/series/1533784/1533784/293453.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55800, 3809, 'One Piece [L] S15 E46', 'http://sinalprivado.info:80/series/1533784/1533784/293454.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55801, 3809, 'One Piece [L] S15 E47', 'http://sinalprivado.info:80/series/1533784/1533784/293455.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55802, 3809, 'One Piece [L] S15 E48', 'http://sinalprivado.info:80/series/1533784/1533784/293456.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55803, 3809, 'One Piece [L] S15 E49', 'http://sinalprivado.info:80/series/1533784/1533784/293457.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55804, 3809, 'One Piece [L] S15 E50', 'http://sinalprivado.info:80/series/1533784/1533784/293458.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55805, 3809, 'One Piece [L] S15 E51', 'http://sinalprivado.info:80/series/1533784/1533784/293459.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55806, 3809, 'One Piece [L] S15 E52', 'http://sinalprivado.info:80/series/1533784/1533784/293460.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55807, 3809, 'One Piece [L] S15 E53', 'http://sinalprivado.info:80/series/1533784/1533784/293461.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55808, 3809, 'One Piece [L] S15 E54', 'http://sinalprivado.info:80/series/1533784/1533784/293462.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55809, 3809, 'One Piece [L] S15 E55', 'http://sinalprivado.info:80/series/1533784/1533784/293463.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55810, 3809, 'One Piece [L] S15 E56', 'http://sinalprivado.info:80/series/1533784/1533784/293464.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55811, 3809, 'One Piece [L] S15 E57', 'http://sinalprivado.info:80/series/1533784/1533784/293465.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55812, 3809, 'One Piece [L] S15 E58', 'http://sinalprivado.info:80/series/1533784/1533784/293466.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55813, 3809, 'One Piece [L] S15 E59', 'http://sinalprivado.info:80/series/1533784/1533784/293467.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55814, 3809, 'One Piece [L] S15 E60', 'http://sinalprivado.info:80/series/1533784/1533784/293468.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55815, 3809, 'One Piece [L] S15 E61', 'http://sinalprivado.info:80/series/1533784/1533784/293469.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55816, 3809, 'One Piece [L] S15 E62', 'http://sinalprivado.info:80/series/1533784/1533784/293470.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55817, 3810, 'One Piece [L] S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/293471.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55818, 3810, 'One Piece [L] S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/293472.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55819, 3810, 'One Piece [L] S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/293473.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55820, 3810, 'One Piece [L] S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/293474.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55821, 3810, 'One Piece [L] S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/293475.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55822, 3810, 'One Piece [L] S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/293476.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55823, 3810, 'One Piece [L] S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/293477.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55824, 3810, 'One Piece [L] S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/293478.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55825, 3810, 'One Piece [L] S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/293479.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55826, 3810, 'One Piece [L] S16 E10', 'http://sinalprivado.info:80/series/1533784/1533784/293480.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55827, 3810, 'One Piece [L] S16 E11', 'http://sinalprivado.info:80/series/1533784/1533784/293481.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55828, 3810, 'One Piece [L] S16 E12', 'http://sinalprivado.info:80/series/1533784/1533784/293482.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55829, 3810, 'One Piece [L] S16 E13', 'http://sinalprivado.info:80/series/1533784/1533784/293483.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55830, 3810, 'One Piece [L] S16 E14', 'http://sinalprivado.info:80/series/1533784/1533784/293484.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55831, 3810, 'One Piece [L] S16 E15', 'http://sinalprivado.info:80/series/1533784/1533784/293485.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55832, 3810, 'One Piece [L] S16 E16', 'http://sinalprivado.info:80/series/1533784/1533784/293486.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55833, 3810, 'One Piece [L] S16 E17', 'http://sinalprivado.info:80/series/1533784/1533784/293487.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55834, 3810, 'One Piece [L] S16 E18', 'http://sinalprivado.info:80/series/1533784/1533784/293488.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55835, 3810, 'One Piece [L] S16 E19', 'http://sinalprivado.info:80/series/1533784/1533784/293489.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55836, 3810, 'One Piece [L] S16 E20', 'http://sinalprivado.info:80/series/1533784/1533784/293490.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55837, 3810, 'One Piece [L] S16 E21', 'http://sinalprivado.info:80/series/1533784/1533784/293491.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55838, 3810, 'One Piece [L] S16 E22', 'http://sinalprivado.info:80/series/1533784/1533784/293492.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55839, 3810, 'One Piece [L] S16 E23', 'http://sinalprivado.info:80/series/1533784/1533784/293493.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55840, 3810, 'One Piece [L] S16 E24', 'http://sinalprivado.info:80/series/1533784/1533784/293494.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55841, 3810, 'One Piece [L] S16 E25', 'http://sinalprivado.info:80/series/1533784/1533784/293495.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55842, 3810, 'One Piece [L] S16 E26', 'http://sinalprivado.info:80/series/1533784/1533784/293496.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55843, 3810, 'One Piece [L] S16 E27', 'http://sinalprivado.info:80/series/1533784/1533784/293497.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55844, 3810, 'One Piece [L] S16 E28', 'http://sinalprivado.info:80/series/1533784/1533784/293498.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55845, 3810, 'One Piece [L] S16 E29', 'http://sinalprivado.info:80/series/1533784/1533784/293499.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55846, 3810, 'One Piece [L] S16 E30', 'http://sinalprivado.info:80/series/1533784/1533784/293500.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55847, 3810, 'One Piece [L] S16 E31', 'http://sinalprivado.info:80/series/1533784/1533784/293501.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55848, 3810, 'One Piece [L] S16 E32', 'http://sinalprivado.info:80/series/1533784/1533784/293502.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55849, 3810, 'One Piece [L] S16 E33', 'http://sinalprivado.info:80/series/1533784/1533784/293503.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55850, 3810, 'One Piece [L] S16 E34', 'http://sinalprivado.info:80/series/1533784/1533784/293504.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55851, 3810, 'One Piece [L] S16 E35', 'http://sinalprivado.info:80/series/1533784/1533784/293505.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55852, 3810, 'One Piece [L] S16 E36', 'http://sinalprivado.info:80/series/1533784/1533784/293506.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55853, 3810, 'One Piece [L] S16 E37', 'http://sinalprivado.info:80/series/1533784/1533784/293507.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55854, 3810, 'One Piece [L] S16 E38', 'http://sinalprivado.info:80/series/1533784/1533784/293508.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55855, 3810, 'One Piece [L] S16 E39', 'http://sinalprivado.info:80/series/1533784/1533784/293509.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55856, 3810, 'One Piece [L] S16 E40', 'http://sinalprivado.info:80/series/1533784/1533784/293510.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55857, 3810, 'One Piece [L] S16 E41', 'http://sinalprivado.info:80/series/1533784/1533784/293511.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55858, 3810, 'One Piece [L] S16 E42', 'http://sinalprivado.info:80/series/1533784/1533784/293512.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55859, 3810, 'One Piece [L] S16 E43', 'http://sinalprivado.info:80/series/1533784/1533784/293513.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55860, 3810, 'One Piece [L] S16 E44', 'http://sinalprivado.info:80/series/1533784/1533784/293514.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55861, 3810, 'One Piece [L] S16 E45', 'http://sinalprivado.info:80/series/1533784/1533784/293515.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55862, 3810, 'One Piece [L] S16 E46', 'http://sinalprivado.info:80/series/1533784/1533784/293516.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55863, 3810, 'One Piece [L] S16 E47', 'http://sinalprivado.info:80/series/1533784/1533784/293517.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55864, 3810, 'One Piece [L] S16 E48', 'http://sinalprivado.info:80/series/1533784/1533784/293518.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55865, 3810, 'One Piece [L] S16 E49', 'http://sinalprivado.info:80/series/1533784/1533784/293519.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55866, 3810, 'One Piece [L] S16 E50', 'http://sinalprivado.info:80/series/1533784/1533784/293520.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55867, 3810, 'One Piece [L] S16 E51', 'http://sinalprivado.info:80/series/1533784/1533784/443963.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55868, 3810, 'One Piece [L] S16 E52', 'http://sinalprivado.info:80/series/1533784/1533784/446632.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55869, 3811, 'One Piece [L] S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/293521.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55870, 3811, 'One Piece [L] S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/293522.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55871, 3811, 'One Piece [L] S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/293523.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55872, 3811, 'One Piece [L] S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/293524.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55873, 3811, 'One Piece [L] S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/293525.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55874, 3811, 'One Piece [L] S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/293526.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55875, 3811, 'One Piece [L] S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/293527.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55876, 3811, 'One Piece [L] S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/293528.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55877, 3811, 'One Piece [L] S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/293529.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55878, 3811, 'One Piece [L] S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/293530.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55879, 3811, 'One Piece [L] S17 E11', 'http://sinalprivado.info:80/series/1533784/1533784/293531.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55880, 3811, 'One Piece [L] S17 E12', 'http://sinalprivado.info:80/series/1533784/1533784/293532.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55881, 3811, 'One Piece [L] S17 E13', 'http://sinalprivado.info:80/series/1533784/1533784/293533.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55882, 3811, 'One Piece [L] S17 E14', 'http://sinalprivado.info:80/series/1533784/1533784/293534.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55883, 3811, 'One Piece [L] S17 E15', 'http://sinalprivado.info:80/series/1533784/1533784/293535.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55884, 3811, 'One Piece [L] S17 E16', 'http://sinalprivado.info:80/series/1533784/1533784/293536.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55885, 3811, 'One Piece [L] S17 E17', 'http://sinalprivado.info:80/series/1533784/1533784/293537.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55886, 3811, 'One Piece [L] S17 E18', 'http://sinalprivado.info:80/series/1533784/1533784/293538.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55887, 3811, 'One Piece [L] S17 E19', 'http://sinalprivado.info:80/series/1533784/1533784/293539.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55888, 3811, 'One Piece [L] S17 E20', 'http://sinalprivado.info:80/series/1533784/1533784/293540.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55889, 3811, 'One Piece [L] S17 E21', 'http://sinalprivado.info:80/series/1533784/1533784/293541.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55890, 3811, 'One Piece [L] S17 E22', 'http://sinalprivado.info:80/series/1533784/1533784/293542.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55891, 3811, 'One Piece [L] S17 E23', 'http://sinalprivado.info:80/series/1533784/1533784/293543.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55892, 3811, 'One Piece [L] S17 E24', 'http://sinalprivado.info:80/series/1533784/1533784/293544.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55893, 3811, 'One Piece [L] S17 E25', 'http://sinalprivado.info:80/series/1533784/1533784/293545.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55894, 3811, 'One Piece [L] S17 E26', 'http://sinalprivado.info:80/series/1533784/1533784/293546.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55895, 3811, 'One Piece [L] S17 E27', 'http://sinalprivado.info:80/series/1533784/1533784/293547.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55896, 3811, 'One Piece [L] S17 E28', 'http://sinalprivado.info:80/series/1533784/1533784/293548.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55897, 3811, 'One Piece [L] S17 E29', 'http://sinalprivado.info:80/series/1533784/1533784/293549.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55898, 3811, 'One Piece [L] S17 E30', 'http://sinalprivado.info:80/series/1533784/1533784/293550.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55899, 3811, 'One Piece [L] S17 E31', 'http://sinalprivado.info:80/series/1533784/1533784/293551.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55900, 3811, 'One Piece [L] S17 E32', 'http://sinalprivado.info:80/series/1533784/1533784/293552.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55901, 3811, 'One Piece [L] S17 E33', 'http://sinalprivado.info:80/series/1533784/1533784/293553.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55902, 3811, 'One Piece [L] S17 E34', 'http://sinalprivado.info:80/series/1533784/1533784/293554.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55903, 3811, 'One Piece [L] S17 E35', 'http://sinalprivado.info:80/series/1533784/1533784/293555.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55904, 3811, 'One Piece [L] S17 E36', 'http://sinalprivado.info:80/series/1533784/1533784/293556.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55905, 3811, 'One Piece [L] S17 E37', 'http://sinalprivado.info:80/series/1533784/1533784/293557.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55906, 3811, 'One Piece [L] S17 E38', 'http://sinalprivado.info:80/series/1533784/1533784/293558.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55907, 3811, 'One Piece [L] S17 E39', 'http://sinalprivado.info:80/series/1533784/1533784/293559.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55908, 3811, 'One Piece [L] S17 E40', 'http://sinalprivado.info:80/series/1533784/1533784/293560.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55909, 3811, 'One Piece [L] S17 E41', 'http://sinalprivado.info:80/series/1533784/1533784/293561.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55910, 3811, 'One Piece [L] S17 E42', 'http://sinalprivado.info:80/series/1533784/1533784/293562.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55911, 3811, 'One Piece [L] S17 E43', 'http://sinalprivado.info:80/series/1533784/1533784/293563.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55912, 3811, 'One Piece [L] S17 E44', 'http://sinalprivado.info:80/series/1533784/1533784/293564.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55913, 3811, 'One Piece [L] S17 E45', 'http://sinalprivado.info:80/series/1533784/1533784/293565.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55914, 3811, 'One Piece [L] S17 E46', 'http://sinalprivado.info:80/series/1533784/1533784/293566.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55915, 3811, 'One Piece [L] S17 E47', 'http://sinalprivado.info:80/series/1533784/1533784/293567.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55916, 3811, 'One Piece [L] S17 E48', 'http://sinalprivado.info:80/series/1533784/1533784/293568.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55917, 3811, 'One Piece [L] S17 E49', 'http://sinalprivado.info:80/series/1533784/1533784/293569.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55918, 3811, 'One Piece [L] S17 E50', 'http://sinalprivado.info:80/series/1533784/1533784/293570.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55919, 3811, 'One Piece [L] S17 E51', 'http://sinalprivado.info:80/series/1533784/1533784/293571.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55920, 3811, 'One Piece [L] S17 E52', 'http://sinalprivado.info:80/series/1533784/1533784/293572.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55921, 3811, 'One Piece [L] S17 E53', 'http://sinalprivado.info:80/series/1533784/1533784/293573.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55922, 3811, 'One Piece [L] S17 E54', 'http://sinalprivado.info:80/series/1533784/1533784/293574.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55923, 3811, 'One Piece [L] S17 E55', 'http://sinalprivado.info:80/series/1533784/1533784/293575.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55924, 3811, 'One Piece [L] S17 E56', 'http://sinalprivado.info:80/series/1533784/1533784/293576.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55925, 3812, 'One Piece [L] S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/293577.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55926, 3812, 'One Piece [L] S18 E02', 'http://sinalprivado.info:80/series/1533784/1533784/293578.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55927, 3812, 'One Piece [L] S18 E03', 'http://sinalprivado.info:80/series/1533784/1533784/293579.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55928, 3812, 'One Piece [L] S18 E04', 'http://sinalprivado.info:80/series/1533784/1533784/293580.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55929, 3812, 'One Piece [L] S18 E05', 'http://sinalprivado.info:80/series/1533784/1533784/293581.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55930, 3812, 'One Piece [L] S18 E06', 'http://sinalprivado.info:80/series/1533784/1533784/293582.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55931, 3812, 'One Piece [L] S18 E07', 'http://sinalprivado.info:80/series/1533784/1533784/293583.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55932, 3812, 'One Piece [L] S18 E08', 'http://sinalprivado.info:80/series/1533784/1533784/293584.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55933, 3812, 'One Piece [L] S18 E09', 'http://sinalprivado.info:80/series/1533784/1533784/293585.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55934, 3812, 'One Piece [L] S18 E10', 'http://sinalprivado.info:80/series/1533784/1533784/293586.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55935, 3812, 'One Piece [L] S18 E11', 'http://sinalprivado.info:80/series/1533784/1533784/293587.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55936, 3812, 'One Piece [L] S18 E12', 'http://sinalprivado.info:80/series/1533784/1533784/293588.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55937, 3812, 'One Piece [L] S18 E13', 'http://sinalprivado.info:80/series/1533784/1533784/293589.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55938, 3812, 'One Piece [L] S18 E14', 'http://sinalprivado.info:80/series/1533784/1533784/293590.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55939, 3812, 'One Piece [L] S18 E15', 'http://sinalprivado.info:80/series/1533784/1533784/293591.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55940, 3812, 'One Piece [L] S18 E16', 'http://sinalprivado.info:80/series/1533784/1533784/293592.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55941, 3812, 'One Piece [L] S18 E17', 'http://sinalprivado.info:80/series/1533784/1533784/293593.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55942, 3812, 'One Piece [L] S18 E18', 'http://sinalprivado.info:80/series/1533784/1533784/293594.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55943, 3812, 'One Piece [L] S18 E19', 'http://sinalprivado.info:80/series/1533784/1533784/293595.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55944, 3812, 'One Piece [L] S18 E20', 'http://sinalprivado.info:80/series/1533784/1533784/293596.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55945, 3812, 'One Piece [L] S18 E21', 'http://sinalprivado.info:80/series/1533784/1533784/293597.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55946, 3812, 'One Piece [L] S18 E22', 'http://sinalprivado.info:80/series/1533784/1533784/293598.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55947, 3812, 'One Piece [L] S18 E23', 'http://sinalprivado.info:80/series/1533784/1533784/293599.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55948, 3812, 'One Piece [L] S18 E24', 'http://sinalprivado.info:80/series/1533784/1533784/293600.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55949, 3812, 'One Piece [L] S18 E25', 'http://sinalprivado.info:80/series/1533784/1533784/293601.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55950, 3812, 'One Piece [L] S18 E26', 'http://sinalprivado.info:80/series/1533784/1533784/293602.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55951, 3812, 'One Piece [L] S18 E27', 'http://sinalprivado.info:80/series/1533784/1533784/293603.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55952, 3812, 'One Piece [L] S18 E28', 'http://sinalprivado.info:80/series/1533784/1533784/293604.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55953, 3812, 'One Piece [L] S18 E29', 'http://sinalprivado.info:80/series/1533784/1533784/293605.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55954, 3812, 'One Piece [L] S18 E30', 'http://sinalprivado.info:80/series/1533784/1533784/293606.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55955, 3812, 'One Piece [L] S18 E31', 'http://sinalprivado.info:80/series/1533784/1533784/293607.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55956, 3812, 'One Piece [L] S18 E32', 'http://sinalprivado.info:80/series/1533784/1533784/293608.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55957, 3812, 'One Piece [L] S18 E33', 'http://sinalprivado.info:80/series/1533784/1533784/293609.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55958, 3812, 'One Piece [L] S18 E34', 'http://sinalprivado.info:80/series/1533784/1533784/293610.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55959, 3812, 'One Piece [L] S18 E35', 'http://sinalprivado.info:80/series/1533784/1533784/293611.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55960, 3812, 'One Piece [L] S18 E36', 'http://sinalprivado.info:80/series/1533784/1533784/293612.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55961, 3812, 'One Piece [L] S18 E37', 'http://sinalprivado.info:80/series/1533784/1533784/293613.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55962, 3812, 'One Piece [L] S18 E38', 'http://sinalprivado.info:80/series/1533784/1533784/293614.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55963, 3812, 'One Piece [L] S18 E39', 'http://sinalprivado.info:80/series/1533784/1533784/293615.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55964, 3812, 'One Piece [L] S18 E40', 'http://sinalprivado.info:80/series/1533784/1533784/293616.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55965, 3812, 'One Piece [L] S18 E41', 'http://sinalprivado.info:80/series/1533784/1533784/293617.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55966, 3812, 'One Piece [L] S18 E42', 'http://sinalprivado.info:80/series/1533784/1533784/293618.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55967, 3812, 'One Piece [L] S18 E43', 'http://sinalprivado.info:80/series/1533784/1533784/293619.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55968, 3812, 'One Piece [L] S18 E44', 'http://sinalprivado.info:80/series/1533784/1533784/293620.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55969, 3812, 'One Piece [L] S18 E45', 'http://sinalprivado.info:80/series/1533784/1533784/293621.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55970, 3812, 'One Piece [L] S18 E46', 'http://sinalprivado.info:80/series/1533784/1533784/293622.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55971, 3812, 'One Piece [L] S18 E47', 'http://sinalprivado.info:80/series/1533784/1533784/293623.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55972, 3812, 'One Piece [L] S18 E48', 'http://sinalprivado.info:80/series/1533784/1533784/293624.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55973, 3812, 'One Piece [L] S18 E49', 'http://sinalprivado.info:80/series/1533784/1533784/293625.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55974, 3812, 'One Piece [L] S18 E50', 'http://sinalprivado.info:80/series/1533784/1533784/293626.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55975, 3812, 'One Piece [L] S18 E51', 'http://sinalprivado.info:80/series/1533784/1533784/293627.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55976, 3812, 'One Piece [L] S18 E52', 'http://sinalprivado.info:80/series/1533784/1533784/293628.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55977, 3812, 'One Piece [L] S18 E53', 'http://sinalprivado.info:80/series/1533784/1533784/293629.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55978, 3812, 'One Piece [L] S18 E54', 'http://sinalprivado.info:80/series/1533784/1533784/293630.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55979, 3812, 'One Piece [L] S18 E55', 'http://sinalprivado.info:80/series/1533784/1533784/293631.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55980, 3813, 'One Piece [L] S19 E01', 'http://sinalprivado.info:80/series/1533784/1533784/293632.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55981, 3813, 'One Piece [L] S19 E02', 'http://sinalprivado.info:80/series/1533784/1533784/293633.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55982, 3813, 'One Piece [L] S19 E03', 'http://sinalprivado.info:80/series/1533784/1533784/293634.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55983, 3813, 'One Piece [L] S19 E04', 'http://sinalprivado.info:80/series/1533784/1533784/293635.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55984, 3813, 'One Piece [L] S19 E05', 'http://sinalprivado.info:80/series/1533784/1533784/293636.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55985, 3813, 'One Piece [L] S19 E06', 'http://sinalprivado.info:80/series/1533784/1533784/293637.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55986, 3813, 'One Piece [L] S19 E07', 'http://sinalprivado.info:80/series/1533784/1533784/293638.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55987, 3813, 'One Piece [L] S19 E08', 'http://sinalprivado.info:80/series/1533784/1533784/293639.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55988, 3813, 'One Piece [L] S19 E09', 'http://sinalprivado.info:80/series/1533784/1533784/293640.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55989, 3813, 'One Piece [L] S19 E10', 'http://sinalprivado.info:80/series/1533784/1533784/293641.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55990, 3813, 'One Piece [L] S19 E11', 'http://sinalprivado.info:80/series/1533784/1533784/293642.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55991, 3813, 'One Piece [L] S19 E12', 'http://sinalprivado.info:80/series/1533784/1533784/293643.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55992, 3813, 'One Piece [L] S19 E13', 'http://sinalprivado.info:80/series/1533784/1533784/293644.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55993, 3813, 'One Piece [L] S19 E14', 'http://sinalprivado.info:80/series/1533784/1533784/293645.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55994, 3813, 'One Piece [L] S19 E15', 'http://sinalprivado.info:80/series/1533784/1533784/293646.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55995, 3813, 'One Piece [L] S19 E16', 'http://sinalprivado.info:80/series/1533784/1533784/293647.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55996, 3813, 'One Piece [L] S19 E17', 'http://sinalprivado.info:80/series/1533784/1533784/293648.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55997, 3813, 'One Piece [L] S19 E18', 'http://sinalprivado.info:80/series/1533784/1533784/293649.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55998, 3813, 'One Piece [L] S19 E19', 'http://sinalprivado.info:80/series/1533784/1533784/293650.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(55999, 3813, 'One Piece [L] S19 E20', 'http://sinalprivado.info:80/series/1533784/1533784/293651.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56000, 3813, 'One Piece [L] S19 E21', 'http://sinalprivado.info:80/series/1533784/1533784/293652.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56001, 3813, 'One Piece [L] S19 E22', 'http://sinalprivado.info:80/series/1533784/1533784/293653.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56002, 3813, 'One Piece [L] S19 E23', 'http://sinalprivado.info:80/series/1533784/1533784/293654.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56003, 3813, 'One Piece [L] S19 E24', 'http://sinalprivado.info:80/series/1533784/1533784/293655.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56004, 3813, 'One Piece [L] S19 E25', 'http://sinalprivado.info:80/series/1533784/1533784/293656.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56005, 3813, 'One Piece [L] S19 E26', 'http://sinalprivado.info:80/series/1533784/1533784/293657.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56006, 3813, 'One Piece [L] S19 E27', 'http://sinalprivado.info:80/series/1533784/1533784/293658.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56007, 3813, 'One Piece [L] S19 E28', 'http://sinalprivado.info:80/series/1533784/1533784/293659.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56008, 3813, 'One Piece [L] S19 E29', 'http://sinalprivado.info:80/series/1533784/1533784/293660.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56009, 3813, 'One Piece [L] S19 E30', 'http://sinalprivado.info:80/series/1533784/1533784/293661.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56010, 3813, 'One Piece [L] S19 E31', 'http://sinalprivado.info:80/series/1533784/1533784/293662.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56011, 3813, 'One Piece [L] S19 E32', 'http://sinalprivado.info:80/series/1533784/1533784/293663.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56012, 3813, 'One Piece [L] S19 E33', 'http://sinalprivado.info:80/series/1533784/1533784/293664.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56013, 3813, 'One Piece [L] S19 E34', 'http://sinalprivado.info:80/series/1533784/1533784/293665.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56014, 3813, 'One Piece [L] S19 E35', 'http://sinalprivado.info:80/series/1533784/1533784/293666.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56015, 3813, 'One Piece [L] S19 E36', 'http://sinalprivado.info:80/series/1533784/1533784/293667.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56016, 3813, 'One Piece [L] S19 E37', 'http://sinalprivado.info:80/series/1533784/1533784/293668.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56017, 3813, 'One Piece [L] S19 E38', 'http://sinalprivado.info:80/series/1533784/1533784/293669.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56018, 3813, 'One Piece [L] S19 E39', 'http://sinalprivado.info:80/series/1533784/1533784/293670.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56019, 3813, 'One Piece [L] S19 E40', 'http://sinalprivado.info:80/series/1533784/1533784/293671.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56020, 3813, 'One Piece [L] S19 E41', 'http://sinalprivado.info:80/series/1533784/1533784/293672.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56021, 3813, 'One Piece [L] S19 E42', 'http://sinalprivado.info:80/series/1533784/1533784/293673.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56022, 3813, 'One Piece [L] S19 E43', 'http://sinalprivado.info:80/series/1533784/1533784/293674.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56023, 3813, 'One Piece [L] S19 E44', 'http://sinalprivado.info:80/series/1533784/1533784/293675.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56024, 3813, 'One Piece [L] S19 E45', 'http://sinalprivado.info:80/series/1533784/1533784/293676.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56025, 3813, 'One Piece [L] S19 E46', 'http://sinalprivado.info:80/series/1533784/1533784/293677.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56026, 3813, 'One Piece [L] S19 E47', 'http://sinalprivado.info:80/series/1533784/1533784/293678.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56027, 3813, 'One Piece [L] S19 E48', 'http://sinalprivado.info:80/series/1533784/1533784/293679.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56028, 3813, 'One Piece [L] S19 E49', 'http://sinalprivado.info:80/series/1533784/1533784/293680.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56029, 3813, 'One Piece [L] S19 E50', 'http://sinalprivado.info:80/series/1533784/1533784/293681.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56030, 3813, 'One Piece [L] S19 E51', 'http://sinalprivado.info:80/series/1533784/1533784/293682.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56031, 3813, 'One Piece [L] S19 E52', 'http://sinalprivado.info:80/series/1533784/1533784/293683.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56032, 3813, 'One Piece [L] S19 E53', 'http://sinalprivado.info:80/series/1533784/1533784/293684.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56033, 3813, 'One Piece [L] S19 E54', 'http://sinalprivado.info:80/series/1533784/1533784/293685.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56034, 3813, 'One Piece [L] S19 E55', 'http://sinalprivado.info:80/series/1533784/1533784/293686.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56035, 3813, 'One Piece [L] S19 E56', 'http://sinalprivado.info:80/series/1533784/1533784/293687.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56036, 3813, 'One Piece [L] S19 E57', 'http://sinalprivado.info:80/series/1533784/1533784/293688.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56037, 3813, 'One Piece [L] S19 E58', 'http://sinalprivado.info:80/series/1533784/1533784/293689.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56038, 3813, 'One Piece [L] S19 E59', 'http://sinalprivado.info:80/series/1533784/1533784/293690.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56039, 3813, 'One Piece [L] S19 E60', 'http://sinalprivado.info:80/series/1533784/1533784/293691.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56040, 3813, 'One Piece [L] S19 E61', 'http://sinalprivado.info:80/series/1533784/1533784/293692.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56041, 3813, 'One Piece [L] S19 E62', 'http://sinalprivado.info:80/series/1533784/1533784/293693.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56042, 3813, 'One Piece [L] S19 E63', 'http://sinalprivado.info:80/series/1533784/1533784/293694.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56043, 3813, 'One Piece [L] S19 E64', 'http://sinalprivado.info:80/series/1533784/1533784/293695.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56044, 3813, 'One Piece [L] S19 E65', 'http://sinalprivado.info:80/series/1533784/1533784/293696.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56045, 3813, 'One Piece [L] S19 E66', 'http://sinalprivado.info:80/series/1533784/1533784/293697.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56046, 3813, 'One Piece [L] S19 E67', 'http://sinalprivado.info:80/series/1533784/1533784/293698.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56047, 3813, 'One Piece [L] S19 E68', 'http://sinalprivado.info:80/series/1533784/1533784/293699.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56048, 3813, 'One Piece [L] S19 E69', 'http://sinalprivado.info:80/series/1533784/1533784/293700.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56049, 3813, 'One Piece [L] S19 E70', 'http://sinalprivado.info:80/series/1533784/1533784/293701.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56050, 3813, 'One Piece [L] S19 E71', 'http://sinalprivado.info:80/series/1533784/1533784/293702.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56051, 3813, 'One Piece [L] S19 E72', 'http://sinalprivado.info:80/series/1533784/1533784/293703.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56052, 3813, 'One Piece [L] S19 E73', 'http://sinalprivado.info:80/series/1533784/1533784/293704.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56053, 3813, 'One Piece [L] S19 E74', 'http://sinalprivado.info:80/series/1533784/1533784/293705.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56054, 3814, 'One Piece [L] S20 E01', 'http://sinalprivado.info:80/series/1533784/1533784/293706.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56055, 3814, 'One Piece [L] S20 E02', 'http://sinalprivado.info:80/series/1533784/1533784/293707.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56056, 3814, 'One Piece [L] S20 E03', 'http://sinalprivado.info:80/series/1533784/1533784/293708.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56057, 3814, 'One Piece [L] S20 E04', 'http://sinalprivado.info:80/series/1533784/1533784/293709.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56058, 3814, 'One Piece [L] S20 E05', 'http://sinalprivado.info:80/series/1533784/1533784/293710.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56059, 3814, 'One Piece [L] S20 E06', 'http://sinalprivado.info:80/series/1533784/1533784/293711.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56060, 3814, 'One Piece [L] S20 E07', 'http://sinalprivado.info:80/series/1533784/1533784/293712.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56061, 3814, 'One Piece [L] S20 E08', 'http://sinalprivado.info:80/series/1533784/1533784/293713.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56062, 3814, 'One Piece [L] S20 E09', 'http://sinalprivado.info:80/series/1533784/1533784/293714.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56063, 3814, 'One Piece [L] S20 E10', 'http://sinalprivado.info:80/series/1533784/1533784/293715.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56064, 3814, 'One Piece [L] S20 E11', 'http://sinalprivado.info:80/series/1533784/1533784/293716.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56065, 3814, 'One Piece [L] S20 E12', 'http://sinalprivado.info:80/series/1533784/1533784/293717.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56066, 3814, 'One Piece [L] S20 E13', 'http://sinalprivado.info:80/series/1533784/1533784/293718.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(56067, 3814, 'One Piece [L] S20 E14', 'http://sinalprivado.info:80/series/1533784/1533784/293719.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56068, 3815, 'One Piece [L] S21 E01', 'http://sinalprivado.info:80/series/1533784/1533784/293720.mp4', 'http://timg.bdta.pro/images/fd1357b9801c553f66e85c5eeadb4d1d.jpg'),
(56069, 3815, 'One Piece [L] S21 E02', 'http://sinalprivado.info:80/series/1533784/1533784/293721.mp4', 'http://timg.bdta.pro/images/9fbcb8f130b4cd7ddd38bfb2da373146.jpg'),
(56070, 3815, 'One Piece [L] S21 E03', 'http://sinalprivado.info:80/series/1533784/1533784/293722.mp4', 'http://timg.bdta.pro/images/09c9cb8e883db0c45b51513910249e52.jpg'),
(56071, 3815, 'One Piece [L] S21 E04', 'http://sinalprivado.info:80/series/1533784/1533784/293723.mp4', 'http://timg.bdta.pro/images/b34282b6507b30489772f1b57931e3df.jpg'),
(56072, 3815, 'One Piece [L] S21 E05', 'http://sinalprivado.info:80/series/1533784/1533784/293724.mp4', 'http://timg.bdta.pro/images/33e8ed20c7eda09feea48e78ab477dc3.jpg'),
(56073, 3815, 'One Piece [L] S21 E06', 'http://sinalprivado.info:80/series/1533784/1533784/293725.mp4', 'http://timg.bdta.pro/images/528323439375a58c9ba2a1edb9901112.jpg'),
(56074, 3815, 'One Piece [L] S21 E07', 'http://sinalprivado.info:80/series/1533784/1533784/293726.mp4', 'http://timg.bdta.pro/images/71b05f6728a43d18e586cdd8c1d617d4.jpg'),
(56075, 3815, 'One Piece [L] S21 E08', 'http://sinalprivado.info:80/series/1533784/1533784/293727.mp4', 'http://timg.bdta.pro/images/d8e1b0fe66f008a9e1257eb3c763ce44.jpg'),
(56076, 3815, 'One Piece [L] S21 E09', 'http://sinalprivado.info:80/series/1533784/1533784/293728.mp4', 'http://timg.bdta.pro/images/11823d2c73e16d53f1c62e10d12d3f9a.jpg'),
(56077, 3815, 'One Piece [L] S21 E10', 'http://sinalprivado.info:80/series/1533784/1533784/293729.mp4', 'http://timg.bdta.pro/images/33c66d42d9bc44fd4ee67d6f97e2fdb8.jpg'),
(56078, 3815, 'One Piece [L] S21 E11', 'http://sinalprivado.info:80/series/1533784/1533784/293730.mp4', 'http://timg.bdta.pro/images/8f593f8e98b62dce767779ac9b9220ab.jpg'),
(56079, 3815, 'One Piece [L] S21 E12', 'http://sinalprivado.info:80/series/1533784/1533784/293731.mp4', 'http://timg.bdta.pro/images/b944143e602c5cf5489f80c592d4369a.jpg'),
(56080, 3815, 'One Piece [L] S21 E13', 'http://sinalprivado.info:80/series/1533784/1533784/293732.mp4', 'http://timg.bdta.pro/images/74b299ff0051e26d0ee5eb3daa881ada.jpg'),
(56081, 3815, 'One Piece [L] S21 E14', 'http://sinalprivado.info:80/series/1533784/1533784/293733.mp4', 'http://timg.bdta.pro/images/ebf91f9de6363a086aa94148c6288218.jpg'),
(56082, 3815, 'One Piece [L] S21 E15', 'http://sinalprivado.info:80/series/1533784/1533784/293734.mp4', 'http://timg.bdta.pro/images/73a1758530f7b7b63f16756560672de4.jpg'),
(56083, 3815, 'One Piece [L] S21 E16', 'http://sinalprivado.info:80/series/1533784/1533784/293735.mp4', 'http://timg.bdta.pro/images/d37be9fdefbad8ac93ae994a90502d27.jpg'),
(56084, 3815, 'One Piece [L] S21 E17', 'http://sinalprivado.info:80/series/1533784/1533784/293736.mp4', 'http://timg.bdta.pro/images/7374d160571e15fa0b94444d24a4acde.jpg'),
(56085, 3815, 'One Piece [L] S21 E18', 'http://sinalprivado.info:80/series/1533784/1533784/293737.mp4', 'http://timg.bdta.pro/images/4bcd15dacfd8e717288c2525a03cca06.jpg'),
(56086, 3815, 'One Piece [L] S21 E19', 'http://sinalprivado.info:80/series/1533784/1533784/293738.mp4', 'http://timg.bdta.pro/images/3dec435b1f0243bfed5c0fd8c9921f94.jpg'),
(56087, 3815, 'One Piece [L] S21 E20', 'http://sinalprivado.info:80/series/1533784/1533784/293739.mp4', 'http://timg.bdta.pro/images/09834c46755420b747609bf0cf01563b.jpg'),
(56088, 3815, 'One Piece [L] S21 E21', 'http://sinalprivado.info:80/series/1533784/1533784/293740.mp4', 'http://timg.bdta.pro/images/c7dba39aa0871862939c63bcc36cdac9.jpg'),
(56089, 3815, 'One Piece [L] S21 E22', 'http://sinalprivado.info:80/series/1533784/1533784/293741.mp4', 'http://timg.bdta.pro/images/405f510188f1102c7971747fae92dd6d.jpg'),
(56090, 3815, 'One Piece [L] S21 E23', 'http://sinalprivado.info:80/series/1533784/1533784/293742.mp4', 'http://timg.bdta.pro/images/441f51fa6ae2d3181e3114d53d2487dd.jpg'),
(56091, 3815, 'One Piece [L] S21 E24', 'http://sinalprivado.info:80/series/1533784/1533784/293743.mp4', 'http://timg.bdta.pro/images/bd219fba4dde68ecaec60a6804bcd8ca.jpg'),
(56092, 3815, 'One Piece [L] S21 E25', 'http://sinalprivado.info:80/series/1533784/1533784/293744.mp4', 'http://timg.bdta.pro/images/124662e9af77c4849520b1b6284f2a42.jpg'),
(56093, 3815, 'One Piece [L] S21 E26', 'http://sinalprivado.info:80/series/1533784/1533784/293745.mp4', 'http://timg.bdta.pro/images/bd88d8f776f64c43691a1d2c2017103b.jpg'),
(56094, 3815, 'One Piece [L] S21 E27', 'http://sinalprivado.info:80/series/1533784/1533784/293746.mp4', 'http://timg.bdta.pro/images/3f25f76168ff2e906c3732b40b6f987c.jpg'),
(56095, 3815, 'One Piece [L] S21 E28', 'http://sinalprivado.info:80/series/1533784/1533784/293747.mp4', 'http://timg.bdta.pro/images/00e8241239ed99a77eeee30f720db7bd.jpg'),
(56096, 3815, 'One Piece [L] S21 E29', 'http://sinalprivado.info:80/series/1533784/1533784/293748.mp4', 'http://timg.bdta.pro/images/e359a5ae7544247ce37627f552c07396.jpg'),
(56097, 3815, 'One Piece [L] S21 E30', 'http://sinalprivado.info:80/series/1533784/1533784/293749.mp4', 'http://timg.bdta.pro/images/604c5860f3e47ad021d43f908f9c280c.jpg'),
(56098, 3815, 'One Piece [L] S21 E31', 'http://sinalprivado.info:80/series/1533784/1533784/293750.mp4', 'http://timg.bdta.pro/images/9934fb806c275b7de8a40f069d80d63d.jpg'),
(56099, 3815, 'One Piece [L] S21 E32', 'http://sinalprivado.info:80/series/1533784/1533784/293751.mp4', 'http://timg.bdta.pro/images/ab797e9ec0462bbca13b347e636e1174.jpg'),
(56100, 3815, 'One Piece [L] S21 E33', 'http://sinalprivado.info:80/series/1533784/1533784/293752.mp4', 'http://timg.bdta.pro/images/43894f123518667b5482d92bad0301d8.jpg'),
(56101, 3815, 'One Piece [L] S21 E34', 'http://sinalprivado.info:80/series/1533784/1533784/293753.mp4', 'http://timg.bdta.pro/images/175a02e918eb2c2df6e486bf90f8bbb3.jpg'),
(56102, 3815, 'One Piece [L] S21 E35', 'http://sinalprivado.info:80/series/1533784/1533784/293754.mp4', 'http://timg.bdta.pro/images/e8e9f9cbb9328d67415debb49a19a5d4.jpg'),
(56103, 3815, 'One Piece [L] S21 E36', 'http://sinalprivado.info:80/series/1533784/1533784/293755.mp4', 'http://timg.bdta.pro/images/f6b6734c55a54cc297927b8b2fd813f3.jpg'),
(56104, 3815, 'One Piece [L] S21 E37', 'http://sinalprivado.info:80/series/1533784/1533784/293756.mp4', 'http://timg.bdta.pro/images/ac178bbdbe07ff19da7ca7b39f815b98.jpg'),
(56105, 3815, 'One Piece [L] S21 E38', 'http://sinalprivado.info:80/series/1533784/1533784/293757.mp4', 'http://timg.bdta.pro/images/76a3e239369703d12d71e84bf276815f.jpg'),
(56106, 3815, 'One Piece [L] S21 E39', 'http://sinalprivado.info:80/series/1533784/1533784/293758.mp4', 'http://timg.bdta.pro/images/db458788963763c7962336166db5c071.jpg'),
(56107, 3815, 'One Piece [L] S21 E40', 'http://sinalprivado.info:80/series/1533784/1533784/293759.mp4', 'http://timg.bdta.pro/images/95d42a55121d9bb1f11850a2da8abca1.jpg'),
(56108, 3815, 'One Piece [L] S21 E41', 'http://sinalprivado.info:80/series/1533784/1533784/293760.mp4', 'http://timg.bdta.pro/images/01aa82330ab9c60436b434056af9cc11.jpg'),
(56109, 3815, 'One Piece [L] S21 E42', 'http://sinalprivado.info:80/series/1533784/1533784/293761.mp4', 'http://timg.bdta.pro/images/e6b6a299356364cccbda179f96b7c79d.jpg'),
(56110, 3815, 'One Piece [L] S21 E43', 'http://sinalprivado.info:80/series/1533784/1533784/293762.mp4', 'http://timg.bdta.pro/images/38cb16794148b2c494c15257a7e9918a.jpg'),
(56111, 3815, 'One Piece [L] S21 E44', 'http://sinalprivado.info:80/series/1533784/1533784/293763.mp4', 'http://timg.bdta.pro/images/bf96c854488146ba22a09e091b1cb052.jpg'),
(56112, 3815, 'One Piece [L] S21 E45', 'http://sinalprivado.info:80/series/1533784/1533784/293764.mp4', 'http://timg.bdta.pro/images/f61718b28069b65638520f14c39b0bf2.jpg'),
(56113, 3815, 'One Piece [L] S21 E46', 'http://sinalprivado.info:80/series/1533784/1533784/293765.mp4', 'http://timg.bdta.pro/images/bc44f266e0e550a1247d35ed7eb4f989.jpg'),
(56114, 3815, 'One Piece [L] S21 E47', 'http://sinalprivado.info:80/series/1533784/1533784/293766.mp4', 'http://timg.bdta.pro/images/95357c8bcf03babb2741b8c3270b374e.jpg'),
(56115, 3815, 'One Piece [L] S21 E48', 'http://sinalprivado.info:80/series/1533784/1533784/293767.mp4', 'http://timg.bdta.pro/images/3e30d59cf650e43ef05b4a42c4423e1f.jpg'),
(56116, 3815, 'One Piece [L] S21 E49', 'http://sinalprivado.info:80/series/1533784/1533784/293768.mp4', 'http://timg.bdta.pro/images/0d9bcb34edfd5cf5ca563689118e19a1.jpg'),
(56117, 3815, 'One Piece [L] S21 E50', 'http://sinalprivado.info:80/series/1533784/1533784/293769.mp4', 'http://timg.bdta.pro/images/3e6f5040b8a7e1adb7e081ba8f6b604f.jpg'),
(56118, 3815, 'One Piece [L] S21 E51', 'http://sinalprivado.info:80/series/1533784/1533784/293770.mp4', 'http://timg.bdta.pro/images/f5da5f1864ea485cdd79a078ca74d8a5.jpg'),
(56119, 3815, 'One Piece [L] S21 E52', 'http://sinalprivado.info:80/series/1533784/1533784/293771.mp4', 'http://timg.bdta.pro/images/13da226e043016abe22895ce60671f51.jpg'),
(56120, 3815, 'One Piece [L] S21 E53', 'http://sinalprivado.info:80/series/1533784/1533784/293772.mp4', 'http://timg.bdta.pro/images/e049c903d4ded1f4b03fddb3ef9586b1.jpg'),
(56121, 3815, 'One Piece [L] S21 E54', 'http://sinalprivado.info:80/series/1533784/1533784/293773.mp4', 'http://timg.bdta.pro/images/30ea9049979e8de8e50361e82d9daec9.jpg'),
(56122, 3815, 'One Piece [L] S21 E55', 'http://sinalprivado.info:80/series/1533784/1533784/293774.mp4', 'http://timg.bdta.pro/images/e925e58964abfc485c70e0eed47f44fd.jpg'),
(56123, 3815, 'One Piece [L] S21 E56', 'http://sinalprivado.info:80/series/1533784/1533784/293775.mp4', 'http://timg.bdta.pro/images/664d1b126c0d774ec6a229bb8ffd9181.jpg'),
(56124, 3815, 'One Piece [L] S21 E57', 'http://sinalprivado.info:80/series/1533784/1533784/293776.mp4', 'http://timg.bdta.pro/images/0bc8fd462f070b340437a6facd6c16b8.jpg'),
(56125, 3815, 'One Piece [L] S21 E58', 'http://sinalprivado.info:80/series/1533784/1533784/293777.mp4', 'http://timg.bdta.pro/images/1efb15270f616ee343a8d05918de6bdd.jpg'),
(56126, 3815, 'One Piece [L] S21 E59', 'http://sinalprivado.info:80/series/1533784/1533784/293778.mp4', 'http://timg.bdta.pro/images/d01836fbd6f2edf77b1ade31c7a50215.jpg'),
(56127, 3815, 'One Piece [L] S21 E60', 'http://sinalprivado.info:80/series/1533784/1533784/293779.mp4', 'http://timg.bdta.pro/images/fa58a46bd24eef8f3cbec6939fba2ed0.jpg'),
(56128, 3815, 'One Piece [L] S21 E61', 'http://sinalprivado.info:80/series/1533784/1533784/293780.mp4', 'http://timg.bdta.pro/images/056a17366cbb54c5e20c62e3359d59a5.jpg'),
(56129, 3815, 'One Piece [L] S21 E62', 'http://sinalprivado.info:80/series/1533784/1533784/293781.mp4', 'http://timg.bdta.pro/images/fa43e3516226a7adaf3fd80689e1d0a5.jpg'),
(56130, 3815, 'One Piece [L] S21 E63', 'http://sinalprivado.info:80/series/1533784/1533784/293782.mp4', 'http://timg.bdta.pro/images/5122d9f02604762b18a05e4596690d9a.jpg'),
(56131, 3815, 'One Piece [L] S21 E64', 'http://sinalprivado.info:80/series/1533784/1533784/293783.mp4', 'http://timg.bdta.pro/images/313de7e0b4dc841055ed17ef8aba36d2.jpg'),
(56132, 3815, 'One Piece [L] S21 E65', 'http://sinalprivado.info:80/series/1533784/1533784/293784.mp4', 'http://timg.bdta.pro/images/278e30a563f5dcefaad3f0aac9905b24.jpg'),
(56133, 3815, 'One Piece [L] S21 E66', 'http://sinalprivado.info:80/series/1533784/1533784/293785.mp4', 'http://timg.bdta.pro/images/63e83248cf32645b229fdd05acffb4c2.jpg'),
(56134, 3815, 'One Piece [L] S21 E67', 'http://sinalprivado.info:80/series/1533784/1533784/293786.mp4', 'http://timg.bdta.pro/images/bb36674cba11f7ce63098164e57e0bb6.jpg'),
(56135, 3815, 'One Piece [L] S21 E68', 'http://sinalprivado.info:80/series/1533784/1533784/293787.mp4', 'http://timg.bdta.pro/images/f6be79007ea135958ad94eece4b47ac2.jpg'),
(56136, 3815, 'One Piece [L] S21 E69', 'http://sinalprivado.info:80/series/1533784/1533784/293788.mp4', 'http://timg.bdta.pro/images/58cf1aad255fd578d4c14189992b0bff.jpg'),
(56137, 3815, 'One Piece [L] S21 E70', 'http://sinalprivado.info:80/series/1533784/1533784/293789.mp4', 'http://timg.bdta.pro/images/caa3ca32ebaab835879f925e2647017b.jpg'),
(56138, 3815, 'One Piece [L] S21 E71', 'http://sinalprivado.info:80/series/1533784/1533784/293790.mp4', 'http://timg.bdta.pro/images/799d0f8b81d445f9d4e5d3d641cd5352.jpg'),
(56139, 3815, 'One Piece [L] S21 E72', 'http://sinalprivado.info:80/series/1533784/1533784/293791.mp4', 'http://timg.bdta.pro/images/2152493c3e457cf75925f5d6f1edd94f.jpg'),
(56140, 3815, 'One Piece [L] S21 E73', 'http://sinalprivado.info:80/series/1533784/1533784/293792.mp4', 'http://timg.bdta.pro/images/c93175155ae529a84d2c029bd5c4e7b7.jpg'),
(56141, 3815, 'One Piece [L] S21 E74', 'http://sinalprivado.info:80/series/1533784/1533784/293793.mp4', 'http://timg.bdta.pro/images/16bbf986c777c76d33a4a8927e4e5ade.jpg'),
(56142, 3815, 'One Piece [L] S21 E75', 'http://sinalprivado.info:80/series/1533784/1533784/293794.mp4', 'http://timg.bdta.pro/images/e072f6814f1a73b8072f682fac12774a.jpg'),
(56143, 3815, 'One Piece [L] S21 E76', 'http://sinalprivado.info:80/series/1533784/1533784/293795.mp4', 'http://timg.bdta.pro/images/f15107f1f9b0b43694f8f96cc4c15dff.jpg'),
(56144, 3815, 'One Piece [L] S21 E77', 'http://sinalprivado.info:80/series/1533784/1533784/293796.mp4', 'http://timg.bdta.pro/images/ae36446eb4635944f86a637062fa7cf1.jpg'),
(56145, 3815, 'One Piece [L] S21 E78', 'http://sinalprivado.info:80/series/1533784/1533784/293797.mp4', 'http://timg.bdta.pro/images/31ca1534655e173b460b514d2e703c21.jpg'),
(56146, 3815, 'One Piece [L] S21 E79', 'http://sinalprivado.info:80/series/1533784/1533784/293798.mp4', 'http://timg.bdta.pro/images/ecb0f5a9a933521bea4e1b38664a3ada.jpg'),
(56147, 3815, 'One Piece [L] S21 E80', 'http://sinalprivado.info:80/series/1533784/1533784/293799.mp4', 'http://timg.bdta.pro/images/f4e00b4ee8b6c5b1f203087c56606976.jpg'),
(56148, 3815, 'One Piece [L] S21 E81', 'http://sinalprivado.info:80/series/1533784/1533784/293800.mp4', 'http://timg.bdta.pro/images/ecfa24945bba621d1402accee8d8ea7b.jpg'),
(56149, 3815, 'One Piece [L] S21 E82', 'http://sinalprivado.info:80/series/1533784/1533784/293801.mp4', 'http://timg.bdta.pro/images/7cd4ddf7bb661b34d19ac8964c7be06f.jpg'),
(56150, 3815, 'One Piece [L] S21 E83', 'http://sinalprivado.info:80/series/1533784/1533784/293802.mp4', 'http://timg.bdta.pro/images/dc40256965a1e960327b893efe057c86.jpg'),
(56151, 3815, 'One Piece [L] S21 E84', 'http://sinalprivado.info:80/series/1533784/1533784/293803.mp4', 'http://timg.bdta.pro/images/770ea7541e75b19d44d003488b864b2c.jpg'),
(56152, 3815, 'One Piece [L] S21 E85', 'http://sinalprivado.info:80/series/1533784/1533784/293804.mp4', 'http://timg.bdta.pro/images/213212edc10cfc8142e0c2dc7941cee4.jpg'),
(56153, 3815, 'One Piece [L] S21 E86', 'http://sinalprivado.info:80/series/1533784/1533784/293805.mp4', 'http://timg.bdta.pro/images/9f1192e7d80d7690bf143be48b5e373d.jpg'),
(56154, 3815, 'One Piece [L] S21 E87', 'http://sinalprivado.info:80/series/1533784/1533784/293806.mp4', 'http://timg.bdta.pro/images/9656a4974a0a112925fde4d670e8bc86.jpg'),
(56155, 3815, 'One Piece [L] S21 E88', 'http://sinalprivado.info:80/series/1533784/1533784/293807.mp4', 'http://timg.bdta.pro/images/90ce192b4e2bfab35c3a3bd9746fc8df.jpg'),
(56156, 3815, 'One Piece [L] S21 E89', 'http://sinalprivado.info:80/series/1533784/1533784/293808.mp4', 'http://timg.bdta.pro/images/5d8eab28e993d382ecd391bacfe6b62d.jpg'),
(56157, 3815, 'One Piece [L] S21 E90', 'http://sinalprivado.info:80/series/1533784/1533784/293809.mp4', 'http://timg.bdta.pro/images/8ca62e7f7a4c5c6e307d9bb626b9e556.jpg'),
(56158, 3815, 'One Piece [L] S21 E91', 'http://sinalprivado.info:80/series/1533784/1533784/293810.mp4', 'http://timg.bdta.pro/images/1de495c71cdf7b60b70b13e5374b6ebe.jpg'),
(56159, 3815, 'One Piece [L] S21 E92', 'http://sinalprivado.info:80/series/1533784/1533784/293811.mp4', 'http://timg.bdta.pro/images/2e968e0827ae73645afac8b0bd5ec564.jpg'),
(56160, 3815, 'One Piece [L] S21 E93', 'http://sinalprivado.info:80/series/1533784/1533784/293812.mp4', 'http://timg.bdta.pro/images/2ff1c35fcd45d564aee28be4a864f8a4.jpg'),
(56161, 3815, 'One Piece [L] S21 E94', 'http://sinalprivado.info:80/series/1533784/1533784/293813.mp4', 'http://timg.bdta.pro/images/d4d3ec1c474f4eb57c4ea0f28eb3ef80.jpg'),
(56162, 3815, 'One Piece [L] S21 E95', 'http://sinalprivado.info:80/series/1533784/1533784/293814.mp4', 'http://timg.bdta.pro/images/80a386383eef75ee2654a62e256cc759.jpg'),
(56163, 3815, 'One Piece [L] S21 E96', 'http://sinalprivado.info:80/series/1533784/1533784/293815.mp4', 'http://timg.bdta.pro/images/14ac8813bb324e041bc799e3650681fb.jpg'),
(56164, 3815, 'One Piece [L] S21 E97', 'http://sinalprivado.info:80/series/1533784/1533784/293816.mp4', 'http://timg.bdta.pro/images/e2e30ef49edb3846f255e8393b5ce835.jpg'),
(56165, 3815, 'One Piece [L] S21 E98', 'http://sinalprivado.info:80/series/1533784/1533784/293817.mp4', 'http://timg.bdta.pro/images/34324e0298391628d25ebd9275a8d2c9.jpg'),
(56166, 3815, 'One Piece [L] S21 E99', 'http://sinalprivado.info:80/series/1533784/1533784/293818.mp4', 'http://timg.bdta.pro/images/622cfa7ce33ac244719579b4db28e043.jpg'),
(56167, 3815, 'One Piece [L] S21 E100', 'http://sinalprivado.info:80/series/1533784/1533784/293819.mp4', 'http://timg.bdta.pro/images/a07d76dfffb72450327a67353650da90.jpg'),
(56168, 3815, 'One Piece [L] S21 E101', 'http://sinalprivado.info:80/series/1533784/1533784/293820.mp4', 'http://timg.bdta.pro/images/c60d39ab27531b50fc123a521161ddc1.jpg'),
(56169, 3815, 'One Piece [L] S21 E102', 'http://sinalprivado.info:80/series/1533784/1533784/293821.mp4', 'http://timg.bdta.pro/images/9a5a8904c6188d00b29319b26fe44c5e.jpg'),
(56170, 3815, 'One Piece [L] S21 E103', 'http://sinalprivado.info:80/series/1533784/1533784/293822.mp4', 'http://timg.bdta.pro/images/caa6260b0750d3c63e4daf0e068e7fe7.jpg'),
(56171, 3815, 'One Piece [L] S21 E104', 'http://sinalprivado.info:80/series/1533784/1533784/293823.mp4', 'http://timg.bdta.pro/images/8e768f5f71b51bf545e1f93d69e3bdb3.jpg'),
(56172, 3815, 'One Piece [L] S21 E105', 'http://sinalprivado.info:80/series/1533784/1533784/293824.mp4', 'http://timg.bdta.pro/images/96faabae15fea1173db814ffe9c265cc.jpg'),
(56173, 3815, 'One Piece [L] S21 E106', 'http://sinalprivado.info:80/series/1533784/1533784/293825.mp4', 'http://timg.bdta.pro/images/8731ec03293560acae7ef4205b208497.jpg'),
(56174, 3815, 'One Piece [L] S21 E107', 'http://sinalprivado.info:80/series/1533784/1533784/293826.mp4', 'http://timg.bdta.pro/images/078df0d98f4301c749a45d6ebb0879f0.jpg'),
(56175, 3815, 'One Piece [L] S21 E108', 'http://sinalprivado.info:80/series/1533784/1533784/293827.mp4', 'http://timg.bdta.pro/images/7df65699587389e56a456034b497b95d.jpg'),
(56176, 3815, 'One Piece [L] S21 E109', 'http://sinalprivado.info:80/series/1533784/1533784/293828.mp4', 'http://timg.bdta.pro/images/3066bb3f8912f8517b687c074d23e240.jpg'),
(56177, 3815, 'One Piece [L] S21 E110', 'http://sinalprivado.info:80/series/1533784/1533784/293829.mp4', 'http://timg.bdta.pro/images/ca9aa723a48c8079ead92265a41206c5.jpg'),
(56178, 3815, 'One Piece [L] S21 E111', 'http://sinalprivado.info:80/series/1533784/1533784/293830.mp4', 'http://timg.bdta.pro/images/f76a728669ba2d0ff16ad2d96c4389e5.jpg'),
(56179, 3815, 'One Piece [L] S21 E112', 'http://sinalprivado.info:80/series/1533784/1533784/293831.mp4', 'http://timg.bdta.pro/images/2778fe6700779b21fb34a7770d3f34d1.jpg'),
(56180, 3815, 'One Piece [L] S21 E113', 'http://sinalprivado.info:80/series/1533784/1533784/293832.mp4', 'http://timg.bdta.pro/images/38a9041dd85ca2d0eaaa592dc82828d9.jpg'),
(56181, 3815, 'One Piece [L] S21 E114', 'http://sinalprivado.info:80/series/1533784/1533784/293833.mp4', 'http://timg.bdta.pro/images/95def8f3312a8a31557922c4de53b21e.jpg'),
(56182, 3815, 'One Piece [L] S21 E115', 'http://sinalprivado.info:80/series/1533784/1533784/293834.mp4', 'http://timg.bdta.pro/images/222268ebef0bd0a7b191ec06845ec680.jpg'),
(56183, 3815, 'One Piece [L] S21 E116', 'http://sinalprivado.info:80/series/1533784/1533784/293835.mp4', 'http://timg.bdta.pro/images/b6db783deaf34c3ee2e059573c510bcc.jpg'),
(56184, 3815, 'One Piece [L] S21 E117', 'http://sinalprivado.info:80/series/1533784/1533784/293836.mp4', 'http://timg.bdta.pro/images/8611212d37996c4de19b200244b8a0a2.jpg'),
(56185, 3815, 'One Piece [L] S21 E118', 'http://sinalprivado.info:80/series/1533784/1533784/293837.mp4', 'http://timg.bdta.pro/images/0f0013d457e0abcc05783c4775d8a0cc.jpg'),
(56186, 3815, 'One Piece [L] S21 E119', 'http://sinalprivado.info:80/series/1533784/1533784/293838.mp4', 'http://timg.bdta.pro/images/6178c455e0317925989503b13c5c7d04.jpg'),
(56187, 3815, 'One Piece [L] S21 E120', 'http://sinalprivado.info:80/series/1533784/1533784/293839.mp4', 'http://timg.bdta.pro/images/767a4015b5728a83cbb8b2ea78b0f1d2.jpg'),
(56188, 3815, 'One Piece [L] S21 E121', 'http://sinalprivado.info:80/series/1533784/1533784/293840.mp4', 'http://timg.bdta.pro/images/1bc26f69c3978897d75da0db94950b0b.jpg'),
(56189, 3815, 'One Piece [L] S21 E122', 'http://sinalprivado.info:80/series/1533784/1533784/293841.mp4', 'http://timg.bdta.pro/images/1ca7b18d9b33524d5c361ac987fd3031.jpg'),
(56190, 3815, 'One Piece [L] S21 E123', 'http://sinalprivado.info:80/series/1533784/1533784/293842.mp4', 'http://timg.bdta.pro/images/35eb43f03ae8542d369f88da4b68f0ec.jpg'),
(56191, 3815, 'One Piece [L] S21 E124', 'http://sinalprivado.info:80/series/1533784/1533784/293843.mp4', 'http://timg.bdta.pro/images/8d5c750bfc74d70bee06cc3158914b21.jpg'),
(56192, 3815, 'One Piece [L] S21 E125', 'http://sinalprivado.info:80/series/1533784/1533784/293844.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56193, 3815, 'One Piece [L] S21 E126', 'http://sinalprivado.info:80/series/1533784/1533784/293845.mp4', 'http://timg.bdta.pro/images/64cddbc7761612c7016bb8225d69af63.jpg'),
(56194, 3815, 'One Piece [L] S21 E127', 'http://sinalprivado.info:80/series/1533784/1533784/293846.mp4', 'http://timg.bdta.pro/images/97126f3c556d991adb4ee3210a389ca1.jpg'),
(56195, 3815, 'One Piece [L] S21 E128', 'http://sinalprivado.info:80/series/1533784/1533784/293847.mp4', 'http://timg.bdta.pro/images/67d7f285210a13240bd553b1edb340a2.jpg'),
(56196, 3815, 'One Piece [L] S21 E129', 'http://sinalprivado.info:80/series/1533784/1533784/293848.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56197, 3815, 'One Piece [L] S21 E130', 'http://sinalprivado.info:80/series/1533784/1533784/293849.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56198, 3815, 'One Piece [L] S21 E131', 'http://sinalprivado.info:80/series/1533784/1533784/293850.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56199, 3815, 'One Piece [L] S21 E132', 'http://sinalprivado.info:80/series/1533784/1533784/293851.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56200, 3815, 'One Piece [L] S21 E133', 'http://sinalprivado.info:80/series/1533784/1533784/293852.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56201, 3815, 'One Piece [L] S21 E134', 'http://sinalprivado.info:80/series/1533784/1533784/293853.mp4', 'http://timg.bdta.pro/images/7b1965d9c94c79b926db814cfa5ae670.jpg'),
(56202, 3815, 'One Piece [L] S21 E135', 'http://sinalprivado.info:80/series/1533784/1533784/293854.mp4', 'http://timg.bdta.pro/images/d52a7b19ffab85f5ed365285086a0504.jpg'),
(56203, 3815, 'One Piece [L] S21 E136', 'http://sinalprivado.info:80/series/1533784/1533784/293855.mp4', 'http://timg.bdta.pro/images/95edd0bd7609533445fbaf0ee5522c21.jpg'),
(56204, 3815, 'One Piece [L] S21 E137', 'http://sinalprivado.info:80/series/1533784/1533784/293856.mp4', 'http://timg.bdta.pro/images/76e2eef53e0e3b3b90756aa798b6eb1f.jpg'),
(56205, 3815, 'One Piece [L] S21 E138', 'http://sinalprivado.info:80/series/1533784/1533784/293857.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56206, 3815, 'One Piece [L] S21 E139', 'http://sinalprivado.info:80/series/1533784/1533784/293858.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56207, 3815, 'One Piece [L] S21 E140', 'http://sinalprivado.info:80/series/1533784/1533784/293859.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56208, 3815, 'One Piece [L] S21 E141', 'http://sinalprivado.info:80/series/1533784/1533784/293860.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56209, 3815, 'One Piece [L] S21 E142', 'http://sinalprivado.info:80/series/1533784/1533784/293861.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56210, 3815, 'One Piece [L] S21 E143', 'http://sinalprivado.info:80/series/1533784/1533784/293862.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56211, 3815, 'One Piece [L] S21 E144', 'http://sinalprivado.info:80/series/1533784/1533784/293863.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56212, 3815, 'One Piece [L] S21 E145', 'http://sinalprivado.info:80/series/1533784/1533784/293864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ux3oZ1wYAGEeHHRtFMjCca6mVjH.jpg'),
(56213, 3815, 'One Piece [L] S21 E146', 'http://sinalprivado.info:80/series/1533784/1533784/293865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mhPxMpAbcaIugvHMzEEvIeeL3wH.jpg'),
(56214, 3815, 'One Piece [L] S21 E147', 'http://sinalprivado.info:80/series/1533784/1533784/293866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lka8HyYILqAgatRIQlo1fGjwPxL.jpg'),
(56215, 3815, 'One Piece [L] S21 E148', 'http://sinalprivado.info:80/series/1533784/1533784/293867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3KOhU9P4C2d6h1jhrwGAHunv8Zt.jpg'),
(56216, 3815, 'One Piece [L] S21 E149', 'http://sinalprivado.info:80/series/1533784/1533784/293868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7scjNYMQwGcfHP7QSayKTthHduZ.jpg'),
(56217, 3815, 'One Piece [L] S21 E150', 'http://sinalprivado.info:80/series/1533784/1533784/293869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6G8uCrtDWmc2rlVIEnsHvASO4bC.jpg'),
(56218, 3815, 'One Piece [L] S21 E151', 'http://sinalprivado.info:80/series/1533784/1533784/293870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/62cjboPSFVpwqQIaaRB7lUri9rK.jpg'),
(56219, 3815, 'One Piece [L] S21 E152', 'http://sinalprivado.info:80/series/1533784/1533784/293871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5eEVzgbWl65z1BoeAhOwPix7oGf.jpg'),
(56220, 3815, 'One Piece [L] S21 E153', 'http://sinalprivado.info:80/series/1533784/1533784/293872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dDX4t0UFHJoHTw7HLQSoyqioAig.jpg'),
(56221, 3815, 'One Piece [L] S21 E154', 'http://sinalprivado.info:80/series/1533784/1533784/293873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qUihSjNlaXmx6wXHJsbiaZlnUqA.jpg'),
(56222, 3815, 'One Piece [L] S21 E155', 'http://sinalprivado.info:80/series/1533784/1533784/293874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uf5Lt8sZnG4RP0u4tvyWewZjGTP.jpg'),
(56223, 3815, 'One Piece [L] S21 E156', 'http://sinalprivado.info:80/series/1533784/1533784/293875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xAQq8smCGJJ9tv0Pq1SgKYRSQue.jpg'),
(56224, 3815, 'One Piece [L] S21 E157', 'http://sinalprivado.info:80/series/1533784/1533784/293876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xqvlK5QcD3upyM7pcWVaBZDl1PZ.jpg'),
(56225, 3815, 'One Piece [L] S21 E158', 'http://sinalprivado.info:80/series/1533784/1533784/293877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/90yJhc9qEoBdoMvn4QvTux4NPWz.jpg'),
(56226, 3815, 'One Piece [L] S21 E159', 'http://sinalprivado.info:80/series/1533784/1533784/293878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jAsLhDpUYZwccNBiQ1LAaKthwIq.jpg'),
(56227, 3815, 'One Piece [L] S21 E160', 'http://sinalprivado.info:80/series/1533784/1533784/293879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ubIw8qdxR65PGP5jYOLxCEPqvm.jpg'),
(56228, 3815, 'One Piece [L] S21 E161', 'http://sinalprivado.info:80/series/1533784/1533784/293880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1wRF8WvB1r7mVFAbkNw13miAedK.jpg'),
(56229, 3815, 'One Piece [L] S21 E162', 'http://sinalprivado.info:80/series/1533784/1533784/293881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ghBlYx4IugT3JpdATgDnv32t6C5.jpg'),
(56230, 3815, 'One Piece [L] S21 E163', 'http://sinalprivado.info:80/series/1533784/1533784/293882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9twT1EdLZfWB4OPouQvkA3g1zrN.jpg'),
(56231, 3815, 'One Piece [L] S21 E164', 'http://sinalprivado.info:80/series/1533784/1533784/293883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6DvnrYHJ8M8nf3pFLl0NAkxrpt.jpg'),
(56232, 3815, 'One Piece [L] S21 E165', 'http://sinalprivado.info:80/series/1533784/1533784/293884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nCqt4iyHTVlWKOTQ8lvOZSz7Xq2.jpg'),
(56233, 3815, 'One Piece [L] S21 E166', 'http://sinalprivado.info:80/series/1533784/1533784/293885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/abWSyxHjiuxXVyuIbWL7c4hact9.jpg'),
(56234, 3815, 'One Piece [L] S21 E167', 'http://sinalprivado.info:80/series/1533784/1533784/293886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybQBP9haPD0fg8ePldgx659GwxD.jpg'),
(56235, 3815, 'One Piece [L] S21 E168', 'http://sinalprivado.info:80/series/1533784/1533784/293887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o7sWNBRtVdQ3l6LRwKttZM49uk9.jpg'),
(56236, 3815, 'One Piece [L] S21 E169', 'http://sinalprivado.info:80/series/1533784/1533784/293888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hH8hV4lWS3Xs7DLDcEWSxiD0TVk.jpg'),
(56237, 3815, 'One Piece [L] S21 E170', 'http://sinalprivado.info:80/series/1533784/1533784/293889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qM9kE9mvDZz6CEKcSYgQ85PYJRD.jpg'),
(56238, 3815, 'One Piece [L] S21 E171', 'http://sinalprivado.info:80/series/1533784/1533784/293890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sAG7kN1KQTQn2bjgJOInzrBTng7.jpg'),
(56239, 3815, 'One Piece [L] S21 E172', 'http://sinalprivado.info:80/series/1533784/1533784/293891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mGIomMWAI4PzuROG2JJQGzeAzOD.jpg'),
(56240, 3815, 'One Piece [L] S21 E173', 'http://sinalprivado.info:80/series/1533784/1533784/293892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jKMz7UIc5tggTYNkxmgshdKkL4G.jpg'),
(56241, 3815, 'One Piece [L] S21 E174', 'http://sinalprivado.info:80/series/1533784/1533784/293893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cUhX3i7JpYVyXu5GXag0pq1oK51.jpg'),
(56242, 3815, 'One Piece [L] S21 E175', 'http://sinalprivado.info:80/series/1533784/1533784/293894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Ifc5yiCyiKyTauwgzKDJVx2kiH.jpg'),
(56243, 3815, 'One Piece [L] S21 E176', 'http://sinalprivado.info:80/series/1533784/1533784/293895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/flwzF5iZFtEPru2t23xebmEv0ap.jpg'),
(56244, 3815, 'One Piece [L] S21 E177', 'http://sinalprivado.info:80/series/1533784/1533784/293896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2gP9F7apwE4MxUpaXxqqjy65wc.jpg'),
(56245, 3815, 'One Piece [L] S21 E178', 'http://sinalprivado.info:80/series/1533784/1533784/293897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3IZIEkDdIwLgPYKum3VAKQivDjl.jpg'),
(56246, 3815, 'One Piece [L] S21 E179', 'http://sinalprivado.info:80/series/1533784/1533784/293898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fK3xztzpcwJCO2kutCAnrDtiGKM.jpg'),
(56247, 3815, 'One Piece [L] S21 E180', 'http://sinalprivado.info:80/series/1533784/1533784/293899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvNDGy23Bp6crhEgkP6vZVAs8nn.jpg'),
(56248, 3815, 'One Piece [L] S21 E181', 'http://sinalprivado.info:80/series/1533784/1533784/293900.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56249, 3815, 'One Piece [L] S21 E182', 'http://sinalprivado.info:80/series/1533784/1533784/293901.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56250, 3815, 'One Piece [L] S21 E183', 'http://sinalprivado.info:80/series/1533784/1533784/293902.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56251, 3815, 'One Piece [L] S21 E184', 'http://sinalprivado.info:80/series/1533784/1533784/293903.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56252, 3815, 'One Piece [L] S21 E185', 'http://sinalprivado.info:80/series/1533784/1533784/293904.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56253, 3815, 'One Piece [L] S21 E186', 'http://sinalprivado.info:80/series/1533784/1533784/293905.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56254, 3815, 'One Piece [L] S21 E187', 'http://sinalprivado.info:80/series/1533784/1533784/293906.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56255, 3815, 'One Piece [L] S21 E188', 'http://sinalprivado.info:80/series/1533784/1533784/293907.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56256, 3815, 'One Piece [L] S21 E189', 'http://sinalprivado.info:80/series/1533784/1533784/293908.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56257, 3815, 'One Piece [L] S21 E190', 'http://sinalprivado.info:80/series/1533784/1533784/293909.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56258, 3815, 'One Piece [L] S21 E191', 'http://sinalprivado.info:80/series/1533784/1533784/293910.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56259, 3815, 'One Piece [L] S21 E192', 'http://sinalprivado.info:80/series/1533784/1533784/293911.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56260, 3815, 'One Piece [L] S21 E193', 'http://sinalprivado.info:80/series/1533784/1533784/293912.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56261, 3815, 'One Piece [L] S21 E194', 'http://sinalprivado.info:80/series/1533784/1533784/293913.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56262, 3815, 'One Piece [L] S21 E195', 'http://sinalprivado.info:80/series/1533784/1533784/293914.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56263, 3815, 'One Piece [L] S21 E196', 'http://sinalprivado.info:80/series/1533784/1533784/293915.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56264, 3815, 'One Piece [L] S21 E197', 'http://sinalprivado.info:80/series/1533784/1533784/293916.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56265, 3815, 'One Piece [L] S21 E198', 'http://sinalprivado.info:80/series/1533784/1533784/293917.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56266, 3815, 'One Piece [L] S21 E199', 'http://sinalprivado.info:80/series/1533784/1533784/293918.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56267, 3815, 'One Piece [L] S21 E200', 'http://sinalprivado.info:80/series/1533784/1533784/293919.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56268, 3815, 'One Piece [L] S21 E201', 'http://sinalprivado.info:80/series/1533784/1533784/293920.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56269, 3815, 'One Piece [L] S21 E202', 'http://sinalprivado.info:80/series/1533784/1533784/293921.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56270, 3815, 'One Piece [L] S21 E203', 'http://sinalprivado.info:80/series/1533784/1533784/293922.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56271, 3815, 'One Piece [L] S21 E204', 'http://sinalprivado.info:80/series/1533784/1533784/302468.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56272, 3815, 'One Piece [L] S21 E205', 'http://sinalprivado.info:80/series/1533784/1533784/308526.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56273, 3815, 'One Piece [L] S21 E206', 'http://sinalprivado.info:80/series/1533784/1533784/315583.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56274, 3815, 'One Piece [L] S21 E207', 'http://sinalprivado.info:80/series/1533784/1533784/322441.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56275, 3815, 'One Piece [L] S21 E208', 'http://sinalprivado.info:80/series/1533784/1533784/330523.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56276, 3815, 'One Piece [L] S21 E209', 'http://sinalprivado.info:80/series/1533784/1533784/338396.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56277, 3815, 'One Piece [L] S21 E210', 'http://sinalprivado.info:80/series/1533784/1533784/344928.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56278, 3815, 'One Piece [L] S21 E211', 'http://sinalprivado.info:80/series/1533784/1533784/356089.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56279, 3815, 'One Piece [L] S21 E212', 'http://sinalprivado.info:80/series/1533784/1533784/356090.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56280, 3815, 'One Piece [L] S21 E213', 'http://sinalprivado.info:80/series/1533784/1533784/362563.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56281, 3815, 'One Piece [L] S21 E214', 'http://sinalprivado.info:80/series/1533784/1533784/367251.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56282, 3815, 'One Piece [L] S21 E215', 'http://sinalprivado.info:80/series/1533784/1533784/377733.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56283, 3815, 'One Piece [L] S21 E216', 'http://sinalprivado.info:80/series/1533784/1533784/392335.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56284, 3815, 'One Piece [L] S21 E217', 'http://sinalprivado.info:80/series/1533784/1533784/395779.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56285, 3815, 'One Piece [L] S21 E218', 'http://sinalprivado.info:80/series/1533784/1533784/402839.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56286, 3815, 'One Piece [L] S21 E219', 'http://sinalprivado.info:80/series/1533784/1533784/408440.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56287, 3815, 'One Piece [L] S21 E220', 'http://sinalprivado.info:80/series/1533784/1533784/419389.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56288, 3815, 'One Piece [L] S21 E221', 'http://sinalprivado.info:80/series/1533784/1533784/424422.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56289, 3815, 'One Piece [L] S21 E222', 'http://sinalprivado.info:80/series/1533784/1533784/432074.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56290, 3815, 'One Piece [L] S21 E223', 'http://sinalprivado.info:80/series/1533784/1533784/434381.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56291, 3815, 'One Piece [L] S21 E224', 'http://sinalprivado.info:80/series/1533784/1533784/460542.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56292, 3815, 'One Piece [L] S21 E225', 'http://sinalprivado.info:80/series/1533784/1533784/460543.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56293, 3815, 'One Piece [L] S21 E226', 'http://sinalprivado.info:80/series/1533784/1533784/473836.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56294, 3815, 'One Piece [L] S21 E227', 'http://sinalprivado.info:80/series/1533784/1533784/477238.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56295, 3816, 'One Piece [L] S22 E01', 'http://sinalprivado.info:80/series/1533784/1533784/482381.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56296, 3816, 'One Piece [L] S22 E02', 'http://sinalprivado.info:80/series/1533784/1533784/482382.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56297, 3816, 'One Piece [L] S22 E03', 'http://sinalprivado.info:80/series/1533784/1533784/482383.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56298, 3816, 'One Piece [L] S22 E04', 'http://sinalprivado.info:80/series/1533784/1533784/482384.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56299, 3816, 'One Piece [L] S22 E05', 'http://sinalprivado.info:80/series/1533784/1533784/482385.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56300, 3816, 'One Piece [L] S22 E06', 'http://sinalprivado.info:80/series/1533784/1533784/482386.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56301, 3816, 'One Piece [L] S22 E07', 'http://sinalprivado.info:80/series/1533784/1533784/482387.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56302, 3816, 'One Piece [L] S22 E08', 'http://sinalprivado.info:80/series/1533784/1533784/482388.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56303, 3816, 'One Piece [L] S22 E09', 'http://sinalprivado.info:80/series/1533784/1533784/482389.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56304, 3816, 'One Piece [L] S22 E10', 'http://sinalprivado.info:80/series/1533784/1533784/482390.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56305, 3816, 'One Piece [L] S22 E11', 'http://sinalprivado.info:80/series/1533784/1533784/482391.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56306, 3816, 'One Piece [L] S22 E12', 'http://sinalprivado.info:80/series/1533784/1533784/482392.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56307, 3816, 'One Piece [L] S22 E13', 'http://sinalprivado.info:80/series/1533784/1533784/482393.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56308, 3816, 'One Piece [L] S22 E14', 'http://sinalprivado.info:80/series/1533784/1533784/482394.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56309, 3816, 'One Piece [L] S22 E15', 'http://sinalprivado.info:80/series/1533784/1533784/482395.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56310, 3816, 'One Piece [L] S22 E16', 'http://sinalprivado.info:80/series/1533784/1533784/482396.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56311, 3816, 'One Piece [L] S22 E17', 'http://sinalprivado.info:80/series/1533784/1533784/482397.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56312, 3816, 'One Piece [L] S22 E18', 'http://sinalprivado.info:80/series/1533784/1533784/482398.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56313, 3816, 'One Piece [L] S22 E19', 'http://sinalprivado.info:80/series/1533784/1533784/482399.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56314, 3816, 'One Piece [L] S22 E20', 'http://sinalprivado.info:80/series/1533784/1533784/482400.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56315, 3816, 'One Piece [L] S22 E21', 'http://sinalprivado.info:80/series/1533784/1533784/482401.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56316, 3816, 'One Piece [L] S22 E22', 'http://sinalprivado.info:80/series/1533784/1533784/482402.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56317, 3816, 'One Piece [L] S22 E23', 'http://sinalprivado.info:80/series/1533784/1533784/482403.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56318, 3816, 'One Piece [L] S22 E24', 'http://sinalprivado.info:80/series/1533784/1533784/482404.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56319, 3816, 'One Piece [L] S22 E25', 'http://sinalprivado.info:80/series/1533784/1533784/482405.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56320, 3816, 'One Piece [L] S22 E26', 'http://sinalprivado.info:80/series/1533784/1533784/482406.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56321, 3816, 'One Piece [L] S22 E27', 'http://sinalprivado.info:80/series/1533784/1533784/482407.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56322, 3816, 'One Piece [L] S22 E28', 'http://sinalprivado.info:80/series/1533784/1533784/482408.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56323, 3816, 'One Piece [L] S22 E29', 'http://sinalprivado.info:80/series/1533784/1533784/482409.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56324, 3816, 'One Piece [L] S22 E30', 'http://sinalprivado.info:80/series/1533784/1533784/482410.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56325, 3816, 'One Piece [L] S22 E31', 'http://sinalprivado.info:80/series/1533784/1533784/482411.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56326, 3816, 'One Piece [L] S22 E32', 'http://sinalprivado.info:80/series/1533784/1533784/482412.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56327, 3816, 'One Piece [L] S22 E33', 'http://sinalprivado.info:80/series/1533784/1533784/482413.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56328, 3816, 'One Piece [L] S22 E34', 'http://sinalprivado.info:80/series/1533784/1533784/482414.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56329, 3816, 'One Piece [L] S22 E35', 'http://sinalprivado.info:80/series/1533784/1533784/759836.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56330, 3816, 'One Piece [L] S22 E36', 'http://sinalprivado.info:80/series/1533784/1533784/759837.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56331, 3816, 'One Piece [L] S22 E37', 'http://sinalprivado.info:80/series/1533784/1533784/765536.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56332, 3816, 'One Piece [L] S22 E38', 'http://sinalprivado.info:80/series/1533784/1533784/773957.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56333, 3816, 'One Piece [L] S22 E39', 'http://sinalprivado.info:80/series/1533784/1533784/783152.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56334, 3816, 'One Piece [L] S22 E40', 'http://sinalprivado.info:80/series/1533784/1533784/792940.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56335, 3816, 'One Piece [L] S22 E41', 'http://sinalprivado.info:80/series/1533784/1533784/805022.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56336, 3816, 'One Piece [L] S22 E42', 'http://sinalprivado.info:80/series/1533784/1533784/808283.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56337, 3816, 'One Piece [L] S22 E43', 'http://sinalprivado.info:80/series/1533784/1533784/819769.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56338, 3816, 'One Piece [L] S22 E44', 'http://sinalprivado.info:80/series/1533784/1533784/832064.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56339, 3816, 'One Piece [L] S22 E45', 'http://sinalprivado.info:80/series/1533784/1533784/840763.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56340, 3816, 'One Piece [L] S22 E46', 'http://sinalprivado.info:80/series/1533784/1533784/858866.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56341, 3816, 'One Piece [L] S22 E47', 'http://sinalprivado.info:80/series/1533784/1533784/861655.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56342, 3816, 'One Piece [L] S22 E48', 'http://sinalprivado.info:80/series/1533784/1533784/867762.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56343, 3816, 'One Piece [L] S22 E49', 'http://sinalprivado.info:80/series/1533784/1533784/876360.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56344, 3816, 'One Piece [L] S22 E50', 'http://sinalprivado.info:80/series/1533784/1533784/879565.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56345, 3816, 'One Piece [L] S22 E51', 'http://sinalprivado.info:80/series/1533784/1533784/880029.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56346, 3816, 'One Piece [L] S22 E52', 'http://sinalprivado.info:80/series/1533784/1533784/880856.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56347, 3816, 'One Piece [L] S22 E53', 'http://sinalprivado.info:80/series/1533784/1533784/881446.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56348, 3816, 'One Piece [L] S22 E54', 'http://sinalprivado.info:80/series/1533784/1533784/882114.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56349, 3816, 'One Piece [L] S22 E55', 'http://sinalprivado.info:80/series/1533784/1533784/884017.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56350, 3816, 'One Piece [L] S22 E56', 'http://sinalprivado.info:80/series/1533784/1533784/885655.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56351, 3816, 'One Piece [L] S22 E57', 'http://sinalprivado.info:80/series/1533784/1533784/887258.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56352, 3816, 'One Piece [L] S22 E58', 'http://sinalprivado.info:80/series/1533784/1533784/889663.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(56353, 3816, 'One Piece [L] S22 E59', 'http://sinalprivado.info:80/series/1533784/1533784/889983.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56354, 3816, 'One Piece [L] S22 E60', 'http://sinalprivado.info:80/series/1533784/1533784/890963.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56355, 3816, 'One Piece [L] S22 E61', 'http://sinalprivado.info:80/series/1533784/1533784/892167.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56356, 3816, 'One Piece [L] S22 E62', 'http://sinalprivado.info:80/series/1533784/1533784/892573.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56357, 3816, 'One Piece [L] S22 E63', 'http://sinalprivado.info:80/series/1533784/1533784/893518.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56358, 3816, 'One Piece [L] S22 E64', 'http://sinalprivado.info:80/series/1533784/1533784/894803.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56359, 3816, 'One Piece [L] S22 E65', 'http://sinalprivado.info:80/series/1533784/1533784/896194.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56360, 3816, 'One Piece [L] S22 E66', 'http://sinalprivado.info:80/series/1533784/1533784/896892.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56361, 3816, 'One Piece [L] S22 E67', 'http://sinalprivado.info:80/series/1533784/1533784/897375.mp4', 'http://gstaticontent.com/images/oag7edI9flSMawmNySEiSEJAbrf_big.jpg'),
(56362, 3817, 'Perdida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147540.mp4', 'http://gstaticontent.com/images/v4kNHEq0pMxMMfmpLOyp6h1C8m1_big.jpg'),
(56363, 3817, 'Perdida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147541.mp4', 'http://gstaticontent.com/images/v4kNHEq0pMxMMfmpLOyp6h1C8m1_big.jpg'),
(56364, 3817, 'Perdida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147542.mp4', 'http://gstaticontent.com/images/v4kNHEq0pMxMMfmpLOyp6h1C8m1_big.jpg'),
(56365, 3817, 'Perdida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147543.mp4', 'http://gstaticontent.com/images/v4kNHEq0pMxMMfmpLOyp6h1C8m1_big.jpg'),
(56366, 3817, 'Perdida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147544.mp4', 'http://gstaticontent.com/images/v4kNHEq0pMxMMfmpLOyp6h1C8m1_big.jpg'),
(56367, 3817, 'Perdida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147545.mp4', 'http://gstaticontent.com/images/v4kNHEq0pMxMMfmpLOyp6h1C8m1_big.jpg'),
(56368, 3817, 'Perdida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147546.mp4', 'http://gstaticontent.com/images/v4kNHEq0pMxMMfmpLOyp6h1C8m1_big.jpg'),
(56369, 3817, 'Perdida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147547.mp4', 'http://gstaticontent.com/images/v4kNHEq0pMxMMfmpLOyp6h1C8m1_big.jpg'),
(56370, 3817, 'Perdida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147548.mp4', 'http://gstaticontent.com/images/v4kNHEq0pMxMMfmpLOyp6h1C8m1_big.jpg'),
(56371, 3817, 'Perdida S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147549.mp4', 'http://gstaticontent.com/images/v4kNHEq0pMxMMfmpLOyp6h1C8m1_big.jpg'),
(56372, 3817, 'Perdida S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147550.mp4', 'http://gstaticontent.com/images/v4kNHEq0pMxMMfmpLOyp6h1C8m1_big.jpg'),
(56373, 3818, 'o ETeimoso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147335.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56374, 3818, 'o ETeimoso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147336.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56375, 3818, 'o ETeimoso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147337.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56376, 3818, 'o ETeimoso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147338.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56377, 3818, 'o ETeimoso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147339.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56378, 3818, 'o ETeimoso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147340.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56379, 3818, 'o ETeimoso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147341.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56380, 3818, 'o ETeimoso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147342.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56381, 3818, 'o ETeimoso S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147343.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56382, 3818, 'o ETeimoso S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147344.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56383, 3818, 'o ETeimoso S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147345.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56384, 3818, 'o ETeimoso S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147346.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56385, 3818, 'o ETeimoso S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147347.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56386, 3818, 'o ETeimoso S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147348.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56387, 3818, 'o ETeimoso S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147349.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56388, 3818, 'o ETeimoso S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147350.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56389, 3818, 'o ETeimoso S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/147351.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56390, 3818, 'o ETeimoso S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/147352.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56391, 3818, 'o ETeimoso S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/147353.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56392, 3818, 'o ETeimoso S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/147354.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56393, 3818, 'o ETeimoso S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/147355.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56394, 3818, 'o ETeimoso S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/147356.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56395, 3818, 'o ETeimoso S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/147357.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56396, 3818, 'o ETeimoso S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/147358.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56397, 3818, 'o ETeimoso S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/147359.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56398, 3818, 'o ETeimoso S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/147360.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56399, 3819, 'o ETeimoso S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147361.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56400, 3819, 'o ETeimoso S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147362.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56401, 3819, 'o ETeimoso S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147363.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56402, 3819, 'o ETeimoso S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147364.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56403, 3819, 'o ETeimoso S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147365.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56404, 3819, 'o ETeimoso S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147366.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56405, 3819, 'o ETeimoso S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147367.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56406, 3819, 'o ETeimoso S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147368.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56407, 3819, 'o ETeimoso S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147369.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56408, 3819, 'o ETeimoso S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147370.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56409, 3819, 'o ETeimoso S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147371.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56410, 3819, 'o ETeimoso S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147372.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56411, 3819, 'o ETeimoso S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147373.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56412, 3819, 'o ETeimoso S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147374.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56413, 3819, 'o ETeimoso S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147375.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56414, 3819, 'o ETeimoso S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147376.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56415, 3819, 'o ETeimoso S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/147377.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56416, 3819, 'o ETeimoso S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/147378.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56417, 3819, 'o ETeimoso S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/147379.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56418, 3819, 'o ETeimoso S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/147380.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56419, 3819, 'o ETeimoso S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/147381.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56420, 3819, 'o ETeimoso S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/147382.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56421, 3819, 'o ETeimoso S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/147383.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56422, 3819, 'o ETeimoso S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/147384.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56423, 3820, 'o ETeimoso S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147385.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56424, 3820, 'o ETeimoso S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147386.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56425, 3820, 'o ETeimoso S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147387.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56426, 3820, 'o ETeimoso S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147388.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56427, 3820, 'o ETeimoso S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147389.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56428, 3820, 'o ETeimoso S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147390.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56429, 3820, 'o ETeimoso S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147391.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56430, 3820, 'o ETeimoso S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147392.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56431, 3820, 'o ETeimoso S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147393.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56432, 3820, 'o ETeimoso S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147394.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56433, 3820, 'o ETeimoso S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147395.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56434, 3820, 'o ETeimoso S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147396.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56435, 3820, 'o ETeimoso S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147397.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56436, 3820, 'o ETeimoso S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147398.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56437, 3820, 'o ETeimoso S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147399.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56438, 3820, 'o ETeimoso S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147400.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56439, 3820, 'o ETeimoso S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/147401.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56440, 3820, 'o ETeimoso S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/147402.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56441, 3820, 'o ETeimoso S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/147403.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56442, 3820, 'o ETeimoso S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/147404.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56443, 3820, 'o ETeimoso S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/147405.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56444, 3820, 'o ETeimoso S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/147406.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56445, 3820, 'o ETeimoso S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/147407.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56446, 3820, 'o ETeimoso S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/147408.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56447, 3820, 'o ETeimoso S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/147409.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56448, 3820, 'o ETeimoso S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/147410.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56449, 3821, 'o ETeimoso S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147411.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56450, 3821, 'o ETeimoso S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147412.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56451, 3821, 'o ETeimoso S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147413.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56452, 3821, 'o ETeimoso S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147414.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56453, 3821, 'o ETeimoso S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147415.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56454, 3821, 'o ETeimoso S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147416.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56455, 3821, 'o ETeimoso S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147417.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56456, 3821, 'o ETeimoso S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147418.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56457, 3821, 'o ETeimoso S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147419.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56458, 3821, 'o ETeimoso S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147420.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56459, 3821, 'o ETeimoso S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147421.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56460, 3821, 'o ETeimoso S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147422.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56461, 3821, 'o ETeimoso S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147423.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56462, 3821, 'o ETeimoso S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147424.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56463, 3821, 'o ETeimoso S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147425.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56464, 3821, 'o ETeimoso S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147426.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56465, 3821, 'o ETeimoso S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/147427.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56466, 3821, 'o ETeimoso S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/147428.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56467, 3821, 'o ETeimoso S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/147429.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56468, 3821, 'o ETeimoso S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/147430.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56469, 3821, 'o ETeimoso S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/147431.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56470, 3821, 'o ETeimoso S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/147432.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56471, 3821, 'o ETeimoso S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/147433.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56472, 3821, 'o ETeimoso S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/147434.mp4', 'http://gstaticontent.com/images/shRed7ZrCRjdIMEYNx2YBVFkkNu_big.jpg'),
(56473, 3822, 'Atypical S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203531.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56474, 3822, 'Atypical S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203532.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56475, 3822, 'Atypical S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203533.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56476, 3822, 'Atypical S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203534.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56477, 3822, 'Atypical S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203535.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56478, 3822, 'Atypical S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203536.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56479, 3822, 'Atypical S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203537.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56480, 3822, 'Atypical S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203538.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56481, 3823, 'Atypical S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203539.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56482, 3823, 'Atypical S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203540.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56483, 3823, 'Atypical S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203541.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56484, 3823, 'Atypical S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203542.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56485, 3823, 'Atypical S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203543.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56486, 3823, 'Atypical S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203544.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56487, 3823, 'Atypical S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203545.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56488, 3823, 'Atypical S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203546.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56489, 3823, 'Atypical S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203547.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56490, 3823, 'Atypical S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203548.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56491, 3824, 'Atypical S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203549.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56492, 3824, 'Atypical S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203550.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56493, 3824, 'Atypical S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203551.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56494, 3824, 'Atypical S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203552.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56495, 3824, 'Atypical S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203553.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56496, 3824, 'Atypical S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203554.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56497, 3824, 'Atypical S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203555.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56498, 3824, 'Atypical S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203556.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56499, 3824, 'Atypical S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203557.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56500, 3824, 'Atypical S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203558.mp4', 'http://gstaticontent.com/images/kNif3eZAjQ7qU3Ol9E7zo0kjPMo_big.jpg'),
(56501, 3825, 'Atypical S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A0yLxnPMgYo2t3wXrOJQSIFIV3N.jpg'),
(56502, 3825, 'Atypical S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/owGRK3zXxuK4hYuzfw4FnMqWR8E.jpg'),
(56503, 3825, 'Atypical S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bz5OqYlhFDBQ9pHhxMsR9XE5JxF.jpg'),
(56504, 3825, 'Atypical S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tXGzfroeqOo3BfgxpPoWZ2eIO4x.jpg'),
(56505, 3825, 'Atypical S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sEK9BTQzJgy1PiceRcvvVPrNum.jpg'),
(56506, 3825, 'Atypical S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3yOsHwXoqHAVvEbnqbVp7P2xCbO.jpg'),
(56507, 3825, 'Atypical S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gkZVywOO77RTtfCgiBYtasVA5mA.jpg'),
(56508, 3825, 'Atypical S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z8A4XKmfOMsgHhvCA0RZFj0He98.jpg'),
(56509, 3825, 'Atypical S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/txYDBxKHwgBbK6kWiQorgNBPKKm.jpg'),
(56510, 3825, 'Atypical S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wRQAzlbnz4fWOtEg45XgUexxUlH.jpg'),
(56511, 3826, 'Designated Survivor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257188.mp4', 'http://gstaticontent.com/images/iWjzw7ei1kHjuFP3paLpxsW6LbV_big.jpg'),
(56512, 3826, 'Designated Survivor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257189.mp4', 'http://gstaticontent.com/images/iWjzw7ei1kHjuFP3paLpxsW6LbV_big.jpg'),
(56513, 3826, 'Designated Survivor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257190.mp4', 'http://gstaticontent.com/images/iWjzw7ei1kHjuFP3paLpxsW6LbV_big.jpg'),
(56514, 3826, 'Designated Survivor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257191.mp4', 'http://gstaticontent.com/images/iWjzw7ei1kHjuFP3paLpxsW6LbV_big.jpg'),
(56515, 3826, 'Designated Survivor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257192.mp4', 'http://gstaticontent.com/images/iWjzw7ei1kHjuFP3paLpxsW6LbV_big.jpg'),
(56516, 3826, 'Designated Survivor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257193.mp4', 'http://gstaticontent.com/images/iWjzw7ei1kHjuFP3paLpxsW6LbV_big.jpg'),
(56517, 3826, 'Designated Survivor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257194.mp4', 'http://gstaticontent.com/images/iWjzw7ei1kHjuFP3paLpxsW6LbV_big.jpg'),
(56518, 3826, 'Designated Survivor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257195.mp4', 'http://gstaticontent.com/images/iWjzw7ei1kHjuFP3paLpxsW6LbV_big.jpg'),
(56519, 3826, 'Designated Survivor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257196.mp4', 'http://gstaticontent.com/images/iWjzw7ei1kHjuFP3paLpxsW6LbV_big.jpg'),
(56520, 3826, 'Designated Survivor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257197.mp4', 'http://gstaticontent.com/images/iWjzw7ei1kHjuFP3paLpxsW6LbV_big.jpg'),
(56521, 3826, 'Designated Survivor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257198.mp4', 'http://gstaticontent.com/images/iWjzw7ei1kHjuFP3paLpxsW6LbV_big.jpg'),
(56522, 3826, 'Designated Survivor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257199.mp4', 'http://gstaticontent.com/images/iWjzw7ei1kHjuFP3paLpxsW6LbV_big.jpg'),
(56523, 3826, 'Designated Survivor S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257200.mp4', 'http://gstaticontent.com/images/iWjzw7ei1kHjuFP3paLpxsW6LbV_big.jpg'),
(56524, 3826, 'Designated Survivor S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/257201.mp4', 'http://gstaticontent.com/images/iWjzw7ei1kHjuFP3paLpxsW6LbV_big.jpg'),
(56525, 3826, 'Designated Survivor S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/257202.mp4', 'http://gstaticontent.com/images/iWjzw7ei1kHjuFP3paLpxsW6LbV_big.jpg'),
(56526, 3826, 'Designated Survivor S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/257203.mp4', 'http://gstaticontent.com/images/iWjzw7ei1kHjuFP3paLpxsW6LbV_big.jpg'),
(56527, 3826, 'Designated Survivor S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/257204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vmUTbH0w9Y0d4g77yPDpiMCGvpQ.jpg'),
(56528, 3826, 'Designated Survivor S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/257205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhG6cHIJR8iLB6Nf6rv9hZdNzr7.jpg'),
(56529, 3826, 'Designated Survivor S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/257206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dQc6BTdyOEqOZiApcFYcHQ6KEJg.jpg'),
(56530, 3826, 'Designated Survivor S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/257207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fRU444JgNhHPl1cOlnw5VLIyCVA.jpg'),
(56531, 3826, 'Designated Survivor S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/257208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dnSd39madc4aZeo4p1rGQDgh1MO.jpg'),
(56532, 3827, 'Designated Survivor S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/by23X7AzEoRn2zYK7xX1AWZGfeN.jpg'),
(56533, 3827, 'Designated Survivor S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/et4JapXznGtwAF1L6sg6NY1fOlk.jpg'),
(56534, 3827, 'Designated Survivor S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfcWlj7JJMaQKQRaTNAfqbgd9Jj.jpg'),
(56535, 3827, 'Designated Survivor S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1cvJZLJJvmRWNX4NXHJdOUQWf1A.jpg'),
(56536, 3827, 'Designated Survivor S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cvcxF4CeCaD7OXdjylNzcrtUh2t.jpg'),
(56537, 3827, 'Designated Survivor S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cS8XlrZpfdsNvp6SWRqARWAvQkZ.jpg'),
(56538, 3827, 'Designated Survivor S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zq9Am6ahHcl5gCXfTxL1U8f5JYv.jpg'),
(56539, 3827, 'Designated Survivor S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dCYvFePoTPFxttUE4yTbeNXKkKU.jpg'),
(56540, 3827, 'Designated Survivor S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bBunhh6dmly8M6mLvUeOmWZX5vh.jpg'),
(56541, 3827, 'Designated Survivor S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l2qoXAsRRD5hTcecozJSVS5s68M.jpg'),
(56542, 3827, 'Designated Survivor S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yJsXVyFbK6RHoM2GTUPmSnVagvc.jpg'),
(56543, 3827, 'Designated Survivor S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5w7TY2RqaVHAD4DoqKtPz1mgL3z.jpg'),
(56544, 3827, 'Designated Survivor S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a179IBEup8GcxgO5k9WaAACOtqm.jpg'),
(56545, 3827, 'Designated Survivor S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/257222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y22wqPjmMHaoJymyhmjbfPoftIi.jpg'),
(56546, 3827, 'Designated Survivor S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/257223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qWB0vPoFtRntyLpdT6wQlUvLiQ3.jpg'),
(56547, 3827, 'Designated Survivor S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/257224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n7TUl6YfWQRKX9XwL7T4iVk1ru4.jpg'),
(56548, 3827, 'Designated Survivor S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/257225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8oqUsjWRgKxaJyUiVgyAQfaC2UF.jpg'),
(56549, 3827, 'Designated Survivor S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/257226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2CpzZ9UyufkUOirvTcqf6qAOOZj.jpg'),
(56550, 3827, 'Designated Survivor S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/257227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/neE2dbZt6Bv4hoM5ncfilAl6Qcr.jpg'),
(56551, 3827, 'Designated Survivor S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/257228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rnf1qwCcK1JV8oeWqFfzQWIGhP.jpg'),
(56552, 3827, 'Designated Survivor S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/257229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/54ZtWvHfhVWl2l5aU8DchaOtsIk.jpg'),
(56553, 3827, 'Designated Survivor S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/257230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3sEDfMkH51UFyJxhu3MzdIYsJje.jpg'),
(56554, 3828, 'Designated Survivor S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vPNRBmQaQeTij6Y86eRiXetruRZ.jpg'),
(56555, 3828, 'Designated Survivor S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k1AI9t3UXEoULi3lpCkDGSMwPqv.jpg'),
(56556, 3828, 'Designated Survivor S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qlnDWbPPjrGfyWjE9TYd4ZcdJnA.jpg'),
(56557, 3828, 'Designated Survivor S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ccBrybQx1AyKZNcM8uGxzI4vHpD.jpg'),
(56558, 3828, 'Designated Survivor S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mTNz837onr3IBRenBVJnXjOgJ1E.jpg'),
(56559, 3828, 'Designated Survivor S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o18KD6roQFPctZv1RitB1e993Io.jpg'),
(56560, 3828, 'Designated Survivor S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/saXkjiDiJBNEW1PedvmDQookAQ4.jpg'),
(56561, 3828, 'Designated Survivor S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/94OqmfNnmnYxo4kDgOYV4CQ539W.jpg'),
(56562, 3828, 'Designated Survivor S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l0hRcK0y54R8XtYz6IQJAL8nst6.jpg'),
(56563, 3828, 'Designated Survivor S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cpy3uV100RyZuvJN535JLTrj4Nz.jpg'),
(56564, 3829, 'LOVE - A História de Lisey S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152131.mp4', 'http://timg.bdta.pro/images/205bd8f5945cd64e7f43f6383500b6bc.jpg'),
(56565, 3829, 'LOVE - A História de Lisey S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152132.mp4', 'http://timg.bdta.pro/images/c35177ef5df2ffda810b3472a7bc85dd.jpg'),
(56566, 3829, 'LOVE - A História de Lisey S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152133.mp4', 'http://timg.bdta.pro/images/357362337222da335258b5afff0b1c76.jpg'),
(56567, 3829, 'LOVE - A História de Lisey S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152134.mp4', 'http://timg.bdta.pro/images/20e6aee1cf241aa6fbce1cf0d4776d48.jpg'),
(56568, 3829, 'LOVE - A História de Lisey S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152135.mp4', 'http://timg.bdta.pro/images/56624c7faad7f76f6af6a76373d6a175.jpg'),
(56569, 3829, 'LOVE - A História de Lisey S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152136.mp4', 'http://timg.bdta.pro/images/907ef8a9d3be3450266eeea8e23f13b4.jpg'),
(56570, 3829, 'LOVE - A História de Lisey S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152137.mp4', 'http://timg.bdta.pro/images/167abdd96b964dbc1ee6155f2433515a.jpg'),
(56571, 3829, 'LOVE - A História de Lisey S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152138.mp4', 'http://timg.bdta.pro/images/e26f43fdcff1cd15e5deaf786fc18ae0.jpg'),
(56572, 3830, 'Os Mestres da Fritura S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147327.mp4', 'http://gstaticontent.com/images/8dEZXEFlgA8tXDTfA6R3kCnvIXt_big.jpg'),
(56573, 3830, 'Os Mestres da Fritura S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147328.mp4', 'http://gstaticontent.com/images/8dEZXEFlgA8tXDTfA6R3kCnvIXt_big.jpg'),
(56574, 3830, 'Os Mestres da Fritura S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147329.mp4', 'http://gstaticontent.com/images/8dEZXEFlgA8tXDTfA6R3kCnvIXt_big.jpg'),
(56575, 3830, 'Os Mestres da Fritura S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147330.mp4', 'http://gstaticontent.com/images/8dEZXEFlgA8tXDTfA6R3kCnvIXt_big.jpg'),
(56576, 3830, 'Os Mestres da Fritura S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147331.mp4', 'http://gstaticontent.com/images/8dEZXEFlgA8tXDTfA6R3kCnvIXt_big.jpg'),
(56577, 3830, 'Os Mestres da Fritura S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147332.mp4', 'http://gstaticontent.com/images/8dEZXEFlgA8tXDTfA6R3kCnvIXt_big.jpg'),
(56578, 3830, 'Os Mestres da Fritura S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147333.mp4', 'http://gstaticontent.com/images/8dEZXEFlgA8tXDTfA6R3kCnvIXt_big.jpg'),
(56579, 3830, 'Os Mestres da Fritura S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147334.mp4', 'http://gstaticontent.com/images/8dEZXEFlgA8tXDTfA6R3kCnvIXt_big.jpg'),
(56580, 3831, 'Stargate Atlantis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147212.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56581, 3831, 'Stargate Atlantis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147213.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56582, 3831, 'Stargate Atlantis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147214.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56583, 3831, 'Stargate Atlantis S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147215.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56584, 3831, 'Stargate Atlantis S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147216.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56585, 3831, 'Stargate Atlantis S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147217.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56586, 3831, 'Stargate Atlantis S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147218.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56587, 3831, 'Stargate Atlantis S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147219.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56588, 3831, 'Stargate Atlantis S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147220.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56589, 3831, 'Stargate Atlantis S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147221.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56590, 3831, 'Stargate Atlantis S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147222.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56591, 3831, 'Stargate Atlantis S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147223.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56592, 3831, 'Stargate Atlantis S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147224.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56593, 3831, 'Stargate Atlantis S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147225.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56594, 3831, 'Stargate Atlantis S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147226.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56595, 3831, 'Stargate Atlantis S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147227.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56596, 3831, 'Stargate Atlantis S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/147228.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56597, 3831, 'Stargate Atlantis S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/147229.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56598, 3831, 'Stargate Atlantis S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/147230.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56599, 3832, 'Stargate Atlantis S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147231.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56600, 3832, 'Stargate Atlantis S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147232.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56601, 3832, 'Stargate Atlantis S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147233.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56602, 3832, 'Stargate Atlantis S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147234.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56603, 3832, 'Stargate Atlantis S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147235.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56604, 3832, 'Stargate Atlantis S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147236.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56605, 3832, 'Stargate Atlantis S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147237.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56606, 3832, 'Stargate Atlantis S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147238.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56607, 3832, 'Stargate Atlantis S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147239.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56608, 3832, 'Stargate Atlantis S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147240.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56609, 3832, 'Stargate Atlantis S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147241.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56610, 3832, 'Stargate Atlantis S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147242.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56611, 3832, 'Stargate Atlantis S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147243.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56612, 3832, 'Stargate Atlantis S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147244.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56613, 3832, 'Stargate Atlantis S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147245.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56614, 3832, 'Stargate Atlantis S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147246.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56615, 3832, 'Stargate Atlantis S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/147247.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56616, 3832, 'Stargate Atlantis S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/147248.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56617, 3832, 'Stargate Atlantis S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/147249.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56618, 3832, 'Stargate Atlantis S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/147250.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56619, 3833, 'Stargate Atlantis S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147251.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56620, 3833, 'Stargate Atlantis S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147252.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56621, 3833, 'Stargate Atlantis S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147253.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56622, 3833, 'Stargate Atlantis S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147254.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56623, 3833, 'Stargate Atlantis S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147255.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56624, 3833, 'Stargate Atlantis S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147256.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56625, 3833, 'Stargate Atlantis S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147257.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56626, 3833, 'Stargate Atlantis S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147258.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56627, 3833, 'Stargate Atlantis S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147259.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56628, 3833, 'Stargate Atlantis S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147260.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56629, 3833, 'Stargate Atlantis S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147261.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56630, 3833, 'Stargate Atlantis S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147262.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56631, 3833, 'Stargate Atlantis S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147263.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56632, 3833, 'Stargate Atlantis S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147264.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56633, 3833, 'Stargate Atlantis S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147265.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56634, 3833, 'Stargate Atlantis S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147266.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56635, 3833, 'Stargate Atlantis S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/147267.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(56636, 3833, 'Stargate Atlantis S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/147268.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56637, 3833, 'Stargate Atlantis S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/147269.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56638, 3833, 'Stargate Atlantis S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/147270.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56639, 3834, 'Stargate Atlantis S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147271.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56640, 3834, 'Stargate Atlantis S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147272.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56641, 3834, 'Stargate Atlantis S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147273.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56642, 3834, 'Stargate Atlantis S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147274.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56643, 3834, 'Stargate Atlantis S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147275.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56644, 3834, 'Stargate Atlantis S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147276.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56645, 3834, 'Stargate Atlantis S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147277.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56646, 3834, 'Stargate Atlantis S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147278.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56647, 3834, 'Stargate Atlantis S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147279.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56648, 3834, 'Stargate Atlantis S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147280.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56649, 3834, 'Stargate Atlantis S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147281.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56650, 3834, 'Stargate Atlantis S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147282.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56651, 3834, 'Stargate Atlantis S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147283.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56652, 3834, 'Stargate Atlantis S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147284.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56653, 3834, 'Stargate Atlantis S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147285.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56654, 3834, 'Stargate Atlantis S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147286.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56655, 3834, 'Stargate Atlantis S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/147287.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56656, 3834, 'Stargate Atlantis S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/147288.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56657, 3834, 'Stargate Atlantis S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/147289.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56658, 3834, 'Stargate Atlantis S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/147290.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56659, 3835, 'Stargate Atlantis S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147291.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56660, 3835, 'Stargate Atlantis S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147292.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56661, 3835, 'Stargate Atlantis S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147293.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56662, 3835, 'Stargate Atlantis S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147294.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56663, 3835, 'Stargate Atlantis S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147295.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56664, 3835, 'Stargate Atlantis S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147296.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56665, 3835, 'Stargate Atlantis S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147297.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56666, 3835, 'Stargate Atlantis S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147298.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56667, 3835, 'Stargate Atlantis S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147299.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56668, 3835, 'Stargate Atlantis S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147300.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56669, 3835, 'Stargate Atlantis S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147301.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56670, 3835, 'Stargate Atlantis S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147302.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56671, 3835, 'Stargate Atlantis S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147303.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56672, 3835, 'Stargate Atlantis S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147304.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56673, 3835, 'Stargate Atlantis S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147305.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56674, 3835, 'Stargate Atlantis S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147306.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56675, 3835, 'Stargate Atlantis S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/147307.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56676, 3835, 'Stargate Atlantis S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/147308.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56677, 3835, 'Stargate Atlantis S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/147309.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56678, 3835, 'Stargate Atlantis S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/147310.mp4', 'http://gstaticontent.com/images/l0JYr2iqwId6VOmCV8dHzlIM6Wd_big.jpg'),
(56679, 3836, 'Latin Flow S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147199.mp4', 'https://i.ibb.co/qBK1GKx/image.png'),
(56680, 3836, 'Latin Flow S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147200.mp4', 'https://i.ibb.co/qBK1GKx/image.png'),
(56681, 3836, 'Latin Flow S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147201.mp4', 'https://i.ibb.co/qBK1GKx/image.png'),
(56682, 3836, 'Latin Flow S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147202.mp4', 'https://i.ibb.co/qBK1GKx/image.png'),
(56683, 3836, 'Latin Flow S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147203.mp4', 'https://i.ibb.co/qBK1GKx/image.png'),
(56684, 3836, 'Latin Flow S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147204.mp4', 'https://i.ibb.co/qBK1GKx/image.png'),
(56685, 3836, 'Latin Flow S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147205.mp4', 'https://i.ibb.co/qBK1GKx/image.png'),
(56686, 3836, 'Latin Flow S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147206.mp4', 'https://i.ibb.co/qBK1GKx/image.png'),
(56687, 3836, 'Latin Flow S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147207.mp4', 'https://i.ibb.co/qBK1GKx/image.png'),
(56688, 3836, 'Latin Flow S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147208.mp4', 'https://i.ibb.co/qBK1GKx/image.png'),
(56689, 3836, 'Latin Flow S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147209.mp4', 'https://i.ibb.co/qBK1GKx/image.png'),
(56690, 3836, 'Latin Flow S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147210.mp4', 'https://i.ibb.co/qBK1GKx/image.png'),
(56691, 3836, 'Latin Flow S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147211.mp4', 'https://i.ibb.co/qBK1GKx/image.png'),
(56692, 3837, 'O Preço da Perfeição S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147311.mp4', 'http://gstaticontent.com/images/3kRHSMg0cuxR0raTWicmQ17hQh1_big.jpg'),
(56693, 3837, 'O Preço da Perfeição S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147312.mp4', 'http://gstaticontent.com/images/3kRHSMg0cuxR0raTWicmQ17hQh1_big.jpg'),
(56694, 3837, 'O Preço da Perfeição S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147313.mp4', 'http://gstaticontent.com/images/3kRHSMg0cuxR0raTWicmQ17hQh1_big.jpg'),
(56695, 3837, 'O Preço da Perfeição S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147314.mp4', 'http://gstaticontent.com/images/3kRHSMg0cuxR0raTWicmQ17hQh1_big.jpg'),
(56696, 3837, 'O Preço da Perfeição S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147315.mp4', 'http://gstaticontent.com/images/3kRHSMg0cuxR0raTWicmQ17hQh1_big.jpg'),
(56697, 3837, 'O Preço da Perfeição S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147316.mp4', 'http://gstaticontent.com/images/3kRHSMg0cuxR0raTWicmQ17hQh1_big.jpg'),
(56698, 3837, 'O Preço da Perfeição S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147317.mp4', 'http://gstaticontent.com/images/3kRHSMg0cuxR0raTWicmQ17hQh1_big.jpg'),
(56699, 3837, 'O Preço da Perfeição S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147318.mp4', 'http://gstaticontent.com/images/3kRHSMg0cuxR0raTWicmQ17hQh1_big.jpg'),
(56700, 3837, 'O Preço da Perfeição S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147319.mp4', 'http://gstaticontent.com/images/3kRHSMg0cuxR0raTWicmQ17hQh1_big.jpg'),
(56701, 3837, 'O Preço da Perfeição S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147320.mp4', 'http://gstaticontent.com/images/3kRHSMg0cuxR0raTWicmQ17hQh1_big.jpg'),
(56702, 3838, 'Trese S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147321.mp4', 'http://gstaticontent.com/images/8PdIMo0Ca6SoPjIsIEgO7FtbEor_big.jpg'),
(56703, 3838, 'Trese S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147322.mp4', 'http://gstaticontent.com/images/8PdIMo0Ca6SoPjIsIEgO7FtbEor_big.jpg'),
(56704, 3838, 'Trese S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147323.mp4', 'http://gstaticontent.com/images/8PdIMo0Ca6SoPjIsIEgO7FtbEor_big.jpg'),
(56705, 3838, 'Trese S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147324.mp4', 'http://gstaticontent.com/images/8PdIMo0Ca6SoPjIsIEgO7FtbEor_big.jpg'),
(56706, 3838, 'Trese S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147325.mp4', 'http://gstaticontent.com/images/8PdIMo0Ca6SoPjIsIEgO7FtbEor_big.jpg'),
(56707, 3838, 'Trese S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147326.mp4', 'http://gstaticontent.com/images/8PdIMo0Ca6SoPjIsIEgO7FtbEor_big.jpg'),
(56708, 3839, 'Caverna do Dragão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155498.mp4', 'http://timg.bdta.pro/images/82e38719a9f277dc6ee44c8a2632a0b3.jpg'),
(56709, 3839, 'Caverna do Dragão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155499.mp4', 'http://timg.bdta.pro/images/24c32e358d004f598e604956ae9363f5.jpg'),
(56710, 3839, 'Caverna do Dragão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155500.mp4', 'http://timg.bdta.pro/images/5096898956520eb93937db8e6974db51.jpg'),
(56711, 3839, 'Caverna do Dragão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155501.mp4', 'http://timg.bdta.pro/images/2d4dff91cb95e4c9708b3285d4efa957.jpg'),
(56712, 3839, 'Caverna do Dragão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155502.mp4', 'http://timg.bdta.pro/images/b1f70ea33603245d3b94c0acf761a92b.jpg'),
(56713, 3839, 'Caverna do Dragão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155503.mp4', 'http://timg.bdta.pro/images/9fa27bccdc3ebb2a9bb73c0cb5716465.jpg'),
(56714, 3839, 'Caverna do Dragão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/155504.mp4', 'http://timg.bdta.pro/images/af7c3cc7c80f937ca199f3e43f1b1ab1.jpg'),
(56715, 3839, 'Caverna do Dragão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/155505.mp4', 'http://timg.bdta.pro/images/08baec5ee0a9649323e732276eb196bd.jpg'),
(56716, 3839, 'Caverna do Dragão S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/155506.mp4', 'http://timg.bdta.pro/images/55c91dc5de37730d166e170d3a69784e.jpg'),
(56717, 3839, 'Caverna do Dragão S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/155507.mp4', 'http://timg.bdta.pro/images/6ec86a26bff65becc2890bd13cda97e2.jpg'),
(56718, 3839, 'Caverna do Dragão S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/155508.mp4', 'http://timg.bdta.pro/images/d6741a43e03a503b880bd47fafda3af3.jpg'),
(56719, 3839, 'Caverna do Dragão S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/155509.mp4', 'http://timg.bdta.pro/images/1e2d3d0bc752d29ce9f9d4761ca53d96.jpg'),
(56720, 3839, 'Caverna do Dragão S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/155510.mp4', 'http://timg.bdta.pro/images/0ca0066b7a74e14c6ce0a382f7d3b8cf.jpg'),
(56721, 3840, 'Caverna do Dragão S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155511.mp4', 'http://timg.bdta.pro/images/9b584e2e32a2a7f089ddff61d2c9e4f2.jpg'),
(56722, 3840, 'Caverna do Dragão S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155512.mp4', 'http://timg.bdta.pro/images/25e18b64b04673b66c1bef26a63663be.jpg'),
(56723, 3840, 'Caverna do Dragão S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155513.mp4', 'http://timg.bdta.pro/images/1bc55caae43d4b1042a9cbd5ef84a46b.jpg'),
(56724, 3840, 'Caverna do Dragão S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155514.mp4', 'http://timg.bdta.pro/images/de526baadd37bc4ff2a83c407f9c5865.jpg'),
(56725, 3840, 'Caverna do Dragão S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155515.mp4', 'http://timg.bdta.pro/images/4d82943ee74776c817aa66bd57861dcb.jpg'),
(56726, 3840, 'Caverna do Dragão S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155516.mp4', 'http://timg.bdta.pro/images/02a9e4ca45b11a7e3cbc04952e873b3e.jpg'),
(56727, 3840, 'Caverna do Dragão S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/155517.mp4', 'http://timg.bdta.pro/images/00460d9b30ef4fabf1347be5b266ad58.jpg'),
(56728, 3840, 'Caverna do Dragão S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/155518.mp4', 'http://timg.bdta.pro/images/9ec96cb7129d2ab1bd6b2df396115703.jpg'),
(56729, 3841, 'Caverna do Dragão S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155519.mp4', 'http://timg.bdta.pro/images/031403722906021d7404235909669e83.jpg'),
(56730, 3841, 'Caverna do Dragão S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155520.mp4', 'http://timg.bdta.pro/images/5b63483a2bf36ebd14922ee785fdae8b.jpg'),
(56731, 3841, 'Caverna do Dragão S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155521.mp4', 'http://timg.bdta.pro/images/d3da1d66015eeea52b15e8c3c283e083.jpg'),
(56732, 3841, 'Caverna do Dragão S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155522.mp4', 'http://timg.bdta.pro/images/eef63b4dbe08ed348c45d4464935e6a5.jpg'),
(56733, 3841, 'Caverna do Dragão S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155523.mp4', 'http://timg.bdta.pro/images/4a1bf0d86d9691d28fa9e7433e44c5a8.jpg'),
(56734, 3841, 'Caverna do Dragão S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155524.mp4', 'http://timg.bdta.pro/images/90560c8bfe32c790cd45d9108da82c6d.jpg'),
(56735, 3842, 'Tratamento de Choque S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147057.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56736, 3842, 'Tratamento de Choque S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147058.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56737, 3842, 'Tratamento de Choque S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147059.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56738, 3842, 'Tratamento de Choque S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147060.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56739, 3842, 'Tratamento de Choque S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147061.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56740, 3842, 'Tratamento de Choque S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147062.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56741, 3842, 'Tratamento de Choque S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147063.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56742, 3842, 'Tratamento de Choque S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147064.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56743, 3842, 'Tratamento de Choque S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147065.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56744, 3842, 'Tratamento de Choque S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147066.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56745, 3843, 'Tratamento de Choque S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147067.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56746, 3843, 'Tratamento de Choque S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147068.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56747, 3843, 'Tratamento de Choque S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147069.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56748, 3843, 'Tratamento de Choque S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147070.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56749, 3843, 'Tratamento de Choque S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147071.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56750, 3843, 'Tratamento de Choque S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147072.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56751, 3843, 'Tratamento de Choque S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147073.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56752, 3843, 'Tratamento de Choque S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147074.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56753, 3843, 'Tratamento de Choque S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147075.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56754, 3843, 'Tratamento de Choque S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147076.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56755, 3843, 'Tratamento de Choque S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147077.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56756, 3843, 'Tratamento de Choque S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147078.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56757, 3843, 'Tratamento de Choque S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147079.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56758, 3843, 'Tratamento de Choque S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147080.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56759, 3843, 'Tratamento de Choque S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147081.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56760, 3843, 'Tratamento de Choque S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147082.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56761, 3843, 'Tratamento de Choque S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/147083.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56762, 3843, 'Tratamento de Choque S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/147084.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56763, 3843, 'Tratamento de Choque S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/147085.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56764, 3843, 'Tratamento de Choque S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/147086.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56765, 3843, 'Tratamento de Choque S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/147087.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56766, 3843, 'Tratamento de Choque S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/147088.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56767, 3844, 'Tratamento de Choque S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147089.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56768, 3844, 'Tratamento de Choque S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147090.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56769, 3844, 'Tratamento de Choque S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147091.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56770, 3844, 'Tratamento de Choque S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147092.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56771, 3844, 'Tratamento de Choque S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147093.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56772, 3844, 'Tratamento de Choque S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147094.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56773, 3844, 'Tratamento de Choque S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147095.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56774, 3844, 'Tratamento de Choque S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147096.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56775, 3844, 'Tratamento de Choque S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147097.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56776, 3844, 'Tratamento de Choque S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147098.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56777, 3844, 'Tratamento de Choque S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147099.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56778, 3844, 'Tratamento de Choque S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147100.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56779, 3844, 'Tratamento de Choque S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147101.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56780, 3844, 'Tratamento de Choque S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147102.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56781, 3844, 'Tratamento de Choque S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147103.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56782, 3844, 'Tratamento de Choque S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147104.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56783, 3844, 'Tratamento de Choque S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/147105.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56784, 3844, 'Tratamento de Choque S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/147106.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56785, 3844, 'Tratamento de Choque S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/147107.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56786, 3844, 'Tratamento de Choque S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/147108.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56787, 3844, 'Tratamento de Choque S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/147109.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56788, 3844, 'Tratamento de Choque S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/147110.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56789, 3845, 'Tratamento de Choque S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147111.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56790, 3845, 'Tratamento de Choque S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147112.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56791, 3845, 'Tratamento de Choque S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147113.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56792, 3845, 'Tratamento de Choque S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147114.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56793, 3845, 'Tratamento de Choque S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147115.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56794, 3845, 'Tratamento de Choque S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147116.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56795, 3845, 'Tratamento de Choque S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147117.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56796, 3845, 'Tratamento de Choque S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147118.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56797, 3845, 'Tratamento de Choque S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147119.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56798, 3845, 'Tratamento de Choque S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147120.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56799, 3845, 'Tratamento de Choque S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147121.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56800, 3845, 'Tratamento de Choque S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147122.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56801, 3845, 'Tratamento de Choque S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147123.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56802, 3845, 'Tratamento de Choque S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147124.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56803, 3845, 'Tratamento de Choque S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147125.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56804, 3845, 'Tratamento de Choque S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147126.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56805, 3845, 'Tratamento de Choque S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/147127.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56806, 3845, 'Tratamento de Choque S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/147128.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56807, 3845, 'Tratamento de Choque S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/147129.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56808, 3845, 'Tratamento de Choque S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/147130.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56809, 3845, 'Tratamento de Choque S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/147131.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56810, 3845, 'Tratamento de Choque S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/147132.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56811, 3845, 'Tratamento de Choque S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/147133.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56812, 3845, 'Tratamento de Choque S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/147134.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56813, 3845, 'Tratamento de Choque S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/147135.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56814, 3846, 'Tratamento de Choque S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147136.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56815, 3846, 'Tratamento de Choque S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147137.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56816, 3846, 'Tratamento de Choque S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147138.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56817, 3846, 'Tratamento de Choque S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147139.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56818, 3846, 'Tratamento de Choque S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147140.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56819, 3846, 'Tratamento de Choque S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147141.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56820, 3846, 'Tratamento de Choque S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147142.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56821, 3846, 'Tratamento de Choque S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147143.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56822, 3846, 'Tratamento de Choque S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147144.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56823, 3846, 'Tratamento de Choque S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147145.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56824, 3846, 'Tratamento de Choque S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147146.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56825, 3846, 'Tratamento de Choque S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147147.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56826, 3846, 'Tratamento de Choque S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147148.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56827, 3846, 'Tratamento de Choque S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147149.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56828, 3846, 'Tratamento de Choque S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147150.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56829, 3846, 'Tratamento de Choque S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147151.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56830, 3846, 'Tratamento de Choque S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/147152.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56831, 3846, 'Tratamento de Choque S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/147153.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56832, 3846, 'Tratamento de Choque S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/147154.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56833, 3846, 'Tratamento de Choque S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/147155.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56834, 3846, 'Tratamento de Choque S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/147156.mp4', 'http://gstaticontent.com/images/yrgrySCCFjhB3p9zqnunAmjDxC9_big.jpg'),
(56835, 3847, 'Blindspotting S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149508.mp4', 'http://timg.bdta.pro/images/231fd3a79a133e9f6d0be3c9d9e59b05.jpg'),
(56836, 3847, 'Blindspotting S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149509.mp4', 'http://timg.bdta.pro/images/181ba26c9ae77fd01531cf24e9fff90f.jpg'),
(56837, 3847, 'Blindspotting S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149510.mp4', 'http://timg.bdta.pro/images/a378b89a73331d709ce8b77ec6a1d7da.jpg'),
(56838, 3847, 'Blindspotting S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149511.mp4', 'http://timg.bdta.pro/images/2737e4e835ddd1026103fa0fbf354abe.jpg'),
(56839, 3847, 'Blindspotting S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149512.mp4', 'http://timg.bdta.pro/images/7c81ad5481ac03b67f03b8a8c9aefe3c.jpg'),
(56840, 3847, 'Blindspotting S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149513.mp4', 'http://timg.bdta.pro/images/fbe65138562d8d7753a7224a65f28179.jpg'),
(56841, 3847, 'Blindspotting S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149514.mp4', 'http://timg.bdta.pro/images/8e7a3fba9a7a2b169fd64e1ef0b35327.jpg'),
(56842, 3847, 'Blindspotting S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149515.mp4', 'http://timg.bdta.pro/images/e9a4f8926bba56836aac0c24f28b083e.jpg'),
(56843, 3848, 'Blindspotting S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289304.mp4', 'http://gstaticontent.com/images/igf2O23e4Jbc9QzI6vIPnxLhvvQ_big.jpg'),
(56844, 3848, 'Blindspotting S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289305.mp4', 'http://gstaticontent.com/images/igf2O23e4Jbc9QzI6vIPnxLhvvQ_big.jpg'),
(56845, 3848, 'Blindspotting S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289306.mp4', 'http://gstaticontent.com/images/igf2O23e4Jbc9QzI6vIPnxLhvvQ_big.jpg'),
(56846, 3848, 'Blindspotting S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289307.mp4', 'http://gstaticontent.com/images/igf2O23e4Jbc9QzI6vIPnxLhvvQ_big.jpg'),
(56847, 3848, 'Blindspotting S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289308.mp4', 'http://gstaticontent.com/images/igf2O23e4Jbc9QzI6vIPnxLhvvQ_big.jpg'),
(56848, 3848, 'Blindspotting S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289309.mp4', 'http://gstaticontent.com/images/igf2O23e4Jbc9QzI6vIPnxLhvvQ_big.jpg'),
(56849, 3848, 'Blindspotting S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289310.mp4', 'http://gstaticontent.com/images/igf2O23e4Jbc9QzI6vIPnxLhvvQ_big.jpg'),
(56850, 3848, 'Blindspotting S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289311.mp4', 'http://gstaticontent.com/images/igf2O23e4Jbc9QzI6vIPnxLhvvQ_big.jpg'),
(56851, 3849, 'Bosch S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227848.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56852, 3849, 'Bosch S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227849.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56853, 3849, 'Bosch S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227850.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56854, 3849, 'Bosch S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227851.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56855, 3849, 'Bosch S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227852.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56856, 3849, 'Bosch S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227853.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56857, 3849, 'Bosch S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227854.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56858, 3849, 'Bosch S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227855.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56859, 3849, 'Bosch S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227856.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56860, 3849, 'Bosch S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227857.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56861, 3850, 'Bosch S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227858.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56862, 3850, 'Bosch S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227859.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56863, 3850, 'Bosch S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227860.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56864, 3850, 'Bosch S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227861.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56865, 3850, 'Bosch S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227862.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56866, 3850, 'Bosch S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227863.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56867, 3850, 'Bosch S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227864.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56868, 3850, 'Bosch S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227865.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56869, 3850, 'Bosch S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227866.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56870, 3850, 'Bosch S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227867.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56871, 3851, 'Bosch S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227868.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56872, 3851, 'Bosch S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227869.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56873, 3851, 'Bosch S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227870.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56874, 3851, 'Bosch S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227871.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56875, 3851, 'Bosch S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227872.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56876, 3851, 'Bosch S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227873.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56877, 3851, 'Bosch S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227874.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56878, 3851, 'Bosch S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227875.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56879, 3851, 'Bosch S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227876.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56880, 3851, 'Bosch S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227877.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56881, 3852, 'Bosch S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227878.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56882, 3852, 'Bosch S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227879.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56883, 3852, 'Bosch S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227880.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56884, 3852, 'Bosch S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227881.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56885, 3852, 'Bosch S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227882.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56886, 3852, 'Bosch S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227883.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56887, 3852, 'Bosch S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227884.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56888, 3852, 'Bosch S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227885.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56889, 3852, 'Bosch S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227886.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56890, 3852, 'Bosch S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227887.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56891, 3853, 'Bosch S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227888.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56892, 3853, 'Bosch S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227889.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56893, 3853, 'Bosch S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227890.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56894, 3853, 'Bosch S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227891.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56895, 3853, 'Bosch S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227892.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56896, 3853, 'Bosch S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227893.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56897, 3853, 'Bosch S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227894.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56898, 3853, 'Bosch S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227895.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56899, 3853, 'Bosch S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227896.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56900, 3853, 'Bosch S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227897.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56901, 3854, 'Bosch S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227898.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56902, 3854, 'Bosch S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227899.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56903, 3854, 'Bosch S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227900.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56904, 3854, 'Bosch S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227901.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56905, 3854, 'Bosch S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227902.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56906, 3854, 'Bosch S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227903.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56907, 3854, 'Bosch S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227904.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56908, 3854, 'Bosch S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227905.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56909, 3854, 'Bosch S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227906.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56910, 3854, 'Bosch S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227907.mp4', 'http://gstaticontent.com/images/8lWIXhs8Ju2B5ddOb6sjSshxLov_big.jpg'),
(56911, 3855, 'Bosch S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXEufSU2dV5OpoxRKI1tzOxcW7K.jpg'),
(56912, 3855, 'Bosch S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Z9K7HqDJbbvy449TwwqDAqeNF9.jpg'),
(56913, 3855, 'Bosch S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mHppdVvuFhw5tXyWCCIpdw1tPUz.jpg'),
(56914, 3855, 'Bosch S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bcEIY59pZK4JG3ZNsO538mTVfzJ.jpg'),
(56915, 3855, 'Bosch S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8D2Hlugc13hRXHqBz4LTsbyDwFa.jpg'),
(56916, 3855, 'Bosch S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rqckMDDu6JjZ1rfkPcwwDnbSapG.jpg'),
(56917, 3855, 'Bosch S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Q32QOLtKN76siMN0iWLGtbN16S.jpg'),
(56918, 3855, 'Bosch S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rLstFDNX3iYyJ3wreHDyLfcUH6j.jpg'),
(56919, 3856, 'Na Fazenda com Jeremy Clarkson S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147049.mp4', 'http://gstaticontent.com/images/3lyP0ZH3BDeMuVc7EMaSMm8JiVe_big.jpg'),
(56920, 3856, 'Na Fazenda com Jeremy Clarkson S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147050.mp4', 'http://gstaticontent.com/images/3lyP0ZH3BDeMuVc7EMaSMm8JiVe_big.jpg'),
(56921, 3856, 'Na Fazenda com Jeremy Clarkson S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147051.mp4', 'http://gstaticontent.com/images/3lyP0ZH3BDeMuVc7EMaSMm8JiVe_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(56922, 3856, 'Na Fazenda com Jeremy Clarkson S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147052.mp4', 'http://gstaticontent.com/images/3lyP0ZH3BDeMuVc7EMaSMm8JiVe_big.jpg'),
(56923, 3856, 'Na Fazenda com Jeremy Clarkson S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147053.mp4', 'http://gstaticontent.com/images/3lyP0ZH3BDeMuVc7EMaSMm8JiVe_big.jpg'),
(56924, 3856, 'Na Fazenda com Jeremy Clarkson S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147054.mp4', 'http://gstaticontent.com/images/3lyP0ZH3BDeMuVc7EMaSMm8JiVe_big.jpg'),
(56925, 3856, 'Na Fazenda com Jeremy Clarkson S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147055.mp4', 'http://gstaticontent.com/images/3lyP0ZH3BDeMuVc7EMaSMm8JiVe_big.jpg'),
(56926, 3856, 'Na Fazenda com Jeremy Clarkson S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147056.mp4', 'http://gstaticontent.com/images/3lyP0ZH3BDeMuVc7EMaSMm8JiVe_big.jpg'),
(56927, 3857, 'Rubí S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/147023.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56928, 3857, 'Rubí S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/147024.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56929, 3857, 'Rubí S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/147025.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56930, 3857, 'Rubí S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/147026.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56931, 3857, 'Rubí S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/147027.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56932, 3857, 'Rubí S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/147028.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56933, 3857, 'Rubí S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/147029.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56934, 3857, 'Rubí S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/147030.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56935, 3857, 'Rubí S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/147031.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56936, 3857, 'Rubí S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/147032.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56937, 3857, 'Rubí S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/147033.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56938, 3857, 'Rubí S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/147034.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56939, 3857, 'Rubí S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/147035.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56940, 3857, 'Rubí S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/147036.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56941, 3857, 'Rubí S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/147037.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56942, 3857, 'Rubí S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/147038.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56943, 3857, 'Rubí S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/147039.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56944, 3857, 'Rubí S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/147040.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56945, 3857, 'Rubí S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/147041.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56946, 3857, 'Rubí S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/147042.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56947, 3857, 'Rubí S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/147043.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56948, 3857, 'Rubí S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/147044.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56949, 3857, 'Rubí S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/147045.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56950, 3857, 'Rubí S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/147046.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56951, 3857, 'Rubí S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/147047.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56952, 3857, 'Rubí S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/147048.mp4', 'http://gstaticontent.com/images/5dL8vO8gGwRNcjEwXl3AX7I3sqT_big.jpg'),
(56953, 3858, 'Te Devo Essa Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157139.mp4', 'http://gstaticontent.com/images/1fe323b5ca24f0b002d559671e1c402a.png'),
(56954, 3858, 'Te Devo Essa Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157140.mp4', 'http://gstaticontent.com/images/1fe323b5ca24f0b002d559671e1c402a.png'),
(56955, 3858, 'Te Devo Essa Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157141.mp4', 'http://gstaticontent.com/images/1fe323b5ca24f0b002d559671e1c402a.png'),
(56956, 3858, 'Te Devo Essa Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157142.mp4', 'http://gstaticontent.com/images/1fe323b5ca24f0b002d559671e1c402a.png'),
(56957, 3858, 'Te Devo Essa Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/157143.mp4', 'http://gstaticontent.com/images/1fe323b5ca24f0b002d559671e1c402a.png'),
(56958, 3858, 'Te Devo Essa Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/157144.mp4', 'http://gstaticontent.com/images/1fe323b5ca24f0b002d559671e1c402a.png'),
(56959, 3858, 'Te Devo Essa Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/157145.mp4', 'http://gstaticontent.com/images/1fe323b5ca24f0b002d559671e1c402a.png'),
(56960, 3858, 'Te Devo Essa Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/157146.mp4', 'http://gstaticontent.com/images/1fe323b5ca24f0b002d559671e1c402a.png'),
(56961, 3858, 'Te Devo Essa Brasil S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/157147.mp4', 'http://gstaticontent.com/images/1fe323b5ca24f0b002d559671e1c402a.png'),
(56962, 3858, 'Te Devo Essa Brasil S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/157148.mp4', 'http://gstaticontent.com/images/1fe323b5ca24f0b002d559671e1c402a.png'),
(56963, 3858, 'Te Devo Essa Brasil S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/157149.mp4', 'http://gstaticontent.com/images/1fe323b5ca24f0b002d559671e1c402a.png'),
(56964, 3858, 'Te Devo Essa Brasil S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/157150.mp4', 'http://gstaticontent.com/images/1fe323b5ca24f0b002d559671e1c402a.png'),
(56965, 3859, 'Cidade dos Pinguins S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146909.mp4', 'http://gstaticontent.com/images/3LtKOlUBdk6t3B01gbaR332YI2U_big.jpg'),
(56966, 3859, 'Cidade dos Pinguins S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146910.mp4', 'http://gstaticontent.com/images/3LtKOlUBdk6t3B01gbaR332YI2U_big.jpg'),
(56967, 3859, 'Cidade dos Pinguins S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146911.mp4', 'http://gstaticontent.com/images/3LtKOlUBdk6t3B01gbaR332YI2U_big.jpg'),
(56968, 3859, 'Cidade dos Pinguins S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146912.mp4', 'http://gstaticontent.com/images/3LtKOlUBdk6t3B01gbaR332YI2U_big.jpg'),
(56969, 3859, 'Cidade dos Pinguins S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146913.mp4', 'http://gstaticontent.com/images/3LtKOlUBdk6t3B01gbaR332YI2U_big.jpg'),
(56970, 3859, 'Cidade dos Pinguins S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146914.mp4', 'http://gstaticontent.com/images/3LtKOlUBdk6t3B01gbaR332YI2U_big.jpg'),
(56971, 3859, 'Cidade dos Pinguins S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146915.mp4', 'http://gstaticontent.com/images/3LtKOlUBdk6t3B01gbaR332YI2U_big.jpg'),
(56972, 3859, 'Cidade dos Pinguins S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146916.mp4', 'http://gstaticontent.com/images/3LtKOlUBdk6t3B01gbaR332YI2U_big.jpg'),
(56973, 3860, 'EUA: A Luta Pela Liberdade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146903.mp4', 'http://gstaticontent.com/images/a7i3jJe9rI7RSvlGoMB7aYI7XVt_big.jpg'),
(56974, 3860, 'EUA: A Luta Pela Liberdade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146904.mp4', 'http://gstaticontent.com/images/a7i3jJe9rI7RSvlGoMB7aYI7XVt_big.jpg'),
(56975, 3860, 'EUA: A Luta Pela Liberdade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146905.mp4', 'http://gstaticontent.com/images/a7i3jJe9rI7RSvlGoMB7aYI7XVt_big.jpg'),
(56976, 3860, 'EUA: A Luta Pela Liberdade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146906.mp4', 'http://gstaticontent.com/images/a7i3jJe9rI7RSvlGoMB7aYI7XVt_big.jpg'),
(56977, 3860, 'EUA: A Luta Pela Liberdade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146907.mp4', 'http://gstaticontent.com/images/a7i3jJe9rI7RSvlGoMB7aYI7XVt_big.jpg'),
(56978, 3860, 'EUA: A Luta Pela Liberdade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146908.mp4', 'http://gstaticontent.com/images/a7i3jJe9rI7RSvlGoMB7aYI7XVt_big.jpg'),
(56979, 3861, 'O Mundo é dos Jovens S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146752.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(56980, 3861, 'O Mundo é dos Jovens S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146753.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(56981, 3861, 'O Mundo é dos Jovens S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146754.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(56982, 3861, 'O Mundo é dos Jovens S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146755.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(56983, 3861, 'O Mundo é dos Jovens S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146756.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(56984, 3861, 'O Mundo é dos Jovens S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146757.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(56985, 3861, 'O Mundo é dos Jovens S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146758.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(56986, 3861, 'O Mundo é dos Jovens S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146759.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(56987, 3861, 'O Mundo é dos Jovens S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146760.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(56988, 3861, 'O Mundo é dos Jovens S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146761.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(56989, 3861, 'O Mundo é dos Jovens S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146762.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(56990, 3861, 'O Mundo é dos Jovens S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146763.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(56991, 3861, 'O Mundo é dos Jovens S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146764.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(56992, 3861, 'O Mundo é dos Jovens S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146765.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(56993, 3861, 'O Mundo é dos Jovens S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146766.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(56994, 3861, 'O Mundo é dos Jovens S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146767.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(56995, 3861, 'O Mundo é dos Jovens S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146768.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(56996, 3861, 'O Mundo é dos Jovens S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146769.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(56997, 3861, 'O Mundo é dos Jovens S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/146770.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(56998, 3861, 'O Mundo é dos Jovens S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/146771.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(56999, 3861, 'O Mundo é dos Jovens S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/146772.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57000, 3861, 'O Mundo é dos Jovens S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/146773.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57001, 3862, 'O Mundo é dos Jovens S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146774.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57002, 3862, 'O Mundo é dos Jovens S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146775.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57003, 3862, 'O Mundo é dos Jovens S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146776.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57004, 3862, 'O Mundo é dos Jovens S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146777.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57005, 3862, 'O Mundo é dos Jovens S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146778.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57006, 3862, 'O Mundo é dos Jovens S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146779.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57007, 3862, 'O Mundo é dos Jovens S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146780.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57008, 3862, 'O Mundo é dos Jovens S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146781.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57009, 3862, 'O Mundo é dos Jovens S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146782.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57010, 3862, 'O Mundo é dos Jovens S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146783.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57011, 3862, 'O Mundo é dos Jovens S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146784.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57012, 3862, 'O Mundo é dos Jovens S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146785.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57013, 3862, 'O Mundo é dos Jovens S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146786.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57014, 3862, 'O Mundo é dos Jovens S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146787.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57015, 3862, 'O Mundo é dos Jovens S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146788.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57016, 3862, 'O Mundo é dos Jovens S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146789.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57017, 3862, 'O Mundo é dos Jovens S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146790.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57018, 3862, 'O Mundo é dos Jovens S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146791.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57019, 3862, 'O Mundo é dos Jovens S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/146792.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57020, 3862, 'O Mundo é dos Jovens S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/146793.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57021, 3862, 'O Mundo é dos Jovens S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/146794.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57022, 3862, 'O Mundo é dos Jovens S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/146795.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57023, 3862, 'O Mundo é dos Jovens S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/146796.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57024, 3863, 'O Mundo é dos Jovens S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146797.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57025, 3863, 'O Mundo é dos Jovens S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146798.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57026, 3863, 'O Mundo é dos Jovens S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146799.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57027, 3863, 'O Mundo é dos Jovens S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146800.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57028, 3863, 'O Mundo é dos Jovens S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146801.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57029, 3863, 'O Mundo é dos Jovens S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146802.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57030, 3863, 'O Mundo é dos Jovens S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146803.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57031, 3863, 'O Mundo é dos Jovens S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146804.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57032, 3863, 'O Mundo é dos Jovens S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146805.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57033, 3863, 'O Mundo é dos Jovens S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146806.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57034, 3863, 'O Mundo é dos Jovens S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146807.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57035, 3863, 'O Mundo é dos Jovens S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146808.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57036, 3863, 'O Mundo é dos Jovens S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146809.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57037, 3863, 'O Mundo é dos Jovens S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146810.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57038, 3863, 'O Mundo é dos Jovens S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146811.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57039, 3863, 'O Mundo é dos Jovens S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146812.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57040, 3863, 'O Mundo é dos Jovens S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146813.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57041, 3863, 'O Mundo é dos Jovens S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146814.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57042, 3863, 'O Mundo é dos Jovens S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/146815.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57043, 3863, 'O Mundo é dos Jovens S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/146816.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57044, 3864, 'O Mundo é dos Jovens S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146817.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57045, 3864, 'O Mundo é dos Jovens S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146818.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57046, 3864, 'O Mundo é dos Jovens S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146819.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57047, 3864, 'O Mundo é dos Jovens S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146820.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57048, 3864, 'O Mundo é dos Jovens S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146821.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57049, 3864, 'O Mundo é dos Jovens S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146822.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57050, 3864, 'O Mundo é dos Jovens S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146823.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57051, 3864, 'O Mundo é dos Jovens S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146824.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57052, 3864, 'O Mundo é dos Jovens S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146825.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57053, 3864, 'O Mundo é dos Jovens S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146826.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57054, 3864, 'O Mundo é dos Jovens S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146827.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57055, 3864, 'O Mundo é dos Jovens S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146828.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57056, 3864, 'O Mundo é dos Jovens S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146829.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57057, 3864, 'O Mundo é dos Jovens S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146830.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57058, 3864, 'O Mundo é dos Jovens S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146831.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57059, 3864, 'O Mundo é dos Jovens S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146832.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57060, 3864, 'O Mundo é dos Jovens S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146833.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57061, 3865, 'O Mundo é dos Jovens S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146834.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57062, 3865, 'O Mundo é dos Jovens S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146835.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57063, 3865, 'O Mundo é dos Jovens S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146836.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57064, 3865, 'O Mundo é dos Jovens S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146837.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57065, 3865, 'O Mundo é dos Jovens S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146838.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57066, 3865, 'O Mundo é dos Jovens S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146839.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57067, 3865, 'O Mundo é dos Jovens S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146840.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57068, 3865, 'O Mundo é dos Jovens S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146841.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57069, 3865, 'O Mundo é dos Jovens S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146842.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57070, 3865, 'O Mundo é dos Jovens S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146843.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57071, 3865, 'O Mundo é dos Jovens S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146844.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57072, 3865, 'O Mundo é dos Jovens S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146845.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57073, 3865, 'O Mundo é dos Jovens S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146846.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57074, 3865, 'O Mundo é dos Jovens S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146847.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57075, 3865, 'O Mundo é dos Jovens S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146848.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57076, 3865, 'O Mundo é dos Jovens S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146849.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57077, 3865, 'O Mundo é dos Jovens S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146850.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57078, 3865, 'O Mundo é dos Jovens S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146851.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57079, 3865, 'O Mundo é dos Jovens S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/146852.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57080, 3865, 'O Mundo é dos Jovens S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/146853.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57081, 3865, 'O Mundo é dos Jovens S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/146854.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57082, 3865, 'O Mundo é dos Jovens S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/146855.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57083, 3865, 'O Mundo é dos Jovens S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/146856.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57084, 3865, 'O Mundo é dos Jovens S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/146857.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57085, 3866, 'O Mundo é dos Jovens S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146858.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57086, 3866, 'O Mundo é dos Jovens S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146859.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57087, 3866, 'O Mundo é dos Jovens S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146860.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57088, 3866, 'O Mundo é dos Jovens S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146861.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57089, 3866, 'O Mundo é dos Jovens S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146862.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57090, 3866, 'O Mundo é dos Jovens S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146863.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57091, 3866, 'O Mundo é dos Jovens S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146864.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57092, 3866, 'O Mundo é dos Jovens S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146865.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57093, 3866, 'O Mundo é dos Jovens S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146866.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57094, 3866, 'O Mundo é dos Jovens S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146867.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57095, 3866, 'O Mundo é dos Jovens S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146868.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57096, 3866, 'O Mundo é dos Jovens S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146869.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57097, 3866, 'O Mundo é dos Jovens S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146870.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57098, 3866, 'O Mundo é dos Jovens S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146871.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57099, 3866, 'O Mundo é dos Jovens S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146872.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57100, 3866, 'O Mundo é dos Jovens S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146873.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57101, 3866, 'O Mundo é dos Jovens S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146874.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57102, 3866, 'O Mundo é dos Jovens S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146875.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57103, 3866, 'O Mundo é dos Jovens S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/146876.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57104, 3866, 'O Mundo é dos Jovens S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/146877.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57105, 3866, 'O Mundo é dos Jovens S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/146878.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57106, 3866, 'O Mundo é dos Jovens S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/146879.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57107, 3867, 'O Mundo é dos Jovens S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146880.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57108, 3867, 'O Mundo é dos Jovens S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146881.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57109, 3867, 'O Mundo é dos Jovens S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146882.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57110, 3867, 'O Mundo é dos Jovens S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146883.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57111, 3867, 'O Mundo é dos Jovens S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146884.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57112, 3867, 'O Mundo é dos Jovens S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146885.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57113, 3867, 'O Mundo é dos Jovens S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146886.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57114, 3867, 'O Mundo é dos Jovens S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146887.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57115, 3867, 'O Mundo é dos Jovens S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146888.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57116, 3867, 'O Mundo é dos Jovens S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146889.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57117, 3867, 'O Mundo é dos Jovens S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146890.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57118, 3867, 'O Mundo é dos Jovens S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146891.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57119, 3867, 'O Mundo é dos Jovens S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146892.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57120, 3867, 'O Mundo é dos Jovens S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146893.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57121, 3867, 'O Mundo é dos Jovens S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146894.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57122, 3867, 'O Mundo é dos Jovens S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146895.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57123, 3867, 'O Mundo é dos Jovens S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146896.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57124, 3867, 'O Mundo é dos Jovens S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146897.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57125, 3867, 'O Mundo é dos Jovens S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/146898.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57126, 3867, 'O Mundo é dos Jovens S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/146899.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57127, 3867, 'O Mundo é dos Jovens S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/146900.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57128, 3867, 'O Mundo é dos Jovens S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/146901.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57129, 3867, 'O Mundo é dos Jovens S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/146902.mp4', 'http://gstaticontent.com/images/dZEWsfaC4MI9plOOWAy7SjuOy1_big.jpg'),
(57130, 3868, 'A Catedral do Mar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146744.mp4', 'http://gstaticontent.com/images/ogUB0lkoQ6VHVQ40H3uYIxptsEo_big.jpg'),
(57131, 3868, 'A Catedral do Mar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146745.mp4', 'http://gstaticontent.com/images/ogUB0lkoQ6VHVQ40H3uYIxptsEo_big.jpg'),
(57132, 3868, 'A Catedral do Mar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146746.mp4', 'http://gstaticontent.com/images/ogUB0lkoQ6VHVQ40H3uYIxptsEo_big.jpg'),
(57133, 3868, 'A Catedral do Mar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146747.mp4', 'http://gstaticontent.com/images/ogUB0lkoQ6VHVQ40H3uYIxptsEo_big.jpg'),
(57134, 3868, 'A Catedral do Mar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146748.mp4', 'http://gstaticontent.com/images/ogUB0lkoQ6VHVQ40H3uYIxptsEo_big.jpg'),
(57135, 3868, 'A Catedral do Mar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146749.mp4', 'http://gstaticontent.com/images/ogUB0lkoQ6VHVQ40H3uYIxptsEo_big.jpg'),
(57136, 3868, 'A Catedral do Mar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146750.mp4', 'http://gstaticontent.com/images/ogUB0lkoQ6VHVQ40H3uYIxptsEo_big.jpg'),
(57137, 3868, 'A Catedral do Mar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146751.mp4', 'http://gstaticontent.com/images/ogUB0lkoQ6VHVQ40H3uYIxptsEo_big.jpg'),
(57138, 3869, 'Brasil Imperial S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146734.mp4', 'http://gstaticontent.com/images/4BnXpUXOKjkxl3KaUkO9ff67CS5_big.jpg'),
(57139, 3869, 'Brasil Imperial S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146735.mp4', 'http://gstaticontent.com/images/4BnXpUXOKjkxl3KaUkO9ff67CS5_big.jpg'),
(57140, 3869, 'Brasil Imperial S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146736.mp4', 'http://gstaticontent.com/images/4BnXpUXOKjkxl3KaUkO9ff67CS5_big.jpg'),
(57141, 3869, 'Brasil Imperial S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146737.mp4', 'http://gstaticontent.com/images/4BnXpUXOKjkxl3KaUkO9ff67CS5_big.jpg'),
(57142, 3869, 'Brasil Imperial S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146738.mp4', 'http://gstaticontent.com/images/4BnXpUXOKjkxl3KaUkO9ff67CS5_big.jpg'),
(57143, 3869, 'Brasil Imperial S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146739.mp4', 'http://gstaticontent.com/images/4BnXpUXOKjkxl3KaUkO9ff67CS5_big.jpg'),
(57144, 3869, 'Brasil Imperial S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146740.mp4', 'http://gstaticontent.com/images/4BnXpUXOKjkxl3KaUkO9ff67CS5_big.jpg'),
(57145, 3869, 'Brasil Imperial S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146741.mp4', 'http://gstaticontent.com/images/4BnXpUXOKjkxl3KaUkO9ff67CS5_big.jpg'),
(57146, 3869, 'Brasil Imperial S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146742.mp4', 'http://gstaticontent.com/images/4BnXpUXOKjkxl3KaUkO9ff67CS5_big.jpg'),
(57147, 3869, 'Brasil Imperial S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146743.mp4', 'http://gstaticontent.com/images/4BnXpUXOKjkxl3KaUkO9ff67CS5_big.jpg'),
(57148, 3870, 'Katla S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146726.mp4', 'http://gstaticontent.com/images/vRPDQP51i1Z2RuoIQaxVSj7Pd5R_big.jpg'),
(57149, 3870, 'Katla S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146727.mp4', 'http://gstaticontent.com/images/vRPDQP51i1Z2RuoIQaxVSj7Pd5R_big.jpg'),
(57150, 3870, 'Katla S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146728.mp4', 'http://gstaticontent.com/images/vRPDQP51i1Z2RuoIQaxVSj7Pd5R_big.jpg'),
(57151, 3870, 'Katla S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146729.mp4', 'http://gstaticontent.com/images/vRPDQP51i1Z2RuoIQaxVSj7Pd5R_big.jpg'),
(57152, 3870, 'Katla S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146730.mp4', 'http://gstaticontent.com/images/vRPDQP51i1Z2RuoIQaxVSj7Pd5R_big.jpg'),
(57153, 3870, 'Katla S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146731.mp4', 'http://gstaticontent.com/images/vRPDQP51i1Z2RuoIQaxVSj7Pd5R_big.jpg'),
(57154, 3870, 'Katla S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146732.mp4', 'http://gstaticontent.com/images/vRPDQP51i1Z2RuoIQaxVSj7Pd5R_big.jpg'),
(57155, 3870, 'Katla S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146733.mp4', 'http://gstaticontent.com/images/vRPDQP51i1Z2RuoIQaxVSj7Pd5R_big.jpg'),
(57156, 3871, 'A Comissária de Bordo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180289.mp4', 'http://gstaticontent.com/images/6f146b01eb7138f623a486f8c8487f90.jpg'),
(57157, 3871, 'A Comissária de Bordo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180290.mp4', 'http://gstaticontent.com/images/6f146b01eb7138f623a486f8c8487f90.jpg'),
(57158, 3871, 'A Comissária de Bordo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180291.mp4', 'http://gstaticontent.com/images/6f146b01eb7138f623a486f8c8487f90.jpg'),
(57159, 3871, 'A Comissária de Bordo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180292.mp4', 'http://gstaticontent.com/images/6f146b01eb7138f623a486f8c8487f90.jpg'),
(57160, 3871, 'A Comissária de Bordo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180293.mp4', 'http://gstaticontent.com/images/6f146b01eb7138f623a486f8c8487f90.jpg'),
(57161, 3871, 'A Comissária de Bordo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180294.mp4', 'http://gstaticontent.com/images/6f146b01eb7138f623a486f8c8487f90.jpg'),
(57162, 3871, 'A Comissária de Bordo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180295.mp4', 'http://gstaticontent.com/images/6f146b01eb7138f623a486f8c8487f90.jpg'),
(57163, 3871, 'A Comissária de Bordo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180296.mp4', 'http://gstaticontent.com/images/6f146b01eb7138f623a486f8c8487f90.jpg'),
(57164, 3872, 'A Comissária de Bordo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180297.mp4', 'http://timg.bdta.pro/images/342618e5fd8892324e8ae8dc91716fe3.jpg'),
(57165, 3872, 'A Comissária de Bordo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180298.mp4', 'http://timg.bdta.pro/images/e5c810178f657a09b13e3bb3c2f72ecb.jpg'),
(57166, 3872, 'A Comissária de Bordo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180299.mp4', 'http://timg.bdta.pro/images/16655c5147c606a5ffe4fa3b7030224d.jpg'),
(57167, 3872, 'A Comissária de Bordo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180300.mp4', 'http://timg.bdta.pro/images/1fae6c3bd6bbb9a6a770d9ba7a893745.jpg'),
(57168, 3872, 'A Comissária de Bordo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180301.mp4', 'http://timg.bdta.pro/images/b9c599d10d1ea270ecafbf63c9b5357f.jpg'),
(57169, 3872, 'A Comissária de Bordo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180302.mp4', 'http://timg.bdta.pro/images/efa506694a1b4ca94a5b395dde2159a3.jpg'),
(57170, 3872, 'A Comissária de Bordo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180303.mp4', 'http://timg.bdta.pro/images/640792db541cea1a0af3a87fbcd56532.jpg'),
(57171, 3872, 'A Comissária de Bordo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180304.mp4', 'http://timg.bdta.pro/images/ff2459d7761171454c05acf3995a9409.jpg'),
(57172, 3873, 'Mundo Bita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146698.mp4', 'http://gstaticontent.com/images/19xWCmiOlwKKpTXBibmAkaLKT1q_big.jpg'),
(57173, 3873, 'Mundo Bita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146699.mp4', 'http://gstaticontent.com/images/19xWCmiOlwKKpTXBibmAkaLKT1q_big.jpg'),
(57174, 3873, 'Mundo Bita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146700.mp4', 'http://gstaticontent.com/images/19xWCmiOlwKKpTXBibmAkaLKT1q_big.jpg'),
(57175, 3873, 'Mundo Bita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146701.mp4', 'http://gstaticontent.com/images/19xWCmiOlwKKpTXBibmAkaLKT1q_big.jpg'),
(57176, 3873, 'Mundo Bita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146702.mp4', 'http://gstaticontent.com/images/19xWCmiOlwKKpTXBibmAkaLKT1q_big.jpg'),
(57177, 3873, 'Mundo Bita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146703.mp4', 'http://gstaticontent.com/images/19xWCmiOlwKKpTXBibmAkaLKT1q_big.jpg'),
(57178, 3873, 'Mundo Bita S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146704.mp4', 'http://gstaticontent.com/images/19xWCmiOlwKKpTXBibmAkaLKT1q_big.jpg'),
(57179, 3873, 'Mundo Bita S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146705.mp4', 'http://gstaticontent.com/images/19xWCmiOlwKKpTXBibmAkaLKT1q_big.jpg'),
(57180, 3873, 'Mundo Bita S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146706.mp4', 'http://gstaticontent.com/images/19xWCmiOlwKKpTXBibmAkaLKT1q_big.jpg'),
(57181, 3873, 'Mundo Bita S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146707.mp4', 'http://gstaticontent.com/images/19xWCmiOlwKKpTXBibmAkaLKT1q_big.jpg'),
(57182, 3873, 'Mundo Bita S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146708.mp4', 'http://gstaticontent.com/images/19xWCmiOlwKKpTXBibmAkaLKT1q_big.jpg'),
(57183, 3873, 'Mundo Bita S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146709.mp4', 'http://gstaticontent.com/images/19xWCmiOlwKKpTXBibmAkaLKT1q_big.jpg'),
(57184, 3873, 'Mundo Bita S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146710.mp4', 'http://gstaticontent.com/images/19xWCmiOlwKKpTXBibmAkaLKT1q_big.jpg'),
(57185, 3873, 'Mundo Bita S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146711.mp4', 'http://gstaticontent.com/images/19xWCmiOlwKKpTXBibmAkaLKT1q_big.jpg'),
(57186, 3873, 'Mundo Bita S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146712.mp4', 'http://gstaticontent.com/images/19xWCmiOlwKKpTXBibmAkaLKT1q_big.jpg'),
(57187, 3873, 'Mundo Bita S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146713.mp4', 'http://gstaticontent.com/images/19xWCmiOlwKKpTXBibmAkaLKT1q_big.jpg'),
(57188, 3874, 'Black Summer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146682.mp4', 'http://gstaticontent.com/images/gx36rMh4CyZAZLVpypkNBhPsFT5_big.jpg'),
(57189, 3874, 'Black Summer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146683.mp4', 'http://gstaticontent.com/images/gx36rMh4CyZAZLVpypkNBhPsFT5_big.jpg'),
(57190, 3874, 'Black Summer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146684.mp4', 'http://gstaticontent.com/images/gx36rMh4CyZAZLVpypkNBhPsFT5_big.jpg'),
(57191, 3874, 'Black Summer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146685.mp4', 'http://gstaticontent.com/images/gx36rMh4CyZAZLVpypkNBhPsFT5_big.jpg'),
(57192, 3874, 'Black Summer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146686.mp4', 'http://gstaticontent.com/images/gx36rMh4CyZAZLVpypkNBhPsFT5_big.jpg'),
(57193, 3874, 'Black Summer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146687.mp4', 'http://gstaticontent.com/images/gx36rMh4CyZAZLVpypkNBhPsFT5_big.jpg'),
(57194, 3874, 'Black Summer S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146688.mp4', 'http://gstaticontent.com/images/gx36rMh4CyZAZLVpypkNBhPsFT5_big.jpg'),
(57195, 3874, 'Black Summer S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146689.mp4', 'http://gstaticontent.com/images/gx36rMh4CyZAZLVpypkNBhPsFT5_big.jpg'),
(57196, 3875, 'Black Summer S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146690.mp4', 'http://gstaticontent.com/images/gx36rMh4CyZAZLVpypkNBhPsFT5_big.jpg'),
(57197, 3875, 'Black Summer S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146691.mp4', 'http://gstaticontent.com/images/gx36rMh4CyZAZLVpypkNBhPsFT5_big.jpg'),
(57198, 3875, 'Black Summer S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146692.mp4', 'http://gstaticontent.com/images/gx36rMh4CyZAZLVpypkNBhPsFT5_big.jpg'),
(57199, 3875, 'Black Summer S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146693.mp4', 'http://gstaticontent.com/images/gx36rMh4CyZAZLVpypkNBhPsFT5_big.jpg'),
(57200, 3875, 'Black Summer S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146694.mp4', 'http://gstaticontent.com/images/gx36rMh4CyZAZLVpypkNBhPsFT5_big.jpg'),
(57201, 3875, 'Black Summer S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146695.mp4', 'http://gstaticontent.com/images/gx36rMh4CyZAZLVpypkNBhPsFT5_big.jpg'),
(57202, 3875, 'Black Summer S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146696.mp4', 'http://gstaticontent.com/images/gx36rMh4CyZAZLVpypkNBhPsFT5_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(57203, 3875, 'Black Summer S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146697.mp4', 'http://gstaticontent.com/images/gx36rMh4CyZAZLVpypkNBhPsFT5_big.jpg'),
(57204, 3876, 'Meu Amigo Bussunda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146678.mp4', 'http://gstaticontent.com/images/wvbnMgIUwSQ0lhagRcltkbI3mnn_big.jpg'),
(57205, 3876, 'Meu Amigo Bussunda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146679.mp4', 'http://gstaticontent.com/images/wvbnMgIUwSQ0lhagRcltkbI3mnn_big.jpg'),
(57206, 3876, 'Meu Amigo Bussunda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146680.mp4', 'http://gstaticontent.com/images/wvbnMgIUwSQ0lhagRcltkbI3mnn_big.jpg'),
(57207, 3876, 'Meu Amigo Bussunda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146681.mp4', 'http://gstaticontent.com/images/wvbnMgIUwSQ0lhagRcltkbI3mnn_big.jpg'),
(57208, 3877, 'Record of Ragnarok S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223414.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57209, 3877, 'Record of Ragnarok S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223415.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57210, 3877, 'Record of Ragnarok S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223416.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57211, 3877, 'Record of Ragnarok S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223417.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57212, 3877, 'Record of Ragnarok S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223418.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57213, 3877, 'Record of Ragnarok S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223419.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57214, 3877, 'Record of Ragnarok S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223420.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57215, 3877, 'Record of Ragnarok S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223421.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57216, 3877, 'Record of Ragnarok S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223422.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57217, 3877, 'Record of Ragnarok S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223423.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57218, 3877, 'Record of Ragnarok S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223424.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57219, 3877, 'Record of Ragnarok S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223425.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57220, 3878, 'Record of Ragnarok S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mh6NE9pf8KrbShE1Pk5nhCmUxll.jpg'),
(57221, 3878, 'Record of Ragnarok S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wDWKKUf0kBrijWUDUbKh8suN0Ic.jpg'),
(57222, 3878, 'Record of Ragnarok S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bDHHRMoVzU3El1Us9Iptk9wzBXc.jpg'),
(57223, 3878, 'Record of Ragnarok S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Is4ayGRXryxrwaoTBDZaL71eb.jpg'),
(57224, 3878, 'Record of Ragnarok S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ragUTF0S1STwB3j2OdeqsGBJnoN.jpg'),
(57225, 3878, 'Record of Ragnarok S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AqfLehARGiJN8d76n7YPz4DhBke.jpg'),
(57226, 3878, 'Record of Ragnarok S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c9FHQKuAqWBdA4MIDzsIlNAWCXE.jpg'),
(57227, 3878, 'Record of Ragnarok S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ghFpzWrDTBuUtXEbnSgYglvZM6n.jpg'),
(57228, 3878, 'Record of Ragnarok S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/571165.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oj0p3YznwlEw9KUwL5hSjH45BbR.jpg'),
(57229, 3878, 'Record of Ragnarok S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pT7DF9d5qJpTRfia1SVJ8c6HPoe.jpg'),
(57230, 3878, 'Record of Ragnarok S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/896729.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57231, 3878, 'Record of Ragnarok S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/poFlCcZG5wlJcPy2xrl2ZW0Lzg6.jpg'),
(57232, 3878, 'Record of Ragnarok S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/896730.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57233, 3878, 'Record of Ragnarok S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/223438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uzJEipxL96FHjRf0efarRwHdDW3.jpg'),
(57234, 3878, 'Record of Ragnarok S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/896731.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57235, 3878, 'Record of Ragnarok S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/223439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uvMrqXRRmNKA2EOa1mF2uCE6XLy.jpg'),
(57236, 3878, 'Record of Ragnarok S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/896732.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57237, 3878, 'Record of Ragnarok S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/223440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nVUnxauKpU3abIYRdVfKV7tCTf3.jpg'),
(57238, 3878, 'Record of Ragnarok S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/896733.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57239, 3878, 'Record of Ragnarok S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/896734.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57240, 3878, 'Record of Ragnarok S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/223441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gNZe7sHTcilhjeihFKfoz1V2q9A.jpg'),
(57241, 3879, 'Record of Ragnarok S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/896750.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57242, 3879, 'Record of Ragnarok S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/896751.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57243, 3879, 'Record of Ragnarok S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/896752.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57244, 3879, 'Record of Ragnarok S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/896753.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57245, 3879, 'Record of Ragnarok S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/896754.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57246, 3879, 'Record of Ragnarok S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/896755.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57247, 3879, 'Record of Ragnarok S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/896756.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57248, 3879, 'Record of Ragnarok S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/896757.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57249, 3879, 'Record of Ragnarok S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/896758.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57250, 3879, 'Record of Ragnarok S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/896759.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57251, 3879, 'Record of Ragnarok S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/896760.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57252, 3879, 'Record of Ragnarok S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/896761.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57253, 3879, 'Record of Ragnarok S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/896762.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57254, 3879, 'Record of Ragnarok S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/896763.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57255, 3879, 'Record of Ragnarok S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/896764.mp4', 'http://gstaticontent.com/images/ygE1AEV6pXFuCzbjS9ts59LxDm5_big.jpg'),
(57256, 3880, 'Segredos em Sulphur Springs S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219538.mp4', 'http://gstaticontent.com/images/i8NL3NNbuF3yWXANo1V6ki7aiPd_big.jpg'),
(57257, 3880, 'Segredos em Sulphur Springs S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219539.mp4', 'http://gstaticontent.com/images/i8NL3NNbuF3yWXANo1V6ki7aiPd_big.jpg'),
(57258, 3880, 'Segredos em Sulphur Springs S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219540.mp4', 'http://gstaticontent.com/images/i8NL3NNbuF3yWXANo1V6ki7aiPd_big.jpg'),
(57259, 3880, 'Segredos em Sulphur Springs S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219541.mp4', 'http://gstaticontent.com/images/i8NL3NNbuF3yWXANo1V6ki7aiPd_big.jpg'),
(57260, 3880, 'Segredos em Sulphur Springs S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219542.mp4', 'http://gstaticontent.com/images/i8NL3NNbuF3yWXANo1V6ki7aiPd_big.jpg'),
(57261, 3880, 'Segredos em Sulphur Springs S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219543.mp4', 'http://gstaticontent.com/images/i8NL3NNbuF3yWXANo1V6ki7aiPd_big.jpg'),
(57262, 3880, 'Segredos em Sulphur Springs S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219544.mp4', 'http://gstaticontent.com/images/i8NL3NNbuF3yWXANo1V6ki7aiPd_big.jpg'),
(57263, 3880, 'Segredos em Sulphur Springs S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219545.mp4', 'http://gstaticontent.com/images/i8NL3NNbuF3yWXANo1V6ki7aiPd_big.jpg'),
(57264, 3880, 'Segredos em Sulphur Springs S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219546.mp4', 'http://gstaticontent.com/images/i8NL3NNbuF3yWXANo1V6ki7aiPd_big.jpg'),
(57265, 3880, 'Segredos em Sulphur Springs S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219547.mp4', 'http://gstaticontent.com/images/i8NL3NNbuF3yWXANo1V6ki7aiPd_big.jpg'),
(57266, 3880, 'Segredos em Sulphur Springs S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219548.mp4', 'http://gstaticontent.com/images/i8NL3NNbuF3yWXANo1V6ki7aiPd_big.jpg'),
(57267, 3881, 'Segredos em Sulphur Springs S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bDiboCkj8foybzzGrqzvJBCKLPK.jpg'),
(57268, 3881, 'Segredos em Sulphur Springs S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219550.mp4', 'http://timg.bdta.pro/images/dfc9ed4a0452d4dc771ff57e6969d640.jpg'),
(57269, 3881, 'Segredos em Sulphur Springs S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219551.mp4', 'http://timg.bdta.pro/images/26bdfef21e6af213bcc6555dc1a1dec5.jpg'),
(57270, 3881, 'Segredos em Sulphur Springs S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219552.mp4', 'http://timg.bdta.pro/images/df0f6537f481b819e4f9ee12e87be1a8.jpg'),
(57271, 3881, 'Segredos em Sulphur Springs S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219553.mp4', 'http://timg.bdta.pro/images/0d9413c2eebc6266f36510ff99d96381.jpg'),
(57272, 3881, 'Segredos em Sulphur Springs S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219554.mp4', 'http://timg.bdta.pro/images/14af0da1c96f7b12211873c9a241385b.jpg'),
(57273, 3881, 'Segredos em Sulphur Springs S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219555.mp4', 'http://timg.bdta.pro/images/4a21430135dc6aea3817f9bd98d39915.jpg'),
(57274, 3881, 'Segredos em Sulphur Springs S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219556.mp4', 'http://timg.bdta.pro/images/91eefdd09122d5ecf9f2267901557e09.jpg'),
(57275, 3882, 'Segredos em Sulphur Springs S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mnYJSkE8rKuk0POv291Bj3alOl3.jpg'),
(57276, 3882, 'Segredos em Sulphur Springs S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v0fZ9cgYitmxtc5hu7nPnSX51QV.jpg'),
(57277, 3882, 'Segredos em Sulphur Springs S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u2lxv17wKZLtZwdODvfoD4wvhya.jpg'),
(57278, 3882, 'Segredos em Sulphur Springs S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ncDwAN1skpfWDNBRlMI7vnbMpV.jpg'),
(57279, 3882, 'Segredos em Sulphur Springs S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4CAY2A4Eoor5hlBcsnvV7hBFa1w.jpg'),
(57280, 3882, 'Segredos em Sulphur Springs S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bDlLwHrE2ziwWLSoKswL8Tb1oGe.jpg'),
(57281, 3882, 'Segredos em Sulphur Springs S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wX4N8IVaA6cmqQCOqbZVOGK5h6g.jpg'),
(57282, 3882, 'Segredos em Sulphur Springs S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219564.mp4', 'http://gstaticontent.com/images/i8NL3NNbuF3yWXANo1V6ki7aiPd_big.jpg'),
(57283, 3883, 'Anatomia do Crime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146559.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57284, 3883, 'Anatomia do Crime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146560.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57285, 3883, 'Anatomia do Crime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146561.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57286, 3883, 'Anatomia do Crime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146562.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57287, 3883, 'Anatomia do Crime S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146563.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57288, 3883, 'Anatomia do Crime S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146564.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57289, 3883, 'Anatomia do Crime S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146565.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57290, 3883, 'Anatomia do Crime S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146566.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57291, 3883, 'Anatomia do Crime S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146567.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57292, 3883, 'Anatomia do Crime S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146568.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57293, 3884, 'Anatomia do Crime S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146569.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57294, 3884, 'Anatomia do Crime S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146570.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57295, 3884, 'Anatomia do Crime S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146571.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57296, 3884, 'Anatomia do Crime S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146572.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57297, 3884, 'Anatomia do Crime S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146573.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57298, 3884, 'Anatomia do Crime S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146574.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57299, 3884, 'Anatomia do Crime S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146575.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57300, 3884, 'Anatomia do Crime S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146576.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57301, 3884, 'Anatomia do Crime S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146577.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57302, 3884, 'Anatomia do Crime S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146578.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57303, 3885, 'Anatomia do Crime S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146579.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57304, 3885, 'Anatomia do Crime S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146580.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57305, 3885, 'Anatomia do Crime S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146581.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57306, 3885, 'Anatomia do Crime S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146582.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57307, 3885, 'Anatomia do Crime S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146583.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57308, 3885, 'Anatomia do Crime S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146584.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57309, 3885, 'Anatomia do Crime S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146585.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57310, 3885, 'Anatomia do Crime S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146586.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57311, 3885, 'Anatomia do Crime S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146587.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57312, 3885, 'Anatomia do Crime S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146588.mp4', 'http://gstaticontent.com/images/mQ0VqAyB1k1KJv3Momo1t5VxOy2_big.jpg'),
(57313, 3886, 'As Terríveis Aventuras de Billy e Mandy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146483.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57314, 3886, 'As Terríveis Aventuras de Billy e Mandy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146484.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57315, 3886, 'As Terríveis Aventuras de Billy e Mandy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146485.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57316, 3886, 'As Terríveis Aventuras de Billy e Mandy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146486.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57317, 3886, 'As Terríveis Aventuras de Billy e Mandy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146487.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57318, 3886, 'As Terríveis Aventuras de Billy e Mandy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146488.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57319, 3886, 'As Terríveis Aventuras de Billy e Mandy S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146489.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57320, 3886, 'As Terríveis Aventuras de Billy e Mandy S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146490.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57321, 3886, 'As Terríveis Aventuras de Billy e Mandy S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146491.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57322, 3886, 'As Terríveis Aventuras de Billy e Mandy S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146492.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57323, 3886, 'As Terríveis Aventuras de Billy e Mandy S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146493.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57324, 3886, 'As Terríveis Aventuras de Billy e Mandy S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146494.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57325, 3886, 'As Terríveis Aventuras de Billy e Mandy S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146495.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57326, 3887, 'As Terríveis Aventuras de Billy e Mandy S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146496.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57327, 3887, 'As Terríveis Aventuras de Billy e Mandy S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146497.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57328, 3887, 'As Terríveis Aventuras de Billy e Mandy S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146498.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57329, 3887, 'As Terríveis Aventuras de Billy e Mandy S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146499.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57330, 3887, 'As Terríveis Aventuras de Billy e Mandy S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146500.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57331, 3887, 'As Terríveis Aventuras de Billy e Mandy S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146501.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57332, 3887, 'As Terríveis Aventuras de Billy e Mandy S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146502.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57333, 3887, 'As Terríveis Aventuras de Billy e Mandy S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146503.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57334, 3887, 'As Terríveis Aventuras de Billy e Mandy S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146504.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57335, 3887, 'As Terríveis Aventuras de Billy e Mandy S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146505.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57336, 3887, 'As Terríveis Aventuras de Billy e Mandy S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146506.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57337, 3887, 'As Terríveis Aventuras de Billy e Mandy S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146507.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57338, 3887, 'As Terríveis Aventuras de Billy e Mandy S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146508.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57339, 3888, 'As Terríveis Aventuras de Billy e Mandy S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146509.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57340, 3888, 'As Terríveis Aventuras de Billy e Mandy S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146510.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57341, 3888, 'As Terríveis Aventuras de Billy e Mandy S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146511.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57342, 3888, 'As Terríveis Aventuras de Billy e Mandy S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146512.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57343, 3888, 'As Terríveis Aventuras de Billy e Mandy S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146513.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57344, 3888, 'As Terríveis Aventuras de Billy e Mandy S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146514.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57345, 3888, 'As Terríveis Aventuras de Billy e Mandy S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146515.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57346, 3888, 'As Terríveis Aventuras de Billy e Mandy S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146516.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57347, 3888, 'As Terríveis Aventuras de Billy e Mandy S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146517.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57348, 3888, 'As Terríveis Aventuras de Billy e Mandy S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146518.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57349, 3888, 'As Terríveis Aventuras de Billy e Mandy S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146519.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57350, 3888, 'As Terríveis Aventuras de Billy e Mandy S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146520.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57351, 3888, 'As Terríveis Aventuras de Billy e Mandy S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146521.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57352, 3889, 'As Terríveis Aventuras de Billy e Mandy S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146522.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57353, 3889, 'As Terríveis Aventuras de Billy e Mandy S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146523.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57354, 3889, 'As Terríveis Aventuras de Billy e Mandy S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146524.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57355, 3889, 'As Terríveis Aventuras de Billy e Mandy S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146525.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57356, 3889, 'As Terríveis Aventuras de Billy e Mandy S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146526.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57357, 3889, 'As Terríveis Aventuras de Billy e Mandy S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146527.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57358, 3889, 'As Terríveis Aventuras de Billy e Mandy S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146528.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57359, 3889, 'As Terríveis Aventuras de Billy e Mandy S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146529.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57360, 3889, 'As Terríveis Aventuras de Billy e Mandy S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146530.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57361, 3889, 'As Terríveis Aventuras de Billy e Mandy S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146531.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57362, 3889, 'As Terríveis Aventuras de Billy e Mandy S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146532.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57363, 3889, 'As Terríveis Aventuras de Billy e Mandy S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146533.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57364, 3889, 'As Terríveis Aventuras de Billy e Mandy S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146534.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57365, 3890, 'As Terríveis Aventuras de Billy e Mandy S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146535.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57366, 3890, 'As Terríveis Aventuras de Billy e Mandy S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146536.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57367, 3890, 'As Terríveis Aventuras de Billy e Mandy S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146537.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57368, 3890, 'As Terríveis Aventuras de Billy e Mandy S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146538.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57369, 3890, 'As Terríveis Aventuras de Billy e Mandy S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146539.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57370, 3890, 'As Terríveis Aventuras de Billy e Mandy S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146540.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57371, 3890, 'As Terríveis Aventuras de Billy e Mandy S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146541.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57372, 3890, 'As Terríveis Aventuras de Billy e Mandy S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146542.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57373, 3890, 'As Terríveis Aventuras de Billy e Mandy S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146543.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57374, 3890, 'As Terríveis Aventuras de Billy e Mandy S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146544.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57375, 3890, 'As Terríveis Aventuras de Billy e Mandy S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146545.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57376, 3890, 'As Terríveis Aventuras de Billy e Mandy S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146546.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57377, 3890, 'As Terríveis Aventuras de Billy e Mandy S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146547.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57378, 3891, 'As Terríveis Aventuras de Billy e Mandy S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146548.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57379, 3891, 'As Terríveis Aventuras de Billy e Mandy S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146549.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57380, 3891, 'As Terríveis Aventuras de Billy e Mandy S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146550.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57381, 3891, 'As Terríveis Aventuras de Billy e Mandy S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146551.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57382, 3891, 'As Terríveis Aventuras de Billy e Mandy S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146552.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57383, 3891, 'As Terríveis Aventuras de Billy e Mandy S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146553.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57384, 3891, 'As Terríveis Aventuras de Billy e Mandy S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146554.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57385, 3891, 'As Terríveis Aventuras de Billy e Mandy S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146555.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57386, 3891, 'As Terríveis Aventuras de Billy e Mandy S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146556.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57387, 3891, 'As Terríveis Aventuras de Billy e Mandy S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146557.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57388, 3891, 'As Terríveis Aventuras de Billy e Mandy S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146558.mp4', 'http://gstaticontent.com/images/dctpxTH60v3HWb18Aol5x9HccYv_big.jpg'),
(57389, 3892, 'Godzilla Singular Point S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146470.mp4', 'http://gstaticontent.com/images/macY0UVe8ocAWq8WwYom25WC9Ps_big.jpg'),
(57390, 3892, 'Godzilla Singular Point S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146471.mp4', 'http://gstaticontent.com/images/macY0UVe8ocAWq8WwYom25WC9Ps_big.jpg'),
(57391, 3892, 'Godzilla Singular Point S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146472.mp4', 'http://gstaticontent.com/images/macY0UVe8ocAWq8WwYom25WC9Ps_big.jpg'),
(57392, 3892, 'Godzilla Singular Point S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146473.mp4', 'http://gstaticontent.com/images/macY0UVe8ocAWq8WwYom25WC9Ps_big.jpg'),
(57393, 3892, 'Godzilla Singular Point S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146474.mp4', 'http://gstaticontent.com/images/macY0UVe8ocAWq8WwYom25WC9Ps_big.jpg'),
(57394, 3892, 'Godzilla Singular Point S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146475.mp4', 'http://gstaticontent.com/images/macY0UVe8ocAWq8WwYom25WC9Ps_big.jpg'),
(57395, 3892, 'Godzilla Singular Point S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146476.mp4', 'http://gstaticontent.com/images/macY0UVe8ocAWq8WwYom25WC9Ps_big.jpg'),
(57396, 3892, 'Godzilla Singular Point S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146477.mp4', 'http://gstaticontent.com/images/macY0UVe8ocAWq8WwYom25WC9Ps_big.jpg'),
(57397, 3892, 'Godzilla Singular Point S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146478.mp4', 'http://gstaticontent.com/images/macY0UVe8ocAWq8WwYom25WC9Ps_big.jpg'),
(57398, 3892, 'Godzilla Singular Point S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146479.mp4', 'http://gstaticontent.com/images/macY0UVe8ocAWq8WwYom25WC9Ps_big.jpg'),
(57399, 3892, 'Godzilla Singular Point S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146480.mp4', 'http://gstaticontent.com/images/macY0UVe8ocAWq8WwYom25WC9Ps_big.jpg'),
(57400, 3892, 'Godzilla Singular Point S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146481.mp4', 'http://gstaticontent.com/images/macY0UVe8ocAWq8WwYom25WC9Ps_big.jpg'),
(57401, 3892, 'Godzilla Singular Point S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146482.mp4', 'http://gstaticontent.com/images/macY0UVe8ocAWq8WwYom25WC9Ps_big.jpg'),
(57402, 3893, 'Hit Parade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146462.mp4', 'http://gstaticontent.com/images/1wESx2T2vbBBncfoNQKYK0Y5cB_big.jpg'),
(57403, 3893, 'Hit Parade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146463.mp4', 'http://gstaticontent.com/images/1wESx2T2vbBBncfoNQKYK0Y5cB_big.jpg'),
(57404, 3893, 'Hit Parade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146464.mp4', 'http://gstaticontent.com/images/1wESx2T2vbBBncfoNQKYK0Y5cB_big.jpg'),
(57405, 3893, 'Hit Parade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146465.mp4', 'http://gstaticontent.com/images/1wESx2T2vbBBncfoNQKYK0Y5cB_big.jpg'),
(57406, 3893, 'Hit Parade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146466.mp4', 'http://gstaticontent.com/images/1wESx2T2vbBBncfoNQKYK0Y5cB_big.jpg'),
(57407, 3893, 'Hit Parade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146467.mp4', 'http://gstaticontent.com/images/1wESx2T2vbBBncfoNQKYK0Y5cB_big.jpg'),
(57408, 3893, 'Hit Parade S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146468.mp4', 'http://gstaticontent.com/images/1wESx2T2vbBBncfoNQKYK0Y5cB_big.jpg'),
(57409, 3893, 'Hit Parade S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146469.mp4', 'http://gstaticontent.com/images/1wESx2T2vbBBncfoNQKYK0Y5cB_big.jpg'),
(57410, 3894, 'Me Tira Daqui S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146450.mp4', 'http://gstaticontent.com/images/p1QrNWkuDwqDg8UP8OeMhr3noSa_big.jpg'),
(57411, 3894, 'Me Tira Daqui S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146451.mp4', 'http://gstaticontent.com/images/p1QrNWkuDwqDg8UP8OeMhr3noSa_big.jpg'),
(57412, 3894, 'Me Tira Daqui S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146452.mp4', 'http://gstaticontent.com/images/p1QrNWkuDwqDg8UP8OeMhr3noSa_big.jpg'),
(57413, 3894, 'Me Tira Daqui S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146453.mp4', 'http://gstaticontent.com/images/p1QrNWkuDwqDg8UP8OeMhr3noSa_big.jpg'),
(57414, 3894, 'Me Tira Daqui S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146454.mp4', 'http://gstaticontent.com/images/p1QrNWkuDwqDg8UP8OeMhr3noSa_big.jpg'),
(57415, 3894, 'Me Tira Daqui S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146455.mp4', 'http://gstaticontent.com/images/p1QrNWkuDwqDg8UP8OeMhr3noSa_big.jpg'),
(57416, 3894, 'Me Tira Daqui S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146456.mp4', 'http://gstaticontent.com/images/p1QrNWkuDwqDg8UP8OeMhr3noSa_big.jpg'),
(57417, 3894, 'Me Tira Daqui S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146457.mp4', 'http://gstaticontent.com/images/p1QrNWkuDwqDg8UP8OeMhr3noSa_big.jpg'),
(57418, 3894, 'Me Tira Daqui S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146458.mp4', 'http://gstaticontent.com/images/p1QrNWkuDwqDg8UP8OeMhr3noSa_big.jpg'),
(57419, 3894, 'Me Tira Daqui S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146459.mp4', 'http://gstaticontent.com/images/p1QrNWkuDwqDg8UP8OeMhr3noSa_big.jpg'),
(57420, 3894, 'Me Tira Daqui S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146460.mp4', 'http://gstaticontent.com/images/p1QrNWkuDwqDg8UP8OeMhr3noSa_big.jpg'),
(57421, 3894, 'Me Tira Daqui S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146461.mp4', 'http://gstaticontent.com/images/p1QrNWkuDwqDg8UP8OeMhr3noSa_big.jpg'),
(57422, 3895, 'O DNA da Justiça S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146441.mp4', 'http://gstaticontent.com/images/summ8ctaf2Ho8qpmpqkFNtw5KZg_big.jpg'),
(57423, 3895, 'O DNA da Justiça S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146442.mp4', 'http://gstaticontent.com/images/summ8ctaf2Ho8qpmpqkFNtw5KZg_big.jpg'),
(57424, 3895, 'O DNA da Justiça S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146443.mp4', 'http://gstaticontent.com/images/summ8ctaf2Ho8qpmpqkFNtw5KZg_big.jpg'),
(57425, 3895, 'O DNA da Justiça S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146444.mp4', 'http://gstaticontent.com/images/summ8ctaf2Ho8qpmpqkFNtw5KZg_big.jpg'),
(57426, 3895, 'O DNA da Justiça S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146445.mp4', 'http://gstaticontent.com/images/summ8ctaf2Ho8qpmpqkFNtw5KZg_big.jpg'),
(57427, 3895, 'O DNA da Justiça S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146446.mp4', 'http://gstaticontent.com/images/summ8ctaf2Ho8qpmpqkFNtw5KZg_big.jpg'),
(57428, 3895, 'O DNA da Justiça S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146447.mp4', 'http://gstaticontent.com/images/summ8ctaf2Ho8qpmpqkFNtw5KZg_big.jpg'),
(57429, 3895, 'O DNA da Justiça S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146448.mp4', 'http://gstaticontent.com/images/summ8ctaf2Ho8qpmpqkFNtw5KZg_big.jpg'),
(57430, 3895, 'O DNA da Justiça S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146449.mp4', 'http://gstaticontent.com/images/summ8ctaf2Ho8qpmpqkFNtw5KZg_big.jpg'),
(57431, 3896, 'O Mito de Sísifo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146425.mp4', 'http://gstaticontent.com/images/kpf1SOApAMXtnKHjdCJSbSyiCVe_big.jpg'),
(57432, 3896, 'O Mito de Sísifo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146426.mp4', 'http://gstaticontent.com/images/kpf1SOApAMXtnKHjdCJSbSyiCVe_big.jpg'),
(57433, 3896, 'O Mito de Sísifo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146427.mp4', 'http://gstaticontent.com/images/kpf1SOApAMXtnKHjdCJSbSyiCVe_big.jpg'),
(57434, 3896, 'O Mito de Sísifo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146428.mp4', 'http://gstaticontent.com/images/kpf1SOApAMXtnKHjdCJSbSyiCVe_big.jpg'),
(57435, 3896, 'O Mito de Sísifo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146429.mp4', 'http://gstaticontent.com/images/kpf1SOApAMXtnKHjdCJSbSyiCVe_big.jpg'),
(57436, 3896, 'O Mito de Sísifo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146430.mp4', 'http://gstaticontent.com/images/kpf1SOApAMXtnKHjdCJSbSyiCVe_big.jpg'),
(57437, 3896, 'O Mito de Sísifo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146431.mp4', 'http://gstaticontent.com/images/kpf1SOApAMXtnKHjdCJSbSyiCVe_big.jpg'),
(57438, 3896, 'O Mito de Sísifo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146432.mp4', 'http://gstaticontent.com/images/kpf1SOApAMXtnKHjdCJSbSyiCVe_big.jpg'),
(57439, 3896, 'O Mito de Sísifo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146433.mp4', 'http://gstaticontent.com/images/kpf1SOApAMXtnKHjdCJSbSyiCVe_big.jpg'),
(57440, 3896, 'O Mito de Sísifo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146434.mp4', 'http://gstaticontent.com/images/kpf1SOApAMXtnKHjdCJSbSyiCVe_big.jpg'),
(57441, 3896, 'O Mito de Sísifo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146435.mp4', 'http://gstaticontent.com/images/kpf1SOApAMXtnKHjdCJSbSyiCVe_big.jpg'),
(57442, 3896, 'O Mito de Sísifo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146436.mp4', 'http://gstaticontent.com/images/kpf1SOApAMXtnKHjdCJSbSyiCVe_big.jpg'),
(57443, 3896, 'O Mito de Sísifo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146437.mp4', 'http://gstaticontent.com/images/kpf1SOApAMXtnKHjdCJSbSyiCVe_big.jpg'),
(57444, 3896, 'O Mito de Sísifo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146438.mp4', 'http://gstaticontent.com/images/kpf1SOApAMXtnKHjdCJSbSyiCVe_big.jpg'),
(57445, 3896, 'O Mito de Sísifo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146439.mp4', 'http://gstaticontent.com/images/kpf1SOApAMXtnKHjdCJSbSyiCVe_big.jpg'),
(57446, 3896, 'O Mito de Sísifo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146440.mp4', 'http://gstaticontent.com/images/kpf1SOApAMXtnKHjdCJSbSyiCVe_big.jpg'),
(57447, 3897, 'O Quinteto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171000.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57448, 3897, 'O Quinteto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171001.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57449, 3897, 'O Quinteto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171002.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57450, 3897, 'O Quinteto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171003.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57451, 3897, 'O Quinteto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171004.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57452, 3897, 'O Quinteto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171005.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57453, 3897, 'O Quinteto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171006.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57454, 3897, 'O Quinteto S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171007.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57455, 3897, 'O Quinteto S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171008.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57456, 3897, 'O Quinteto S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171009.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57457, 3897, 'O Quinteto S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171010.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57458, 3897, 'O Quinteto S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171011.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57459, 3897, 'O Quinteto S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171012.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57460, 3897, 'O Quinteto S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171013.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57461, 3897, 'O Quinteto S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171014.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57462, 3897, 'O Quinteto S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171015.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57463, 3897, 'O Quinteto S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171016.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57464, 3897, 'O Quinteto S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171017.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57465, 3897, 'O Quinteto S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/171018.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57466, 3897, 'O Quinteto S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/171019.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57467, 3897, 'O Quinteto S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/171020.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57468, 3897, 'O Quinteto S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/171021.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57469, 3898, 'O Quinteto S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171022.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57470, 3898, 'O Quinteto S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171023.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57471, 3898, 'O Quinteto S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171024.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(57472, 3898, 'O Quinteto S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171025.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57473, 3898, 'O Quinteto S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171026.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57474, 3898, 'O Quinteto S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171027.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57475, 3898, 'O Quinteto S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171028.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57476, 3898, 'O Quinteto S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171029.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57477, 3898, 'O Quinteto S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171030.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57478, 3898, 'O Quinteto S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171031.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57479, 3898, 'O Quinteto S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171032.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57480, 3898, 'O Quinteto S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171033.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57481, 3898, 'O Quinteto S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171034.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57482, 3898, 'O Quinteto S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171035.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57483, 3898, 'O Quinteto S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171036.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57484, 3898, 'O Quinteto S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171037.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57485, 3898, 'O Quinteto S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171038.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57486, 3898, 'O Quinteto S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171039.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57487, 3898, 'O Quinteto S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/171040.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57488, 3898, 'O Quinteto S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/171041.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57489, 3898, 'O Quinteto S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/171042.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57490, 3898, 'O Quinteto S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/171043.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57491, 3899, 'O Quinteto S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tZUiVlpbvetxrST1rIs6wVoJ4oy.jpg'),
(57492, 3899, 'O Quinteto S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sWOttKHgxoOUYmuknOhgeOH0BNa.jpg'),
(57493, 3899, 'O Quinteto S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vHuv4NN3gCm1LmqRSbne9Q2z256.jpg'),
(57494, 3899, 'O Quinteto S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wLog8AUIfn4h5I30G2idGyV85kN.jpg'),
(57495, 3899, 'O Quinteto S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ca5RXlVTmzecaF5a64Q5FATxvKF.jpg'),
(57496, 3899, 'O Quinteto S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4vVEIbkrYw7nVMPhM2kbhTOPVIW.jpg'),
(57497, 3899, 'O Quinteto S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTYu6WoYK1wCwE9XlL5YZ0V2jBc.jpg'),
(57498, 3899, 'O Quinteto S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5F5xsEu7xux3FjKio7O8oBeqnky.jpg'),
(57499, 3899, 'O Quinteto S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2VUWl2Jx4H8tIJ9fyK01uMzVf2.jpg'),
(57500, 3899, 'O Quinteto S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDO9IolGMNWJMBTnBGJ61X92Rg4.jpg'),
(57501, 3899, 'O Quinteto S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8JluUQk4vumEC3xNhoh3mGApSYg.jpg'),
(57502, 3899, 'O Quinteto S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pHSpoYmf4xvokcfiukHAw2xrH45.jpg'),
(57503, 3899, 'O Quinteto S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wMaJaWyqK0eb99NaSknPltEOfuP.jpg'),
(57504, 3899, 'O Quinteto S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/umrfGnsYvwvyfBEt8gfzdnSQUEO.jpg'),
(57505, 3899, 'O Quinteto S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xGKdXJHbtLrsa7i4s3AD5d7KV97.jpg'),
(57506, 3899, 'O Quinteto S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xumLG53HioIEKuJX9ohQ7K895yp.jpg'),
(57507, 3899, 'O Quinteto S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ahnKPW4TzwqI0VbwvTn3mE7uOk.jpg'),
(57508, 3899, 'O Quinteto S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gEIvNnszUzfqGFtmxJI6kTjJRda.jpg'),
(57509, 3899, 'O Quinteto S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/171062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/CIttei1Pbcb9GE81pwWhVu6RCT.jpg'),
(57510, 3899, 'O Quinteto S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/171063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ukS4jvfNqz7YzL1C2nqXy1II2Rz.jpg'),
(57511, 3899, 'O Quinteto S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/171064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ooTSN8fbONUeiUaJEsrqwUQ9kxd.jpg'),
(57512, 3899, 'O Quinteto S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/171065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3BHTcT1gXISluDPIxFlCscAeHON.jpg'),
(57513, 3899, 'O Quinteto S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/171066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/edBXaqXSNEh8VRHAdsc73TXHKG7.jpg'),
(57514, 3899, 'O Quinteto S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/171067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c9F8EJycKISC1tW62ZXjHhHU4yy.jpg'),
(57515, 3899, 'O Quinteto S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/171068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qz4xwcpHL8piZthBr6kJmBQ7ehI.jpg'),
(57516, 3900, 'O Quinteto S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9BlT1JY8Tb3tj48iQHN0e4AZ2ct.jpg'),
(57517, 3900, 'O Quinteto S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/V0fKPu3PeWeNHxky7ST8VQCbBz.jpg'),
(57518, 3900, 'O Quinteto S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zKfB4yBTdUeEUSqfnfrPkq9krf8.jpg'),
(57519, 3900, 'O Quinteto S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Arab07yKYElkOZZ9glOuXDUhKRJ.jpg'),
(57520, 3900, 'O Quinteto S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyL1z1M3aDs1xNaZCRlZU8Z9Gb5.jpg'),
(57521, 3900, 'O Quinteto S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tdU2rFFqo6OOkmTFoa9xKgmk7j8.jpg'),
(57522, 3900, 'O Quinteto S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hBnznubz1erxnzMw1p5RO8mEgAc.jpg'),
(57523, 3900, 'O Quinteto S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/20Nr9eTkII7upqa3AVbvCQ4pJ8D.jpg'),
(57524, 3900, 'O Quinteto S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/22fDCOUGzJjx4xpeL7SeflnKbaK.jpg'),
(57525, 3900, 'O Quinteto S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/koRIhbw9NvNtcBNtH4x2FglpJJ3.jpg'),
(57526, 3900, 'O Quinteto S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zvaqqW8fCfk5cAIWoFInVQYmPfm.jpg'),
(57527, 3900, 'O Quinteto S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cG6jvVXWGU4n9TSlvZYlwKJKMP6.jpg'),
(57528, 3900, 'O Quinteto S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vM3pkvvHjmfGkppgSLglAW6zBjX.jpg'),
(57529, 3900, 'O Quinteto S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/XZvD55BL2czkpeV73dBXg4irDR.jpg'),
(57530, 3900, 'O Quinteto S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8taL6PXKHG1YvNN8xQU7TfndKf.jpg'),
(57531, 3900, 'O Quinteto S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8hE25DydYdzqPu64KTaeP3v7l2.jpg'),
(57532, 3900, 'O Quinteto S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oc421tjcNwM1He9HaqsCVsQVRym.jpg'),
(57533, 3900, 'O Quinteto S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1kDRi2OUib9vkqs0ldKVB8VlqaN.jpg'),
(57534, 3900, 'O Quinteto S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/171087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ixHpWjdCJ0ws5fWmgzYN3zaZZV.jpg'),
(57535, 3900, 'O Quinteto S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/171088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ihWHLEssOWYoCLTF812v0h5eU5d.jpg'),
(57536, 3900, 'O Quinteto S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/171089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ihWHLEssOWYoCLTF812v0h5eU5d.jpg'),
(57537, 3900, 'O Quinteto S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/171090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nudBKCkr3nx385LpR3dDpSo0h26.jpg'),
(57538, 3900, 'O Quinteto S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/171091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w5tvTuVRz6XGLpnRFYxJYq7MxLT.jpg'),
(57539, 3900, 'O Quinteto S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/171092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2IzlvBSGeIjjkeuEG0sFULR023K.jpg'),
(57540, 3901, 'O Quinteto S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tFLdMXdtJi3IBjRiztyXkToUbU5.jpg'),
(57541, 3901, 'O Quinteto S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6bGSMoOdfAPZjI7z1RuGxBe6IdK.jpg'),
(57542, 3901, 'O Quinteto S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/14HMPVqDPnVmUsqIPz4AnNRMvM4.jpg'),
(57543, 3901, 'O Quinteto S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171096.mp4', 'http://gstaticontent.com/images/9ILyAj7k7nbT5QlZPvDLdUhrCBx_big.jpg'),
(57544, 3901, 'O Quinteto S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/geVrmtFIo7BTeXcc4NAsJWqbIo0.jpg'),
(57545, 3901, 'O Quinteto S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/49O4v7CorfajQdFCxahzHrZoAhG.jpg'),
(57546, 3901, 'O Quinteto S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzxVql55dXRldBB3OjgIlZoDH9G.jpg'),
(57547, 3901, 'O Quinteto S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/riHm0gA6uheC6bWN1zevJGZnLzT.jpg'),
(57548, 3901, 'O Quinteto S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Y4CotpOhXZgqRrV1cbcdTnVtqY.jpg'),
(57549, 3901, 'O Quinteto S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rVbYZhwehgZ44hJtO8QIG1On2gG.jpg'),
(57550, 3901, 'O Quinteto S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5BLQFgHSZdwmJkJEelDSpzQ7Wiu.jpg'),
(57551, 3901, 'O Quinteto S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/myvZsf9INnbLH8w3G4Xg1Jobo5Q.jpg'),
(57552, 3901, 'O Quinteto S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9IK8R9YWKTDknQJnXKZmslUJQAK.jpg'),
(57553, 3901, 'O Quinteto S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hfELCuBRthyR59UCEYDxgbFGLGe.jpg'),
(57554, 3901, 'O Quinteto S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2oWcaj58XPfeIXtHbX7YMlchzvr.jpg'),
(57555, 3901, 'O Quinteto S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6G5z57BWoSZX7n9OexlLrMzpmLF.jpg'),
(57556, 3901, 'O Quinteto S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9HiQIsKkMbu8JKSH9fn4lckiaA.jpg'),
(57557, 3901, 'O Quinteto S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dxXKfPgXFRpWFury94IfoO3c6wi.jpg'),
(57558, 3901, 'O Quinteto S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/171111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1SwDZKtheLsrii3Bo1saktsibf.jpg'),
(57559, 3901, 'O Quinteto S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/171112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l5CfBc6fDaper5vRbc8Cg2Rmo2W.jpg'),
(57560, 3901, 'O Quinteto S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/171113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Z8t7IoOcE80DgJ8wZiyHQWqTHY.jpg'),
(57561, 3901, 'O Quinteto S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/171114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nv8WBMPB4CAKcaO0MomNPVv70uu.jpg'),
(57562, 3901, 'O Quinteto S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/171115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4J9fYhy6Nv5yrqBqT7G3fUuYGwU.jpg'),
(57563, 3901, 'O Quinteto S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/171116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h30BlhKqnpM4fBgutns1veO5tk1.jpg'),
(57564, 3901, 'O Quinteto S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/171117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Id8puMHFFwdinlyDGPkBlmGkdL.jpg'),
(57565, 3901, 'O Quinteto S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/171118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Gyn0oHlym4XkPraWH9nGUZl51U.jpg'),
(57566, 3902, 'Por Dentro da Pixar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146405.mp4', 'http://gstaticontent.com/images/jWSWOEi3ejvC8JviVaiAn7XdZ9j_big.jpg'),
(57567, 3902, 'Por Dentro da Pixar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146406.mp4', 'http://gstaticontent.com/images/jWSWOEi3ejvC8JviVaiAn7XdZ9j_big.jpg'),
(57568, 3902, 'Por Dentro da Pixar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146407.mp4', 'http://gstaticontent.com/images/jWSWOEi3ejvC8JviVaiAn7XdZ9j_big.jpg'),
(57569, 3902, 'Por Dentro da Pixar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146408.mp4', 'http://gstaticontent.com/images/jWSWOEi3ejvC8JviVaiAn7XdZ9j_big.jpg'),
(57570, 3902, 'Por Dentro da Pixar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146409.mp4', 'http://gstaticontent.com/images/jWSWOEi3ejvC8JviVaiAn7XdZ9j_big.jpg'),
(57571, 3902, 'Por Dentro da Pixar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146410.mp4', 'http://gstaticontent.com/images/jWSWOEi3ejvC8JviVaiAn7XdZ9j_big.jpg'),
(57572, 3902, 'Por Dentro da Pixar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146411.mp4', 'http://gstaticontent.com/images/jWSWOEi3ejvC8JviVaiAn7XdZ9j_big.jpg'),
(57573, 3902, 'Por Dentro da Pixar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146412.mp4', 'http://gstaticontent.com/images/jWSWOEi3ejvC8JviVaiAn7XdZ9j_big.jpg'),
(57574, 3902, 'Por Dentro da Pixar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146413.mp4', 'http://gstaticontent.com/images/jWSWOEi3ejvC8JviVaiAn7XdZ9j_big.jpg'),
(57575, 3902, 'Por Dentro da Pixar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146414.mp4', 'http://gstaticontent.com/images/jWSWOEi3ejvC8JviVaiAn7XdZ9j_big.jpg'),
(57576, 3902, 'Por Dentro da Pixar S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146415.mp4', 'http://gstaticontent.com/images/jWSWOEi3ejvC8JviVaiAn7XdZ9j_big.jpg'),
(57577, 3902, 'Por Dentro da Pixar S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146416.mp4', 'http://gstaticontent.com/images/jWSWOEi3ejvC8JviVaiAn7XdZ9j_big.jpg'),
(57578, 3902, 'Por Dentro da Pixar S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146417.mp4', 'http://gstaticontent.com/images/jWSWOEi3ejvC8JviVaiAn7XdZ9j_big.jpg'),
(57579, 3902, 'Por Dentro da Pixar S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146418.mp4', 'http://gstaticontent.com/images/jWSWOEi3ejvC8JviVaiAn7XdZ9j_big.jpg'),
(57580, 3902, 'Por Dentro da Pixar S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146419.mp4', 'http://gstaticontent.com/images/jWSWOEi3ejvC8JviVaiAn7XdZ9j_big.jpg'),
(57581, 3902, 'Por Dentro da Pixar S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146420.mp4', 'http://gstaticontent.com/images/jWSWOEi3ejvC8JviVaiAn7XdZ9j_big.jpg'),
(57582, 3902, 'Por Dentro da Pixar S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146421.mp4', 'http://gstaticontent.com/images/jWSWOEi3ejvC8JviVaiAn7XdZ9j_big.jpg'),
(57583, 3902, 'Por Dentro da Pixar S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146422.mp4', 'http://gstaticontent.com/images/jWSWOEi3ejvC8JviVaiAn7XdZ9j_big.jpg'),
(57584, 3902, 'Por Dentro da Pixar S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/146423.mp4', 'http://gstaticontent.com/images/jWSWOEi3ejvC8JviVaiAn7XdZ9j_big.jpg'),
(57585, 3902, 'Por Dentro da Pixar S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/146424.mp4', 'http://gstaticontent.com/images/jWSWOEi3ejvC8JviVaiAn7XdZ9j_big.jpg'),
(57586, 3903, 'This Is Pop S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146397.mp4', 'http://gstaticontent.com/images/6Gst0AfJYYU5UiDXIkuMoj6XB85_big.jpg'),
(57587, 3903, 'This Is Pop S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146398.mp4', 'http://gstaticontent.com/images/6Gst0AfJYYU5UiDXIkuMoj6XB85_big.jpg'),
(57588, 3903, 'This Is Pop S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146399.mp4', 'http://gstaticontent.com/images/6Gst0AfJYYU5UiDXIkuMoj6XB85_big.jpg'),
(57589, 3903, 'This Is Pop S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146400.mp4', 'http://gstaticontent.com/images/6Gst0AfJYYU5UiDXIkuMoj6XB85_big.jpg'),
(57590, 3903, 'This Is Pop S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146401.mp4', 'http://gstaticontent.com/images/6Gst0AfJYYU5UiDXIkuMoj6XB85_big.jpg'),
(57591, 3903, 'This Is Pop S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146402.mp4', 'http://gstaticontent.com/images/6Gst0AfJYYU5UiDXIkuMoj6XB85_big.jpg'),
(57592, 3903, 'This Is Pop S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146403.mp4', 'http://gstaticontent.com/images/6Gst0AfJYYU5UiDXIkuMoj6XB85_big.jpg'),
(57593, 3903, 'This Is Pop S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146404.mp4', 'http://gstaticontent.com/images/6Gst0AfJYYU5UiDXIkuMoj6XB85_big.jpg'),
(57594, 3904, 'We Are Who We Are [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146389.mp4', 'http://gstaticontent.com/images/33btSKKmjmc24hK9Vj1sRWQGfyh_big.jpg'),
(57595, 3904, 'We Are Who We Are [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146390.mp4', 'http://gstaticontent.com/images/33btSKKmjmc24hK9Vj1sRWQGfyh_big.jpg'),
(57596, 3904, 'We Are Who We Are [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146391.mp4', 'http://gstaticontent.com/images/33btSKKmjmc24hK9Vj1sRWQGfyh_big.jpg'),
(57597, 3904, 'We Are Who We Are [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146392.mp4', 'http://gstaticontent.com/images/33btSKKmjmc24hK9Vj1sRWQGfyh_big.jpg'),
(57598, 3904, 'We Are Who We Are [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146393.mp4', 'http://gstaticontent.com/images/33btSKKmjmc24hK9Vj1sRWQGfyh_big.jpg'),
(57599, 3904, 'We Are Who We Are [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146394.mp4', 'http://gstaticontent.com/images/33btSKKmjmc24hK9Vj1sRWQGfyh_big.jpg'),
(57600, 3904, 'We Are Who We Are [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146395.mp4', 'http://gstaticontent.com/images/33btSKKmjmc24hK9Vj1sRWQGfyh_big.jpg'),
(57601, 3904, 'We Are Who We Are [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146396.mp4', 'http://gstaticontent.com/images/33btSKKmjmc24hK9Vj1sRWQGfyh_big.jpg'),
(57602, 3905, 'Doces Magnólias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222290.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57603, 3905, 'Doces Magnólias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222291.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57604, 3905, 'Doces Magnólias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222292.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57605, 3905, 'Doces Magnólias S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222293.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57606, 3905, 'Doces Magnólias S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222294.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57607, 3905, 'Doces Magnólias S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222295.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57608, 3905, 'Doces Magnólias S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222296.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57609, 3905, 'Doces Magnólias S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222297.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57610, 3905, 'Doces Magnólias S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222298.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57611, 3905, 'Doces Magnólias S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222299.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57612, 3906, 'Doces Magnólias S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222300.mp4', 'http://timg.bdta.pro/images/ca324ab30b925172b9a682161a63c499.jpg'),
(57613, 3906, 'Doces Magnólias S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222301.mp4', 'http://timg.bdta.pro/images/9cb4180c80108d45e673d95d294af8df.jpg'),
(57614, 3906, 'Doces Magnólias S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222302.mp4', 'http://timg.bdta.pro/images/708c0fa3c98e3b523c73bdfd5a2a9ed7.jpg'),
(57615, 3906, 'Doces Magnólias S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222303.mp4', 'http://timg.bdta.pro/images/052c6af8a4d3264de8bc37f508d2e782.jpg'),
(57616, 3906, 'Doces Magnólias S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222304.mp4', 'http://timg.bdta.pro/images/9229d4be807f9729540413b95a6e092f.jpg'),
(57617, 3906, 'Doces Magnólias S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222305.mp4', 'http://timg.bdta.pro/images/de0bfb72b8eab62242e1ba1a887a6709.jpg'),
(57618, 3906, 'Doces Magnólias S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222306.mp4', 'http://timg.bdta.pro/images/459f4cf37536f7f4533166f7740507f4.jpg'),
(57619, 3906, 'Doces Magnólias S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222307.mp4', 'http://timg.bdta.pro/images/0986d6750a0248771b8b87b16e9f0439.jpg'),
(57620, 3906, 'Doces Magnólias S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222308.mp4', 'http://timg.bdta.pro/images/0715b9284e534b81d38fd63d087d189a.jpg'),
(57621, 3906, 'Doces Magnólias S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222309.mp4', 'http://timg.bdta.pro/images/2691332e6b1319ae2209e6f157b1384a.jpg'),
(57622, 3907, 'Doces Magnólias S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222310.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57623, 3907, 'Doces Magnólias S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222311.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57624, 3907, 'Doces Magnólias S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222312.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57625, 3907, 'Doces Magnólias S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222313.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57626, 3907, 'Doces Magnólias S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222314.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57627, 3907, 'Doces Magnólias S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222315.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57628, 3907, 'Doces Magnólias S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222316.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57629, 3907, 'Doces Magnólias S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222317.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57630, 3907, 'Doces Magnólias S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222318.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57631, 3907, 'Doces Magnólias S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222319.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57632, 3908, 'Doces Magnólias S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/687795.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57633, 3908, 'Doces Magnólias S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/687796.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57634, 3908, 'Doces Magnólias S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/687797.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57635, 3908, 'Doces Magnólias S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/687798.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57636, 3908, 'Doces Magnólias S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/687799.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57637, 3908, 'Doces Magnólias S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/687800.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57638, 3908, 'Doces Magnólias S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/687801.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57639, 3908, 'Doces Magnólias S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/687802.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57640, 3908, 'Doces Magnólias S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/687803.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57641, 3908, 'Doces Magnólias S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/687804.mp4', 'http://gstaticontent.com/images/nCORacN1hynDTRclAJEWmyJy3iu_big.jpg'),
(57642, 3909, 'Jiraiya: O Incrível Ninja S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149876.mp4', 'http://timg.bdta.pro/images/7b18f4415e148220a2e588b146c4ef87.jpg'),
(57643, 3909, 'Jiraiya: O Incrível Ninja S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149877.mp4', 'http://timg.bdta.pro/images/f70cf38a1c580439e179c62fcac205e4.jpg'),
(57644, 3909, 'Jiraiya: O Incrível Ninja S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149878.mp4', 'http://timg.bdta.pro/images/fcbe63035f8e8fee615e34d680ccefb9.jpg'),
(57645, 3909, 'Jiraiya: O Incrível Ninja S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149879.mp4', 'http://timg.bdta.pro/images/534fd5012753aa339e7f50a6d9509111.jpg'),
(57646, 3909, 'Jiraiya: O Incrível Ninja S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149880.mp4', 'http://timg.bdta.pro/images/e55ce5593506b2c48a2a54de228c7c57.jpg'),
(57647, 3909, 'Jiraiya: O Incrível Ninja S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149881.mp4', 'http://timg.bdta.pro/images/4056f86171e8fb60a570ecd102032f5c.jpg'),
(57648, 3909, 'Jiraiya: O Incrível Ninja S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149882.mp4', 'http://timg.bdta.pro/images/98d009683dfa3e5d2a48a5b828c57f11.jpg'),
(57649, 3909, 'Jiraiya: O Incrível Ninja S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149883.mp4', 'http://timg.bdta.pro/images/f6d9f4c232c7cc01fec8c1f96b0b0694.jpg'),
(57650, 3909, 'Jiraiya: O Incrível Ninja S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149884.mp4', 'http://timg.bdta.pro/images/e395cce9da9e97107d87042629a11025.jpg'),
(57651, 3909, 'Jiraiya: O Incrível Ninja S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149885.mp4', 'http://timg.bdta.pro/images/39dceefa0ab349275427c41aba24fd5a.jpg'),
(57652, 3909, 'Jiraiya: O Incrível Ninja S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149886.mp4', 'http://timg.bdta.pro/images/d580a7c91385d549b35d2872b050513a.jpg'),
(57653, 3909, 'Jiraiya: O Incrível Ninja S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149887.mp4', 'http://timg.bdta.pro/images/51ebfe660ea3c5c2b493d8bf0bedb0e1.jpg'),
(57654, 3909, 'Jiraiya: O Incrível Ninja S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/149888.mp4', 'http://timg.bdta.pro/images/80e547f4a0ce4a3e30f7bab3e71fe744.jpg'),
(57655, 3909, 'Jiraiya: O Incrível Ninja S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/149889.mp4', 'http://timg.bdta.pro/images/9fe07b8306ef862adfc017f072700943.jpg'),
(57656, 3909, 'Jiraiya: O Incrível Ninja S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/149890.mp4', 'http://timg.bdta.pro/images/7bbe1669cf9cf873a2ab2d30dab129d3.jpg'),
(57657, 3909, 'Jiraiya: O Incrível Ninja S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/149891.mp4', 'http://timg.bdta.pro/images/a6bc45ace8aeed2419aaf186ff664278.jpg'),
(57658, 3909, 'Jiraiya: O Incrível Ninja S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/149892.mp4', 'http://timg.bdta.pro/images/6050fa586bbd2858c986401e4a6937a1.jpg'),
(57659, 3909, 'Jiraiya: O Incrível Ninja S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/149893.mp4', 'http://timg.bdta.pro/images/8537937897551fd47c6221d56d151abb.jpg'),
(57660, 3909, 'Jiraiya: O Incrível Ninja S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/149894.mp4', 'http://timg.bdta.pro/images/604008dc7ae874633680c25f181d2efb.jpg'),
(57661, 3909, 'Jiraiya: O Incrível Ninja S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/149895.mp4', 'http://timg.bdta.pro/images/0fcf7ae6456e4a05ad5791174f71180c.jpg'),
(57662, 3909, 'Jiraiya: O Incrível Ninja S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/149896.mp4', 'http://timg.bdta.pro/images/ed551ca5405720d600d81cd8bf49c56b.jpg'),
(57663, 3909, 'Jiraiya: O Incrível Ninja S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/149897.mp4', 'http://timg.bdta.pro/images/35e372b6e1236ebfdee5df83e1b8ccce.jpg'),
(57664, 3909, 'Jiraiya: O Incrível Ninja S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/149898.mp4', 'http://timg.bdta.pro/images/b8d8e801c9d844ebbcd60ed156d36081.jpg'),
(57665, 3909, 'Jiraiya: O Incrível Ninja S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/149899.mp4', 'http://timg.bdta.pro/images/f914e22435d5f7b238c3209df6d34ff3.jpg'),
(57666, 3909, 'Jiraiya: O Incrível Ninja S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/149900.mp4', 'http://timg.bdta.pro/images/c731b78fadcf2c04414e10c8c9a14c30.jpg'),
(57667, 3909, 'Jiraiya: O Incrível Ninja S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/149901.mp4', 'http://timg.bdta.pro/images/25f9440bec590880bd7e853292bd5fae.jpg'),
(57668, 3909, 'Jiraiya: O Incrível Ninja S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/149902.mp4', 'http://timg.bdta.pro/images/30261ed6fa717beb88f0d90358385138.jpg'),
(57669, 3909, 'Jiraiya: O Incrível Ninja S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/149903.mp4', 'http://timg.bdta.pro/images/8cc4a1225df13465ebfc23220d20c6d3.jpg'),
(57670, 3909, 'Jiraiya: O Incrível Ninja S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/149904.mp4', 'http://timg.bdta.pro/images/0e7804332ec14cf42f9d3958af66e7ba.jpg'),
(57671, 3909, 'Jiraiya: O Incrível Ninja S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/149905.mp4', 'http://timg.bdta.pro/images/36dab28803e49eec587e551f904e9f9d.jpg'),
(57672, 3909, 'Jiraiya: O Incrível Ninja S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/149906.mp4', 'http://timg.bdta.pro/images/4eeb8312d46c892fb354b15aa2e83e78.jpg'),
(57673, 3909, 'Jiraiya: O Incrível Ninja S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/149907.mp4', 'http://timg.bdta.pro/images/2b754a3909417867f5140580c4e0e21a.jpg'),
(57674, 3909, 'Jiraiya: O Incrível Ninja S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/149908.mp4', 'http://timg.bdta.pro/images/7c84a5a41f4e5feb97bdabef187a336c.jpg'),
(57675, 3909, 'Jiraiya: O Incrível Ninja S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/149909.mp4', 'http://timg.bdta.pro/images/fb0ebd762114caffd6e28be59af28209.jpg'),
(57676, 3909, 'Jiraiya: O Incrível Ninja S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/149910.mp4', 'http://timg.bdta.pro/images/938b182c822b728f36c16339e80a81d7.jpg'),
(57677, 3909, 'Jiraiya: O Incrível Ninja S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/149911.mp4', 'http://timg.bdta.pro/images/36f00010091a46f0b1a9cb616a30ca09.jpg'),
(57678, 3909, 'Jiraiya: O Incrível Ninja S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/149912.mp4', 'http://timg.bdta.pro/images/b09c3244b56271de604510569fc0b3c4.jpg'),
(57679, 3909, 'Jiraiya: O Incrível Ninja S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/149913.mp4', 'http://timg.bdta.pro/images/94c1de497e240f9d06130e64aae6c6e5.jpg'),
(57680, 3909, 'Jiraiya: O Incrível Ninja S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/149914.mp4', 'http://timg.bdta.pro/images/766affb875baf865c02b498c2d5ea643.jpg'),
(57681, 3909, 'Jiraiya: O Incrível Ninja S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/149915.mp4', 'http://timg.bdta.pro/images/3ee876dd7f5643db89ba8d46edccc9dd.jpg'),
(57682, 3909, 'Jiraiya: O Incrível Ninja S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/149916.mp4', 'http://timg.bdta.pro/images/1b8269dc502d9aadc6e8428a43755ac3.jpg'),
(57683, 3909, 'Jiraiya: O Incrível Ninja S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/149917.mp4', 'http://timg.bdta.pro/images/8718a61e2c99b35fcc0ae4027927ecd7.jpg'),
(57684, 3909, 'Jiraiya: O Incrível Ninja S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/149918.mp4', 'http://timg.bdta.pro/images/8e1884509c9b286ea796bc252ec1f639.jpg'),
(57685, 3909, 'Jiraiya: O Incrível Ninja S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/149919.mp4', 'http://timg.bdta.pro/images/8ecd79909e3721f57139554d79c73329.jpg'),
(57686, 3909, 'Jiraiya: O Incrível Ninja S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/149920.mp4', 'http://timg.bdta.pro/images/d888bff961533d292b8e151c0ea9fee5.jpg'),
(57687, 3909, 'Jiraiya: O Incrível Ninja S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/149921.mp4', 'http://timg.bdta.pro/images/8333071ac705ff6ebcdcdb59219fe3fb.jpg'),
(57688, 3909, 'Jiraiya: O Incrível Ninja S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/149922.mp4', 'http://timg.bdta.pro/images/414a61ff44f36723338b57332d059773.jpg'),
(57689, 3909, 'Jiraiya: O Incrível Ninja S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/149923.mp4', 'http://timg.bdta.pro/images/413f23d7fc01d5a961166e6cd9f1d588.jpg'),
(57690, 3909, 'Jiraiya: O Incrível Ninja S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/149924.mp4', 'http://timg.bdta.pro/images/18860214d6d12dd8c7a49f8eb1e7e650.jpg'),
(57691, 3909, 'Jiraiya: O Incrível Ninja S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/149925.mp4', 'http://timg.bdta.pro/images/64795635df9c6df382074fec68c8a3f2.jpg'),
(57692, 3910, 'Jiva! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146193.mp4', 'http://gstaticontent.com/images/vPPZCbycpfdD6XjmizTIFnkLBZF_big.jpg'),
(57693, 3910, 'Jiva! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146194.mp4', 'http://gstaticontent.com/images/vPPZCbycpfdD6XjmizTIFnkLBZF_big.jpg'),
(57694, 3910, 'Jiva! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146195.mp4', 'http://gstaticontent.com/images/vPPZCbycpfdD6XjmizTIFnkLBZF_big.jpg'),
(57695, 3910, 'Jiva! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146196.mp4', 'http://gstaticontent.com/images/vPPZCbycpfdD6XjmizTIFnkLBZF_big.jpg'),
(57696, 3910, 'Jiva! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146197.mp4', 'http://gstaticontent.com/images/vPPZCbycpfdD6XjmizTIFnkLBZF_big.jpg'),
(57697, 3911, 'Lexa: Mostra Esse Poder S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146188.mp4', 'http://gstaticontent.com/images/nUwlytunUF0eUSxGjuZ1i6wslL5_big.jpg'),
(57698, 3911, 'Lexa: Mostra Esse Poder S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146189.mp4', 'http://gstaticontent.com/images/nUwlytunUF0eUSxGjuZ1i6wslL5_big.jpg'),
(57699, 3911, 'Lexa: Mostra Esse Poder S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146190.mp4', 'http://gstaticontent.com/images/nUwlytunUF0eUSxGjuZ1i6wslL5_big.jpg'),
(57700, 3911, 'Lexa: Mostra Esse Poder S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146191.mp4', 'http://gstaticontent.com/images/nUwlytunUF0eUSxGjuZ1i6wslL5_big.jpg'),
(57701, 3911, 'Lexa: Mostra Esse Poder S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146192.mp4', 'http://gstaticontent.com/images/nUwlytunUF0eUSxGjuZ1i6wslL5_big.jpg'),
(57702, 3912, 'Manhãs de Setembro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198091.mp4', 'http://gstaticontent.com/images/5xXAIbhJVLrqCA2Uxk4vdItOaB4_big.jpg'),
(57703, 3912, 'Manhãs de Setembro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198092.mp4', 'http://gstaticontent.com/images/5xXAIbhJVLrqCA2Uxk4vdItOaB4_big.jpg'),
(57704, 3912, 'Manhãs de Setembro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198093.mp4', 'http://gstaticontent.com/images/5xXAIbhJVLrqCA2Uxk4vdItOaB4_big.jpg'),
(57705, 3912, 'Manhãs de Setembro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198094.mp4', 'http://gstaticontent.com/images/5xXAIbhJVLrqCA2Uxk4vdItOaB4_big.jpg'),
(57706, 3912, 'Manhãs de Setembro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198095.mp4', 'http://gstaticontent.com/images/5xXAIbhJVLrqCA2Uxk4vdItOaB4_big.jpg'),
(57707, 3913, 'Manhãs de Setembro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198096.mp4', 'http://gstaticontent.com/images/5xXAIbhJVLrqCA2Uxk4vdItOaB4_big.jpg'),
(57708, 3913, 'Manhãs de Setembro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198097.mp4', 'http://gstaticontent.com/images/5xXAIbhJVLrqCA2Uxk4vdItOaB4_big.jpg'),
(57709, 3913, 'Manhãs de Setembro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198098.mp4', 'http://gstaticontent.com/images/5xXAIbhJVLrqCA2Uxk4vdItOaB4_big.jpg'),
(57710, 3913, 'Manhãs de Setembro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198099.mp4', 'http://gstaticontent.com/images/5xXAIbhJVLrqCA2Uxk4vdItOaB4_big.jpg'),
(57711, 3913, 'Manhãs de Setembro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198100.mp4', 'http://gstaticontent.com/images/5xXAIbhJVLrqCA2Uxk4vdItOaB4_big.jpg'),
(57712, 3913, 'Manhãs de Setembro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198101.mp4', 'http://gstaticontent.com/images/5xXAIbhJVLrqCA2Uxk4vdItOaB4_big.jpg'),
(57713, 3914, 'Sex/Life S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209135.mp4', 'http://gstaticontent.com/images/2ST6l4WP7ZfqAetuttBqx8F3AAH_big.jpg'),
(57714, 3914, 'Sex/Life S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209136.mp4', 'http://gstaticontent.com/images/2ST6l4WP7ZfqAetuttBqx8F3AAH_big.jpg'),
(57715, 3914, 'Sex/Life S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209137.mp4', 'http://gstaticontent.com/images/2ST6l4WP7ZfqAetuttBqx8F3AAH_big.jpg'),
(57716, 3914, 'Sex/Life S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209138.mp4', 'http://gstaticontent.com/images/2ST6l4WP7ZfqAetuttBqx8F3AAH_big.jpg'),
(57717, 3914, 'Sex/Life S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209139.mp4', 'http://gstaticontent.com/images/2ST6l4WP7ZfqAetuttBqx8F3AAH_big.jpg'),
(57718, 3914, 'Sex/Life S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209140.mp4', 'http://gstaticontent.com/images/2ST6l4WP7ZfqAetuttBqx8F3AAH_big.jpg'),
(57719, 3914, 'Sex/Life S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209141.mp4', 'http://gstaticontent.com/images/2ST6l4WP7ZfqAetuttBqx8F3AAH_big.jpg'),
(57720, 3914, 'Sex/Life S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209142.mp4', 'http://gstaticontent.com/images/2ST6l4WP7ZfqAetuttBqx8F3AAH_big.jpg'),
(57721, 3915, 'Sex/Life S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hyl1X5AUpYajVIzlXDiLLdlADRn.jpg'),
(57722, 3915, 'Sex/Life S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ixXPyApPjpTKTqCBD8qUdqKmGkr.jpg'),
(57723, 3915, 'Sex/Life S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pnaBnrvmv6jm0F7Kihg3SjT3iNP.jpg'),
(57724, 3915, 'Sex/Life S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vYm4kOzYcu3ehFaE3zoqwmdvqii.jpg'),
(57725, 3915, 'Sex/Life S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8rGfoiwgaXIjXMVOoZ7nYnwQnyw.jpg'),
(57726, 3915, 'Sex/Life S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZlWnNghvizTH6HYnTp9deKJEXA.jpg'),
(57727, 3916, 'Solos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146181.mp4', 'http://gstaticontent.com/images/szoC8f6wAXGmgn0aiSDroRx7Ngs_big.jpg'),
(57728, 3916, 'Solos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146182.mp4', 'http://gstaticontent.com/images/szoC8f6wAXGmgn0aiSDroRx7Ngs_big.jpg'),
(57729, 3916, 'Solos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146183.mp4', 'http://gstaticontent.com/images/szoC8f6wAXGmgn0aiSDroRx7Ngs_big.jpg'),
(57730, 3916, 'Solos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146184.mp4', 'http://gstaticontent.com/images/szoC8f6wAXGmgn0aiSDroRx7Ngs_big.jpg'),
(57731, 3916, 'Solos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146185.mp4', 'http://gstaticontent.com/images/szoC8f6wAXGmgn0aiSDroRx7Ngs_big.jpg'),
(57732, 3916, 'Solos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146186.mp4', 'http://gstaticontent.com/images/szoC8f6wAXGmgn0aiSDroRx7Ngs_big.jpg'),
(57733, 3916, 'Solos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146187.mp4', 'http://gstaticontent.com/images/szoC8f6wAXGmgn0aiSDroRx7Ngs_big.jpg'),
(57734, 3917, 'Você Nunca Esteve Sozinha: O Doc de Juliette S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155479.mp4', 'http://gstaticontent.com/images/5b9308c1b2a39275391a1c81f837fbd7.jpg'),
(57735, 3917, 'Você Nunca Esteve Sozinha: O Doc de Juliette S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155480.mp4', 'http://timg.bdta.pro/images/a0e8228019f6855c6a807e116ed607cb.jpg'),
(57736, 3917, 'Você Nunca Esteve Sozinha: O Doc de Juliette S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155481.mp4', 'http://gstaticontent.com/images/5b9308c1b2a39275391a1c81f837fbd7.jpg'),
(57737, 3917, 'Você Nunca Esteve Sozinha: O Doc de Juliette S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155482.mp4', 'http://gstaticontent.com/images/5b9308c1b2a39275391a1c81f837fbd7.jpg'),
(57738, 3917, 'Você Nunca Esteve Sozinha: O Doc de Juliette S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155483.mp4', 'http://timg.bdta.pro/images/2274565c5c9f7ce4a3a0ee4d9a009624.jpg'),
(57739, 3917, 'Você Nunca Esteve Sozinha: O Doc de Juliette S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155484.mp4', 'http://gstaticontent.com/images/5b9308c1b2a39275391a1c81f837fbd7.jpg'),
(57740, 3917, 'Você Nunca Esteve Sozinha: O Doc de Juliette S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/155485.mp4', 'http://timg.bdta.pro/images/6836879ffdb240b1a6681a31fa84c04b.jpg'),
(57741, 3918, 'A Unidade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241506.mp4', 'http://timg.bdta.pro/images/552edaa4378f42f32dd64b8a26324039.jpg'),
(57742, 3918, 'A Unidade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241507.mp4', 'http://timg.bdta.pro/images/4c0fb6ce55191fc4225fd4c2a7b36b8d.jpg'),
(57743, 3918, 'A Unidade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241508.mp4', 'http://timg.bdta.pro/images/de25b3a67dd8e8573f341f5495ddb997.jpg'),
(57744, 3918, 'A Unidade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241509.mp4', 'http://timg.bdta.pro/images/7f94319ce096f7fad7ad9ad054e15751.jpg'),
(57745, 3918, 'A Unidade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241510.mp4', 'http://timg.bdta.pro/images/bea93ad8f8ef7f0ee2ec2860b0d3031a.jpg'),
(57746, 3918, 'A Unidade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241511.mp4', 'http://timg.bdta.pro/images/ade188690e32fa364fadeaca12b857bd.jpg'),
(57747, 3919, 'A Unidade S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241512.mp4', 'http://timg.bdta.pro/images/697f5d7599ee0a4ab919c623b28d0449.jpg'),
(57748, 3919, 'A Unidade S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241513.mp4', 'http://timg.bdta.pro/images/00c7eb42f81cd0d01e0357965b9566b3.jpg'),
(57749, 3919, 'A Unidade S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241514.mp4', 'http://timg.bdta.pro/images/19fc54d0b5f38bbf58681bb33c0d0634.jpg'),
(57750, 3919, 'A Unidade S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241515.mp4', 'http://timg.bdta.pro/images/82b76a78b7fd55d7729258d4c3d7f902.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(57751, 3919, 'A Unidade S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241516.mp4', 'http://timg.bdta.pro/images/090c6d732608ac13c575ab61f80019b2.jpg'),
(57752, 3919, 'A Unidade S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241517.mp4', 'http://timg.bdta.pro/images/791524c3f673709978c582a9f8c076e4.jpg'),
(57753, 3920, 'A Unidade S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241518.mp4', 'http://gstaticontent.com/images/9804381a06e79f1d3096b2fa2940238f.jpg'),
(57754, 3920, 'A Unidade S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241519.mp4', 'http://gstaticontent.com/images/9804381a06e79f1d3096b2fa2940238f.jpg'),
(57755, 3920, 'A Unidade S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241520.mp4', 'http://gstaticontent.com/images/9804381a06e79f1d3096b2fa2940238f.jpg'),
(57756, 3920, 'A Unidade S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241521.mp4', 'http://gstaticontent.com/images/9804381a06e79f1d3096b2fa2940238f.jpg'),
(57757, 3920, 'A Unidade S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241522.mp4', 'http://gstaticontent.com/images/9804381a06e79f1d3096b2fa2940238f.jpg'),
(57758, 3920, 'A Unidade S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241523.mp4', 'http://gstaticontent.com/images/9804381a06e79f1d3096b2fa2940238f.jpg'),
(57759, 3921, 'As Novas Aventuras do Ursinho Puff S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145889.mp4', 'http://timg.bdta.pro/images/d4442c5e94ecb8c452a39c8b0fb15a59.jpg'),
(57760, 3921, 'As Novas Aventuras do Ursinho Puff S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145890.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57761, 3921, 'As Novas Aventuras do Ursinho Puff S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145891.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57762, 3921, 'As Novas Aventuras do Ursinho Puff S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145892.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57763, 3921, 'As Novas Aventuras do Ursinho Puff S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145893.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57764, 3921, 'As Novas Aventuras do Ursinho Puff S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145894.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57765, 3921, 'As Novas Aventuras do Ursinho Puff S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145895.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57766, 3921, 'As Novas Aventuras do Ursinho Puff S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145896.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57767, 3921, 'As Novas Aventuras do Ursinho Puff S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145897.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57768, 3921, 'As Novas Aventuras do Ursinho Puff S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145898.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57769, 3921, 'As Novas Aventuras do Ursinho Puff S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145899.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57770, 3921, 'As Novas Aventuras do Ursinho Puff S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145900.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57771, 3921, 'As Novas Aventuras do Ursinho Puff S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145901.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57772, 3921, 'As Novas Aventuras do Ursinho Puff S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145902.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57773, 3921, 'As Novas Aventuras do Ursinho Puff S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145903.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57774, 3921, 'As Novas Aventuras do Ursinho Puff S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145904.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57775, 3921, 'As Novas Aventuras do Ursinho Puff S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145905.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57776, 3921, 'As Novas Aventuras do Ursinho Puff S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/145906.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57777, 3921, 'As Novas Aventuras do Ursinho Puff S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/145907.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57778, 3921, 'As Novas Aventuras do Ursinho Puff S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/145908.mp4', 'http://timg.bdta.pro/images/620730b91b766bfbe5fc0cb90e78040b.jpg'),
(57779, 3921, 'As Novas Aventuras do Ursinho Puff S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/145909.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57780, 3921, 'As Novas Aventuras do Ursinho Puff S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/145910.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57781, 3922, 'As Novas Aventuras do Ursinho Puff S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145911.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57782, 3922, 'As Novas Aventuras do Ursinho Puff S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145912.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57783, 3922, 'As Novas Aventuras do Ursinho Puff S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145913.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57784, 3922, 'As Novas Aventuras do Ursinho Puff S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145914.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57785, 3922, 'As Novas Aventuras do Ursinho Puff S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145915.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57786, 3922, 'As Novas Aventuras do Ursinho Puff S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145916.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57787, 3922, 'As Novas Aventuras do Ursinho Puff S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145917.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57788, 3922, 'As Novas Aventuras do Ursinho Puff S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145918.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57789, 3922, 'As Novas Aventuras do Ursinho Puff S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145919.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57790, 3922, 'As Novas Aventuras do Ursinho Puff S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145920.mp4', 'http://timg.bdta.pro/images/20a624b36e5a0225201bdab0c0911d27.jpg'),
(57791, 3923, 'As Novas Aventuras do Ursinho Puff S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145921.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57792, 3923, 'As Novas Aventuras do Ursinho Puff S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145922.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57793, 3923, 'As Novas Aventuras do Ursinho Puff S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145923.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57794, 3923, 'As Novas Aventuras do Ursinho Puff S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145924.mp4', 'http://timg.bdta.pro/images/9390839ccf963f07ef6b6b2d881ecdb4.jpg'),
(57795, 3923, 'As Novas Aventuras do Ursinho Puff S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145925.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57796, 3923, 'As Novas Aventuras do Ursinho Puff S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145926.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57797, 3923, 'As Novas Aventuras do Ursinho Puff S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145927.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57798, 3923, 'As Novas Aventuras do Ursinho Puff S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145928.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57799, 3923, 'As Novas Aventuras do Ursinho Puff S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145929.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57800, 3923, 'As Novas Aventuras do Ursinho Puff S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145930.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57801, 3924, 'As Novas Aventuras do Ursinho Puff S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145931.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57802, 3924, 'As Novas Aventuras do Ursinho Puff S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145932.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57803, 3924, 'As Novas Aventuras do Ursinho Puff S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145933.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57804, 3924, 'As Novas Aventuras do Ursinho Puff S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145934.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57805, 3924, 'As Novas Aventuras do Ursinho Puff S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145935.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57806, 3924, 'As Novas Aventuras do Ursinho Puff S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145936.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57807, 3924, 'As Novas Aventuras do Ursinho Puff S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145937.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57808, 3924, 'As Novas Aventuras do Ursinho Puff S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145938.mp4', 'http://gstaticontent.com/images/21677285453e71a9ff5ceb2bcfc03193.jpg'),
(57809, 3925, 'Breeders S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195793.mp4', 'http://timg.bdta.pro/images/9a286b171d044d7570d73d1863fb3e46.jpg'),
(57810, 3925, 'Breeders S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195794.mp4', 'http://timg.bdta.pro/images/4c19732f8277a09673308ee4bc2b86f9.jpg'),
(57811, 3925, 'Breeders S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195795.mp4', 'http://timg.bdta.pro/images/a5175ba7dedb4105feeadcc1078ca13b.jpg'),
(57812, 3925, 'Breeders S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195796.mp4', 'http://timg.bdta.pro/images/10aaf575f858fbc9de4d23205dc3e37a.jpg'),
(57813, 3925, 'Breeders S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195797.mp4', 'http://timg.bdta.pro/images/403bc5fe4d25b8d375e93ada51edf7d4.jpg'),
(57814, 3925, 'Breeders S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195798.mp4', 'http://timg.bdta.pro/images/9d075aa150b09f4a540fcfa3e920cf40.jpg'),
(57815, 3925, 'Breeders S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195799.mp4', 'http://timg.bdta.pro/images/d5dfc99147ca1fa465308f28d28f09b4.jpg'),
(57816, 3925, 'Breeders S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195800.mp4', 'http://timg.bdta.pro/images/ab660b1220f43badad8b12b4d5df1e2c.jpg'),
(57817, 3925, 'Breeders S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195801.mp4', 'http://timg.bdta.pro/images/ad62e4cb4971f780450b490c9ae155a0.jpg'),
(57818, 3925, 'Breeders S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195802.mp4', 'http://timg.bdta.pro/images/0eea6a78916135c3834379e0681889d8.jpg'),
(57819, 3926, 'Breeders S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195803.mp4', 'http://timg.bdta.pro/images/f52a85dc656f34f34d8af81981bc1fdf.jpg'),
(57820, 3926, 'Breeders S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195804.mp4', 'http://timg.bdta.pro/images/afdea1ac6cf73f28b1e386256d9eec5a.jpg'),
(57821, 3926, 'Breeders S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195805.mp4', 'http://timg.bdta.pro/images/32af3ad76817f90b7e65507a1850da9d.jpg'),
(57822, 3926, 'Breeders S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195806.mp4', 'http://timg.bdta.pro/images/3618f8627d5f1e6203f37eb1ab0838eb.jpg'),
(57823, 3926, 'Breeders S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195807.mp4', 'http://timg.bdta.pro/images/847cadebbe130cd10d1aa22f62536b80.jpg'),
(57824, 3926, 'Breeders S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195808.mp4', 'http://timg.bdta.pro/images/eb7227528fc8dba861aa7559285ca5e4.jpg'),
(57825, 3926, 'Breeders S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195809.mp4', 'http://timg.bdta.pro/images/655e6b97141f922f2bf02b383135d296.jpg'),
(57826, 3926, 'Breeders S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195810.mp4', 'http://timg.bdta.pro/images/2bb21326871383a9fd02cd02a5831e95.jpg'),
(57827, 3926, 'Breeders S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195811.mp4', 'http://timg.bdta.pro/images/83d5dbd49b4d2526562d5d67fe48082b.jpg'),
(57828, 3926, 'Breeders S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195812.mp4', 'http://timg.bdta.pro/images/41e0a720d96fdfd0da6785cdf9287447.jpg'),
(57829, 3927, 'Breeders S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195813.mp4', 'http://timg.bdta.pro/images/560d830eefe9302a14eae7aa281f591d.jpg'),
(57830, 3927, 'Breeders S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195814.mp4', 'http://timg.bdta.pro/images/981dae0f52fbd25ec7130fe4a33d2d0e.jpg'),
(57831, 3927, 'Breeders S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195815.mp4', 'http://timg.bdta.pro/images/4a4789dad4a7262ce641ed290199b88e.jpg'),
(57832, 3927, 'Breeders S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195816.mp4', 'http://timg.bdta.pro/images/50110fd5671fa5163e7621d87c276ac8.jpg'),
(57833, 3927, 'Breeders S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195817.mp4', 'http://timg.bdta.pro/images/1d735d0bb8ef12488502e16982820f66.jpg'),
(57834, 3927, 'Breeders S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195818.mp4', 'http://timg.bdta.pro/images/64156c69fd7df357d708cf2ce22b3bdc.jpg'),
(57835, 3927, 'Breeders S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195819.mp4', 'http://timg.bdta.pro/images/ad51154f377ecb4fd561649a8211a9bf.jpg'),
(57836, 3927, 'Breeders S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195820.mp4', 'http://timg.bdta.pro/images/6586e17a100620f7431adf9321a76854.jpg'),
(57837, 3927, 'Breeders S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195821.mp4', 'http://timg.bdta.pro/images/15dff047c07f88f1335f8b783ab37d96.jpg'),
(57838, 3927, 'Breeders S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195822.mp4', 'http://timg.bdta.pro/images/cbb912258c71d8809aac82fb1d5a0dbe.jpg'),
(57839, 3928, 'Colônia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146171.mp4', 'http://timg.bdta.pro/images/ede4592f9a6982b01f7a701d2e9a9cd9.jpg'),
(57840, 3928, 'Colônia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146172.mp4', 'http://timg.bdta.pro/images/a595d0c770221461c1d52df8ad703951.jpg'),
(57841, 3928, 'Colônia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146173.mp4', 'http://timg.bdta.pro/images/d53638c4a78debcc15b9b51c91c8e82e.jpg'),
(57842, 3928, 'Colônia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146174.mp4', 'http://timg.bdta.pro/images/1da92ab541a928df75f14e92fc50de2e.jpg'),
(57843, 3928, 'Colônia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146175.mp4', 'http://timg.bdta.pro/images/e428b90b239f0c3f58724527d349a07c.jpg'),
(57844, 3928, 'Colônia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146176.mp4', 'http://timg.bdta.pro/images/9d87b040fcbd099a0380749b734888cf.jpg'),
(57845, 3928, 'Colônia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146177.mp4', 'http://timg.bdta.pro/images/dada88edb442cc35b68ce44cdfc42a70.jpg'),
(57846, 3928, 'Colônia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146178.mp4', 'http://timg.bdta.pro/images/7cfcbbad5059dde0ce69c94b18621a16.jpg'),
(57847, 3928, 'Colônia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146179.mp4', 'http://timg.bdta.pro/images/b0fbf798f919f611d821431b54aacbe7.jpg'),
(57848, 3928, 'Colônia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146180.mp4', 'http://timg.bdta.pro/images/125da2eab52862760e5cf234844593ad.jpg'),
(57849, 3929, 'DAVE S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161758.mp4', 'http://timg.bdta.pro/images/23743d1ce060d626baef7c2b37c442f4.jpg'),
(57850, 3929, 'DAVE S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161759.mp4', 'http://timg.bdta.pro/images/8528f0ab9180a95394dfa2c4fc34da56.jpg'),
(57851, 3929, 'DAVE S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161760.mp4', 'http://timg.bdta.pro/images/1974f5a6ac3d928db5f62b79fdbee670.jpg'),
(57852, 3929, 'DAVE S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161761.mp4', 'http://timg.bdta.pro/images/6fc726e24d54548d868810ce67fc7c0c.jpg'),
(57853, 3929, 'DAVE S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161762.mp4', 'http://timg.bdta.pro/images/e18efc6c477eaa0db39bba3f5d6f16cd.jpg'),
(57854, 3929, 'DAVE S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161763.mp4', 'http://timg.bdta.pro/images/833b607baffdfad40ecac5d44ba07c29.jpg'),
(57855, 3929, 'DAVE S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161764.mp4', 'http://timg.bdta.pro/images/b5219a46c8a9a93d966491b50cc4bc32.jpg'),
(57856, 3929, 'DAVE S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161765.mp4', 'http://timg.bdta.pro/images/adb1185c303191055fdc7ad9795610b9.jpg'),
(57857, 3929, 'DAVE S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161766.mp4', 'http://timg.bdta.pro/images/e3c2c1ff0fe52db616baf14b8308879a.jpg'),
(57858, 3929, 'DAVE S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161767.mp4', 'http://timg.bdta.pro/images/481a6f2975d938add0985393ade3955e.jpg'),
(57859, 3930, 'DAVE S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f6NVyFj188xeUOPXKtJcLSZNUd8.jpg'),
(57860, 3930, 'DAVE S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/94w23pjPHrRdRc3Lk4u9JvvKhDh.jpg'),
(57861, 3930, 'DAVE S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ed1zbeg1rJ53znRkANPJVsrevfE.jpg'),
(57862, 3930, 'DAVE S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3z9a90SmvfX3d6C950dEZ2Y8cD.jpg'),
(57863, 3930, 'DAVE S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/msgeyJut3SbvLD5Z8ct92E7uN6y.jpg'),
(57864, 3930, 'DAVE S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hjZ7UrS1sTwklk3ZC1vkZ1Ff4Iv.jpg'),
(57865, 3930, 'DAVE S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gdOrG6hKGCTviLV1jZi2r3uLSAU.jpg'),
(57866, 3930, 'DAVE S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aMBLPGuDKnBY4wIhdXFkn2FZJNY.jpg'),
(57867, 3930, 'DAVE S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vyP9c2dyhlDULcKmQp1gh1H7sJm.jpg'),
(57868, 3930, 'DAVE S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rlmwfyE0DDkt04QFzdnLOQbdLtm.jpg'),
(57869, 3931, 'Elize Matsunaga: Era uma Vez um Crime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146167.mp4', 'http://timg.bdta.pro/images/5449f28d2ee31b1a62524fc65863da2c.jpg'),
(57870, 3931, 'Elize Matsunaga: Era uma Vez um Crime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146168.mp4', 'http://timg.bdta.pro/images/0f6e0f0553a071906776c98cc798c2da.jpg'),
(57871, 3931, 'Elize Matsunaga: Era uma Vez um Crime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146169.mp4', 'http://timg.bdta.pro/images/a746aadcc7f8a8e0bfac79306bfa4af9.jpg'),
(57872, 3931, 'Elize Matsunaga: Era uma Vez um Crime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146170.mp4', 'http://timg.bdta.pro/images/a15c1956a52da89937eadc700d4206b7.jpg'),
(57873, 3932, 'Esquadrilha Parafuso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146102.mp4', 'http://timg.bdta.pro/images/a875b7b67f97a8ba8879ed964c1d85d1.jpg'),
(57874, 3932, 'Esquadrilha Parafuso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146103.mp4', 'http://timg.bdta.pro/images/9bf0f052380d515348f0a3338f880b6c.jpg'),
(57875, 3932, 'Esquadrilha Parafuso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146104.mp4', 'http://timg.bdta.pro/images/2a9866febfda4ceac11fe275452a4623.jpg'),
(57876, 3932, 'Esquadrilha Parafuso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146105.mp4', 'http://timg.bdta.pro/images/db1f24816b49c4bb10b9b7e959961975.jpg'),
(57877, 3932, 'Esquadrilha Parafuso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146106.mp4', 'http://timg.bdta.pro/images/0f6db271861ac3ba8a4d58e3c9c5c53c.jpg'),
(57878, 3932, 'Esquadrilha Parafuso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146107.mp4', 'http://timg.bdta.pro/images/6460544afd00d723a375ca0438aef209.jpg'),
(57879, 3932, 'Esquadrilha Parafuso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146108.mp4', 'http://timg.bdta.pro/images/786a9b050660824be1cda9cf19300570.jpg'),
(57880, 3932, 'Esquadrilha Parafuso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146109.mp4', 'http://timg.bdta.pro/images/03701cfd1021574172f1b2d2a383f494.jpg'),
(57881, 3932, 'Esquadrilha Parafuso S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146110.mp4', 'http://timg.bdta.pro/images/7c98334d9419e35e88d7c0be30f3ae9d.jpg'),
(57882, 3932, 'Esquadrilha Parafuso S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146111.mp4', 'http://timg.bdta.pro/images/ac9b2fee80c848de06ede517bb22e2ec.jpg'),
(57883, 3932, 'Esquadrilha Parafuso S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146112.mp4', 'http://timg.bdta.pro/images/c7f723d33db26f35d5a5c6b40aee6fa9.jpg'),
(57884, 3932, 'Esquadrilha Parafuso S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146113.mp4', 'http://timg.bdta.pro/images/c7f723d33db26f35d5a5c6b40aee6fa9.jpg'),
(57885, 3932, 'Esquadrilha Parafuso S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146114.mp4', 'http://timg.bdta.pro/images/2ae177a5c488c44d30a4433cf358e470.jpg'),
(57886, 3932, 'Esquadrilha Parafuso S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146115.mp4', 'http://timg.bdta.pro/images/a15afba7b3622c42613ec0fbe2732192.jpg'),
(57887, 3932, 'Esquadrilha Parafuso S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146116.mp4', 'http://timg.bdta.pro/images/518f9b0b25a01a471aef4e00a475897a.jpg'),
(57888, 3932, 'Esquadrilha Parafuso S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146117.mp4', 'http://timg.bdta.pro/images/3f5492e09db69b201be7dafa8874dc35.jpg'),
(57889, 3932, 'Esquadrilha Parafuso S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146118.mp4', 'http://timg.bdta.pro/images/09e45d0ae753f3144fc88690240cbbd5.jpg'),
(57890, 3932, 'Esquadrilha Parafuso S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146119.mp4', 'http://timg.bdta.pro/images/0a4a5dd90e6b7de993018b6487b6657e.jpg'),
(57891, 3932, 'Esquadrilha Parafuso S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/146120.mp4', 'http://timg.bdta.pro/images/8b139d44e0787afb660fef66781b2856.jpg'),
(57892, 3932, 'Esquadrilha Parafuso S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/146121.mp4', 'http://timg.bdta.pro/images/98275ecf4ac5b825e7ce3c3acce15c60.jpg'),
(57893, 3932, 'Esquadrilha Parafuso S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/146122.mp4', 'http://timg.bdta.pro/images/3a7fe944fe3f6f8a9153cbcf0c8da90f.jpg'),
(57894, 3932, 'Esquadrilha Parafuso S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/146123.mp4', 'http://timg.bdta.pro/images/1b7ce765bb7e000258dd2fbb165bb1db.jpg'),
(57895, 3932, 'Esquadrilha Parafuso S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/146124.mp4', 'http://timg.bdta.pro/images/9b7eb868c4568e6ba982906591226026.jpg'),
(57896, 3932, 'Esquadrilha Parafuso S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/146125.mp4', 'http://timg.bdta.pro/images/d5723a7205c1e15db570134ef6d48282.jpg'),
(57897, 3932, 'Esquadrilha Parafuso S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/146126.mp4', 'http://timg.bdta.pro/images/ae51e03c59252bb240df860cf79805f1.jpg'),
(57898, 3932, 'Esquadrilha Parafuso S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/146127.mp4', 'http://timg.bdta.pro/images/db7a77f01c8b380f99b3bbc3a8879689.jpg'),
(57899, 3932, 'Esquadrilha Parafuso S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/146128.mp4', 'http://timg.bdta.pro/images/9e8e08985ec9658d0e81ed39b04c9d89.jpg'),
(57900, 3932, 'Esquadrilha Parafuso S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/146129.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57901, 3932, 'Esquadrilha Parafuso S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/146130.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57902, 3932, 'Esquadrilha Parafuso S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/146131.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57903, 3932, 'Esquadrilha Parafuso S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/146132.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57904, 3932, 'Esquadrilha Parafuso S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/146133.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57905, 3932, 'Esquadrilha Parafuso S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/146134.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57906, 3932, 'Esquadrilha Parafuso S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/146135.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57907, 3932, 'Esquadrilha Parafuso S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/146136.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57908, 3932, 'Esquadrilha Parafuso S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/146137.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57909, 3932, 'Esquadrilha Parafuso S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/146138.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57910, 3932, 'Esquadrilha Parafuso S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/146139.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57911, 3932, 'Esquadrilha Parafuso S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/146140.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57912, 3932, 'Esquadrilha Parafuso S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/146141.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57913, 3932, 'Esquadrilha Parafuso S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/146142.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57914, 3932, 'Esquadrilha Parafuso S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/146143.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57915, 3932, 'Esquadrilha Parafuso S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/146144.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57916, 3932, 'Esquadrilha Parafuso S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/146145.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57917, 3932, 'Esquadrilha Parafuso S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/146146.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57918, 3932, 'Esquadrilha Parafuso S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/146147.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57919, 3932, 'Esquadrilha Parafuso S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/146148.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57920, 3932, 'Esquadrilha Parafuso S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/146149.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57921, 3932, 'Esquadrilha Parafuso S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/146150.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57922, 3932, 'Esquadrilha Parafuso S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/146151.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57923, 3932, 'Esquadrilha Parafuso S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/146152.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57924, 3932, 'Esquadrilha Parafuso S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/146153.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57925, 3932, 'Esquadrilha Parafuso S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/146154.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57926, 3932, 'Esquadrilha Parafuso S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/146155.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57927, 3932, 'Esquadrilha Parafuso S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/146156.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57928, 3932, 'Esquadrilha Parafuso S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/146157.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57929, 3932, 'Esquadrilha Parafuso S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/146158.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57930, 3932, 'Esquadrilha Parafuso S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/146159.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57931, 3932, 'Esquadrilha Parafuso S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/146160.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57932, 3932, 'Esquadrilha Parafuso S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/146161.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57933, 3932, 'Esquadrilha Parafuso S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/146162.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57934, 3932, 'Esquadrilha Parafuso S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/146163.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57935, 3932, 'Esquadrilha Parafuso S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/146164.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57936, 3932, 'Esquadrilha Parafuso S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/146165.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57937, 3932, 'Esquadrilha Parafuso S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/146166.mp4', 'http://gstaticontent.com/images/54175acc12f16e621a576b8f64050a9c.jpg'),
(57938, 3933, 'Guerra de Vizinhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/184330.mp4', 'http://timg.bdta.pro/images/aa051971bb8328782ac124062a4d8d1d.jpg'),
(57939, 3933, 'Guerra de Vizinhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/184331.mp4', 'http://timg.bdta.pro/images/afbef226551b15032134a58a4b7c3150.jpg'),
(57940, 3933, 'Guerra de Vizinhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/184332.mp4', 'http://timg.bdta.pro/images/15c651298dcd3b7da26fe064e75fde3b.jpg'),
(57941, 3933, 'Guerra de Vizinhos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/184333.mp4', 'http://timg.bdta.pro/images/9787ec465d157b354457dbda76461c14.jpg'),
(57942, 3933, 'Guerra de Vizinhos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/184334.mp4', 'http://timg.bdta.pro/images/ec0ade5ead11867f4b9e6bcb14d0a845.jpg'),
(57943, 3933, 'Guerra de Vizinhos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/184335.mp4', 'http://timg.bdta.pro/images/f960b91da9e0e449ef61573f82f1a70a.jpg'),
(57944, 3933, 'Guerra de Vizinhos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/184336.mp4', 'http://timg.bdta.pro/images/a817cd119f0eb7824abfb8fd9fd916d3.jpg'),
(57945, 3933, 'Guerra de Vizinhos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/184337.mp4', 'http://timg.bdta.pro/images/feb2c683e3610a0fec4fc2ece377b60a.jpg'),
(57946, 3934, 'Guerra de Vizinhos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/184338.mp4', 'http://gstaticontent.com/images/3f07f2f34f0e7f6c3eb3eada1143dc12.jpg'),
(57947, 3934, 'Guerra de Vizinhos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/184339.mp4', 'http://gstaticontent.com/images/3f07f2f34f0e7f6c3eb3eada1143dc12.jpg'),
(57948, 3934, 'Guerra de Vizinhos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/184340.mp4', 'http://gstaticontent.com/images/3f07f2f34f0e7f6c3eb3eada1143dc12.jpg'),
(57949, 3934, 'Guerra de Vizinhos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/184341.mp4', 'http://gstaticontent.com/images/3f07f2f34f0e7f6c3eb3eada1143dc12.jpg'),
(57950, 3934, 'Guerra de Vizinhos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/184342.mp4', 'http://gstaticontent.com/images/3f07f2f34f0e7f6c3eb3eada1143dc12.jpg'),
(57951, 3934, 'Guerra de Vizinhos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/184343.mp4', 'http://gstaticontent.com/images/3f07f2f34f0e7f6c3eb3eada1143dc12.jpg'),
(57952, 3934, 'Guerra de Vizinhos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/184344.mp4', 'http://gstaticontent.com/images/3f07f2f34f0e7f6c3eb3eada1143dc12.jpg'),
(57953, 3934, 'Guerra de Vizinhos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/184345.mp4', 'http://gstaticontent.com/images/3f07f2f34f0e7f6c3eb3eada1143dc12.jpg'),
(57954, 3935, 'Hacks S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179851.mp4', 'http://timg.bdta.pro/images/a6a5998639433583b50de19cb953e05e.jpg'),
(57955, 3935, 'Hacks S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179852.mp4', 'http://timg.bdta.pro/images/36e582e2c7e207f32eb3f307020119f1.jpg'),
(57956, 3935, 'Hacks S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179853.mp4', 'http://timg.bdta.pro/images/f7774b5c2f4c82d2d22aa2b552cd77db.jpg'),
(57957, 3935, 'Hacks S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179854.mp4', 'http://timg.bdta.pro/images/747155bcf42ebac0cfa9ca20dca9a90e.jpg'),
(57958, 3935, 'Hacks S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179855.mp4', 'http://timg.bdta.pro/images/d3c3fbb858ab6f51943cfef8b6f14628.jpg'),
(57959, 3935, 'Hacks S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179856.mp4', 'http://timg.bdta.pro/images/762a43cf5672247914c407138a6d8ec9.jpg'),
(57960, 3935, 'Hacks S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179857.mp4', 'http://timg.bdta.pro/images/023011f84c5075fa6b6eeb8a6a302ce1.jpg'),
(57961, 3935, 'Hacks S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179858.mp4', 'http://timg.bdta.pro/images/fd9228c1a95dc3d614aee8e910472424.jpg'),
(57962, 3935, 'Hacks S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179859.mp4', 'http://timg.bdta.pro/images/a48b897e3ef174d82da7378fdde7508b.jpg'),
(57963, 3935, 'Hacks S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179860.mp4', 'http://timg.bdta.pro/images/9139a7fc621e28bb49a5ac24dadbbe08.jpg'),
(57964, 3936, 'Hacks S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179861.mp4', 'http://timg.bdta.pro/images/7abbd962ea3a66e7a9967586ccfd295d.jpg'),
(57965, 3936, 'Hacks S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179862.mp4', 'http://timg.bdta.pro/images/2507def5a03fb32d88efdd4a1dc0db82.jpg'),
(57966, 3936, 'Hacks S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179863.mp4', 'http://timg.bdta.pro/images/b69d07f65b11cc35989d6cb1071869ca.jpg'),
(57967, 3936, 'Hacks S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179864.mp4', 'http://timg.bdta.pro/images/bee8ac7152056630795c605dafe075d5.jpg'),
(57968, 3936, 'Hacks S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179865.mp4', 'http://timg.bdta.pro/images/4dce07e10e9aa3d6016d6eae7dd02e01.jpg'),
(57969, 3936, 'Hacks S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179866.mp4', 'http://timg.bdta.pro/images/9764e853e1bd7f057294f45fe6f4d223.jpg'),
(57970, 3936, 'Hacks S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179867.mp4', 'http://timg.bdta.pro/images/92ee326ffb974d0abb53f452345195b9.jpg'),
(57971, 3936, 'Hacks S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179868.mp4', 'http://timg.bdta.pro/images/5f6dfe050eeec9ffaa4c87fd6e1b277e.jpg'),
(57972, 3937, 'Hacks S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/373993.mp4', 'http://gstaticontent.com/images/cbe15d6f860230916186636177b6beec.jpg'),
(57973, 3937, 'Hacks S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/373994.mp4', 'http://gstaticontent.com/images/cbe15d6f860230916186636177b6beec.jpg'),
(57974, 3937, 'Hacks S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/373995.mp4', 'http://gstaticontent.com/images/cbe15d6f860230916186636177b6beec.jpg'),
(57975, 3937, 'Hacks S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/373996.mp4', 'http://gstaticontent.com/images/cbe15d6f860230916186636177b6beec.jpg'),
(57976, 3937, 'Hacks S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/373997.mp4', 'http://gstaticontent.com/images/cbe15d6f860230916186636177b6beec.jpg'),
(57977, 3937, 'Hacks S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/373998.mp4', 'http://gstaticontent.com/images/cbe15d6f860230916186636177b6beec.jpg'),
(57978, 3937, 'Hacks S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/373999.mp4', 'http://gstaticontent.com/images/cbe15d6f860230916186636177b6beec.jpg'),
(57979, 3937, 'Hacks S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/374000.mp4', 'http://gstaticontent.com/images/cbe15d6f860230916186636177b6beec.jpg'),
(57980, 3937, 'Hacks S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/374001.mp4', 'http://gstaticontent.com/images/cbe15d6f860230916186636177b6beec.jpg'),
(57981, 3938, 'Hacks S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/766749.mp4', 'http://gstaticontent.com/images/cbe15d6f860230916186636177b6beec.jpg'),
(57982, 3938, 'Hacks S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/766750.mp4', 'http://gstaticontent.com/images/cbe15d6f860230916186636177b6beec.jpg'),
(57983, 3938, 'Hacks S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/775796.mp4', 'http://gstaticontent.com/images/cbe15d6f860230916186636177b6beec.jpg'),
(57984, 3938, 'Hacks S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/780157.mp4', 'http://gstaticontent.com/images/cbe15d6f860230916186636177b6beec.jpg'),
(57985, 3938, 'Hacks S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/794413.mp4', 'http://gstaticontent.com/images/cbe15d6f860230916186636177b6beec.jpg'),
(57986, 3938, 'Hacks S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/795725.mp4', 'http://gstaticontent.com/images/cbe15d6f860230916186636177b6beec.jpg'),
(57987, 3938, 'Hacks S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/800909.mp4', 'http://gstaticontent.com/images/cbe15d6f860230916186636177b6beec.jpg'),
(57988, 3938, 'Hacks S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/800910.mp4', 'http://gstaticontent.com/images/cbe15d6f860230916186636177b6beec.jpg'),
(57989, 3938, 'Hacks S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/809890.mp4', 'http://gstaticontent.com/images/cbe15d6f860230916186636177b6beec.jpg'),
(57990, 3938, 'Hacks S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/822116.mp4', 'http://gstaticontent.com/images/cbe15d6f860230916186636177b6beec.jpg'),
(57991, 3939, 'Mestres da Sabotagem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257452.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(57992, 3939, 'Mestres da Sabotagem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257453.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(57993, 3939, 'Mestres da Sabotagem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257454.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(57994, 3939, 'Mestres da Sabotagem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257455.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(57995, 3939, 'Mestres da Sabotagem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257456.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(57996, 3939, 'Mestres da Sabotagem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257457.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(57997, 3939, 'Mestres da Sabotagem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257458.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(57998, 3939, 'Mestres da Sabotagem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257459.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(57999, 3939, 'Mestres da Sabotagem S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257460.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58000, 3939, 'Mestres da Sabotagem S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257461.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58001, 3940, 'Mestres da Sabotagem S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257462.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58002, 3940, 'Mestres da Sabotagem S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257463.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58003, 3940, 'Mestres da Sabotagem S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257464.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58004, 3940, 'Mestres da Sabotagem S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257465.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58005, 3940, 'Mestres da Sabotagem S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257466.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58006, 3940, 'Mestres da Sabotagem S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257467.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58007, 3940, 'Mestres da Sabotagem S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257468.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58008, 3940, 'Mestres da Sabotagem S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257469.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58009, 3940, 'Mestres da Sabotagem S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257470.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58010, 3940, 'Mestres da Sabotagem S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257471.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58011, 3940, 'Mestres da Sabotagem S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257472.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58012, 3940, 'Mestres da Sabotagem S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257473.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58013, 3940, 'Mestres da Sabotagem S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257474.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58014, 3941, 'Mestres da Sabotagem S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257475.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58015, 3941, 'Mestres da Sabotagem S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257476.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58016, 3941, 'Mestres da Sabotagem S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257477.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58017, 3941, 'Mestres da Sabotagem S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257478.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58018, 3941, 'Mestres da Sabotagem S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257479.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58019, 3941, 'Mestres da Sabotagem S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257480.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58020, 3941, 'Mestres da Sabotagem S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257481.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58021, 3941, 'Mestres da Sabotagem S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257482.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58022, 3941, 'Mestres da Sabotagem S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257483.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58023, 3941, 'Mestres da Sabotagem S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257484.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58024, 3941, 'Mestres da Sabotagem S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257485.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58025, 3941, 'Mestres da Sabotagem S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257486.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58026, 3941, 'Mestres da Sabotagem S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257487.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58027, 3942, 'Mestres da Sabotagem S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257488.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58028, 3942, 'Mestres da Sabotagem S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257489.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58029, 3942, 'Mestres da Sabotagem S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257490.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58030, 3942, 'Mestres da Sabotagem S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257491.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(58031, 3942, 'Mestres da Sabotagem S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257492.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58032, 3942, 'Mestres da Sabotagem S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257493.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58033, 3942, 'Mestres da Sabotagem S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257494.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58034, 3942, 'Mestres da Sabotagem S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257495.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58035, 3942, 'Mestres da Sabotagem S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257496.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58036, 3942, 'Mestres da Sabotagem S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257497.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58037, 3942, 'Mestres da Sabotagem S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257498.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58038, 3942, 'Mestres da Sabotagem S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257499.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58039, 3942, 'Mestres da Sabotagem S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257500.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58040, 3943, 'Mestres da Sabotagem S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257501.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58041, 3943, 'Mestres da Sabotagem S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257502.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58042, 3943, 'Mestres da Sabotagem S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257503.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58043, 3943, 'Mestres da Sabotagem S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257504.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58044, 3943, 'Mestres da Sabotagem S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257505.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58045, 3943, 'Mestres da Sabotagem S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257506.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58046, 3943, 'Mestres da Sabotagem S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257507.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58047, 3943, 'Mestres da Sabotagem S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257508.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58048, 3943, 'Mestres da Sabotagem S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257509.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58049, 3943, 'Mestres da Sabotagem S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257510.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58050, 3943, 'Mestres da Sabotagem S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257511.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58051, 3943, 'Mestres da Sabotagem S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257512.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58052, 3943, 'Mestres da Sabotagem S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257513.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58053, 3944, 'Mestres da Sabotagem S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257514.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58054, 3944, 'Mestres da Sabotagem S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257515.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58055, 3944, 'Mestres da Sabotagem S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257516.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58056, 3944, 'Mestres da Sabotagem S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257517.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58057, 3944, 'Mestres da Sabotagem S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257518.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58058, 3944, 'Mestres da Sabotagem S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257519.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58059, 3944, 'Mestres da Sabotagem S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257520.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58060, 3944, 'Mestres da Sabotagem S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257521.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58061, 3944, 'Mestres da Sabotagem S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257522.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58062, 3944, 'Mestres da Sabotagem S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257523.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58063, 3944, 'Mestres da Sabotagem S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257524.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58064, 3944, 'Mestres da Sabotagem S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257525.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58065, 3944, 'Mestres da Sabotagem S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257526.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58066, 3945, 'Mestres da Sabotagem S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257527.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58067, 3945, 'Mestres da Sabotagem S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257528.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58068, 3945, 'Mestres da Sabotagem S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257529.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58069, 3945, 'Mestres da Sabotagem S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257530.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58070, 3945, 'Mestres da Sabotagem S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257531.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58071, 3945, 'Mestres da Sabotagem S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257532.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58072, 3945, 'Mestres da Sabotagem S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257533.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58073, 3945, 'Mestres da Sabotagem S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257534.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58074, 3945, 'Mestres da Sabotagem S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257535.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58075, 3945, 'Mestres da Sabotagem S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257536.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58076, 3945, 'Mestres da Sabotagem S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257537.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58077, 3945, 'Mestres da Sabotagem S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257538.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58078, 3945, 'Mestres da Sabotagem S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257539.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58079, 3946, 'Mestres da Sabotagem S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257540.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58080, 3946, 'Mestres da Sabotagem S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257541.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58081, 3946, 'Mestres da Sabotagem S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257542.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58082, 3946, 'Mestres da Sabotagem S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257543.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58083, 3946, 'Mestres da Sabotagem S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257544.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58084, 3946, 'Mestres da Sabotagem S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257545.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58085, 3946, 'Mestres da Sabotagem S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257546.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58086, 3946, 'Mestres da Sabotagem S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257547.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58087, 3946, 'Mestres da Sabotagem S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257548.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58088, 3946, 'Mestres da Sabotagem S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257549.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58089, 3946, 'Mestres da Sabotagem S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257550.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58090, 3946, 'Mestres da Sabotagem S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257551.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58091, 3946, 'Mestres da Sabotagem S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257552.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58092, 3947, 'Mestres da Sabotagem S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257553.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58093, 3947, 'Mestres da Sabotagem S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257554.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58094, 3947, 'Mestres da Sabotagem S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257555.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58095, 3947, 'Mestres da Sabotagem S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257556.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58096, 3947, 'Mestres da Sabotagem S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257557.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58097, 3947, 'Mestres da Sabotagem S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257558.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58098, 3947, 'Mestres da Sabotagem S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257559.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58099, 3947, 'Mestres da Sabotagem S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257560.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58100, 3947, 'Mestres da Sabotagem S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257561.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58101, 3947, 'Mestres da Sabotagem S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257562.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58102, 3947, 'Mestres da Sabotagem S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257563.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58103, 3947, 'Mestres da Sabotagem S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257564.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58104, 3947, 'Mestres da Sabotagem S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257565.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58105, 3948, 'Mestres da Sabotagem S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257566.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58106, 3948, 'Mestres da Sabotagem S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257567.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58107, 3948, 'Mestres da Sabotagem S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257568.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58108, 3948, 'Mestres da Sabotagem S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257569.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58109, 3948, 'Mestres da Sabotagem S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257570.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58110, 3948, 'Mestres da Sabotagem S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257571.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58111, 3948, 'Mestres da Sabotagem S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257572.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58112, 3948, 'Mestres da Sabotagem S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257573.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58113, 3948, 'Mestres da Sabotagem S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257574.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58114, 3948, 'Mestres da Sabotagem S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257575.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58115, 3948, 'Mestres da Sabotagem S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257576.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58116, 3948, 'Mestres da Sabotagem S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257577.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58117, 3949, 'Mestres da Sabotagem S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257578.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58118, 3949, 'Mestres da Sabotagem S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257579.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58119, 3949, 'Mestres da Sabotagem S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257580.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58120, 3949, 'Mestres da Sabotagem S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257581.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58121, 3949, 'Mestres da Sabotagem S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257582.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58122, 3949, 'Mestres da Sabotagem S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257583.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58123, 3949, 'Mestres da Sabotagem S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257584.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58124, 3949, 'Mestres da Sabotagem S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257585.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58125, 3949, 'Mestres da Sabotagem S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257586.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58126, 3949, 'Mestres da Sabotagem S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257587.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58127, 3949, 'Mestres da Sabotagem S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257588.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58128, 3949, 'Mestres da Sabotagem S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257589.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58129, 3949, 'Mestres da Sabotagem S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257590.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58130, 3949, 'Mestres da Sabotagem S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/257591.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58131, 3949, 'Mestres da Sabotagem S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/257592.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58132, 3949, 'Mestres da Sabotagem S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/257593.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58133, 3949, 'Mestres da Sabotagem S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/257594.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58134, 3949, 'Mestres da Sabotagem S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/257595.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58135, 3949, 'Mestres da Sabotagem S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/257596.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58136, 3950, 'Mestres da Sabotagem S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257597.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58137, 3950, 'Mestres da Sabotagem S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257598.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58138, 3950, 'Mestres da Sabotagem S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257599.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58139, 3950, 'Mestres da Sabotagem S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257600.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58140, 3950, 'Mestres da Sabotagem S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257601.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58141, 3950, 'Mestres da Sabotagem S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257602.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58142, 3950, 'Mestres da Sabotagem S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257603.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58143, 3950, 'Mestres da Sabotagem S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257604.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58144, 3950, 'Mestres da Sabotagem S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257605.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58145, 3950, 'Mestres da Sabotagem S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257606.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58146, 3950, 'Mestres da Sabotagem S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257607.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58147, 3950, 'Mestres da Sabotagem S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257608.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58148, 3950, 'Mestres da Sabotagem S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257609.mp4', 'http://gstaticontent.com/images/d84b55d57fb3e002979a26dafc88ddf1.jpg'),
(58149, 3951, 'Possessions S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146096.mp4', 'http://timg.bdta.pro/images/213914c87b5ee32311cc840c2e6d5ef3.jpg'),
(58150, 3951, 'Possessions S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146097.mp4', 'http://timg.bdta.pro/images/d898ea89b09e1e505381d302de3e1b91.jpg'),
(58151, 3951, 'Possessions S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146098.mp4', 'http://timg.bdta.pro/images/0e5372907c9656e99ec4538d69dccf07.jpg'),
(58152, 3951, 'Possessions S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146099.mp4', 'http://timg.bdta.pro/images/d19bb2fef5ab8cf2771ca8d378bc4a19.jpg'),
(58153, 3951, 'Possessions S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146100.mp4', 'http://timg.bdta.pro/images/37d1d2d1929d2323e499355468ab7507.jpg'),
(58154, 3951, 'Possessions S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146101.mp4', 'http://timg.bdta.pro/images/d0c93cf754dd075f2e29caff712afb32.jpg'),
(58155, 3952, 'Resident Evil: No Escuro Absoluto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146092.mp4', 'http://timg.bdta.pro/images/2c4761b142fd4bff7ae96fdbed639818.jpg'),
(58156, 3952, 'Resident Evil: No Escuro Absoluto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146093.mp4', 'http://timg.bdta.pro/images/3a5577e6c3de372f310af03fec4b6f91.jpg'),
(58157, 3952, 'Resident Evil: No Escuro Absoluto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146094.mp4', 'http://timg.bdta.pro/images/d1abb4551be5bfd31d16793d467b884d.jpg'),
(58158, 3952, 'Resident Evil: No Escuro Absoluto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146095.mp4', 'http://timg.bdta.pro/images/7e09deb9ba3a30b16a996d5e673fe943.jpg'),
(58159, 3953, 'Samurai X S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145997.mp4', 'http://timg.bdta.pro/images/8fa674da023bafc85528cb5700fbe17c.jpg'),
(58160, 3953, 'Samurai X S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145998.mp4', 'http://timg.bdta.pro/images/a6b0e3cb9606d0cfa0c69f8e980481d9.jpg'),
(58161, 3953, 'Samurai X S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145999.mp4', 'http://timg.bdta.pro/images/0e9f79f00abbba476c7f6681ccc7bedc.jpg'),
(58162, 3953, 'Samurai X S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146000.mp4', 'http://timg.bdta.pro/images/3004f56f775ea549604dd78a8e53aefb.jpg'),
(58163, 3953, 'Samurai X S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146001.mp4', 'http://timg.bdta.pro/images/c8a7c2a896645211b8b0f42b46d8218b.jpg'),
(58164, 3953, 'Samurai X S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146002.mp4', 'http://timg.bdta.pro/images/607d905f93d1bdf307076e94e6f1f7b2.jpg'),
(58165, 3953, 'Samurai X S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146003.mp4', 'http://timg.bdta.pro/images/c815c184ec216315b0f2150ad4ed3104.jpg'),
(58166, 3953, 'Samurai X S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146004.mp4', 'http://timg.bdta.pro/images/bea893e3478f3479b03c875f43901772.jpg'),
(58167, 3953, 'Samurai X S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146005.mp4', 'http://timg.bdta.pro/images/4922f264d8c359b212c367d0c88446d8.jpg'),
(58168, 3953, 'Samurai X S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146006.mp4', 'http://timg.bdta.pro/images/6766b0bc31d40711c245b9af14c03683.jpg'),
(58169, 3953, 'Samurai X S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146007.mp4', 'http://timg.bdta.pro/images/e7f52da2e59e6893107603a267ad4c69.jpg'),
(58170, 3953, 'Samurai X S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146008.mp4', 'http://timg.bdta.pro/images/b4f24ff431bd0cc7836f8f5b1d2ac69d.jpg'),
(58171, 3953, 'Samurai X S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146009.mp4', 'http://timg.bdta.pro/images/9d5336fbf8ad038b8abc08fd292809e1.jpg'),
(58172, 3953, 'Samurai X S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146010.mp4', 'http://timg.bdta.pro/images/c51f65419a0d7def2a91e6ed807571f0.jpg'),
(58173, 3953, 'Samurai X S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146011.mp4', 'http://timg.bdta.pro/images/017036178e70a8a099378b71162dd88d.jpg'),
(58174, 3953, 'Samurai X S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146012.mp4', 'http://timg.bdta.pro/images/f6192092e91a7b2d69e46976b697d5fd.jpg'),
(58175, 3953, 'Samurai X S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146013.mp4', 'http://timg.bdta.pro/images/1885d3bcd3c64d048386fd20e4069f47.jpg'),
(58176, 3953, 'Samurai X S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146014.mp4', 'http://timg.bdta.pro/images/b7e577ba1fd136753b137648405cf40a.jpg'),
(58177, 3953, 'Samurai X S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/146015.mp4', 'http://timg.bdta.pro/images/2f4a398fe4df0aa1183d0676f48f1a1c.jpg'),
(58178, 3953, 'Samurai X S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/146016.mp4', 'http://timg.bdta.pro/images/fe4f71c9d3732624444065c3bc537d13.jpg'),
(58179, 3953, 'Samurai X S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/146017.mp4', 'http://timg.bdta.pro/images/c19c357434b050e2530aeb3c3e37d9fd.jpg'),
(58180, 3953, 'Samurai X S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/146018.mp4', 'http://timg.bdta.pro/images/8f7bccef261310490acec8db1495506e.jpg'),
(58181, 3953, 'Samurai X S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/146019.mp4', 'http://timg.bdta.pro/images/5acc82cd5563e2729250ebcafbb4169e.jpg'),
(58182, 3953, 'Samurai X S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/146020.mp4', 'http://timg.bdta.pro/images/1389ce57b01fac393bbbc07ea6d5953d.jpg'),
(58183, 3953, 'Samurai X S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/146021.mp4', 'http://timg.bdta.pro/images/832213ec2a7c4c12be00bd2b35bceb09.jpg'),
(58184, 3953, 'Samurai X S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/146022.mp4', 'http://timg.bdta.pro/images/2b2d6994c0f3dd81943b9826e25123eb.jpg'),
(58185, 3953, 'Samurai X S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/146023.mp4', 'http://timg.bdta.pro/images/948bf22617f27bfc35ef002aa7fbaae0.jpg'),
(58186, 3954, 'Samurai X S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146024.mp4', 'http://timg.bdta.pro/images/8f0feb16d8d7f52d0ffc4230d0a8c511.jpg'),
(58187, 3954, 'Samurai X S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146025.mp4', 'http://timg.bdta.pro/images/3282c359faa8c6a2143fcee5228da5fe.jpg'),
(58188, 3954, 'Samurai X S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146026.mp4', 'http://timg.bdta.pro/images/a94a903819e10dc641bb6390e2a29f94.jpg'),
(58189, 3954, 'Samurai X S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146027.mp4', 'http://timg.bdta.pro/images/38e23217025d5c24f3f567eecaac673d.jpg'),
(58190, 3954, 'Samurai X S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146028.mp4', 'http://timg.bdta.pro/images/a7fa4a707d75bd5347aed345e941c56c.jpg'),
(58191, 3954, 'Samurai X S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146029.mp4', 'http://timg.bdta.pro/images/0053fbbb9bb8cbace8a1363e8945d58a.jpg'),
(58192, 3954, 'Samurai X S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146030.mp4', 'http://timg.bdta.pro/images/c15ff2e2c964693539f21d029b51985a.jpg'),
(58193, 3954, 'Samurai X S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146031.mp4', 'http://timg.bdta.pro/images/72b1e0325feb06c9a51bf7bb618b26af.jpg'),
(58194, 3954, 'Samurai X S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146032.mp4', 'http://timg.bdta.pro/images/59bb92851ca59df09e58b7bbe265904e.jpg'),
(58195, 3954, 'Samurai X S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146033.mp4', 'http://timg.bdta.pro/images/20ef52f2c75fb9bb1da5f507b92c7891.jpg'),
(58196, 3954, 'Samurai X S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146034.mp4', 'http://timg.bdta.pro/images/81a47ffad9d53b8ba5c87dfe1f85f7e4.jpg'),
(58197, 3954, 'Samurai X S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146035.mp4', 'http://timg.bdta.pro/images/ddc53a04e66a3b59f6d91e32bc6921fe.jpg'),
(58198, 3954, 'Samurai X S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146036.mp4', 'http://timg.bdta.pro/images/af971f9bd85881a2346f88e73bc674bc.jpg'),
(58199, 3954, 'Samurai X S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146037.mp4', 'http://timg.bdta.pro/images/c51f65419a0d7def2a91e6ed807571f0.jpg'),
(58200, 3954, 'Samurai X S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146038.mp4', 'http://timg.bdta.pro/images/935f96502eef160370b6bdf4dadac07a.jpg'),
(58201, 3954, 'Samurai X S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146039.mp4', 'http://timg.bdta.pro/images/a146960a10f8a493ab45bec4c1219df2.jpg'),
(58202, 3954, 'Samurai X S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146040.mp4', 'http://timg.bdta.pro/images/25701dfeab95355a3817f7e7a138a246.jpg'),
(58203, 3954, 'Samurai X S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146041.mp4', 'http://timg.bdta.pro/images/40fb481f99c0eeb4d729e2bcfacdbaa9.jpg'),
(58204, 3954, 'Samurai X S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/146042.mp4', 'http://timg.bdta.pro/images/34a7aec97958857217dda00281f4be2e.jpg'),
(58205, 3954, 'Samurai X S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/146043.mp4', 'http://timg.bdta.pro/images/a758c63b4c26cbdf218744d861467758.jpg'),
(58206, 3954, 'Samurai X S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/146044.mp4', 'http://timg.bdta.pro/images/63ea568a78992aadd288f6913cdfddca.jpg'),
(58207, 3954, 'Samurai X S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/146045.mp4', 'http://timg.bdta.pro/images/38be8b62da8f7f5f08cb8576578b9b0a.jpg'),
(58208, 3954, 'Samurai X S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/146046.mp4', 'http://timg.bdta.pro/images/76f40a1927c4b1e3206d589a5457fe36.jpg'),
(58209, 3954, 'Samurai X S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/146047.mp4', 'http://timg.bdta.pro/images/ccb5219a818b0f76023c281a69f6d033.jpg'),
(58210, 3954, 'Samurai X S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/146048.mp4', 'http://timg.bdta.pro/images/f065443ced67ae597905aba6cd38ef03.jpg'),
(58211, 3954, 'Samurai X S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/146049.mp4', 'http://timg.bdta.pro/images/a1d47650b72eaadb8e4f3505e0a2eef3.jpg'),
(58212, 3954, 'Samurai X S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/146050.mp4', 'http://timg.bdta.pro/images/ccd0b4a27892ba04d8928bc2262877d9.jpg'),
(58213, 3954, 'Samurai X S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/146051.mp4', 'http://timg.bdta.pro/images/5e97876b07403e1ff19ea4fe751ef253.jpg'),
(58214, 3954, 'Samurai X S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/146052.mp4', 'http://timg.bdta.pro/images/b5bf5043e411f40687f15d53c50b6c2b.jpg'),
(58215, 3954, 'Samurai X S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/146053.mp4', 'http://timg.bdta.pro/images/c67aed9a63d9b4b23aad9e5c6b033dc2.jpg'),
(58216, 3954, 'Samurai X S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/146054.mp4', 'http://timg.bdta.pro/images/0edd0457536c72e567d6a7bcd1d46350.jpg'),
(58217, 3954, 'Samurai X S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/146055.mp4', 'http://timg.bdta.pro/images/05828e594535ce67a19b42eebd84ce10.jpg'),
(58218, 3954, 'Samurai X S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/146056.mp4', 'http://timg.bdta.pro/images/438e2c12cc38ec4b81b744eccb65d94a.jpg'),
(58219, 3954, 'Samurai X S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/146057.mp4', 'http://timg.bdta.pro/images/f67c322c33643a9d831f01248258378c.jpg'),
(58220, 3954, 'Samurai X S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/146058.mp4', 'http://timg.bdta.pro/images/dca696a77b2175dd3ee70832ee8036d9.jpg'),
(58221, 3955, 'Samurai X S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/146059.mp4', 'http://timg.bdta.pro/images/360041cb8bb2d85d1964c614b7a30d22.jpg'),
(58222, 3955, 'Samurai X S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/146060.mp4', 'http://timg.bdta.pro/images/58c5ca68c9ce092af5222739a83cb79d.jpg'),
(58223, 3955, 'Samurai X S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/146061.mp4', 'http://timg.bdta.pro/images/e87794c8f952098ec65137aab3df32b7.jpg'),
(58224, 3955, 'Samurai X S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/146062.mp4', 'http://timg.bdta.pro/images/0159c5cc9559c0baf6279e71ab3ae25c.jpg'),
(58225, 3955, 'Samurai X S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/146063.mp4', 'http://timg.bdta.pro/images/5802ccb5274b85d72652666ed2333240.jpg'),
(58226, 3955, 'Samurai X S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/146064.mp4', 'http://timg.bdta.pro/images/0ca18a681692d9543577381f974cd0c6.jpg'),
(58227, 3955, 'Samurai X S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/146065.mp4', 'http://timg.bdta.pro/images/9905a9a060194799667cd356e394619c.jpg'),
(58228, 3955, 'Samurai X S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/146066.mp4', 'http://timg.bdta.pro/images/cb672c876000a83f746545634fe0d38b.jpg'),
(58229, 3955, 'Samurai X S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/146067.mp4', 'http://timg.bdta.pro/images/df167f6bf1b27320e00cad299aaf9f7b.jpg'),
(58230, 3955, 'Samurai X S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/146068.mp4', 'http://timg.bdta.pro/images/0688049949a2040b54650e069e3e2868.jpg'),
(58231, 3955, 'Samurai X S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/146069.mp4', 'http://timg.bdta.pro/images/caad4027297f97ed34157c6cd4cbffce.jpg'),
(58232, 3955, 'Samurai X S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/146070.mp4', 'http://timg.bdta.pro/images/caad4027297f97ed34157c6cd4cbffce.jpg'),
(58233, 3955, 'Samurai X S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/146071.mp4', 'http://timg.bdta.pro/images/68f0884559e4931af5474ccb50bff107.jpg'),
(58234, 3955, 'Samurai X S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/146072.mp4', 'http://timg.bdta.pro/images/ca2507a97eae8e7ceea06f1d48a7cff3.jpg'),
(58235, 3955, 'Samurai X S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/146073.mp4', 'http://timg.bdta.pro/images/de96d905571bfc9ae3a83c6ee609684a.jpg'),
(58236, 3955, 'Samurai X S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/146074.mp4', 'http://timg.bdta.pro/images/d494a35b60081461339c7cb7f4306009.jpg'),
(58237, 3955, 'Samurai X S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/146075.mp4', 'http://timg.bdta.pro/images/e7b0d5e6264d4ce7688a15b93b801788.jpg'),
(58238, 3955, 'Samurai X S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/146076.mp4', 'http://timg.bdta.pro/images/56bb73d11326d5eb1cfb560196fd320a.jpg'),
(58239, 3955, 'Samurai X S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/146077.mp4', 'http://timg.bdta.pro/images/b583f2f694dbff3ca63c83598af4a6e5.jpg'),
(58240, 3955, 'Samurai X S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/146078.mp4', 'http://timg.bdta.pro/images/8bbba2c4b9c40dfb9f97c99c78d0eb09.jpg'),
(58241, 3955, 'Samurai X S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/146079.mp4', 'http://timg.bdta.pro/images/63ea568a78992aadd288f6913cdfddca.jpg'),
(58242, 3955, 'Samurai X S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/146080.mp4', 'http://timg.bdta.pro/images/64804a6a976e95f191a6db0c05df4b95.jpg'),
(58243, 3955, 'Samurai X S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/146081.mp4', 'http://timg.bdta.pro/images/c25972cc1a6ab85a18b3c17d8982c3b3.jpg'),
(58244, 3955, 'Samurai X S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/146082.mp4', 'http://timg.bdta.pro/images/72c18130129467341273102ab86a76f0.jpg'),
(58245, 3955, 'Samurai X S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/146083.mp4', 'http://timg.bdta.pro/images/2be5f1aafc54800bd3be6b2b5ab968bb.jpg'),
(58246, 3955, 'Samurai X S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/146084.mp4', 'http://timg.bdta.pro/images/c36fe42f37ea2bf12b03b41f9d334067.jpg'),
(58247, 3955, 'Samurai X S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/146085.mp4', 'http://timg.bdta.pro/images/1e31e3f6f75a202e8dc10775bff287d0.jpg'),
(58248, 3955, 'Samurai X S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/146086.mp4', 'http://timg.bdta.pro/images/96a6f94a16e0e5b6548e93065ec7cc06.jpg'),
(58249, 3955, 'Samurai X S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/146087.mp4', 'http://timg.bdta.pro/images/3b514e4043e84fb9e5a25425c8830cef.jpg'),
(58250, 3955, 'Samurai X S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/146088.mp4', 'http://timg.bdta.pro/images/9a9d9630100c73e831404356fc51d45f.jpg'),
(58251, 3955, 'Samurai X S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/146089.mp4', 'http://timg.bdta.pro/images/71c76eba6f3f68d4d511d3c2980680af.jpg'),
(58252, 3955, 'Samurai X S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/146090.mp4', 'http://timg.bdta.pro/images/199a2fb53d9c9363bfa1d2711a669d6f.jpg'),
(58253, 3955, 'Samurai X S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/146091.mp4', 'http://gstaticontent.com/images/b45ff22762cf602ffd7b5122b4a73c94.jpg'),
(58254, 3956, 'Search Party S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145967.mp4', 'http://timg.bdta.pro/images/f6548d6724afe24df4d15a2bdf6bb9f5.jpg'),
(58255, 3956, 'Search Party S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145968.mp4', 'http://timg.bdta.pro/images/be8730497e2ff305558c4030fa48e8db.jpg'),
(58256, 3956, 'Search Party S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145969.mp4', 'http://timg.bdta.pro/images/abcb79be789846ca6c31e20a96342a9c.jpg'),
(58257, 3956, 'Search Party S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145970.mp4', 'http://timg.bdta.pro/images/a602929e59910a1dc966bda27fa9bf28.jpg'),
(58258, 3956, 'Search Party S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145971.mp4', 'http://timg.bdta.pro/images/a03d0fff7d552c79fa49817e32fc511b.jpg'),
(58259, 3956, 'Search Party S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145972.mp4', 'http://timg.bdta.pro/images/9348013c652b764a156348eeed9c83b5.jpg'),
(58260, 3956, 'Search Party S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145973.mp4', 'http://timg.bdta.pro/images/c0ce8e7fef0fdae0ebd1f8e62ab0a78d.jpg'),
(58261, 3956, 'Search Party S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145974.mp4', 'http://timg.bdta.pro/images/8771c411288af22a414d9a78d69e8840.jpg'),
(58262, 3956, 'Search Party S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145975.mp4', 'http://timg.bdta.pro/images/afca926c18b45dbb946e02e43d2f7132.jpg'),
(58263, 3956, 'Search Party S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145976.mp4', 'http://timg.bdta.pro/images/e86cf4b835a399d28652dab01870c9c1.jpg'),
(58264, 3957, 'Search Party S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145977.mp4', 'http://timg.bdta.pro/images/ed97f4010ecfe7aaf01d5beed5f0f963.jpg'),
(58265, 3957, 'Search Party S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145978.mp4', 'http://timg.bdta.pro/images/c8878861c6d0579589d98e99dbffbb14.jpg'),
(58266, 3957, 'Search Party S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145979.mp4', 'http://timg.bdta.pro/images/40f0e187b2a3a7d847910a9f9d18094c.jpg'),
(58267, 3957, 'Search Party S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145980.mp4', 'http://timg.bdta.pro/images/17b4d1bee5f1b381e28cc3a3a606b873.jpg'),
(58268, 3957, 'Search Party S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145981.mp4', 'http://timg.bdta.pro/images/d4dd21e9a5ef586515256544e625a7d5.jpg'),
(58269, 3957, 'Search Party S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145982.mp4', 'http://timg.bdta.pro/images/56c72f4a4be30e3b2c1688649517e327.jpg'),
(58270, 3957, 'Search Party S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145983.mp4', 'http://timg.bdta.pro/images/28c16967dbf21e5d363ba32001b3f02a.jpg'),
(58271, 3957, 'Search Party S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145984.mp4', 'http://timg.bdta.pro/images/608cdbe01f773385721d8274ae9190f6.jpg'),
(58272, 3957, 'Search Party S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145985.mp4', 'http://timg.bdta.pro/images/7071cd48eaef3c5fb634229b03dcb2ee.jpg'),
(58273, 3957, 'Search Party S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145986.mp4', 'http://timg.bdta.pro/images/7464eee27359f5fc4dd88e234a8702f9.jpg'),
(58274, 3958, 'Search Party S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145987.mp4', 'http://timg.bdta.pro/images/89c1e355f7e536476fd83af4c5b62c15.jpg'),
(58275, 3958, 'Search Party S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145988.mp4', 'http://timg.bdta.pro/images/58b0ea477356a1dc2dd3d4198d7224fc.jpg'),
(58276, 3958, 'Search Party S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145989.mp4', 'http://timg.bdta.pro/images/4c17aba439b543c684c3d86870b7afab.jpg'),
(58277, 3958, 'Search Party S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145990.mp4', 'http://timg.bdta.pro/images/797d00b4d77b3cf7b295627e1702fcd7.jpg'),
(58278, 3958, 'Search Party S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145991.mp4', 'http://timg.bdta.pro/images/46ca66812d05d3e2c4fbe20aafe414a9.jpg'),
(58279, 3958, 'Search Party S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145992.mp4', 'http://timg.bdta.pro/images/e5362699b25941d7e64fa6ae6fd3754b.jpg'),
(58280, 3958, 'Search Party S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145993.mp4', 'http://timg.bdta.pro/images/bc6e8a31487ee5910db2caaf4421a285.jpg'),
(58281, 3958, 'Search Party S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145994.mp4', 'http://timg.bdta.pro/images/6e1afe38d80944d19b6747c3904211ce.jpg'),
(58282, 3958, 'Search Party S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145995.mp4', 'http://timg.bdta.pro/images/2e0b81475870229f58c81a06fd4467c8.jpg'),
(58283, 3958, 'Search Party S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145996.mp4', 'http://timg.bdta.pro/images/b7128c2a40133d3ce700561132c179f9.jpg'),
(58284, 3959, 'Trigonometry S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145959.mp4', 'http://timg.bdta.pro/images/229eba6da0cdde1e45610aea5f3cb62f.jpg'),
(58285, 3959, 'Trigonometry S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145960.mp4', 'http://timg.bdta.pro/images/e39b495c13d4ac695106963590b1527c.jpg'),
(58286, 3959, 'Trigonometry S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145961.mp4', 'http://timg.bdta.pro/images/45761008deb0c6592a3289eb8b191fb8.jpg'),
(58287, 3959, 'Trigonometry S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145962.mp4', 'http://timg.bdta.pro/images/50fbba2a64992bfb451d9d596af3ebf3.jpg'),
(58288, 3959, 'Trigonometry S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145963.mp4', 'http://timg.bdta.pro/images/88303165f2625a48f495b89a64f989df.jpg'),
(58289, 3959, 'Trigonometry S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145964.mp4', 'http://timg.bdta.pro/images/12798d6aaa326aee8bf6a431772b7119.jpg'),
(58290, 3959, 'Trigonometry S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145965.mp4', 'http://timg.bdta.pro/images/ff07d69dd80abfa2a3fa9a115cc5f807.jpg'),
(58291, 3959, 'Trigonometry S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145966.mp4', 'http://timg.bdta.pro/images/e9ecba0db0816c4dafdd35e6b8d873a0.jpg'),
(58292, 3960, 'Valéria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232730.mp4', 'http://timg.bdta.pro/images/cb79bbc58b542432b7ead4536a221448.jpg'),
(58293, 3960, 'Valéria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232731.mp4', 'http://timg.bdta.pro/images/1990b9ca95bcc4321a0bb325830eff2b.jpg'),
(58294, 3960, 'Valéria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232732.mp4', 'http://timg.bdta.pro/images/e603a5d94ca4ed1f0030e83c84a155c7.jpg'),
(58295, 3960, 'Valéria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232733.mp4', 'http://timg.bdta.pro/images/23db4522a48657e6dc1c332741ed7544.jpg'),
(58296, 3960, 'Valéria S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232734.mp4', 'http://timg.bdta.pro/images/a67ce8b91fe453716f236831cc20d8a8.jpg'),
(58297, 3960, 'Valéria S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232735.mp4', 'http://timg.bdta.pro/images/8be3c1354bf8171b44f7bafa2b98b582.jpg'),
(58298, 3960, 'Valéria S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232736.mp4', 'http://timg.bdta.pro/images/2046b05c5bd3e8bf8b2342d6684c8e75.jpg'),
(58299, 3960, 'Valéria S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232737.mp4', 'http://timg.bdta.pro/images/abf8679548b3abda5a9b5473e3839740.jpg'),
(58300, 3961, 'Valéria S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232738.mp4', 'http://timg.bdta.pro/images/7bcdccc5fd549e46254e985308367674.jpg'),
(58301, 3961, 'Valéria S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232739.mp4', 'http://timg.bdta.pro/images/ac57a94d4edb3d59078e68e72c4658d5.jpg'),
(58302, 3961, 'Valéria S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232740.mp4', 'http://timg.bdta.pro/images/25e9b6c9c6d6c7a1bb29860ed83a0402.jpg'),
(58303, 3961, 'Valéria S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232741.mp4', 'http://timg.bdta.pro/images/d5e2d84bdbc40c2daadbcfeafde34340.jpg'),
(58304, 3961, 'Valéria S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232742.mp4', 'http://timg.bdta.pro/images/3c5bd344e2389eb9a08ef8606cb33be4.jpg'),
(58305, 3961, 'Valéria S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232743.mp4', 'http://timg.bdta.pro/images/49c460b3d99ba75611c77e0c42c3eca4.jpg'),
(58306, 3961, 'Valéria S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232744.mp4', 'http://timg.bdta.pro/images/67cacb657c2ffcb52f5a4eae13a8931f.jpg'),
(58307, 3961, 'Valéria S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232745.mp4', 'http://timg.bdta.pro/images/563fc2059056163d1d3b344ddbb82f52.jpg'),
(58308, 3962, 'Valéria S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nwjepGKcvuMzc931wKxCY3mBXe3.jpg'),
(58309, 3962, 'Valéria S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vCQ7f18aNuXqVzSvMAgMOLdYvNH.jpg'),
(58310, 3962, 'Valéria S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jW3yb9vVarhVavIYEzqtFSpihJw.jpg'),
(58311, 3962, 'Valéria S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tRPC3a2OFOvQIPkcdKksJTGQ0tg.jpg'),
(58312, 3962, 'Valéria S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vdBbpEYK9zXKFv0tWWfSWTuEhRy.jpg'),
(58313, 3962, 'Valéria S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5kABHVkY2IOQgxKEWgLFyWj0f32.jpg'),
(58314, 3962, 'Valéria S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iqvyvO2DuuOWSKIoHs6VjwDlgbe.jpg'),
(58315, 3962, 'Valéria S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5DcxA5Q1FtOqYX7YITBCCmJm0CI.jpg'),
(58316, 3963, 'Valéria S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/697138.mp4', 'http://gstaticontent.com/images/3f42023fd7e89de9f2e22ad31e2c5ffc.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(58317, 3963, 'Valéria S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/697139.mp4', 'http://gstaticontent.com/images/3f42023fd7e89de9f2e22ad31e2c5ffc.jpg'),
(58318, 3963, 'Valéria S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/697140.mp4', 'http://gstaticontent.com/images/3f42023fd7e89de9f2e22ad31e2c5ffc.jpg'),
(58319, 3963, 'Valéria S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/697141.mp4', 'http://gstaticontent.com/images/3f42023fd7e89de9f2e22ad31e2c5ffc.jpg'),
(58320, 3963, 'Valéria S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/697142.mp4', 'http://gstaticontent.com/images/3f42023fd7e89de9f2e22ad31e2c5ffc.jpg'),
(58321, 3963, 'Valéria S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/697143.mp4', 'http://gstaticontent.com/images/3f42023fd7e89de9f2e22ad31e2c5ffc.jpg'),
(58322, 3964, 'Vincenzo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145939.mp4', 'http://timg.bdta.pro/images/aa3f9dbd5c81a461db4e6f3f7a30543e.jpg'),
(58323, 3964, 'Vincenzo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145940.mp4', 'http://timg.bdta.pro/images/8a4d176f5565fcccbd6b517aee56af0e.jpg'),
(58324, 3964, 'Vincenzo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145941.mp4', 'http://timg.bdta.pro/images/32aa1eb021475259dfb475364accf724.jpg'),
(58325, 3964, 'Vincenzo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145942.mp4', 'http://timg.bdta.pro/images/ee2c6e8f3b749af0571f490db03c8326.jpg'),
(58326, 3964, 'Vincenzo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145943.mp4', 'http://timg.bdta.pro/images/eae5df4370b810c12c00046550ed1939.jpg'),
(58327, 3964, 'Vincenzo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145944.mp4', 'http://timg.bdta.pro/images/d484df1cd60a3178abefd046761c9453.jpg'),
(58328, 3964, 'Vincenzo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145945.mp4', 'http://timg.bdta.pro/images/3c471081790323b15581f69cb1d3ffd2.jpg'),
(58329, 3964, 'Vincenzo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145946.mp4', 'http://timg.bdta.pro/images/120ae1aa741d58c713d78c3349914501.jpg'),
(58330, 3964, 'Vincenzo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145947.mp4', 'http://timg.bdta.pro/images/a01497d8cca8615f5afbcf3784b864c1.jpg'),
(58331, 3964, 'Vincenzo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145948.mp4', 'http://timg.bdta.pro/images/fba73c5907319dea22005ca20dd4d805.jpg'),
(58332, 3964, 'Vincenzo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145949.mp4', 'http://timg.bdta.pro/images/31c152e3b5253d1116fee3c34a2bd1e9.jpg'),
(58333, 3964, 'Vincenzo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145950.mp4', 'http://timg.bdta.pro/images/2bb039c650dc6b14338fdf00a5a3c4f2.jpg'),
(58334, 3964, 'Vincenzo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145951.mp4', 'http://timg.bdta.pro/images/a1e7d385dd3a44503cd1233717112440.jpg'),
(58335, 3964, 'Vincenzo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145952.mp4', 'http://timg.bdta.pro/images/1380380afe3ded49d3fd0f904d897656.jpg'),
(58336, 3964, 'Vincenzo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145953.mp4', 'http://timg.bdta.pro/images/a37d5e675d18b7bf218fb79ba95b3dbf.jpg'),
(58337, 3964, 'Vincenzo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145954.mp4', 'http://timg.bdta.pro/images/28de98991a14bbc4a92d2a10f279def7.jpg'),
(58338, 3964, 'Vincenzo S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145955.mp4', 'http://timg.bdta.pro/images/6315e578297d030aa2ff0a4fee508c9d.jpg'),
(58339, 3964, 'Vincenzo S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/145956.mp4', 'http://timg.bdta.pro/images/def35474de0c824ec3039652004997f5.jpg'),
(58340, 3964, 'Vincenzo S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/145957.mp4', 'http://timg.bdta.pro/images/0bb85cff30f900e3aaa216af1ea371d8.jpg'),
(58341, 3964, 'Vincenzo S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/145958.mp4', 'http://timg.bdta.pro/images/1709f8306c695032475be47790e1d0ab.jpg'),
(58342, 3965, 'El Cid S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145846.mp4', 'http://timg.bdta.pro/images/8257d4672b261ca4502fb6bbaecd2e6b.jpg'),
(58343, 3965, 'El Cid S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145847.mp4', 'http://timg.bdta.pro/images/6ab71f42a719b0ed30fc12d2d230d4a3.jpg'),
(58344, 3965, 'El Cid S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145848.mp4', 'http://timg.bdta.pro/images/9e80f64bc29d235794c912f06a687ea7.jpg'),
(58345, 3965, 'El Cid S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145849.mp4', 'http://timg.bdta.pro/images/f821823080c994b1aa2fbfcf51794f21.jpg'),
(58346, 3965, 'El Cid S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145850.mp4', 'http://timg.bdta.pro/images/54087278065d4b53ce7115fa68788096.jpg'),
(58347, 3966, 'El Cid S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145851.mp4', 'http://timg.bdta.pro/images/71dd36ab0bcf3ef8f10013016227c284.jpg'),
(58348, 3966, 'El Cid S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145852.mp4', 'http://timg.bdta.pro/images/1fd9641ebf76194715d61cd6e99b9860.jpg'),
(58349, 3966, 'El Cid S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145853.mp4', 'http://timg.bdta.pro/images/c950c934c6d60b6a747b0b8afce55fdc.jpg'),
(58350, 3966, 'El Cid S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145854.mp4', 'http://timg.bdta.pro/images/9e2994f99c2a3fcc4f702b71fc1e0a52.jpg'),
(58351, 3966, 'El Cid S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145855.mp4', 'http://timg.bdta.pro/images/b3aaf9add5abe1becfee8ad1fa603db5.jpg'),
(58352, 3967, 'Inferno Sobre Rodas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145789.mp4', 'http://timg.bdta.pro/images/3c3701454129fcc2f839460c8e5300be.jpg'),
(58353, 3967, 'Inferno Sobre Rodas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145790.mp4', 'http://timg.bdta.pro/images/52899d1287daf3aef5544f9c7fa92260.jpg'),
(58354, 3967, 'Inferno Sobre Rodas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145791.mp4', 'http://timg.bdta.pro/images/d303d8dd6b9c3932c6ef002c147f35e9.jpg'),
(58355, 3967, 'Inferno Sobre Rodas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145792.mp4', 'http://timg.bdta.pro/images/0708c4648fa6733f7d8dd30282ca74df.jpg'),
(58356, 3967, 'Inferno Sobre Rodas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145793.mp4', 'http://timg.bdta.pro/images/36189171934dbcf96bc5988f0dff4c84.jpg'),
(58357, 3967, 'Inferno Sobre Rodas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145794.mp4', 'http://timg.bdta.pro/images/dd1644cc95f8ef7590f4c4ad70d9da8d.jpg'),
(58358, 3967, 'Inferno Sobre Rodas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145795.mp4', 'http://timg.bdta.pro/images/0d28579b27c8c4a5866c4695490cc2cf.jpg'),
(58359, 3967, 'Inferno Sobre Rodas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145796.mp4', 'http://timg.bdta.pro/images/101eda721e2761058034965aa3b74fad.jpg'),
(58360, 3967, 'Inferno Sobre Rodas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145797.mp4', 'http://timg.bdta.pro/images/92d296f3ada6ccd5c3078ae45b457df2.jpg'),
(58361, 3967, 'Inferno Sobre Rodas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145798.mp4', 'http://timg.bdta.pro/images/294ccf1056ea6253030f294fe0c58505.jpg'),
(58362, 3968, 'Inferno Sobre Rodas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145799.mp4', 'http://timg.bdta.pro/images/2eba5dd3d2526b7ddec6ad8927ffc20b.jpg'),
(58363, 3968, 'Inferno Sobre Rodas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145800.mp4', 'http://timg.bdta.pro/images/2d965b7dfabbe5a46f0ed7166d5f15f1.jpg'),
(58364, 3968, 'Inferno Sobre Rodas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145801.mp4', 'http://timg.bdta.pro/images/68238f38a26279f2982b0c701773dc54.jpg'),
(58365, 3968, 'Inferno Sobre Rodas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145802.mp4', 'http://timg.bdta.pro/images/114c51dde5a782f55885d28697b20172.jpg'),
(58366, 3968, 'Inferno Sobre Rodas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145803.mp4', 'http://timg.bdta.pro/images/7576ce46e9035541b6ecd2d11b3cee9e.jpg'),
(58367, 3968, 'Inferno Sobre Rodas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145804.mp4', 'http://timg.bdta.pro/images/6f6655c37de93e2d8dfcebd0be7199d0.jpg'),
(58368, 3968, 'Inferno Sobre Rodas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145805.mp4', 'http://timg.bdta.pro/images/eac0cb813bad7cec3b000bbe79dbf395.jpg'),
(58369, 3968, 'Inferno Sobre Rodas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145806.mp4', 'http://timg.bdta.pro/images/19eb9314b90db8975713675125f4d12b.jpg'),
(58370, 3968, 'Inferno Sobre Rodas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145807.mp4', 'http://timg.bdta.pro/images/a28cf0a71bad624e581d6261bb71130d.jpg'),
(58371, 3968, 'Inferno Sobre Rodas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145808.mp4', 'http://timg.bdta.pro/images/f2ac5a803b8db80ff6ee9e5d764c84a2.jpg'),
(58372, 3969, 'Inferno Sobre Rodas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145809.mp4', 'http://timg.bdta.pro/images/7ad51bd8c05bdbb9f399ca7450eae755.jpg'),
(58373, 3969, 'Inferno Sobre Rodas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145810.mp4', 'http://timg.bdta.pro/images/f61a5cd5deabac86fb067d3066702f8f.jpg'),
(58374, 3969, 'Inferno Sobre Rodas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145811.mp4', 'http://timg.bdta.pro/images/83b39d57a09fcd85bccb100b196ad97a.jpg'),
(58375, 3969, 'Inferno Sobre Rodas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145812.mp4', 'http://timg.bdta.pro/images/6fa1de42a1f2ee38e22eeb11fdfd847a.jpg'),
(58376, 3969, 'Inferno Sobre Rodas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145813.mp4', 'http://timg.bdta.pro/images/cf7b5fff07f83d3e903efe96f98fd47e.jpg'),
(58377, 3969, 'Inferno Sobre Rodas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145814.mp4', 'http://timg.bdta.pro/images/c36234c718c1f992e233a398b3f181eb.jpg'),
(58378, 3969, 'Inferno Sobre Rodas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145815.mp4', 'http://timg.bdta.pro/images/486ec61df73c3cf1d004fb3039599d73.jpg'),
(58379, 3969, 'Inferno Sobre Rodas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145816.mp4', 'http://timg.bdta.pro/images/41087410898ae1e4b015439298b81f77.jpg'),
(58380, 3969, 'Inferno Sobre Rodas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145817.mp4', 'http://timg.bdta.pro/images/8da8a3640869c79ef0bd593e07892bb5.jpg'),
(58381, 3969, 'Inferno Sobre Rodas S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145818.mp4', 'http://timg.bdta.pro/images/25ae34297ab9f2068e1118b11a041a85.jpg'),
(58382, 3970, 'Inferno Sobre Rodas S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145819.mp4', 'http://timg.bdta.pro/images/d418af50d3125e868bc279bd075e2a78.jpg'),
(58383, 3970, 'Inferno Sobre Rodas S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145820.mp4', 'http://timg.bdta.pro/images/80151003ba35d09f92b719c48dd87e51.jpg'),
(58384, 3970, 'Inferno Sobre Rodas S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145821.mp4', 'http://timg.bdta.pro/images/62500cf8bf763cb536b986891ca7b992.jpg'),
(58385, 3970, 'Inferno Sobre Rodas S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145822.mp4', 'http://timg.bdta.pro/images/ce9492713f7a946e5a8d86906dc4cf62.jpg'),
(58386, 3970, 'Inferno Sobre Rodas S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145823.mp4', 'http://timg.bdta.pro/images/8741c2a858ce4dcdfaa687104dccb4d6.jpg'),
(58387, 3970, 'Inferno Sobre Rodas S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145824.mp4', 'http://timg.bdta.pro/images/4dd2466aec0628884e53a3fe1445014f.jpg'),
(58388, 3970, 'Inferno Sobre Rodas S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145825.mp4', 'http://timg.bdta.pro/images/4392334c0e57bb28d7225aafefeeed8a.jpg'),
(58389, 3970, 'Inferno Sobre Rodas S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145826.mp4', 'http://timg.bdta.pro/images/9c113866facfa108551a41bd5d9240b9.jpg'),
(58390, 3970, 'Inferno Sobre Rodas S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145827.mp4', 'http://timg.bdta.pro/images/f8e376f8152a751589062892dda0f3a8.jpg'),
(58391, 3970, 'Inferno Sobre Rodas S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145828.mp4', 'http://timg.bdta.pro/images/ee43685fa3dde6676ae7779456945e79.jpg'),
(58392, 3970, 'Inferno Sobre Rodas S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145829.mp4', 'http://timg.bdta.pro/images/4a58262f69a534586f860270ede06af2.jpg'),
(58393, 3970, 'Inferno Sobre Rodas S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145830.mp4', 'http://timg.bdta.pro/images/17c0cda9f449e7f38ba77bb40ae03255.jpg'),
(58394, 3970, 'Inferno Sobre Rodas S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145831.mp4', 'http://timg.bdta.pro/images/aa3085b96cbd5f2b91bb0953074169a5.jpg'),
(58395, 3971, 'Inferno Sobre Rodas S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145832.mp4', 'http://timg.bdta.pro/images/8ab419e7ce70d1a90a36b4347d8ebfe7.jpg'),
(58396, 3971, 'Inferno Sobre Rodas S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145833.mp4', 'http://timg.bdta.pro/images/dfdc823ec3d2fe4b6060990467d2e858.jpg'),
(58397, 3971, 'Inferno Sobre Rodas S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145834.mp4', 'http://timg.bdta.pro/images/10c16dc221740c08d9f5c8701b7af73f.jpg'),
(58398, 3971, 'Inferno Sobre Rodas S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145835.mp4', 'http://timg.bdta.pro/images/459f051408aa483d84dd0d919280ecee.jpg'),
(58399, 3971, 'Inferno Sobre Rodas S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145836.mp4', 'http://timg.bdta.pro/images/f5696674e79934f91cf09db1bc62cdb9.jpg'),
(58400, 3971, 'Inferno Sobre Rodas S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145837.mp4', 'http://timg.bdta.pro/images/fcf76a437292d62198dd2ebeae8398e2.jpg'),
(58401, 3971, 'Inferno Sobre Rodas S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145838.mp4', 'http://timg.bdta.pro/images/224351d2f2a798c2024d899cdb728c41.jpg'),
(58402, 3971, 'Inferno Sobre Rodas S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145839.mp4', 'http://timg.bdta.pro/images/fd3e90d723cc5dbb825dcf1217900745.jpg'),
(58403, 3971, 'Inferno Sobre Rodas S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145840.mp4', 'http://timg.bdta.pro/images/c6740a1be238bcdb2f489d5599da1d47.jpg'),
(58404, 3971, 'Inferno Sobre Rodas S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145841.mp4', 'http://timg.bdta.pro/images/92ec73ef548f898e80d95409539c6cb0.jpg'),
(58405, 3971, 'Inferno Sobre Rodas S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145842.mp4', 'http://timg.bdta.pro/images/96b4b3b3d4bbf97aad31f362fbcb3ea4.jpg'),
(58406, 3971, 'Inferno Sobre Rodas S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145843.mp4', 'http://timg.bdta.pro/images/3162b58043317f7b8e2ea24c1d240ed3.jpg'),
(58407, 3971, 'Inferno Sobre Rodas S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145844.mp4', 'http://timg.bdta.pro/images/c87defa55e23b4370cd4a3a2e6aa9d96.jpg'),
(58408, 3971, 'Inferno Sobre Rodas S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145845.mp4', 'http://timg.bdta.pro/images/f35dd4d8f953eab0cf5b89c9515cabda.jpg'),
(58409, 3972, 'It\'s a Sin S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145784.mp4', 'http://timg.bdta.pro/images/5012d430318e9ef21199118603451fe2.jpg'),
(58410, 3972, 'It\'s a Sin S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145785.mp4', 'http://timg.bdta.pro/images/58e2aa5c1b2459d8218ab4a72e88a09c.jpg'),
(58411, 3972, 'It\'s a Sin S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145786.mp4', 'http://timg.bdta.pro/images/18c6ab794081473feb43e9f42f3343fb.jpg'),
(58412, 3972, 'It\'s a Sin S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145787.mp4', 'http://timg.bdta.pro/images/8092bdd39ab2a9cf1a12ecb59923d237.jpg'),
(58413, 3972, 'It\'s a Sin S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145788.mp4', 'http://timg.bdta.pro/images/e9094bc81f259f51ce2715af44c40696.jpg'),
(58414, 3973, 'Johnny Test S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145686.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58415, 3973, 'Johnny Test S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145687.mp4', 'http://timg.bdta.pro/images/a19168b43740ac139d7515aa1a665b8d.jpg'),
(58416, 3973, 'Johnny Test S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145688.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58417, 3973, 'Johnny Test S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145689.mp4', 'http://timg.bdta.pro/images/b73a8bbcc11bccdcb5182395e86a6f8c.jpg'),
(58418, 3973, 'Johnny Test S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145690.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58419, 3973, 'Johnny Test S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145691.mp4', 'http://timg.bdta.pro/images/5a417e0da68107f0e8bb2e6f75140492.jpg'),
(58420, 3973, 'Johnny Test S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145692.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58421, 3973, 'Johnny Test S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145693.mp4', 'http://timg.bdta.pro/images/1b5e1907a42096fa83e5d7f8741a3a50.jpg'),
(58422, 3973, 'Johnny Test S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145694.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58423, 3973, 'Johnny Test S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145695.mp4', 'http://timg.bdta.pro/images/eefe2ef95f672d31deb95ac8a6aeda60.jpg'),
(58424, 3973, 'Johnny Test S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145696.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58425, 3973, 'Johnny Test S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145697.mp4', 'http://timg.bdta.pro/images/6945a7f5d8bbe02746f00546951dc993.jpg'),
(58426, 3973, 'Johnny Test S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145698.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58427, 3973, 'Johnny Test S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145699.mp4', 'http://timg.bdta.pro/images/937251bef2b108f02a346c26f08a980b.jpg'),
(58428, 3973, 'Johnny Test S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145700.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58429, 3973, 'Johnny Test S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145701.mp4', 'http://timg.bdta.pro/images/acaec84f7251ee868795e2e268d38556.jpg'),
(58430, 3973, 'Johnny Test S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145702.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58431, 3973, 'Johnny Test S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/145703.mp4', 'http://timg.bdta.pro/images/f461be3bbcc3aabf8c46aa1a6252c78e.jpg'),
(58432, 3973, 'Johnny Test S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/145704.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58433, 3973, 'Johnny Test S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/145705.mp4', 'http://timg.bdta.pro/images/7c2891e2180185e80f3ad212c26bb4d0.jpg'),
(58434, 3974, 'Johnny Test S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145706.mp4', 'http://timg.bdta.pro/images/ee8c4c4534826147c7ecee745f4ae803.jpg'),
(58435, 3974, 'Johnny Test S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145707.mp4', 'http://timg.bdta.pro/images/089d11b06fcac28aa97deb2e4cf6e5c1.jpg'),
(58436, 3974, 'Johnny Test S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145708.mp4', 'http://timg.bdta.pro/images/b12fb8d5a58c957d709d8f79c496c886.jpg'),
(58437, 3974, 'Johnny Test S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145709.mp4', 'http://timg.bdta.pro/images/b8c28fb63a7fb6b7a9ec8c4f71010e4d.jpg'),
(58438, 3974, 'Johnny Test S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145710.mp4', 'http://timg.bdta.pro/images/a4f38c4b9e525304b2b899ac51af607c.jpg'),
(58439, 3974, 'Johnny Test S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145711.mp4', 'http://timg.bdta.pro/images/83176ae5d78b79d5d653f645c7a26223.jpg'),
(58440, 3974, 'Johnny Test S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145712.mp4', 'http://timg.bdta.pro/images/9c637b9fd0e08e96ffcf3088ea9cb7d4.jpg'),
(58441, 3974, 'Johnny Test S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145713.mp4', 'http://timg.bdta.pro/images/bf30c04c9fa7182f527e3e5f0cd711a2.jpg'),
(58442, 3974, 'Johnny Test S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145714.mp4', 'http://timg.bdta.pro/images/64d98cd4b22d0addca4c5b9fe340cc2a.jpg'),
(58443, 3974, 'Johnny Test S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145715.mp4', 'http://timg.bdta.pro/images/705c5fe97ca0942ac130dddfaf526137.jpg'),
(58444, 3974, 'Johnny Test S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145716.mp4', 'http://timg.bdta.pro/images/a2ac328f96e4e19f740fb68be69ddae0.jpg'),
(58445, 3974, 'Johnny Test S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145717.mp4', 'http://timg.bdta.pro/images/5c3a96981afdfbc74fd8ab9a7f1fb5ae.jpg'),
(58446, 3974, 'Johnny Test S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145718.mp4', 'http://timg.bdta.pro/images/efe68d6d4772ac04b1d8612af49917bc.jpg'),
(58447, 3975, 'Johnny Test S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145719.mp4', 'http://timg.bdta.pro/images/6ac1ef1fe912fcd684d11bc31dec96be.jpg'),
(58448, 3975, 'Johnny Test S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145720.mp4', 'http://timg.bdta.pro/images/f49f5aaa7d8d64fc8492593ec031b824.jpg'),
(58449, 3975, 'Johnny Test S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145721.mp4', 'http://timg.bdta.pro/images/887d35aea1886c4167a267598c4d900d.jpg'),
(58450, 3975, 'Johnny Test S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145722.mp4', 'http://timg.bdta.pro/images/a035e3c479ea56a8bc13312e000a15aa.jpg'),
(58451, 3975, 'Johnny Test S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145723.mp4', 'http://timg.bdta.pro/images/6d2015fbc6dd9ac4474b6104a0be5a5a.jpg'),
(58452, 3975, 'Johnny Test S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145724.mp4', 'http://timg.bdta.pro/images/6a02090e6cfef5b99e7928bc32a69897.jpg'),
(58453, 3975, 'Johnny Test S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145725.mp4', 'http://timg.bdta.pro/images/807764448c47c1c796d57ed96f913356.jpg'),
(58454, 3975, 'Johnny Test S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145726.mp4', 'http://timg.bdta.pro/images/017f7a8f88966a4520ab9bc91ed830fc.jpg'),
(58455, 3975, 'Johnny Test S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145727.mp4', 'http://timg.bdta.pro/images/c68b4d3497b72b39b293e999a8b5e40d.jpg'),
(58456, 3975, 'Johnny Test S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145728.mp4', 'http://timg.bdta.pro/images/1b83c452a891fe1a22e7cb66ea480116.jpg'),
(58457, 3975, 'Johnny Test S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145729.mp4', 'http://timg.bdta.pro/images/317f0d0131b32f67f48eaca3b1bc8628.jpg'),
(58458, 3975, 'Johnny Test S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145730.mp4', 'http://timg.bdta.pro/images/e38a2f4886c68dee5baa202a8756f3f7.jpg'),
(58459, 3975, 'Johnny Test S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145731.mp4', 'http://timg.bdta.pro/images/19dc87f6121004334630ab1c596c0776.jpg'),
(58460, 3976, 'Johnny Test S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145732.mp4', 'http://timg.bdta.pro/images/e072f880f1710616a487e1d903f20d8e.jpg'),
(58461, 3976, 'Johnny Test S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145733.mp4', 'http://timg.bdta.pro/images/bcd6476e611b4ebb9d685ee8509492c3.jpg'),
(58462, 3976, 'Johnny Test S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145734.mp4', 'http://timg.bdta.pro/images/c691d4cf476f42a442988fe80a62bf72.jpg'),
(58463, 3976, 'Johnny Test S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145735.mp4', 'http://timg.bdta.pro/images/7ff432018cd46e5b37ebdf90e81edb22.jpg'),
(58464, 3976, 'Johnny Test S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145736.mp4', 'http://timg.bdta.pro/images/e8f376aeecb9cddee515520122e40f1a.jpg'),
(58465, 3976, 'Johnny Test S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145737.mp4', 'http://timg.bdta.pro/images/4a88a1586aba1cdf5f0bacbbb165a991.jpg'),
(58466, 3976, 'Johnny Test S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145738.mp4', 'http://timg.bdta.pro/images/07db5818e8e36b24b6206e84764a1805.jpg'),
(58467, 3976, 'Johnny Test S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145739.mp4', 'http://timg.bdta.pro/images/cbfb9bbf49ba5806025368bb604a73be.jpg'),
(58468, 3976, 'Johnny Test S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145740.mp4', 'http://timg.bdta.pro/images/1c1ab3fe4a38905586aa4313b4aecd28.jpg'),
(58469, 3976, 'Johnny Test S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145741.mp4', 'http://timg.bdta.pro/images/97ac09e41d5e270667e89a1609cab208.jpg'),
(58470, 3976, 'Johnny Test S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145742.mp4', 'http://timg.bdta.pro/images/2769b5cb01da2fee4d01b64e78357b53.jpg'),
(58471, 3976, 'Johnny Test S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145743.mp4', 'http://timg.bdta.pro/images/d30e7b29bb99ced26c73b8eecde89325.jpg'),
(58472, 3976, 'Johnny Test S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145744.mp4', 'http://timg.bdta.pro/images/cc01a10c59346184f7cabeee11e3a150.jpg'),
(58473, 3976, 'Johnny Test S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145745.mp4', 'http://timg.bdta.pro/images/b434d8c44e8c4aaa6e976331949747cd.jpg'),
(58474, 3976, 'Johnny Test S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145746.mp4', 'http://timg.bdta.pro/images/77af1aa7036340f959809df85c4a92cb.jpg'),
(58475, 3976, 'Johnny Test S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145747.mp4', 'http://timg.bdta.pro/images/685fa208d55357c1d09d2bbd9b8966b6.jpg'),
(58476, 3976, 'Johnny Test S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145748.mp4', 'http://timg.bdta.pro/images/399a8039214651e8bda260dbdf82e0b6.jpg'),
(58477, 3976, 'Johnny Test S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/145749.mp4', 'http://timg.bdta.pro/images/2db1e5af85798496fe3ba019a3f639ec.jpg'),
(58478, 3976, 'Johnny Test S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/145750.mp4', 'http://timg.bdta.pro/images/b1831fda135686c27e3a98f263249f1c.jpg'),
(58479, 3976, 'Johnny Test S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/145751.mp4', 'http://timg.bdta.pro/images/c758b120a0f69bf7d921599e9bdf302b.jpg'),
(58480, 3976, 'Johnny Test S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/145752.mp4', 'http://timg.bdta.pro/images/8ced6932aa58b0d3fa42344aa2f316b5.jpg'),
(58481, 3976, 'Johnny Test S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/145753.mp4', 'http://timg.bdta.pro/images/340684f62f22ef78446e8d5988d84790.jpg'),
(58482, 3976, 'Johnny Test S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/145754.mp4', 'http://timg.bdta.pro/images/955a8c7af3318a53cee4b7f183446621.jpg'),
(58483, 3976, 'Johnny Test S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/145755.mp4', 'http://timg.bdta.pro/images/2020d3b63225b2151dfb2341a01e42d7.jpg'),
(58484, 3976, 'Johnny Test S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/145756.mp4', 'http://timg.bdta.pro/images/e67612010532ac059e41a4913e41fc56.jpg'),
(58485, 3976, 'Johnny Test S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/145757.mp4', 'http://timg.bdta.pro/images/d63c7bc3a38e755e3c7a8f30b685c21f.jpg'),
(58486, 3977, 'Johnny Test S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145758.mp4', 'http://timg.bdta.pro/images/f8d9955fc5b4de874e66a537f6cf546b.jpg'),
(58487, 3977, 'Johnny Test S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145759.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58488, 3977, 'Johnny Test S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145760.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58489, 3977, 'Johnny Test S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145761.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58490, 3977, 'Johnny Test S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145762.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58491, 3977, 'Johnny Test S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145763.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58492, 3977, 'Johnny Test S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145764.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58493, 3977, 'Johnny Test S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145765.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58494, 3977, 'Johnny Test S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145766.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58495, 3977, 'Johnny Test S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145767.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58496, 3977, 'Johnny Test S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145768.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58497, 3977, 'Johnny Test S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145769.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58498, 3977, 'Johnny Test S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145770.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58499, 3977, 'Johnny Test S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145771.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58500, 3977, 'Johnny Test S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145772.mp4', 'http://timg.bdta.pro/images/86c0b31119448187d2ada3bbf91a709d.jpg'),
(58501, 3977, 'Johnny Test S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145773.mp4', 'http://timg.bdta.pro/images/ae9b44b2d9aef2c746493870ab8a51ac.jpg'),
(58502, 3977, 'Johnny Test S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145774.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58503, 3977, 'Johnny Test S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/145775.mp4', 'http://timg.bdta.pro/images/f2a9d1f22c1166fa39d0613942adf9a5.jpg'),
(58504, 3977, 'Johnny Test S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/145776.mp4', 'http://timg.bdta.pro/images/3c845a1b61448db808504845caca6a22.jpg'),
(58505, 3977, 'Johnny Test S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/145777.mp4', 'http://timg.bdta.pro/images/11bd2cfb707464c49c4beb97d3365d1d.jpg'),
(58506, 3977, 'Johnny Test S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/145778.mp4', 'http://timg.bdta.pro/images/7b15416b630f033acb466a88452741cc.jpg'),
(58507, 3977, 'Johnny Test S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/145779.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58508, 3977, 'Johnny Test S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/145780.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58509, 3977, 'Johnny Test S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/145781.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58510, 3977, 'Johnny Test S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/145782.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58511, 3977, 'Johnny Test S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/145783.mp4', 'http://gstaticontent.com/images/28ecc5700c675ff185caeaeebeafeabf.jpg'),
(58512, 3978, 'Mestres do Universo: Salvando Eternia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164306.mp4', 'http://timg.bdta.pro/images/a0f19c62e549243c06f5db2804aade03.jpg'),
(58513, 3978, 'Mestres do Universo: Salvando Eternia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164307.mp4', 'http://timg.bdta.pro/images/b15b7d43f7980aa1c0cef9f3afe13d70.jpg'),
(58514, 3978, 'Mestres do Universo: Salvando Eternia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164308.mp4', 'http://timg.bdta.pro/images/86e170930e7170ee775627780411eb1d.jpg'),
(58515, 3978, 'Mestres do Universo: Salvando Eternia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164309.mp4', 'http://timg.bdta.pro/images/de0398a89dc22c9045342b84bb37904c.jpg'),
(58516, 3978, 'Mestres do Universo: Salvando Eternia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164310.mp4', 'http://timg.bdta.pro/images/b0724cb8246bbc60da6a0b00b46b7f0b.jpg'),
(58517, 3979, 'Mestres do Universo: Salvando Eternia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164311.mp4', 'http://gstaticontent.com/images/c2f11408649ed8946b3145baf4e335e0.jpg'),
(58518, 3979, 'Mestres do Universo: Salvando Eternia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164312.mp4', 'http://gstaticontent.com/images/c2f11408649ed8946b3145baf4e335e0.jpg'),
(58519, 3979, 'Mestres do Universo: Salvando Eternia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164313.mp4', 'http://gstaticontent.com/images/c2f11408649ed8946b3145baf4e335e0.jpg'),
(58520, 3979, 'Mestres do Universo: Salvando Eternia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164314.mp4', 'http://gstaticontent.com/images/c2f11408649ed8946b3145baf4e335e0.jpg'),
(58521, 3979, 'Mestres do Universo: Salvando Eternia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164315.mp4', 'http://gstaticontent.com/images/c2f11408649ed8946b3145baf4e335e0.jpg'),
(58522, 3980, 'Os Ausentes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145676.mp4', 'http://timg.bdta.pro/images/a8501f60c111466c8ddaad626ce994fd.jpg'),
(58523, 3980, 'Os Ausentes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145677.mp4', 'http://timg.bdta.pro/images/5300b090e6b2928b8122c55bd1a1db2e.jpg'),
(58524, 3980, 'Os Ausentes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145678.mp4', 'http://timg.bdta.pro/images/3f0f95ea9a245a00e9db8735c670b80c.jpg'),
(58525, 3980, 'Os Ausentes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145679.mp4', 'http://timg.bdta.pro/images/661e2282dd8cd2a000334dba0aaa362f.jpg'),
(58526, 3980, 'Os Ausentes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145680.mp4', 'http://timg.bdta.pro/images/4e72c480decffa5b7ffd1e47eca84143.jpg'),
(58527, 3980, 'Os Ausentes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145681.mp4', 'http://timg.bdta.pro/images/1fb968c10a7759fa0e290880f3ab7c8e.jpg'),
(58528, 3980, 'Os Ausentes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145682.mp4', 'http://timg.bdta.pro/images/c61b39075cb520cea4a1700463bdb40a.jpg'),
(58529, 3980, 'Os Ausentes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145683.mp4', 'http://timg.bdta.pro/images/d2d3b27f2983aacace96e33aa24ce175.jpg'),
(58530, 3980, 'Os Ausentes S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145684.mp4', 'http://timg.bdta.pro/images/885f1c752d42ef79806e3fd269101dc9.jpg'),
(58531, 3980, 'Os Ausentes S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145685.mp4', 'http://timg.bdta.pro/images/113af965d9f6cab0a112fe0537e9d43b.jpg'),
(58532, 3981, 'Physical S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234805.mp4', 'http://timg.bdta.pro/images/62131f11391a18dd96514f9360540696.jpg'),
(58533, 3981, 'Physical S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234806.mp4', 'http://timg.bdta.pro/images/1e270c2fac8a7c89c3b51e752a1f4c0d.jpg'),
(58534, 3981, 'Physical S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234807.mp4', 'http://timg.bdta.pro/images/10be94dd01cffe8ca107d16ac901800c.jpg'),
(58535, 3981, 'Physical S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234808.mp4', 'http://timg.bdta.pro/images/11d4bc3483d75ec759f8865770f789f0.jpg'),
(58536, 3981, 'Physical S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234809.mp4', 'http://timg.bdta.pro/images/7fa03e32860ac9f62db5b077101c5e4e.jpg'),
(58537, 3981, 'Physical S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234810.mp4', 'http://timg.bdta.pro/images/f6a04721e65bd405db0b047713cd033d.jpg'),
(58538, 3981, 'Physical S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234811.mp4', 'http://timg.bdta.pro/images/fe0282b41b55694ac60ed510469ac945.jpg'),
(58539, 3981, 'Physical S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234812.mp4', 'http://timg.bdta.pro/images/6147b25503a55fbb0e9754da53c44e48.jpg'),
(58540, 3981, 'Physical S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234813.mp4', 'http://timg.bdta.pro/images/c4767b12afff648081113208d86e484a.jpg'),
(58541, 3981, 'Physical S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234814.mp4', 'http://timg.bdta.pro/images/27e925977d08b1612866a4a1cd6f38b2.jpg'),
(58542, 3982, 'Physical S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234815.mp4', 'http://timg.bdta.pro/images/f38a7accce4d11394f14ea0b5d574f18.jpg'),
(58543, 3982, 'Physical S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234816.mp4', 'http://timg.bdta.pro/images/bd8dee7e0712b6610951b1665a1abc69.jpg'),
(58544, 3982, 'Physical S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234817.mp4', 'http://timg.bdta.pro/images/309a47811ca20d99e23f281917d16387.jpg'),
(58545, 3982, 'Physical S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234818.mp4', 'http://timg.bdta.pro/images/9d15241ba18b0698a2544371d2f09c03.jpg'),
(58546, 3982, 'Physical S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234819.mp4', 'http://timg.bdta.pro/images/472fcef31dab1f89cd03636e287a132c.jpg'),
(58547, 3982, 'Physical S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234820.mp4', 'http://timg.bdta.pro/images/67fc07421db0356750c8c0555588c884.jpg'),
(58548, 3982, 'Physical S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234821.mp4', 'http://timg.bdta.pro/images/35cb89d8b51bd304dc22250b60c93dca.jpg'),
(58549, 3982, 'Physical S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234822.mp4', 'http://timg.bdta.pro/images/df67a6e15b2e62412fb63ce03a7a4d43.jpg'),
(58550, 3982, 'Physical S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234823.mp4', 'http://timg.bdta.pro/images/03f175103ae274a0b0211f67caab04ec.jpg'),
(58551, 3982, 'Physical S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234824.mp4', 'http://timg.bdta.pro/images/b0d9b21a54a9176e5f8b0b9ca1131f88.jpg'),
(58552, 3983, 'Physical S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1iUc7LtJfVqqNK6sq7Bkbz0Nbkd.jpg'),
(58553, 3983, 'Physical S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sUHiyYYqWgTq0v8KsJ1Vokh9urW.jpg'),
(58554, 3983, 'Physical S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234827.mp4', 'http://image.tmdb.org/t/p/w1280/6QJWB5HnbaA6QvzJuVEP0KfoCRX.jpg'),
(58555, 3983, 'Physical S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234828.mp4', 'http://image.tmdb.org/t/p/w1280/n8YAMOu3aUUJYTJzn9g2ivitJti.jpg'),
(58556, 3983, 'Physical S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234829.mp4', 'http://image.tmdb.org/t/p/w1280/cMPYXWC2KmWeQ7svpGIMfM1qzwy.jpg'),
(58557, 3983, 'Physical S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234830.mp4', 'http://image.tmdb.org/t/p/w1280/dHjTbQOjNNmViyhiQPhsJKLAIGP.jpg'),
(58558, 3983, 'Physical S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234831.mp4', 'http://image.tmdb.org/t/p/w1280/tC5lKpcc3vqCEFYsBFC5QyxAIXm.jpg'),
(58559, 3983, 'Physical S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234832.mp4', 'http://gstaticontent.com/images/db688b07a466bf4e9c4809b31f17615d.jpg'),
(58560, 3983, 'Physical S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234833.mp4', 'http://gstaticontent.com/images/db688b07a466bf4e9c4809b31f17615d.jpg'),
(58561, 3983, 'Physical S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234834.mp4', 'http://gstaticontent.com/images/db688b07a466bf4e9c4809b31f17615d.jpg'),
(58562, 3984, 'Power Book III Raising Kanan S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199623.mp4', 'http://timg.bdta.pro/images/9148f03ab4c01df07c878428342a23cd.jpg'),
(58563, 3984, 'Power Book III Raising Kanan S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199624.mp4', 'http://timg.bdta.pro/images/dd162a9aecc9cf3fb196d64d731c3ca2.jpg'),
(58564, 3984, 'Power Book III Raising Kanan S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199625.mp4', 'http://timg.bdta.pro/images/a993fb7f3557acc6b35172639903dc7d.jpg'),
(58565, 3984, 'Power Book III Raising Kanan S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199626.mp4', 'http://timg.bdta.pro/images/4f2f1a397869d16fc797b2289ae2094e.jpg'),
(58566, 3984, 'Power Book III Raising Kanan S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199627.mp4', 'http://timg.bdta.pro/images/7829c074c1266803eb74fe475f20f3c5.jpg'),
(58567, 3984, 'Power Book III Raising Kanan S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199628.mp4', 'http://timg.bdta.pro/images/085e90428248cf362f238ae83aceffe3.jpg'),
(58568, 3984, 'Power Book III Raising Kanan S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199629.mp4', 'http://timg.bdta.pro/images/1a60b1957f7566a9c57cabc7fcc2ac0d.jpg'),
(58569, 3984, 'Power Book III Raising Kanan S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199630.mp4', 'http://timg.bdta.pro/images/3a6a179bc42def564f47ccff0a12b3e1.jpg'),
(58570, 3984, 'Power Book III Raising Kanan S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199631.mp4', 'http://image.tmdb.org/t/p/w1280/m7VGj7betVGAUW4Q7wEyxhkQWhZ.jpg'),
(58571, 3984, 'Power Book III Raising Kanan S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199632.mp4', 'http://image.tmdb.org/t/p/w1280/qK7cpBuAuFHpmws1d8JHl6iV6Uf.jpg'),
(58572, 3985, 'Power Book III Raising Kanan S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199633.mp4', 'http://timg.bdta.pro/images/b9cf3c5f7ba7aea03a872edf8070431f.jpg'),
(58573, 3985, 'Power Book III Raising Kanan S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199634.mp4', 'http://timg.bdta.pro/images/fd07f7c56c7799f952894609b9c37d52.jpg'),
(58574, 3985, 'Power Book III Raising Kanan S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199635.mp4', 'http://timg.bdta.pro/images/5893c015401b65f9e24b06ba63e91436.jpg'),
(58575, 3985, 'Power Book III Raising Kanan S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199636.mp4', 'http://timg.bdta.pro/images/b30bf10da7b5fa988f1bffeaba0240cd.jpg'),
(58576, 3985, 'Power Book III Raising Kanan S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199637.mp4', 'http://timg.bdta.pro/images/66d5ec864b2b241246791b18cfae5345.jpg'),
(58577, 3985, 'Power Book III Raising Kanan S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199638.mp4', 'http://timg.bdta.pro/images/bfaaf4c3d02949258fb6dfb14910ce99.jpg'),
(58578, 3985, 'Power Book III Raising Kanan S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199639.mp4', 'http://gstaticontent.com/images/0e5903618dd4b2dfdb382bd7576bb34c.jpg'),
(58579, 3985, 'Power Book III Raising Kanan S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199640.mp4', 'http://timg.bdta.pro/images/de716f841394cd850eddd4709e12925a.jpg'),
(58580, 3985, 'Power Book III Raising Kanan S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199641.mp4', 'http://timg.bdta.pro/images/d8b935f5599c7ceefe7af4991c90fc70.jpg'),
(58581, 3985, 'Power Book III Raising Kanan S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199642.mp4', 'http://timg.bdta.pro/images/a30fff1a50d9d0ac975105f6d8ea7aa9.jpg'),
(58582, 3986, 'Power Book III Raising Kanan S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/297469.mp4', 'http://gstaticontent.com/images/0e5903618dd4b2dfdb382bd7576bb34c.jpg'),
(58583, 3986, 'Power Book III Raising Kanan S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/297470.mp4', 'http://gstaticontent.com/images/0e5903618dd4b2dfdb382bd7576bb34c.jpg'),
(58584, 3986, 'Power Book III Raising Kanan S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/297471.mp4', 'http://gstaticontent.com/images/0e5903618dd4b2dfdb382bd7576bb34c.jpg'),
(58585, 3986, 'Power Book III Raising Kanan S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/297472.mp4', 'http://gstaticontent.com/images/0e5903618dd4b2dfdb382bd7576bb34c.jpg'),
(58586, 3986, 'Power Book III Raising Kanan S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/297473.mp4', 'http://gstaticontent.com/images/0e5903618dd4b2dfdb382bd7576bb34c.jpg'),
(58587, 3986, 'Power Book III Raising Kanan S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/297474.mp4', 'http://gstaticontent.com/images/0e5903618dd4b2dfdb382bd7576bb34c.jpg'),
(58588, 3986, 'Power Book III Raising Kanan S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/297475.mp4', 'http://gstaticontent.com/images/0e5903618dd4b2dfdb382bd7576bb34c.jpg'),
(58589, 3986, 'Power Book III Raising Kanan S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/297476.mp4', 'http://gstaticontent.com/images/0e5903618dd4b2dfdb382bd7576bb34c.jpg'),
(58590, 3986, 'Power Book III Raising Kanan S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/297477.mp4', 'http://gstaticontent.com/images/0e5903618dd4b2dfdb382bd7576bb34c.jpg'),
(58591, 3986, 'Power Book III Raising Kanan S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/297478.mp4', 'http://gstaticontent.com/images/0e5903618dd4b2dfdb382bd7576bb34c.jpg'),
(58592, 3987, 'Power Book III Raising Kanan S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/720980.mp4', 'http://gstaticontent.com/images/0e5903618dd4b2dfdb382bd7576bb34c.jpg'),
(58593, 3987, 'Power Book III Raising Kanan S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/728549.mp4', 'http://gstaticontent.com/images/0e5903618dd4b2dfdb382bd7576bb34c.jpg'),
(58594, 3987, 'Power Book III Raising Kanan S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/737993.mp4', 'http://gstaticontent.com/images/0e5903618dd4b2dfdb382bd7576bb34c.jpg'),
(58595, 3987, 'Power Book III Raising Kanan S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/750997.mp4', 'http://gstaticontent.com/images/0e5903618dd4b2dfdb382bd7576bb34c.jpg'),
(58596, 3987, 'Power Book III Raising Kanan S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/758678.mp4', 'http://gstaticontent.com/images/0e5903618dd4b2dfdb382bd7576bb34c.jpg'),
(58597, 3987, 'Power Book III Raising Kanan S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/764369.mp4', 'http://gstaticontent.com/images/0e5903618dd4b2dfdb382bd7576bb34c.jpg'),
(58598, 3987, 'Power Book III Raising Kanan S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/772698.mp4', 'http://gstaticontent.com/images/0e5903618dd4b2dfdb382bd7576bb34c.jpg'),
(58599, 3987, 'Power Book III Raising Kanan S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/793865.mp4', 'http://gstaticontent.com/images/0e5903618dd4b2dfdb382bd7576bb34c.jpg'),
(58600, 3987, 'Power Book III Raising Kanan S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/798356.mp4', 'http://gstaticontent.com/images/0e5903618dd4b2dfdb382bd7576bb34c.jpg'),
(58601, 3987, 'Power Book III Raising Kanan S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/805782.mp4', 'http://gstaticontent.com/images/0e5903618dd4b2dfdb382bd7576bb34c.jpg'),
(58602, 3988, 'RUN S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154206.mp4', 'http://timg.bdta.pro/images/e4b01f88696d38b32d498aa1d794bbd0.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(58603, 3988, 'RUN S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154207.mp4', 'http://timg.bdta.pro/images/94677e94598f24e1b177d86620b37c4f.jpg'),
(58604, 3988, 'RUN S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154208.mp4', 'http://timg.bdta.pro/images/28acea60fb466a2d05ab725c191fd30f.jpg'),
(58605, 3988, 'RUN S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154209.mp4', 'http://timg.bdta.pro/images/ac2f70018f026903dc4b577607cec024.jpg'),
(58606, 3988, 'RUN S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154210.mp4', 'http://timg.bdta.pro/images/387de5ec102c20823fb7af375b55dd8d.jpg'),
(58607, 3988, 'RUN S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154211.mp4', 'http://timg.bdta.pro/images/2c9471e8e1ad516d332d4cabedd5c5da.jpg'),
(58608, 3988, 'RUN S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154212.mp4', 'http://timg.bdta.pro/images/7dcffb04303baf0713886f3ef86520ec.jpg'),
(58609, 3989, 'Superman: A Série Animada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154152.mp4', 'http://timg.bdta.pro/images/fe36f6119a1e517bdc971b004ed9680f.jpg'),
(58610, 3989, 'Superman: A Série Animada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154153.mp4', 'http://timg.bdta.pro/images/d65a89e5e531da2445caa94ffc68d188.jpg'),
(58611, 3989, 'Superman: A Série Animada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154154.mp4', 'http://timg.bdta.pro/images/ce38735c748c3e715f93dd7a8bd57518.jpg'),
(58612, 3989, 'Superman: A Série Animada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154155.mp4', 'http://timg.bdta.pro/images/20858a1a3b723530d4a9d8d3cd749024.jpg'),
(58613, 3989, 'Superman: A Série Animada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154156.mp4', 'http://timg.bdta.pro/images/a0b9effbd2e66b550afbb18e292cf959.jpg'),
(58614, 3989, 'Superman: A Série Animada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154157.mp4', 'http://timg.bdta.pro/images/60a34aa063206f7a8898e96a583951d3.jpg'),
(58615, 3989, 'Superman: A Série Animada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154158.mp4', 'http://timg.bdta.pro/images/0f80fc813bad772985bd5c3b8edbb395.jpg'),
(58616, 3989, 'Superman: A Série Animada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154159.mp4', 'http://timg.bdta.pro/images/c3266b73ef54f79c8198f15065c7b42b.jpg'),
(58617, 3989, 'Superman: A Série Animada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154160.mp4', 'http://timg.bdta.pro/images/fb297587efabaf9ddecb6406ef757383.jpg'),
(58618, 3989, 'Superman: A Série Animada S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154161.mp4', 'http://timg.bdta.pro/images/21d6721fbab2ba4d236cfa9ac297279c.jpg'),
(58619, 3989, 'Superman: A Série Animada S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/154162.mp4', 'http://timg.bdta.pro/images/aee01c7df9f6234b8314b2c6d3f4ee03.jpg'),
(58620, 3989, 'Superman: A Série Animada S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/154163.mp4', 'http://timg.bdta.pro/images/dbbeb0c97d742748e7872fecae282ae1.jpg'),
(58621, 3989, 'Superman: A Série Animada S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/154164.mp4', 'http://timg.bdta.pro/images/6a0511308b4a43113bddb808e9629c9c.jpg'),
(58622, 3990, 'Superman: A Série Animada S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154165.mp4', 'http://timg.bdta.pro/images/42b7952d03130ce19768f20ae95e6d5d.jpg'),
(58623, 3990, 'Superman: A Série Animada S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154166.mp4', 'http://timg.bdta.pro/images/4057773958d9567ad0a15f196053fce8.jpg'),
(58624, 3990, 'Superman: A Série Animada S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154167.mp4', 'http://timg.bdta.pro/images/50fb40bc5c1185d39430edba122404a7.jpg'),
(58625, 3990, 'Superman: A Série Animada S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154168.mp4', 'http://timg.bdta.pro/images/deb25fc5f29e91223a35312cf95c4d0d.jpg'),
(58626, 3990, 'Superman: A Série Animada S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154169.mp4', 'http://timg.bdta.pro/images/0cacc267dd87463d7cf37f120f2773a6.jpg'),
(58627, 3990, 'Superman: A Série Animada S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154170.mp4', 'http://timg.bdta.pro/images/1de8f4560de6a776a89be93513f90927.jpg'),
(58628, 3990, 'Superman: A Série Animada S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154171.mp4', 'http://timg.bdta.pro/images/899d41edf5d1a799b13d8acacb0c70e8.jpg'),
(58629, 3990, 'Superman: A Série Animada S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154172.mp4', 'http://timg.bdta.pro/images/1e907c644b1a612e4e6cf78fcb0a30b8.jpg'),
(58630, 3990, 'Superman: A Série Animada S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154173.mp4', 'http://timg.bdta.pro/images/5faf1ec8992478b8be3bd384abd8b664.jpg'),
(58631, 3990, 'Superman: A Série Animada S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154174.mp4', 'http://timg.bdta.pro/images/c9eb763c898a57edfab9ca58539ac17a.jpg'),
(58632, 3990, 'Superman: A Série Animada S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/154175.mp4', 'http://timg.bdta.pro/images/5162756c0d4a30830be19f76d080896a.jpg'),
(58633, 3990, 'Superman: A Série Animada S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/154176.mp4', 'http://timg.bdta.pro/images/579702e57e1b01cd8ac4ba5dd92acd09.jpg'),
(58634, 3990, 'Superman: A Série Animada S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/154177.mp4', 'http://timg.bdta.pro/images/ace591f920a265a42fde41f70c3d2464.jpg'),
(58635, 3990, 'Superman: A Série Animada S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/154178.mp4', 'http://timg.bdta.pro/images/d430205112a63f04f7f24b7ce34d70dd.jpg'),
(58636, 3990, 'Superman: A Série Animada S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/154179.mp4', 'http://timg.bdta.pro/images/e03f150d38471eb16cdbbee018fbe84b.jpg'),
(58637, 3990, 'Superman: A Série Animada S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/154180.mp4', 'http://timg.bdta.pro/images/0593e629f9aaddaf52e518b020b0470c.jpg'),
(58638, 3990, 'Superman: A Série Animada S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/154181.mp4', 'http://timg.bdta.pro/images/f4e77e0cd75d032156d2bed915dac7b7.jpg'),
(58639, 3990, 'Superman: A Série Animada S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/154182.mp4', 'http://timg.bdta.pro/images/244d9a320cb5e8afcb6be971bb93852d.jpg'),
(58640, 3990, 'Superman: A Série Animada S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/154183.mp4', 'http://timg.bdta.pro/images/7dbba2dbcb6cc9883da6344ef3783e5a.jpg'),
(58641, 3990, 'Superman: A Série Animada S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/154184.mp4', 'http://timg.bdta.pro/images/95b90dc08dd49a6113433232d7d460fc.jpg'),
(58642, 3990, 'Superman: A Série Animada S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/154185.mp4', 'http://timg.bdta.pro/images/3636736d7a0ca62ca9d4dfb7eb46a325.jpg'),
(58643, 3990, 'Superman: A Série Animada S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/154186.mp4', 'http://timg.bdta.pro/images/626255864bb9fa07fd3e5070ffda0bfb.jpg'),
(58644, 3990, 'Superman: A Série Animada S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/154187.mp4', 'http://timg.bdta.pro/images/9c91db176fcdfae1f319fb8962e44190.jpg'),
(58645, 3990, 'Superman: A Série Animada S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/154188.mp4', 'http://timg.bdta.pro/images/4d05910fea236f556818cc99bcf8c21f.jpg'),
(58646, 3990, 'Superman: A Série Animada S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/154189.mp4', 'http://timg.bdta.pro/images/948b08b2deb4a149ff673bff45f54836.jpg'),
(58647, 3990, 'Superman: A Série Animada S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/154190.mp4', 'http://timg.bdta.pro/images/fe9b023359f97be1670cf41beff7c881.jpg'),
(58648, 3990, 'Superman: A Série Animada S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/154191.mp4', 'http://timg.bdta.pro/images/93edc9fc26c87b7a2a04be91588c8766.jpg'),
(58649, 3990, 'Superman: A Série Animada S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/154192.mp4', 'http://timg.bdta.pro/images/687aaafb7f170ede235598a21ee0a5d3.jpg'),
(58650, 3991, 'Superman: A Série Animada S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154193.mp4', 'http://timg.bdta.pro/images/ed056774c35920b8023fcee56d43ae85.jpg'),
(58651, 3991, 'Superman: A Série Animada S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154194.mp4', 'http://timg.bdta.pro/images/2a74d6838901d815255ad29a25ddf923.jpg'),
(58652, 3991, 'Superman: A Série Animada S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154195.mp4', 'http://timg.bdta.pro/images/d51c44b118454489fc529603fb5fae7f.jpg'),
(58653, 3991, 'Superman: A Série Animada S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154196.mp4', 'http://timg.bdta.pro/images/a6c3f2869ab38f80b39f0e3a7091c10d.jpg'),
(58654, 3991, 'Superman: A Série Animada S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154197.mp4', 'http://timg.bdta.pro/images/fc9b89545086dd70c07365053edaaca4.jpg'),
(58655, 3991, 'Superman: A Série Animada S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154198.mp4', 'http://timg.bdta.pro/images/6fab7f682644f5e7f96d385567e262d8.jpg'),
(58656, 3991, 'Superman: A Série Animada S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154199.mp4', 'http://timg.bdta.pro/images/6bf67f7daa1dff041b5d1247620935d3.jpg'),
(58657, 3991, 'Superman: A Série Animada S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154200.mp4', 'http://timg.bdta.pro/images/88f952c65af17e255b6437e69146f1b8.jpg'),
(58658, 3991, 'Superman: A Série Animada S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154201.mp4', 'http://timg.bdta.pro/images/12d86082beb323bbb86c95ac4d127647.jpg'),
(58659, 3991, 'Superman: A Série Animada S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154202.mp4', 'http://timg.bdta.pro/images/b93482d6603854839792f3f4eea117fc.jpg'),
(58660, 3991, 'Superman: A Série Animada S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/154203.mp4', 'http://timg.bdta.pro/images/d5f1014ff2700c4cb3ff8962609e4739.jpg'),
(58661, 3991, 'Superman: A Série Animada S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/154204.mp4', 'http://timg.bdta.pro/images/a5c5b6520eed97231bb74db3e491c37a.jpg'),
(58662, 3991, 'Superman: A Série Animada S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/154205.mp4', 'http://timg.bdta.pro/images/25d33a96cb1b3721621425bcdd23b9a8.jpg'),
(58663, 3992, 'Superman e Lois S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223946.mp4', 'http://timg.bdta.pro/images/af2b9e6aff175234fc01efefad171371.jpg'),
(58664, 3992, 'Superman e Lois S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223947.mp4', 'http://timg.bdta.pro/images/9da06d5138c771653c5308979b6f9713.jpg'),
(58665, 3992, 'Superman e Lois S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223948.mp4', 'http://timg.bdta.pro/images/58d3e360899b311d1e0070a87963daca.jpg'),
(58666, 3992, 'Superman e Lois S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223949.mp4', 'http://timg.bdta.pro/images/ee41e28a6be88860518fc7eca751c85e.jpg'),
(58667, 3992, 'Superman e Lois S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223950.mp4', 'http://timg.bdta.pro/images/fdf6d72c7b4b13126d926f61bf2e4c54.jpg'),
(58668, 3992, 'Superman e Lois S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223951.mp4', 'http://timg.bdta.pro/images/4adc1c77db84be57a282269a5b4fb6d7.jpg'),
(58669, 3992, 'Superman e Lois S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223952.mp4', 'http://timg.bdta.pro/images/5c4b583a327cc8bc053e7e9f51da42e8.jpg'),
(58670, 3992, 'Superman e Lois S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223953.mp4', 'http://timg.bdta.pro/images/d6c0fdc746e043c3e015f7c1debc1cfb.jpg'),
(58671, 3992, 'Superman e Lois S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223954.mp4', 'http://timg.bdta.pro/images/dfc96221014f05e8c33cc9dea0edd878.jpg'),
(58672, 3992, 'Superman e Lois S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223955.mp4', 'http://timg.bdta.pro/images/07a459caa902ac5c63fd579c194fcc45.jpg'),
(58673, 3992, 'Superman e Lois S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223956.mp4', 'http://timg.bdta.pro/images/5f1fd4c844c496648bfc5fa48b0cb6f4.jpg'),
(58674, 3992, 'Superman e Lois S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223957.mp4', 'http://timg.bdta.pro/images/b9551446d46a61796784eca93bf8963b.jpg'),
(58675, 3992, 'Superman e Lois S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/223958.mp4', 'http://timg.bdta.pro/images/007b466afcba2b0233464be656181520.jpg'),
(58676, 3992, 'Superman e Lois S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/223959.mp4', 'http://timg.bdta.pro/images/41e8d2cd848e38f22156caffc95e6548.jpg'),
(58677, 3992, 'Superman e Lois S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/223960.mp4', 'http://timg.bdta.pro/images/0ae4da0a03c8bf30f7135655915f5970.jpg'),
(58678, 3993, 'Superman e Lois S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223961.mp4', 'http://timg.bdta.pro/images/8a975bb4fe10741b4011ee3ee4c6992e.jpg'),
(58679, 3993, 'Superman e Lois S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223962.mp4', 'http://timg.bdta.pro/images/f30b8d7e69a777031aa77c37483ba6da.jpg'),
(58680, 3993, 'Superman e Lois S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223963.mp4', 'http://timg.bdta.pro/images/25b5d744a273b5ecd5e153902d633926.jpg'),
(58681, 3993, 'Superman e Lois S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223964.mp4', 'http://timg.bdta.pro/images/9dc330f74fa01fde0b6838d526fdc1cf.jpg'),
(58682, 3993, 'Superman e Lois S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223965.mp4', 'http://timg.bdta.pro/images/b8190c2821069043b70d77b08551d686.jpg'),
(58683, 3993, 'Superman e Lois S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223966.mp4', 'http://timg.bdta.pro/images/7408062cc0f067ce1469841b21e3a125.jpg'),
(58684, 3993, 'Superman e Lois S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223967.mp4', 'http://timg.bdta.pro/images/435bfd1bbf8b0f6955a6fc2bc474d35b.jpg'),
(58685, 3993, 'Superman e Lois S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223968.mp4', 'http://timg.bdta.pro/images/48dd9b9aa0d88e15f41487da219e9891.jpg'),
(58686, 3993, 'Superman e Lois S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223969.mp4', 'http://timg.bdta.pro/images/baadd6f3127e04ffe4c2468eb24dacb1.jpg'),
(58687, 3993, 'Superman e Lois S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223970.mp4', 'http://timg.bdta.pro/images/cf739be537499af013aaeb1216b7f49a.jpg'),
(58688, 3993, 'Superman e Lois S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223971.mp4', 'http://timg.bdta.pro/images/2b1bbda577c1ad259ea6b82876b8762a.jpg'),
(58689, 3993, 'Superman e Lois S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223972.mp4', 'http://timg.bdta.pro/images/1833f47c014d61bf1538c70da870746d.jpg'),
(58690, 3993, 'Superman e Lois S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/223973.mp4', 'http://timg.bdta.pro/images/d62d5b8e93a09060af8819da75b164ab.jpg'),
(58691, 3993, 'Superman e Lois S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/223974.mp4', 'http://timg.bdta.pro/images/f4740a94d0d276aaf9505e323a4d77b6.jpg'),
(58692, 3993, 'Superman e Lois S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/223975.mp4', 'http://timg.bdta.pro/images/d964fa7eac3f63360996272a0ff8ebff.jpg'),
(58693, 3994, 'Superman e Lois S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223976.mp4', 'http://image.tmdb.org/t/p/w1280/4zy1LOR0FnuoKwlLx1lf7dA7Ejg.jpg'),
(58694, 3994, 'Superman e Lois S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223977.mp4', 'http://image.tmdb.org/t/p/w1280/7scVIQxtJy3d4dTI5gYq4uasrNp.jpg'),
(58695, 3994, 'Superman e Lois S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223978.mp4', 'http://image.tmdb.org/t/p/w1280/k4t4YAfI03UXmngz3MDcmOAI9Jx.jpg'),
(58696, 3994, 'Superman e Lois S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223979.mp4', 'http://image.tmdb.org/t/p/w1280/wPSTfLFDgy1zp6Qqr1Fn8T6Wn7x.jpg'),
(58697, 3994, 'Superman e Lois S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223980.mp4', 'http://image.tmdb.org/t/p/w1280/fklxDOsu3njpZXpcdwaHZsJfodZ.jpg'),
(58698, 3994, 'Superman e Lois S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223981.mp4', 'http://image.tmdb.org/t/p/w1280/qr9TDAEia5dIrzrnRFuG5qhwGoV.jpg'),
(58699, 3994, 'Superman e Lois S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223982.mp4', 'http://image.tmdb.org/t/p/w1280/35qNdxu4cjqBu9bHKqTtGjrhPrt.jpg'),
(58700, 3994, 'Superman e Lois S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223983.mp4', 'http://image.tmdb.org/t/p/w1280/icUxWccDq0LfmVS4O5ChdswInWq.jpg'),
(58701, 3994, 'Superman e Lois S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223984.mp4', 'http://image.tmdb.org/t/p/w1280/dJaDW2z2ncVBmUKmTiMCbTLhQwG.jpg'),
(58702, 3994, 'Superman e Lois S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223985.mp4', 'http://image.tmdb.org/t/p/w1280/21RcjR05CC3VTAz9aZ9438G1CKp.jpg'),
(58703, 3994, 'Superman e Lois S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223986.mp4', 'http://gstaticontent.com/images/fcfb179fb6bebd6935c85909e5adf4cc.jpg'),
(58704, 3994, 'Superman e Lois S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223987.mp4', 'http://image.tmdb.org/t/p/w1280/tKdoKMTq3tzJEDVQKfCFCiCs902.jpg'),
(58705, 3994, 'Superman e Lois S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/223988.mp4', 'http://image.tmdb.org/t/p/w1280/qMUEhVELgB028IiZsLKfe72pNpd.jpg'),
(58706, 3995, 'Superman e Lois S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/480996.mp4', 'http://gstaticontent.com/images/fcfb179fb6bebd6935c85909e5adf4cc.jpg'),
(58707, 3995, 'Superman e Lois S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/480997.mp4', 'http://gstaticontent.com/images/fcfb179fb6bebd6935c85909e5adf4cc.jpg'),
(58708, 3995, 'Superman e Lois S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/490073.mp4', 'http://gstaticontent.com/images/fcfb179fb6bebd6935c85909e5adf4cc.jpg'),
(58709, 3995, 'Superman e Lois S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/497876.mp4', 'http://gstaticontent.com/images/fcfb179fb6bebd6935c85909e5adf4cc.jpg'),
(58710, 3995, 'Superman e Lois S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/499464.mp4', 'http://gstaticontent.com/images/fcfb179fb6bebd6935c85909e5adf4cc.jpg'),
(58711, 3995, 'Superman e Lois S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/504736.mp4', 'http://gstaticontent.com/images/fcfb179fb6bebd6935c85909e5adf4cc.jpg'),
(58712, 3995, 'Superman e Lois S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/509244.mp4', 'http://gstaticontent.com/images/fcfb179fb6bebd6935c85909e5adf4cc.jpg'),
(58713, 3995, 'Superman e Lois S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/514935.mp4', 'http://gstaticontent.com/images/fcfb179fb6bebd6935c85909e5adf4cc.jpg'),
(58714, 3995, 'Superman e Lois S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/521863.mp4', 'http://gstaticontent.com/images/fcfb179fb6bebd6935c85909e5adf4cc.jpg'),
(58715, 3995, 'Superman e Lois S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/521864.mp4', 'http://gstaticontent.com/images/fcfb179fb6bebd6935c85909e5adf4cc.jpg'),
(58716, 3996, 'The North Water [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149248.mp4', 'http://timg.bdta.pro/images/4d44010b1558a3c841c7069b049d8f9e.jpg'),
(58717, 3996, 'The North Water [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149249.mp4', 'http://timg.bdta.pro/images/3d3a176acce597e54afd88837eb846dd.jpg'),
(58718, 3996, 'The North Water [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149250.mp4', 'http://timg.bdta.pro/images/d568c78ea8418a20b26e9a728ba20223.jpg'),
(58719, 3996, 'The North Water [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149251.mp4', 'http://timg.bdta.pro/images/2a91bc5d18dd5cf0b35a9d8c401b9c5d.jpg'),
(58720, 3996, 'The North Water [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149252.mp4', 'http://timg.bdta.pro/images/46dccf95b6942cf143b345b33f4f16ae.jpg'),
(58721, 3997, 'Veep S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154087.mp4', 'http://timg.bdta.pro/images/f8dfacff4a55f97a4712d9d2895761f3.jpg'),
(58722, 3997, 'Veep S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154088.mp4', 'http://timg.bdta.pro/images/d27fadeb08407b34c08df35d711bec5f.jpg'),
(58723, 3997, 'Veep S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154089.mp4', 'http://timg.bdta.pro/images/f5693753d51f0712c4b2d997edebe570.jpg'),
(58724, 3997, 'Veep S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154090.mp4', 'http://timg.bdta.pro/images/6c6b989b6c75c6c0fc216fa9199e9a78.jpg'),
(58725, 3997, 'Veep S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154091.mp4', 'http://timg.bdta.pro/images/db03378ce31d97bb19f512fd9aa43f21.jpg'),
(58726, 3997, 'Veep S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154092.mp4', 'http://timg.bdta.pro/images/0a4a4dff27ce294dae0b45a9ff30e604.jpg'),
(58727, 3997, 'Veep S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154093.mp4', 'http://timg.bdta.pro/images/ca0a5d01cf63edd66ef39c87fb1efe65.jpg'),
(58728, 3997, 'Veep S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154094.mp4', 'http://timg.bdta.pro/images/a7bbafe4d9ae243951cdb75a3b6602ef.jpg'),
(58729, 3998, 'Veep S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154095.mp4', 'http://timg.bdta.pro/images/d8fe4d6d61f5d213e985ccbe2a3a2fd9.jpg'),
(58730, 3998, 'Veep S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154096.mp4', 'http://timg.bdta.pro/images/2698be65774348d755e0db9424bb7c10.jpg'),
(58731, 3998, 'Veep S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154097.mp4', 'http://timg.bdta.pro/images/88a041e53534dfcf7cffedc762af7564.jpg'),
(58732, 3998, 'Veep S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154098.mp4', 'http://timg.bdta.pro/images/605fe422189e971ede3b568513fadd18.jpg'),
(58733, 3998, 'Veep S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154099.mp4', 'http://timg.bdta.pro/images/65a43ee6aaba45c8616ee4a71010f604.jpg'),
(58734, 3998, 'Veep S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154100.mp4', 'http://timg.bdta.pro/images/370c308d1878b648f95ead4aad6e0ebc.jpg'),
(58735, 3998, 'Veep S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154101.mp4', 'http://timg.bdta.pro/images/fce317d0f215b79efe73dfa5ae469ae4.jpg'),
(58736, 3998, 'Veep S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154102.mp4', 'http://timg.bdta.pro/images/302f6558c840b32bb725f1a1b1216d17.jpg'),
(58737, 3998, 'Veep S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154103.mp4', 'http://timg.bdta.pro/images/57e29c15fd807e3d1f54ce15a57b5b91.jpg'),
(58738, 3998, 'Veep S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154104.mp4', 'http://timg.bdta.pro/images/0a6bc5ba4251057abb6e9957cc9d0844.jpg'),
(58739, 3999, 'Veep S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154105.mp4', 'http://timg.bdta.pro/images/6fbd60567ceb8ef00d47ab69f2dda39f.jpg'),
(58740, 3999, 'Veep S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154106.mp4', 'http://timg.bdta.pro/images/7464d0a92f449f4bf3bfe790db435669.jpg'),
(58741, 3999, 'Veep S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154107.mp4', 'http://timg.bdta.pro/images/8a246e406e63dd7d022f1e1dd89325cb.jpg'),
(58742, 3999, 'Veep S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154108.mp4', 'http://timg.bdta.pro/images/a3353f00b5559c09a5d7c0c266f720b4.jpg'),
(58743, 3999, 'Veep S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154109.mp4', 'http://timg.bdta.pro/images/65224f40c99f75c59ace386670d38d83.jpg'),
(58744, 3999, 'Veep S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154110.mp4', 'http://timg.bdta.pro/images/508e5f0222b3dbc990e93996f1481cfc.jpg'),
(58745, 3999, 'Veep S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154111.mp4', 'http://timg.bdta.pro/images/c2ab2862ae01309270f22adc4fe2539b.jpg'),
(58746, 3999, 'Veep S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154112.mp4', 'http://timg.bdta.pro/images/8863c698eb656ab67ce8e2be1a6ebf17.jpg'),
(58747, 3999, 'Veep S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154113.mp4', 'http://timg.bdta.pro/images/773e6741c86e4f3fd92e78e263823a10.jpg'),
(58748, 3999, 'Veep S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154114.mp4', 'http://timg.bdta.pro/images/b7c896e4979ecb91e1f17df135be6286.jpg'),
(58749, 4000, 'Veep S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154115.mp4', 'http://timg.bdta.pro/images/0a2497f37c50cdcf44e381e114884b0c.jpg'),
(58750, 4000, 'Veep S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154116.mp4', 'http://timg.bdta.pro/images/3fe7711007739b296fb61d0777ef7b90.jpg'),
(58751, 4000, 'Veep S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154117.mp4', 'http://timg.bdta.pro/images/8d07045f42bae18e7e7133a9c059392a.jpg'),
(58752, 4000, 'Veep S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154118.mp4', 'http://timg.bdta.pro/images/760ed6d1c991cc9ec33e2bbc30b2943a.jpg'),
(58753, 4000, 'Veep S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154119.mp4', 'http://timg.bdta.pro/images/efeb6c8e229f4662f81f1fd9abe2e918.jpg'),
(58754, 4000, 'Veep S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154120.mp4', 'http://timg.bdta.pro/images/7da11c5a0f63d31d058be69da33f2e5c.jpg'),
(58755, 4000, 'Veep S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154121.mp4', 'http://timg.bdta.pro/images/94452c0e9065f2cc7896d880e9bc709e.jpg'),
(58756, 4000, 'Veep S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154122.mp4', 'http://timg.bdta.pro/images/e29c3cdfc567242cf4733ebc1706fab2.jpg'),
(58757, 4000, 'Veep S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154123.mp4', 'http://timg.bdta.pro/images/dfff76417a21155c008ed49f60c2ae58.jpg'),
(58758, 4000, 'Veep S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154124.mp4', 'http://timg.bdta.pro/images/e0dbe0b7650c450114f7be0271d4c9ad.jpg'),
(58759, 4001, 'Veep S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154125.mp4', 'http://timg.bdta.pro/images/dec232a54cca721cb7f1e3fb3235a3eb.jpg'),
(58760, 4001, 'Veep S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154126.mp4', 'http://timg.bdta.pro/images/b57707e8afe23d5a4bdd6034276a2d82.jpg'),
(58761, 4001, 'Veep S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154127.mp4', 'http://timg.bdta.pro/images/d8ab58adc7f35bcdf5d184cd1ffed78f.jpg'),
(58762, 4001, 'Veep S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154128.mp4', 'http://timg.bdta.pro/images/0a56529d4f02887f78b4be6e19dd54ed.jpg'),
(58763, 4001, 'Veep S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154129.mp4', 'http://timg.bdta.pro/images/f1fd3b25b8cee7b977b9c91fb3b90d07.jpg'),
(58764, 4001, 'Veep S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154130.mp4', 'http://timg.bdta.pro/images/c31014eff0d764e95834f6c36b5a3da3.jpg'),
(58765, 4001, 'Veep S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154131.mp4', 'http://timg.bdta.pro/images/c163a32044026b5e769c552a55d4b888.jpg'),
(58766, 4001, 'Veep S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154132.mp4', 'http://timg.bdta.pro/images/272b01943c350d59a6dd3a5f5af9e6fc.jpg'),
(58767, 4001, 'Veep S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154133.mp4', 'http://timg.bdta.pro/images/54d8766908e71e0d2cec2e25791a48af.jpg'),
(58768, 4001, 'Veep S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154134.mp4', 'http://timg.bdta.pro/images/c8b02778814059108e483a970d429d6f.jpg'),
(58769, 4002, 'Veep S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154135.mp4', 'http://timg.bdta.pro/images/9be3b5dd063d88eebb0a53111e2e2889.jpg'),
(58770, 4002, 'Veep S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154136.mp4', 'http://timg.bdta.pro/images/38b62863f5bfbcf0b43b2e0d02f74580.jpg'),
(58771, 4002, 'Veep S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154137.mp4', 'http://timg.bdta.pro/images/e6fe108240b98e1e5a0132ed108a9537.jpg'),
(58772, 4002, 'Veep S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154138.mp4', 'http://timg.bdta.pro/images/97c1d222f59ea7c483a304a311c4b6bb.jpg'),
(58773, 4002, 'Veep S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154139.mp4', 'http://timg.bdta.pro/images/7f36a56147e29cf01640313b142a7b48.jpg'),
(58774, 4002, 'Veep S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154140.mp4', 'http://timg.bdta.pro/images/e9c9646397c42358ed136f004ac8c2a6.jpg'),
(58775, 4002, 'Veep S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154141.mp4', 'http://timg.bdta.pro/images/c3360ec6c7089848600d2ce20e92d1f2.jpg'),
(58776, 4002, 'Veep S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154142.mp4', 'http://timg.bdta.pro/images/5224c31f52f365f34816c1096676a53f.jpg'),
(58777, 4002, 'Veep S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154143.mp4', 'http://timg.bdta.pro/images/08d1611ea9241d4e355486968fed900f.jpg'),
(58778, 4002, 'Veep S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154144.mp4', 'http://timg.bdta.pro/images/d7358a0ce3a9505327030004ad82f935.jpg'),
(58779, 4003, 'Veep S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154145.mp4', 'http://timg.bdta.pro/images/e1285cbd6c40861cf8d9a300766ded58.jpg'),
(58780, 4003, 'Veep S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154146.mp4', 'http://timg.bdta.pro/images/d017b9fff649747801af462fc956a448.jpg'),
(58781, 4003, 'Veep S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154147.mp4', 'http://timg.bdta.pro/images/38a91cf7eee56772f634ff1a7af8b7d7.jpg'),
(58782, 4003, 'Veep S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154148.mp4', 'http://timg.bdta.pro/images/44edb639e45fe787b97cc9148b6aef3b.jpg'),
(58783, 4003, 'Veep S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154149.mp4', 'http://timg.bdta.pro/images/f7889601dd84037eccc80bfe72ca24f3.jpg'),
(58784, 4003, 'Veep S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154150.mp4', 'http://timg.bdta.pro/images/908b72abb023aefadb1f444970b16491.jpg'),
(58785, 4003, 'Veep S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154151.mp4', 'http://timg.bdta.pro/images/e42557ecd73fdf9f4c066c5ba04e67cc.jpg'),
(58786, 4004, 'Xena: A Princesa Guerreira S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153953.mp4', 'http://timg.bdta.pro/images/43830ad24bd24aab7bace970b27239a6.jpg'),
(58787, 4004, 'Xena: A Princesa Guerreira S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153954.mp4', 'http://timg.bdta.pro/images/31853111dd2fcb134ed1e227e08158c4.jpg'),
(58788, 4004, 'Xena: A Princesa Guerreira S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153955.mp4', 'http://timg.bdta.pro/images/5ed9b23f2ac4e4c418b4e30ea5f4516d.jpg'),
(58789, 4004, 'Xena: A Princesa Guerreira S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153956.mp4', 'http://timg.bdta.pro/images/bdf4cea212b22aff3e29444ed9783a9d.jpg'),
(58790, 4004, 'Xena: A Princesa Guerreira S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153957.mp4', 'http://timg.bdta.pro/images/e00950352c8abe2ab80a0c25cf01c612.jpg'),
(58791, 4004, 'Xena: A Princesa Guerreira S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153958.mp4', 'http://timg.bdta.pro/images/47227920d46fde817655479b9d737471.jpg'),
(58792, 4004, 'Xena: A Princesa Guerreira S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153959.mp4', 'http://timg.bdta.pro/images/3d532097cbd2849ca8ebaf426241e346.jpg'),
(58793, 4004, 'Xena: A Princesa Guerreira S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153960.mp4', 'http://timg.bdta.pro/images/01f89812160953fc7af7a95b1a2dac33.jpg'),
(58794, 4004, 'Xena: A Princesa Guerreira S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153961.mp4', 'http://timg.bdta.pro/images/612ab5b4aa2e09d0de8a3881d9aa10e5.jpg'),
(58795, 4004, 'Xena: A Princesa Guerreira S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153962.mp4', 'http://timg.bdta.pro/images/d729543bd752571ad1238582bf94b3ce.jpg'),
(58796, 4004, 'Xena: A Princesa Guerreira S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153963.mp4', 'http://timg.bdta.pro/images/9f8aa9e2e63606e3c4f7301f29fa7996.jpg'),
(58797, 4004, 'Xena: A Princesa Guerreira S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153964.mp4', 'http://timg.bdta.pro/images/43f923a89ac1427db16f2b5a459b539f.jpg'),
(58798, 4004, 'Xena: A Princesa Guerreira S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153965.mp4', 'http://timg.bdta.pro/images/cfd7fd6d5bd3cf9ee1542a27f6a871d3.jpg'),
(58799, 4004, 'Xena: A Princesa Guerreira S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153966.mp4', 'http://timg.bdta.pro/images/0e4c604e2462902b2885172ee59bf5b7.jpg'),
(58800, 4004, 'Xena: A Princesa Guerreira S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153967.mp4', 'http://timg.bdta.pro/images/82b88ce597fedb54523699dcaf23d67d.jpg'),
(58801, 4004, 'Xena: A Princesa Guerreira S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/153968.mp4', 'http://timg.bdta.pro/images/8a86db744c75f629a2588eeba962fbd8.jpg'),
(58802, 4004, 'Xena: A Princesa Guerreira S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/153969.mp4', 'http://timg.bdta.pro/images/298fbebdfec6fc465ab534bffb1938cf.jpg'),
(58803, 4004, 'Xena: A Princesa Guerreira S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/153970.mp4', 'http://timg.bdta.pro/images/a90515419616e9ccf4fdb999e8a9cf7b.jpg'),
(58804, 4004, 'Xena: A Princesa Guerreira S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/153971.mp4', 'http://timg.bdta.pro/images/cf9c37fb5cf0c2e1aa3d7b1321006b21.jpg'),
(58805, 4004, 'Xena: A Princesa Guerreira S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/153972.mp4', 'http://timg.bdta.pro/images/36a01622d63979aa97b12171fce2f321.jpg'),
(58806, 4004, 'Xena: A Princesa Guerreira S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/153973.mp4', 'http://timg.bdta.pro/images/6954d4a49d03abaf0074da52a4a558b5.jpg'),
(58807, 4004, 'Xena: A Princesa Guerreira S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/153974.mp4', 'http://timg.bdta.pro/images/4e2fec81a45c3ee96a32b0802da6f5c2.jpg'),
(58808, 4004, 'Xena: A Princesa Guerreira S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/153975.mp4', 'http://timg.bdta.pro/images/44b96c6a884fbc5149d845b3672b4407.jpg'),
(58809, 4004, 'Xena: A Princesa Guerreira S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/153976.mp4', 'http://timg.bdta.pro/images/81ac80e163f26cbf0282bd1fccc314a0.jpg'),
(58810, 4005, 'Xena: A Princesa Guerreira S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153977.mp4', 'http://timg.bdta.pro/images/8f5915c0dacbedf5a6a10cf6da1a3d2d.jpg'),
(58811, 4005, 'Xena: A Princesa Guerreira S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153978.mp4', 'http://timg.bdta.pro/images/c35ea1ed2fcc3b37e6622786cd6ac13d.jpg'),
(58812, 4005, 'Xena: A Princesa Guerreira S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153979.mp4', 'http://timg.bdta.pro/images/c08498aac11d97cebde9241e8bc1af4b.jpg'),
(58813, 4005, 'Xena: A Princesa Guerreira S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153980.mp4', 'http://timg.bdta.pro/images/dc96dc210d314f145ac7222ceb2c0b11.jpg'),
(58814, 4005, 'Xena: A Princesa Guerreira S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153981.mp4', 'http://timg.bdta.pro/images/32db7b3de15c74fa023687a1803c313c.jpg'),
(58815, 4005, 'Xena: A Princesa Guerreira S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153982.mp4', 'http://timg.bdta.pro/images/7f64a8dcad57a2d78cec77b0377dadef.jpg'),
(58816, 4005, 'Xena: A Princesa Guerreira S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153983.mp4', 'http://timg.bdta.pro/images/a408d5890f75538d1fab11cd3c1953cc.jpg'),
(58817, 4005, 'Xena: A Princesa Guerreira S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153984.mp4', 'http://timg.bdta.pro/images/8ef0c49f6416c11cccac2af84499e108.jpg'),
(58818, 4005, 'Xena: A Princesa Guerreira S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153985.mp4', 'http://timg.bdta.pro/images/58d25e9ba33e01edf26c1b939a786703.jpg'),
(58819, 4005, 'Xena: A Princesa Guerreira S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153986.mp4', 'http://timg.bdta.pro/images/7938dad943a16f8006f8a53fd17d0d38.jpg'),
(58820, 4005, 'Xena: A Princesa Guerreira S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153987.mp4', 'http://timg.bdta.pro/images/5ac9646b2300ea0a415e909f055db92e.jpg'),
(58821, 4005, 'Xena: A Princesa Guerreira S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153988.mp4', 'http://timg.bdta.pro/images/ed6b5ed76f1ba144d24a8a89da781a8e.jpg'),
(58822, 4005, 'Xena: A Princesa Guerreira S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153989.mp4', 'http://timg.bdta.pro/images/b2393ee242c646b8567759ae0e7906ab.jpg'),
(58823, 4005, 'Xena: A Princesa Guerreira S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153990.mp4', 'http://timg.bdta.pro/images/edc626f6d395ff10f4865cf5f2dfafd3.jpg'),
(58824, 4005, 'Xena: A Princesa Guerreira S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153991.mp4', 'http://timg.bdta.pro/images/b3d4ecf30f4fc312e02f5b56841af37d.jpg'),
(58825, 4005, 'Xena: A Princesa Guerreira S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/153992.mp4', 'http://timg.bdta.pro/images/eee67a82ae7c4bcce2a5bb89d21b0d21.jpg'),
(58826, 4005, 'Xena: A Princesa Guerreira S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/153993.mp4', 'http://timg.bdta.pro/images/3ee8c326ebe06cd8144cbfd976477099.jpg'),
(58827, 4005, 'Xena: A Princesa Guerreira S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/153994.mp4', 'http://timg.bdta.pro/images/09bc1a29e12cc8f797842ed5ad6847fd.jpg'),
(58828, 4005, 'Xena: A Princesa Guerreira S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/153995.mp4', 'http://timg.bdta.pro/images/e86821e98e023d300117536b86282c52.jpg'),
(58829, 4005, 'Xena: A Princesa Guerreira S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/153996.mp4', 'http://timg.bdta.pro/images/1df618b6bc11536d05a51b06a3055a9a.jpg'),
(58830, 4005, 'Xena: A Princesa Guerreira S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/153997.mp4', 'http://timg.bdta.pro/images/77c2a4ecc29101efef69952cefb9d894.jpg'),
(58831, 4005, 'Xena: A Princesa Guerreira S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/153998.mp4', 'http://timg.bdta.pro/images/4bb1ebbf1b188a748bd4629649e86eaa.jpg'),
(58832, 4006, 'Xena: A Princesa Guerreira S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153999.mp4', 'http://timg.bdta.pro/images/f0496d86220fb2c24228439aa5eb496c.jpg'),
(58833, 4006, 'Xena: A Princesa Guerreira S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154000.mp4', 'http://timg.bdta.pro/images/10755e109c46aa24e8ad8d5712ea849d.jpg'),
(58834, 4006, 'Xena: A Princesa Guerreira S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154001.mp4', 'http://timg.bdta.pro/images/7ea0d6678033878070ad5c4eb257c714.jpg'),
(58835, 4006, 'Xena: A Princesa Guerreira S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154002.mp4', 'http://timg.bdta.pro/images/f8982d724233ff3187ba2d5975d11d90.jpg'),
(58836, 4006, 'Xena: A Princesa Guerreira S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154003.mp4', 'http://timg.bdta.pro/images/bc8f60dce5f888a7bef82ff804ac8234.jpg'),
(58837, 4006, 'Xena: A Princesa Guerreira S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154004.mp4', 'http://timg.bdta.pro/images/42aa9aa80ce293f1219726d9389d06cf.jpg'),
(58838, 4006, 'Xena: A Princesa Guerreira S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154005.mp4', 'http://timg.bdta.pro/images/8d3a92a6978b8932ed9be168f11f3b7d.jpg'),
(58839, 4006, 'Xena: A Princesa Guerreira S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154006.mp4', 'http://timg.bdta.pro/images/67b0dec59d0c67000cabdb5e202def31.jpg'),
(58840, 4006, 'Xena: A Princesa Guerreira S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154007.mp4', 'http://timg.bdta.pro/images/3e8fcc4c3230feea09c86d17a87ea198.jpg'),
(58841, 4006, 'Xena: A Princesa Guerreira S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154008.mp4', 'http://timg.bdta.pro/images/66c2e59ced8f14987e7627d999a9831a.jpg'),
(58842, 4006, 'Xena: A Princesa Guerreira S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/154009.mp4', 'http://timg.bdta.pro/images/987a80279523cdad3f4f1a83b9da81ba.jpg'),
(58843, 4006, 'Xena: A Princesa Guerreira S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/154010.mp4', 'http://timg.bdta.pro/images/a98594ecbb858eb723bdd279343cc275.jpg'),
(58844, 4006, 'Xena: A Princesa Guerreira S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/154011.mp4', 'http://timg.bdta.pro/images/13b70eeed35c1cbedf0b7aa1cf73453f.jpg'),
(58845, 4006, 'Xena: A Princesa Guerreira S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/154012.mp4', 'http://timg.bdta.pro/images/36a4e61e6340b7121091b7d046d528df.jpg'),
(58846, 4006, 'Xena: A Princesa Guerreira S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/154013.mp4', 'http://timg.bdta.pro/images/9ed8edd20f4a983fe75a92a587a41bcd.jpg'),
(58847, 4006, 'Xena: A Princesa Guerreira S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/154014.mp4', 'http://timg.bdta.pro/images/de233754c1f3624783e4cd703cc479b6.jpg'),
(58848, 4006, 'Xena: A Princesa Guerreira S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/154015.mp4', 'http://timg.bdta.pro/images/0acf01a1eaf0cbf561804696c45b69d3.jpg'),
(58849, 4006, 'Xena: A Princesa Guerreira S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/154016.mp4', 'http://timg.bdta.pro/images/bd6ff400cc523d62ef1adeab56eedb2c.jpg'),
(58850, 4006, 'Xena: A Princesa Guerreira S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/154017.mp4', 'http://timg.bdta.pro/images/b66778a0f41a2d3182236916ecc4eb2a.jpg'),
(58851, 4006, 'Xena: A Princesa Guerreira S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/154018.mp4', 'http://timg.bdta.pro/images/c1e9dde13e69559b3f501171ee934f0f.jpg'),
(58852, 4006, 'Xena: A Princesa Guerreira S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/154019.mp4', 'http://timg.bdta.pro/images/0d7c6b645d6b7798d9ec154fdfaf5bb9.jpg'),
(58853, 4006, 'Xena: A Princesa Guerreira S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/154020.mp4', 'http://timg.bdta.pro/images/cdd819e3c116716af1c7fa0cdd3c67ac.jpg'),
(58854, 4007, 'Xena: A Princesa Guerreira S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154021.mp4', 'http://timg.bdta.pro/images/7349ec72ba69574cd5538f7829eae814.jpg'),
(58855, 4007, 'Xena: A Princesa Guerreira S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154022.mp4', 'http://timg.bdta.pro/images/95f249b975e3c784f51b378a83b9c65c.jpg'),
(58856, 4007, 'Xena: A Princesa Guerreira S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154023.mp4', 'http://timg.bdta.pro/images/09638234830227c0f38a89369a942c4f.jpg'),
(58857, 4007, 'Xena: A Princesa Guerreira S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154024.mp4', 'http://timg.bdta.pro/images/58b0a6eaab5c590642ada4a4c60683ae.jpg'),
(58858, 4007, 'Xena: A Princesa Guerreira S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154025.mp4', 'http://timg.bdta.pro/images/933a5c6a86db6f0beea08b4299a39e3e.jpg'),
(58859, 4007, 'Xena: A Princesa Guerreira S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154026.mp4', 'http://timg.bdta.pro/images/aa0603b841c49e823014b6739c369ec9.jpg'),
(58860, 4007, 'Xena: A Princesa Guerreira S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154027.mp4', 'http://timg.bdta.pro/images/b67d7ed5e7c9cf79805aed9a25bb8f4f.jpg'),
(58861, 4007, 'Xena: A Princesa Guerreira S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154028.mp4', 'http://timg.bdta.pro/images/874667440f773d8ec0c7de4c75ec5dad.jpg'),
(58862, 4007, 'Xena: A Princesa Guerreira S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154029.mp4', 'http://timg.bdta.pro/images/d52cb06ccc04a0cbfb028b903cef8ac4.jpg'),
(58863, 4007, 'Xena: A Princesa Guerreira S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154030.mp4', 'http://timg.bdta.pro/images/ba14b94fc352b14d27d72179635b36c3.jpg'),
(58864, 4007, 'Xena: A Princesa Guerreira S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/154031.mp4', 'http://timg.bdta.pro/images/e06a61ac2aef46264524ecdcb1d9e33a.jpg'),
(58865, 4007, 'Xena: A Princesa Guerreira S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/154032.mp4', 'http://timg.bdta.pro/images/c49dfbe4cbaf44d838b9b4ca28fbe0d0.jpg'),
(58866, 4007, 'Xena: A Princesa Guerreira S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/154033.mp4', 'http://timg.bdta.pro/images/04943409ac6777c5fe80b5a563db692c.jpg'),
(58867, 4007, 'Xena: A Princesa Guerreira S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/154034.mp4', 'http://timg.bdta.pro/images/54efe6f41ae69b3a7a5287a28293b4ab.jpg'),
(58868, 4007, 'Xena: A Princesa Guerreira S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/154035.mp4', 'http://timg.bdta.pro/images/49f7797083831bfbab0b4b612aad900f.jpg'),
(58869, 4007, 'Xena: A Princesa Guerreira S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/154036.mp4', 'http://timg.bdta.pro/images/ef81cd803ee2ed9daff80013d897386d.jpg'),
(58870, 4007, 'Xena: A Princesa Guerreira S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/154037.mp4', 'http://timg.bdta.pro/images/d5693b9f3cea4f258ff6f9d52b2c756c.jpg'),
(58871, 4007, 'Xena: A Princesa Guerreira S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/154038.mp4', 'http://timg.bdta.pro/images/c42a3387a7cc457862d276b838ff0e90.jpg'),
(58872, 4007, 'Xena: A Princesa Guerreira S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/154039.mp4', 'http://timg.bdta.pro/images/e36a444dc509911d771cef5dc24895ce.jpg'),
(58873, 4007, 'Xena: A Princesa Guerreira S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/154040.mp4', 'http://timg.bdta.pro/images/43aaf6bf2aab64723d80331cfe6eb440.jpg'),
(58874, 4007, 'Xena: A Princesa Guerreira S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/154041.mp4', 'http://timg.bdta.pro/images/e269b71c3604aa684f360a84b447f63a.jpg'),
(58875, 4007, 'Xena: A Princesa Guerreira S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/154042.mp4', 'http://timg.bdta.pro/images/6d91656b23af6253a653011e941f843b.jpg'),
(58876, 4008, 'Xena: A Princesa Guerreira S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154043.mp4', 'http://timg.bdta.pro/images/3f64605fbb420ae89c2d7ac72671be86.jpg'),
(58877, 4008, 'Xena: A Princesa Guerreira S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154044.mp4', 'http://timg.bdta.pro/images/cf6b9d55c98e3b3a5f18bd1193880fe1.jpg'),
(58878, 4008, 'Xena: A Princesa Guerreira S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154045.mp4', 'http://timg.bdta.pro/images/c71981554682a2d096c3e8a26c18a262.jpg'),
(58879, 4008, 'Xena: A Princesa Guerreira S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154046.mp4', 'http://timg.bdta.pro/images/e66fcbeceea05999ecd8ec50e7309231.jpg'),
(58880, 4008, 'Xena: A Princesa Guerreira S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154047.mp4', 'http://timg.bdta.pro/images/44c139769ec919d887966679aaa0432b.jpg'),
(58881, 4008, 'Xena: A Princesa Guerreira S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154048.mp4', 'http://timg.bdta.pro/images/fcff4e252f3adbbda0394631fd58bbe2.jpg'),
(58882, 4008, 'Xena: A Princesa Guerreira S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154049.mp4', 'http://timg.bdta.pro/images/e4f5390cdeac1458a91d578041752d50.jpg'),
(58883, 4008, 'Xena: A Princesa Guerreira S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154050.mp4', 'http://timg.bdta.pro/images/24c19075e6179e24c026e19ff7747af0.jpg'),
(58884, 4008, 'Xena: A Princesa Guerreira S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154051.mp4', 'http://timg.bdta.pro/images/6397ffc4d7a8444e948bb01809102300.jpg'),
(58885, 4008, 'Xena: A Princesa Guerreira S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154052.mp4', 'http://timg.bdta.pro/images/5782a9cdbf2fb537759a015358659e2b.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(58886, 4008, 'Xena: A Princesa Guerreira S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/154053.mp4', 'http://timg.bdta.pro/images/413df123b6268b3afdd371403dfa8bbf.jpg'),
(58887, 4008, 'Xena: A Princesa Guerreira S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/154054.mp4', 'http://timg.bdta.pro/images/4fbc8f8a040e81437f602c7a25746639.jpg'),
(58888, 4008, 'Xena: A Princesa Guerreira S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/154055.mp4', 'http://timg.bdta.pro/images/154fd7156509cd78e9cb4eb2158ce8c6.jpg'),
(58889, 4008, 'Xena: A Princesa Guerreira S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/154056.mp4', 'http://timg.bdta.pro/images/d063c918325f11de27c576bb424869e0.jpg'),
(58890, 4008, 'Xena: A Princesa Guerreira S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/154057.mp4', 'http://timg.bdta.pro/images/fb52b98d985e7cdd08d35993849e4158.jpg'),
(58891, 4008, 'Xena: A Princesa Guerreira S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/154058.mp4', 'http://timg.bdta.pro/images/21889da4f3b9c7dffcba631934fcebe9.jpg'),
(58892, 4008, 'Xena: A Princesa Guerreira S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/154059.mp4', 'http://timg.bdta.pro/images/bc370074190f999ef7999babc5bba86e.jpg'),
(58893, 4008, 'Xena: A Princesa Guerreira S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/154060.mp4', 'http://timg.bdta.pro/images/cf884a8d4d0ffdc95e3678c788bb053e.jpg'),
(58894, 4008, 'Xena: A Princesa Guerreira S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/154061.mp4', 'http://timg.bdta.pro/images/7efcd73988a42bc30fcaa4ade21e4160.jpg'),
(58895, 4008, 'Xena: A Princesa Guerreira S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/154062.mp4', 'http://timg.bdta.pro/images/7c4ce4e1302f925446a9483ff8593dd5.jpg'),
(58896, 4008, 'Xena: A Princesa Guerreira S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/154063.mp4', 'http://timg.bdta.pro/images/9a8a3307d5529965028cd87e9ce864a9.jpg'),
(58897, 4008, 'Xena: A Princesa Guerreira S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/154064.mp4', 'http://timg.bdta.pro/images/4dbd06cf74f906d4481687239bcdd09e.jpg'),
(58898, 4009, 'Xena: A Princesa Guerreira S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154065.mp4', 'http://timg.bdta.pro/images/02ee41bdab337a4ede846d7b9c973033.jpg'),
(58899, 4009, 'Xena: A Princesa Guerreira S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154066.mp4', 'http://timg.bdta.pro/images/256d99ce53926dfebe76722e416e0571.jpg'),
(58900, 4009, 'Xena: A Princesa Guerreira S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154067.mp4', 'http://timg.bdta.pro/images/cac56116479ed5137f00633bcde30935.jpg'),
(58901, 4009, 'Xena: A Princesa Guerreira S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154068.mp4', 'http://timg.bdta.pro/images/4fa7b6b036417836b67f5e2882cdef1a.jpg'),
(58902, 4009, 'Xena: A Princesa Guerreira S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154069.mp4', 'http://timg.bdta.pro/images/f51c617b4f994acd05995158badcf4c3.jpg'),
(58903, 4009, 'Xena: A Princesa Guerreira S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154070.mp4', 'http://timg.bdta.pro/images/8eedabf04c4f258fe2974f75123e28c8.jpg'),
(58904, 4009, 'Xena: A Princesa Guerreira S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154071.mp4', 'http://timg.bdta.pro/images/556188d469ce8fc4ce78688ea27747f9.jpg'),
(58905, 4009, 'Xena: A Princesa Guerreira S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154072.mp4', 'http://timg.bdta.pro/images/6752178638e610b9ccce71a10a59dac9.jpg'),
(58906, 4009, 'Xena: A Princesa Guerreira S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154073.mp4', 'http://timg.bdta.pro/images/8dc5e06b3258a83d2bf211f33dddf9e0.jpg'),
(58907, 4009, 'Xena: A Princesa Guerreira S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154074.mp4', 'http://timg.bdta.pro/images/d498823177b4f1cc44072fd728978361.jpg'),
(58908, 4009, 'Xena: A Princesa Guerreira S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/154075.mp4', 'http://timg.bdta.pro/images/38dcd9ccf8dc07cb49abecc224ad93c2.jpg'),
(58909, 4009, 'Xena: A Princesa Guerreira S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/154076.mp4', 'http://timg.bdta.pro/images/9125b592411516d4d59b093d53ee41f7.jpg'),
(58910, 4009, 'Xena: A Princesa Guerreira S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/154077.mp4', 'http://timg.bdta.pro/images/8e002a5b62343d164a17d8711db3da73.jpg'),
(58911, 4009, 'Xena: A Princesa Guerreira S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/154078.mp4', 'http://timg.bdta.pro/images/40094f3adcba7dd2c76bfa792227a55d.jpg'),
(58912, 4009, 'Xena: A Princesa Guerreira S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/154079.mp4', 'http://timg.bdta.pro/images/9aa98f7534b0f3b9d9cc588f80abd2bd.jpg'),
(58913, 4009, 'Xena: A Princesa Guerreira S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/154080.mp4', 'http://timg.bdta.pro/images/742b4a54f229efeb2d0cba186aaa3e87.jpg'),
(58914, 4009, 'Xena: A Princesa Guerreira S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/154081.mp4', 'http://timg.bdta.pro/images/b0bc0656006b0f6a00a3bb5faafc2100.jpg'),
(58915, 4009, 'Xena: A Princesa Guerreira S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/154082.mp4', 'http://timg.bdta.pro/images/4e1e161de9e7d4b852ace6192b51a8af.jpg'),
(58916, 4009, 'Xena: A Princesa Guerreira S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/154083.mp4', 'http://timg.bdta.pro/images/48fee31a16c473455e5bd72c2d7fdfe4.jpg'),
(58917, 4009, 'Xena: A Princesa Guerreira S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/154084.mp4', 'http://timg.bdta.pro/images/e0a3864b3d8250a2b82c2cd28ac1907c.jpg'),
(58918, 4009, 'Xena: A Princesa Guerreira S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/154085.mp4', 'http://timg.bdta.pro/images/709985f87a24db88655c695e08a7e528.jpg'),
(58919, 4009, 'Xena: A Princesa Guerreira S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/154086.mp4', 'http://timg.bdta.pro/images/0cc463684f2ae901c967cda9494056c8.jpg'),
(58920, 4010, 'A Cozinheira de Castamar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153941.mp4', 'http://timg.bdta.pro/images/349ee8dec160a2e7d657611e2e08ae47.jpg'),
(58921, 4010, 'A Cozinheira de Castamar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153942.mp4', 'http://timg.bdta.pro/images/6bb526f97f79f6e1fe64ee6c9db95e74.jpg'),
(58922, 4010, 'A Cozinheira de Castamar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153943.mp4', 'http://timg.bdta.pro/images/29fecd27139b54671003b3969b1591e1.jpg'),
(58923, 4010, 'A Cozinheira de Castamar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153944.mp4', 'http://timg.bdta.pro/images/bb60980c0b59229c00d3424dc36f4901.jpg'),
(58924, 4010, 'A Cozinheira de Castamar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153945.mp4', 'http://timg.bdta.pro/images/c10086089b71d2e1d69a743968fd4c07.jpg'),
(58925, 4010, 'A Cozinheira de Castamar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153946.mp4', 'http://timg.bdta.pro/images/6035871ace8132e748c6d01e83959162.jpg'),
(58926, 4010, 'A Cozinheira de Castamar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153947.mp4', 'http://timg.bdta.pro/images/90c653e8ddd90d939c67631ce7008b30.jpg'),
(58927, 4010, 'A Cozinheira de Castamar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153948.mp4', 'http://timg.bdta.pro/images/d51ffe879eb9ebe92f06a3e1331e90b2.jpg'),
(58928, 4010, 'A Cozinheira de Castamar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153949.mp4', 'http://timg.bdta.pro/images/b8b53b45faaaa0f98b06df893f485145.jpg'),
(58929, 4010, 'A Cozinheira de Castamar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153950.mp4', 'http://timg.bdta.pro/images/064ca82ac62c2122517c929ea4ceaca2.jpg'),
(58930, 4010, 'A Cozinheira de Castamar S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153951.mp4', 'http://timg.bdta.pro/images/51072c24be7a8decd5bf1ef21f4c01b6.jpg'),
(58931, 4010, 'A Cozinheira de Castamar S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153952.mp4', 'http://timg.bdta.pro/images/14b2610a3283d0501eb2660e2fefcb05.jpg'),
(58932, 4011, 'A Vida Secreta dos Chimpanzés S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153935.mp4', 'http://timg.bdta.pro/images/c5fb7c49b48f237f62b0d4e1b7cd5c54.jpg'),
(58933, 4011, 'A Vida Secreta dos Chimpanzés S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153936.mp4', 'http://timg.bdta.pro/images/4acac24ffe9f2edd17203817f926e182.jpg'),
(58934, 4011, 'A Vida Secreta dos Chimpanzés S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153937.mp4', 'http://timg.bdta.pro/images/69282720d2085eb22f61c67023b7da71.jpg'),
(58935, 4011, 'A Vida Secreta dos Chimpanzés S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153938.mp4', 'http://timg.bdta.pro/images/f76febcbd3b9c047ca5ca3da8967e8c7.jpg'),
(58936, 4011, 'A Vida Secreta dos Chimpanzés S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153939.mp4', 'http://timg.bdta.pro/images/3be8ff9e9e7e5022b7e3f01ce870b106.jpg'),
(58937, 4011, 'A Vida Secreta dos Chimpanzés S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153940.mp4', 'http://timg.bdta.pro/images/1822afca9cbd9e8718be1f8223316b33.jpg'),
(58938, 4012, 'Adult Material S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153931.mp4', 'http://timg.bdta.pro/images/372f0aad9f8428b8478efd0acb06e46e.jpg'),
(58939, 4012, 'Adult Material S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153932.mp4', 'http://timg.bdta.pro/images/f64aff69b1e2635c539bbbfc7db8528d.jpg'),
(58940, 4012, 'Adult Material S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153933.mp4', 'http://timg.bdta.pro/images/961ca989822b3d61922f7719b4d693f1.jpg'),
(58941, 4012, 'Adult Material S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153934.mp4', 'http://timg.bdta.pro/images/ce65fa106d018c7b479e74dfc573b3ef.jpg'),
(58942, 4013, 'Aero Por Tras da Aviacao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153879.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58943, 4013, 'Aero Por Tras da Aviacao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153880.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58944, 4013, 'Aero Por Tras da Aviacao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153881.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58945, 4013, 'Aero Por Tras da Aviacao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153882.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58946, 4013, 'Aero Por Tras da Aviacao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153883.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58947, 4013, 'Aero Por Tras da Aviacao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153884.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58948, 4013, 'Aero Por Tras da Aviacao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153885.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58949, 4013, 'Aero Por Tras da Aviacao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153886.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58950, 4013, 'Aero Por Tras da Aviacao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153887.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58951, 4013, 'Aero Por Tras da Aviacao S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153888.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58952, 4013, 'Aero Por Tras da Aviacao S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153889.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58953, 4013, 'Aero Por Tras da Aviacao S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153890.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58954, 4013, 'Aero Por Tras da Aviacao S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153891.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58955, 4014, 'Aero Por Tras da Aviacao S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153892.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58956, 4014, 'Aero Por Tras da Aviacao S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153893.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58957, 4014, 'Aero Por Tras da Aviacao S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153894.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58958, 4014, 'Aero Por Tras da Aviacao S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153895.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58959, 4014, 'Aero Por Tras da Aviacao S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153896.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58960, 4014, 'Aero Por Tras da Aviacao S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153897.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58961, 4014, 'Aero Por Tras da Aviacao S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153898.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58962, 4014, 'Aero Por Tras da Aviacao S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153899.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58963, 4014, 'Aero Por Tras da Aviacao S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153900.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58964, 4014, 'Aero Por Tras da Aviacao S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153901.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58965, 4014, 'Aero Por Tras da Aviacao S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153902.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58966, 4014, 'Aero Por Tras da Aviacao S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153903.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58967, 4014, 'Aero Por Tras da Aviacao S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153904.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58968, 4015, 'Aero Por Tras da Aviacao S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153905.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58969, 4015, 'Aero Por Tras da Aviacao S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153906.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58970, 4015, 'Aero Por Tras da Aviacao S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153907.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58971, 4015, 'Aero Por Tras da Aviacao S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153908.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58972, 4015, 'Aero Por Tras da Aviacao S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153909.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58973, 4015, 'Aero Por Tras da Aviacao S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153910.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58974, 4015, 'Aero Por Tras da Aviacao S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153911.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58975, 4015, 'Aero Por Tras da Aviacao S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153912.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58976, 4015, 'Aero Por Tras da Aviacao S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153913.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58977, 4015, 'Aero Por Tras da Aviacao S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153914.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58978, 4015, 'Aero Por Tras da Aviacao S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153915.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58979, 4015, 'Aero Por Tras da Aviacao S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153916.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58980, 4015, 'Aero Por Tras da Aviacao S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153917.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58981, 4016, 'Aero Por Tras da Aviacao S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153918.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58982, 4016, 'Aero Por Tras da Aviacao S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153919.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58983, 4016, 'Aero Por Tras da Aviacao S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153920.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58984, 4016, 'Aero Por Tras da Aviacao S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153921.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58985, 4016, 'Aero Por Tras da Aviacao S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153922.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58986, 4016, 'Aero Por Tras da Aviacao S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153923.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58987, 4016, 'Aero Por Tras da Aviacao S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153924.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58988, 4016, 'Aero Por Tras da Aviacao S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153925.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58989, 4016, 'Aero Por Tras da Aviacao S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153926.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58990, 4016, 'Aero Por Tras da Aviacao S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153927.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58991, 4016, 'Aero Por Tras da Aviacao S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153928.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58992, 4016, 'Aero Por Tras da Aviacao S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153929.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58993, 4016, 'Aero Por Tras da Aviacao S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153930.mp4', 'http://gstaticontent.com/images/e19ed63cfd1c6fcf451cbca62db06486.jpg'),
(58994, 4017, 'Apenas Um Show S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153633.mp4', 'http://timg.bdta.pro/images/f2832a5963e7ca888683a103b17ad690.jpg'),
(58995, 4017, 'Apenas Um Show S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153634.mp4', 'http://timg.bdta.pro/images/d085e04b3a832b757812c1945e56af79.jpg'),
(58996, 4017, 'Apenas Um Show S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153635.mp4', 'http://timg.bdta.pro/images/d468e07f45bce0b94d0c92a2e423b78b.jpg'),
(58997, 4017, 'Apenas Um Show S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153636.mp4', 'http://timg.bdta.pro/images/5279448199caa4bae92ff03bd07e2975.jpg'),
(58998, 4017, 'Apenas Um Show S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153637.mp4', 'http://timg.bdta.pro/images/f3dd53de7abba19ec50691b71fc2b036.jpg'),
(58999, 4017, 'Apenas Um Show S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153638.mp4', 'http://timg.bdta.pro/images/d6564905e8da8cfbe9138f6be81e84ad.jpg'),
(59000, 4017, 'Apenas Um Show S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153639.mp4', 'http://timg.bdta.pro/images/369dd463a3606add8b4036b870b2457e.jpg'),
(59001, 4017, 'Apenas Um Show S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153640.mp4', 'http://timg.bdta.pro/images/9312aaca7f218b53a3d4f1d53aca04b5.jpg'),
(59002, 4017, 'Apenas Um Show S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153641.mp4', 'http://timg.bdta.pro/images/7bc56b5df6107dac9a19846e1391d6ca.jpg'),
(59003, 4017, 'Apenas Um Show S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153642.mp4', 'http://timg.bdta.pro/images/555cba27a7e1fde2b59d43086e50e4ad.jpg'),
(59004, 4017, 'Apenas Um Show S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153643.mp4', 'http://timg.bdta.pro/images/80f24f3105749bddd55e6fe99972519b.jpg'),
(59005, 4017, 'Apenas Um Show S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153644.mp4', 'http://timg.bdta.pro/images/8f62582f089dd8da5685d5d1b8a4052f.jpg'),
(59006, 4018, 'Apenas Um Show S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153645.mp4', 'http://timg.bdta.pro/images/dd38bc1e450b66418a6b3f18d9ec5abe.jpg'),
(59007, 4018, 'Apenas Um Show S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153646.mp4', 'http://timg.bdta.pro/images/abfd4f635379a393900aaea3d8181dd9.jpg'),
(59008, 4018, 'Apenas Um Show S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153647.mp4', 'http://timg.bdta.pro/images/27cc64c46f74369f295ccf77162a6b46.jpg'),
(59009, 4018, 'Apenas Um Show S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153648.mp4', 'http://timg.bdta.pro/images/1c812c48c078c234d6db4b9a7573a662.jpg'),
(59010, 4018, 'Apenas Um Show S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153649.mp4', 'http://timg.bdta.pro/images/306d73b1da5089a467b6cb078672f535.jpg'),
(59011, 4018, 'Apenas Um Show S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153650.mp4', 'http://timg.bdta.pro/images/10b567f1269ea4c093f57478f9f53149.jpg'),
(59012, 4018, 'Apenas Um Show S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153651.mp4', 'http://timg.bdta.pro/images/78f87f496e14af04b12cf8518af579d8.jpg'),
(59013, 4018, 'Apenas Um Show S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153652.mp4', 'http://timg.bdta.pro/images/94e38b70ae57501fc37fc296761bb5a5.jpg'),
(59014, 4018, 'Apenas Um Show S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153653.mp4', 'http://timg.bdta.pro/images/74b5bc450088cec94d7f243e262bc177.jpg'),
(59015, 4018, 'Apenas Um Show S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153654.mp4', 'http://timg.bdta.pro/images/8be3d7025408b5aa0854dc47998c4ee2.jpg'),
(59016, 4018, 'Apenas Um Show S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153655.mp4', 'http://timg.bdta.pro/images/f8c42ab77548c71f9e23f560d4f2cf29.jpg'),
(59017, 4018, 'Apenas Um Show S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153656.mp4', 'http://timg.bdta.pro/images/b3dda5bcb0ce7e1b58214ee144ceb52d.jpg'),
(59018, 4018, 'Apenas Um Show S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153657.mp4', 'http://timg.bdta.pro/images/cbb1d7c63571fe02e6fadb162b3267b4.jpg'),
(59019, 4018, 'Apenas Um Show S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153658.mp4', 'http://timg.bdta.pro/images/259702357877ff2b0387054c67f6c71f.jpg'),
(59020, 4018, 'Apenas Um Show S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153659.mp4', 'http://timg.bdta.pro/images/12f49fd3d06e98ac588de6e0a0329433.jpg'),
(59021, 4018, 'Apenas Um Show S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/153660.mp4', 'http://timg.bdta.pro/images/81100184e5349b3b42ceffb439abcdf8.jpg'),
(59022, 4018, 'Apenas Um Show S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/153661.mp4', 'http://timg.bdta.pro/images/1a0299ecebe37be36b45626061a50395.jpg'),
(59023, 4018, 'Apenas Um Show S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/153662.mp4', 'http://timg.bdta.pro/images/012fdf841a2687e44a0bbbcef3cd5228.jpg'),
(59024, 4018, 'Apenas Um Show S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/153663.mp4', 'http://timg.bdta.pro/images/c9b97910df03ad558e08eed9ed101938.jpg'),
(59025, 4018, 'Apenas Um Show S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/153664.mp4', 'http://timg.bdta.pro/images/bb1b7b7ef4995c768e5d3687acd40ac1.jpg'),
(59026, 4018, 'Apenas Um Show S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/153665.mp4', 'http://timg.bdta.pro/images/e628dae9750ba0819c7fc72c8c481a22.jpg'),
(59027, 4018, 'Apenas Um Show S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/153666.mp4', 'http://timg.bdta.pro/images/97fab2338988bf5d7189e1e7b1bf25f2.jpg'),
(59028, 4018, 'Apenas Um Show S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/153667.mp4', 'http://timg.bdta.pro/images/c1a373ab4adbc362f3f58ce4160630c3.jpg'),
(59029, 4018, 'Apenas Um Show S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/153668.mp4', 'http://timg.bdta.pro/images/7b3ddbe03795e544f2df1db053217979.jpg'),
(59030, 4018, 'Apenas Um Show S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/153669.mp4', 'http://timg.bdta.pro/images/ddd32117b57abae041b420feb759c36d.jpg'),
(59031, 4018, 'Apenas Um Show S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/153670.mp4', 'http://timg.bdta.pro/images/cb22e3658afec4653fea42d293f23bd0.jpg'),
(59032, 4018, 'Apenas Um Show S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/153671.mp4', 'http://timg.bdta.pro/images/fcbb3c1814c80e31d9ed8dfcc56e20fb.jpg'),
(59033, 4018, 'Apenas Um Show S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/153672.mp4', 'http://timg.bdta.pro/images/5504fa8161384acb3a1eea29d56b70d8.jpg'),
(59034, 4019, 'Apenas Um Show S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153673.mp4', 'http://timg.bdta.pro/images/4bb338ae3c9cbb33e0aaf624bad86a9e.jpg'),
(59035, 4019, 'Apenas Um Show S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153674.mp4', 'http://timg.bdta.pro/images/c9f38fb45f8bd2aa0a89daa56ebf6b64.jpg'),
(59036, 4019, 'Apenas Um Show S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153675.mp4', 'http://timg.bdta.pro/images/e70777cf0a89059f28a4595d473f3e6e.jpg'),
(59037, 4019, 'Apenas Um Show S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153676.mp4', 'http://timg.bdta.pro/images/0306336fd1bc7b861ebe4faa57c7cf96.jpg'),
(59038, 4019, 'Apenas Um Show S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153677.mp4', 'http://timg.bdta.pro/images/ca2c58931362934b161381bcbb065d0f.jpg'),
(59039, 4019, 'Apenas Um Show S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153678.mp4', 'http://timg.bdta.pro/images/878c338f7ffd478f2063d4e1aa720169.jpg'),
(59040, 4019, 'Apenas Um Show S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153679.mp4', 'http://timg.bdta.pro/images/7c31f516c52b3efc6556ab4a1bae9ac9.jpg'),
(59041, 4019, 'Apenas Um Show S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153680.mp4', 'http://timg.bdta.pro/images/af63edaca79188f9f7e3973c0d0da67d.jpg'),
(59042, 4019, 'Apenas Um Show S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153681.mp4', 'http://timg.bdta.pro/images/0951c20a42b23bee666d721c950956b5.jpg'),
(59043, 4019, 'Apenas Um Show S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153682.mp4', 'http://timg.bdta.pro/images/c7b2c59a3ad6b74a56c8e364ebad0e27.jpg'),
(59044, 4019, 'Apenas Um Show S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153683.mp4', 'http://timg.bdta.pro/images/cb1e586f27ef2e868d8c0c8849ed0272.jpg'),
(59045, 4019, 'Apenas Um Show S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153684.mp4', 'http://timg.bdta.pro/images/17014d391362fef37bc031c492920c1d.jpg'),
(59046, 4019, 'Apenas Um Show S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153685.mp4', 'http://timg.bdta.pro/images/e6122bd7cdb95547f421dbc0f4391741.jpg'),
(59047, 4019, 'Apenas Um Show S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153686.mp4', 'http://timg.bdta.pro/images/46b8317608354e9e58adb2978d04a337.jpg'),
(59048, 4019, 'Apenas Um Show S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153687.mp4', 'http://timg.bdta.pro/images/e113cde6473785eae6c0ac2eaad99ac4.jpg'),
(59049, 4019, 'Apenas Um Show S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/153688.mp4', 'http://timg.bdta.pro/images/12be347b8ec2599931c724d72dfcac96.jpg'),
(59050, 4019, 'Apenas Um Show S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/153689.mp4', 'http://timg.bdta.pro/images/52bc33d819ad5606fb5ae7d6bc3a362d.jpg'),
(59051, 4019, 'Apenas Um Show S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/153690.mp4', 'http://timg.bdta.pro/images/f0f3c8ae43548233e74e8a5140889a5c.jpg'),
(59052, 4019, 'Apenas Um Show S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/153691.mp4', 'http://timg.bdta.pro/images/2d85fee65b0ab8d5e2889191358da5c3.jpg'),
(59053, 4019, 'Apenas Um Show S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/153692.mp4', 'http://timg.bdta.pro/images/17f7954740014ab37146f33a8b99c01c.jpg'),
(59054, 4019, 'Apenas Um Show S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/153693.mp4', 'http://timg.bdta.pro/images/a7fa2ac6fe44e8057c21b0e6cc2d0df0.jpg'),
(59055, 4019, 'Apenas Um Show S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/153694.mp4', 'http://timg.bdta.pro/images/3dcba39d128330dc5579e078f814e1b9.jpg'),
(59056, 4019, 'Apenas Um Show S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/153695.mp4', 'http://timg.bdta.pro/images/15b9edb36120f82db3e6f56edd79c4cb.jpg'),
(59057, 4019, 'Apenas Um Show S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/153696.mp4', 'http://timg.bdta.pro/images/d07e2554b219bf82b5835e2ef9d20f26.jpg'),
(59058, 4019, 'Apenas Um Show S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/153697.mp4', 'http://timg.bdta.pro/images/1f9fbc26e126a769de558986fc3c6a03.jpg'),
(59059, 4019, 'Apenas Um Show S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/153698.mp4', 'http://timg.bdta.pro/images/de147e4397c5aec0f733287beef58adc.jpg'),
(59060, 4019, 'Apenas Um Show S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/153699.mp4', 'http://timg.bdta.pro/images/478ad3399d55eba51bf7bbdc59a9a70a.jpg'),
(59061, 4019, 'Apenas Um Show S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/153700.mp4', 'http://timg.bdta.pro/images/acc20cfe7cbfe53c303ae38ed41987b4.jpg'),
(59062, 4019, 'Apenas Um Show S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/153701.mp4', 'http://timg.bdta.pro/images/76824470ae0dccc96f61da4233419563.jpg'),
(59063, 4019, 'Apenas Um Show S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/153702.mp4', 'http://timg.bdta.pro/images/716b2888b40f1fb6e98d51d82d572296.jpg'),
(59064, 4019, 'Apenas Um Show S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/153703.mp4', 'http://timg.bdta.pro/images/ee449a3836de396dce978de5104bf431.jpg'),
(59065, 4019, 'Apenas Um Show S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/153704.mp4', 'http://timg.bdta.pro/images/d7bc22134421c422bd2a0e7be5b3e10f.jpg'),
(59066, 4019, 'Apenas Um Show S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/153705.mp4', 'http://timg.bdta.pro/images/b51dc45fa81c0ceffbd676097529d372.jpg'),
(59067, 4019, 'Apenas Um Show S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/153706.mp4', 'http://timg.bdta.pro/images/905dca2721c0c9254a7de5fe866e568a.jpg'),
(59068, 4019, 'Apenas Um Show S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/153707.mp4', 'http://timg.bdta.pro/images/d68321d9e78776883dad5c5859fb16c5.jpg'),
(59069, 4019, 'Apenas Um Show S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/153708.mp4', 'http://timg.bdta.pro/images/bfaa717b7e3d8e9c33edf6613d2eee76.jpg'),
(59070, 4019, 'Apenas Um Show S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/153709.mp4', 'http://timg.bdta.pro/images/5e3ed8027a3e47112c480b5eec13ed8d.jpg'),
(59071, 4019, 'Apenas Um Show S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/153710.mp4', 'http://timg.bdta.pro/images/c191ec820ce1a7b4603464a1261171cc.jpg'),
(59072, 4019, 'Apenas Um Show S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/153711.mp4', 'http://timg.bdta.pro/images/efd53d24a7ced1d38f891ae0563a0e93.jpg'),
(59073, 4020, 'Apenas Um Show S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153712.mp4', 'http://timg.bdta.pro/images/e935706c01e34bf06ed83f4c7e4518f5.jpg'),
(59074, 4020, 'Apenas Um Show S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153713.mp4', 'http://timg.bdta.pro/images/9beaf4d259544d9c20417a954fc35105.jpg'),
(59075, 4020, 'Apenas Um Show S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153714.mp4', 'http://timg.bdta.pro/images/dd6367dff1a2de27b02ce5045491562b.jpg'),
(59076, 4020, 'Apenas Um Show S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153715.mp4', 'http://timg.bdta.pro/images/3cc26b2fa38f9df9e11502fb44c234e5.jpg'),
(59077, 4020, 'Apenas Um Show S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153716.mp4', 'http://gstaticontent.com/images/2de85532133f09d0d95aa11b699ca53c.jpg'),
(59078, 4020, 'Apenas Um Show S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153717.mp4', 'http://timg.bdta.pro/images/e7cf15243c36273c5014aa4e88af9f5f.jpg'),
(59079, 4020, 'Apenas Um Show S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153718.mp4', 'http://timg.bdta.pro/images/f7ae46e0c5aad8cc3d2c0e8900327082.jpg'),
(59080, 4020, 'Apenas Um Show S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153719.mp4', 'http://timg.bdta.pro/images/57d2b91bc14fe85164d292ebb30ac8ee.jpg'),
(59081, 4020, 'Apenas Um Show S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153720.mp4', 'http://timg.bdta.pro/images/cdde75a75b67f3b26d74621ee2b939ba.jpg'),
(59082, 4020, 'Apenas Um Show S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153721.mp4', 'http://timg.bdta.pro/images/0a6f6e9c5d2cd23edc8d1f15b6b7b17c.jpg'),
(59083, 4020, 'Apenas Um Show S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153722.mp4', 'http://gstaticontent.com/images/2de85532133f09d0d95aa11b699ca53c.jpg'),
(59084, 4020, 'Apenas Um Show S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153723.mp4', 'http://timg.bdta.pro/images/e4f9d474bc1909b97161e2c883631ec5.jpg'),
(59085, 4020, 'Apenas Um Show S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153724.mp4', 'http://timg.bdta.pro/images/1df123b517508027831a056b593a0302.jpg'),
(59086, 4020, 'Apenas Um Show S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153725.mp4', 'http://timg.bdta.pro/images/8806af7a256f14183071ecaeeb4a0447.jpg'),
(59087, 4020, 'Apenas Um Show S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153726.mp4', 'http://timg.bdta.pro/images/d3044f7dcaa4c464494dca15dadd5018.jpg'),
(59088, 4020, 'Apenas Um Show S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/153727.mp4', 'http://timg.bdta.pro/images/01c09788a6719768223deee746942086.jpg'),
(59089, 4020, 'Apenas Um Show S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/153728.mp4', 'http://timg.bdta.pro/images/44524e6d8e252f702c436c15002e7e84.jpg'),
(59090, 4020, 'Apenas Um Show S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/153729.mp4', 'http://timg.bdta.pro/images/8e21749d4138e47dc60e140d171eda58.jpg'),
(59091, 4020, 'Apenas Um Show S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/153730.mp4', 'http://timg.bdta.pro/images/7b2914cd6c49364d26a1563efa53f623.jpg'),
(59092, 4020, 'Apenas Um Show S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/153731.mp4', 'http://timg.bdta.pro/images/a561bca4e4a722a0d549f82d87624f01.jpg'),
(59093, 4020, 'Apenas Um Show S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/153732.mp4', 'http://timg.bdta.pro/images/6120e42443f50216b903b887efb603cc.jpg'),
(59094, 4020, 'Apenas Um Show S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/153733.mp4', 'http://timg.bdta.pro/images/51cf7621ae78547ff1756acc98ea10ab.jpg'),
(59095, 4020, 'Apenas Um Show S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/153734.mp4', 'http://timg.bdta.pro/images/e3c8264f6557fd9154a0fd0c1cc8fb17.jpg'),
(59096, 4020, 'Apenas Um Show S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/153735.mp4', 'http://timg.bdta.pro/images/854ef7d1c4e3a923026e04d8af0ff513.jpg'),
(59097, 4020, 'Apenas Um Show S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/153736.mp4', 'http://timg.bdta.pro/images/464f6ac9f1b779242b0bddf1fb19c2fa.jpg'),
(59098, 4020, 'Apenas Um Show S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/153737.mp4', 'http://timg.bdta.pro/images/3f4580f8b5581f555fdd51d04b1b5443.jpg'),
(59099, 4020, 'Apenas Um Show S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/153738.mp4', 'http://timg.bdta.pro/images/e90252e64f3041f99d64651b286da767.jpg'),
(59100, 4020, 'Apenas Um Show S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/153739.mp4', 'http://timg.bdta.pro/images/d027aacd8fff96f46dd6d8bc1ef60036.jpg'),
(59101, 4020, 'Apenas Um Show S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/153740.mp4', 'http://timg.bdta.pro/images/7446b664d18a5079e7617afde1aa7da5.jpg'),
(59102, 4020, 'Apenas Um Show S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/153741.mp4', 'http://timg.bdta.pro/images/1a9d01c4bc2f22b3e4dcfab6c692216e.jpg'),
(59103, 4020, 'Apenas Um Show S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/153742.mp4', 'http://timg.bdta.pro/images/da085e0969fafb34716d788aabf2b044.jpg'),
(59104, 4020, 'Apenas Um Show S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/153743.mp4', 'http://timg.bdta.pro/images/02818b5c8cd4bbca027bbec0ceb6cd4b.jpg'),
(59105, 4020, 'Apenas Um Show S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/153744.mp4', 'http://timg.bdta.pro/images/9ce4e7637c1edf89ff003f07ac915b2d.jpg'),
(59106, 4020, 'Apenas Um Show S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/153745.mp4', 'http://timg.bdta.pro/images/993ac7c8b70f635e494a635b375483f1.jpg'),
(59107, 4020, 'Apenas Um Show S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/153746.mp4', 'http://timg.bdta.pro/images/e4804c25b4343a3f0597950fa9225287.jpg'),
(59108, 4020, 'Apenas Um Show S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/153747.mp4', 'http://timg.bdta.pro/images/804fcbc4c5a1f921a42e57494faf51b2.jpg'),
(59109, 4020, 'Apenas Um Show S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/153748.mp4', 'http://timg.bdta.pro/images/778f68937026432b34f36a4e87619395.jpg'),
(59110, 4021, 'Apenas Um Show S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153749.mp4', 'http://timg.bdta.pro/images/864c08fe944d585cf72157b5e58f801d.jpg'),
(59111, 4021, 'Apenas Um Show S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153750.mp4', 'http://timg.bdta.pro/images/ced4b8488511eabb639f2b86786204b9.jpg'),
(59112, 4021, 'Apenas Um Show S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153751.mp4', 'http://timg.bdta.pro/images/be24bf4cd6d95d83f908806ca8756324.jpg'),
(59113, 4021, 'Apenas Um Show S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153752.mp4', 'http://timg.bdta.pro/images/4ff155a5d3944d9ceb7126dae91b6f18.jpg'),
(59114, 4021, 'Apenas Um Show S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153753.mp4', 'http://timg.bdta.pro/images/b3b5201563b0e68e6b180764cfeb6fb5.jpg'),
(59115, 4021, 'Apenas Um Show S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153754.mp4', 'http://timg.bdta.pro/images/a02ec522deaf9d03f1c2272c2ec29379.jpg'),
(59116, 4021, 'Apenas Um Show S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153755.mp4', 'http://timg.bdta.pro/images/3f7bccd4a89f571a27c6aa00fdb0863d.jpg'),
(59117, 4021, 'Apenas Um Show S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153756.mp4', 'http://timg.bdta.pro/images/77ab1d32b047131d969a76078d4c2d9e.jpg'),
(59118, 4021, 'Apenas Um Show S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153757.mp4', 'http://timg.bdta.pro/images/7dfc7ce28007245546db4ca67abf264f.jpg'),
(59119, 4021, 'Apenas Um Show S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153758.mp4', 'http://timg.bdta.pro/images/add1ffdb3f37dff6ae5f5f8b77eab797.jpg'),
(59120, 4021, 'Apenas Um Show S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153759.mp4', 'http://timg.bdta.pro/images/6bcfc2256fb738bd8c950afc7d5f9b24.jpg'),
(59121, 4021, 'Apenas Um Show S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153760.mp4', 'http://timg.bdta.pro/images/666b54922adfb6b4d8a1b3ade31a5beb.jpg'),
(59122, 4021, 'Apenas Um Show S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153761.mp4', 'http://timg.bdta.pro/images/6791d6fe20086973e6c1b61b7c221a89.jpg'),
(59123, 4021, 'Apenas Um Show S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153762.mp4', 'http://timg.bdta.pro/images/a9a2da8319adbb4428a4b27e72599275.jpg'),
(59124, 4021, 'Apenas Um Show S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153763.mp4', 'http://timg.bdta.pro/images/a3fddda5f82cc42cef19f4ebfadfb6b6.jpg'),
(59125, 4021, 'Apenas Um Show S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/153764.mp4', 'http://timg.bdta.pro/images/e627663f20e9fa00f7916dcdbf25a967.jpg'),
(59126, 4021, 'Apenas Um Show S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/153765.mp4', 'http://timg.bdta.pro/images/61b9dcd0053bfb85a2d21f0c8d09bbfa.jpg'),
(59127, 4021, 'Apenas Um Show S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/153766.mp4', 'http://timg.bdta.pro/images/b27c8215d6066bd78e2f01eb9b1bf1bd.jpg'),
(59128, 4021, 'Apenas Um Show S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/153767.mp4', 'http://timg.bdta.pro/images/4c3aa41db35326732c13dd22c4e28a21.jpg'),
(59129, 4021, 'Apenas Um Show S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/153768.mp4', 'http://timg.bdta.pro/images/46a6461c23a90b061f44c47404a21b6c.jpg'),
(59130, 4021, 'Apenas Um Show S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/153769.mp4', 'http://timg.bdta.pro/images/3d16f84ad8824fa16a005871a7bad9b1.jpg'),
(59131, 4021, 'Apenas Um Show S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/153770.mp4', 'http://timg.bdta.pro/images/5354e9b70044785b09ae14e4edb8b5e9.jpg'),
(59132, 4021, 'Apenas Um Show S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/153771.mp4', 'http://timg.bdta.pro/images/1459654b9263e9d4595c8a3f37f70f0d.jpg'),
(59133, 4021, 'Apenas Um Show S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/153772.mp4', 'http://timg.bdta.pro/images/cc3613359885f12a5aab7b63d256e7bd.jpg'),
(59134, 4021, 'Apenas Um Show S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/153773.mp4', 'http://timg.bdta.pro/images/d0ce828c8bff8983695925ca2cdcc3e9.jpg'),
(59135, 4021, 'Apenas Um Show S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/153774.mp4', 'http://timg.bdta.pro/images/bf3e1d55caf4f52bb6592125efcf9557.jpg'),
(59136, 4021, 'Apenas Um Show S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/153775.mp4', 'http://timg.bdta.pro/images/e8e4c90eb002831be5ef436a8b64f2bb.jpg'),
(59137, 4021, 'Apenas Um Show S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/153776.mp4', 'http://timg.bdta.pro/images/00b5f8eea657b789c654bf1a46654ad8.jpg'),
(59138, 4021, 'Apenas Um Show S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/153777.mp4', 'http://timg.bdta.pro/images/c8ffd244b8a143f8ff8494af0d53e50e.jpg'),
(59139, 4021, 'Apenas Um Show S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/153778.mp4', 'http://timg.bdta.pro/images/489f378e998e7d474de7f964c33775b8.jpg'),
(59140, 4021, 'Apenas Um Show S05 E31', 'http://sinalprivado.info:80/series/1533784/1533784/153779.mp4', 'http://timg.bdta.pro/images/af93af78a39335b5d7a6ac33171236f4.jpg'),
(59141, 4021, 'Apenas Um Show S05 E32', 'http://sinalprivado.info:80/series/1533784/1533784/153780.mp4', 'http://timg.bdta.pro/images/076dc5fc4db4a5f13a06ee5bf082f4e9.jpg'),
(59142, 4021, 'Apenas Um Show S05 E33', 'http://sinalprivado.info:80/series/1533784/1533784/153781.mp4', 'http://timg.bdta.pro/images/bbf6ba207189241b10d7d37a623df350.jpg'),
(59143, 4021, 'Apenas Um Show S05 E34', 'http://sinalprivado.info:80/series/1533784/1533784/153782.mp4', 'http://timg.bdta.pro/images/fb3b940e51d0f25a156d933aabf613d0.jpg'),
(59144, 4021, 'Apenas Um Show S05 E35', 'http://sinalprivado.info:80/series/1533784/1533784/153783.mp4', 'http://timg.bdta.pro/images/3c7c08fcde6234a066d7293309488bc5.jpg'),
(59145, 4021, 'Apenas Um Show S05 E36', 'http://sinalprivado.info:80/series/1533784/1533784/153784.mp4', 'http://timg.bdta.pro/images/5b54f5089309affbc3f60ad32feac779.jpg'),
(59146, 4021, 'Apenas Um Show S05 E37', 'http://sinalprivado.info:80/series/1533784/1533784/153785.mp4', 'http://timg.bdta.pro/images/0074045ecc7bcf32db7b67f976b412a7.jpg'),
(59147, 4022, 'Apenas Um Show S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153786.mp4', 'http://timg.bdta.pro/images/04c54570a70d7ba6b9358037674331f8.jpg'),
(59148, 4022, 'Apenas Um Show S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153787.mp4', 'http://timg.bdta.pro/images/a76bedb035d309cf124d2e42eef5c514.jpg'),
(59149, 4022, 'Apenas Um Show S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153788.mp4', 'http://timg.bdta.pro/images/d22843f16b9885da3a4046ab7dc751cc.jpg'),
(59150, 4022, 'Apenas Um Show S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153789.mp4', 'http://timg.bdta.pro/images/3eb21e8364a9ea6afe637e9a44829f19.jpg'),
(59151, 4022, 'Apenas Um Show S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153790.mp4', 'http://timg.bdta.pro/images/98a9bf5f90cfa12b29d55d701990ccbe.jpg'),
(59152, 4022, 'Apenas Um Show S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153791.mp4', 'http://timg.bdta.pro/images/057283c739b3e225c2f058beee54d4ae.jpg'),
(59153, 4022, 'Apenas Um Show S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153792.mp4', 'http://timg.bdta.pro/images/054d511b6fbf00e6c0331d2c614f6b1f.jpg'),
(59154, 4022, 'Apenas Um Show S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153793.mp4', 'http://timg.bdta.pro/images/623e56d14d4e98d2410dc3581eaa1bec.jpg'),
(59155, 4022, 'Apenas Um Show S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153794.mp4', 'http://timg.bdta.pro/images/9528dfaeaccf45586380c3cb46e0ff33.jpg'),
(59156, 4022, 'Apenas Um Show S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153795.mp4', 'http://timg.bdta.pro/images/4509c21c0e963761ea93a5bec41e5d9a.jpg'),
(59157, 4022, 'Apenas Um Show S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153796.mp4', 'http://timg.bdta.pro/images/d344b9c3ec2deb15de5b1812f205c732.jpg'),
(59158, 4022, 'Apenas Um Show S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153797.mp4', 'http://timg.bdta.pro/images/9b04513bdb4fc246d79b0a9f9e9c8dae.jpg'),
(59159, 4022, 'Apenas Um Show S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153798.mp4', 'http://timg.bdta.pro/images/e60e334a47f64e18026e9653816ebd7b.jpg'),
(59160, 4022, 'Apenas Um Show S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153799.mp4', 'http://timg.bdta.pro/images/28fc6f14ce109f6296ce4d8a664ba61e.jpg'),
(59161, 4022, 'Apenas Um Show S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153800.mp4', 'http://timg.bdta.pro/images/edeab7c1e3d633a61893847e9bcd7210.jpg'),
(59162, 4022, 'Apenas Um Show S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/153801.mp4', 'http://timg.bdta.pro/images/8d9f37e080b1d441050313e54fbe637c.jpg'),
(59163, 4022, 'Apenas Um Show S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/153802.mp4', 'http://timg.bdta.pro/images/10611da606e8a0f349646234b4939153.jpg'),
(59164, 4022, 'Apenas Um Show S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/153803.mp4', 'http://timg.bdta.pro/images/20d155fdb7a8265ecd42811424999a09.jpg'),
(59165, 4022, 'Apenas Um Show S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/153804.mp4', 'http://timg.bdta.pro/images/20a1d5c82d1451cc5b62d7478af65051.jpg'),
(59166, 4022, 'Apenas Um Show S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/153805.mp4', 'http://timg.bdta.pro/images/821bea6e0ffa500edf14a319676a4486.jpg'),
(59167, 4022, 'Apenas Um Show S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/153806.mp4', 'http://timg.bdta.pro/images/b77cfda35865a09daff31d0af3b38821.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(59168, 4022, 'Apenas Um Show S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/153807.mp4', 'http://timg.bdta.pro/images/3045566f568348f6f837eb3a538d85f2.jpg'),
(59169, 4022, 'Apenas Um Show S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/153808.mp4', 'http://timg.bdta.pro/images/94bc5aeb55df3153017d495cc9df42eb.jpg'),
(59170, 4022, 'Apenas Um Show S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/153809.mp4', 'http://timg.bdta.pro/images/62aaf0f6be23e0189542478a04e1ac02.jpg'),
(59171, 4022, 'Apenas Um Show S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/153810.mp4', 'http://timg.bdta.pro/images/04d9ebd1540dfa4499f2839594961a6b.jpg'),
(59172, 4022, 'Apenas Um Show S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/153811.mp4', 'http://timg.bdta.pro/images/9c160262da14165bea290ad8d33c23ee.jpg'),
(59173, 4022, 'Apenas Um Show S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/153812.mp4', 'http://timg.bdta.pro/images/cd100cfca0ec5ca76424c036cdc65200.jpg'),
(59174, 4022, 'Apenas Um Show S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/153813.mp4', 'http://timg.bdta.pro/images/d3f4cde9d3609411fa14fea6f1a0f57c.jpg'),
(59175, 4023, 'Apenas Um Show S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153814.mp4', 'http://timg.bdta.pro/images/74bdf34b8695115457752cfe03d4adb4.jpg'),
(59176, 4023, 'Apenas Um Show S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153815.mp4', 'http://timg.bdta.pro/images/19acff827ad7276808107d27889a728d.jpg'),
(59177, 4023, 'Apenas Um Show S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153816.mp4', 'http://timg.bdta.pro/images/5497a8e774c0f7086d826300fe17028d.jpg'),
(59178, 4023, 'Apenas Um Show S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153817.mp4', 'http://timg.bdta.pro/images/1f2e21c337b7876d8af5dbd824f7b37d.jpg'),
(59179, 4023, 'Apenas Um Show S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153818.mp4', 'http://timg.bdta.pro/images/ed64f5952bd61b7a55e1e81f1fca7c57.jpg'),
(59180, 4023, 'Apenas Um Show S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153819.mp4', 'http://timg.bdta.pro/images/a8a5ef5378d1fd5cca4d2ba2b20aa545.jpg'),
(59181, 4023, 'Apenas Um Show S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153820.mp4', 'http://timg.bdta.pro/images/5ab1a3962643bc1e416c217c5a1b673f.jpg'),
(59182, 4023, 'Apenas Um Show S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153821.mp4', 'http://timg.bdta.pro/images/c75063a91422b72b7ea2fa44fe9b1bc2.jpg'),
(59183, 4023, 'Apenas Um Show S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153822.mp4', 'http://timg.bdta.pro/images/ab7db6bcac9b0aa62e320ab9d6739e90.jpg'),
(59184, 4023, 'Apenas Um Show S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153823.mp4', 'http://timg.bdta.pro/images/643eb185cfdb80dc52b68ea865533735.jpg'),
(59185, 4023, 'Apenas Um Show S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153824.mp4', 'http://timg.bdta.pro/images/32b85baf1dba52e04bd4530cd57ba859.jpg'),
(59186, 4023, 'Apenas Um Show S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153825.mp4', 'http://timg.bdta.pro/images/100dd0b2c6f9569cb651f76dc9a94736.jpg'),
(59187, 4023, 'Apenas Um Show S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153826.mp4', 'http://timg.bdta.pro/images/19b58ea550692d8926c68b931c699e0a.jpg'),
(59188, 4023, 'Apenas Um Show S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153827.mp4', 'http://timg.bdta.pro/images/c219369191a81c259e9e2f3af2746b49.jpg'),
(59189, 4023, 'Apenas Um Show S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153828.mp4', 'http://timg.bdta.pro/images/94331fa8dd9c4af05fa6a49088f32b8a.jpg'),
(59190, 4023, 'Apenas Um Show S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/153829.mp4', 'http://timg.bdta.pro/images/b46865c05b5e5ab35e6b2329a37014f8.jpg'),
(59191, 4023, 'Apenas Um Show S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/153830.mp4', 'http://timg.bdta.pro/images/821637d3d8b7be6e43a65e5448fa8e4e.jpg'),
(59192, 4023, 'Apenas Um Show S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/153831.mp4', 'http://timg.bdta.pro/images/a1bf43d70e897622c6eb07506c9c7ce5.jpg'),
(59193, 4023, 'Apenas Um Show S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/153832.mp4', 'http://timg.bdta.pro/images/cb82c094c15fdcd53d5c35a930f35486.jpg'),
(59194, 4023, 'Apenas Um Show S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/153833.mp4', 'http://timg.bdta.pro/images/0da96cdc651d213e650039848f4d6b0f.jpg'),
(59195, 4023, 'Apenas Um Show S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/153834.mp4', 'http://timg.bdta.pro/images/b5f30a894ecbcbb0ca6ba110e6329733.jpg'),
(59196, 4023, 'Apenas Um Show S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/153835.mp4', 'http://timg.bdta.pro/images/1c27d7de450adc288f00f1776a5f9d24.jpg'),
(59197, 4023, 'Apenas Um Show S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/153836.mp4', 'http://timg.bdta.pro/images/148ac2388a3e762b8bd76b92e139fb8f.jpg'),
(59198, 4023, 'Apenas Um Show S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/153837.mp4', 'http://timg.bdta.pro/images/2b3768efa1f037e97543b895e7f0821b.jpg'),
(59199, 4023, 'Apenas Um Show S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/153838.mp4', 'http://timg.bdta.pro/images/1d18ef2fbe4b78aa84c68beebe6c275f.jpg'),
(59200, 4023, 'Apenas Um Show S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/153839.mp4', 'http://timg.bdta.pro/images/a64bdff89390b68c572023ff6f2f9d5a.jpg'),
(59201, 4023, 'Apenas Um Show S07 E27', 'http://sinalprivado.info:80/series/1533784/1533784/153840.mp4', 'http://timg.bdta.pro/images/83a1ecd15af20070b002a9630e4cdb16.jpg'),
(59202, 4023, 'Apenas Um Show S07 E28', 'http://sinalprivado.info:80/series/1533784/1533784/153841.mp4', 'http://timg.bdta.pro/images/3931f1b1f5974d9b2c1cbb2beb74accf.jpg'),
(59203, 4023, 'Apenas Um Show S07 E29', 'http://sinalprivado.info:80/series/1533784/1533784/153842.mp4', 'http://timg.bdta.pro/images/967ecb1377af1b40be31f5c5911c5968.jpg'),
(59204, 4023, 'Apenas Um Show S07 E30', 'http://sinalprivado.info:80/series/1533784/1533784/153843.mp4', 'http://timg.bdta.pro/images/84cd14569538d73ca8367cdbaf95edba.jpg'),
(59205, 4023, 'Apenas Um Show S07 E31', 'http://sinalprivado.info:80/series/1533784/1533784/153844.mp4', 'http://timg.bdta.pro/images/a261d990ae133bd51b336e95df3b2e63.jpg'),
(59206, 4023, 'Apenas Um Show S07 E32', 'http://sinalprivado.info:80/series/1533784/1533784/153845.mp4', 'http://timg.bdta.pro/images/7d9e5958e923f4e0f9e77c4dafd0b8ca.jpg'),
(59207, 4023, 'Apenas Um Show S07 E33', 'http://sinalprivado.info:80/series/1533784/1533784/153846.mp4', 'http://timg.bdta.pro/images/559f74a213277617a98286be60b6d1b3.jpg'),
(59208, 4023, 'Apenas Um Show S07 E34', 'http://sinalprivado.info:80/series/1533784/1533784/153847.mp4', 'http://timg.bdta.pro/images/2553c4e24fd40ef7deec7008928e0ce0.jpg'),
(59209, 4023, 'Apenas Um Show S07 E35', 'http://sinalprivado.info:80/series/1533784/1533784/153848.mp4', 'http://timg.bdta.pro/images/4f09b0a919911efb66b591adf7378f93.jpg'),
(59210, 4023, 'Apenas Um Show S07 E36', 'http://sinalprivado.info:80/series/1533784/1533784/153849.mp4', 'http://timg.bdta.pro/images/dd8f472aafc4c6b368c22eaa0f1bb421.jpg'),
(59211, 4024, 'Apenas Um Show S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153850.mp4', 'http://timg.bdta.pro/images/48f61e168e05b5e931f4f42d663c5e2a.jpg'),
(59212, 4024, 'Apenas Um Show S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153851.mp4', 'http://timg.bdta.pro/images/b2e3744661d3346ece2c0f6c9b998937.jpg'),
(59213, 4024, 'Apenas Um Show S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153852.mp4', 'http://timg.bdta.pro/images/53a03f36777a2a0b27264da581885b08.jpg'),
(59214, 4024, 'Apenas Um Show S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153853.mp4', 'http://timg.bdta.pro/images/8248d47ed98422f65b585557c9a7c6aa.jpg'),
(59215, 4024, 'Apenas Um Show S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153854.mp4', 'http://timg.bdta.pro/images/9857b97eaefe0f25749279afbdb95915.jpg'),
(59216, 4024, 'Apenas Um Show S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153855.mp4', 'http://timg.bdta.pro/images/03816f43b472322c19bc32e8bf0cef58.jpg'),
(59217, 4024, 'Apenas Um Show S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153856.mp4', 'http://timg.bdta.pro/images/ecaecc4dc989894cebf252d1bcbf3732.jpg'),
(59218, 4024, 'Apenas Um Show S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153857.mp4', 'http://timg.bdta.pro/images/af414941de08dedfa5b2abf58fa7e6c7.jpg'),
(59219, 4024, 'Apenas Um Show S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153858.mp4', 'http://timg.bdta.pro/images/9552d995ca3374425e2f335e99996b0e.jpg'),
(59220, 4024, 'Apenas Um Show S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153859.mp4', 'http://timg.bdta.pro/images/b32dd2c14db5d79395f95ecd39dbe767.jpg'),
(59221, 4024, 'Apenas Um Show S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153860.mp4', 'http://timg.bdta.pro/images/8dc4980549d9b98d713385162926f57b.jpg'),
(59222, 4024, 'Apenas Um Show S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153861.mp4', 'http://timg.bdta.pro/images/de07bd07052804d4127cba510d6eb630.jpg'),
(59223, 4024, 'Apenas Um Show S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153862.mp4', 'http://timg.bdta.pro/images/9b5af72be95da8f06d8236232bb90d29.jpg'),
(59224, 4024, 'Apenas Um Show S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153863.mp4', 'http://timg.bdta.pro/images/c14d4b6373a89c19bf8ca7dd538a8224.jpg'),
(59225, 4024, 'Apenas Um Show S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153864.mp4', 'http://timg.bdta.pro/images/4e082c2a082775523b5567bec9560a70.jpg'),
(59226, 4024, 'Apenas Um Show S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/153865.mp4', 'http://timg.bdta.pro/images/52209b61993d4a7f0df46da3a32a9a2c.jpg'),
(59227, 4024, 'Apenas Um Show S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/153866.mp4', 'http://timg.bdta.pro/images/b60746a3e4b4d85280b34e570e300df8.jpg'),
(59228, 4024, 'Apenas Um Show S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/153867.mp4', 'http://timg.bdta.pro/images/759d361c38b0d5aa80c5f64803d313b8.jpg'),
(59229, 4024, 'Apenas Um Show S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/153868.mp4', 'http://timg.bdta.pro/images/1997a18f3acaee4dd23b5ea103969c47.jpg'),
(59230, 4024, 'Apenas Um Show S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/153869.mp4', 'http://timg.bdta.pro/images/19007398bb09e5be6526c6b2c04de33b.jpg'),
(59231, 4024, 'Apenas Um Show S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/153870.mp4', 'http://timg.bdta.pro/images/d17a063168663d0f4fa01dc32ba0237c.jpg'),
(59232, 4024, 'Apenas Um Show S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/153871.mp4', 'http://timg.bdta.pro/images/f7f62ad0013d0542f9fe3f1907e938db.jpg'),
(59233, 4024, 'Apenas Um Show S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/153872.mp4', 'http://timg.bdta.pro/images/9f78dc9e6c0101f2a35e41dffedc59aa.jpg'),
(59234, 4024, 'Apenas Um Show S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/153873.mp4', 'http://timg.bdta.pro/images/9a0c15561738ddcace82a9f2252777b9.jpg'),
(59235, 4024, 'Apenas Um Show S08 E25', 'http://sinalprivado.info:80/series/1533784/1533784/153874.mp4', 'http://timg.bdta.pro/images/23ac43f9bd575cfeaf1da382f9549b26.jpg'),
(59236, 4024, 'Apenas Um Show S08 E26', 'http://sinalprivado.info:80/series/1533784/1533784/153875.mp4', 'http://timg.bdta.pro/images/898d3d957eeea9ce740e91b7704f6b00.jpg'),
(59237, 4024, 'Apenas Um Show S08 E27', 'http://sinalprivado.info:80/series/1533784/1533784/153876.mp4', 'http://timg.bdta.pro/images/8d93b0df802c248b8b8d493b6d887b5c.jpg'),
(59238, 4024, 'Apenas Um Show S08 E28', 'http://sinalprivado.info:80/series/1533784/1533784/153877.mp4', 'http://timg.bdta.pro/images/4b8e17fb3ec9ac6d6d7571be2915ece7.jpg'),
(59239, 4024, 'Apenas Um Show S08 E29', 'http://sinalprivado.info:80/series/1533784/1533784/153878.mp4', 'http://timg.bdta.pro/images/95b1de46f7b08c49e00c23f8a052f3ed.jpg'),
(59240, 4025, 'Beethoven S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153620.mp4', 'http://gstaticontent.com/images/f5a62e1321d13f2f3d4b5e6f82e9286a.jpg'),
(59241, 4025, 'Beethoven S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153621.mp4', 'http://gstaticontent.com/images/f5a62e1321d13f2f3d4b5e6f82e9286a.jpg'),
(59242, 4025, 'Beethoven S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153622.mp4', 'http://gstaticontent.com/images/f5a62e1321d13f2f3d4b5e6f82e9286a.jpg'),
(59243, 4025, 'Beethoven S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153623.mp4', 'http://gstaticontent.com/images/f5a62e1321d13f2f3d4b5e6f82e9286a.jpg'),
(59244, 4025, 'Beethoven S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153624.mp4', 'http://gstaticontent.com/images/f5a62e1321d13f2f3d4b5e6f82e9286a.jpg'),
(59245, 4025, 'Beethoven S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153625.mp4', 'http://gstaticontent.com/images/f5a62e1321d13f2f3d4b5e6f82e9286a.jpg'),
(59246, 4025, 'Beethoven S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153626.mp4', 'http://gstaticontent.com/images/f5a62e1321d13f2f3d4b5e6f82e9286a.jpg'),
(59247, 4025, 'Beethoven S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153627.mp4', 'http://gstaticontent.com/images/f5a62e1321d13f2f3d4b5e6f82e9286a.jpg'),
(59248, 4025, 'Beethoven S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153628.mp4', 'http://gstaticontent.com/images/f5a62e1321d13f2f3d4b5e6f82e9286a.jpg'),
(59249, 4025, 'Beethoven S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153629.mp4', 'http://gstaticontent.com/images/f5a62e1321d13f2f3d4b5e6f82e9286a.jpg'),
(59250, 4025, 'Beethoven S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153630.mp4', 'http://gstaticontent.com/images/f5a62e1321d13f2f3d4b5e6f82e9286a.jpg'),
(59251, 4025, 'Beethoven S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153631.mp4', 'http://gstaticontent.com/images/f5a62e1321d13f2f3d4b5e6f82e9286a.jpg'),
(59252, 4025, 'Beethoven S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153632.mp4', 'http://gstaticontent.com/images/f5a62e1321d13f2f3d4b5e6f82e9286a.jpg'),
(59253, 4026, 'Chad S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153612.mp4', 'http://timg.bdta.pro/images/8d131980efc31cf3277542deebea614e.jpg'),
(59254, 4026, 'Chad S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153613.mp4', 'http://timg.bdta.pro/images/031ee3caebc1d0c8da8e612ebcb7879d.jpg'),
(59255, 4026, 'Chad S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153614.mp4', 'http://timg.bdta.pro/images/35d3a53799eeb674d1477c5dcf3e1467.jpg'),
(59256, 4026, 'Chad S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153615.mp4', 'http://timg.bdta.pro/images/2ce1b3c7e259a025b664234f1cf0c09c.jpg'),
(59257, 4026, 'Chad S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153616.mp4', 'http://timg.bdta.pro/images/316ec66092c2e74b4dc9877b2bc81ce3.jpg'),
(59258, 4026, 'Chad S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153617.mp4', 'http://timg.bdta.pro/images/92628eaf57657a79f844dc4cb7f9610c.jpg'),
(59259, 4026, 'Chad S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153618.mp4', 'http://timg.bdta.pro/images/d6410ea6308a33a82360f94ba5e73f8a.jpg'),
(59260, 4026, 'Chad S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153619.mp4', 'http://timg.bdta.pro/images/1af58ecde8ab8516cf7e6abccb20a436.jpg'),
(59261, 4027, 'Como Se Tornar um Tirano S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153606.mp4', 'http://timg.bdta.pro/images/952968aa732f5a8923726763e3167424.jpg'),
(59262, 4027, 'Como Se Tornar um Tirano S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153607.mp4', 'http://timg.bdta.pro/images/081bc3d2bfcce492d30285f2ca5a9a6b.jpg'),
(59263, 4027, 'Como Se Tornar um Tirano S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153608.mp4', 'http://timg.bdta.pro/images/9a89b285f5c372024a1b69802758af5b.jpg'),
(59264, 4027, 'Como Se Tornar um Tirano S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153609.mp4', 'http://timg.bdta.pro/images/dbc83f7f68ee923177c3b145ee732388.jpg'),
(59265, 4027, 'Como Se Tornar um Tirano S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153610.mp4', 'http://timg.bdta.pro/images/adff2f6605086f2528bbe831e5b0499f.jpg'),
(59266, 4027, 'Como Se Tornar um Tirano S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153611.mp4', 'http://timg.bdta.pro/images/c273ab75bb49bce7bae137148fcee8e5.jpg'),
(59267, 4028, 'Filthy Rich S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153596.mp4', 'http://timg.bdta.pro/images/3d60bf5d4232c4398629650797c5ce1c.jpg'),
(59268, 4028, 'Filthy Rich S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153597.mp4', 'http://timg.bdta.pro/images/a7bab32b3484a67222bcd575f1f7fa99.jpg'),
(59269, 4028, 'Filthy Rich S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153598.mp4', 'http://timg.bdta.pro/images/66f2cf762e97123b35881dee8e55514e.jpg'),
(59270, 4028, 'Filthy Rich S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153599.mp4', 'http://timg.bdta.pro/images/d680939066363db0d3a963c42d000414.jpg'),
(59271, 4028, 'Filthy Rich S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153600.mp4', 'http://timg.bdta.pro/images/12ada215e19fff57bfc1101f3295bd5f.jpg'),
(59272, 4028, 'Filthy Rich S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153601.mp4', 'http://timg.bdta.pro/images/509e72a7de881681321119ef3b93c056.jpg'),
(59273, 4028, 'Filthy Rich S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153602.mp4', 'http://timg.bdta.pro/images/1a26a0225c4938f10e9907f5b41dba2b.jpg'),
(59274, 4028, 'Filthy Rich S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153603.mp4', 'http://timg.bdta.pro/images/a6c7849b1ba7b0d9d19cc372169eea58.jpg'),
(59275, 4028, 'Filthy Rich S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153604.mp4', 'http://timg.bdta.pro/images/7aaa8dd7817b723a8988fedf88454b58.jpg'),
(59276, 4028, 'Filthy Rich S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153605.mp4', 'http://timg.bdta.pro/images/524c91478bbcfffd288d2c3f15201eda.jpg'),
(59277, 4029, 'Gossip Girl S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204568.mp4', 'http://timg.bdta.pro/images/20d70b4f081c52c783c00efc9a54c0d4.jpg'),
(59278, 4029, 'Gossip Girl S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204569.mp4', 'http://timg.bdta.pro/images/c6a631a343b8b8c5772789ef2ff34eeb.jpg'),
(59279, 4029, 'Gossip Girl S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204570.mp4', 'http://timg.bdta.pro/images/421654a6b6edf0ee0da122d64ef0d5e6.jpg'),
(59280, 4029, 'Gossip Girl S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204571.mp4', 'http://timg.bdta.pro/images/f79d04c1397b2347a9a069e4acba68eb.jpg'),
(59281, 4029, 'Gossip Girl S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204572.mp4', 'http://timg.bdta.pro/images/88f8af15acf69f0e1447ac7e0a2f696b.jpg'),
(59282, 4029, 'Gossip Girl S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204573.mp4', 'http://timg.bdta.pro/images/be98a4b659bc94e8c2da4986bb307514.jpg'),
(59283, 4029, 'Gossip Girl S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zS7itnAOh7b5qeVjlOOLvJmvSEW.jpg'),
(59284, 4029, 'Gossip Girl S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cisIyQG7gmj1YWsYRqvmThMDmbF.jpg'),
(59285, 4029, 'Gossip Girl S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/irUA7YNqiTUEt7GvRvbCNKAtlYm.jpg'),
(59286, 4029, 'Gossip Girl S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aKyx72CUac9tq4dPSbAoPHozzmF.jpg'),
(59287, 4029, 'Gossip Girl S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3easY6AxJmEZhirf0VpYtYcToat.jpg'),
(59288, 4030, 'Gossip Girl S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kKrh16YWR2yZtfsOOCzAymNgfWw.jpg'),
(59289, 4030, 'Gossip Girl S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qa0suZ0ZtED9spK3OoOymDwEDuj.jpg'),
(59290, 4030, 'Gossip Girl S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204581.mp4', 'http://image.tmdb.org/t/p/w1280/fqyoeOS2SmxRRyKEJ2qMoB6N3Ne.jpg'),
(59291, 4030, 'Gossip Girl S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204582.mp4', 'http://image.tmdb.org/t/p/w1280/xBPZrxi1WqEZgOhItueEor73hMO.jpg'),
(59292, 4030, 'Gossip Girl S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dPqMJ4VEqlKawSUMrZQZHTCoOti.jpg'),
(59293, 4030, 'Gossip Girl S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z3G98rFKIf2QoqtgTFwAl48msEt.jpg'),
(59294, 4030, 'Gossip Girl S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204585.mp4', 'http://image.tmdb.org/t/p/w1280/taca6VVAIexhd7nz2pVJFdZGxTB.jpg'),
(59295, 4030, 'Gossip Girl S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204586.mp4', 'http://image.tmdb.org/t/p/w1280/uLC5RgT90I5y4GhntHFW05PV4l1.jpg'),
(59296, 4030, 'Gossip Girl S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204587.mp4', 'http://image.tmdb.org/t/p/w1280/kV18DsmzyZHL75GUfSexhjdzODC.jpg'),
(59297, 4030, 'Gossip Girl S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204588.mp4', 'http://image.tmdb.org/t/p/w1280/22DvqguqkNsfIjZibWImZtdCB0e.jpg'),
(59298, 4031, 'Invasão (2005) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153574.mp4', 'http://timg.bdta.pro/images/dc7cd0c6e807c9a00771cf811ca04325.jpg'),
(59299, 4031, 'Invasão (2005) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153575.mp4', 'http://timg.bdta.pro/images/d533ebe46d73557502bf6815ef2b2cd8.jpg'),
(59300, 4031, 'Invasão (2005) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153576.mp4', 'http://timg.bdta.pro/images/6441c6990228e79731f62af468f31c1e.jpg'),
(59301, 4031, 'Invasão (2005) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153577.mp4', 'http://timg.bdta.pro/images/7617c3836549ca113629e39771c4b249.jpg'),
(59302, 4031, 'Invasão (2005) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153578.mp4', 'http://timg.bdta.pro/images/e8e15c40bf865f8505c66a3bd36042f5.jpg'),
(59303, 4031, 'Invasão (2005) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153579.mp4', 'http://timg.bdta.pro/images/675fbd2a8114294288af59e0e36a477e.jpg'),
(59304, 4031, 'Invasão (2005) S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153580.mp4', 'http://timg.bdta.pro/images/c2f6469da1e99f32e97181e06e29ab33.jpg'),
(59305, 4031, 'Invasão (2005) S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153581.mp4', 'http://timg.bdta.pro/images/61bb52ce7da62de53665a2f4cd97500f.jpg'),
(59306, 4031, 'Invasão (2005) S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153582.mp4', 'http://timg.bdta.pro/images/3795b85b24696a144ecf6bbd8ee69d61.jpg'),
(59307, 4031, 'Invasão (2005) S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153583.mp4', 'http://timg.bdta.pro/images/5a8df939a5675e112e9265b26228facd.jpg'),
(59308, 4031, 'Invasão (2005) S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153584.mp4', 'http://timg.bdta.pro/images/4c53d2277ced2da661b2cd9adbc0f4d8.jpg'),
(59309, 4031, 'Invasão (2005) S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153585.mp4', 'http://timg.bdta.pro/images/81473b5948da23ab8d4d926d187310f5.jpg'),
(59310, 4031, 'Invasão (2005) S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153586.mp4', 'http://timg.bdta.pro/images/8b12e0a4c4a5a8ad23b23f9c9c0f5a50.jpg'),
(59311, 4031, 'Invasão (2005) S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153587.mp4', 'http://timg.bdta.pro/images/daafacb897424b65088afa6912639177.jpg'),
(59312, 4031, 'Invasão (2005) S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153588.mp4', 'http://timg.bdta.pro/images/a231f75ce5cee6daa6cf9c0fdc7fad23.jpg'),
(59313, 4031, 'Invasão (2005) S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/153589.mp4', 'http://timg.bdta.pro/images/f58e0d2d5f157308fdd1b99a5bac33c3.jpg'),
(59314, 4031, 'Invasão (2005) S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/153590.mp4', 'http://timg.bdta.pro/images/01e0b2212559c076e821b91bc3c6bfec.jpg'),
(59315, 4031, 'Invasão (2005) S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/153591.mp4', 'http://timg.bdta.pro/images/bb19321e74dbf7f1782ca8ed87e9f77f.jpg'),
(59316, 4031, 'Invasão (2005) S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/153592.mp4', 'http://timg.bdta.pro/images/6e662f27b511a506b18b2e0163345c4c.jpg'),
(59317, 4031, 'Invasão (2005) S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/153593.mp4', 'http://timg.bdta.pro/images/4f93801d8fe337a9c6f19fdaf04ec198.jpg'),
(59318, 4031, 'Invasão (2005) S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/153594.mp4', 'http://timg.bdta.pro/images/4dfe1ddf45d8d5b94b4ecda12f6f920d.jpg'),
(59319, 4031, 'Invasão (2005) S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/153595.mp4', 'http://timg.bdta.pro/images/e8f623bf602dbdecad9bf5765ef218d4.jpg'),
(59320, 4032, 'Monstros no Trabalho S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157151.mp4', 'http://timg.bdta.pro/images/79aaf880b1262018b8aea8b6f0032a4f.jpg'),
(59321, 4032, 'Monstros no Trabalho S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157152.mp4', 'http://timg.bdta.pro/images/65c4cae20837b3aa423d4fc211691766.jpg'),
(59322, 4032, 'Monstros no Trabalho S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157153.mp4', 'http://timg.bdta.pro/images/5416ff8d0d76a73971b342040c3275b6.jpg'),
(59323, 4032, 'Monstros no Trabalho S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157154.mp4', 'http://timg.bdta.pro/images/b8c3e987366e7921b626dce300cf6ca4.jpg'),
(59324, 4032, 'Monstros no Trabalho S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/157155.mp4', 'http://timg.bdta.pro/images/35fed88bc816992f759d84cc3979b02c.jpg'),
(59325, 4032, 'Monstros no Trabalho S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/157156.mp4', 'http://timg.bdta.pro/images/2f84ffb11de1a0c975a3bad8ed472b26.jpg'),
(59326, 4032, 'Monstros no Trabalho S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/157157.mp4', 'http://timg.bdta.pro/images/34480e68e3397390033bc30d0e0598a3.jpg'),
(59327, 4032, 'Monstros no Trabalho S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/157158.mp4', 'http://timg.bdta.pro/images/070fa5118d9a70bb3babc00826b3b759.jpg'),
(59328, 4032, 'Monstros no Trabalho S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/157159.mp4', 'http://timg.bdta.pro/images/a5f6cd068b2343f8001ece03a5d2a062.jpg'),
(59329, 4032, 'Monstros no Trabalho S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/157160.mp4', 'http://timg.bdta.pro/images/f58b0c45d797ba14b9da3ef1b21806b2.jpg'),
(59330, 4033, 'Monstros no Trabalho S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/345088.mp4', 'http://gstaticontent.com/images/c749466f2c39c79a33dbb56766c3c4db.jpg'),
(59331, 4033, 'Monstros no Trabalho S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/345089.mp4', 'http://gstaticontent.com/images/c749466f2c39c79a33dbb56766c3c4db.jpg'),
(59332, 4033, 'Monstros no Trabalho S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/345090.mp4', 'http://gstaticontent.com/images/c749466f2c39c79a33dbb56766c3c4db.jpg'),
(59333, 4033, 'Monstros no Trabalho S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/345091.mp4', 'http://gstaticontent.com/images/c749466f2c39c79a33dbb56766c3c4db.jpg'),
(59334, 4033, 'Monstros no Trabalho S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/345092.mp4', 'http://gstaticontent.com/images/c749466f2c39c79a33dbb56766c3c4db.jpg'),
(59335, 4033, 'Monstros no Trabalho S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/345093.mp4', 'http://gstaticontent.com/images/c749466f2c39c79a33dbb56766c3c4db.jpg'),
(59336, 4033, 'Monstros no Trabalho S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/345094.mp4', 'http://gstaticontent.com/images/c749466f2c39c79a33dbb56766c3c4db.jpg'),
(59337, 4033, 'Monstros no Trabalho S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/345095.mp4', 'http://gstaticontent.com/images/c749466f2c39c79a33dbb56766c3c4db.jpg'),
(59338, 4033, 'Monstros no Trabalho S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/345096.mp4', 'http://gstaticontent.com/images/c749466f2c39c79a33dbb56766c3c4db.jpg'),
(59339, 4033, 'Monstros no Trabalho S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/345097.mp4', 'http://gstaticontent.com/images/c749466f2c39c79a33dbb56766c3c4db.jpg'),
(59340, 4034, 'Moonlight S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153521.mp4', 'http://timg.bdta.pro/images/4a32c5815d473b3fbbc84e5e3858050b.jpg'),
(59341, 4034, 'Moonlight S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153522.mp4', 'http://timg.bdta.pro/images/b3f31b98591ad5c8e917362ff38e9d8b.jpg'),
(59342, 4034, 'Moonlight S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153523.mp4', 'http://timg.bdta.pro/images/8e4821c924fb35b0c37bc3ef0a8fc6e9.jpg'),
(59343, 4034, 'Moonlight S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153524.mp4', 'http://timg.bdta.pro/images/004eef18e41542734f1c728d85da23f1.jpg'),
(59344, 4034, 'Moonlight S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153525.mp4', 'http://timg.bdta.pro/images/36808aa43f4f6d94068b82fa4c6e8f56.jpg'),
(59345, 4034, 'Moonlight S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153526.mp4', 'http://timg.bdta.pro/images/0d00880a99007bfc1d0f2ca9b8862f49.jpg'),
(59346, 4035, 'Moonlight S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153527.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59347, 4035, 'Moonlight S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153528.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59348, 4035, 'Moonlight S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153529.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59349, 4035, 'Moonlight S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153530.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59350, 4035, 'Moonlight S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153531.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59351, 4035, 'Moonlight S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153532.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59352, 4035, 'Moonlight S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153533.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59353, 4035, 'Moonlight S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153534.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59354, 4035, 'Moonlight S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153535.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59355, 4035, 'Moonlight S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153536.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59356, 4035, 'Moonlight S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153537.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59357, 4035, 'Moonlight S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153538.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59358, 4035, 'Moonlight S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153539.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59359, 4035, 'Moonlight S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153540.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59360, 4035, 'Moonlight S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153541.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59361, 4035, 'Moonlight S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/153542.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59362, 4035, 'Moonlight S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/153543.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59363, 4035, 'Moonlight S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/153544.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59364, 4036, 'Moonlight S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153545.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59365, 4036, 'Moonlight S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153546.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59366, 4036, 'Moonlight S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153547.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59367, 4036, 'Moonlight S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153548.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59368, 4036, 'Moonlight S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153549.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59369, 4036, 'Moonlight S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153550.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59370, 4036, 'Moonlight S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153551.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59371, 4036, 'Moonlight S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153552.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59372, 4036, 'Moonlight S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153553.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59373, 4036, 'Moonlight S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153554.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59374, 4036, 'Moonlight S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153555.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59375, 4036, 'Moonlight S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153556.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59376, 4036, 'Moonlight S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153557.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59377, 4036, 'Moonlight S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153558.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59378, 4036, 'Moonlight S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153559.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59379, 4037, 'Moonlight S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153560.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59380, 4037, 'Moonlight S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153561.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59381, 4037, 'Moonlight S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153562.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59382, 4037, 'Moonlight S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153563.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59383, 4037, 'Moonlight S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153564.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59384, 4037, 'Moonlight S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153565.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59385, 4037, 'Moonlight S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153566.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59386, 4037, 'Moonlight S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153567.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59387, 4037, 'Moonlight S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153568.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59388, 4037, 'Moonlight S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153569.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59389, 4037, 'Moonlight S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153570.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59390, 4037, 'Moonlight S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153571.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59391, 4037, 'Moonlight S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153572.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59392, 4037, 'Moonlight S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153573.mp4', 'http://gstaticontent.com/images/086bac0278a6700fa21363bd0dac60c9.jpg'),
(59393, 4038, 'Mrs. America S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153512.mp4', 'http://timg.bdta.pro/images/4983999b82e686ae1182aa97d41febcd.jpg'),
(59394, 4038, 'Mrs. America S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153513.mp4', 'http://timg.bdta.pro/images/db235007e8d9a429f813c1bc372f486e.jpg'),
(59395, 4038, 'Mrs. America S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153514.mp4', 'http://timg.bdta.pro/images/662734f9e26c0bda53860e9185644098.jpg'),
(59396, 4038, 'Mrs. America S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153515.mp4', 'http://timg.bdta.pro/images/c70e560a676536dd7e06db34c473c522.jpg'),
(59397, 4038, 'Mrs. America S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153516.mp4', 'http://timg.bdta.pro/images/963ef140a88b85fad3dfcfa818295acb.jpg'),
(59398, 4038, 'Mrs. America S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153517.mp4', 'http://timg.bdta.pro/images/581b6ee11cef46ce4b99ab55ef881a95.jpg'),
(59399, 4038, 'Mrs. America S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153518.mp4', 'http://timg.bdta.pro/images/a36a57020c21a88ef4402b3956e83761.jpg'),
(59400, 4038, 'Mrs. America S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153519.mp4', 'http://timg.bdta.pro/images/85789b87a970a463ae4e69aa9d9a0931.jpg'),
(59401, 4038, 'Mrs. America S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153520.mp4', 'http://timg.bdta.pro/images/17297a92aa440542af3a2ee322b3ab21.jpg'),
(59402, 4039, 'O Crime do Século S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153510.mp4', 'http://timg.bdta.pro/images/16e9916a6be6dc56624aa85508570659.jpg'),
(59403, 4039, 'O Crime do Século S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153511.mp4', 'http://timg.bdta.pro/images/15403ead215917c7665e11180122a84b.jpg'),
(59404, 4040, 'O Incrível Mundo de Gumball S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153289.mp4', 'http://timg.bdta.pro/images/3a903419d22d5500722e91d68ced2c9a.jpg'),
(59405, 4040, 'O Incrível Mundo de Gumball S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153290.mp4', 'http://timg.bdta.pro/images/3fbcb2c6e80d8cd442726af1630dec0f.jpg'),
(59406, 4040, 'O Incrível Mundo de Gumball S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153291.mp4', 'http://timg.bdta.pro/images/3f739d18892bf3a34f0172d1e3fa920d.jpg'),
(59407, 4040, 'O Incrível Mundo de Gumball S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153292.mp4', 'http://timg.bdta.pro/images/d034b95d6003625e4de31d35fb74092c.jpg'),
(59408, 4040, 'O Incrível Mundo de Gumball S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153293.mp4', 'http://timg.bdta.pro/images/05705d92a73fa1e585aef8e8bde3ea79.jpg'),
(59409, 4040, 'O Incrível Mundo de Gumball S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153294.mp4', 'http://timg.bdta.pro/images/1ed741ac0575876820a2f08afdacaa24.jpg'),
(59410, 4040, 'O Incrível Mundo de Gumball S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153295.mp4', 'http://timg.bdta.pro/images/c7d7ddcdc27b17f37d02eeef8e0e13ee.jpg'),
(59411, 4040, 'O Incrível Mundo de Gumball S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153296.mp4', 'http://timg.bdta.pro/images/24fe14609c6941e7bbbc3113c0a210ea.jpg'),
(59412, 4040, 'O Incrível Mundo de Gumball S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153297.mp4', 'http://timg.bdta.pro/images/e97b5bf051e0716346571cf1de4b62ad.jpg'),
(59413, 4040, 'O Incrível Mundo de Gumball S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153298.mp4', 'http://timg.bdta.pro/images/3233d7893a9c9e706115eaf11fc2340e.jpg'),
(59414, 4040, 'O Incrível Mundo de Gumball S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153299.mp4', 'http://timg.bdta.pro/images/fa527f318838840bc9481ec19cf7d78c.jpg'),
(59415, 4040, 'O Incrível Mundo de Gumball S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153300.mp4', 'http://timg.bdta.pro/images/b9cf885361da5270132080b631e0ad0a.jpg'),
(59416, 4040, 'O Incrível Mundo de Gumball S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153301.mp4', 'http://timg.bdta.pro/images/9ae71cd83a01bdaa3b3d4b6eade2d2a7.jpg'),
(59417, 4040, 'O Incrível Mundo de Gumball S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153302.mp4', 'http://timg.bdta.pro/images/6c4ada92c7c33b9f2d1fe843f2958092.jpg'),
(59418, 4040, 'O Incrível Mundo de Gumball S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153303.mp4', 'http://timg.bdta.pro/images/a0c99340d4ea9c14148d441be98357be.jpg'),
(59419, 4040, 'O Incrível Mundo de Gumball S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/153304.mp4', 'http://timg.bdta.pro/images/c4ceeca666301c484859cf5877e73678.jpg'),
(59420, 4040, 'O Incrível Mundo de Gumball S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/153305.mp4', 'http://timg.bdta.pro/images/86f50c7b48bfccdd2e3f2f95e1b9e532.jpg'),
(59421, 4040, 'O Incrível Mundo de Gumball S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/153306.mp4', 'http://timg.bdta.pro/images/b2f532164efa447fbe2e7d0bbbd326ac.jpg'),
(59422, 4041, 'O Incrível Mundo de Gumball S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153307.mp4', 'http://timg.bdta.pro/images/92c450fd8d9beaa5f7567d79912d127d.jpg'),
(59423, 4041, 'O Incrível Mundo de Gumball S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153308.mp4', 'http://timg.bdta.pro/images/ec65643e2b08c1ee764bcc9e98eca5b4.jpg'),
(59424, 4041, 'O Incrível Mundo de Gumball S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153309.mp4', 'http://timg.bdta.pro/images/a6edf508e680158645b3a4f049fb58db.jpg'),
(59425, 4041, 'O Incrível Mundo de Gumball S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153310.mp4', 'http://timg.bdta.pro/images/44c5b33f781a1a7a79d5c450f03dbd3c.jpg'),
(59426, 4041, 'O Incrível Mundo de Gumball S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153311.mp4', 'http://timg.bdta.pro/images/5572fab426145a4743884671cae72115.jpg'),
(59427, 4041, 'O Incrível Mundo de Gumball S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153312.mp4', 'http://timg.bdta.pro/images/80448fcfec9d1742afc78e3a4d59ab51.jpg'),
(59428, 4041, 'O Incrível Mundo de Gumball S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153313.mp4', 'http://timg.bdta.pro/images/020db980fd906106022d0581e2ae7592.jpg'),
(59429, 4041, 'O Incrível Mundo de Gumball S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153314.mp4', 'http://timg.bdta.pro/images/0c5641dfb73fa4db4f0063bbb104736b.jpg'),
(59430, 4041, 'O Incrível Mundo de Gumball S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153315.mp4', 'http://timg.bdta.pro/images/5baaf417083977bafe0242f18bd1ddbd.jpg'),
(59431, 4041, 'O Incrível Mundo de Gumball S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153316.mp4', 'http://timg.bdta.pro/images/95e475d5b833819d6c7a0a4147e70149.jpg'),
(59432, 4041, 'O Incrível Mundo de Gumball S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153317.mp4', 'http://timg.bdta.pro/images/594b721d5ea7431bac0aa85174877991.jpg'),
(59433, 4041, 'O Incrível Mundo de Gumball S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153318.mp4', 'http://timg.bdta.pro/images/3bd922623aff5702fc18e72e6acaaa1f.jpg'),
(59434, 4041, 'O Incrível Mundo de Gumball S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153319.mp4', 'http://timg.bdta.pro/images/bfedc999412b11ec353522a477b86cfb.jpg'),
(59435, 4041, 'O Incrível Mundo de Gumball S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153320.mp4', 'http://timg.bdta.pro/images/1aa6fc258a0e022cf7dfd4acd55432f0.jpg'),
(59436, 4041, 'O Incrível Mundo de Gumball S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153321.mp4', 'http://timg.bdta.pro/images/a3bc2dab09ea9560728908b2c808ea75.jpg'),
(59437, 4041, 'O Incrível Mundo de Gumball S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/153322.mp4', 'http://timg.bdta.pro/images/2a2641b41b91775804b69441bc7beead.jpg'),
(59438, 4041, 'O Incrível Mundo de Gumball S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/153323.mp4', 'http://timg.bdta.pro/images/729ab9fd1bfcc52cc247c77314bbdde4.jpg'),
(59439, 4041, 'O Incrível Mundo de Gumball S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/153324.mp4', 'http://timg.bdta.pro/images/0bbb0f66eedcfe53b42122fa962fab03.jpg'),
(59440, 4041, 'O Incrível Mundo de Gumball S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/153325.mp4', 'http://timg.bdta.pro/images/bd9d1ee39b89969da6875e8d99d34f08.jpg'),
(59441, 4041, 'O Incrível Mundo de Gumball S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/153326.mp4', 'http://timg.bdta.pro/images/daeaefcb5d33da23462b6e6a6968a6a6.jpg'),
(59442, 4041, 'O Incrível Mundo de Gumball S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/153327.mp4', 'http://timg.bdta.pro/images/e3b2c991aa94e7c7970c589397373854.jpg'),
(59443, 4041, 'O Incrível Mundo de Gumball S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/153328.mp4', 'http://timg.bdta.pro/images/c974d60faeb19e46ff7098c4be795652.jpg'),
(59444, 4041, 'O Incrível Mundo de Gumball S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/153329.mp4', 'http://timg.bdta.pro/images/5c89878cdc00a89b673444a15dbc6f86.jpg'),
(59445, 4041, 'O Incrível Mundo de Gumball S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/153330.mp4', 'http://timg.bdta.pro/images/093de5eaa4f71f8e8dd61e97441b63ad.jpg'),
(59446, 4041, 'O Incrível Mundo de Gumball S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/153331.mp4', 'http://timg.bdta.pro/images/7ed35ea3bebd7d9b155504fbb974af24.jpg'),
(59447, 4041, 'O Incrível Mundo de Gumball S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/153332.mp4', 'http://timg.bdta.pro/images/292888bcff4e8cf3bbb86df127f25a6e.jpg'),
(59448, 4041, 'O Incrível Mundo de Gumball S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/153333.mp4', 'http://timg.bdta.pro/images/ea24ab09fb42daee68e5fc8dccabc47f.jpg'),
(59449, 4041, 'O Incrível Mundo de Gumball S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/153334.mp4', 'http://timg.bdta.pro/images/d894d7336d64df50e322af4734f4f05f.jpg'),
(59450, 4041, 'O Incrível Mundo de Gumball S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/153335.mp4', 'http://timg.bdta.pro/images/ad1dd519d47a091e43ab8e6a8aab4532.jpg'),
(59451, 4041, 'O Incrível Mundo de Gumball S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/153336.mp4', 'http://timg.bdta.pro/images/a9bee6074ec2d05b60de43630ee08473.jpg'),
(59452, 4041, 'O Incrível Mundo de Gumball S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/153337.mp4', 'http://timg.bdta.pro/images/8a79fede306155d9242ede7dca34beda.jpg'),
(59453, 4041, 'O Incrível Mundo de Gumball S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/153338.mp4', 'http://timg.bdta.pro/images/78e71af98f1cc38d9221f8a884060fa0.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(59454, 4041, 'O Incrível Mundo de Gumball S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/153339.mp4', 'http://timg.bdta.pro/images/448d6dcba843a1c14d482c42e1c7ef86.jpg'),
(59455, 4041, 'O Incrível Mundo de Gumball S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/153340.mp4', 'http://timg.bdta.pro/images/8cc97066646c5b2273511c65b8851f4b.jpg'),
(59456, 4041, 'O Incrível Mundo de Gumball S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/153341.mp4', 'http://timg.bdta.pro/images/70e6df4a2d16e27cceb196d7b4647ebf.jpg'),
(59457, 4041, 'O Incrível Mundo de Gumball S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/153342.mp4', 'http://timg.bdta.pro/images/70bb20719a6cf19df90d2de38cee2fd9.jpg'),
(59458, 4041, 'O Incrível Mundo de Gumball S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/153343.mp4', 'http://timg.bdta.pro/images/869c9ff9a8bd660270b8427c1cf7c69a.jpg'),
(59459, 4041, 'O Incrível Mundo de Gumball S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/153344.mp4', 'http://timg.bdta.pro/images/c7b120f65e99e60b7cadf9b1c5efc947.jpg'),
(59460, 4041, 'O Incrível Mundo de Gumball S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/153345.mp4', 'http://timg.bdta.pro/images/06baa9e29f8c945cdee3bb1cd85feecc.jpg'),
(59461, 4041, 'O Incrível Mundo de Gumball S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/153346.mp4', 'http://timg.bdta.pro/images/c7232aa0332f7e60e07bda1cbca7807b.jpg'),
(59462, 4042, 'O Incrível Mundo de Gumball S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153347.mp4', 'http://timg.bdta.pro/images/8252441f3ed5c8dfa01cb87299db5d95.jpg'),
(59463, 4042, 'O Incrível Mundo de Gumball S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153348.mp4', 'http://timg.bdta.pro/images/7641694737d0a62e103ec43b00819fa8.jpg'),
(59464, 4042, 'O Incrível Mundo de Gumball S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153349.mp4', 'http://timg.bdta.pro/images/8599f110a88f1d8947db43aec3eee29e.jpg'),
(59465, 4042, 'O Incrível Mundo de Gumball S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153350.mp4', 'http://timg.bdta.pro/images/c00f5cd9b272624befb86a3096f6402e.jpg'),
(59466, 4042, 'O Incrível Mundo de Gumball S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153351.mp4', 'http://timg.bdta.pro/images/7f98b75bed28f0e539cae8ffbb5668ca.jpg'),
(59467, 4042, 'O Incrível Mundo de Gumball S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153352.mp4', 'http://timg.bdta.pro/images/6ce7260abb6035ecf0c5560e8813b35e.jpg'),
(59468, 4042, 'O Incrível Mundo de Gumball S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153353.mp4', 'http://timg.bdta.pro/images/88f8075c382293ee1d735e1f451c56b7.jpg'),
(59469, 4042, 'O Incrível Mundo de Gumball S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153354.mp4', 'http://timg.bdta.pro/images/229042aa67bc8b2185558cc062a14fd0.jpg'),
(59470, 4042, 'O Incrível Mundo de Gumball S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153355.mp4', 'http://timg.bdta.pro/images/31a13d87dcad5f6fe86ec7e9e2096dc3.jpg'),
(59471, 4042, 'O Incrível Mundo de Gumball S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153356.mp4', 'http://timg.bdta.pro/images/2ccd6009e18785b8903a5027128e61bb.jpg'),
(59472, 4042, 'O Incrível Mundo de Gumball S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153357.mp4', 'http://timg.bdta.pro/images/65a4d772b550822e17fc2d4084ed12a0.jpg'),
(59473, 4042, 'O Incrível Mundo de Gumball S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153358.mp4', 'http://timg.bdta.pro/images/4a93dc41bc7f50f55b039539afff738d.jpg'),
(59474, 4042, 'O Incrível Mundo de Gumball S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153359.mp4', 'http://timg.bdta.pro/images/2c24799e75573c4df5a001a3d3a2398f.jpg'),
(59475, 4042, 'O Incrível Mundo de Gumball S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153360.mp4', 'http://timg.bdta.pro/images/5501c932acf93a4046e4ab82751d5237.jpg'),
(59476, 4042, 'O Incrível Mundo de Gumball S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153361.mp4', 'http://timg.bdta.pro/images/e184f797e5e5a9ed9af18a7b5c9fa0cb.jpg'),
(59477, 4042, 'O Incrível Mundo de Gumball S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/153362.mp4', 'http://timg.bdta.pro/images/999d9abfd1891ca4919b98bddff5728f.jpg'),
(59478, 4042, 'O Incrível Mundo de Gumball S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/153363.mp4', 'http://timg.bdta.pro/images/55f87736008cf08fa053ecd9aef0a842.jpg'),
(59479, 4042, 'O Incrível Mundo de Gumball S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/153364.mp4', 'http://timg.bdta.pro/images/c4838b534e91394e5e51b37f23b96638.jpg'),
(59480, 4042, 'O Incrível Mundo de Gumball S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/153365.mp4', 'http://timg.bdta.pro/images/f0386616fbfd9b5502613714a7c28ae5.jpg'),
(59481, 4042, 'O Incrível Mundo de Gumball S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/153366.mp4', 'http://timg.bdta.pro/images/f4b48e1f7e2d28ee9d0ec3b641afe734.jpg'),
(59482, 4042, 'O Incrível Mundo de Gumball S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/153367.mp4', 'http://timg.bdta.pro/images/1f610e2f48fe4191da88b10592479e58.jpg'),
(59483, 4042, 'O Incrível Mundo de Gumball S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/153368.mp4', 'http://timg.bdta.pro/images/053ca40141eb4bb996c791ac9691ee25.jpg'),
(59484, 4042, 'O Incrível Mundo de Gumball S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/153369.mp4', 'http://timg.bdta.pro/images/2328c9387331cb6fe31d8e26a4de72f2.jpg'),
(59485, 4042, 'O Incrível Mundo de Gumball S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/153370.mp4', 'http://timg.bdta.pro/images/099101b7afc1eef864882b1a8bdde80f.jpg'),
(59486, 4042, 'O Incrível Mundo de Gumball S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/153371.mp4', 'http://timg.bdta.pro/images/cd66b78b7ba4f631aebafb1e795bd226.jpg'),
(59487, 4042, 'O Incrível Mundo de Gumball S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/153372.mp4', 'http://timg.bdta.pro/images/fa5a1197965888523040eb871457b9ef.jpg'),
(59488, 4042, 'O Incrível Mundo de Gumball S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/153373.mp4', 'http://timg.bdta.pro/images/8aba2a201032943c35692445b9303004.jpg'),
(59489, 4042, 'O Incrível Mundo de Gumball S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/153374.mp4', 'http://timg.bdta.pro/images/1ce26ed4854099f70ca05044ed177d0c.jpg'),
(59490, 4042, 'O Incrível Mundo de Gumball S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/153375.mp4', 'http://timg.bdta.pro/images/83dc386b0f21f96718f8f2c2d8236347.jpg'),
(59491, 4042, 'O Incrível Mundo de Gumball S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/153376.mp4', 'http://timg.bdta.pro/images/1f7ff44930e77f9cd1a00b8b1cf11410.jpg'),
(59492, 4042, 'O Incrível Mundo de Gumball S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/153377.mp4', 'http://timg.bdta.pro/images/60a3ce9d1c280e102534784009df69d1.jpg'),
(59493, 4042, 'O Incrível Mundo de Gumball S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/153378.mp4', 'http://timg.bdta.pro/images/42afb2751d4cdc4634a397f2cd0d52ec.jpg'),
(59494, 4042, 'O Incrível Mundo de Gumball S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/153379.mp4', 'http://timg.bdta.pro/images/05ca7dc3de0d3834c107003203c6217d.jpg'),
(59495, 4042, 'O Incrível Mundo de Gumball S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/153380.mp4', 'http://timg.bdta.pro/images/db42d29f9ffef3ca03fcd95c026aea40.jpg'),
(59496, 4042, 'O Incrível Mundo de Gumball S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/153381.mp4', 'http://timg.bdta.pro/images/0a318accaae157d549c07a74e65b7528.jpg'),
(59497, 4042, 'O Incrível Mundo de Gumball S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/153382.mp4', 'http://timg.bdta.pro/images/afaef3aa2ee8e81653af0232d29c0fae.jpg'),
(59498, 4042, 'O Incrível Mundo de Gumball S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/153383.mp4', 'http://timg.bdta.pro/images/7befd8ce6a510cd0c0f7597e5e918449.jpg'),
(59499, 4042, 'O Incrível Mundo de Gumball S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/153384.mp4', 'http://timg.bdta.pro/images/18ca31dab94277a46b86408822abfbf3.jpg'),
(59500, 4042, 'O Incrível Mundo de Gumball S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/153385.mp4', 'http://timg.bdta.pro/images/022e57fa6adb45b5e1b39e098a14b754.jpg'),
(59501, 4042, 'O Incrível Mundo de Gumball S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/153386.mp4', 'http://timg.bdta.pro/images/022e57fa6adb45b5e1b39e098a14b754.jpg'),
(59502, 4043, 'O Incrível Mundo de Gumball S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153387.mp4', 'http://timg.bdta.pro/images/3b99cd5ad6cb2dbf595bccb4c91702a5.jpg'),
(59503, 4043, 'O Incrível Mundo de Gumball S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153388.mp4', 'http://timg.bdta.pro/images/5ced19ba7f2bb08784c814fca0fc1af5.jpg'),
(59504, 4043, 'O Incrível Mundo de Gumball S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153389.mp4', 'http://timg.bdta.pro/images/279004e3bef8cf6789757f17003a8e14.jpg'),
(59505, 4043, 'O Incrível Mundo de Gumball S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153390.mp4', 'http://timg.bdta.pro/images/b8a952249e2f3d95e2c80bcbb8f0274b.jpg'),
(59506, 4043, 'O Incrível Mundo de Gumball S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153391.mp4', 'http://timg.bdta.pro/images/287ae5ebf6a3e286d2dea14a4307f5e0.jpg'),
(59507, 4043, 'O Incrível Mundo de Gumball S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153392.mp4', 'http://timg.bdta.pro/images/c036d9dacbca3127ada8cd17252dbcb6.jpg'),
(59508, 4043, 'O Incrível Mundo de Gumball S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153393.mp4', 'http://timg.bdta.pro/images/3b59f6899ea98208b0516e70d3cab8a7.jpg'),
(59509, 4043, 'O Incrível Mundo de Gumball S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153394.mp4', 'http://timg.bdta.pro/images/311e9d5e6273937adeb81ff2eb75a787.jpg'),
(59510, 4043, 'O Incrível Mundo de Gumball S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153395.mp4', 'http://timg.bdta.pro/images/910817ad1960042db9c78824e170eb1d.jpg'),
(59511, 4043, 'O Incrível Mundo de Gumball S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153396.mp4', 'http://timg.bdta.pro/images/2e71c6d06fbe241eba3c924438bdd371.jpg'),
(59512, 4043, 'O Incrível Mundo de Gumball S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153397.mp4', 'http://timg.bdta.pro/images/3956815c36bac66ddb38a4fcef38aef7.jpg'),
(59513, 4043, 'O Incrível Mundo de Gumball S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153398.mp4', 'http://timg.bdta.pro/images/91e1992a8aacdfb361a55363489a899f.jpg'),
(59514, 4043, 'O Incrível Mundo de Gumball S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153399.mp4', 'http://timg.bdta.pro/images/7943d59856a846d4c984c72304ed0863.jpg'),
(59515, 4043, 'O Incrível Mundo de Gumball S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153400.mp4', 'http://timg.bdta.pro/images/3da8c30349fa1f0fb3c424eee9b9484f.jpg'),
(59516, 4043, 'O Incrível Mundo de Gumball S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153401.mp4', 'http://timg.bdta.pro/images/8b903a3e28c0c46028acaef39189ff40.jpg'),
(59517, 4043, 'O Incrível Mundo de Gumball S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/153402.mp4', 'http://timg.bdta.pro/images/1e6b0600962e993d6a0348e6f0f3657c.jpg'),
(59518, 4043, 'O Incrível Mundo de Gumball S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/153403.mp4', 'http://timg.bdta.pro/images/4f885d5dad6b373b8a5dcfa8e940cdba.jpg'),
(59519, 4043, 'O Incrível Mundo de Gumball S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/153404.mp4', 'http://timg.bdta.pro/images/89fec7d518290316f6921a11fe1ae9b1.jpg'),
(59520, 4043, 'O Incrível Mundo de Gumball S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/153405.mp4', 'http://timg.bdta.pro/images/e07956106bd620497cee04dd71dab350.jpg'),
(59521, 4043, 'O Incrível Mundo de Gumball S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/153406.mp4', 'http://timg.bdta.pro/images/4c0d07c923a878e3207bf243704196b0.jpg'),
(59522, 4043, 'O Incrível Mundo de Gumball S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/153407.mp4', 'http://timg.bdta.pro/images/fe4bdf9549c8244546afb647a5aaeaa0.jpg'),
(59523, 4043, 'O Incrível Mundo de Gumball S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/153408.mp4', 'http://timg.bdta.pro/images/0fb37b9e014be0eb1d0fb028f53ff177.jpg'),
(59524, 4043, 'O Incrível Mundo de Gumball S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/153409.mp4', 'http://timg.bdta.pro/images/b9ff6363edc61fafe8096f27b5345fe9.jpg'),
(59525, 4043, 'O Incrível Mundo de Gumball S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/153410.mp4', 'http://timg.bdta.pro/images/703b921b743ecdfb3597c7ab12399725.jpg'),
(59526, 4043, 'O Incrível Mundo de Gumball S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/153411.mp4', 'http://timg.bdta.pro/images/55e9c8b0f6035dbfdf858ffd4d1ae954.jpg'),
(59527, 4043, 'O Incrível Mundo de Gumball S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/153412.mp4', 'http://timg.bdta.pro/images/ed9665bfc6b08eda9c070da985797138.jpg'),
(59528, 4043, 'O Incrível Mundo de Gumball S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/153413.mp4', 'http://timg.bdta.pro/images/97dfb6056f3a3a14327222b583ee048e.jpg'),
(59529, 4043, 'O Incrível Mundo de Gumball S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/153414.mp4', 'http://timg.bdta.pro/images/0de37c6439869c5ee5ce040b23ead27f.jpg'),
(59530, 4043, 'O Incrível Mundo de Gumball S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/153415.mp4', 'http://timg.bdta.pro/images/4c56b925bbb86e6f546cdddb75b5b6a0.jpg'),
(59531, 4043, 'O Incrível Mundo de Gumball S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/153416.mp4', 'http://timg.bdta.pro/images/1d272f204d7283242838db31c189102f.jpg'),
(59532, 4043, 'O Incrível Mundo de Gumball S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/153417.mp4', 'http://timg.bdta.pro/images/fa2271c70a0090ee7edb1d299ebd9468.jpg'),
(59533, 4043, 'O Incrível Mundo de Gumball S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/153418.mp4', 'http://timg.bdta.pro/images/4146e1ee06eaee2578043b903826546a.jpg'),
(59534, 4043, 'O Incrível Mundo de Gumball S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/153419.mp4', 'http://timg.bdta.pro/images/a9745eb0ab9f8ab5b3970e7c6a4744ac.jpg'),
(59535, 4043, 'O Incrível Mundo de Gumball S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/153420.mp4', 'http://timg.bdta.pro/images/457d96af32f91e9e79a545c270df355d.jpg'),
(59536, 4043, 'O Incrível Mundo de Gumball S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/153421.mp4', 'http://timg.bdta.pro/images/26405ae2a2acc4522f6dcbf601e03f66.jpg'),
(59537, 4043, 'O Incrível Mundo de Gumball S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/153422.mp4', 'http://timg.bdta.pro/images/add04d75233d39772735beded8be4000.jpg'),
(59538, 4043, 'O Incrível Mundo de Gumball S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/153423.mp4', 'http://timg.bdta.pro/images/70960298b5b144ed86a727d159ebfa11.jpg'),
(59539, 4043, 'O Incrível Mundo de Gumball S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/153424.mp4', 'http://timg.bdta.pro/images/90a5c21ce1c6cd4ad5ac1d06b6e6e84c.jpg'),
(59540, 4043, 'O Incrível Mundo de Gumball S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/153425.mp4', 'http://timg.bdta.pro/images/a6eb111cd86674e88f59339d4f573860.jpg'),
(59541, 4044, 'O Incrível Mundo de Gumball S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153426.mp4', 'http://timg.bdta.pro/images/95c76ee1f1fb9f4ce44df6a83c05052f.jpg'),
(59542, 4044, 'O Incrível Mundo de Gumball S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153427.mp4', 'http://timg.bdta.pro/images/49db30b8a68b48ae81fb745a4e302087.jpg'),
(59543, 4044, 'O Incrível Mundo de Gumball S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153428.mp4', 'http://timg.bdta.pro/images/393750533ead9931b33a437b25c1eea8.jpg'),
(59544, 4044, 'O Incrível Mundo de Gumball S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153429.mp4', 'http://timg.bdta.pro/images/58a08e23b68ee10f220b70d2127809ac.jpg'),
(59545, 4044, 'O Incrível Mundo de Gumball S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153430.mp4', 'http://timg.bdta.pro/images/8bc0b0d228a616e2119ad6ac9a66aac0.jpg'),
(59546, 4044, 'O Incrível Mundo de Gumball S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153431.mp4', 'http://timg.bdta.pro/images/681dd7830a0375ea956d5a11288e5f40.jpg'),
(59547, 4044, 'O Incrível Mundo de Gumball S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153432.mp4', 'http://timg.bdta.pro/images/be7ea719a8794c7e647b50c983a39207.jpg'),
(59548, 4044, 'O Incrível Mundo de Gumball S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153433.mp4', 'http://timg.bdta.pro/images/6f268254301ea3d0cfff0fa45705e1f6.jpg'),
(59549, 4044, 'O Incrível Mundo de Gumball S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153434.mp4', 'http://timg.bdta.pro/images/c220e8dbd81e1cc78111872b06fb25d8.jpg'),
(59550, 4044, 'O Incrível Mundo de Gumball S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153435.mp4', 'http://timg.bdta.pro/images/193e84876097131dd97705a7a6e3d9b7.jpg'),
(59551, 4044, 'O Incrível Mundo de Gumball S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153436.mp4', 'http://timg.bdta.pro/images/c275d2cd099314f700d3a3546ef19dc8.jpg'),
(59552, 4044, 'O Incrível Mundo de Gumball S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153437.mp4', 'http://timg.bdta.pro/images/2da23a4ba17721309b63e4f45cc16cb7.jpg'),
(59553, 4044, 'O Incrível Mundo de Gumball S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153438.mp4', 'http://timg.bdta.pro/images/91bc56c67fd9a67dfa59a0c880cc5b70.jpg'),
(59554, 4044, 'O Incrível Mundo de Gumball S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153439.mp4', 'http://timg.bdta.pro/images/d616deaa769390653f5afaaa2ed9aa12.jpg'),
(59555, 4044, 'O Incrível Mundo de Gumball S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153440.mp4', 'http://timg.bdta.pro/images/07e9b362ecd18fb45a12353982c410f5.jpg'),
(59556, 4044, 'O Incrível Mundo de Gumball S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/153441.mp4', 'http://timg.bdta.pro/images/bfbd9405c2492762d6e07c8a488a25d8.jpg'),
(59557, 4044, 'O Incrível Mundo de Gumball S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/153442.mp4', 'http://timg.bdta.pro/images/a8984d4a89df3da73bc65d94310b67b2.jpg'),
(59558, 4044, 'O Incrível Mundo de Gumball S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/153443.mp4', 'http://timg.bdta.pro/images/c9224deba90b4e0fe1a42012f897d324.jpg'),
(59559, 4044, 'O Incrível Mundo de Gumball S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/153444.mp4', 'http://timg.bdta.pro/images/9bb553386014ab6a799baba84c471f6c.jpg'),
(59560, 4044, 'O Incrível Mundo de Gumball S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/153445.mp4', 'http://timg.bdta.pro/images/a63c394b41c2cedd894685f8079d27e2.jpg'),
(59561, 4044, 'O Incrível Mundo de Gumball S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/153446.mp4', 'http://timg.bdta.pro/images/3e4c78fd507559846e4161c28392ae3b.jpg'),
(59562, 4044, 'O Incrível Mundo de Gumball S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/153447.mp4', 'http://timg.bdta.pro/images/35ef68ce4543605dfe3678be7d214182.jpg'),
(59563, 4044, 'O Incrível Mundo de Gumball S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/153448.mp4', 'http://timg.bdta.pro/images/ec77fc761b1946d6f90436905dece60a.jpg'),
(59564, 4044, 'O Incrível Mundo de Gumball S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/153449.mp4', 'http://timg.bdta.pro/images/b1e308fa0421134e001d065167fc3ecd.jpg'),
(59565, 4044, 'O Incrível Mundo de Gumball S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/153450.mp4', 'http://timg.bdta.pro/images/e5a933ab923580f9ccee408feb9357c2.jpg'),
(59566, 4044, 'O Incrível Mundo de Gumball S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/153451.mp4', 'http://timg.bdta.pro/images/eadff1282569f5b1e077ef3887343727.jpg'),
(59567, 4044, 'O Incrível Mundo de Gumball S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/153452.mp4', 'http://timg.bdta.pro/images/f91b2548d31662cea5b379c01428f9c1.jpg'),
(59568, 4044, 'O Incrível Mundo de Gumball S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/153453.mp4', 'http://timg.bdta.pro/images/cf1d17b49b19690f2606219ca5ed422c.jpg'),
(59569, 4044, 'O Incrível Mundo de Gumball S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/153454.mp4', 'http://timg.bdta.pro/images/b6d62e37249f23504b0a3a03f17427eb.jpg'),
(59570, 4044, 'O Incrível Mundo de Gumball S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/153455.mp4', 'http://timg.bdta.pro/images/8f419bb0305b7296c2eeba0a5de30a50.jpg'),
(59571, 4044, 'O Incrível Mundo de Gumball S05 E31', 'http://sinalprivado.info:80/series/1533784/1533784/153456.mp4', 'http://timg.bdta.pro/images/06f2edf7e9036aa5713b85faaad882b8.jpg'),
(59572, 4044, 'O Incrível Mundo de Gumball S05 E32', 'http://sinalprivado.info:80/series/1533784/1533784/153457.mp4', 'http://timg.bdta.pro/images/528c2e2aecaa0cc062595a200a39ae02.jpg'),
(59573, 4044, 'O Incrível Mundo de Gumball S05 E33', 'http://sinalprivado.info:80/series/1533784/1533784/153458.mp4', 'http://timg.bdta.pro/images/73eedc82e0a0ae3e6145b1939fe33d58.jpg'),
(59574, 4044, 'O Incrível Mundo de Gumball S05 E34', 'http://sinalprivado.info:80/series/1533784/1533784/153459.mp4', 'http://timg.bdta.pro/images/67e5c70c270921d304af871475ab32b0.jpg'),
(59575, 4044, 'O Incrível Mundo de Gumball S05 E35', 'http://sinalprivado.info:80/series/1533784/1533784/153460.mp4', 'http://timg.bdta.pro/images/7ebf09bbc8f8f24122f730bdba8e7143.jpg'),
(59576, 4044, 'O Incrível Mundo de Gumball S05 E36', 'http://sinalprivado.info:80/series/1533784/1533784/153461.mp4', 'http://timg.bdta.pro/images/3a6d75c0480ca4c245555a9e641901ab.jpg'),
(59577, 4044, 'O Incrível Mundo de Gumball S05 E37', 'http://sinalprivado.info:80/series/1533784/1533784/153462.mp4', 'http://timg.bdta.pro/images/17fb346b04e34c049abe45a72733e1b2.jpg'),
(59578, 4044, 'O Incrível Mundo de Gumball S05 E38', 'http://sinalprivado.info:80/series/1533784/1533784/153463.mp4', 'http://timg.bdta.pro/images/e18b6db33b71bd427762512ae70eb79e.jpg'),
(59579, 4044, 'O Incrível Mundo de Gumball S05 E39', 'http://sinalprivado.info:80/series/1533784/1533784/153464.mp4', 'http://timg.bdta.pro/images/a17c5f497755545b7ef53c7fa70ba994.jpg'),
(59580, 4044, 'O Incrível Mundo de Gumball S05 E40', 'http://sinalprivado.info:80/series/1533784/1533784/153465.mp4', 'http://timg.bdta.pro/images/7886f0216e26705ca662e9c36f330a60.jpg'),
(59581, 4045, 'O Incrível Mundo de Gumball S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153466.mp4', 'http://timg.bdta.pro/images/e2878526bae8bc407084c60778d5f92f.jpg'),
(59582, 4045, 'O Incrível Mundo de Gumball S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153467.mp4', 'http://timg.bdta.pro/images/dc45d1ccf4de98196c0226ba294b1b4b.jpg'),
(59583, 4045, 'O Incrível Mundo de Gumball S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153468.mp4', 'http://timg.bdta.pro/images/42afb3cbf781519e04bd70db58295d30.jpg'),
(59584, 4045, 'O Incrível Mundo de Gumball S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153469.mp4', 'http://timg.bdta.pro/images/14c9ae55259226cadf95df6595472ed1.jpg'),
(59585, 4045, 'O Incrível Mundo de Gumball S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153470.mp4', 'http://timg.bdta.pro/images/214fad64e1fa3155ce89915c87862f0c.jpg'),
(59586, 4045, 'O Incrível Mundo de Gumball S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153471.mp4', 'http://timg.bdta.pro/images/84a9be7b20c783d1e8b7f6c256889b46.jpg'),
(59587, 4045, 'O Incrível Mundo de Gumball S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153472.mp4', 'http://timg.bdta.pro/images/ec8f37b0f14366674fc74e97b7bc2dc1.jpg'),
(59588, 4045, 'O Incrível Mundo de Gumball S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153473.mp4', 'http://timg.bdta.pro/images/06226663b74e2ee47186ec56ab5bc03f.jpg'),
(59589, 4045, 'O Incrível Mundo de Gumball S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153474.mp4', 'http://timg.bdta.pro/images/91110ffa8fddbdccb55ce3367fcf7bc2.jpg'),
(59590, 4045, 'O Incrível Mundo de Gumball S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153475.mp4', 'http://timg.bdta.pro/images/64a49009e8ee2f7a3e92c610a43a4d53.jpg'),
(59591, 4045, 'O Incrível Mundo de Gumball S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153476.mp4', 'http://timg.bdta.pro/images/3e2bc7d5b65a7054731bbff48ad95814.jpg'),
(59592, 4045, 'O Incrível Mundo de Gumball S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153477.mp4', 'http://timg.bdta.pro/images/1228535488de7d70b4d3f0f8b4487a06.jpg'),
(59593, 4045, 'O Incrível Mundo de Gumball S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153478.mp4', 'http://timg.bdta.pro/images/7a1f7ebd3ecc2d2fe20144416c697c94.jpg'),
(59594, 4045, 'O Incrível Mundo de Gumball S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153479.mp4', 'http://timg.bdta.pro/images/b4c27903868b575fd889ffd3550707e0.jpg'),
(59595, 4045, 'O Incrível Mundo de Gumball S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153480.mp4', 'http://timg.bdta.pro/images/853b00f5648457f36df4b464566bf9b6.jpg'),
(59596, 4045, 'O Incrível Mundo de Gumball S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/153481.mp4', 'http://timg.bdta.pro/images/a0c0ffdeb45032a47cecc4451ac973c0.jpg'),
(59597, 4045, 'O Incrível Mundo de Gumball S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/153482.mp4', 'http://timg.bdta.pro/images/49cab7b61d0236942656d238190d8852.jpg'),
(59598, 4045, 'O Incrível Mundo de Gumball S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/153483.mp4', 'http://timg.bdta.pro/images/ebb7e255ba1c8abe0574db4a6da48057.jpg'),
(59599, 4045, 'O Incrível Mundo de Gumball S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/153484.mp4', 'http://timg.bdta.pro/images/f24f72c1e6c1a9623981f16e1a8f0c46.jpg'),
(59600, 4045, 'O Incrível Mundo de Gumball S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/153485.mp4', 'http://timg.bdta.pro/images/85c803c6e5a1598bf638f5e490ef68eb.jpg'),
(59601, 4045, 'O Incrível Mundo de Gumball S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/153486.mp4', 'http://timg.bdta.pro/images/6af7012a781c0de3bd696020591c6d27.jpg'),
(59602, 4045, 'O Incrível Mundo de Gumball S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/153487.mp4', 'http://timg.bdta.pro/images/eae48b9aa7391c2115feffdcdb9ba2ce.jpg'),
(59603, 4045, 'O Incrível Mundo de Gumball S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/153488.mp4', 'http://timg.bdta.pro/images/d02319aee07242d960625e101ee8ba7f.jpg'),
(59604, 4045, 'O Incrível Mundo de Gumball S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/153489.mp4', 'http://timg.bdta.pro/images/0dab35bda425091788045e3a0610212e.jpg'),
(59605, 4045, 'O Incrível Mundo de Gumball S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/153490.mp4', 'http://timg.bdta.pro/images/62beb39fb7ff3eca45ff2615f1a0b4d3.jpg'),
(59606, 4045, 'O Incrível Mundo de Gumball S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/153491.mp4', 'http://timg.bdta.pro/images/00c163f10d295914843b480fde60d91f.jpg'),
(59607, 4045, 'O Incrível Mundo de Gumball S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/153492.mp4', 'http://timg.bdta.pro/images/1d00f2841d63f7615c8af11e9ddd1036.jpg'),
(59608, 4045, 'O Incrível Mundo de Gumball S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/153493.mp4', 'http://timg.bdta.pro/images/ae50f86933c4456225b2ed356eb050ce.jpg'),
(59609, 4045, 'O Incrível Mundo de Gumball S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/153494.mp4', 'http://timg.bdta.pro/images/1868e8ba918ae018cb4323a3ef06766c.jpg'),
(59610, 4045, 'O Incrível Mundo de Gumball S06 E30', 'http://sinalprivado.info:80/series/1533784/1533784/153495.mp4', 'http://timg.bdta.pro/images/c08625c9952819a018490a5f1ba712f1.jpg'),
(59611, 4045, 'O Incrível Mundo de Gumball S06 E31', 'http://sinalprivado.info:80/series/1533784/1533784/153496.mp4', 'http://timg.bdta.pro/images/ce7ab0abbc703bb5f998fe98a35b2f66.jpg'),
(59612, 4045, 'O Incrível Mundo de Gumball S06 E32', 'http://sinalprivado.info:80/series/1533784/1533784/153497.mp4', 'http://gstaticontent.com/images/56becdd766578ae00c91530684d7a781.jpg'),
(59613, 4045, 'O Incrível Mundo de Gumball S06 E33', 'http://sinalprivado.info:80/series/1533784/1533784/153498.mp4', 'http://gstaticontent.com/images/56becdd766578ae00c91530684d7a781.jpg'),
(59614, 4045, 'O Incrível Mundo de Gumball S06 E34', 'http://sinalprivado.info:80/series/1533784/1533784/153499.mp4', 'http://gstaticontent.com/images/56becdd766578ae00c91530684d7a781.jpg'),
(59615, 4045, 'O Incrível Mundo de Gumball S06 E35', 'http://sinalprivado.info:80/series/1533784/1533784/153500.mp4', 'http://gstaticontent.com/images/56becdd766578ae00c91530684d7a781.jpg'),
(59616, 4045, 'O Incrível Mundo de Gumball S06 E36', 'http://sinalprivado.info:80/series/1533784/1533784/153501.mp4', 'http://gstaticontent.com/images/56becdd766578ae00c91530684d7a781.jpg'),
(59617, 4045, 'O Incrível Mundo de Gumball S06 E37', 'http://sinalprivado.info:80/series/1533784/1533784/153502.mp4', 'http://gstaticontent.com/images/56becdd766578ae00c91530684d7a781.jpg'),
(59618, 4045, 'O Incrível Mundo de Gumball S06 E38', 'http://sinalprivado.info:80/series/1533784/1533784/153503.mp4', 'http://gstaticontent.com/images/56becdd766578ae00c91530684d7a781.jpg'),
(59619, 4045, 'O Incrível Mundo de Gumball S06 E39', 'http://sinalprivado.info:80/series/1533784/1533784/153504.mp4', 'http://gstaticontent.com/images/56becdd766578ae00c91530684d7a781.jpg'),
(59620, 4045, 'O Incrível Mundo de Gumball S06 E40', 'http://sinalprivado.info:80/series/1533784/1533784/153505.mp4', 'http://gstaticontent.com/images/56becdd766578ae00c91530684d7a781.jpg'),
(59621, 4045, 'O Incrível Mundo de Gumball S06 E41', 'http://sinalprivado.info:80/series/1533784/1533784/153506.mp4', 'http://gstaticontent.com/images/56becdd766578ae00c91530684d7a781.jpg'),
(59622, 4045, 'O Incrível Mundo de Gumball S06 E42', 'http://sinalprivado.info:80/series/1533784/1533784/153507.mp4', 'http://gstaticontent.com/images/56becdd766578ae00c91530684d7a781.jpg'),
(59623, 4045, 'O Incrível Mundo de Gumball S06 E43', 'http://sinalprivado.info:80/series/1533784/1533784/153508.mp4', 'http://gstaticontent.com/images/56becdd766578ae00c91530684d7a781.jpg'),
(59624, 4045, 'O Incrível Mundo de Gumball S06 E44', 'http://sinalprivado.info:80/series/1533784/1533784/153509.mp4', 'http://gstaticontent.com/images/56becdd766578ae00c91530684d7a781.jpg'),
(59625, 4046, 'Eles S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153279.mp4', 'http://timg.bdta.pro/images/f898a0cc8176da93ac97c1c7122fcdab.jpg'),
(59626, 4046, 'Eles S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153280.mp4', 'http://timg.bdta.pro/images/244712301ea703ce0025db9285390b3a.jpg'),
(59627, 4046, 'Eles S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153281.mp4', 'http://timg.bdta.pro/images/0a6735905f41f1c78b2638fb0e89a58a.jpg'),
(59628, 4046, 'Eles S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153282.mp4', 'http://timg.bdta.pro/images/97aef1f9c634fea90020b3eff77e54d0.jpg'),
(59629, 4046, 'Eles S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153283.mp4', 'http://timg.bdta.pro/images/90f3549cbf0915e3ad30511802db60a8.jpg'),
(59630, 4046, 'Eles S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153284.mp4', 'http://timg.bdta.pro/images/3a8dc139552b26004fd1e20c8bd3d1e5.jpg'),
(59631, 4046, 'Eles S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153285.mp4', 'http://timg.bdta.pro/images/fa7904e522a95d7fedc5a4d93c609f01.jpg'),
(59632, 4046, 'Eles S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153286.mp4', 'http://timg.bdta.pro/images/ced44c2bf9b9a39c96c441721ef6fe95.jpg'),
(59633, 4046, 'Eles S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153287.mp4', 'http://timg.bdta.pro/images/4defb4af48185e01789072faf768f6b9.jpg'),
(59634, 4046, 'Eles S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153288.mp4', 'http://timg.bdta.pro/images/be9e3899792f0a3b0fef810df457f3ad.jpg'),
(59635, 4047, 'Eles S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/444755.mp4', 'http://gstaticontent.com/images/e69cc8b991aa7c3303e856947a4ceffa.jpg'),
(59636, 4047, 'Eles S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/444756.mp4', 'http://gstaticontent.com/images/e69cc8b991aa7c3303e856947a4ceffa.jpg'),
(59637, 4047, 'Eles S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/444757.mp4', 'http://gstaticontent.com/images/e69cc8b991aa7c3303e856947a4ceffa.jpg'),
(59638, 4047, 'Eles S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/444758.mp4', 'http://gstaticontent.com/images/e69cc8b991aa7c3303e856947a4ceffa.jpg'),
(59639, 4047, 'Eles S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/444759.mp4', 'http://gstaticontent.com/images/e69cc8b991aa7c3303e856947a4ceffa.jpg'),
(59640, 4047, 'Eles S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/444760.mp4', 'http://gstaticontent.com/images/e69cc8b991aa7c3303e856947a4ceffa.jpg'),
(59641, 4047, 'Eles S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/444761.mp4', 'http://gstaticontent.com/images/e69cc8b991aa7c3303e856947a4ceffa.jpg'),
(59642, 4047, 'Eles S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/444762.mp4', 'http://gstaticontent.com/images/e69cc8b991aa7c3303e856947a4ceffa.jpg'),
(59643, 4048, 'Porchat? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254229.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59644, 4048, 'Porchat? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254230.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59645, 4048, 'Porchat? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254231.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59646, 4048, 'Porchat? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254232.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59647, 4048, 'Porchat? S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254233.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59648, 4048, 'Porchat? S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254234.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59649, 4048, 'Porchat? S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254235.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59650, 4048, 'Porchat? S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254236.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59651, 4048, 'Porchat? S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254237.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59652, 4048, 'Porchat? S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254238.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59653, 4048, 'Porchat? S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254239.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59654, 4048, 'Porchat? S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254240.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59655, 4048, 'Porchat? S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254241.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59656, 4048, 'Porchat? S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/254242.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59657, 4048, 'Porchat? S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/254243.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59658, 4048, 'Porchat? S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/254244.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59659, 4048, 'Porchat? S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/254245.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59660, 4048, 'Porchat? S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/254246.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59661, 4048, 'Porchat? S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/254247.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59662, 4048, 'Porchat? S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/254248.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59663, 4049, 'Porchat? S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254249.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59664, 4049, 'Porchat? S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254250.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59665, 4049, 'Porchat? S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254251.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59666, 4049, 'Porchat? S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254252.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59667, 4049, 'Porchat? S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254253.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59668, 4049, 'Porchat? S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254254.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59669, 4049, 'Porchat? S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254255.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59670, 4049, 'Porchat? S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254256.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59671, 4049, 'Porchat? S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254257.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59672, 4049, 'Porchat? S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254258.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59673, 4049, 'Porchat? S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254259.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59674, 4049, 'Porchat? S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254260.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59675, 4049, 'Porchat? S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254261.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59676, 4049, 'Porchat? S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/254262.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59677, 4049, 'Porchat? S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/254263.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59678, 4050, 'Porchat? S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254264.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59679, 4050, 'Porchat? S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254265.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59680, 4050, 'Porchat? S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254266.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59681, 4050, 'Porchat? S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254267.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59682, 4050, 'Porchat? S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254268.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59683, 4050, 'Porchat? S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254269.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59684, 4050, 'Porchat? S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254270.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59685, 4050, 'Porchat? S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254271.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59686, 4050, 'Porchat? S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254272.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59687, 4050, 'Porchat? S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254273.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59688, 4050, 'Porchat? S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254274.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59689, 4050, 'Porchat? S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254275.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59690, 4050, 'Porchat? S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254276.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59691, 4050, 'Porchat? S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/254277.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59692, 4050, 'Porchat? S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/254278.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59693, 4050, 'Porchat? S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/254279.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59694, 4050, 'Porchat? S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/254280.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59695, 4050, 'Porchat? S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/254281.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59696, 4050, 'Porchat? S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/254282.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59697, 4050, 'Porchat? S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/254283.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59698, 4050, 'Porchat? S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/254284.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59699, 4050, 'Porchat? S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/254285.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59700, 4050, 'Porchat? S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/254286.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59701, 4050, 'Porchat? S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/254287.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59702, 4050, 'Porchat? S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/254288.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59703, 4050, 'Porchat? S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/254289.mp4', 'http://image.tmdb.org/t/p/w1280/kqhLORyn6IGD9QiyZFNeQBN4X3C.jpg'),
(59704, 4050, 'Porchat? S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/254290.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59705, 4050, 'Porchat? S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/254291.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59706, 4050, 'Porchat? S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/254292.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59707, 4050, 'Porchat? S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/254293.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59708, 4050, 'Porchat? S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/254294.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59709, 4050, 'Porchat? S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/254295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/81egEtzPbrZDJFgQGPJw1TyuZfc.jpg'),
(59710, 4050, 'Porchat? S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/254296.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59711, 4050, 'Porchat? S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/254297.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59712, 4050, 'Porchat? S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/254298.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59713, 4050, 'Porchat? S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/254299.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59714, 4050, 'Porchat? S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/254300.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59715, 4050, 'Porchat? S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/254301.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59716, 4050, 'Porchat? S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/254302.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59717, 4050, 'Porchat? S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/254303.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59718, 4051, 'Porchat? S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254304.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59719, 4051, 'Porchat? S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254305.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59720, 4051, 'Porchat? S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254306.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59721, 4051, 'Porchat? S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254307.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59722, 4051, 'Porchat? S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254308.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59723, 4051, 'Porchat? S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254309.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59724, 4051, 'Porchat? S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254310.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59725, 4051, 'Porchat? S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254311.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59726, 4051, 'Porchat? S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254312.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59727, 4051, 'Porchat? S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254313.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59728, 4051, 'Porchat? S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254314.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59729, 4051, 'Porchat? S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254315.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59730, 4051, 'Porchat? S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254316.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59731, 4051, 'Porchat? S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/254317.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(59732, 4051, 'Porchat? S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/254318.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59733, 4051, 'Porchat? S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/254319.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59734, 4051, 'Porchat? S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/254320.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59735, 4051, 'Porchat? S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/254321.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59736, 4051, 'Porchat? S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/254322.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59737, 4051, 'Porchat? S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/254323.mp4', 'http://timg.bdta.pro/images/2c4d8b14aca3074ad4bcf0400a81892d.jpg'),
(59738, 4051, 'Porchat? S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/254324.mp4', 'http://timg.bdta.pro/images/080171fd2fc892b6f88981e9a31fecff.jpg'),
(59739, 4051, 'Porchat? S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/254325.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59740, 4051, 'Porchat? S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/254326.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59741, 4051, 'Porchat? S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/254327.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59742, 4051, 'Porchat? S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/254328.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59743, 4051, 'Porchat? S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/254329.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59744, 4051, 'Porchat? S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/254330.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59745, 4051, 'Porchat? S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/254331.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59746, 4051, 'Porchat? S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/254332.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59747, 4051, 'Porchat? S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/254333.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59748, 4051, 'Porchat? S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/254334.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59749, 4051, 'Porchat? S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/254335.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59750, 4051, 'Porchat? S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/254336.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59751, 4051, 'Porchat? S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/254337.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59752, 4051, 'Porchat? S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/254338.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59753, 4051, 'Porchat? S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/254339.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59754, 4051, 'Porchat? S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/254340.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59755, 4051, 'Porchat? S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/254341.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59756, 4051, 'Porchat? S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/254342.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59757, 4051, 'Porchat? S04 E40', 'http://sinalprivado.info:80/series/1533784/1533784/254343.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59758, 4052, 'Porchat? S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254344.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59759, 4052, 'Porchat? S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254345.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59760, 4052, 'Porchat? S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254346.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59761, 4052, 'Porchat? S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254347.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59762, 4052, 'Porchat? S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254348.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59763, 4052, 'Porchat? S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254349.mp4', 'http://image.tmdb.org/t/p/w1280/ca6ZCzFYtZek2QARJF73hLHQDjW.jpg'),
(59764, 4052, 'Porchat? S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254350.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59765, 4052, 'Porchat? S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254351.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59766, 4052, 'Porchat? S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254352.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59767, 4052, 'Porchat? S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254353.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59768, 4052, 'Porchat? S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254354.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59769, 4052, 'Porchat? S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254355.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59770, 4052, 'Porchat? S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254356.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59771, 4052, 'Porchat? S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/254357.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59772, 4052, 'Porchat? S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/254358.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59773, 4052, 'Porchat? S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/254359.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59774, 4052, 'Porchat? S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/254360.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59775, 4052, 'Porchat? S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/254361.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59776, 4052, 'Porchat? S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/254362.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59777, 4052, 'Porchat? S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/254363.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59778, 4052, 'Porchat? S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/254364.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59779, 4052, 'Porchat? S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/254365.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59780, 4052, 'Porchat? S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/254366.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59781, 4052, 'Porchat? S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/254367.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59782, 4052, 'Porchat? S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/254368.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59783, 4052, 'Porchat? S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/254369.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59784, 4052, 'Porchat? S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/254370.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59785, 4052, 'Porchat? S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/254371.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59786, 4052, 'Porchat? S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/254372.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59787, 4052, 'Porchat? S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/254373.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59788, 4052, 'Porchat? S05 E31', 'http://sinalprivado.info:80/series/1533784/1533784/254374.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59789, 4052, 'Porchat? S05 E32', 'http://sinalprivado.info:80/series/1533784/1533784/254375.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59790, 4052, 'Porchat? S05 E33', 'http://sinalprivado.info:80/series/1533784/1533784/254376.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59791, 4052, 'Porchat? S05 E34', 'http://sinalprivado.info:80/series/1533784/1533784/254377.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59792, 4052, 'Porchat? S05 E35', 'http://sinalprivado.info:80/series/1533784/1533784/254378.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59793, 4052, 'Porchat? S05 E36', 'http://sinalprivado.info:80/series/1533784/1533784/254379.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59794, 4052, 'Porchat? S05 E37', 'http://sinalprivado.info:80/series/1533784/1533784/254380.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59795, 4052, 'Porchat? S05 E38', 'http://sinalprivado.info:80/series/1533784/1533784/254381.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59796, 4052, 'Porchat? S05 E39', 'http://sinalprivado.info:80/series/1533784/1533784/254382.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59797, 4053, 'Porchat? S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/301283.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59798, 4053, 'Porchat? S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/304273.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59799, 4053, 'Porchat? S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/309915.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59800, 4053, 'Porchat? S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/317496.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59801, 4053, 'Porchat? S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/323843.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59802, 4053, 'Porchat? S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331296.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59803, 4053, 'Porchat? S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/336266.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59804, 4053, 'Porchat? S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/351583.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59805, 4053, 'Porchat? S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/351584.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59806, 4053, 'Porchat? S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/351585.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59807, 4053, 'Porchat? S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/358904.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59808, 4053, 'Porchat? S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/365324.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59809, 4053, 'Porchat? S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/373341.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59810, 4053, 'Porchat? S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/381108.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59811, 4053, 'Porchat? S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/388883.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59812, 4053, 'Porchat? S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/394495.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59813, 4053, 'Porchat? S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/400462.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59814, 4053, 'Porchat? S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/406355.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59815, 4053, 'Porchat? S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/411681.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59816, 4053, 'Porchat? S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/414624.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59817, 4053, 'Porchat? S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/421068.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59818, 4053, 'Porchat? S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/426878.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59819, 4053, 'Porchat? S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/429175.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59820, 4053, 'Porchat? S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/439167.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59821, 4053, 'Porchat? S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/441528.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59822, 4053, 'Porchat? S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/451224.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59823, 4053, 'Porchat? S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/452195.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59824, 4053, 'Porchat? S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/457380.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59825, 4053, 'Porchat? S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/463995.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59826, 4053, 'Porchat? S06 E30', 'http://sinalprivado.info:80/series/1533784/1533784/469720.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59827, 4053, 'Porchat? S06 E31', 'http://sinalprivado.info:80/series/1533784/1533784/481253.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59828, 4053, 'Porchat? S06 E32', 'http://sinalprivado.info:80/series/1533784/1533784/481254.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59829, 4053, 'Porchat? S06 E33', 'http://sinalprivado.info:80/series/1533784/1533784/490470.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59830, 4053, 'Porchat? S06 E34', 'http://sinalprivado.info:80/series/1533784/1533784/498150.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59831, 4053, 'Porchat? S06 E35', 'http://sinalprivado.info:80/series/1533784/1533784/499829.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59832, 4053, 'Porchat? S06 E36', 'http://sinalprivado.info:80/series/1533784/1533784/505150.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59833, 4053, 'Porchat? S06 E37', 'http://sinalprivado.info:80/series/1533784/1533784/512998.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59834, 4053, 'Porchat? S06 E38', 'http://sinalprivado.info:80/series/1533784/1533784/517503.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59835, 4053, 'Porchat? S06 E39', 'http://sinalprivado.info:80/series/1533784/1533784/517504.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59836, 4053, 'Porchat? S06 E40', 'http://sinalprivado.info:80/series/1533784/1533784/522161.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59837, 4054, 'Porchat? S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/736465.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59838, 4054, 'Porchat? S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/741348.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59839, 4054, 'Porchat? S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/753686.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59840, 4054, 'Porchat? S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/764296.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59841, 4054, 'Porchat? S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/772655.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59842, 4054, 'Porchat? S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/778809.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59843, 4054, 'Porchat? S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/786711.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59844, 4054, 'Porchat? S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/789454.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59845, 4054, 'Porchat? S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/802196.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59846, 4054, 'Porchat? S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/811554.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59847, 4054, 'Porchat? S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/820656.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59848, 4054, 'Porchat? S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/823700.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59849, 4054, 'Porchat? S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/835560.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59850, 4054, 'Porchat? S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/845318.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59851, 4054, 'Porchat? S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/850399.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59852, 4054, 'Porchat? S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/857002.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59853, 4054, 'Porchat? S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/864330.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59854, 4054, 'Porchat? S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/870175.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59855, 4054, 'Porchat? S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/873817.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59856, 4054, 'Porchat? S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/879406.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59857, 4054, 'Porchat? S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/879882.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59858, 4054, 'Porchat? S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/880364.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59859, 4054, 'Porchat? S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/881182.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59860, 4054, 'Porchat? S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/881306.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59861, 4054, 'Porchat? S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/882197.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59862, 4054, 'Porchat? S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/883783.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59863, 4054, 'Porchat? S07 E27', 'http://sinalprivado.info:80/series/1533784/1533784/885310.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59864, 4054, 'Porchat? S07 E28', 'http://sinalprivado.info:80/series/1533784/1533784/886062.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59865, 4054, 'Porchat? S07 E29', 'http://sinalprivado.info:80/series/1533784/1533784/888146.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59866, 4054, 'Porchat? S07 E30', 'http://sinalprivado.info:80/series/1533784/1533784/888147.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59867, 4054, 'Porchat? S07 E31', 'http://sinalprivado.info:80/series/1533784/1533784/889616.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59868, 4054, 'Porchat? S07 E32', 'http://sinalprivado.info:80/series/1533784/1533784/890676.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59869, 4054, 'Porchat? S07 E33', 'http://sinalprivado.info:80/series/1533784/1533784/890677.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59870, 4054, 'Porchat? S07 E34', 'http://sinalprivado.info:80/series/1533784/1533784/891846.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59871, 4054, 'Porchat? S07 E35', 'http://sinalprivado.info:80/series/1533784/1533784/892424.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59872, 4054, 'Porchat? S07 E36', 'http://sinalprivado.info:80/series/1533784/1533784/893099.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59873, 4054, 'Porchat? S07 E37', 'http://sinalprivado.info:80/series/1533784/1533784/893454.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59874, 4054, 'Porchat? S07 E38', 'http://sinalprivado.info:80/series/1533784/1533784/894202.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59875, 4054, 'Porchat? S07 E39', 'http://sinalprivado.info:80/series/1533784/1533784/895862.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59876, 4054, 'Porchat? S07 E40', 'http://sinalprivado.info:80/series/1533784/1533784/896390.mp4', 'http://gstaticontent.com/images/aef305d90abfb2734c9ca58cc2c73e2f.jpg'),
(59877, 4055, 'Ridley Jones S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162013.mp4', 'http://gstaticontent.com/images/1b1503554d9674ca4c20ea268cf10d65.jpg'),
(59878, 4055, 'Ridley Jones S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162014.mp4', 'http://gstaticontent.com/images/1b1503554d9674ca4c20ea268cf10d65.jpg'),
(59879, 4055, 'Ridley Jones S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162015.mp4', 'http://gstaticontent.com/images/1b1503554d9674ca4c20ea268cf10d65.jpg'),
(59880, 4055, 'Ridley Jones S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162016.mp4', 'http://gstaticontent.com/images/1b1503554d9674ca4c20ea268cf10d65.jpg'),
(59881, 4055, 'Ridley Jones S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162017.mp4', 'http://gstaticontent.com/images/1b1503554d9674ca4c20ea268cf10d65.jpg'),
(59882, 4055, 'Ridley Jones S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162018.mp4', 'http://gstaticontent.com/images/1b1503554d9674ca4c20ea268cf10d65.jpg'),
(59883, 4056, 'Ridley Jones S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162019.mp4', 'http://gstaticontent.com/images/1b1503554d9674ca4c20ea268cf10d65.jpg'),
(59884, 4056, 'Ridley Jones S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162020.mp4', 'http://gstaticontent.com/images/1b1503554d9674ca4c20ea268cf10d65.jpg'),
(59885, 4056, 'Ridley Jones S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162021.mp4', 'http://gstaticontent.com/images/1b1503554d9674ca4c20ea268cf10d65.jpg'),
(59886, 4056, 'Ridley Jones S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162022.mp4', 'http://gstaticontent.com/images/1b1503554d9674ca4c20ea268cf10d65.jpg'),
(59887, 4056, 'Ridley Jones S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162023.mp4', 'http://gstaticontent.com/images/1b1503554d9674ca4c20ea268cf10d65.jpg'),
(59888, 4057, 'Roubos Inacreditáveis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153273.mp4', 'http://timg.bdta.pro/images/094f40bdead300f02eea706b710c651e.jpg'),
(59889, 4057, 'Roubos Inacreditáveis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153274.mp4', 'http://timg.bdta.pro/images/65b373b429cad8491e3f6f8447d9edc4.jpg'),
(59890, 4057, 'Roubos Inacreditáveis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153275.mp4', 'http://timg.bdta.pro/images/c38dacb21aab566a1ab02b79c4ae191a.jpg'),
(59891, 4057, 'Roubos Inacreditáveis S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153276.mp4', 'http://timg.bdta.pro/images/ac71ded4f01c9c069e1204c1eb96dbcb.jpg'),
(59892, 4057, 'Roubos Inacreditáveis S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153277.mp4', 'http://timg.bdta.pro/images/38a0a38076ab8bc55eaf7ae063b86ebf.jpg'),
(59893, 4057, 'Roubos Inacreditáveis S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153278.mp4', 'http://timg.bdta.pro/images/107462e1c1e28d4bec0a98f75c7332a5.jpg'),
(59894, 4058, 'Uma Vida Nova S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/145856.mp4', 'http://timg.bdta.pro/images/b0ed9de714d8944b602f918d069d51c6.jpg'),
(59895, 4058, 'Uma Vida Nova S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/145857.mp4', 'http://timg.bdta.pro/images/66768fa21da4f5de100ab24a4ce88c04.jpg'),
(59896, 4058, 'Uma Vida Nova S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/145858.mp4', 'http://timg.bdta.pro/images/d6606e83704e23918d00c8593ac17e55.jpg'),
(59897, 4058, 'Uma Vida Nova S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/145859.mp4', 'http://timg.bdta.pro/images/7197a1335c985ab3c577c6d15e3892f0.jpg'),
(59898, 4058, 'Uma Vida Nova S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/145860.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59899, 4058, 'Uma Vida Nova S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/145861.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59900, 4058, 'Uma Vida Nova S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/145862.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59901, 4058, 'Uma Vida Nova S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/145863.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59902, 4058, 'Uma Vida Nova S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/145864.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59903, 4058, 'Uma Vida Nova S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/145865.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59904, 4058, 'Uma Vida Nova S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/145866.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59905, 4058, 'Uma Vida Nova S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/145867.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59906, 4058, 'Uma Vida Nova S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/145868.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59907, 4058, 'Uma Vida Nova S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/145869.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59908, 4058, 'Uma Vida Nova S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/145870.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59909, 4058, 'Uma Vida Nova S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/145871.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59910, 4058, 'Uma Vida Nova S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/145872.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59911, 4058, 'Uma Vida Nova S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/145873.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59912, 4058, 'Uma Vida Nova S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/145874.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59913, 4058, 'Uma Vida Nova S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/145875.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59914, 4058, 'Uma Vida Nova S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/145876.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59915, 4058, 'Uma Vida Nova S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/145877.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59916, 4058, 'Uma Vida Nova S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/145878.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59917, 4058, 'Uma Vida Nova S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/145879.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59918, 4058, 'Uma Vida Nova S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/145880.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59919, 4058, 'Uma Vida Nova S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/145881.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59920, 4058, 'Uma Vida Nova S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/145882.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59921, 4058, 'Uma Vida Nova S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/145883.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59922, 4058, 'Uma Vida Nova S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/145884.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59923, 4058, 'Uma Vida Nova S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/145885.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59924, 4058, 'Uma Vida Nova S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/145886.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59925, 4058, 'Uma Vida Nova S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/145887.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59926, 4058, 'Uma Vida Nova S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/145888.mp4', 'http://gstaticontent.com/images/460290b0f7e681380c5b2d7b96c653b7.jpg'),
(59927, 4059, 'A Escuta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153213.mp4', 'http://timg.bdta.pro/images/de8ba945e540cffe1413c12c6cb9c4e5.jpg'),
(59928, 4059, 'A Escuta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153214.mp4', 'http://timg.bdta.pro/images/e3fcad5a3757dba28a102b098cc6f9d2.jpg'),
(59929, 4059, 'A Escuta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153215.mp4', 'http://timg.bdta.pro/images/4eaa864a6711992efd1c1071c53b865e.jpg'),
(59930, 4059, 'A Escuta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153216.mp4', 'http://timg.bdta.pro/images/6487cf66e27e592ff3332b61c81d6c67.jpg'),
(59931, 4059, 'A Escuta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153217.mp4', 'http://timg.bdta.pro/images/673907f987773c2711a716699a7511f8.jpg'),
(59932, 4059, 'A Escuta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153218.mp4', 'http://timg.bdta.pro/images/6f516a41b3ad7bc785dec3be810e16e9.jpg'),
(59933, 4059, 'A Escuta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153219.mp4', 'http://timg.bdta.pro/images/bd8f53f69f5eed434beacb1acb6321eb.jpg'),
(59934, 4059, 'A Escuta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153220.mp4', 'http://timg.bdta.pro/images/b88fa3c5fa626d84d2c85eb8813eab28.jpg'),
(59935, 4059, 'A Escuta S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153221.mp4', 'http://timg.bdta.pro/images/21eed3769c21b8871c534df6ba5b3c6c.jpg'),
(59936, 4059, 'A Escuta S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153222.mp4', 'http://timg.bdta.pro/images/2dfb4f9e5d57decd52b08d287ef3f35d.jpg'),
(59937, 4059, 'A Escuta S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153223.mp4', 'http://timg.bdta.pro/images/2025ab34e604996723e5331d2783d005.jpg'),
(59938, 4059, 'A Escuta S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153224.mp4', 'http://timg.bdta.pro/images/d5754c2cf1f8d42d90c8220371451ee4.jpg'),
(59939, 4059, 'A Escuta S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153225.mp4', 'http://timg.bdta.pro/images/b6b1a195ae9809f05044206535e1bf34.jpg'),
(59940, 4060, 'A Escuta S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153226.mp4', 'http://timg.bdta.pro/images/7b2a2ac87af16a3e7b4e0473728eb275.jpg'),
(59941, 4060, 'A Escuta S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153227.mp4', 'http://timg.bdta.pro/images/2b3abffe55c00794e05dc15597729305.jpg'),
(59942, 4060, 'A Escuta S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153228.mp4', 'http://timg.bdta.pro/images/a917b2bae1167ec422a168f3501d5af5.jpg'),
(59943, 4060, 'A Escuta S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153229.mp4', 'http://timg.bdta.pro/images/74bf0a9785b9d2ceddbe72d0aa553326.jpg'),
(59944, 4060, 'A Escuta S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153230.mp4', 'http://timg.bdta.pro/images/9f516a1306284cb45a9f7b623fc77f7c.jpg'),
(59945, 4060, 'A Escuta S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153231.mp4', 'http://timg.bdta.pro/images/f14dce00573e6e32d43ed1db8742df3c.jpg'),
(59946, 4060, 'A Escuta S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153232.mp4', 'http://timg.bdta.pro/images/69ef8ad2eaf32744a589ba61bca38a16.jpg'),
(59947, 4060, 'A Escuta S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153233.mp4', 'http://timg.bdta.pro/images/ea9a2f7ebd900402ea6369211a8afb30.jpg'),
(59948, 4060, 'A Escuta S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153234.mp4', 'http://timg.bdta.pro/images/13fee25260dad68fc45d033c2b59db82.jpg'),
(59949, 4060, 'A Escuta S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153235.mp4', 'http://timg.bdta.pro/images/005e622708b98bac9f6ec84065a6693e.jpg'),
(59950, 4060, 'A Escuta S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153236.mp4', 'http://timg.bdta.pro/images/dad7f890435de41f56b9f113e955c190.jpg'),
(59951, 4060, 'A Escuta S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153237.mp4', 'http://timg.bdta.pro/images/ababcdccb159e606ed16d9be59de41ec.jpg'),
(59952, 4061, 'A Escuta S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153238.mp4', 'http://timg.bdta.pro/images/8bb29c126a9c6201b14aabe2504365b2.jpg'),
(59953, 4061, 'A Escuta S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153239.mp4', 'http://timg.bdta.pro/images/a0c1e133baa5430bdb2bbdb09e3e5055.jpg'),
(59954, 4061, 'A Escuta S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153240.mp4', 'http://timg.bdta.pro/images/07e5dbd0eb35b3b066a59a126dba71c3.jpg'),
(59955, 4061, 'A Escuta S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153241.mp4', 'http://timg.bdta.pro/images/52d582e611619a4426a2ef8d8b2b07dc.jpg'),
(59956, 4061, 'A Escuta S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153242.mp4', 'http://timg.bdta.pro/images/7734ebc360925b6d8f9b351a21efa3da.jpg'),
(59957, 4061, 'A Escuta S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153243.mp4', 'http://timg.bdta.pro/images/1bce069dc5c5b87f7343149453290ffb.jpg'),
(59958, 4061, 'A Escuta S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153244.mp4', 'http://timg.bdta.pro/images/a6d8a7216ece5a29e91f185c69f9d666.jpg'),
(59959, 4061, 'A Escuta S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153245.mp4', 'http://timg.bdta.pro/images/94e074af7491c37fe3ccfb897fe78ba8.jpg'),
(59960, 4061, 'A Escuta S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153246.mp4', 'http://timg.bdta.pro/images/176f7bcc8bb7ff49fe6b16b48b8b3087.jpg'),
(59961, 4061, 'A Escuta S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153247.mp4', 'http://timg.bdta.pro/images/853860b06848baf692dd0f6a816300e8.jpg'),
(59962, 4061, 'A Escuta S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153248.mp4', 'http://timg.bdta.pro/images/e916cf0a7a121d0a6bff26fba97f2a53.jpg'),
(59963, 4061, 'A Escuta S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153249.mp4', 'http://timg.bdta.pro/images/e1aa1b97de6f127d32564f9f2eb60322.jpg'),
(59964, 4062, 'A Escuta S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153250.mp4', 'http://timg.bdta.pro/images/32e5315c230e8a7065160db02c3c37ca.jpg'),
(59965, 4062, 'A Escuta S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153251.mp4', 'http://timg.bdta.pro/images/7c828e1548b1ff4ecb932d9d4c48f5e5.jpg'),
(59966, 4062, 'A Escuta S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153252.mp4', 'http://timg.bdta.pro/images/57bd8fae48bba1d534b800e20c4b16f7.jpg'),
(59967, 4062, 'A Escuta S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153253.mp4', 'http://timg.bdta.pro/images/c97441d9e098e60d7abee9987ed24562.jpg'),
(59968, 4062, 'A Escuta S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153254.mp4', 'http://timg.bdta.pro/images/c3e47d0b80c26012169764e4567423f6.jpg'),
(59969, 4062, 'A Escuta S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153255.mp4', 'http://timg.bdta.pro/images/24f38cf7e1d8cb1a0158248979eb8466.jpg'),
(59970, 4062, 'A Escuta S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153256.mp4', 'http://timg.bdta.pro/images/c33435c8aff9e11de0a0b75fc75baa2e.jpg'),
(59971, 4062, 'A Escuta S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153257.mp4', 'http://timg.bdta.pro/images/e3289f51f97575ffd5e9e9775fce436c.jpg'),
(59972, 4062, 'A Escuta S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153258.mp4', 'http://timg.bdta.pro/images/ec163623778acf42187ed09d3efbd5ec.jpg'),
(59973, 4062, 'A Escuta S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153259.mp4', 'http://timg.bdta.pro/images/4f7bf26ec5a3b8cda413c99abfb49858.jpg'),
(59974, 4062, 'A Escuta S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153260.mp4', 'http://timg.bdta.pro/images/5690ec1d6e5bd47908b0bb8b9231caf0.jpg'),
(59975, 4062, 'A Escuta S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153261.mp4', 'http://timg.bdta.pro/images/7c605b3acf327a48753b4dc640fef058.jpg'),
(59976, 4062, 'A Escuta S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153262.mp4', 'http://timg.bdta.pro/images/2c1b1f7a695d277684c7cbc6341df574.jpg'),
(59977, 4063, 'A Escuta S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153263.mp4', 'http://timg.bdta.pro/images/ceba8eb0f6588055b75e4585db7ec38a.jpg'),
(59978, 4063, 'A Escuta S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153264.mp4', 'http://timg.bdta.pro/images/9a8faf0c3c75f4c2c5d2f7733fd76d27.jpg'),
(59979, 4063, 'A Escuta S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153265.mp4', 'http://timg.bdta.pro/images/34d7d72cb3b0909a99f63b069d11d8f8.jpg'),
(59980, 4063, 'A Escuta S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153266.mp4', 'http://timg.bdta.pro/images/1737d0dfd8adfe49f77129a5ea50fa2a.jpg'),
(59981, 4063, 'A Escuta S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153267.mp4', 'http://timg.bdta.pro/images/e5752fb93aed46c061ab4e8fb7fe4098.jpg'),
(59982, 4063, 'A Escuta S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153268.mp4', 'http://timg.bdta.pro/images/b1c8c612789f60be98e9093a90683a1c.jpg'),
(59983, 4063, 'A Escuta S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153269.mp4', 'http://timg.bdta.pro/images/7d65d3b015fa8361278b77d81b9c0896.jpg'),
(59984, 4063, 'A Escuta S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153270.mp4', 'http://timg.bdta.pro/images/28eb3d5944b2e933e139118714c6d122.jpg'),
(59985, 4063, 'A Escuta S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153271.mp4', 'http://timg.bdta.pro/images/021913393726927cc785247562a4518a.jpg'),
(59986, 4063, 'A Escuta S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153272.mp4', 'http://timg.bdta.pro/images/de83c3a812b607f86a6fb4a53be3cea3.jpg'),
(59987, 4064, 'Brincando com Fogo: Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196174.mp4', 'http://gstaticontent.com/images/ed3a54596a1b49f2e9ed981a4aabaa77.jpg'),
(59988, 4064, 'Brincando com Fogo: Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196175.mp4', 'http://gstaticontent.com/images/ed3a54596a1b49f2e9ed981a4aabaa77.jpg'),
(59989, 4064, 'Brincando com Fogo: Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196176.mp4', 'http://gstaticontent.com/images/ed3a54596a1b49f2e9ed981a4aabaa77.jpg'),
(59990, 4064, 'Brincando com Fogo: Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196177.mp4', 'http://gstaticontent.com/images/ed3a54596a1b49f2e9ed981a4aabaa77.jpg'),
(59991, 4064, 'Brincando com Fogo: Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tDKl4SuPCJ7z6OJYJWruBolLbK0.jpg'),
(59992, 4064, 'Brincando com Fogo: Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s4TWc4OTZ1N69zJ8nrCJ7QK9u0b.jpg'),
(59993, 4064, 'Brincando com Fogo: Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Ul7BFDwReWEb5c3zVXk0uj4Z0R.jpg'),
(59994, 4064, 'Brincando com Fogo: Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7vNUOKxOQo3pzJTIYRBeILTO6TU.jpg'),
(59995, 4065, 'Brincando com Fogo: Brasil S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196182.mp4', 'http://gstaticontent.com/images/ed3a54596a1b49f2e9ed981a4aabaa77.jpg'),
(59996, 4065, 'Brincando com Fogo: Brasil S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196183.mp4', 'http://gstaticontent.com/images/ed3a54596a1b49f2e9ed981a4aabaa77.jpg'),
(59997, 4065, 'Brincando com Fogo: Brasil S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196184.mp4', 'http://gstaticontent.com/images/ed3a54596a1b49f2e9ed981a4aabaa77.jpg'),
(59998, 4065, 'Brincando com Fogo: Brasil S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196185.mp4', 'http://gstaticontent.com/images/ed3a54596a1b49f2e9ed981a4aabaa77.jpg'),
(59999, 4065, 'Brincando com Fogo: Brasil S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196186.mp4', 'http://gstaticontent.com/images/ed3a54596a1b49f2e9ed981a4aabaa77.jpg'),
(60000, 4065, 'Brincando com Fogo: Brasil S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196187.mp4', 'http://gstaticontent.com/images/ed3a54596a1b49f2e9ed981a4aabaa77.jpg'),
(60001, 4065, 'Brincando com Fogo: Brasil S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196188.mp4', 'http://gstaticontent.com/images/ed3a54596a1b49f2e9ed981a4aabaa77.jpg'),
(60002, 4065, 'Brincando com Fogo: Brasil S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196189.mp4', 'http://gstaticontent.com/images/ed3a54596a1b49f2e9ed981a4aabaa77.jpg'),
(60003, 4066, 'Call Me Kat [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153200.mp4', 'http://timg.bdta.pro/images/8cd5ad5b73e8b4bbe2ac8de03e9217a7.jpg'),
(60004, 4066, 'Call Me Kat [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153201.mp4', 'http://timg.bdta.pro/images/4e170b0080e63e75d4a40f23d29938b7.jpg'),
(60005, 4066, 'Call Me Kat [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153202.mp4', 'http://timg.bdta.pro/images/b73f74c72c6359533b73ecc421398d42.jpg'),
(60006, 4066, 'Call Me Kat [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153203.mp4', 'http://timg.bdta.pro/images/23f16a5a059dc4935f85a021835095b0.jpg'),
(60007, 4066, 'Call Me Kat [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153204.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(60008, 4066, 'Call Me Kat [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153205.mp4', 'http://timg.bdta.pro/images/a1c305ee13f54c6f6310c5952affb520.jpg'),
(60009, 4066, 'Call Me Kat [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153206.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(60010, 4066, 'Call Me Kat [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153207.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(60011, 4066, 'Call Me Kat [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153208.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(60012, 4066, 'Call Me Kat [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153209.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(60013, 4066, 'Call Me Kat [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153210.mp4', 'http://timg.bdta.pro/images/4ca0777c0da41425e014c834efd114dc.jpg'),
(60014, 4066, 'Call Me Kat [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153211.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(60015, 4066, 'Call Me Kat [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153212.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(60016, 4067, 'Darkwing Duck S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153109.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60017, 4067, 'Darkwing Duck S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153110.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60018, 4067, 'Darkwing Duck S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153111.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60019, 4067, 'Darkwing Duck S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153112.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60020, 4067, 'Darkwing Duck S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153113.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60021, 4067, 'Darkwing Duck S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153114.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60022, 4067, 'Darkwing Duck S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153115.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(60023, 4067, 'Darkwing Duck S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153116.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60024, 4067, 'Darkwing Duck S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153117.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60025, 4067, 'Darkwing Duck S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153118.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60026, 4067, 'Darkwing Duck S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153119.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60027, 4067, 'Darkwing Duck S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153120.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60028, 4067, 'Darkwing Duck S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153121.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60029, 4067, 'Darkwing Duck S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153122.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60030, 4067, 'Darkwing Duck S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153123.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60031, 4067, 'Darkwing Duck S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/153124.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60032, 4067, 'Darkwing Duck S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/153125.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60033, 4067, 'Darkwing Duck S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/153126.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60034, 4067, 'Darkwing Duck S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/153127.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60035, 4067, 'Darkwing Duck S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/153128.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60036, 4067, 'Darkwing Duck S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/153129.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60037, 4067, 'Darkwing Duck S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/153130.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60038, 4067, 'Darkwing Duck S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/153131.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60039, 4067, 'Darkwing Duck S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/153132.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60040, 4067, 'Darkwing Duck S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/153133.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60041, 4067, 'Darkwing Duck S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/153134.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60042, 4067, 'Darkwing Duck S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/153135.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60043, 4067, 'Darkwing Duck S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/153136.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60044, 4067, 'Darkwing Duck S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/153137.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60045, 4067, 'Darkwing Duck S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/153138.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60046, 4067, 'Darkwing Duck S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/153139.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60047, 4067, 'Darkwing Duck S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/153140.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60048, 4067, 'Darkwing Duck S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/153141.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60049, 4067, 'Darkwing Duck S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/153142.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60050, 4067, 'Darkwing Duck S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/153143.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60051, 4067, 'Darkwing Duck S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/153144.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60052, 4067, 'Darkwing Duck S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/153145.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60053, 4067, 'Darkwing Duck S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/153146.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60054, 4067, 'Darkwing Duck S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/153147.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60055, 4067, 'Darkwing Duck S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/153148.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60056, 4067, 'Darkwing Duck S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/153149.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60057, 4067, 'Darkwing Duck S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/153150.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60058, 4067, 'Darkwing Duck S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/153151.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60059, 4067, 'Darkwing Duck S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/153152.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60060, 4067, 'Darkwing Duck S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/153153.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60061, 4067, 'Darkwing Duck S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/153154.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60062, 4067, 'Darkwing Duck S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/153155.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60063, 4067, 'Darkwing Duck S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/153156.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60064, 4067, 'Darkwing Duck S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/153157.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60065, 4067, 'Darkwing Duck S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/153158.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60066, 4067, 'Darkwing Duck S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/153159.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60067, 4067, 'Darkwing Duck S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/153160.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60068, 4067, 'Darkwing Duck S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/153161.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60069, 4067, 'Darkwing Duck S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/153162.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60070, 4067, 'Darkwing Duck S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/153163.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60071, 4067, 'Darkwing Duck S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/153164.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60072, 4067, 'Darkwing Duck S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/153165.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60073, 4067, 'Darkwing Duck S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/153166.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60074, 4067, 'Darkwing Duck S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/153167.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60075, 4067, 'Darkwing Duck S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/153168.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60076, 4067, 'Darkwing Duck S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/153169.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60077, 4067, 'Darkwing Duck S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/153170.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60078, 4067, 'Darkwing Duck S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/153171.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60079, 4067, 'Darkwing Duck S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/153172.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60080, 4067, 'Darkwing Duck S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/153173.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60081, 4067, 'Darkwing Duck S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/153174.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60082, 4067, 'Darkwing Duck S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/153175.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60083, 4067, 'Darkwing Duck S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/153176.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60084, 4067, 'Darkwing Duck S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/153177.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60085, 4067, 'Darkwing Duck S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/153178.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60086, 4067, 'Darkwing Duck S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/153179.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60087, 4067, 'Darkwing Duck S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/153180.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60088, 4067, 'Darkwing Duck S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/153181.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60089, 4067, 'Darkwing Duck S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/153182.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60090, 4067, 'Darkwing Duck S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/153183.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60091, 4067, 'Darkwing Duck S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/153184.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60092, 4067, 'Darkwing Duck S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/153185.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60093, 4067, 'Darkwing Duck S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/153186.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60094, 4068, 'Darkwing Duck S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153187.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60095, 4068, 'Darkwing Duck S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153188.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60096, 4068, 'Darkwing Duck S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153189.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60097, 4068, 'Darkwing Duck S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153190.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60098, 4068, 'Darkwing Duck S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153191.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60099, 4068, 'Darkwing Duck S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153192.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60100, 4068, 'Darkwing Duck S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153193.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60101, 4068, 'Darkwing Duck S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153194.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60102, 4068, 'Darkwing Duck S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153195.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60103, 4068, 'Darkwing Duck S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153196.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60104, 4068, 'Darkwing Duck S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153197.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60105, 4068, 'Darkwing Duck S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153198.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60106, 4068, 'Darkwing Duck S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153199.mp4', 'http://gstaticontent.com/images/e55a618d5f9414caad02c46c626c28d4.jpg'),
(60107, 4069, 'Elas No Singular S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153101.mp4', 'http://gstaticontent.com/images/5e7a777b6a0ff43953b6d1eac64f2dd9.jpg'),
(60108, 4069, 'Elas No Singular S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153102.mp4', 'http://gstaticontent.com/images/5e7a777b6a0ff43953b6d1eac64f2dd9.jpg'),
(60109, 4069, 'Elas No Singular S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153103.mp4', 'http://gstaticontent.com/images/5e7a777b6a0ff43953b6d1eac64f2dd9.jpg'),
(60110, 4069, 'Elas No Singular S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153104.mp4', 'http://gstaticontent.com/images/5e7a777b6a0ff43953b6d1eac64f2dd9.jpg'),
(60111, 4069, 'Elas No Singular S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153105.mp4', 'http://gstaticontent.com/images/5e7a777b6a0ff43953b6d1eac64f2dd9.jpg'),
(60112, 4069, 'Elas No Singular S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153106.mp4', 'http://gstaticontent.com/images/5e7a777b6a0ff43953b6d1eac64f2dd9.jpg'),
(60113, 4069, 'Elas No Singular S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153107.mp4', 'http://gstaticontent.com/images/5e7a777b6a0ff43953b6d1eac64f2dd9.jpg'),
(60114, 4069, 'Elas No Singular S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153108.mp4', 'http://gstaticontent.com/images/5e7a777b6a0ff43953b6d1eac64f2dd9.jpg'),
(60115, 4070, 'Eureka S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153037.mp4', 'http://timg.bdta.pro/images/e4ed69bb7fcdcfc3d66ae7ddf785170e.jpg'),
(60116, 4070, 'Eureka S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153038.mp4', 'http://timg.bdta.pro/images/e5e02ed840820299ed577719df8df06e.jpg'),
(60117, 4070, 'Eureka S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153039.mp4', 'http://timg.bdta.pro/images/d97e01ecf849918f31713d4b67040762.jpg'),
(60118, 4070, 'Eureka S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153040.mp4', 'http://timg.bdta.pro/images/e69a2d5f816798aca1a5b28630c9049d.jpg'),
(60119, 4070, 'Eureka S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153041.mp4', 'http://timg.bdta.pro/images/81d3bfec4676232bdba6a568b09a5187.jpg'),
(60120, 4070, 'Eureka S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153042.mp4', 'http://timg.bdta.pro/images/3833bd66abd05bed414ed9aa25639d9f.jpg'),
(60121, 4070, 'Eureka S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153043.mp4', 'http://timg.bdta.pro/images/1c70959b35d926d085ad2719f60c15a1.jpg'),
(60122, 4070, 'Eureka S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153044.mp4', 'http://timg.bdta.pro/images/038014ea57281029b1b654bf8a8e75a4.jpg'),
(60123, 4070, 'Eureka S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153045.mp4', 'http://timg.bdta.pro/images/05edbe615762103b59dda929ef4b798b.jpg'),
(60124, 4070, 'Eureka S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153046.mp4', 'http://timg.bdta.pro/images/d9012223bf9a9e75412e8b9e33777c24.jpg'),
(60125, 4070, 'Eureka S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153047.mp4', 'http://timg.bdta.pro/images/c5636e9e5a8286384f039c2275ccdddd.jpg'),
(60126, 4070, 'Eureka S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153048.mp4', 'http://timg.bdta.pro/images/3d9edf2ea0e50882d711bc1873aa60b0.jpg'),
(60127, 4071, 'Eureka S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153049.mp4', 'http://timg.bdta.pro/images/6ca1cf0b94519ec8d451cd9779124e57.jpg'),
(60128, 4071, 'Eureka S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153050.mp4', 'http://timg.bdta.pro/images/2734b8f3395c22c16224051785dbc7f5.jpg'),
(60129, 4071, 'Eureka S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153051.mp4', 'http://timg.bdta.pro/images/653186963ca7f1ad08a64076b7102214.jpg'),
(60130, 4071, 'Eureka S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153052.mp4', 'http://timg.bdta.pro/images/7136aefaac013a7edbfb250d2c0017a0.jpg'),
(60131, 4071, 'Eureka S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153053.mp4', 'http://timg.bdta.pro/images/9e12f301e5e28c595a23cbd9e1db3c53.jpg'),
(60132, 4071, 'Eureka S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153054.mp4', 'http://timg.bdta.pro/images/83e6fce6edb7df13fec7d322991b0c8a.jpg'),
(60133, 4071, 'Eureka S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153055.mp4', 'http://timg.bdta.pro/images/a9ddaf5a0d3d509e656a5f1c6cee9a1a.jpg'),
(60134, 4071, 'Eureka S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153056.mp4', 'http://timg.bdta.pro/images/d731b2877dcf783c268f3def20527c8f.jpg'),
(60135, 4071, 'Eureka S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153057.mp4', 'http://timg.bdta.pro/images/ec766afa68dbf63737158533af8a12a4.jpg'),
(60136, 4071, 'Eureka S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153058.mp4', 'http://timg.bdta.pro/images/c266bdeb68da8ab14d4fc759b0c91c37.jpg'),
(60137, 4071, 'Eureka S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153059.mp4', 'http://timg.bdta.pro/images/5aec72890a0a7112c6179784b69f1384.jpg'),
(60138, 4071, 'Eureka S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153060.mp4', 'http://timg.bdta.pro/images/8cd50a96cc84a7263d09325a389e3733.jpg'),
(60139, 4071, 'Eureka S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153061.mp4', 'http://timg.bdta.pro/images/d867ac9a5cf120edd68f6e00593a2101.jpg'),
(60140, 4072, 'Eureka S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153062.mp4', 'http://timg.bdta.pro/images/a1f96ed8f41360021eef00ea5969bcf5.jpg'),
(60141, 4072, 'Eureka S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153063.mp4', 'http://timg.bdta.pro/images/849cce50c6c02fa186a8ceffcf326dd8.jpg'),
(60142, 4072, 'Eureka S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153064.mp4', 'http://timg.bdta.pro/images/ace62b00393ba68c46b25b07c1df41e0.jpg'),
(60143, 4072, 'Eureka S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153065.mp4', 'http://timg.bdta.pro/images/3f287fc633d17c276836785e3cbb76f3.jpg'),
(60144, 4072, 'Eureka S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153066.mp4', 'http://timg.bdta.pro/images/8b4c6c30a2731bc0f5a9e275930f5b85.jpg'),
(60145, 4072, 'Eureka S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153067.mp4', 'http://timg.bdta.pro/images/b9db86ffd99e371a773852566d5aec02.jpg'),
(60146, 4072, 'Eureka S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153068.mp4', 'http://timg.bdta.pro/images/2d069bddd4cc65d3f692e11528d2c1f6.jpg'),
(60147, 4072, 'Eureka S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153069.mp4', 'http://timg.bdta.pro/images/c9239ad73ac4d9fa1673c5f661320124.jpg'),
(60148, 4072, 'Eureka S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153070.mp4', 'http://timg.bdta.pro/images/e66302d12455554ef44d19caca89214b.jpg'),
(60149, 4072, 'Eureka S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153071.mp4', 'http://timg.bdta.pro/images/7610189d767d726b928fdfb0c2b384d1.jpg'),
(60150, 4072, 'Eureka S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153072.mp4', 'http://timg.bdta.pro/images/8b086d43f9a2a1d9c147d84577054ba3.jpg'),
(60151, 4072, 'Eureka S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153073.mp4', 'http://timg.bdta.pro/images/03fd45054bff54d7626e7c800ac95f06.jpg'),
(60152, 4072, 'Eureka S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153074.mp4', 'http://timg.bdta.pro/images/7af0510a463d3aaf84107ca78961ece2.jpg'),
(60153, 4072, 'Eureka S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153075.mp4', 'http://timg.bdta.pro/images/5c9261e16f90e3706f4d9e164a1be083.jpg'),
(60154, 4072, 'Eureka S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153076.mp4', 'http://timg.bdta.pro/images/2c1462e1f0314d13e937b65fbe243c8f.jpg'),
(60155, 4072, 'Eureka S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/153077.mp4', 'http://timg.bdta.pro/images/5a35975359e51409bb12c0f8b48d4723.jpg'),
(60156, 4072, 'Eureka S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/153078.mp4', 'http://timg.bdta.pro/images/03fba243cdbe71f7f545bdb4bd847f7e.jpg'),
(60157, 4072, 'Eureka S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/153079.mp4', 'http://timg.bdta.pro/images/c721093926b6ad2a69c8308470d7e740.jpg'),
(60158, 4073, 'Eureka S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/153080.mp4', 'http://timg.bdta.pro/images/614b2dc175b26b8bcdcc997abddbf30c.jpg'),
(60159, 4073, 'Eureka S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/153081.mp4', 'http://timg.bdta.pro/images/d3e537b78c37d6ad67a396317817483e.jpg'),
(60160, 4073, 'Eureka S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/153082.mp4', 'http://timg.bdta.pro/images/2e9e7a7babb1399cd35ada9e1be7579e.jpg'),
(60161, 4073, 'Eureka S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/153083.mp4', 'http://timg.bdta.pro/images/c81da607dba1a3645448daf0a0082bfd.jpg'),
(60162, 4073, 'Eureka S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/153084.mp4', 'http://timg.bdta.pro/images/bd2854d26c8fac8e1ede65550c830fb5.jpg'),
(60163, 4073, 'Eureka S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/153085.mp4', 'http://timg.bdta.pro/images/0bb383ff90fea3443e5f426e9699639a.jpg'),
(60164, 4073, 'Eureka S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/153086.mp4', 'http://timg.bdta.pro/images/7d4efac8247118e816f380cc29b8e03b.jpg'),
(60165, 4073, 'Eureka S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/153087.mp4', 'http://timg.bdta.pro/images/e4af5b72e019e41f7679b8ca4fdb38ae.jpg'),
(60166, 4073, 'Eureka S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/153088.mp4', 'http://timg.bdta.pro/images/55c1cfb12b426cc90ed48ae4f4df39ce.jpg'),
(60167, 4073, 'Eureka S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/153089.mp4', 'http://timg.bdta.pro/images/0cd4bd76b4e97845066b1c95e2d69dc0.jpg'),
(60168, 4073, 'Eureka S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/153090.mp4', 'http://timg.bdta.pro/images/d3b679a0285573ac62e20b7d4751cea2.jpg'),
(60169, 4073, 'Eureka S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153091.mp4', 'http://timg.bdta.pro/images/740cc556f0d3c47993dc98c2483d5a67.jpg'),
(60170, 4073, 'Eureka S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153092.mp4', 'http://timg.bdta.pro/images/d49669d205bdea767d8264e7c15184db.jpg'),
(60171, 4073, 'Eureka S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153093.mp4', 'http://timg.bdta.pro/images/10b5692f4c5311da4e5782811f55fa2f.jpg'),
(60172, 4073, 'Eureka S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153094.mp4', 'http://timg.bdta.pro/images/aa1fffcab5e74c8a707299b8ffcf3c42.jpg'),
(60173, 4073, 'Eureka S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/153095.mp4', 'http://timg.bdta.pro/images/5b1b41abf9f58aa66cc353619117b85a.jpg'),
(60174, 4073, 'Eureka S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/153096.mp4', 'http://timg.bdta.pro/images/25aa52a29fdc98f514b0c4d132643057.jpg'),
(60175, 4073, 'Eureka S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/153097.mp4', 'http://timg.bdta.pro/images/4fb3be06fb905ae8ca59bedc89f5d3dc.jpg'),
(60176, 4073, 'Eureka S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/153098.mp4', 'http://timg.bdta.pro/images/19198e89b3e204163b2515ad0f7e9a8d.jpg'),
(60177, 4073, 'Eureka S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/153099.mp4', 'http://timg.bdta.pro/images/add74a8154b254f5052eefba8f78556e.jpg'),
(60178, 4073, 'Eureka S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/153100.mp4', 'http://timg.bdta.pro/images/74e4992f9da1aa673ae9c60c37847221.jpg'),
(60179, 4074, 'Ilha Record S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193927.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60180, 4074, 'Ilha Record S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193928.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60181, 4074, 'Ilha Record S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193929.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60182, 4074, 'Ilha Record S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193930.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60183, 4074, 'Ilha Record S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193931.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60184, 4074, 'Ilha Record S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193932.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60185, 4074, 'Ilha Record S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193933.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60186, 4074, 'Ilha Record S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193934.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60187, 4074, 'Ilha Record S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193935.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60188, 4074, 'Ilha Record S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193936.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60189, 4074, 'Ilha Record S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193937.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60190, 4074, 'Ilha Record S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193938.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60191, 4074, 'Ilha Record S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193939.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60192, 4074, 'Ilha Record S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/193940.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60193, 4074, 'Ilha Record S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/193941.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60194, 4074, 'Ilha Record S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/193942.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60195, 4074, 'Ilha Record S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/193943.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60196, 4074, 'Ilha Record S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/193944.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60197, 4074, 'Ilha Record S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/193945.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60198, 4074, 'Ilha Record S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/193946.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60199, 4074, 'Ilha Record S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/193947.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60200, 4074, 'Ilha Record S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/193948.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60201, 4074, 'Ilha Record S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/193949.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60202, 4074, 'Ilha Record S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/193950.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60203, 4074, 'Ilha Record S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/193951.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60204, 4074, 'Ilha Record S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/193952.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60205, 4074, 'Ilha Record S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/193953.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60206, 4074, 'Ilha Record S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/193954.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60207, 4074, 'Ilha Record S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/193955.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60208, 4074, 'Ilha Record S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/193956.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60209, 4074, 'Ilha Record S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/193957.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60210, 4074, 'Ilha Record S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/193958.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60211, 4074, 'Ilha Record S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/193959.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60212, 4074, 'Ilha Record S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/193960.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60213, 4074, 'Ilha Record S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/193961.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60214, 4074, 'Ilha Record S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/193962.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60215, 4074, 'Ilha Record S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/193963.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60216, 4074, 'Ilha Record S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/193964.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60217, 4074, 'Ilha Record S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/193965.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60218, 4074, 'Ilha Record S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/193966.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60219, 4075, 'Ilha Record S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193967.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60220, 4075, 'Ilha Record S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193968.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60221, 4075, 'Ilha Record S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193969.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60222, 4075, 'Ilha Record S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193970.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60223, 4075, 'Ilha Record S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193971.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60224, 4075, 'Ilha Record S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193972.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60225, 4075, 'Ilha Record S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193973.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60226, 4075, 'Ilha Record S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193974.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60227, 4075, 'Ilha Record S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193975.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60228, 4075, 'Ilha Record S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193976.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60229, 4075, 'Ilha Record S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193977.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60230, 4075, 'Ilha Record S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193978.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60231, 4075, 'Ilha Record S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193979.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60232, 4075, 'Ilha Record S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/193980.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60233, 4075, 'Ilha Record S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/193981.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60234, 4075, 'Ilha Record S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/193982.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60235, 4075, 'Ilha Record S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/193983.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60236, 4075, 'Ilha Record S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/193984.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60237, 4075, 'Ilha Record S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/193985.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60238, 4075, 'Ilha Record S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/193986.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60239, 4075, 'Ilha Record S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/193987.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60240, 4075, 'Ilha Record S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/193988.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60241, 4075, 'Ilha Record S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/193989.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60242, 4075, 'Ilha Record S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/193990.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60243, 4075, 'Ilha Record S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/193991.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60244, 4075, 'Ilha Record S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/193992.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60245, 4075, 'Ilha Record S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/193993.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60246, 4075, 'Ilha Record S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/193994.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60247, 4075, 'Ilha Record S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/193995.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60248, 4075, 'Ilha Record S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/193996.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60249, 4075, 'Ilha Record S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/193997.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60250, 4075, 'Ilha Record S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/193998.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60251, 4075, 'Ilha Record S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/193999.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60252, 4075, 'Ilha Record S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/194000.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60253, 4075, 'Ilha Record S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/194001.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60254, 4075, 'Ilha Record S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/194002.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60255, 4075, 'Ilha Record S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/194003.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60256, 4075, 'Ilha Record S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/194004.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60257, 4075, 'Ilha Record S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/194005.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60258, 4075, 'Ilha Record S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/194006.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60259, 4075, 'Ilha Record S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/194007.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60260, 4075, 'Ilha Record S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/194008.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60261, 4075, 'Ilha Record S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/194009.mp4', 'http://gstaticontent.com/images/af72bbf18a98cfdf60c55f3a3a4ed6f1.jpg'),
(60262, 4076, 'Loopy de Loop S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152989.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60263, 4076, 'Loopy de Loop S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152990.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60264, 4076, 'Loopy de Loop S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152991.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60265, 4076, 'Loopy de Loop S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152992.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60266, 4076, 'Loopy de Loop S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152993.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60267, 4076, 'Loopy de Loop S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152994.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60268, 4076, 'Loopy de Loop S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152995.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60269, 4076, 'Loopy de Loop S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152996.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60270, 4076, 'Loopy de Loop S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152997.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60271, 4076, 'Loopy de Loop S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152998.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60272, 4076, 'Loopy de Loop S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152999.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60273, 4076, 'Loopy de Loop S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/153000.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60274, 4076, 'Loopy de Loop S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/153001.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60275, 4076, 'Loopy de Loop S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/153002.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60276, 4076, 'Loopy de Loop S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/153003.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60277, 4076, 'Loopy de Loop S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/153004.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60278, 4076, 'Loopy de Loop S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/153005.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60279, 4076, 'Loopy de Loop S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/153006.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60280, 4076, 'Loopy de Loop S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/153007.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60281, 4076, 'Loopy de Loop S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/153008.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60282, 4076, 'Loopy de Loop S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/153009.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60283, 4076, 'Loopy de Loop S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/153010.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60284, 4076, 'Loopy de Loop S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/153011.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60285, 4076, 'Loopy de Loop S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/153012.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60286, 4076, 'Loopy de Loop S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/153013.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60287, 4076, 'Loopy de Loop S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/153014.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60288, 4076, 'Loopy de Loop S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/153015.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60289, 4076, 'Loopy de Loop S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/153016.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60290, 4076, 'Loopy de Loop S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/153017.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60291, 4076, 'Loopy de Loop S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/153018.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60292, 4076, 'Loopy de Loop S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/153019.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60293, 4076, 'Loopy de Loop S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/153020.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60294, 4076, 'Loopy de Loop S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/153021.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60295, 4076, 'Loopy de Loop S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/153022.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60296, 4076, 'Loopy de Loop S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/153023.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60297, 4076, 'Loopy de Loop S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/153024.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60298, 4076, 'Loopy de Loop S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/153025.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60299, 4076, 'Loopy de Loop S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/153026.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60300, 4076, 'Loopy de Loop S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/153027.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60301, 4076, 'Loopy de Loop S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/153028.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60302, 4076, 'Loopy de Loop S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/153029.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60303, 4076, 'Loopy de Loop S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/153030.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60304, 4076, 'Loopy de Loop S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/153031.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60305, 4076, 'Loopy de Loop S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/153032.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60306, 4076, 'Loopy de Loop S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/153033.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60307, 4076, 'Loopy de Loop S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/153034.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60308, 4076, 'Loopy de Loop S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/153035.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60309, 4076, 'Loopy de Loop S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/153036.mp4', 'http://gstaticontent.com/images/c8d37c896a35afbd3038497aa89f9e43.jpg'),
(60310, 4077, 'O Universo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151559.mp4', 'http://timg.bdta.pro/images/127f16a81298200a0ee2fa7c56eb730b.jpg'),
(60311, 4077, 'O Universo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151560.mp4', 'http://timg.bdta.pro/images/f17d3ea59d5e7f0ea7fccc71dc38c6f4.jpg'),
(60312, 4077, 'O Universo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151561.mp4', 'http://timg.bdta.pro/images/51da7e95f6277b8f5a02402ee9032e75.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(60313, 4077, 'O Universo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151562.mp4', 'http://timg.bdta.pro/images/82f2815a6e3fb2911520a1158a7e3d75.jpg'),
(60314, 4077, 'O Universo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151563.mp4', 'http://timg.bdta.pro/images/f43368bcab73f9620a0c3c0e87b55654.jpg'),
(60315, 4077, 'O Universo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151564.mp4', 'http://timg.bdta.pro/images/eac43e9aaad4b6c05a4176df45932d4b.jpg'),
(60316, 4077, 'O Universo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151565.mp4', 'http://timg.bdta.pro/images/d94aa935ac9f64cbf4aa502552c0d9fd.jpg'),
(60317, 4077, 'O Universo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151566.mp4', 'http://timg.bdta.pro/images/7859863ccf156c8b915e748660945201.jpg'),
(60318, 4077, 'O Universo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151567.mp4', 'http://timg.bdta.pro/images/5cd7c804d282a1fc6a4c09c6d7a6e0a5.jpg'),
(60319, 4077, 'O Universo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151568.mp4', 'http://timg.bdta.pro/images/58510403058502a102587a4c48ececb9.jpg'),
(60320, 4077, 'O Universo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151569.mp4', 'http://timg.bdta.pro/images/b8867997143dad144bc730b141792df7.jpg'),
(60321, 4077, 'O Universo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151570.mp4', 'http://timg.bdta.pro/images/8dcb8295de3aef60937f1aad95bb8b29.jpg'),
(60322, 4077, 'O Universo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151571.mp4', 'http://timg.bdta.pro/images/8a5b3bf7d40c784260c06053b193a187.jpg'),
(60323, 4077, 'O Universo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151572.mp4', 'http://timg.bdta.pro/images/ec12098a634ae9b39782ccbfe195c6fc.jpg'),
(60324, 4078, 'O Universo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151573.mp4', 'http://timg.bdta.pro/images/bd3acde5da49ba98aeddd470ff92dc46.jpg'),
(60325, 4078, 'O Universo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151574.mp4', 'http://timg.bdta.pro/images/8bf265deae0ce23d41e4543839fdb98f.jpg'),
(60326, 4078, 'O Universo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151575.mp4', 'http://timg.bdta.pro/images/de32725fd0059cb8700911e7f469420a.jpg'),
(60327, 4078, 'O Universo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151576.mp4', 'http://timg.bdta.pro/images/c603b795e1a8d817aab2a234419d0fda.jpg'),
(60328, 4078, 'O Universo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151577.mp4', 'http://timg.bdta.pro/images/ccaec8732150277a3b75807cebe2152f.jpg'),
(60329, 4078, 'O Universo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151578.mp4', 'http://timg.bdta.pro/images/6173f0d8a97b45e310ff50dccb7937e3.jpg'),
(60330, 4078, 'O Universo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151579.mp4', 'http://timg.bdta.pro/images/d851073d40039c208209c79f5b107b48.jpg'),
(60331, 4078, 'O Universo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151580.mp4', 'http://timg.bdta.pro/images/2f86c0ae817bf8e0bc183e70a04129cd.jpg'),
(60332, 4078, 'O Universo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151581.mp4', 'http://timg.bdta.pro/images/2c63f24d1750e2a8ccc89c1f79585d0c.jpg'),
(60333, 4078, 'O Universo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151582.mp4', 'http://timg.bdta.pro/images/f3c6a4157bfc8646b7200061cc9f38ed.jpg'),
(60334, 4078, 'O Universo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151583.mp4', 'http://timg.bdta.pro/images/d009d40d8fda53a7580a8398f99509b1.jpg'),
(60335, 4078, 'O Universo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151584.mp4', 'http://timg.bdta.pro/images/d5b38d50776213a5a39fa21992728d3f.jpg'),
(60336, 4078, 'O Universo S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151585.mp4', 'http://timg.bdta.pro/images/e32fbfddc15d93fa7b65c3fba81931df.jpg'),
(60337, 4078, 'O Universo S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151586.mp4', 'http://timg.bdta.pro/images/32ee02ab0a718c7bf871084c74f7b96f.jpg'),
(60338, 4078, 'O Universo S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/151587.mp4', 'http://timg.bdta.pro/images/75cc612455cb899c6df25e4aa66145ff.jpg'),
(60339, 4078, 'O Universo S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/151588.mp4', 'http://timg.bdta.pro/images/9a5617189edf5232718891e3ba6868c9.jpg'),
(60340, 4078, 'O Universo S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/151589.mp4', 'http://timg.bdta.pro/images/3067ed46f7524da1b9b3802e5b2f885d.jpg'),
(60341, 4078, 'O Universo S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/151590.mp4', 'http://timg.bdta.pro/images/2a0c39f8f56a7df0e5e7c11ef36f70dd.jpg'),
(60342, 4079, 'O Universo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151591.mp4', 'http://timg.bdta.pro/images/0ef4e461d5c3e30bede26edcc5d7916b.jpg'),
(60343, 4079, 'O Universo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151592.mp4', 'http://timg.bdta.pro/images/fde7ce6b77bcacbeb52f22ff22b52588.jpg'),
(60344, 4079, 'O Universo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151593.mp4', 'http://timg.bdta.pro/images/ff5f2ccc54165b5a223271321c152826.jpg'),
(60345, 4079, 'O Universo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151594.mp4', 'http://timg.bdta.pro/images/fbbee3112b70f9c4d1753e283d6277d1.jpg'),
(60346, 4079, 'O Universo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151595.mp4', 'http://timg.bdta.pro/images/d530082a903bfed59c16c455fe03c052.jpg'),
(60347, 4079, 'O Universo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151596.mp4', 'http://timg.bdta.pro/images/896a7350355bca1cf5412609c18dd71d.jpg'),
(60348, 4079, 'O Universo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151597.mp4', 'http://timg.bdta.pro/images/d204278edfaa8ae526bb96d3e359c537.jpg'),
(60349, 4079, 'O Universo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151598.mp4', 'http://timg.bdta.pro/images/99fddcd5ba1fc7e051d4adf6aa1cf29f.jpg'),
(60350, 4079, 'O Universo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151599.mp4', 'http://timg.bdta.pro/images/f084a7544ebd631a89b968fbc376baf4.jpg'),
(60351, 4079, 'O Universo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151600.mp4', 'http://timg.bdta.pro/images/ab7e1f1f44c8ae67beecb4dbf0129a36.jpg'),
(60352, 4079, 'O Universo S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151601.mp4', 'http://timg.bdta.pro/images/9c6a520aa3eb680741a95026919f88e7.jpg'),
(60353, 4079, 'O Universo S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151602.mp4', 'http://timg.bdta.pro/images/d677f2a077fded2591598d1350309b39.jpg'),
(60354, 4080, 'O Universo S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151603.mp4', 'http://timg.bdta.pro/images/53cdbf1a497bc082b615aaa79955a5d1.jpg'),
(60355, 4080, 'O Universo S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151604.mp4', 'http://timg.bdta.pro/images/27db7283b7b55ac2d0bed724bbd6666b.jpg'),
(60356, 4080, 'O Universo S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151605.mp4', 'http://timg.bdta.pro/images/8abff4da0815a6de390a6fd7eb643e90.jpg'),
(60357, 4080, 'O Universo S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151606.mp4', 'http://timg.bdta.pro/images/c03ebf71dd26d29d9a52a5bd5caa4595.jpg'),
(60358, 4080, 'O Universo S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151607.mp4', 'http://timg.bdta.pro/images/ff576fa0e0a9b90094ecf60f6996937f.jpg'),
(60359, 4080, 'O Universo S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151608.mp4', 'http://timg.bdta.pro/images/903ac60bfb2a9f80cc6df8a4e74887a1.jpg'),
(60360, 4080, 'O Universo S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151609.mp4', 'http://timg.bdta.pro/images/797c8bb6c263e474f6b3f125922224d7.jpg'),
(60361, 4080, 'O Universo S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151610.mp4', 'http://timg.bdta.pro/images/ffb7b3f30057871820002816054b7c32.jpg'),
(60362, 4080, 'O Universo S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151611.mp4', 'http://timg.bdta.pro/images/3711ec503e689ade9c12e02a9db4272d.jpg'),
(60363, 4080, 'O Universo S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151612.mp4', 'http://timg.bdta.pro/images/fc60c5c327500c416682c6091289eae6.jpg'),
(60364, 4080, 'O Universo S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151613.mp4', 'http://timg.bdta.pro/images/0ceb210c822483bb208648c0c5736990.jpg'),
(60365, 4080, 'O Universo S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151614.mp4', 'http://timg.bdta.pro/images/17fff44f3bf756a44fc58773f68921a0.jpg'),
(60366, 4081, 'O Universo S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151615.mp4', 'http://timg.bdta.pro/images/7c3efc8d27c6a5f57c724d2a88391b3a.jpg'),
(60367, 4081, 'O Universo S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151616.mp4', 'http://timg.bdta.pro/images/3d075dd190cd28eda8e5c1e9dfe08259.jpg'),
(60368, 4081, 'O Universo S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151617.mp4', 'http://timg.bdta.pro/images/dc2f3d5bae5c5a4661fec36b4ae7c91d.jpg'),
(60369, 4081, 'O Universo S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151618.mp4', 'http://timg.bdta.pro/images/97c0a634640726e8d08deada4901314d.jpg'),
(60370, 4081, 'O Universo S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151619.mp4', 'http://timg.bdta.pro/images/04a243814780de0eeda542afdabbbacd.jpg'),
(60371, 4081, 'O Universo S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151620.mp4', 'http://timg.bdta.pro/images/c31afae62b463770da13c54b8ac07cf4.jpg'),
(60372, 4081, 'O Universo S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151621.mp4', 'http://timg.bdta.pro/images/cfbd0dd00af26a95d85f1025391a941e.jpg'),
(60373, 4081, 'O Universo S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151622.mp4', 'http://timg.bdta.pro/images/35afeea37766c44cd49a6a1eb4207fec.jpg'),
(60374, 4082, 'O Universo S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151623.mp4', 'http://timg.bdta.pro/images/840b0ec58c0e664f17104b0cfe8e115e.jpg'),
(60375, 4082, 'O Universo S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151624.mp4', 'http://timg.bdta.pro/images/098b679cccd1ce5eb3513d28f4fac679.jpg'),
(60376, 4082, 'O Universo S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151625.mp4', 'http://timg.bdta.pro/images/d8002b392c6bea7c0376cdbccddf544b.jpg'),
(60377, 4082, 'O Universo S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151626.mp4', 'http://timg.bdta.pro/images/54a397d63a8eb4427eba1199c8bc148a.jpg'),
(60378, 4082, 'O Universo S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151627.mp4', 'http://timg.bdta.pro/images/54c1815bf7e990067e3bb561ad532f7e.jpg'),
(60379, 4082, 'O Universo S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151628.mp4', 'http://timg.bdta.pro/images/55f5825b910091074ff32ff1952957b5.jpg'),
(60380, 4082, 'O Universo S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151629.mp4', 'http://timg.bdta.pro/images/c183fea26f6774df43393656baa88dbe.jpg'),
(60381, 4083, 'O Universo S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151630.mp4', 'http://gstaticontent.com/images/a479278c1d81d032f95d43244d285b85.jpg'),
(60382, 4083, 'O Universo S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151631.mp4', 'http://gstaticontent.com/images/a479278c1d81d032f95d43244d285b85.jpg'),
(60383, 4083, 'O Universo S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151632.mp4', 'http://gstaticontent.com/images/a479278c1d81d032f95d43244d285b85.jpg'),
(60384, 4083, 'O Universo S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151633.mp4', 'http://gstaticontent.com/images/a479278c1d81d032f95d43244d285b85.jpg'),
(60385, 4083, 'O Universo S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151634.mp4', 'http://gstaticontent.com/images/a479278c1d81d032f95d43244d285b85.jpg'),
(60386, 4083, 'O Universo S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151635.mp4', 'http://gstaticontent.com/images/a479278c1d81d032f95d43244d285b85.jpg'),
(60387, 4083, 'O Universo S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151636.mp4', 'http://gstaticontent.com/images/a479278c1d81d032f95d43244d285b85.jpg'),
(60388, 4084, 'O Universo S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151637.mp4', 'http://timg.bdta.pro/images/08d89ea34f8d5c9f058dc2e383851de6.jpg'),
(60389, 4084, 'O Universo S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151638.mp4', 'http://timg.bdta.pro/images/ae9ce91d2cca15d59f331bb503c6eba8.jpg'),
(60390, 4084, 'O Universo S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151639.mp4', 'http://timg.bdta.pro/images/155cb9de5483c0f4d164c81efadb30bf.jpg'),
(60391, 4084, 'O Universo S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151640.mp4', 'http://timg.bdta.pro/images/c1282ca9089255c2df90faab4f52c05c.jpg'),
(60392, 4085, 'O Universo S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151641.mp4', 'http://timg.bdta.pro/images/0ec81de39605f9fcd4eafda6923c4810.jpg'),
(60393, 4085, 'O Universo S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151642.mp4', 'http://timg.bdta.pro/images/c4be6a8ac9882e14b4ba367c2e3a34e1.jpg'),
(60394, 4085, 'O Universo S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151643.mp4', 'http://timg.bdta.pro/images/61c23e8d080e436046e6d25a62d1d219.jpg'),
(60395, 4085, 'O Universo S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151644.mp4', 'http://timg.bdta.pro/images/681fa310a1f9c842afe516f66c0e44cc.jpg'),
(60396, 4086, 'Schmigadoon! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210383.mp4', 'http://timg.bdta.pro/images/889872eae950a29b6d370f758cbf722b.jpg'),
(60397, 4086, 'Schmigadoon! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210384.mp4', 'http://timg.bdta.pro/images/bd20a0b174b4fe5ffff9883e5d9c56aa.jpg'),
(60398, 4086, 'Schmigadoon! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210385.mp4', 'http://timg.bdta.pro/images/cd8d7c8806b31301b211d56654c018a1.jpg'),
(60399, 4086, 'Schmigadoon! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210386.mp4', 'http://timg.bdta.pro/images/3b3a39bc75c6cd4808be8814be703165.jpg'),
(60400, 4086, 'Schmigadoon! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210387.mp4', 'http://timg.bdta.pro/images/9353ea71bd670c455fe756bd8dd32a33.jpg'),
(60401, 4086, 'Schmigadoon! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210388.mp4', 'http://timg.bdta.pro/images/4226cbf05faefc070199dbdf7c78cfdd.jpg'),
(60402, 4087, 'Schmigadoon! S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/170AROBmgVY8vQ9xcESXgnpM7IU.jpg'),
(60403, 4087, 'Schmigadoon! S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ahkGCFQk1Gb1gooJrijz5Qy1U1M.jpg'),
(60404, 4087, 'Schmigadoon! S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210391.mp4', 'http://image.tmdb.org/t/p/w1280/nA7YcX5LiNGkd8pZ76DIgYwIj6a.jpg'),
(60405, 4087, 'Schmigadoon! S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210392.mp4', 'http://image.tmdb.org/t/p/w1280/hQHysS1wGSM7CvWKMc7U6uL5IaW.jpg'),
(60406, 4087, 'Schmigadoon! S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210393.mp4', 'http://image.tmdb.org/t/p/w1280/5UqUgkn4CYnAgGifxiIWJyqs5wL.jpg'),
(60407, 4087, 'Schmigadoon! S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210394.mp4', 'http://image.tmdb.org/t/p/w1280/r6NDm4PEm1T8SkYtWBGQxqaSk7k.jpg'),
(60408, 4088, 'Hakenshimasu! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152978.mp4', 'http://timg.bdta.pro/images/47d12706b1bb35154191d611fffcada4.jpg'),
(60409, 4088, 'Hakenshimasu! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152979.mp4', 'http://timg.bdta.pro/images/d52ab8b2d4bcc01f4ea23c515d927904.jpg'),
(60410, 4088, 'Hakenshimasu! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152980.mp4', 'http://timg.bdta.pro/images/26b4b7000dc420edcb2acffed048daa2.jpg'),
(60411, 4088, 'Hakenshimasu! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152981.mp4', 'http://timg.bdta.pro/images/b8c9879197c25ffd8936293a6e4f1849.jpg'),
(60412, 4088, 'Hakenshimasu! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152982.mp4', 'http://timg.bdta.pro/images/d6da4623a44d881f9b57be74abe765b4.jpg'),
(60413, 4088, 'Hakenshimasu! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152983.mp4', 'http://timg.bdta.pro/images/ed17f0e6cdedfc43496fb0506eb7f84e.jpg'),
(60414, 4088, 'Hakenshimasu! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152984.mp4', 'http://timg.bdta.pro/images/cb0b6525fd83f1299507427ad824df63.jpg'),
(60415, 4088, 'Hakenshimasu! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152985.mp4', 'http://timg.bdta.pro/images/c4789fb18ff81b6b0490e85655266b5c.jpg'),
(60416, 4088, 'Hakenshimasu! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152986.mp4', 'http://timg.bdta.pro/images/51e4171bb0776bcb246c0380d1847f82.jpg'),
(60417, 4088, 'Hakenshimasu! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152987.mp4', 'http://timg.bdta.pro/images/0d677666ebff659de90e977cd96b978a.jpg'),
(60418, 4088, 'Hakenshimasu! S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152988.mp4', 'http://timg.bdta.pro/images/49d47201fb4829dc79bbdbde94ffab63.jpg'),
(60419, 4089, 'Sítio do Picapau Amarelo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152450.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60420, 4089, 'Sítio do Picapau Amarelo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152451.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60421, 4089, 'Sítio do Picapau Amarelo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152452.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60422, 4089, 'Sítio do Picapau Amarelo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152453.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60423, 4089, 'Sítio do Picapau Amarelo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152454.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60424, 4089, 'Sítio do Picapau Amarelo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152455.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60425, 4089, 'Sítio do Picapau Amarelo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152456.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60426, 4089, 'Sítio do Picapau Amarelo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152457.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60427, 4089, 'Sítio do Picapau Amarelo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152458.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60428, 4089, 'Sítio do Picapau Amarelo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152459.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60429, 4089, 'Sítio do Picapau Amarelo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152460.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60430, 4089, 'Sítio do Picapau Amarelo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152461.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60431, 4089, 'Sítio do Picapau Amarelo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152462.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60432, 4089, 'Sítio do Picapau Amarelo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152463.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60433, 4089, 'Sítio do Picapau Amarelo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152464.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60434, 4089, 'Sítio do Picapau Amarelo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152465.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60435, 4089, 'Sítio do Picapau Amarelo S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152466.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60436, 4089, 'Sítio do Picapau Amarelo S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152467.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60437, 4089, 'Sítio do Picapau Amarelo S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152468.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60438, 4089, 'Sítio do Picapau Amarelo S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/152469.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60439, 4090, 'Sítio do Picapau Amarelo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152470.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60440, 4090, 'Sítio do Picapau Amarelo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152471.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60441, 4090, 'Sítio do Picapau Amarelo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152472.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60442, 4090, 'Sítio do Picapau Amarelo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152473.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60443, 4090, 'Sítio do Picapau Amarelo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152474.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60444, 4090, 'Sítio do Picapau Amarelo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152475.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60445, 4090, 'Sítio do Picapau Amarelo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152476.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60446, 4090, 'Sítio do Picapau Amarelo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152477.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60447, 4090, 'Sítio do Picapau Amarelo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152478.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60448, 4090, 'Sítio do Picapau Amarelo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152479.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60449, 4090, 'Sítio do Picapau Amarelo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152480.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60450, 4090, 'Sítio do Picapau Amarelo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152481.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60451, 4090, 'Sítio do Picapau Amarelo S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152482.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60452, 4090, 'Sítio do Picapau Amarelo S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152483.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60453, 4090, 'Sítio do Picapau Amarelo S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152484.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60454, 4090, 'Sítio do Picapau Amarelo S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152485.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60455, 4090, 'Sítio do Picapau Amarelo S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152486.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60456, 4090, 'Sítio do Picapau Amarelo S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152487.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60457, 4091, 'Sítio do Picapau Amarelo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152488.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60458, 4091, 'Sítio do Picapau Amarelo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152489.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60459, 4091, 'Sítio do Picapau Amarelo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152490.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60460, 4091, 'Sítio do Picapau Amarelo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152491.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60461, 4091, 'Sítio do Picapau Amarelo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152492.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60462, 4091, 'Sítio do Picapau Amarelo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152493.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60463, 4091, 'Sítio do Picapau Amarelo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152494.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60464, 4091, 'Sítio do Picapau Amarelo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152495.mp4', 'http://gstaticontent.com/images/5776f55248a4ea6fd751eb4a6339d187.jpg'),
(60465, 4092, 'The White Lotus S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202997.mp4', 'http://timg.bdta.pro/images/6116f374213ea2a5f7be0ac63764a415.jpg'),
(60466, 4092, 'The White Lotus S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202998.mp4', 'http://timg.bdta.pro/images/255ea114563244e2de639f65cb4f1696.jpg'),
(60467, 4092, 'The White Lotus S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202999.mp4', 'http://timg.bdta.pro/images/ebbb69154472233b4c76d282c3600c42.jpg'),
(60468, 4092, 'The White Lotus S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203000.mp4', 'http://timg.bdta.pro/images/fa095c8cc8abbdd580dcce0bdee79921.jpg'),
(60469, 4092, 'The White Lotus S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203001.mp4', 'http://timg.bdta.pro/images/3b1e35279bf24db1d3d11de63e41b487.jpg'),
(60470, 4092, 'The White Lotus S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203002.mp4', 'http://timg.bdta.pro/images/5dafad18866f28d88ea03508032a6472.jpg'),
(60471, 4093, 'The White Lotus S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4z73uxjvVtRTxtVMpAOqBvLUWKB.jpg'),
(60472, 4093, 'The White Lotus S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/csqwjkw9OD54u2IhRm55tNd5J9N.jpg'),
(60473, 4093, 'The White Lotus S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203005.mp4', 'http://image.tmdb.org/t/p/w1280/rtSmCH9xGCze8rEOyvPTQ8Z7CSI.jpg'),
(60474, 4093, 'The White Lotus S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2tZIDlI6phQX9z7RGK78iFToaHa.jpg'),
(60475, 4093, 'The White Lotus S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lYlIwggNP8mPtySr4jnNzFdT7X0.jpg'),
(60476, 4093, 'The White Lotus S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203008.mp4', 'http://image.tmdb.org/t/p/w1280/rqLxfTioOxhrklaY7pyK5ZiuRX7.jpg'),
(60477, 4093, 'The White Lotus S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203009.mp4', 'http://image.tmdb.org/t/p/w1280/243a6NIkZ1ai5FmT2bpdcf4Av5g.jpg'),
(60478, 4094, 'The White Lotus S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/699437.mp4', 'http://gstaticontent.com/images/98c4e617637816f15398a43570db9afc.jpg'),
(60479, 4094, 'The White Lotus S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/703791.mp4', 'http://gstaticontent.com/images/98c4e617637816f15398a43570db9afc.jpg'),
(60480, 4094, 'The White Lotus S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/715889.mp4', 'http://gstaticontent.com/images/98c4e617637816f15398a43570db9afc.jpg'),
(60481, 4094, 'The White Lotus S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/720787.mp4', 'http://gstaticontent.com/images/98c4e617637816f15398a43570db9afc.jpg'),
(60482, 4094, 'The White Lotus S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/728389.mp4', 'http://gstaticontent.com/images/98c4e617637816f15398a43570db9afc.jpg'),
(60483, 4094, 'The White Lotus S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/737106.mp4', 'http://gstaticontent.com/images/98c4e617637816f15398a43570db9afc.jpg'),
(60484, 4094, 'The White Lotus S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/750009.mp4', 'http://gstaticontent.com/images/98c4e617637816f15398a43570db9afc.jpg'),
(60485, 4094, 'The White Lotus S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/757768.mp4', 'http://gstaticontent.com/images/98c4e617637816f15398a43570db9afc.jpg'),
(60486, 4095, 'Tico e Teco: Defensores da Lei S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152913.mp4', 'http://timg.bdta.pro/images/605697c876be89fbf06a4b476ebdfeec.jpg'),
(60487, 4095, 'Tico e Teco: Defensores da Lei S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152914.mp4', 'http://timg.bdta.pro/images/9593960f241e596f0b25aefc1541ba0a.jpg'),
(60488, 4095, 'Tico e Teco: Defensores da Lei S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152915.mp4', 'http://timg.bdta.pro/images/e95121b8291789027a9e3975f40c9650.jpg'),
(60489, 4095, 'Tico e Teco: Defensores da Lei S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152916.mp4', 'http://timg.bdta.pro/images/d0cca52bf664e01517df82220592a608.jpg'),
(60490, 4095, 'Tico e Teco: Defensores da Lei S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152917.mp4', 'http://timg.bdta.pro/images/dc2413eee012275445e8151e3aec9503.jpg'),
(60491, 4095, 'Tico e Teco: Defensores da Lei S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152918.mp4', 'http://timg.bdta.pro/images/9190ad33380d74ba49a68f7f5f87eab9.jpg'),
(60492, 4095, 'Tico e Teco: Defensores da Lei S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152919.mp4', 'http://timg.bdta.pro/images/c2d80a5599e2c8d2e86e4345387ad085.jpg'),
(60493, 4095, 'Tico e Teco: Defensores da Lei S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152920.mp4', 'http://timg.bdta.pro/images/de8745e2cf2b046bb0fa5c2ecf654924.jpg'),
(60494, 4095, 'Tico e Teco: Defensores da Lei S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152921.mp4', 'http://timg.bdta.pro/images/0e146d729e1922077b4a979b9bacdc46.jpg'),
(60495, 4095, 'Tico e Teco: Defensores da Lei S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152922.mp4', 'http://timg.bdta.pro/images/69dbb2624eba7f02364e8309e23c6f33.jpg'),
(60496, 4095, 'Tico e Teco: Defensores da Lei S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152923.mp4', 'http://timg.bdta.pro/images/09dae64a1fbaf3b013e1a8f5a092c2b0.jpg'),
(60497, 4095, 'Tico e Teco: Defensores da Lei S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152924.mp4', 'http://timg.bdta.pro/images/e0745131e1a074adb539bc17cea63574.jpg'),
(60498, 4095, 'Tico e Teco: Defensores da Lei S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152925.mp4', 'http://timg.bdta.pro/images/96b6a8b0531fe02924b40146e08245f1.jpg'),
(60499, 4096, 'Tico e Teco: Defensores da Lei S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152926.mp4', 'http://timg.bdta.pro/images/fc3e9f60fe77b43ce9d6297c638a76f2.jpg'),
(60500, 4096, 'Tico e Teco: Defensores da Lei S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152927.mp4', 'http://timg.bdta.pro/images/c867c0185f68eb07f041c54cd801d7cd.jpg'),
(60501, 4096, 'Tico e Teco: Defensores da Lei S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152928.mp4', 'http://timg.bdta.pro/images/58bde1688d67aa1a868b30ba465df9bd.jpg'),
(60502, 4096, 'Tico e Teco: Defensores da Lei S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152929.mp4', 'http://timg.bdta.pro/images/0b2a4cacd610de4f131cf6fd8c44b6ab.jpg'),
(60503, 4096, 'Tico e Teco: Defensores da Lei S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152930.mp4', 'http://timg.bdta.pro/images/94e882734059592e1c82152a74d0a922.jpg'),
(60504, 4096, 'Tico e Teco: Defensores da Lei S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152931.mp4', 'http://timg.bdta.pro/images/6962eda609dee49c5b5fb36a3f710897.jpg'),
(60505, 4096, 'Tico e Teco: Defensores da Lei S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152932.mp4', 'http://timg.bdta.pro/images/168c486968de73355f8a55bfd7dfc2b0.jpg'),
(60506, 4096, 'Tico e Teco: Defensores da Lei S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152933.mp4', 'http://timg.bdta.pro/images/e426ba6d45a828cfee1f7cbfc8c30331.jpg'),
(60507, 4096, 'Tico e Teco: Defensores da Lei S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152934.mp4', 'http://timg.bdta.pro/images/1692edce9af94cace2d4a5d528c5fb9b.jpg'),
(60508, 4096, 'Tico e Teco: Defensores da Lei S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152935.mp4', 'http://timg.bdta.pro/images/1c86ab0f853614c3d5a92304f66d31dc.jpg'),
(60509, 4096, 'Tico e Teco: Defensores da Lei S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152936.mp4', 'http://timg.bdta.pro/images/a19dd59467e8b10bdb6347e62fad8145.jpg'),
(60510, 4096, 'Tico e Teco: Defensores da Lei S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152937.mp4', 'http://timg.bdta.pro/images/d0c06089b0756d3885b7e07e9439e905.jpg'),
(60511, 4096, 'Tico e Teco: Defensores da Lei S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152938.mp4', 'http://timg.bdta.pro/images/83bb7f8ff9936ccb955e0a988b2f4de5.jpg'),
(60512, 4096, 'Tico e Teco: Defensores da Lei S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152939.mp4', 'http://timg.bdta.pro/images/5b8b85e22b3567ca1959cf628e9d35ee.jpg'),
(60513, 4096, 'Tico e Teco: Defensores da Lei S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152940.mp4', 'http://timg.bdta.pro/images/f6321be223a9356735702b7620a18095.jpg'),
(60514, 4096, 'Tico e Teco: Defensores da Lei S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152941.mp4', 'http://timg.bdta.pro/images/0c89b26e4ded3d4e99c8cb95a9674751.jpg'),
(60515, 4096, 'Tico e Teco: Defensores da Lei S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152942.mp4', 'http://timg.bdta.pro/images/83056193f84d2057e92ce9f2f90fde70.jpg'),
(60516, 4096, 'Tico e Teco: Defensores da Lei S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152943.mp4', 'http://timg.bdta.pro/images/a571119781d75dd2fe9ee220fe17c559.jpg'),
(60517, 4096, 'Tico e Teco: Defensores da Lei S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152944.mp4', 'http://timg.bdta.pro/images/bfbdd23925ff36ebdff68508884143ab.jpg'),
(60518, 4096, 'Tico e Teco: Defensores da Lei S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/152945.mp4', 'http://timg.bdta.pro/images/38ff5baedf262830b6cdf524cfcd21ae.jpg'),
(60519, 4096, 'Tico e Teco: Defensores da Lei S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/152946.mp4', 'http://timg.bdta.pro/images/5f9501fcbd875150887ebfc3b954f642.jpg'),
(60520, 4096, 'Tico e Teco: Defensores da Lei S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/152947.mp4', 'http://timg.bdta.pro/images/1eff09843695901d2950dd45d1c06f56.jpg'),
(60521, 4096, 'Tico e Teco: Defensores da Lei S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/152948.mp4', 'http://timg.bdta.pro/images/b5e7f0b3db16d6b1c59557d5634bb389.jpg'),
(60522, 4096, 'Tico e Teco: Defensores da Lei S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/152949.mp4', 'http://timg.bdta.pro/images/9edb5a5fd4e8c0dbcd5d5d8912dd9004.jpg'),
(60523, 4096, 'Tico e Teco: Defensores da Lei S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/152950.mp4', 'http://timg.bdta.pro/images/ef4ba2e5727a1eaf1c8c9cf1d4856e6c.jpg'),
(60524, 4096, 'Tico e Teco: Defensores da Lei S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/152951.mp4', 'http://timg.bdta.pro/images/0356243302536c1a5f90347a7a7541b7.jpg'),
(60525, 4096, 'Tico e Teco: Defensores da Lei S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/152952.mp4', 'http://timg.bdta.pro/images/ae7c6fca388cd9448a14656c1006586c.jpg'),
(60526, 4096, 'Tico e Teco: Defensores da Lei S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/152953.mp4', 'http://timg.bdta.pro/images/5db00a7b6e1c6fd3091ad251b5dbe589.jpg'),
(60527, 4096, 'Tico e Teco: Defensores da Lei S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/152954.mp4', 'http://timg.bdta.pro/images/86e37b00bf52a8b6f5f621414a387479.jpg'),
(60528, 4096, 'Tico e Teco: Defensores da Lei S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/152955.mp4', 'http://timg.bdta.pro/images/de20f4a78300727c2f9f00c34423a09a.jpg'),
(60529, 4096, 'Tico e Teco: Defensores da Lei S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/152956.mp4', 'http://timg.bdta.pro/images/ce9be30fc6d3bb58aca68a478cf5fc09.jpg'),
(60530, 4096, 'Tico e Teco: Defensores da Lei S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/152957.mp4', 'http://timg.bdta.pro/images/748e9501186df367644786d13f8f634b.jpg'),
(60531, 4096, 'Tico e Teco: Defensores da Lei S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/152958.mp4', 'http://timg.bdta.pro/images/2cb252362053d8014896a525c0678acc.jpg'),
(60532, 4096, 'Tico e Teco: Defensores da Lei S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/152959.mp4', 'http://timg.bdta.pro/images/31ba8ceafaebb5f44f30fe5c0fa577de.jpg'),
(60533, 4096, 'Tico e Teco: Defensores da Lei S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/152960.mp4', 'http://timg.bdta.pro/images/74aeeae0b963ebf82fe59fa7ae91c25f.jpg'),
(60534, 4096, 'Tico e Teco: Defensores da Lei S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/152961.mp4', 'http://timg.bdta.pro/images/1b11080e36d03a4db5c52769b5080b46.jpg'),
(60535, 4096, 'Tico e Teco: Defensores da Lei S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/152962.mp4', 'http://timg.bdta.pro/images/dffc200ea99fa1cfdce36341cf35cad9.jpg'),
(60536, 4096, 'Tico e Teco: Defensores da Lei S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/152963.mp4', 'http://timg.bdta.pro/images/346c60287a3c972e93a353eea0e5d297.jpg'),
(60537, 4096, 'Tico e Teco: Defensores da Lei S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/152964.mp4', 'http://timg.bdta.pro/images/21febb7514790c25630c444ba7d34c0b.jpg'),
(60538, 4096, 'Tico e Teco: Defensores da Lei S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/152965.mp4', 'http://timg.bdta.pro/images/2f9aecbd9fd59ab08e3f853117de726a.jpg'),
(60539, 4096, 'Tico e Teco: Defensores da Lei S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/152966.mp4', 'http://timg.bdta.pro/images/803b702dc78df95ff075db7a3e248949.jpg'),
(60540, 4096, 'Tico e Teco: Defensores da Lei S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/152967.mp4', 'http://timg.bdta.pro/images/576d4a2cc5efbe0846cbd81873828ad3.jpg'),
(60541, 4096, 'Tico e Teco: Defensores da Lei S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/152968.mp4', 'http://timg.bdta.pro/images/0810e02b46fb973e250ddac9730ee58c.jpg'),
(60542, 4096, 'Tico e Teco: Defensores da Lei S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/152969.mp4', 'http://timg.bdta.pro/images/c1be09322df2753460569c7c0d00706e.jpg'),
(60543, 4096, 'Tico e Teco: Defensores da Lei S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/152970.mp4', 'http://timg.bdta.pro/images/9c63558966d2fe53411070174f880e13.jpg'),
(60544, 4096, 'Tico e Teco: Defensores da Lei S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/152971.mp4', 'http://timg.bdta.pro/images/3417c0c029828f087ebfbe322d655ff0.jpg'),
(60545, 4096, 'Tico e Teco: Defensores da Lei S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/152972.mp4', 'http://timg.bdta.pro/images/ccf8b7805b5d9f30684a12c9dfbe0355.jpg'),
(60546, 4097, 'Tico e Teco: Defensores da Lei S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152973.mp4', 'http://timg.bdta.pro/images/427aa7586edf673436750c331e3da188.jpg'),
(60547, 4097, 'Tico e Teco: Defensores da Lei S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152974.mp4', 'http://timg.bdta.pro/images/58fefdcefab5ae3834f841d8700c19ac.jpg'),
(60548, 4097, 'Tico e Teco: Defensores da Lei S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152975.mp4', 'http://timg.bdta.pro/images/e8ce40fa2edaa82148de2bb25775ed64.jpg'),
(60549, 4097, 'Tico e Teco: Defensores da Lei S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152976.mp4', 'http://timg.bdta.pro/images/9ff3c055f4e34be54ef6b8776a1e394b.jpg'),
(60550, 4097, 'Tico e Teco: Defensores da Lei S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152977.mp4', 'http://timg.bdta.pro/images/bdd1ced2c245b1ccc88eae4058528216.jpg'),
(60551, 4098, 'Toquio 2020 No Sportv Cerimonia de Abertura Toquio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152910.mp4', 'http://gstaticontent.com/images/d666f076d450fb505c2d6f0f6fb30aea.jpg'),
(60552, 4098, 'Toquio 2020 No Sportv Cerimonia de Abertura Toquio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152911.mp4', 'http://gstaticontent.com/images/d666f076d450fb505c2d6f0f6fb30aea.jpg'),
(60553, 4098, 'Toquio 2020 No Sportv Cerimonia de Abertura Toquio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152912.mp4', 'http://gstaticontent.com/images/d666f076d450fb505c2d6f0f6fb30aea.jpg'),
(60554, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152871.mp4', 'http://timg.bdta.pro/images/f4df7537fbbc93086e3824ee2355bbba.jpg'),
(60555, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152872.mp4', 'http://timg.bdta.pro/images/3208f13d20457880d2ba48e3e031731e.jpg'),
(60556, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152873.mp4', 'http://timg.bdta.pro/images/07d51c31544b9dd7abf316c9e9daba55.jpg'),
(60557, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152874.mp4', 'http://timg.bdta.pro/images/e46664230bfa2e67afea4071c6a2f701.jpg'),
(60558, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152875.mp4', 'http://timg.bdta.pro/images/a73211d860d1166937d91354f3f6ff45.jpg'),
(60559, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152876.mp4', 'http://timg.bdta.pro/images/dbba184bf2d33fe1c079d966152a3ddf.jpg'),
(60560, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152877.mp4', 'http://timg.bdta.pro/images/1bc54088ce182372a7110a2ff8c9ef36.jpg'),
(60561, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152878.mp4', 'http://timg.bdta.pro/images/18c3eef0ee69446fb1f851a155d47632.jpg'),
(60562, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152879.mp4', 'http://timg.bdta.pro/images/0f02a765606f3bd842de22af819ff3a7.jpg'),
(60563, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152880.mp4', 'http://timg.bdta.pro/images/17d9643287f4e92d886e666087a3c6f9.jpg'),
(60564, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152881.mp4', 'http://timg.bdta.pro/images/cb7c0b0e9eb4390c222e24ccf58be183.jpg'),
(60565, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152882.mp4', 'http://timg.bdta.pro/images/20f522def948e39da595736e5420584a.jpg'),
(60566, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152883.mp4', 'http://timg.bdta.pro/images/15c1887654b675c0ec2f84fb4c20cffe.jpg'),
(60567, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152884.mp4', 'http://timg.bdta.pro/images/dbac55b1e0cde876768e9e262376d83f.jpg'),
(60568, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152885.mp4', 'http://timg.bdta.pro/images/20677633c47b4750275da2d13d93d194.jpg'),
(60569, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152886.mp4', 'http://timg.bdta.pro/images/40576e2c0b3f2f8aca8c0a21012b7a99.jpg'),
(60570, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152887.mp4', 'http://timg.bdta.pro/images/9bfbcaef4d57c882937e56e92bc1b756.jpg'),
(60571, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152888.mp4', 'http://timg.bdta.pro/images/6b30f4a85c5a8d61cc95fba6e68f7787.jpg'),
(60572, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152889.mp4', 'http://timg.bdta.pro/images/145c48f4a58b4cc8998f81bab6de7db9.jpg'),
(60573, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/152890.mp4', 'http://timg.bdta.pro/images/ecad318fe68f42031aeab857bb0458fa.jpg'),
(60574, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/152891.mp4', 'http://timg.bdta.pro/images/a160e8255892baa459cb98edc48dc4d6.jpg'),
(60575, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/152892.mp4', 'http://timg.bdta.pro/images/095017bc5fd22b88937c954bbacb3e7b.jpg'),
(60576, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/152893.mp4', 'http://timg.bdta.pro/images/4788fda359d66d292dee8c168f37c793.jpg'),
(60577, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/152894.mp4', 'http://timg.bdta.pro/images/c14a761aa4720d9fa32048626b56ef02.jpg'),
(60578, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/152895.mp4', 'http://timg.bdta.pro/images/3e62ea9511bafb3089a9dc0f1feeb1f0.jpg'),
(60579, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/152896.mp4', 'http://timg.bdta.pro/images/64e6fa08b4cbe13a66e4f3e197c88e8f.jpg'),
(60580, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/152897.mp4', 'http://timg.bdta.pro/images/8193381cfd43b8212d81c9da69f2579b.jpg'),
(60581, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/152898.mp4', 'http://timg.bdta.pro/images/dccda2c67196d3e4d4af219f195a82e4.jpg'),
(60582, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/152899.mp4', 'http://timg.bdta.pro/images/edbcd57bdd078fc1e73d3d3e2970a3a5.jpg'),
(60583, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/152900.mp4', 'http://timg.bdta.pro/images/6528d8c854cbdb8de04cb8e900b65a27.jpg'),
(60584, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/152901.mp4', 'http://timg.bdta.pro/images/cd5925ea7c42cfb8da5f8b51cc8cda17.jpg'),
(60585, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/152902.mp4', 'http://timg.bdta.pro/images/b14605691c4323047c3e6c157ae30b4d.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(60586, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/152903.mp4', 'http://timg.bdta.pro/images/71aa49b9291eea07bfe864749ad156c6.jpg'),
(60587, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/152904.mp4', 'http://timg.bdta.pro/images/3edc67bc203d6baed75ea129033ee425.jpg'),
(60588, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/152905.mp4', 'http://timg.bdta.pro/images/4b0a5ef434ae29308c9b2c98772f8d6e.jpg'),
(60589, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/152906.mp4', 'http://timg.bdta.pro/images/b8b4d24efd62973f7e0c57cc802a4168.jpg'),
(60590, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/152907.mp4', 'http://timg.bdta.pro/images/986eea91daecd9d8f4a587498faef157.jpg'),
(60591, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/152908.mp4', 'http://timg.bdta.pro/images/eac25ac9fcdcd636dad40b9c2a736ada.jpg'),
(60592, 4099, 'Series | TV Quack Pack O Pato Donald e Seus Sobrinhos S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/152909.mp4', 'http://timg.bdta.pro/images/ba6e329591f67f62d92f7f1b6dfeb4e9.jpg'),
(60593, 4100, 'Yashahime Princess Half Demon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152762.mp4', 'http://timg.bdta.pro/images/6421b34273e95ecf8d46bd85b3c592d0.jpg'),
(60594, 4100, 'Yashahime Princess Half Demon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152763.mp4', 'http://timg.bdta.pro/images/27eece12ab6b93011e6d81836d9a9e25.jpg'),
(60595, 4100, 'Yashahime Princess Half Demon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152764.mp4', 'http://timg.bdta.pro/images/ac940f779c156e63255e09f30ca4708d.jpg'),
(60596, 4100, 'Yashahime Princess Half Demon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152765.mp4', 'http://timg.bdta.pro/images/3b9e1ad084375df5ed35d57936699a44.jpg'),
(60597, 4100, 'Yashahime Princess Half Demon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152766.mp4', 'http://timg.bdta.pro/images/1d08f1fa1c55ce2e1b8cd66b42ab3cc2.jpg'),
(60598, 4100, 'Yashahime Princess Half Demon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152767.mp4', 'http://timg.bdta.pro/images/9b8a46d2918eb4e1d4e346a779018a4a.jpg'),
(60599, 4100, 'Yashahime Princess Half Demon S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152768.mp4', 'http://timg.bdta.pro/images/0b3d2b10d8755ca51312c14b0b99f6a5.jpg'),
(60600, 4100, 'Yashahime Princess Half Demon S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152769.mp4', 'http://timg.bdta.pro/images/5085ae279934ca7d0e2f05fcf34fa9d0.jpg'),
(60601, 4100, 'Yashahime Princess Half Demon S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152770.mp4', 'http://timg.bdta.pro/images/cb14ca21e7692028ba070314d67b8f0c.jpg'),
(60602, 4100, 'Yashahime Princess Half Demon S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152771.mp4', 'http://timg.bdta.pro/images/6168d4676092f945511f87045a7f39b4.jpg'),
(60603, 4100, 'Yashahime Princess Half Demon S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152772.mp4', 'http://timg.bdta.pro/images/175555d9ed3eeda0b867bf27d8c39559.jpg'),
(60604, 4100, 'Yashahime Princess Half Demon S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152773.mp4', 'http://timg.bdta.pro/images/d59ab5d65c68a5c4fd89ac42f7762cdb.jpg'),
(60605, 4100, 'Yashahime Princess Half Demon S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152774.mp4', 'http://timg.bdta.pro/images/12ccc7e46bbcc834b5f88d746e532f92.jpg'),
(60606, 4100, 'Yashahime Princess Half Demon S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152775.mp4', 'http://timg.bdta.pro/images/ca9328b0d8cd03e845d76ff64149dd26.jpg'),
(60607, 4100, 'Yashahime Princess Half Demon S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152776.mp4', 'http://timg.bdta.pro/images/74f44a954488576db179931ddf689c2f.jpg'),
(60608, 4100, 'Yashahime Princess Half Demon S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152777.mp4', 'http://timg.bdta.pro/images/4d3288e87821240950f00f64cd0a1075.jpg'),
(60609, 4100, 'Yashahime Princess Half Demon S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152778.mp4', 'http://timg.bdta.pro/images/e5719404b8ba316be996480c3a80a4e1.jpg'),
(60610, 4100, 'Yashahime Princess Half Demon S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152779.mp4', 'http://timg.bdta.pro/images/5359674b11e689cf053e1ef0c02b3d5c.jpg'),
(60611, 4100, 'Yashahime Princess Half Demon S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152780.mp4', 'http://timg.bdta.pro/images/7b4ec7a71b41a6d155bcfeb8d975e88b.jpg'),
(60612, 4100, 'Yashahime Princess Half Demon S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/152781.mp4', 'http://timg.bdta.pro/images/13ac9dae55cc48f56dda689277a4bd00.jpg'),
(60613, 4100, 'Yashahime Princess Half Demon S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/152782.mp4', 'http://timg.bdta.pro/images/7d2f7ed01a0139bf3430b786b849d38a.jpg'),
(60614, 4100, 'Yashahime Princess Half Demon S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/152783.mp4', 'http://timg.bdta.pro/images/e527842c7f1f73bb07d37203545b1ef0.jpg'),
(60615, 4100, 'Yashahime Princess Half Demon S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/152784.mp4', 'http://timg.bdta.pro/images/59da3ecfec00f91dd525fe02b023d767.jpg'),
(60616, 4100, 'Yashahime Princess Half Demon S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/152785.mp4', 'http://timg.bdta.pro/images/8254ceed51f04339fadca5d5a4b9736f.jpg'),
(60617, 4101, 'Allen v. Farrow S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152758.mp4', 'http://timg.bdta.pro/images/6b81bb52d607b485851118ba7025f5f6.jpg'),
(60618, 4101, 'Allen v. Farrow S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152759.mp4', 'http://timg.bdta.pro/images/efbe794cafd461c27b63e54a70d763b8.jpg'),
(60619, 4101, 'Allen v. Farrow S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152760.mp4', 'http://timg.bdta.pro/images/497ae86a79b48d1dc8c0f3cd836962e3.jpg'),
(60620, 4101, 'Allen v. Farrow S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152761.mp4', 'http://timg.bdta.pro/images/8eda8a1613a1ab85ed98d83b68a85897.jpg'),
(60621, 4102, 'Brincando Com Fogo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227374.mp4', 'http://timg.bdta.pro/images/523001624ce67ffd830f2eb6a7526044.jpg'),
(60622, 4102, 'Brincando Com Fogo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227375.mp4', 'http://timg.bdta.pro/images/f811cb8cbac094f7de7cc8fb28bdbf0a.jpg'),
(60623, 4102, 'Brincando Com Fogo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227376.mp4', 'http://timg.bdta.pro/images/9dbeee2fc1e6a31551c2cf9830ee7d9a.jpg'),
(60624, 4102, 'Brincando Com Fogo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227377.mp4', 'http://timg.bdta.pro/images/023793288d39b9a414ea57833a746055.jpg'),
(60625, 4102, 'Brincando Com Fogo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227378.mp4', 'http://timg.bdta.pro/images/7195f6da83805a2e2a623cf5514bda89.jpg'),
(60626, 4102, 'Brincando Com Fogo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227379.mp4', 'http://timg.bdta.pro/images/3fe0c515e08305c35f65fcc4fb933148.jpg'),
(60627, 4102, 'Brincando Com Fogo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227380.mp4', 'http://timg.bdta.pro/images/120b44101f7c8ebb668a6435b3e9d1c5.jpg'),
(60628, 4102, 'Brincando Com Fogo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227381.mp4', 'http://timg.bdta.pro/images/fc56d32869b676ffd2e9847ff5446579.jpg'),
(60629, 4103, 'Brincando Com Fogo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227382.mp4', 'http://timg.bdta.pro/images/5be68a8adfb5931ceb74715339d789d2.jpg'),
(60630, 4103, 'Brincando Com Fogo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227383.mp4', 'http://timg.bdta.pro/images/e51fe976f587ba2fe0f72fb15cfdc227.jpg'),
(60631, 4103, 'Brincando Com Fogo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227384.mp4', 'http://timg.bdta.pro/images/c2b549f1e04d47d37f1ddb8b3fc6047f.jpg'),
(60632, 4103, 'Brincando Com Fogo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227385.mp4', 'http://timg.bdta.pro/images/f1a336379fc37b7441f37eb54e20148b.jpg'),
(60633, 4103, 'Brincando Com Fogo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227386.mp4', 'http://timg.bdta.pro/images/b77fe2458812421b63d51dc898355016.jpg'),
(60634, 4103, 'Brincando Com Fogo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227387.mp4', 'http://timg.bdta.pro/images/306fbd0f740cad8de39fa9951325b483.jpg'),
(60635, 4103, 'Brincando Com Fogo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227388.mp4', 'http://timg.bdta.pro/images/d64f7bf2813050a4604c094145c4b12c.jpg'),
(60636, 4103, 'Brincando Com Fogo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227389.mp4', 'http://timg.bdta.pro/images/c769d3e709f740b3fed3726286272693.jpg'),
(60637, 4103, 'Brincando Com Fogo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227390.mp4', 'http://timg.bdta.pro/images/39d7bf57e41327c2bf284ef34959d126.jpg'),
(60638, 4103, 'Brincando Com Fogo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227391.mp4', 'http://timg.bdta.pro/images/4c27617cd606a071dc8c89e8dfe9051b.jpg'),
(60639, 4104, 'Brincando Com Fogo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227392.mp4', 'http://gstaticontent.com/images/e77064521661270cb188efda49505f61.jpg'),
(60640, 4104, 'Brincando Com Fogo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227393.mp4', 'http://gstaticontent.com/images/e77064521661270cb188efda49505f61.jpg'),
(60641, 4104, 'Brincando Com Fogo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227394.mp4', 'http://gstaticontent.com/images/e77064521661270cb188efda49505f61.jpg'),
(60642, 4104, 'Brincando Com Fogo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227395.mp4', 'http://gstaticontent.com/images/e77064521661270cb188efda49505f61.jpg'),
(60643, 4104, 'Brincando Com Fogo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227396.mp4', 'http://gstaticontent.com/images/e77064521661270cb188efda49505f61.jpg'),
(60644, 4104, 'Brincando Com Fogo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227397.mp4', 'http://gstaticontent.com/images/e77064521661270cb188efda49505f61.jpg'),
(60645, 4104, 'Brincando Com Fogo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227398.mp4', 'http://gstaticontent.com/images/e77064521661270cb188efda49505f61.jpg'),
(60646, 4104, 'Brincando Com Fogo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227399.mp4', 'http://gstaticontent.com/images/e77064521661270cb188efda49505f61.jpg'),
(60647, 4104, 'Brincando Com Fogo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227400.mp4', 'http://gstaticontent.com/images/e77064521661270cb188efda49505f61.jpg'),
(60648, 4104, 'Brincando Com Fogo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227401.mp4', 'http://gstaticontent.com/images/e77064521661270cb188efda49505f61.jpg'),
(60649, 4105, 'Brincando Com Fogo S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bW0L1odiJbcRfBnVemQF72OzC78.jpg'),
(60650, 4105, 'Brincando Com Fogo S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3dMW4Vn0N35h7NEZOs9PZ6TYo9V.jpg'),
(60651, 4105, 'Brincando Com Fogo S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d798bltbJoy7esJBN0PUF8deDbo.jpg'),
(60652, 4105, 'Brincando Com Fogo S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKuK0cFb6cCL0aXsDQyBoLHDDGu.jpg'),
(60653, 4105, 'Brincando Com Fogo S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iXEC10uLSfayPEGROQJHDGppv0Y.jpg'),
(60654, 4106, 'Brincando Com Fogo S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7MPneQPYdiCRd4J5sib7IlWThpd.jpg'),
(60655, 4106, 'Brincando Com Fogo S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/llCgUbnsS0g7eRdPdjYL55FuCKF.jpg'),
(60656, 4106, 'Brincando Com Fogo S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJP2H9GD0GZBpgQhib6ZVIHEPh4.jpg'),
(60657, 4106, 'Brincando Com Fogo S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mwRZaQ7uVqDpabLcUHLdJkZRhx3.jpg'),
(60658, 4106, 'Brincando Com Fogo S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nED315ZJaTp3DmsptMkoT56tqx8.jpg'),
(60659, 4106, 'Brincando Com Fogo S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ms938MPfo3ElpB0Cco9I7DYkyGP.jpg'),
(60660, 4106, 'Brincando Com Fogo S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/own6oAjYsKTYd6c8xra0D5wl0ZS.jpg'),
(60661, 4106, 'Brincando Com Fogo S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nGQm170LiMWpnaX4dfId9MvQPml.jpg'),
(60662, 4106, 'Brincando Com Fogo S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Rt9Q8zaOMVYeNjKfZ83r69rwFe.jpg'),
(60663, 4106, 'Brincando Com Fogo S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8fmiplRnoAaMYD4ifXVwwrnthVM.jpg'),
(60664, 4107, 'Geração 30 e Poucos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152750.mp4', 'http://timg.bdta.pro/images/b308c7f0ed282d936f85f5b966dc105f.jpg'),
(60665, 4107, 'Geração 30 e Poucos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152751.mp4', 'http://timg.bdta.pro/images/fdf1876b0dc4c1862b621c5b95c8abc3.jpg'),
(60666, 4107, 'Geração 30 e Poucos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152752.mp4', 'http://timg.bdta.pro/images/efb3f05fbf33fd0c53f185d3824b1f22.jpg'),
(60667, 4107, 'Geração 30 e Poucos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152753.mp4', 'http://timg.bdta.pro/images/8df2f001dec2d7cbb6fab930dc35215d.jpg'),
(60668, 4107, 'Geração 30 e Poucos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152754.mp4', 'http://timg.bdta.pro/images/ba46ab617bc4553e8ce76913b2dc027f.jpg'),
(60669, 4107, 'Geração 30 e Poucos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152755.mp4', 'http://timg.bdta.pro/images/22f9ab865e721a96abe625d663174d3e.jpg'),
(60670, 4107, 'Geração 30 e Poucos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152756.mp4', 'http://timg.bdta.pro/images/9acbf946cb6f16b1f82ac788907b7947.jpg'),
(60671, 4107, 'Geração 30 e Poucos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152757.mp4', 'http://timg.bdta.pro/images/d52386cb803b131f9e18826adc1e3756.jpg'),
(60672, 4108, 'Hora do Recreio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152685.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60673, 4108, 'Hora do Recreio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152686.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60674, 4108, 'Hora do Recreio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152687.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60675, 4108, 'Hora do Recreio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152688.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60676, 4108, 'Hora do Recreio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152689.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60677, 4108, 'Hora do Recreio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152690.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60678, 4108, 'Hora do Recreio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152691.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60679, 4108, 'Hora do Recreio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152692.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60680, 4108, 'Hora do Recreio S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152693.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60681, 4108, 'Hora do Recreio S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152694.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60682, 4108, 'Hora do Recreio S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152695.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60683, 4108, 'Hora do Recreio S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152696.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60684, 4108, 'Hora do Recreio S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152697.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60685, 4109, 'Hora do Recreio S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152698.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60686, 4109, 'Hora do Recreio S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152699.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60687, 4109, 'Hora do Recreio S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152700.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60688, 4109, 'Hora do Recreio S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152701.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60689, 4109, 'Hora do Recreio S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152702.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60690, 4109, 'Hora do Recreio S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152703.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60691, 4109, 'Hora do Recreio S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152704.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60692, 4109, 'Hora do Recreio S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152705.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60693, 4109, 'Hora do Recreio S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152706.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60694, 4109, 'Hora do Recreio S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152707.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60695, 4109, 'Hora do Recreio S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152708.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60696, 4109, 'Hora do Recreio S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152709.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60697, 4109, 'Hora do Recreio S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152710.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60698, 4110, 'Hora do Recreio S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152711.mp4', 'http://timg.bdta.pro/images/e421ec33374ff25d74ea6971825d546a.jpg'),
(60699, 4110, 'Hora do Recreio S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152712.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60700, 4110, 'Hora do Recreio S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152713.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60701, 4110, 'Hora do Recreio S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152714.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60702, 4110, 'Hora do Recreio S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152715.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60703, 4110, 'Hora do Recreio S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152716.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60704, 4110, 'Hora do Recreio S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152717.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60705, 4110, 'Hora do Recreio S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152718.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60706, 4111, 'Hora do Recreio S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152719.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60707, 4111, 'Hora do Recreio S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152720.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60708, 4111, 'Hora do Recreio S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152721.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60709, 4111, 'Hora do Recreio S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152722.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60710, 4111, 'Hora do Recreio S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152723.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60711, 4111, 'Hora do Recreio S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152724.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60712, 4111, 'Hora do Recreio S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152725.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60713, 4111, 'Hora do Recreio S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152726.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60714, 4111, 'Hora do Recreio S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152727.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60715, 4111, 'Hora do Recreio S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152728.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60716, 4111, 'Hora do Recreio S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152729.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60717, 4111, 'Hora do Recreio S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152730.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60718, 4111, 'Hora do Recreio S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152731.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60719, 4111, 'Hora do Recreio S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152732.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60720, 4111, 'Hora do Recreio S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152733.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60721, 4111, 'Hora do Recreio S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152734.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60722, 4111, 'Hora do Recreio S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152735.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60723, 4111, 'Hora do Recreio S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152736.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60724, 4111, 'Hora do Recreio S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152737.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60725, 4111, 'Hora do Recreio S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/152738.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60726, 4111, 'Hora do Recreio S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/152739.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60727, 4111, 'Hora do Recreio S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/152740.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60728, 4112, 'Hora do Recreio S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152741.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60729, 4112, 'Hora do Recreio S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152742.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60730, 4112, 'Hora do Recreio S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152743.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60731, 4112, 'Hora do Recreio S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152744.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60732, 4112, 'Hora do Recreio S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152745.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60733, 4112, 'Hora do Recreio S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152746.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60734, 4112, 'Hora do Recreio S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152747.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60735, 4112, 'Hora do Recreio S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152748.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60736, 4112, 'Hora do Recreio S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152749.mp4', 'http://gstaticontent.com/images/399996f81ef28a621dd7da05d607ed5b.jpg'),
(60737, 4113, 'Os Jetsons S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152027.mp4', 'http://timg.bdta.pro/images/0e9bb610f9f17582e4558aa200c56998.jpg'),
(60738, 4113, 'Os Jetsons S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152028.mp4', 'http://timg.bdta.pro/images/06441b14c4ac159d2d2903901c47a121.jpg'),
(60739, 4113, 'Os Jetsons S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152029.mp4', 'http://timg.bdta.pro/images/e65897653937ae1928711f5e4f97ba28.jpg'),
(60740, 4113, 'Os Jetsons S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152030.mp4', 'http://timg.bdta.pro/images/18cb72ca40c1a156a6ead5566df87cbe.jpg'),
(60741, 4113, 'Os Jetsons S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152031.mp4', 'http://timg.bdta.pro/images/d9bb2228101c8d2906137880aece3dda.jpg'),
(60742, 4113, 'Os Jetsons S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152032.mp4', 'http://timg.bdta.pro/images/82a27bf69339fc7a8de2b27f3d51e8fb.jpg'),
(60743, 4113, 'Os Jetsons S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152033.mp4', 'http://timg.bdta.pro/images/fa9443aaa80515dbf916706b929864db.jpg'),
(60744, 4113, 'Os Jetsons S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152034.mp4', 'http://timg.bdta.pro/images/4ab80ea482e401785e9ef7f0f18cce8a.jpg'),
(60745, 4113, 'Os Jetsons S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152035.mp4', 'http://timg.bdta.pro/images/1bab4f4a1b63b6dcb5119dfcfb6b067f.jpg'),
(60746, 4113, 'Os Jetsons S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152036.mp4', 'http://timg.bdta.pro/images/ca68e2fcf0baa80f30748b4326473298.jpg'),
(60747, 4113, 'Os Jetsons S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152037.mp4', 'http://timg.bdta.pro/images/64a8e3de3c005f9af51087420bff1af7.jpg'),
(60748, 4113, 'Os Jetsons S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152038.mp4', 'http://timg.bdta.pro/images/eee61e66c95cd6b104aa384afd1ca83b.jpg'),
(60749, 4113, 'Os Jetsons S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152039.mp4', 'http://timg.bdta.pro/images/2fb0a05155d4f6013cbf90f65cc967ad.jpg'),
(60750, 4113, 'Os Jetsons S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152040.mp4', 'http://timg.bdta.pro/images/8b37d75065fc741873a30549537a5054.jpg'),
(60751, 4113, 'Os Jetsons S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152041.mp4', 'http://timg.bdta.pro/images/c770cf0a9b281b5572e3e06ffbab770e.jpg'),
(60752, 4113, 'Os Jetsons S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152042.mp4', 'http://timg.bdta.pro/images/70344d8e0ebee4d4326819b9bbe3d529.jpg'),
(60753, 4113, 'Os Jetsons S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152043.mp4', 'http://timg.bdta.pro/images/6b38274c8ae40efe45a5d5988d447220.jpg'),
(60754, 4113, 'Os Jetsons S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152044.mp4', 'http://timg.bdta.pro/images/0ac95b832c9b3dccae5829ca2abcfd8f.jpg'),
(60755, 4113, 'Os Jetsons S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152045.mp4', 'http://timg.bdta.pro/images/847b0b90524b81744043d3e852fdb91d.jpg'),
(60756, 4113, 'Os Jetsons S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/152046.mp4', 'http://timg.bdta.pro/images/875769710c11810829d728810201efb6.jpg'),
(60757, 4113, 'Os Jetsons S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/152047.mp4', 'http://timg.bdta.pro/images/b461a1c487cfd455bdfd14370b77204c.jpg'),
(60758, 4113, 'Os Jetsons S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/152048.mp4', 'http://timg.bdta.pro/images/a99079f82fed5fafb8d793363653f5c5.jpg'),
(60759, 4113, 'Os Jetsons S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/152049.mp4', 'http://timg.bdta.pro/images/6a1bab26bbc631e8251286c2f877d984.jpg'),
(60760, 4113, 'Os Jetsons S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/152050.mp4', 'http://timg.bdta.pro/images/8c50f75b28adabcd5b89cd146bbe6ceb.jpg'),
(60761, 4114, 'Os Jetsons S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152051.mp4', 'http://timg.bdta.pro/images/0807250083e59f21a61888e69a1f1500.jpg'),
(60762, 4114, 'Os Jetsons S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152052.mp4', 'http://timg.bdta.pro/images/268f7f9c2f30636d8d16d577e59b2b15.jpg'),
(60763, 4114, 'Os Jetsons S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152053.mp4', 'http://timg.bdta.pro/images/01cc3803b11acf52055d3dfbdd9b0cc4.jpg'),
(60764, 4114, 'Os Jetsons S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152054.mp4', 'http://timg.bdta.pro/images/fe647467f543e2a1b8051d6ff70d54eb.jpg'),
(60765, 4114, 'Os Jetsons S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152055.mp4', 'http://timg.bdta.pro/images/cfbbda9ff38ade840c3b55f3bdef2b42.jpg'),
(60766, 4114, 'Os Jetsons S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152056.mp4', 'http://timg.bdta.pro/images/84203adc641d8228d580c9599ab4aa95.jpg'),
(60767, 4114, 'Os Jetsons S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152057.mp4', 'http://timg.bdta.pro/images/508da82df4ad4c9405d892a55665fc89.jpg'),
(60768, 4114, 'Os Jetsons S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152058.mp4', 'http://timg.bdta.pro/images/3541ccf8ebc5f09d00f431940b23a81d.jpg'),
(60769, 4114, 'Os Jetsons S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152059.mp4', 'http://timg.bdta.pro/images/90e2ce478c761c6a2c213192d373a094.jpg'),
(60770, 4114, 'Os Jetsons S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152060.mp4', 'http://timg.bdta.pro/images/fb0eb6f348b6c1de759bafb0a7fc845d.jpg'),
(60771, 4114, 'Os Jetsons S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152061.mp4', 'http://timg.bdta.pro/images/2a008a45943a2aef3d221df51fed2055.jpg'),
(60772, 4114, 'Os Jetsons S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152062.mp4', 'http://timg.bdta.pro/images/04bb8d5f539bc368659d5435f403e52c.jpg'),
(60773, 4114, 'Os Jetsons S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152063.mp4', 'http://timg.bdta.pro/images/d6ed8b664ffa92e3c55afb2ddd1658f5.jpg'),
(60774, 4114, 'Os Jetsons S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152064.mp4', 'http://timg.bdta.pro/images/f6fc2b387bdc3f2b5553d656a7084a14.jpg'),
(60775, 4114, 'Os Jetsons S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152065.mp4', 'http://timg.bdta.pro/images/50a67469cbbcb846683c80fa1954b7d3.jpg'),
(60776, 4114, 'Os Jetsons S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152066.mp4', 'http://timg.bdta.pro/images/d930a1ed88eb2226d4e3c5d746ca9ddd.jpg'),
(60777, 4114, 'Os Jetsons S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152067.mp4', 'http://timg.bdta.pro/images/e3d8b8926bbc6f2aaaef5acc9dc1cbfd.jpg'),
(60778, 4114, 'Os Jetsons S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152068.mp4', 'http://timg.bdta.pro/images/b8c5f2665504182cb16a5a075b930fde.jpg'),
(60779, 4114, 'Os Jetsons S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152069.mp4', 'http://timg.bdta.pro/images/5d021326f90858a460559b971bc21aec.jpg'),
(60780, 4114, 'Os Jetsons S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/152070.mp4', 'http://timg.bdta.pro/images/c39470b4bb4ddac8fedd29b754ba27d1.jpg'),
(60781, 4114, 'Os Jetsons S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/152071.mp4', 'http://timg.bdta.pro/images/c9c68447f40a8f62824dfd36b9f0da92.jpg'),
(60782, 4114, 'Os Jetsons S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/152072.mp4', 'http://timg.bdta.pro/images/6de2618388324694381f11d021ff7597.jpg'),
(60783, 4114, 'Os Jetsons S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/152073.mp4', 'http://timg.bdta.pro/images/c8094adadf63ac6da01f95105ebb0584.jpg'),
(60784, 4114, 'Os Jetsons S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/152074.mp4', 'http://timg.bdta.pro/images/16f08394b4142617a8daf1f6ec1560b4.jpg'),
(60785, 4114, 'Os Jetsons S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/152075.mp4', 'http://timg.bdta.pro/images/3e998579cceda573271041071b21b0e3.jpg'),
(60786, 4114, 'Os Jetsons S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/152076.mp4', 'http://timg.bdta.pro/images/f64cfa72413907f3fbeec6ff93c62349.jpg'),
(60787, 4114, 'Os Jetsons S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/152077.mp4', 'http://timg.bdta.pro/images/fefff186c3afd3e141e32d855d17dd37.jpg'),
(60788, 4114, 'Os Jetsons S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/152078.mp4', 'http://timg.bdta.pro/images/7323f2ddcc83553d7adfe7ca3db0bf67.jpg'),
(60789, 4114, 'Os Jetsons S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/152079.mp4', 'http://timg.bdta.pro/images/9ca22b0227edb15ff47d9c3591b7f211.jpg'),
(60790, 4114, 'Os Jetsons S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/152080.mp4', 'http://timg.bdta.pro/images/662d46a6c9c458d8fc7986b7f0a25eb3.jpg'),
(60791, 4114, 'Os Jetsons S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/152081.mp4', 'http://timg.bdta.pro/images/dbb82b436bdc2a001954e7bac15a91f4.jpg'),
(60792, 4114, 'Os Jetsons S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/152082.mp4', 'http://timg.bdta.pro/images/b10ae0349e25a9ed4c33bc65744e857f.jpg'),
(60793, 4114, 'Os Jetsons S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/152083.mp4', 'http://timg.bdta.pro/images/7364f0dfc729187bfd0ee6fdb156bba4.jpg'),
(60794, 4114, 'Os Jetsons S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/152084.mp4', 'http://timg.bdta.pro/images/a777749f7c8a2d334be6841440ee464c.jpg'),
(60795, 4114, 'Os Jetsons S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/152085.mp4', 'http://timg.bdta.pro/images/c08b48dbbe4f98ac6ef4ec13a768e642.jpg'),
(60796, 4114, 'Os Jetsons S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/152086.mp4', 'http://timg.bdta.pro/images/b4d73a6524b865fd187c061703f8b8d3.jpg'),
(60797, 4114, 'Os Jetsons S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/152087.mp4', 'http://timg.bdta.pro/images/a440eed45742aee985354402c57b9f42.jpg'),
(60798, 4114, 'Os Jetsons S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/152088.mp4', 'http://timg.bdta.pro/images/2890de7a1d1a270a7580d3b9597dcc88.jpg'),
(60799, 4114, 'Os Jetsons S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/152089.mp4', 'http://timg.bdta.pro/images/037df2fe9c898feaff988bb0407bf6d2.jpg'),
(60800, 4114, 'Os Jetsons S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/152090.mp4', 'http://timg.bdta.pro/images/7185650e2245804a83d0ae3783e8c77c.jpg'),
(60801, 4114, 'Os Jetsons S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/152091.mp4', 'http://timg.bdta.pro/images/0c9224d5048fc70eb798bb340c1031c1.jpg'),
(60802, 4115, 'Os Jetsons S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152092.mp4', 'http://timg.bdta.pro/images/d5d2be81823c0b142af53ab0d0a99289.jpg'),
(60803, 4115, 'Os Jetsons S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152093.mp4', 'http://timg.bdta.pro/images/f18202fef87e84fb1cfafbec31d82307.jpg'),
(60804, 4115, 'Os Jetsons S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152094.mp4', 'http://timg.bdta.pro/images/549b505cfb2bba61a85e035efbe46ea9.jpg'),
(60805, 4115, 'Os Jetsons S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152095.mp4', 'http://timg.bdta.pro/images/4a925e92fca783d70c76f611c7a33674.jpg'),
(60806, 4115, 'Os Jetsons S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152096.mp4', 'http://timg.bdta.pro/images/9db9910244e4de20cecc72aeffa14bf8.jpg'),
(60807, 4115, 'Os Jetsons S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152097.mp4', 'http://timg.bdta.pro/images/87df367f5b4524f6a89b1a3a499404ad.jpg'),
(60808, 4115, 'Os Jetsons S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152098.mp4', 'http://timg.bdta.pro/images/f452cde5c6166ab71586f4fd72492dd4.jpg'),
(60809, 4115, 'Os Jetsons S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152099.mp4', 'http://timg.bdta.pro/images/56e07415e3efd5c44d95eb7c43771c43.jpg'),
(60810, 4115, 'Os Jetsons S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152100.mp4', 'http://timg.bdta.pro/images/f3d520dbf4cdbd68e13f7bd45008f5e3.jpg'),
(60811, 4115, 'Os Jetsons S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152101.mp4', 'http://timg.bdta.pro/images/c239f858d5f7b52cb0618126789294a4.jpg'),
(60812, 4116, 'Os Padrinhos Mágicos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152505.mp4', 'http://timg.bdta.pro/images/94140a63900a3ca29830fe43dbdbdec5.jpg'),
(60813, 4116, 'Os Padrinhos Mágicos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152506.mp4', 'http://timg.bdta.pro/images/24ab2f55896db574b50f03cbe79a4783.jpg'),
(60814, 4116, 'Os Padrinhos Mágicos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152507.mp4', 'http://timg.bdta.pro/images/21caa25181bca0003484873e0f655847.jpg'),
(60815, 4116, 'Os Padrinhos Mágicos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152508.mp4', 'http://timg.bdta.pro/images/678c9b6507da7884730562b022d3dba3.jpg'),
(60816, 4116, 'Os Padrinhos Mágicos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152509.mp4', 'http://timg.bdta.pro/images/dee478af5a99db7e730034845da4c30c.jpg'),
(60817, 4116, 'Os Padrinhos Mágicos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152510.mp4', 'http://timg.bdta.pro/images/655fc362c87123ec6483a331d7cefd02.jpg'),
(60818, 4116, 'Os Padrinhos Mágicos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152511.mp4', 'http://timg.bdta.pro/images/f2323895dbd29cad7655a608d43079b4.jpg'),
(60819, 4117, 'Os Padrinhos Mágicos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152512.mp4', 'http://timg.bdta.pro/images/ef5c71e2993dbaa1712f320a7b14e67a.jpg'),
(60820, 4117, 'Os Padrinhos Mágicos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152513.mp4', 'http://timg.bdta.pro/images/b97ea8610706a2c69b832fcd3b66a581.jpg'),
(60821, 4117, 'Os Padrinhos Mágicos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152514.mp4', 'http://timg.bdta.pro/images/4f5e5807bc5710fc88420bc4240c4913.jpg'),
(60822, 4117, 'Os Padrinhos Mágicos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152515.mp4', 'http://timg.bdta.pro/images/4d9f0dfb71971b5c601293c6f12c0336.jpg'),
(60823, 4117, 'Os Padrinhos Mágicos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152516.mp4', 'http://timg.bdta.pro/images/713b197130fd93d1b0dd2b82c2b5bedb.jpg'),
(60824, 4117, 'Os Padrinhos Mágicos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152517.mp4', 'http://timg.bdta.pro/images/955cbc5fb949637c2bf0d4d215f1c874.jpg'),
(60825, 4117, 'Os Padrinhos Mágicos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152518.mp4', 'http://timg.bdta.pro/images/348ea06a331ef366646569a7abedb816.jpg'),
(60826, 4117, 'Os Padrinhos Mágicos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152519.mp4', 'http://timg.bdta.pro/images/39bfe248e92ffc301197cb0e4c2d9fa8.jpg'),
(60827, 4117, 'Os Padrinhos Mágicos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152520.mp4', 'http://timg.bdta.pro/images/14ab4a5635e8d0e8c15fae36703a6ec2.jpg'),
(60828, 4117, 'Os Padrinhos Mágicos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152521.mp4', 'http://timg.bdta.pro/images/d06aefe9e7c4e1d21f1a0172e8648af8.jpg'),
(60829, 4117, 'Os Padrinhos Mágicos S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152522.mp4', 'http://timg.bdta.pro/images/f3291a9369061a0bc22c2c4c04b04bf8.jpg'),
(60830, 4117, 'Os Padrinhos Mágicos S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152523.mp4', 'http://timg.bdta.pro/images/b24c810e0080b29a8d0a34beec3f4380.jpg'),
(60831, 4117, 'Os Padrinhos Mágicos S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152524.mp4', 'http://timg.bdta.pro/images/d61c0a3ac129308a63314b430eecbac9.jpg'),
(60832, 4117, 'Os Padrinhos Mágicos S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152525.mp4', 'http://timg.bdta.pro/images/9e035803af1eaa6f80f7c97e740c77aa.jpg'),
(60833, 4117, 'Os Padrinhos Mágicos S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152526.mp4', 'http://timg.bdta.pro/images/213f97f8d93cf8bb29ef8ba6a29d1d28.jpg'),
(60834, 4117, 'Os Padrinhos Mágicos S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152527.mp4', 'http://timg.bdta.pro/images/4ba1b3ceb5b8230597e29a62b9ea4e3d.jpg'),
(60835, 4117, 'Os Padrinhos Mágicos S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152528.mp4', 'http://timg.bdta.pro/images/a42a11ae485ff5df2d919f8b91e5f45b.jpg'),
(60836, 4117, 'Os Padrinhos Mágicos S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152529.mp4', 'http://timg.bdta.pro/images/6e16fdd7540a358b481862a6670e3a97.jpg'),
(60837, 4117, 'Os Padrinhos Mágicos S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152530.mp4', 'http://timg.bdta.pro/images/f3b1b6b0bb608ec4973d38648a3df847.jpg'),
(60838, 4118, 'Os Padrinhos Mágicos S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152531.mp4', 'http://timg.bdta.pro/images/84436bb262f8445ebbce04d9d7a1e24f.jpg'),
(60839, 4118, 'Os Padrinhos Mágicos S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152532.mp4', 'http://timg.bdta.pro/images/77a31bec3e2aebb3d1354a73d6ffc24d.jpg'),
(60840, 4118, 'Os Padrinhos Mágicos S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152533.mp4', 'http://timg.bdta.pro/images/72bc1148583aa2d740703d2d73366223.jpg'),
(60841, 4118, 'Os Padrinhos Mágicos S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152534.mp4', 'http://timg.bdta.pro/images/f7122a543a19c39e90b27cf618fdb436.jpg'),
(60842, 4118, 'Os Padrinhos Mágicos S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152535.mp4', 'http://timg.bdta.pro/images/9e5ffe2d8ababbac0d78fcb24020b10c.jpg'),
(60843, 4118, 'Os Padrinhos Mágicos S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152536.mp4', 'http://timg.bdta.pro/images/0830eca0a8896f12c77e27c41229abd2.jpg'),
(60844, 4118, 'Os Padrinhos Mágicos S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152537.mp4', 'http://timg.bdta.pro/images/16d3e2ff10af4661c24b0eefb944e8c0.jpg'),
(60845, 4118, 'Os Padrinhos Mágicos S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152538.mp4', 'http://timg.bdta.pro/images/1d6618d28defeaee54a97b69bb0079fa.jpg'),
(60846, 4118, 'Os Padrinhos Mágicos S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152539.mp4', 'http://timg.bdta.pro/images/145a46fa43f0d0b7d8b1ccb8d2260917.jpg'),
(60847, 4118, 'Os Padrinhos Mágicos S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152540.mp4', 'http://timg.bdta.pro/images/6ea0a21d95d75c589201f96b2f3466ed.jpg'),
(60848, 4118, 'Os Padrinhos Mágicos S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152541.mp4', 'http://timg.bdta.pro/images/c8a3adf03db014c72457cdb31aed90a9.jpg'),
(60849, 4118, 'Os Padrinhos Mágicos S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152542.mp4', 'http://timg.bdta.pro/images/f512c7c9761b4daa1cb9f5bbdc471237.jpg'),
(60850, 4118, 'Os Padrinhos Mágicos S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152543.mp4', 'http://timg.bdta.pro/images/19817bc67647689a403f317e6be07da5.jpg'),
(60851, 4118, 'Os Padrinhos Mágicos S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152544.mp4', 'http://timg.bdta.pro/images/e39a413c6583efa58332f1d358605945.jpg'),
(60852, 4119, 'Os Padrinhos Mágicos S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152545.mp4', 'http://timg.bdta.pro/images/f3534e5f6fc59e6f774b11768b14e387.jpg'),
(60853, 4119, 'Os Padrinhos Mágicos S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152546.mp4', 'http://timg.bdta.pro/images/b3a4f28c4394ece3a08287b1c29dd6a7.jpg'),
(60854, 4119, 'Os Padrinhos Mágicos S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152547.mp4', 'http://timg.bdta.pro/images/e731451ecc6232aacf53328bcf00cefb.jpg'),
(60855, 4119, 'Os Padrinhos Mágicos S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152548.mp4', 'http://timg.bdta.pro/images/f8302d42b45dbadc14872b0d3f241d28.jpg'),
(60856, 4119, 'Os Padrinhos Mágicos S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152549.mp4', 'http://timg.bdta.pro/images/912a43348327c2bf5b0201ad7787fe39.jpg'),
(60857, 4119, 'Os Padrinhos Mágicos S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152550.mp4', 'http://timg.bdta.pro/images/d4d6b6684ce0c18423d7fc65a6d7c3c8.jpg'),
(60858, 4119, 'Os Padrinhos Mágicos S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152551.mp4', 'http://timg.bdta.pro/images/4fc07f864bb430f561c8372e65610bce.jpg'),
(60859, 4119, 'Os Padrinhos Mágicos S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152552.mp4', 'http://timg.bdta.pro/images/67a8d3f3e104bd6584273477b2b4de51.jpg'),
(60860, 4119, 'Os Padrinhos Mágicos S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152553.mp4', 'http://timg.bdta.pro/images/1cd3881c36526e6b9376eea20b02d120.jpg'),
(60861, 4119, 'Os Padrinhos Mágicos S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152554.mp4', 'http://timg.bdta.pro/images/a66ec6e6547a44fa35ff83fdd30c775c.jpg'),
(60862, 4119, 'Os Padrinhos Mágicos S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152555.mp4', 'http://timg.bdta.pro/images/1cd3881c36526e6b9376eea20b02d120.jpg'),
(60863, 4119, 'Os Padrinhos Mágicos S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152556.mp4', 'http://timg.bdta.pro/images/8921c81b21a2ce0b1499d9ea446a3720.jpg'),
(60864, 4119, 'Os Padrinhos Mágicos S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152557.mp4', 'http://timg.bdta.pro/images/1cd3881c36526e6b9376eea20b02d120.jpg'),
(60865, 4119, 'Os Padrinhos Mágicos S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152558.mp4', 'http://timg.bdta.pro/images/7e6a33316b7d3d37e24ac684f71b9157.jpg'),
(60866, 4119, 'Os Padrinhos Mágicos S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152559.mp4', 'http://timg.bdta.pro/images/2eab6d57ab4e486f7d8857c2453307bd.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(60867, 4119, 'Os Padrinhos Mágicos S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152560.mp4', 'http://timg.bdta.pro/images/3320dbb55cce0e9db2f83bf28cc5afe8.jpg'),
(60868, 4119, 'Os Padrinhos Mágicos S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152561.mp4', 'http://timg.bdta.pro/images/124bb553ec5eb3314742792abff0b620.jpg'),
(60869, 4119, 'Os Padrinhos Mágicos S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152562.mp4', 'http://timg.bdta.pro/images/20bb579255ecdffe695522964a347334.jpg'),
(60870, 4119, 'Os Padrinhos Mágicos S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152563.mp4', 'http://timg.bdta.pro/images/a3bd77697a0975bdeca63aa42ac8bc09.jpg'),
(60871, 4120, 'Os Padrinhos Mágicos S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152564.mp4', 'http://timg.bdta.pro/images/1bcbf531c333fe2505200c600e6061a1.jpg'),
(60872, 4120, 'Os Padrinhos Mágicos S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152565.mp4', 'http://timg.bdta.pro/images/0a6281fee6ddd683de0f5d8cc6765152.jpg'),
(60873, 4120, 'Os Padrinhos Mágicos S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152566.mp4', 'http://timg.bdta.pro/images/902354e17e54daf8b7ce6b5baafecc04.jpg'),
(60874, 4120, 'Os Padrinhos Mágicos S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152567.mp4', 'http://timg.bdta.pro/images/1555645506d3be685844a6d646cbcd80.jpg'),
(60875, 4120, 'Os Padrinhos Mágicos S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152568.mp4', 'http://timg.bdta.pro/images/bb1f0ff551d04dd754a7a1a87a95581d.jpg'),
(60876, 4120, 'Os Padrinhos Mágicos S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152569.mp4', 'http://timg.bdta.pro/images/b89c4d58425931fd3ac66669d3957165.jpg'),
(60877, 4120, 'Os Padrinhos Mágicos S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152570.mp4', 'http://timg.bdta.pro/images/a58b564e48231bb8a28fd21549467470.jpg'),
(60878, 4120, 'Os Padrinhos Mágicos S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152571.mp4', 'http://timg.bdta.pro/images/3a59cff31735dc8bf85ce0a2f7ca191f.jpg'),
(60879, 4120, 'Os Padrinhos Mágicos S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152572.mp4', 'http://timg.bdta.pro/images/d551474c730752c6586f6e644847de1c.jpg'),
(60880, 4120, 'Os Padrinhos Mágicos S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152573.mp4', 'http://timg.bdta.pro/images/0e2f62c42f309bbd26a0b0c1c596b076.jpg'),
(60881, 4120, 'Os Padrinhos Mágicos S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152574.mp4', 'http://timg.bdta.pro/images/587cc894e9187e166c9f90e8f5dd1a79.jpg'),
(60882, 4120, 'Os Padrinhos Mágicos S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152575.mp4', 'http://timg.bdta.pro/images/831a1d06b525b79ae1e7d85234fa37b2.jpg'),
(60883, 4120, 'Os Padrinhos Mágicos S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152576.mp4', 'http://timg.bdta.pro/images/9279f78e172c9cf75f8ef4041a1bedeb.jpg'),
(60884, 4120, 'Os Padrinhos Mágicos S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152577.mp4', 'http://timg.bdta.pro/images/dc70a79687fe2900f71c28aa191aeaac.jpg'),
(60885, 4120, 'Os Padrinhos Mágicos S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152578.mp4', 'http://timg.bdta.pro/images/4e63657f57048c52c0720433b4b595b3.jpg'),
(60886, 4120, 'Os Padrinhos Mágicos S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152579.mp4', 'http://timg.bdta.pro/images/227c68c3552b6667354b4949dad4e6f6.jpg'),
(60887, 4120, 'Os Padrinhos Mágicos S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152580.mp4', 'http://timg.bdta.pro/images/ca12a4c53188afa2e9f9753c369eadeb.jpg'),
(60888, 4120, 'Os Padrinhos Mágicos S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152581.mp4', 'http://timg.bdta.pro/images/0d1ba3c597de2bb5408e646eef20df26.jpg'),
(60889, 4120, 'Os Padrinhos Mágicos S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152582.mp4', 'http://timg.bdta.pro/images/f71b6eb79b5663042518158130c36c39.jpg'),
(60890, 4120, 'Os Padrinhos Mágicos S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/152583.mp4', 'http://timg.bdta.pro/images/63a098151e7929db4188c9ec6a933689.jpg'),
(60891, 4120, 'Os Padrinhos Mágicos S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/152584.mp4', 'http://timg.bdta.pro/images/a1b44a94e387ceca12d240b5154872d7.jpg'),
(60892, 4120, 'Os Padrinhos Mágicos S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/152585.mp4', 'http://timg.bdta.pro/images/a39ea4f905a8efee4634448bf9d4015a.jpg'),
(60893, 4120, 'Os Padrinhos Mágicos S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/152586.mp4', 'http://timg.bdta.pro/images/5bc5bb8433af61bb34f322f10f84a136.jpg'),
(60894, 4120, 'Os Padrinhos Mágicos S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/152587.mp4', 'http://timg.bdta.pro/images/8a0749ddc78607f58c0631a87773f112.jpg'),
(60895, 4120, 'Os Padrinhos Mágicos S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/152588.mp4', 'http://timg.bdta.pro/images/0fd0dc4fc9aeea012af564f026a857ed.jpg'),
(60896, 4121, 'Os Padrinhos Mágicos S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152589.mp4', 'http://timg.bdta.pro/images/8075581460d5e3325c88bb79c33e06b7.jpg'),
(60897, 4121, 'Os Padrinhos Mágicos S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152590.mp4', 'http://timg.bdta.pro/images/5eaa4a1d7abe28f2480a91ce1b9f0089.jpg'),
(60898, 4121, 'Os Padrinhos Mágicos S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152591.mp4', 'http://timg.bdta.pro/images/990e60a3b1159073515c367b4172f924.jpg'),
(60899, 4121, 'Os Padrinhos Mágicos S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152592.mp4', 'http://timg.bdta.pro/images/6b0f8380394c9853721af9d7d9c29d75.jpg'),
(60900, 4121, 'Os Padrinhos Mágicos S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152593.mp4', 'http://timg.bdta.pro/images/78fa7b8334287c349b9ac40c32d8cb90.jpg'),
(60901, 4121, 'Os Padrinhos Mágicos S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152594.mp4', 'http://timg.bdta.pro/images/36b7e4a933f842540e3fdcf3b7819542.jpg'),
(60902, 4121, 'Os Padrinhos Mágicos S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152595.mp4', 'http://timg.bdta.pro/images/5a83c8ebfe304c378136664a009bb5c4.jpg'),
(60903, 4121, 'Os Padrinhos Mágicos S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152596.mp4', 'http://timg.bdta.pro/images/a7f89cb17224a49d0c2b13d0e6c84741.jpg'),
(60904, 4121, 'Os Padrinhos Mágicos S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152597.mp4', 'http://timg.bdta.pro/images/0991eaa01145e04bda21d73ac8dae748.jpg'),
(60905, 4121, 'Os Padrinhos Mágicos S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152598.mp4', 'http://timg.bdta.pro/images/ef3988895ec16000836d2783a1167461.jpg'),
(60906, 4121, 'Os Padrinhos Mágicos S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152599.mp4', 'http://timg.bdta.pro/images/020552907a7c4c0d91412ec7b6269ac9.jpg'),
(60907, 4121, 'Os Padrinhos Mágicos S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152600.mp4', 'http://timg.bdta.pro/images/3f6b1dc6b887bdee3511b1d312c653bb.jpg'),
(60908, 4121, 'Os Padrinhos Mágicos S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152601.mp4', 'http://timg.bdta.pro/images/4691bfee2eaffebb7c1b88b40774db78.jpg'),
(60909, 4121, 'Os Padrinhos Mágicos S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152602.mp4', 'http://timg.bdta.pro/images/6a8407d8a028d47ef9e5b020fcce137f.jpg'),
(60910, 4121, 'Os Padrinhos Mágicos S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152603.mp4', 'http://timg.bdta.pro/images/a33bde3890d5e9718bde43a7d7fb9e36.jpg'),
(60911, 4121, 'Os Padrinhos Mágicos S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152604.mp4', 'http://timg.bdta.pro/images/53c8520d5da14307d5acc91f6aa8af96.jpg'),
(60912, 4121, 'Os Padrinhos Mágicos S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152605.mp4', 'http://timg.bdta.pro/images/51f484f2c51571e4ddb522973f16da5b.jpg'),
(60913, 4121, 'Os Padrinhos Mágicos S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152606.mp4', 'http://timg.bdta.pro/images/ca7f4d9558531fff5e3b8856b7310c55.jpg'),
(60914, 4121, 'Os Padrinhos Mágicos S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152607.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60915, 4121, 'Os Padrinhos Mágicos S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/152608.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60916, 4122, 'Os Padrinhos Mágicos S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152609.mp4', 'http://timg.bdta.pro/images/56a4ca8b986069af2b74fa00a4a70106.jpg'),
(60917, 4122, 'Os Padrinhos Mágicos S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152610.mp4', 'http://timg.bdta.pro/images/7dfaf370144907e0ecaf9bc800c98f65.jpg'),
(60918, 4122, 'Os Padrinhos Mágicos S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152611.mp4', 'http://timg.bdta.pro/images/fcfec56bb2bbb3093b0933093632834e.jpg'),
(60919, 4122, 'Os Padrinhos Mágicos S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152612.mp4', 'http://timg.bdta.pro/images/7df8895df1bf27f772647d484b833758.jpg'),
(60920, 4122, 'Os Padrinhos Mágicos S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152613.mp4', 'http://timg.bdta.pro/images/0944526e3becc0fc968ff22cb8aec160.jpg'),
(60921, 4122, 'Os Padrinhos Mágicos S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152614.mp4', 'http://timg.bdta.pro/images/be9f025d367f3961a5b43351b3701d00.jpg'),
(60922, 4122, 'Os Padrinhos Mágicos S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152615.mp4', 'http://timg.bdta.pro/images/0197873be75839c8eb51ed9ebb7376b9.jpg'),
(60923, 4122, 'Os Padrinhos Mágicos S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152616.mp4', 'http://timg.bdta.pro/images/025ff0426f53d024b1176d04848fc2b9.jpg'),
(60924, 4122, 'Os Padrinhos Mágicos S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152617.mp4', 'http://timg.bdta.pro/images/327b85b07b91f2b8115efa172efbbbb3.jpg'),
(60925, 4122, 'Os Padrinhos Mágicos S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152618.mp4', 'http://timg.bdta.pro/images/56a09e3ef2d8ca4fd1803b36c92532ca.jpg'),
(60926, 4122, 'Os Padrinhos Mágicos S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152619.mp4', 'http://timg.bdta.pro/images/b10f373b3c95196d2ea30c02398d5fdb.jpg'),
(60927, 4122, 'Os Padrinhos Mágicos S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152620.mp4', 'http://timg.bdta.pro/images/6d26acd7221981eb6308e4421e08d4f1.jpg'),
(60928, 4122, 'Os Padrinhos Mágicos S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152621.mp4', 'http://timg.bdta.pro/images/37b8efb48acaed8fa66cf0fd1a684e85.jpg'),
(60929, 4122, 'Os Padrinhos Mágicos S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152622.mp4', 'http://timg.bdta.pro/images/c1fd80d4a31e5974da814eac9e25b7d9.jpg'),
(60930, 4122, 'Os Padrinhos Mágicos S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152623.mp4', 'http://timg.bdta.pro/images/922a3a3e763467aba93748b47f570093.jpg'),
(60931, 4122, 'Os Padrinhos Mágicos S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152624.mp4', 'http://timg.bdta.pro/images/e244aaf881ec7e986706fd17e011d5bc.jpg'),
(60932, 4122, 'Os Padrinhos Mágicos S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152625.mp4', 'http://timg.bdta.pro/images/c12bf88fdada9131606c7c8241ce1890.jpg'),
(60933, 4122, 'Os Padrinhos Mágicos S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152626.mp4', 'http://timg.bdta.pro/images/33ce0310a9c731fe3dc3f18ff17c3d03.jpg'),
(60934, 4122, 'Os Padrinhos Mágicos S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152627.mp4', 'http://timg.bdta.pro/images/36e2edd2fce25260ff7b2fec8c2fe427.jpg'),
(60935, 4122, 'Os Padrinhos Mágicos S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/152628.mp4', 'http://timg.bdta.pro/images/7c4f755b61153523d03b8033bf98fbee.jpg'),
(60936, 4122, 'Os Padrinhos Mágicos S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/152629.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60937, 4122, 'Os Padrinhos Mágicos S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/152630.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60938, 4122, 'Os Padrinhos Mágicos S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/152631.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60939, 4122, 'Os Padrinhos Mágicos S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/152632.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60940, 4122, 'Os Padrinhos Mágicos S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/152633.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60941, 4123, 'Os Padrinhos Mágicos S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152634.mp4', 'http://timg.bdta.pro/images/38a118ab49d3c8fb9d1adf8ad99ac3eb.jpg'),
(60942, 4123, 'Os Padrinhos Mágicos S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152635.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60943, 4123, 'Os Padrinhos Mágicos S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152636.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60944, 4123, 'Os Padrinhos Mágicos S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152637.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60945, 4123, 'Os Padrinhos Mágicos S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152638.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60946, 4124, 'Os Padrinhos Mágicos S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152639.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60947, 4124, 'Os Padrinhos Mágicos S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152640.mp4', 'http://timg.bdta.pro/images/d351eab8dc1c0e3905d587a254736647.jpg'),
(60948, 4124, 'Os Padrinhos Mágicos S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152641.mp4', 'http://timg.bdta.pro/images/952ddc054dfb3a5ed8664f2c9b580a8b.jpg'),
(60949, 4124, 'Os Padrinhos Mágicos S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152642.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60950, 4124, 'Os Padrinhos Mágicos S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152643.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60951, 4124, 'Os Padrinhos Mágicos S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152644.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60952, 4124, 'Os Padrinhos Mágicos S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152645.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60953, 4124, 'Os Padrinhos Mágicos S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152646.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60954, 4124, 'Os Padrinhos Mágicos S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152647.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60955, 4124, 'Os Padrinhos Mágicos S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152648.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60956, 4124, 'Os Padrinhos Mágicos S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152649.mp4', 'http://timg.bdta.pro/images/3592be931b177ed249ed89e3065c3a36.jpg'),
(60957, 4124, 'Os Padrinhos Mágicos S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152650.mp4', 'http://timg.bdta.pro/images/1073c09d0d9cae048ad00169dc7fed1e.jpg'),
(60958, 4124, 'Os Padrinhos Mágicos S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152651.mp4', 'http://timg.bdta.pro/images/cb4a609d2e92cc12f04e465b36ec3004.jpg'),
(60959, 4124, 'Os Padrinhos Mágicos S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152652.mp4', 'http://timg.bdta.pro/images/333a3225d4728a67112b48d5c0460b78.jpg'),
(60960, 4124, 'Os Padrinhos Mágicos S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152653.mp4', 'http://timg.bdta.pro/images/e0c425304b6666f1d031ff65bf440220.jpg'),
(60961, 4124, 'Os Padrinhos Mágicos S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152654.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60962, 4124, 'Os Padrinhos Mágicos S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152655.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60963, 4124, 'Os Padrinhos Mágicos S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152656.mp4', 'http://timg.bdta.pro/images/4c5da1a5ce883f17a46e54a921c4252e.jpg'),
(60964, 4124, 'Os Padrinhos Mágicos S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152657.mp4', 'http://timg.bdta.pro/images/2d1571e68e221be042d972518e3784d2.jpg'),
(60965, 4124, 'Os Padrinhos Mágicos S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/152658.mp4', 'http://timg.bdta.pro/images/cd8070b7d6629979e0c2ce70d661b503.jpg'),
(60966, 4124, 'Os Padrinhos Mágicos S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/152659.mp4', 'http://timg.bdta.pro/images/34bd5bf4a07e87b448a41dd17cd7b06d.jpg'),
(60967, 4124, 'Os Padrinhos Mágicos S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/152660.mp4', 'http://timg.bdta.pro/images/cd2a2e3c3bd8dca6cccbbe946def6a53.jpg'),
(60968, 4124, 'Os Padrinhos Mágicos S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/152661.mp4', 'http://timg.bdta.pro/images/63a6bd5f10e72a53a34a7793fa12f44c.jpg'),
(60969, 4124, 'Os Padrinhos Mágicos S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/152662.mp4', 'http://timg.bdta.pro/images/02073fe5e636b6f14a3801e0211fc0b2.jpg'),
(60970, 4124, 'Os Padrinhos Mágicos S09 E25', 'http://sinalprivado.info:80/series/1533784/1533784/152663.mp4', 'http://timg.bdta.pro/images/7b8f072c6539bae150f11b26aab6e538.jpg'),
(60971, 4124, 'Os Padrinhos Mágicos S09 E26', 'http://sinalprivado.info:80/series/1533784/1533784/152664.mp4', 'http://timg.bdta.pro/images/545d18acc1a82f7cde4a6c87743b58c8.jpg'),
(60972, 4125, 'Os Padrinhos Mágicos S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152665.mp4', 'http://timg.bdta.pro/images/547f9d962336a6e01bdb7adbda032746.jpg'),
(60973, 4125, 'Os Padrinhos Mágicos S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152666.mp4', 'http://timg.bdta.pro/images/cc8737d737babb0bb29fa80bb7d80067.jpg'),
(60974, 4125, 'Os Padrinhos Mágicos S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152667.mp4', 'http://timg.bdta.pro/images/a38d62bce74d24a92609da4cdd18da9c.jpg'),
(60975, 4125, 'Os Padrinhos Mágicos S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152668.mp4', 'http://timg.bdta.pro/images/54d0b344afe45fa1c1571177f4969bf0.jpg'),
(60976, 4125, 'Os Padrinhos Mágicos S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152669.mp4', 'http://timg.bdta.pro/images/085e93c6a3a4155949e8e7f23736fac7.jpg'),
(60977, 4125, 'Os Padrinhos Mágicos S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152670.mp4', 'http://timg.bdta.pro/images/b01ca87c326a03b966374cbc93506154.jpg'),
(60978, 4125, 'Os Padrinhos Mágicos S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152671.mp4', 'http://timg.bdta.pro/images/3558291d9122432c3f7cbb9d748c7f37.jpg'),
(60979, 4125, 'Os Padrinhos Mágicos S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152672.mp4', 'http://timg.bdta.pro/images/fa5e54c63c8567854498f9bf81430f8e.jpg'),
(60980, 4125, 'Os Padrinhos Mágicos S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152673.mp4', 'http://timg.bdta.pro/images/81568bccac0b8a7a62676805a9f3e653.jpg'),
(60981, 4125, 'Os Padrinhos Mágicos S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152674.mp4', 'http://timg.bdta.pro/images/4124b66284dc0919c15dc95b52b627ce.jpg'),
(60982, 4125, 'Os Padrinhos Mágicos S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152675.mp4', 'http://timg.bdta.pro/images/38e2510087a16bc2ca1974ffa9b51caa.jpg'),
(60983, 4125, 'Os Padrinhos Mágicos S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152676.mp4', 'http://timg.bdta.pro/images/05d9f19a4f59ce91daaa584d9ebf45e2.jpg'),
(60984, 4125, 'Os Padrinhos Mágicos S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152677.mp4', 'http://timg.bdta.pro/images/8bebd5fdfec8d5fc678de9a28c6e0e1d.jpg'),
(60985, 4125, 'Os Padrinhos Mágicos S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152678.mp4', 'http://timg.bdta.pro/images/97aa6ccd45354b8a4561c4d38ca73a8c.jpg'),
(60986, 4125, 'Os Padrinhos Mágicos S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152679.mp4', 'http://gstaticontent.com/images/73998bbfb4784c9319c52378e6bff35a.jpg'),
(60987, 4125, 'Os Padrinhos Mágicos S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152680.mp4', 'http://timg.bdta.pro/images/7524abb6c117b32e1f666f6e657009ae.jpg'),
(60988, 4125, 'Os Padrinhos Mágicos S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152681.mp4', 'http://timg.bdta.pro/images/a40e98b3a53120f9195296edcd4dc085.jpg'),
(60989, 4125, 'Os Padrinhos Mágicos S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152682.mp4', 'http://timg.bdta.pro/images/ee0570761193b19f86d4c08ebb1806dd.jpg'),
(60990, 4125, 'Os Padrinhos Mágicos S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152683.mp4', 'http://timg.bdta.pro/images/869b7cff3598582c89ccd7c2420ad298.jpg'),
(60991, 4125, 'Os Padrinhos Mágicos S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/152684.mp4', 'http://timg.bdta.pro/images/9f05bb7cc7f276e2b2407c1d2a0f29f1.jpg'),
(60992, 4126, 'Raízes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152499.mp4', 'http://timg.bdta.pro/images/da91958c250605d28d68c099789fa09f.jpg'),
(60993, 4126, 'Raízes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152500.mp4', 'http://timg.bdta.pro/images/d3e8c884c2daae9a6a720e83efe58421.jpg'),
(60994, 4126, 'Raízes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152501.mp4', 'http://timg.bdta.pro/images/510f1c83272793c19947047e6f6f4984.jpg'),
(60995, 4126, 'Raízes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152502.mp4', 'http://timg.bdta.pro/images/34fcb589645f2ca48c65175a8638c5d6.jpg'),
(60996, 4126, 'Raízes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152503.mp4', 'http://timg.bdta.pro/images/55b44e6faeb4614354992ff34cb4d984.jpg'),
(60997, 4126, 'Raízes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152504.mp4', 'http://timg.bdta.pro/images/1218d7bc9d178cad626337d8ceef144c.jpg'),
(60998, 4127, 'Sophie: Assassinato em West Cork S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152496.mp4', 'http://timg.bdta.pro/images/429b2a13965292732664c9a626184804.jpg'),
(60999, 4127, 'Sophie: Assassinato em West Cork S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152497.mp4', 'http://timg.bdta.pro/images/e329e39c8619b90256680115964b1e0f.jpg'),
(61000, 4127, 'Sophie: Assassinato em West Cork S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152498.mp4', 'http://timg.bdta.pro/images/fffd71603925fd24b9df489aba628ff0.jpg'),
(61001, 4128, 'Supermães S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210804.mp4', 'http://timg.bdta.pro/images/8af3db5b181e3d2a84e9ed433f3db25d.jpg'),
(61002, 4128, 'Supermães S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210805.mp4', 'http://timg.bdta.pro/images/dcb0546f91cc0303a01081e2d51306b5.jpg'),
(61003, 4128, 'Supermães S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210806.mp4', 'http://timg.bdta.pro/images/9e8bf558f242bf514c28e16e6641159d.jpg'),
(61004, 4128, 'Supermães S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210807.mp4', 'http://timg.bdta.pro/images/8208b6994986f7b128d736c8dfb69781.jpg'),
(61005, 4128, 'Supermães S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210808.mp4', 'http://timg.bdta.pro/images/a641888d85441fb282415c6e392a151c.jpg'),
(61006, 4128, 'Supermães S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210809.mp4', 'http://timg.bdta.pro/images/a152f6465f22dfb74ca130091927dc58.jpg'),
(61007, 4128, 'Supermães S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210810.mp4', 'http://timg.bdta.pro/images/f42c869165416e35811e64ae0f06a26c.jpg'),
(61008, 4128, 'Supermães S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210811.mp4', 'http://timg.bdta.pro/images/b7797f02381ebf5603de276723091502.jpg'),
(61009, 4128, 'Supermães S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210812.mp4', 'http://timg.bdta.pro/images/7fe55c82a114b3e24572a956c8f25b51.jpg'),
(61010, 4128, 'Supermães S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210813.mp4', 'http://timg.bdta.pro/images/62d78bac290d3e442ba995f10d17b90a.jpg'),
(61011, 4128, 'Supermães S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/210814.mp4', 'http://timg.bdta.pro/images/e7ef13d9ab181091e6fb1b66660e9db6.jpg'),
(61012, 4128, 'Supermães S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/210815.mp4', 'http://timg.bdta.pro/images/2917379ceb2f6b0544ce0b83736a9e39.jpg'),
(61013, 4128, 'Supermães S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/210816.mp4', 'http://timg.bdta.pro/images/622667cd9bc08bad04921944af1507d1.jpg'),
(61014, 4129, 'Supermães S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210817.mp4', 'http://timg.bdta.pro/images/2aa40c968e3fa48c20903b317bbc5d8b.jpg'),
(61015, 4129, 'Supermães S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210818.mp4', 'http://timg.bdta.pro/images/a9e24d3de0a748f49ce3ad4418082c7c.jpg'),
(61016, 4129, 'Supermães S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210819.mp4', 'http://timg.bdta.pro/images/f70e495facd83610b1d0eab5415fba26.jpg'),
(61017, 4129, 'Supermães S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210820.mp4', 'http://timg.bdta.pro/images/075330f3c7e8db7f95c5467637a4553b.jpg'),
(61018, 4129, 'Supermães S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210821.mp4', 'http://timg.bdta.pro/images/43c3e0bc49671737583f2a5e1b14eaa8.jpg'),
(61019, 4129, 'Supermães S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210822.mp4', 'http://timg.bdta.pro/images/04e5f15ae0cd51bd5d955480c11542fc.jpg'),
(61020, 4129, 'Supermães S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210823.mp4', 'http://timg.bdta.pro/images/56e897768bd463817a964c3c6d77ffb8.jpg'),
(61021, 4129, 'Supermães S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210824.mp4', 'http://timg.bdta.pro/images/009c7e0c61a5a33f3b16af0bfbb7e948.jpg'),
(61022, 4129, 'Supermães S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210825.mp4', 'http://timg.bdta.pro/images/fe2aaa0bc62a27cf3168f2847951145c.jpg'),
(61023, 4129, 'Supermães S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210826.mp4', 'http://timg.bdta.pro/images/966ccdd2ca6f60872aee9821b318a789.jpg'),
(61024, 4129, 'Supermães S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/210827.mp4', 'http://timg.bdta.pro/images/9a740c642b1c4636b075f4e02c142fd3.jpg'),
(61025, 4129, 'Supermães S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/210828.mp4', 'http://timg.bdta.pro/images/d21d2d3e446cb73074697de0f37ae54c.jpg'),
(61026, 4129, 'Supermães S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/210829.mp4', 'http://timg.bdta.pro/images/7a52cc7d1801ed6712b8cab461c7b92d.jpg'),
(61027, 4130, 'Supermães S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210830.mp4', 'http://timg.bdta.pro/images/db3be941bd5a5fc462773f77601ff491.jpg'),
(61028, 4130, 'Supermães S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210831.mp4', 'http://timg.bdta.pro/images/5c9a5061072cbeb2f28b57fb1f2ca6c5.jpg'),
(61029, 4130, 'Supermães S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210832.mp4', 'http://timg.bdta.pro/images/4115be6766fd6dc7b0b5e49f6447f84b.jpg'),
(61030, 4130, 'Supermães S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210833.mp4', 'http://timg.bdta.pro/images/0a6043f4b117be123c3cb97f8d77c6eb.jpg'),
(61031, 4130, 'Supermães S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210834.mp4', 'http://timg.bdta.pro/images/c3ef44b47c1e8544e1f31dcdcec4939b.jpg'),
(61032, 4130, 'Supermães S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210835.mp4', 'http://timg.bdta.pro/images/46fbd5cacc8f95f9cc03fec3ee406ef0.jpg'),
(61033, 4130, 'Supermães S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210836.mp4', 'http://timg.bdta.pro/images/5d709a8ecd0c703b114b4bd881050490.jpg'),
(61034, 4130, 'Supermães S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210837.mp4', 'http://timg.bdta.pro/images/1358e9b36966c16c8d71a171254b493e.jpg'),
(61035, 4130, 'Supermães S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210838.mp4', 'http://timg.bdta.pro/images/28d2d47a203b3d8194c8563ab16dd624.jpg'),
(61036, 4130, 'Supermães S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210839.mp4', 'http://timg.bdta.pro/images/ea19f256557c769b788fb7a66ecb6b73.jpg'),
(61037, 4130, 'Supermães S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/210840.mp4', 'http://timg.bdta.pro/images/468174ac9c272cb07628e60139cde6c9.jpg'),
(61038, 4130, 'Supermães S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/210841.mp4', 'http://timg.bdta.pro/images/05b9a5f3865daaa09597908e5b634bd8.jpg'),
(61039, 4130, 'Supermães S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/210842.mp4', 'http://timg.bdta.pro/images/1cea0e69b77e8bd8c7b5f7f6d5916b4a.jpg'),
(61040, 4131, 'Supermães S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210843.mp4', 'http://timg.bdta.pro/images/a1fe257e32d6ffa2a057e2a558ae9bb9.jpg'),
(61041, 4131, 'Supermães S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210844.mp4', 'http://timg.bdta.pro/images/8e9b2274d6c190419d700c6e270f3836.jpg'),
(61042, 4131, 'Supermães S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210845.mp4', 'http://timg.bdta.pro/images/035c7199198d670399d96e7b13f6dcf3.jpg'),
(61043, 4131, 'Supermães S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210846.mp4', 'http://timg.bdta.pro/images/85a83c7674c0fc32cce4cc660175a55d.jpg'),
(61044, 4131, 'Supermães S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210847.mp4', 'http://timg.bdta.pro/images/833420b8bf6621b6ae49557efbd7640e.jpg'),
(61045, 4131, 'Supermães S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210848.mp4', 'http://timg.bdta.pro/images/f61b825b7fb1d6a98deb2b4754d951ef.jpg'),
(61046, 4131, 'Supermães S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210849.mp4', 'http://timg.bdta.pro/images/4af75071b289422f8a607631c9717552.jpg'),
(61047, 4131, 'Supermães S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210850.mp4', 'http://timg.bdta.pro/images/f963d6b2ce4fd74c8b0941fdd0ca4437.jpg'),
(61048, 4132, 'Supermães S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210851.mp4', 'http://gstaticontent.com/images/59bb29c57ac429e140987343c7ed9164.jpg'),
(61049, 4132, 'Supermães S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210852.mp4', 'http://gstaticontent.com/images/59bb29c57ac429e140987343c7ed9164.jpg'),
(61050, 4132, 'Supermães S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210853.mp4', 'http://gstaticontent.com/images/59bb29c57ac429e140987343c7ed9164.jpg'),
(61051, 4132, 'Supermães S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210854.mp4', 'http://gstaticontent.com/images/59bb29c57ac429e140987343c7ed9164.jpg'),
(61052, 4132, 'Supermães S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210855.mp4', 'http://gstaticontent.com/images/59bb29c57ac429e140987343c7ed9164.jpg'),
(61053, 4132, 'Supermães S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210856.mp4', 'http://gstaticontent.com/images/59bb29c57ac429e140987343c7ed9164.jpg'),
(61054, 4132, 'Supermães S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210857.mp4', 'http://gstaticontent.com/images/59bb29c57ac429e140987343c7ed9164.jpg'),
(61055, 4132, 'Supermães S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210858.mp4', 'http://gstaticontent.com/images/59bb29c57ac429e140987343c7ed9164.jpg'),
(61056, 4132, 'Supermães S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210859.mp4', 'http://gstaticontent.com/images/59bb29c57ac429e140987343c7ed9164.jpg'),
(61057, 4132, 'Supermães S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210860.mp4', 'http://gstaticontent.com/images/59bb29c57ac429e140987343c7ed9164.jpg'),
(61058, 4133, 'Supermães S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210861.mp4', 'http://timg.bdta.pro/images/f54eff6857f3624017ecc603cbd61b9b.jpg'),
(61059, 4133, 'Supermães S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210862.mp4', 'http://timg.bdta.pro/images/285f05c0ea4b20173c8f4da2d6ae6d5d.jpg'),
(61060, 4133, 'Supermães S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210863.mp4', 'http://timg.bdta.pro/images/3139ec10ac8df2cf243b7da09bfc9057.jpg'),
(61061, 4133, 'Supermães S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210864.mp4', 'http://timg.bdta.pro/images/1f2ffa8593464aa434af37cfe54323e9.jpg'),
(61062, 4133, 'Supermães S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210865.mp4', 'http://timg.bdta.pro/images/4d7db9868b2431ba6de8b70fb58dc693.jpg'),
(61063, 4133, 'Supermães S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210866.mp4', 'http://timg.bdta.pro/images/ccb29497e9c8ab5396c3d174bfc26410.jpg'),
(61064, 4133, 'Supermães S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210867.mp4', 'http://timg.bdta.pro/images/8bf4ee8e1f3101b14bb89a822522097a.jpg'),
(61065, 4133, 'Supermães S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210868.mp4', 'http://timg.bdta.pro/images/abb5051ac859d2001f68db8bdd336326.jpg'),
(61066, 4133, 'Supermães S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210869.mp4', 'http://timg.bdta.pro/images/954355c92f03d2af3b5755fc867166fa.jpg'),
(61067, 4133, 'Supermães S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210870.mp4', 'http://timg.bdta.pro/images/294cedb1d5a93cbdb1a508f15b64e65e.jpg'),
(61068, 4133, 'Supermães S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/210871.mp4', 'http://timg.bdta.pro/images/9439717bbf3925ef221f43866eb7644c.jpg'),
(61069, 4133, 'Supermães S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/210872.mp4', 'http://timg.bdta.pro/images/16631d3d9e7cb639b92425f77165d48d.jpg'),
(61070, 4133, 'Supermães S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/210873.mp4', 'http://timg.bdta.pro/images/b6055eaef0b692920ae1d3f11069205f.jpg'),
(61071, 4134, 'Supermães S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wa8Bd84F2LaHRXv84hwG0COppDe.jpg'),
(61072, 4134, 'Supermães S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5DBag5MVC7VRIB1KbfWDt84Fakd.jpg'),
(61073, 4134, 'Supermães S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3cP0A6jHx5jf0XvsfoAIuDsIaX.jpg'),
(61074, 4134, 'Supermães S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i5rWOq0sZNBsYSo5I9W7GNPZn7L.jpg'),
(61075, 4134, 'Supermães S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zHuZaBE74WaQqKp5y83E83mrREk.jpg'),
(61076, 4134, 'Supermães S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ft3kfHIcuh9Ojkzs5oc1Tf3TBqw.jpg'),
(61077, 4134, 'Supermães S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2MrI1ZxsF85tjAbg5qYQA8Ew4pi.jpg'),
(61078, 4134, 'Supermães S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pxAiBJeIKFWuodnPvNKA0Os3hQy.jpg'),
(61079, 4134, 'Supermães S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2DgGdZr4jfHdRzhZbE2CIJg2CHV.jpg'),
(61080, 4134, 'Supermães S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFKmpjM6OftYSMAe3qL8SZSQjI7.jpg'),
(61081, 4134, 'Supermães S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/210884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/T5AxDcAnYLIeCB1W6o5NTqkjr5.jpg'),
(61082, 4134, 'Supermães S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/210885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pnlIB8VOepfqFG8tHLXzfhBEqvZ.jpg'),
(61083, 4134, 'Supermães S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/210886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hOjITGT8X6pGxYimdCg8EHd5nNQ.jpg'),
(61084, 4135, 'Young Royals S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198838.mp4', 'http://timg.bdta.pro/images/2b0f1c2e97b837e89ee96c9207e6dc6b.jpg'),
(61085, 4135, 'Young Royals S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198839.mp4', 'http://timg.bdta.pro/images/4bbf52802dceaa882141244ef112a79f.jpg'),
(61086, 4135, 'Young Royals S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198840.mp4', 'http://timg.bdta.pro/images/3dd5491befd40d8ad2ac28362ae2a583.jpg'),
(61087, 4135, 'Young Royals S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198841.mp4', 'http://timg.bdta.pro/images/7ff0ddcbca3ed522e2f0383de69c31b0.jpg'),
(61088, 4135, 'Young Royals S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198842.mp4', 'http://timg.bdta.pro/images/8156acea61021755235b9817f109eb12.jpg'),
(61089, 4135, 'Young Royals S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198843.mp4', 'http://timg.bdta.pro/images/121761d0b6a1c132214bdd5d613743e8.jpg'),
(61090, 4136, 'Young Royals S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oKC5RNbyjDc7Vy5G4M4bQLqzla9.jpg'),
(61091, 4136, 'Young Royals S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kFfZzXrd7OkAhu9Rnyqe2RWAA9Y.jpg'),
(61092, 4136, 'Young Royals S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6HqA2e2IpIh7LBgfIsH0W1KkIze.jpg'),
(61093, 4136, 'Young Royals S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vd5NXCewP8e0vH8ER9VfCsnF54h.jpg'),
(61094, 4136, 'Young Royals S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/owkOCFFP1wWMDrD5noSFpHIgiO7.jpg'),
(61095, 4136, 'Young Royals S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vGJKCBxpBvHv0skVN35350ZlSX0.jpg'),
(61096, 4137, 'Young Royals S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300916.mp4', 'http://gstaticontent.com/images/214dde5e7acc32e0d8396315a7d74baa.jpg'),
(61097, 4137, 'Young Royals S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/300917.mp4', 'http://gstaticontent.com/images/214dde5e7acc32e0d8396315a7d74baa.jpg'),
(61098, 4137, 'Young Royals S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/300918.mp4', 'http://gstaticontent.com/images/214dde5e7acc32e0d8396315a7d74baa.jpg'),
(61099, 4137, 'Young Royals S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/300919.mp4', 'http://gstaticontent.com/images/214dde5e7acc32e0d8396315a7d74baa.jpg'),
(61100, 4137, 'Young Royals S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/300920.mp4', 'http://gstaticontent.com/images/214dde5e7acc32e0d8396315a7d74baa.jpg'),
(61101, 4137, 'Young Royals S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/303704.mp4', 'http://gstaticontent.com/images/214dde5e7acc32e0d8396315a7d74baa.jpg'),
(61102, 4138, 'Catherine the Great S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152446.mp4', 'http://timg.bdta.pro/images/8e320461ae34c68f6b21f86e6ddf0891.jpg'),
(61103, 4138, 'Catherine the Great S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152447.mp4', 'http://timg.bdta.pro/images/5490cf4c4fc25717b3ec4067b4dc7788.jpg'),
(61104, 4138, 'Catherine the Great S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152448.mp4', 'http://timg.bdta.pro/images/9729a50f9c20ccb9f45122cd172acb89.jpg'),
(61105, 4138, 'Catherine the Great S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152449.mp4', 'http://timg.bdta.pro/images/0fc1a1abb1a615296129690b4885c6be.jpg'),
(61106, 4139, 'iCarly [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157161.mp4', 'http://gstaticontent.com/images/2004099e73fdea89e53b2b897e75c29d.jpg'),
(61107, 4139, 'iCarly [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157162.mp4', 'http://timg.bdta.pro/images/7ef3e53ff4aa6448625bbe7d8c871468.jpg'),
(61108, 4139, 'iCarly [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157163.mp4', 'http://timg.bdta.pro/images/42181001b0bcebda94e2c7c35adf7bc3.jpg'),
(61109, 4139, 'iCarly [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157164.mp4', 'http://timg.bdta.pro/images/6d7683f7a787c592593de900788b16b0.jpg'),
(61110, 4139, 'iCarly [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/157165.mp4', 'http://timg.bdta.pro/images/44c53a7fd6c7ecc9a9a62b7d1e4be342.jpg'),
(61111, 4139, 'iCarly [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/157166.mp4', 'http://timg.bdta.pro/images/549a259b4fd4e663861d0ae3ebd67af0.jpg'),
(61112, 4139, 'iCarly [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/157167.mp4', 'http://timg.bdta.pro/images/26a90d873eebd65efa1bcc80fc44808c.jpg'),
(61113, 4139, 'iCarly [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/157168.mp4', 'http://timg.bdta.pro/images/275147ec4d78a0aa1ed055dbd80364bd.jpg'),
(61114, 4139, 'iCarly [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/157169.mp4', 'http://timg.bdta.pro/images/ddffef1f46f7cee4b5ea0916facd7bdf.jpg'),
(61115, 4139, 'iCarly [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/157170.mp4', 'http://timg.bdta.pro/images/0dd4c6f2aa8c9d012c33afec865843fe.jpg'),
(61116, 4139, 'iCarly [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/157171.mp4', 'http://timg.bdta.pro/images/c75308063b8ffa9f29bc481816414f5f.jpg'),
(61117, 4139, 'iCarly [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/157172.mp4', 'http://timg.bdta.pro/images/5ce961b96962be23a8ba7f8b9a02cce0.jpg'),
(61118, 4139, 'iCarly [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/157173.mp4', 'http://timg.bdta.pro/images/00e83001b0adc0ed8eb3b29461263bd0.jpg'),
(61119, 4139, 'iCarly [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/157174.mp4', 'http://gstaticontent.com/images/2004099e73fdea89e53b2b897e75c29d.jpg'),
(61120, 1187, 'iCarly S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228787.mp4', 'http://gstaticontent.com/images/2004099e73fdea89e53b2b897e75c29d.jpg'),
(61121, 1187, 'iCarly S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xOyUwDk8MNn8Bzz5M5k7nkkAMjE.jpg'),
(61122, 1187, 'iCarly S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c1qtADwMK0QylfCQLQhRy5fwo2a.jpg'),
(61123, 1187, 'iCarly S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yl0IoW0CCWQHCKXqaBVzZAEBohE.jpg'),
(61124, 1187, 'iCarly S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j70iw551N6kqZB0fIf7IDqR6Qc7.jpg'),
(61125, 1187, 'iCarly S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a2EHnPTuImFSJx1gfsyyUGFVdfr.jpg'),
(61126, 1187, 'iCarly S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fJsncGdNDi9FDBD4SXvkbZaSzIV.jpg'),
(61127, 1187, 'iCarly S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dTcFDLFv84KdQue1Yg3FOutEluX.jpg'),
(61128, 1187, 'iCarly S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4axJppLhuL65EdNeuea8RHJOJcx.jpg'),
(61129, 1187, 'iCarly S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1dZFbOzu6wIZVjtjSGUBE8SU7Eu.jpg'),
(61130, 1187, 'iCarly S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7rS6QXnCeh1iS9TpOaLU12ZgpkD.jpg'),
(61131, 1187, 'iCarly S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6dptU9jynsE1S01qQyGoAQF2EjD.jpg'),
(61132, 1187, 'iCarly S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6HsqOA2gpROCDmmReQM8HqCG6GI.jpg'),
(61133, 1187, 'iCarly S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x6X7UUMOioQKnX7FA9l9xTGjfoP.jpg'),
(61134, 1188, 'iCarly S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228801.mp4', 'http://timg.bdta.pro/images/72037e7220c892cbb5dbe3e6e2cbcf0f.jpg'),
(61135, 1188, 'iCarly S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228802.mp4', 'http://timg.bdta.pro/images/5cf895d75ad6322c764dcbfb8139ebbf.jpg'),
(61136, 1188, 'iCarly S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228803.mp4', 'http://timg.bdta.pro/images/7bd3c0df4075692166200ad74538bf1e.jpg'),
(61137, 1188, 'iCarly S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228804.mp4', 'http://timg.bdta.pro/images/5a74e896e5f9fbcebc54158ae383a39e.jpg'),
(61138, 1188, 'iCarly S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228805.mp4', 'http://timg.bdta.pro/images/b7259e89a17ec7d0048d771486f5243e.jpg'),
(61139, 1188, 'iCarly S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228806.mp4', 'http://timg.bdta.pro/images/ca1279fb5127790ccf260e9123e1c77a.jpg'),
(61140, 1188, 'iCarly S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228807.mp4', 'http://timg.bdta.pro/images/365650ae465183aea41734fe0fca8074.jpg'),
(61141, 1188, 'iCarly S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228808.mp4', 'http://timg.bdta.pro/images/595b998fc3eee3b18fcd3f28d4399153.jpg'),
(61142, 1188, 'iCarly S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228809.mp4', 'http://timg.bdta.pro/images/e20da36a2faaee6eab664ef88e53f8b3.jpg'),
(61143, 1188, 'iCarly S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228810.mp4', 'http://timg.bdta.pro/images/860d359caa3d0b554cad3e0777584098.jpg'),
(61144, 1189, 'iCarly S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wkYrzrYasAOIdmeHD197PxgzCHa.jpg'),
(61145, 1189, 'iCarly S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p0u2XKuMvkNjjWOlpxSSaTxnax9.jpg'),
(61146, 1189, 'iCarly S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228813.mp4', 'http://image.tmdb.org/t/p/w1280/lD9cuH8Nmy9cLiQko8KWjcGsKhe.jpg'),
(61147, 1189, 'iCarly S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228814.mp4', 'http://image.tmdb.org/t/p/w1280/atn5QrOfg5l1Xy8EdiQEseySZn0.jpg'),
(61148, 1189, 'iCarly S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228815.mp4', 'http://image.tmdb.org/t/p/w1280/iGTUFBOjlHrQEBiZVp36wO466FZ.jpg'),
(61149, 1189, 'iCarly S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228816.mp4', 'http://image.tmdb.org/t/p/w1280/vDqTABkcQMZNz8QqsMXuE3tgJ6E.jpg'),
(61150, 1189, 'iCarly S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228817.mp4', 'http://image.tmdb.org/t/p/w1280/5lj18VmvfEU8BdDSrUBqbiaK5Hv.jpg'),
(61151, 1189, 'iCarly S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228818.mp4', 'http://image.tmdb.org/t/p/w1280/m6h0WMYzUOia3XXCmZvYxuo1Qur.jpg'),
(61152, 1189, 'iCarly S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228819.mp4', 'http://image.tmdb.org/t/p/w1280/bW6p61aYaVxg2kyUDbCA3uW0SfG.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(61153, 1189, 'iCarly S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228820.mp4', 'http://image.tmdb.org/t/p/w1280/tEo0f94inliUM3TSav6yjwzWdwR.jpg'),
(61154, 4140, 'Casamento às Cegas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241446.mp4', 'http://timg.bdta.pro/images/f69f3322e310d02e0cbbd2aa9d8608fc.jpg'),
(61155, 4140, 'Casamento às Cegas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241447.mp4', 'http://timg.bdta.pro/images/42edcd3282300c9190f615e908dda3e6.jpg'),
(61156, 4140, 'Casamento às Cegas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241448.mp4', 'http://timg.bdta.pro/images/b2f89c18014952dcc0a2133b161a0fe4.jpg'),
(61157, 4140, 'Casamento às Cegas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241449.mp4', 'http://timg.bdta.pro/images/4c5015e0a320eb266c36717ed47ab955.jpg'),
(61158, 4140, 'Casamento às Cegas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241450.mp4', 'http://timg.bdta.pro/images/f274dbd6252622d1ab46e6798844f98c.jpg'),
(61159, 4140, 'Casamento às Cegas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241451.mp4', 'http://timg.bdta.pro/images/2edbf8fdd528e92c15839d0f35e7e0b4.jpg'),
(61160, 4140, 'Casamento às Cegas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241452.mp4', 'http://timg.bdta.pro/images/2554e960b48c5328486f5412c2e01c81.jpg'),
(61161, 4140, 'Casamento às Cegas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241453.mp4', 'http://timg.bdta.pro/images/656c14cc0c7553e6a84b107a12cf0e0e.jpg'),
(61162, 4140, 'Casamento às Cegas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241454.mp4', 'http://timg.bdta.pro/images/18e5a21fc0fdf3776d3445740f619b66.jpg'),
(61163, 4140, 'Casamento às Cegas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241455.mp4', 'http://timg.bdta.pro/images/cb19b7629570efdedccbd11c1c985638.jpg'),
(61164, 4140, 'Casamento às Cegas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241456.mp4', 'http://timg.bdta.pro/images/acb1514515e4287826e8b8a6ab44c7d9.jpg'),
(61165, 4141, 'Casamento às Cegas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241457.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61166, 4141, 'Casamento às Cegas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241458.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61167, 4141, 'Casamento às Cegas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241459.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61168, 4141, 'Casamento às Cegas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241460.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61169, 4141, 'Casamento às Cegas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241461.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61170, 4141, 'Casamento às Cegas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241462.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61171, 4141, 'Casamento às Cegas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241463.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61172, 4141, 'Casamento às Cegas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241464.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61173, 4141, 'Casamento às Cegas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241465.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61174, 4141, 'Casamento às Cegas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241466.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61175, 4141, 'Casamento às Cegas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241467.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61176, 4142, 'Casamento às Cegas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1J2Mu7fv3RSxO8i5D62edT1GGDV.jpg'),
(61177, 4142, 'Casamento às Cegas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zsILd6vArlCsJUDZEdbbvzwzrCS.jpg'),
(61178, 4142, 'Casamento às Cegas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9aon2kG5RinVmT2kyhCgPfmZ93O.jpg'),
(61179, 4142, 'Casamento às Cegas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1LWihmgPm56ZbKrbh2cQ5QZttKX.jpg'),
(61180, 4142, 'Casamento às Cegas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dSWL7HLGRHMamoVUClWdkIDiluQ.jpg'),
(61181, 4142, 'Casamento às Cegas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cfXaYEPdhQPJzrvIRRgOTUTeC53.jpg'),
(61182, 4142, 'Casamento às Cegas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1bhxRl8cmRk4eMyDz1NbP84LT3.jpg'),
(61183, 4142, 'Casamento às Cegas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kGzoZ9myXeDzAzjTcdLbAir8u6A.jpg'),
(61184, 4142, 'Casamento às Cegas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMCB4F4AKmfjzijRvUzb6ntZuHS.jpg'),
(61185, 4142, 'Casamento às Cegas S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mukMmIRVsFus0GRuLIs4xQv2LTZ.jpg'),
(61186, 4142, 'Casamento às Cegas S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/549hBUVfIskmMNTbXsQ5K5cOpd9.jpg'),
(61187, 4142, 'Casamento às Cegas S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h0bx4Pv9hEAT3hw8UrIBtQWIOJG.jpg'),
(61188, 4142, 'Casamento às Cegas S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241480.mp4', 'http://image.tmdb.org/t/p/w1280/kyQ8msh5yreZJXSsS2vBXR4gGKm.jpg'),
(61189, 4142, 'Casamento às Cegas S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241481.mp4', 'http://image.tmdb.org/t/p/w1280/m1Rf8Q2CDvWihbH2QTXwrBlxSay.jpg'),
(61190, 4142, 'Casamento às Cegas S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241482.mp4', 'http://image.tmdb.org/t/p/w1280/ktd2wPCGMKndSPe25SpwDm34lDZ.jpg'),
(61191, 4143, 'Casamento às Cegas S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c1xlyybtqLfuFqywLBOVNQZGeQg.jpg'),
(61192, 4143, 'Casamento às Cegas S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oGbLXtXx8lscJXQ9E62GCoAmPs6.jpg'),
(61193, 4143, 'Casamento às Cegas S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zH98STKqqlswmddy1uTlWnRFcY3.jpg'),
(61194, 4143, 'Casamento às Cegas S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zfh8BeYyy62INOnTb2RzylgIrjp.jpg'),
(61195, 4143, 'Casamento às Cegas S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ks4WCWDG3OIrSh4SF85vBqqr2D.jpg'),
(61196, 4143, 'Casamento às Cegas S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sKd7U8dCUCJ42RMgI5Xidrcg3tz.jpg'),
(61197, 4143, 'Casamento às Cegas S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mpADna5epvqVAUisDKG0rcx1e8M.jpg'),
(61198, 4143, 'Casamento às Cegas S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mk29WS4mUmJwDuiHcy5QwWhANac.jpg'),
(61199, 4143, 'Casamento às Cegas S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gVcTZKIGtWP5AOvX4Cqj2Rkn49b.jpg'),
(61200, 4143, 'Casamento às Cegas S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fhyIT1QlDAn2wnH8odOe65nNOSI.jpg'),
(61201, 4143, 'Casamento às Cegas S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u9NRCTLKMkdCRXdfrD9nRP6kgvj.jpg'),
(61202, 4143, 'Casamento às Cegas S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wCIjPBtjr9fNPQci2JDsMWOzzJx.jpg'),
(61203, 4144, 'Casamento às Cegas S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241495.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61204, 4144, 'Casamento às Cegas S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241496.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61205, 4144, 'Casamento às Cegas S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241497.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61206, 4144, 'Casamento às Cegas S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241498.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61207, 4144, 'Casamento às Cegas S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241499.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61208, 4144, 'Casamento às Cegas S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241500.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61209, 4144, 'Casamento às Cegas S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241501.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61210, 4144, 'Casamento às Cegas S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241502.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61211, 4144, 'Casamento às Cegas S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241503.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61212, 4144, 'Casamento às Cegas S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241504.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61213, 4144, 'Casamento às Cegas S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241505.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61214, 4145, 'Casamento às Cegas S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/312604.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61215, 4145, 'Casamento às Cegas S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/312605.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61216, 4145, 'Casamento às Cegas S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/312606.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61217, 4145, 'Casamento às Cegas S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/312607.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61218, 4145, 'Casamento às Cegas S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/312608.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61219, 4145, 'Casamento às Cegas S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/312609.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61220, 4145, 'Casamento às Cegas S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/312610.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61221, 4145, 'Casamento às Cegas S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/312611.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61222, 4145, 'Casamento às Cegas S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/312612.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61223, 4145, 'Casamento às Cegas S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/312613.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61224, 4145, 'Casamento às Cegas S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/312614.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61225, 4145, 'Casamento às Cegas S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/312615.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61226, 4145, 'Casamento às Cegas S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/312616.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61227, 4146, 'Casamento às Cegas S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/470703.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61228, 4146, 'Casamento às Cegas S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/470704.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61229, 4146, 'Casamento às Cegas S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/470705.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61230, 4146, 'Casamento às Cegas S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/470706.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61231, 4146, 'Casamento às Cegas S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/470707.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61232, 4146, 'Casamento às Cegas S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/470708.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61233, 4146, 'Casamento às Cegas S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/478450.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61234, 4146, 'Casamento às Cegas S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/478451.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61235, 4146, 'Casamento às Cegas S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/478452.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61236, 4146, 'Casamento às Cegas S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/483298.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61237, 4146, 'Casamento às Cegas S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/483299.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61238, 4146, 'Casamento às Cegas S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/491429.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61239, 4146, 'Casamento às Cegas S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/502706.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61240, 4147, 'Casamento às Cegas S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/698414.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61241, 4147, 'Casamento às Cegas S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/698415.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61242, 4147, 'Casamento às Cegas S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/698416.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61243, 4147, 'Casamento às Cegas S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/698417.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61244, 4147, 'Casamento às Cegas S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/698418.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61245, 4147, 'Casamento às Cegas S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/698419.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61246, 4147, 'Casamento às Cegas S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/707372.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61247, 4147, 'Casamento às Cegas S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/707373.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61248, 4147, 'Casamento às Cegas S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/707374.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61249, 4147, 'Casamento às Cegas S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/711432.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61250, 4147, 'Casamento às Cegas S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/718901.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61251, 4147, 'Casamento às Cegas S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/735566.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61252, 4147, 'Casamento às Cegas S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/768474.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61253, 4147, 'Casamento às Cegas S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/776980.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61254, 4148, 'Casamento às Cegas S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/887619.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61255, 4148, 'Casamento às Cegas S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/887620.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61256, 4148, 'Casamento às Cegas S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/887621.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61257, 4148, 'Casamento às Cegas S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/887622.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61258, 4148, 'Casamento às Cegas S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/887623.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61259, 4148, 'Casamento às Cegas S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/887624.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61260, 4148, 'Casamento às Cegas S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/888231.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61261, 4148, 'Casamento às Cegas S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/888232.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61262, 4148, 'Casamento às Cegas S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/888233.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61263, 4148, 'Casamento às Cegas S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/889642.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61264, 4148, 'Casamento às Cegas S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/889643.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61265, 4148, 'Casamento às Cegas S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/890130.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61266, 4148, 'Casamento às Cegas S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/893479.mp4', 'http://gstaticontent.com/images/bf71bd7656da45b8fde7254b3335e4fb.jpg'),
(61267, 4149, 'Chaves S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152225.mp4', 'http://timg.bdta.pro/images/37df6e8918c3a9d6eac1ce17f42b1b03.jpg'),
(61268, 4149, 'Chaves S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152226.mp4', 'http://timg.bdta.pro/images/fa23b12829abe328f4a7788524309a9b.jpg'),
(61269, 4149, 'Chaves S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152227.mp4', 'http://timg.bdta.pro/images/34e5d8c9e11d31d2c74b07fbdb88bce1.jpg'),
(61270, 4149, 'Chaves S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152228.mp4', 'http://timg.bdta.pro/images/ec04060013c51b7f961520abcc5e80d9.jpg'),
(61271, 4149, 'Chaves S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152229.mp4', 'http://timg.bdta.pro/images/c4da7c9fb754a95028cee827e785a769.jpg'),
(61272, 4149, 'Chaves S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152230.mp4', 'http://timg.bdta.pro/images/5aa3ab9257569e110267cf5411ba1733.jpg'),
(61273, 4149, 'Chaves S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152231.mp4', 'http://timg.bdta.pro/images/c203e013f8140e9ec4d22d3c8b97af8d.jpg'),
(61274, 4149, 'Chaves S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152232.mp4', 'http://timg.bdta.pro/images/9c46386608c6c1af5587dd616ef1e359.jpg'),
(61275, 4149, 'Chaves S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152233.mp4', 'http://timg.bdta.pro/images/76e5085291adf719c3c166bd4d0c8724.jpg'),
(61276, 4149, 'Chaves S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152234.mp4', 'http://timg.bdta.pro/images/093dea52beccd143f98e2f4997e75fdc.jpg'),
(61277, 4149, 'Chaves S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152235.mp4', 'http://timg.bdta.pro/images/7538d2ecf5b44e42d622fd00374f064d.jpg'),
(61278, 4149, 'Chaves S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152236.mp4', 'http://timg.bdta.pro/images/6733f8bffb6426da099aad70d3bbac63.jpg'),
(61279, 4149, 'Chaves S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152237.mp4', 'http://timg.bdta.pro/images/95d63a3674af9838480d65702743e9e4.jpg'),
(61280, 4149, 'Chaves S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152238.mp4', 'http://timg.bdta.pro/images/a8142dbeace45fbd7230fdb73b573a0e.jpg'),
(61281, 4149, 'Chaves S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152239.mp4', 'http://timg.bdta.pro/images/7498fd53e11e94729507ca6e28cabdef.jpg'),
(61282, 4149, 'Chaves S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152240.mp4', 'http://timg.bdta.pro/images/c8b513b1451749006cbeab2c350f9e83.jpg'),
(61283, 4149, 'Chaves S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152241.mp4', 'http://timg.bdta.pro/images/c1084bc3fa8eb57360d56d7245d8b84d.jpg'),
(61284, 4149, 'Chaves S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152242.mp4', 'http://timg.bdta.pro/images/82869f2eaaa2214968aaa77d6aaa49f4.jpg'),
(61285, 4149, 'Chaves S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152243.mp4', 'http://timg.bdta.pro/images/d75cb88601084d02c456e06313a86ba5.jpg'),
(61286, 4149, 'Chaves S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/152244.mp4', 'http://timg.bdta.pro/images/9428c17b06f13f67b5ffdfdd01350c8a.jpg'),
(61287, 4149, 'Chaves S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/152245.mp4', 'http://timg.bdta.pro/images/4597d93a3d226efd856cdee1f6f733fa.jpg'),
(61288, 4149, 'Chaves S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/152246.mp4', 'http://timg.bdta.pro/images/961da6488749baf010ab282b798cb17a.jpg'),
(61289, 4150, 'Chaves S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152247.mp4', 'http://timg.bdta.pro/images/27dc3d5253ac3bcaf2a50f6367269913.jpg'),
(61290, 4150, 'Chaves S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152248.mp4', 'http://timg.bdta.pro/images/caacc8c1d621ed77791134b228611955.jpg'),
(61291, 4150, 'Chaves S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152249.mp4', 'http://timg.bdta.pro/images/95bd30451c465b08b81971a476bf6ff0.jpg'),
(61292, 4150, 'Chaves S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152250.mp4', 'http://timg.bdta.pro/images/1dc32a7d8c867ed4bb92751ca93216b6.jpg'),
(61293, 4150, 'Chaves S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152251.mp4', 'http://timg.bdta.pro/images/f931d283ca13819f4188863400abdd33.jpg'),
(61294, 4150, 'Chaves S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152252.mp4', 'http://timg.bdta.pro/images/bd8e57c6e4f173a902060f1a7ec5eaee.jpg'),
(61295, 4150, 'Chaves S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152253.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61296, 4150, 'Chaves S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152254.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61297, 4150, 'Chaves S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152255.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61298, 4150, 'Chaves S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152256.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61299, 4150, 'Chaves S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152257.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61300, 4150, 'Chaves S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152258.mp4', 'http://timg.bdta.pro/images/292bb4079f29f63791bea7142fe331eb.jpg'),
(61301, 4150, 'Chaves S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152259.mp4', 'http://timg.bdta.pro/images/77d9c555f156080c467975f3682a2c2a.jpg'),
(61302, 4150, 'Chaves S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152260.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61303, 4150, 'Chaves S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152261.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61304, 4150, 'Chaves S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152262.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61305, 4150, 'Chaves S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152263.mp4', 'http://timg.bdta.pro/images/133b29eb5234b16c8a6c41b8ea5dbe86.jpg'),
(61306, 4150, 'Chaves S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152264.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61307, 4150, 'Chaves S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152265.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61308, 4150, 'Chaves S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/152266.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61309, 4150, 'Chaves S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/152267.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61310, 4150, 'Chaves S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/152268.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61311, 4150, 'Chaves S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/152269.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61312, 4150, 'Chaves S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/152270.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61313, 4150, 'Chaves S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/152271.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61314, 4150, 'Chaves S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/152272.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61315, 4150, 'Chaves S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/152273.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61316, 4150, 'Chaves S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/152274.mp4', 'http://timg.bdta.pro/images/f69a3ef983e430cffc9160f8caf16960.jpg'),
(61317, 4150, 'Chaves S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/152275.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61318, 4150, 'Chaves S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/152276.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61319, 4150, 'Chaves S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/152277.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61320, 4151, 'Chaves S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152278.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61321, 4151, 'Chaves S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152279.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61322, 4151, 'Chaves S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152280.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61323, 4151, 'Chaves S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152281.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61324, 4151, 'Chaves S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152282.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61325, 4151, 'Chaves S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152283.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61326, 4151, 'Chaves S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152284.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61327, 4151, 'Chaves S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152285.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61328, 4151, 'Chaves S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152286.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61329, 4151, 'Chaves S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152287.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61330, 4151, 'Chaves S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152288.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61331, 4151, 'Chaves S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152289.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61332, 4151, 'Chaves S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152290.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61333, 4151, 'Chaves S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152291.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61334, 4151, 'Chaves S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152292.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61335, 4151, 'Chaves S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152293.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61336, 4151, 'Chaves S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152294.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61337, 4151, 'Chaves S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152295.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61338, 4151, 'Chaves S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152296.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61339, 4151, 'Chaves S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/152297.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61340, 4151, 'Chaves S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/152298.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61341, 4151, 'Chaves S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/152299.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61342, 4151, 'Chaves S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/152300.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61343, 4151, 'Chaves S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/152301.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61344, 4151, 'Chaves S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/152302.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61345, 4151, 'Chaves S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/152303.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61346, 4151, 'Chaves S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/152304.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61347, 4151, 'Chaves S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/152305.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61348, 4151, 'Chaves S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/152306.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61349, 4151, 'Chaves S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/152307.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61350, 4151, 'Chaves S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/152308.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61351, 4152, 'Chaves S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152309.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61352, 4152, 'Chaves S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152310.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61353, 4152, 'Chaves S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152311.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61354, 4152, 'Chaves S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152312.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61355, 4152, 'Chaves S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152313.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61356, 4152, 'Chaves S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152314.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61357, 4152, 'Chaves S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152315.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61358, 4152, 'Chaves S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152316.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61359, 4152, 'Chaves S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152317.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61360, 4152, 'Chaves S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152318.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61361, 4152, 'Chaves S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152319.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61362, 4152, 'Chaves S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152320.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61363, 4152, 'Chaves S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152321.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61364, 4152, 'Chaves S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152322.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61365, 4152, 'Chaves S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152323.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61366, 4152, 'Chaves S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152324.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61367, 4152, 'Chaves S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152325.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61368, 4152, 'Chaves S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152326.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61369, 4152, 'Chaves S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152327.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61370, 4152, 'Chaves S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/152328.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61371, 4152, 'Chaves S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/152329.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61372, 4152, 'Chaves S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/152330.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61373, 4152, 'Chaves S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/152331.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61374, 4152, 'Chaves S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/152332.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61375, 4152, 'Chaves S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/152333.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61376, 4152, 'Chaves S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/152334.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61377, 4152, 'Chaves S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/152335.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61378, 4152, 'Chaves S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/152336.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61379, 4152, 'Chaves S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/152337.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61380, 4152, 'Chaves S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/152338.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61381, 4153, 'Chaves S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152339.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61382, 4153, 'Chaves S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152340.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61383, 4153, 'Chaves S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152341.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61384, 4153, 'Chaves S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152342.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61385, 4153, 'Chaves S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152343.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61386, 4153, 'Chaves S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152344.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61387, 4153, 'Chaves S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152345.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61388, 4153, 'Chaves S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152346.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61389, 4153, 'Chaves S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152347.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61390, 4153, 'Chaves S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152348.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61391, 4153, 'Chaves S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152349.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61392, 4153, 'Chaves S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152350.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61393, 4153, 'Chaves S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152351.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61394, 4153, 'Chaves S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152352.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61395, 4153, 'Chaves S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152353.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61396, 4153, 'Chaves S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152354.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61397, 4153, 'Chaves S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152355.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61398, 4153, 'Chaves S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152356.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61399, 4153, 'Chaves S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152357.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61400, 4153, 'Chaves S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/152358.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61401, 4153, 'Chaves S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/152359.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61402, 4153, 'Chaves S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/152360.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61403, 4153, 'Chaves S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/152361.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61404, 4153, 'Chaves S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/152362.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61405, 4153, 'Chaves S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/152363.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61406, 4153, 'Chaves S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/152364.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61407, 4153, 'Chaves S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/152365.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61408, 4153, 'Chaves S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/152366.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61409, 4153, 'Chaves S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/152367.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61410, 4153, 'Chaves S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/152368.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61411, 4154, 'Chaves S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152369.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61412, 4154, 'Chaves S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152370.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61413, 4154, 'Chaves S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152371.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61414, 4154, 'Chaves S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152372.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61415, 4154, 'Chaves S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152373.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61416, 4154, 'Chaves S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152374.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61417, 4154, 'Chaves S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152375.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61418, 4154, 'Chaves S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152376.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61419, 4154, 'Chaves S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152377.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61420, 4154, 'Chaves S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152378.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61421, 4154, 'Chaves S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152379.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61422, 4154, 'Chaves S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152380.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61423, 4154, 'Chaves S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152381.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61424, 4154, 'Chaves S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152382.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61425, 4154, 'Chaves S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152383.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61426, 4154, 'Chaves S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152384.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61427, 4154, 'Chaves S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152385.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61428, 4154, 'Chaves S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152386.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61429, 4154, 'Chaves S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152387.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61430, 4154, 'Chaves S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/152388.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61431, 4154, 'Chaves S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/152389.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61432, 4154, 'Chaves S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/152390.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61433, 4154, 'Chaves S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/152391.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61434, 4154, 'Chaves S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/152392.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61435, 4154, 'Chaves S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/152393.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61436, 4154, 'Chaves S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/152394.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61437, 4154, 'Chaves S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/152395.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61438, 4154, 'Chaves S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/152396.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61439, 4154, 'Chaves S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/152397.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61440, 4154, 'Chaves S06 E30', 'http://sinalprivado.info:80/series/1533784/1533784/152398.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(61441, 4154, 'Chaves S06 E31', 'http://sinalprivado.info:80/series/1533784/1533784/152399.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61442, 4154, 'Chaves S06 E32', 'http://sinalprivado.info:80/series/1533784/1533784/152400.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61443, 4154, 'Chaves S06 E33', 'http://sinalprivado.info:80/series/1533784/1533784/152401.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61444, 4154, 'Chaves S06 E34', 'http://sinalprivado.info:80/series/1533784/1533784/152402.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61445, 4155, 'Chaves S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152403.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61446, 4155, 'Chaves S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152404.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61447, 4155, 'Chaves S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152405.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61448, 4155, 'Chaves S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152406.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61449, 4155, 'Chaves S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152407.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61450, 4155, 'Chaves S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152408.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61451, 4155, 'Chaves S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/152409.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61452, 4155, 'Chaves S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/152410.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61453, 4155, 'Chaves S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/152411.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61454, 4155, 'Chaves S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/152412.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61455, 4155, 'Chaves S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/152413.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61456, 4155, 'Chaves S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/152414.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61457, 4155, 'Chaves S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/152415.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61458, 4155, 'Chaves S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/152416.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61459, 4155, 'Chaves S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/152417.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61460, 4155, 'Chaves S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/152418.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61461, 4155, 'Chaves S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/152419.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61462, 4155, 'Chaves S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/152420.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61463, 4155, 'Chaves S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/152421.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61464, 4155, 'Chaves S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/152422.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61465, 4155, 'Chaves S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/152423.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61466, 4155, 'Chaves S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/152424.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61467, 4155, 'Chaves S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/152425.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61468, 4155, 'Chaves S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/152426.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61469, 4155, 'Chaves S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/152427.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61470, 4155, 'Chaves S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/152428.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61471, 4155, 'Chaves S07 E27', 'http://sinalprivado.info:80/series/1533784/1533784/152429.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61472, 4155, 'Chaves S07 E28', 'http://sinalprivado.info:80/series/1533784/1533784/152430.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61473, 4155, 'Chaves S07 E29', 'http://sinalprivado.info:80/series/1533784/1533784/152431.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61474, 4155, 'Chaves S07 E30', 'http://sinalprivado.info:80/series/1533784/1533784/152432.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61475, 4155, 'Chaves S07 E31', 'http://sinalprivado.info:80/series/1533784/1533784/152433.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61476, 4155, 'Chaves S07 E32', 'http://sinalprivado.info:80/series/1533784/1533784/152434.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61477, 4155, 'Chaves S07 E33', 'http://sinalprivado.info:80/series/1533784/1533784/152435.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61478, 4155, 'Chaves S07 E34', 'http://sinalprivado.info:80/series/1533784/1533784/152436.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61479, 4155, 'Chaves S07 E35', 'http://sinalprivado.info:80/series/1533784/1533784/152437.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61480, 4155, 'Chaves S07 E36', 'http://sinalprivado.info:80/series/1533784/1533784/152438.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61481, 4155, 'Chaves S07 E37', 'http://sinalprivado.info:80/series/1533784/1533784/152439.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61482, 4155, 'Chaves S07 E38', 'http://sinalprivado.info:80/series/1533784/1533784/152440.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61483, 4155, 'Chaves S07 E39', 'http://sinalprivado.info:80/series/1533784/1533784/152441.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61484, 4155, 'Chaves S07 E40', 'http://sinalprivado.info:80/series/1533784/1533784/152442.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61485, 4155, 'Chaves S07 E41', 'http://sinalprivado.info:80/series/1533784/1533784/152443.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61486, 4155, 'Chaves S07 E42', 'http://sinalprivado.info:80/series/1533784/1533784/152444.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61487, 4155, 'Chaves S07 E43', 'http://sinalprivado.info:80/series/1533784/1533784/152445.mp4', 'http://gstaticontent.com/images/cfbdfe1ecbc84868bef019b1144975a2.jpg'),
(61488, 4156, 'Tattoo Fail S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152219.mp4', 'http://gstaticontent.com/images/e96e33c4dd0dcdbec8b7bb83a36a8ae4.jpg'),
(61489, 4156, 'Tattoo Fail S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152220.mp4', 'http://gstaticontent.com/images/e96e33c4dd0dcdbec8b7bb83a36a8ae4.jpg'),
(61490, 4156, 'Tattoo Fail S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152221.mp4', 'http://gstaticontent.com/images/e96e33c4dd0dcdbec8b7bb83a36a8ae4.jpg'),
(61491, 4156, 'Tattoo Fail S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152222.mp4', 'http://gstaticontent.com/images/e96e33c4dd0dcdbec8b7bb83a36a8ae4.jpg'),
(61492, 4156, 'Tattoo Fail S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152223.mp4', 'http://gstaticontent.com/images/e96e33c4dd0dcdbec8b7bb83a36a8ae4.jpg'),
(61493, 4156, 'Tattoo Fail S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152224.mp4', 'http://gstaticontent.com/images/e96e33c4dd0dcdbec8b7bb83a36a8ae4.jpg'),
(61494, 4157, 'Transformers: War for Cybertron: O Cerco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152213.mp4', 'http://timg.bdta.pro/images/2d4382186639d6631682d6df4457ef8f.jpg'),
(61495, 4157, 'Transformers: War for Cybertron: O Cerco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152214.mp4', 'http://timg.bdta.pro/images/195da237dcec82349e45c7c6a6c09802.jpg'),
(61496, 4157, 'Transformers: War for Cybertron: O Cerco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152215.mp4', 'http://timg.bdta.pro/images/046fdcc958fdae9b6e734b8cc501e4ae.jpg'),
(61497, 4157, 'Transformers: War for Cybertron: O Cerco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152216.mp4', 'http://timg.bdta.pro/images/cb6c728e0ebefc89fd5cbe028c9a522d.jpg'),
(61498, 4157, 'Transformers: War for Cybertron: O Cerco S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152217.mp4', 'http://timg.bdta.pro/images/85fcc133aa9f82a4decf0ee1698189f2.jpg'),
(61499, 4157, 'Transformers: War for Cybertron: O Cerco S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152218.mp4', 'http://timg.bdta.pro/images/543f006ff9623486a961972ca6dcb84a.jpg'),
(61500, 4158, 'Transformers: War for Cybertron: O Nascer da Terra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152207.mp4', 'http://timg.bdta.pro/images/752dd6503a51d2e9e259e6af0c7dc1d3.jpg'),
(61501, 4158, 'Transformers: War for Cybertron: O Nascer da Terra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152208.mp4', 'http://timg.bdta.pro/images/fff4d28ab935bb1256d865a0078651a7.jpg'),
(61502, 4158, 'Transformers: War for Cybertron: O Nascer da Terra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152209.mp4', 'http://timg.bdta.pro/images/ea2b899a1fccdbf718230de34758a41a.jpg'),
(61503, 4158, 'Transformers: War for Cybertron: O Nascer da Terra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152210.mp4', 'http://timg.bdta.pro/images/1b61ea2214cef67f8371b2705b4958c6.jpg'),
(61504, 4158, 'Transformers: War for Cybertron: O Nascer da Terra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152211.mp4', 'http://timg.bdta.pro/images/5c194a11112825d327febf7da15713b1.jpg'),
(61505, 4158, 'Transformers: War for Cybertron: O Nascer da Terra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152212.mp4', 'http://timg.bdta.pro/images/874ee796ee218e5c2a343755cb11e4cf.jpg'),
(61506, 4159, 'Transformers: War for Cybertron: O Reino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/152201.mp4', 'http://timg.bdta.pro/images/9480a7d515d8160f767ecb43383838c4.jpg'),
(61507, 4159, 'Transformers: War for Cybertron: O Reino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/152202.mp4', 'http://timg.bdta.pro/images/357305890738f985d2137e653ff6a07b.jpg'),
(61508, 4159, 'Transformers: War for Cybertron: O Reino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/152203.mp4', 'http://timg.bdta.pro/images/30e8f4c1284a0e690677fa02c28685ed.jpg'),
(61509, 4159, 'Transformers: War for Cybertron: O Reino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/152204.mp4', 'http://timg.bdta.pro/images/6c75d974745b7baf18126e59bb5ef544.jpg'),
(61510, 4159, 'Transformers: War for Cybertron: O Reino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/152205.mp4', 'http://timg.bdta.pro/images/b349db9c25ca6ee870be4f87880c01fd.jpg'),
(61511, 4159, 'Transformers: War for Cybertron: O Reino S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/152206.mp4', 'http://timg.bdta.pro/images/9cd8ed346d567d08d4c8e18fc0021a3b.jpg'),
(61512, 4160, 'South Park S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211475.mp4', 'http://timg.bdta.pro/images/1b30661412df1a448eccf80818b491eb.jpg'),
(61513, 4160, 'South Park S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211476.mp4', 'http://timg.bdta.pro/images/f8e5f8fba3a9b68a888a88ca74b2bb99.jpg'),
(61514, 4160, 'South Park S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211477.mp4', 'http://timg.bdta.pro/images/b1015db238adfdff15e0801f515c9051.jpg'),
(61515, 4160, 'South Park S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211478.mp4', 'http://timg.bdta.pro/images/c96738d7a536e5dfcaa400c563afae73.jpg'),
(61516, 4160, 'South Park S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211479.mp4', 'http://timg.bdta.pro/images/3f5fa6457ce77614372d906d104782fa.jpg'),
(61517, 4160, 'South Park S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211480.mp4', 'http://timg.bdta.pro/images/7500dd537099b7bc31182e4dc47854f9.jpg'),
(61518, 4160, 'South Park S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211481.mp4', 'http://timg.bdta.pro/images/0360fbccd14bf893c540706f666d955c.jpg'),
(61519, 4160, 'South Park S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211482.mp4', 'http://timg.bdta.pro/images/53f06c4c6dff8b55ac8ae35688051091.jpg'),
(61520, 4160, 'South Park S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211483.mp4', 'http://timg.bdta.pro/images/278bc4924f46e2e0005090381659fa71.jpg'),
(61521, 4160, 'South Park S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211484.mp4', 'http://timg.bdta.pro/images/fc31abc0d6e1f1dfdf5d08d890c9d1de.jpg'),
(61522, 4160, 'South Park S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211485.mp4', 'http://timg.bdta.pro/images/3e70372809019c71ba899c68b3e3a1b0.jpg'),
(61523, 4160, 'South Park S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211486.mp4', 'http://timg.bdta.pro/images/41cc47d0a3e8807afe15841d1f0e7afc.jpg'),
(61524, 4160, 'South Park S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211487.mp4', 'http://timg.bdta.pro/images/7a2cd8ddccf202836744df385ad960a6.jpg'),
(61525, 4161, 'South Park S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211488.mp4', 'http://timg.bdta.pro/images/16f67f40879b488b937b7077dd01c781.jpg'),
(61526, 4161, 'South Park S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211489.mp4', 'http://timg.bdta.pro/images/bd141c98cd1b54b8f55f35b13973de8b.jpg'),
(61527, 4161, 'South Park S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211490.mp4', 'http://timg.bdta.pro/images/3dd57d881fa0e00d2bc228b3a96ac549.jpg'),
(61528, 4161, 'South Park S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211491.mp4', 'http://timg.bdta.pro/images/09518418d9988c35b097ccac4b2f27c7.jpg'),
(61529, 4161, 'South Park S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211492.mp4', 'http://timg.bdta.pro/images/e4d38286fef01bb1f70767d9ab90e68e.jpg'),
(61530, 4161, 'South Park S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211493.mp4', 'http://timg.bdta.pro/images/82da32281504c10937fc8c114324318f.jpg'),
(61531, 4161, 'South Park S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211494.mp4', 'http://timg.bdta.pro/images/8bfae3274c212def32aa69f43e72af87.jpg'),
(61532, 4161, 'South Park S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211495.mp4', 'http://timg.bdta.pro/images/4946c28b1487cb82317fdf5b1041901a.jpg'),
(61533, 4161, 'South Park S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211496.mp4', 'http://timg.bdta.pro/images/06495c5ab128893a97af312fc1e313f6.jpg'),
(61534, 4161, 'South Park S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211497.mp4', 'http://timg.bdta.pro/images/7d254a56db7cf680a200f9e57d78f770.jpg'),
(61535, 4161, 'South Park S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211498.mp4', 'http://timg.bdta.pro/images/0956423956a4370207b955c23ceb5c3a.jpg'),
(61536, 4161, 'South Park S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211499.mp4', 'http://timg.bdta.pro/images/2dde6c8f88ea5fcf28d92e118fc6021a.jpg'),
(61537, 4161, 'South Park S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211500.mp4', 'http://timg.bdta.pro/images/0d3cd9239730d2450d31a4a491854d0c.jpg'),
(61538, 4161, 'South Park S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/211501.mp4', 'http://timg.bdta.pro/images/3fb9d406a17359d0d532f397e79ff4c1.jpg'),
(61539, 4161, 'South Park S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/211502.mp4', 'http://timg.bdta.pro/images/080567a23c5ec905380a62a32735e4d9.jpg'),
(61540, 4161, 'South Park S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/211503.mp4', 'http://timg.bdta.pro/images/b51a46274a4a26b351cf30b63b1fa81a.jpg'),
(61541, 4161, 'South Park S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/211504.mp4', 'http://timg.bdta.pro/images/f9ce1cdf109365b6449bff9bd4367f7e.jpg'),
(61542, 4161, 'South Park S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/211505.mp4', 'http://timg.bdta.pro/images/0e299c85966833f6db15dc6a55ed02da.jpg'),
(61543, 4162, 'South Park S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211506.mp4', 'http://timg.bdta.pro/images/1fc4e1613333bc488181dc532ecb6f02.jpg'),
(61544, 4162, 'South Park S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211507.mp4', 'http://timg.bdta.pro/images/3463fb473b5122dbc41c340dd7105124.jpg'),
(61545, 4162, 'South Park S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211508.mp4', 'http://timg.bdta.pro/images/6a1cbf5440392856cf488a5fc27e826e.jpg'),
(61546, 4162, 'South Park S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211509.mp4', 'http://timg.bdta.pro/images/5e2661865eeebd605ae27e7969a53a99.jpg'),
(61547, 4162, 'South Park S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211510.mp4', 'http://timg.bdta.pro/images/4be7255e8960d9071c4b993dedf57f17.jpg'),
(61548, 4162, 'South Park S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211511.mp4', 'http://timg.bdta.pro/images/c2f52b8d2611ec26e055004b2b70e81f.jpg'),
(61549, 4162, 'South Park S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211512.mp4', 'http://timg.bdta.pro/images/42fdcd4adc61334b6a6f156ce673cc81.jpg'),
(61550, 4162, 'South Park S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211513.mp4', 'http://timg.bdta.pro/images/0f3a7cf0dea03bfff5350abb65f012d5.jpg'),
(61551, 4162, 'South Park S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211514.mp4', 'http://timg.bdta.pro/images/ac1aa22f8938970f6ac5f4d9f5717994.jpg'),
(61552, 4162, 'South Park S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211515.mp4', 'http://timg.bdta.pro/images/2913265ffc107115372df8e07add0762.jpg'),
(61553, 4162, 'South Park S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211516.mp4', 'http://timg.bdta.pro/images/0991460ab90f051f0982e99d9e7fbb90.jpg'),
(61554, 4162, 'South Park S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211517.mp4', 'http://timg.bdta.pro/images/b79b8508f3a2fd34afd62bd8e8e5d485.jpg'),
(61555, 4162, 'South Park S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211518.mp4', 'http://timg.bdta.pro/images/2c6161727b25a3a146c8684689c8b336.jpg'),
(61556, 4162, 'South Park S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/211519.mp4', 'http://timg.bdta.pro/images/19a149fc28365bc7f0bc4f79d7b8353f.jpg'),
(61557, 4162, 'South Park S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/211520.mp4', 'http://timg.bdta.pro/images/c76bbd5c3f9bca24ae6fbdeb6e260b69.jpg'),
(61558, 4162, 'South Park S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/211521.mp4', 'http://timg.bdta.pro/images/d622122d3230da21efba8353c11dc44f.jpg'),
(61559, 4162, 'South Park S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/211522.mp4', 'http://timg.bdta.pro/images/a392c977192ce5a57796248677c1eef3.jpg'),
(61560, 4163, 'South Park S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211523.mp4', 'http://timg.bdta.pro/images/a0e6c3ee5fd8be56dbbc7960c619d6a0.jpg'),
(61561, 4163, 'South Park S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211524.mp4', 'http://timg.bdta.pro/images/f216122b4becabc3367cf819b8fd46da.jpg'),
(61562, 4163, 'South Park S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211525.mp4', 'http://timg.bdta.pro/images/a7b708015ef75aa6ac258f8bb0734601.jpg'),
(61563, 4163, 'South Park S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211526.mp4', 'http://timg.bdta.pro/images/c34a3565968b49a623ad830953765dac.jpg'),
(61564, 4163, 'South Park S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211527.mp4', 'http://timg.bdta.pro/images/63c7792b7e4affc8071e5d84d0c506ac.jpg'),
(61565, 4163, 'South Park S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211528.mp4', 'http://timg.bdta.pro/images/9204629b5d09b1230f7aaeb19e035263.jpg'),
(61566, 4163, 'South Park S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211529.mp4', 'http://timg.bdta.pro/images/faded7a9a064976b1342b151a672a85a.jpg'),
(61567, 4163, 'South Park S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211530.mp4', 'http://timg.bdta.pro/images/dd97bb0165644f8afd0b1f12a118faf3.jpg'),
(61568, 4163, 'South Park S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211531.mp4', 'http://timg.bdta.pro/images/122dbf79a5da38b72372239ef4f6294c.jpg'),
(61569, 4163, 'South Park S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211532.mp4', 'http://timg.bdta.pro/images/3ff892852b841fbe98923c5acdfd84ac.jpg'),
(61570, 4163, 'South Park S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211533.mp4', 'http://timg.bdta.pro/images/24aa731176aa7b6778492a40c89f9a8b.jpg'),
(61571, 4163, 'South Park S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211534.mp4', 'http://timg.bdta.pro/images/aa882c357f25d1cde6689071722365d2.jpg'),
(61572, 4163, 'South Park S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211535.mp4', 'http://timg.bdta.pro/images/952eb0b26ad63086e71351d520139cb4.jpg'),
(61573, 4163, 'South Park S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/211536.mp4', 'http://timg.bdta.pro/images/46302ee0fb1fbc92ce838615a2ab4dbf.jpg'),
(61574, 4163, 'South Park S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/211537.mp4', 'http://timg.bdta.pro/images/2e0b435c21aa658d639b19229e903c8f.jpg'),
(61575, 4163, 'South Park S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/211538.mp4', 'http://timg.bdta.pro/images/ca4fafca2172f2d015dec6a8282c6a07.jpg'),
(61576, 4163, 'South Park S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/211539.mp4', 'http://timg.bdta.pro/images/d810bc3575c34f09bd06b055f53642b0.jpg'),
(61577, 4164, 'South Park S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211540.mp4', 'http://timg.bdta.pro/images/46c71db1c30b4c98c14241cefec8116d.jpg'),
(61578, 4164, 'South Park S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211541.mp4', 'http://timg.bdta.pro/images/38421f310b3fb0cbd3e47cb521f37a10.jpg'),
(61579, 4164, 'South Park S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211542.mp4', 'http://timg.bdta.pro/images/be28ffda45771f9673e1ce90c2000601.jpg'),
(61580, 4164, 'South Park S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211543.mp4', 'http://timg.bdta.pro/images/8991e51f06b37007dc5946f4f3edd66f.jpg'),
(61581, 4164, 'South Park S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211544.mp4', 'http://timg.bdta.pro/images/37620ba104ddf9cf3c208e0a8cb55b67.jpg'),
(61582, 4164, 'South Park S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211545.mp4', 'http://timg.bdta.pro/images/788846411c62a0fa259c4ed93b02aad2.jpg'),
(61583, 4164, 'South Park S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211546.mp4', 'http://timg.bdta.pro/images/9c31c283b63a0de1ea57668312a7e98e.jpg'),
(61584, 4164, 'South Park S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211547.mp4', 'http://timg.bdta.pro/images/82884e9df634abd4370447a0fa4ee805.jpg'),
(61585, 4164, 'South Park S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211548.mp4', 'http://timg.bdta.pro/images/5ca24055b3ce1a533779cef68a9c25ca.jpg'),
(61586, 4164, 'South Park S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211549.mp4', 'http://timg.bdta.pro/images/6735db3e142ea653689b5c06643546ea.jpg'),
(61587, 4164, 'South Park S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211550.mp4', 'http://timg.bdta.pro/images/2c7c0298f8d26538cb4e8e126ae9ec06.jpg'),
(61588, 4164, 'South Park S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211551.mp4', 'http://timg.bdta.pro/images/6563a008d417c25fbeaeef86e6c06bb2.jpg'),
(61589, 4164, 'South Park S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211552.mp4', 'http://timg.bdta.pro/images/ec4296ec597284fc4ab1c24c7b9f74b1.jpg'),
(61590, 4164, 'South Park S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/211553.mp4', 'http://timg.bdta.pro/images/0962337f9b31aa987edb8620e05b6a42.jpg'),
(61591, 4165, 'South Park S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211554.mp4', 'http://timg.bdta.pro/images/5e5565138b1a00e60712ec42a47ac45b.jpg'),
(61592, 4165, 'South Park S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211555.mp4', 'http://timg.bdta.pro/images/03efcd82509aa200f666150396a175eb.jpg'),
(61593, 4165, 'South Park S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211556.mp4', 'http://timg.bdta.pro/images/eca39844036d15cfa0b046cab4132f2a.jpg'),
(61594, 4165, 'South Park S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211557.mp4', 'http://timg.bdta.pro/images/022705ea9ce972c694daa70fd5d1deeb.jpg'),
(61595, 4165, 'South Park S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211558.mp4', 'http://timg.bdta.pro/images/f1f7aaffc20298ae331e12471f5e1c14.jpg'),
(61596, 4165, 'South Park S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211559.mp4', 'http://timg.bdta.pro/images/340726f557e5003186ff93a7cf919a78.jpg'),
(61597, 4165, 'South Park S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211560.mp4', 'http://timg.bdta.pro/images/3b090545a57378a50b32d70258ab77e6.jpg'),
(61598, 4165, 'South Park S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211561.mp4', 'http://timg.bdta.pro/images/adac4a7628325c8b58332465d65a7294.jpg'),
(61599, 4165, 'South Park S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211562.mp4', 'http://timg.bdta.pro/images/43e9c3f6cf183f8223e27e4eb27f55c2.jpg'),
(61600, 4165, 'South Park S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211563.mp4', 'http://timg.bdta.pro/images/811fc9b49569908eb0c298b0c758501a.jpg'),
(61601, 4165, 'South Park S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211564.mp4', 'http://timg.bdta.pro/images/cd2637b1a9a6085ed4d27c1207b5ade0.jpg'),
(61602, 4165, 'South Park S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211565.mp4', 'http://timg.bdta.pro/images/0732ef360e94812f380cf26f28481497.jpg'),
(61603, 4165, 'South Park S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211566.mp4', 'http://timg.bdta.pro/images/76426a34f261e5c82da39631f709a81f.jpg'),
(61604, 4165, 'South Park S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/211567.mp4', 'http://timg.bdta.pro/images/7282f5281ce63bbc91afa71646aea0e0.jpg'),
(61605, 4165, 'South Park S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/211568.mp4', 'http://timg.bdta.pro/images/267644adb131a246c2509a2b85e0458a.jpg'),
(61606, 4165, 'South Park S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/211569.mp4', 'http://timg.bdta.pro/images/d0af0c1785d764bf14f5fc6525bcd7cc.jpg'),
(61607, 4165, 'South Park S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/211570.mp4', 'http://timg.bdta.pro/images/ae462a3a528917431905c3462e13bf98.jpg'),
(61608, 4166, 'South Park S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211571.mp4', 'http://timg.bdta.pro/images/409b312231515526ba2c8b8714e15b1d.jpg'),
(61609, 4166, 'South Park S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211572.mp4', 'http://timg.bdta.pro/images/9b9a9c9ee267c99fa9f548bb0e8731d8.jpg'),
(61610, 4166, 'South Park S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211573.mp4', 'http://timg.bdta.pro/images/e36d0f172b0c207ad17627449b1577e8.jpg'),
(61611, 4166, 'South Park S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211574.mp4', 'http://timg.bdta.pro/images/3c4c40210762a4668b6ce0046aa8797c.jpg'),
(61612, 4166, 'South Park S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211575.mp4', 'http://timg.bdta.pro/images/ffb07ddb883593221cdd536a08765802.jpg'),
(61613, 4166, 'South Park S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211576.mp4', 'http://timg.bdta.pro/images/a8d030a7084d2f7525617a148f623f4b.jpg'),
(61614, 4166, 'South Park S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211577.mp4', 'http://timg.bdta.pro/images/867422b2886a0526f9ef800e855edfa4.jpg'),
(61615, 4166, 'South Park S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211578.mp4', 'http://timg.bdta.pro/images/c252e98a540f73d347b274debf8c2948.jpg'),
(61616, 4166, 'South Park S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211579.mp4', 'http://timg.bdta.pro/images/b388c477feda42d3dab0eac089d32a9e.jpg'),
(61617, 4166, 'South Park S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211580.mp4', 'http://timg.bdta.pro/images/6596adbe09d59d92b4814d8062eeae83.jpg'),
(61618, 4166, 'South Park S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211581.mp4', 'http://timg.bdta.pro/images/f515bc1628d86bd2ded60006da166929.jpg'),
(61619, 4166, 'South Park S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211582.mp4', 'http://timg.bdta.pro/images/aa66a163495f4f05711e780e6247048e.jpg'),
(61620, 4166, 'South Park S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211583.mp4', 'http://timg.bdta.pro/images/2dd542509a7a1bb3e596e5ab5a8205aa.jpg'),
(61621, 4166, 'South Park S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/211584.mp4', 'http://timg.bdta.pro/images/e0ba83c8c0c02772944fddaeaeabad27.jpg'),
(61622, 4166, 'South Park S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/211585.mp4', 'http://timg.bdta.pro/images/88892b14b4a800e03936e0013ed1edc0.jpg'),
(61623, 4167, 'South Park S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211586.mp4', 'http://timg.bdta.pro/images/c592ef466911c67906801f581a39fa30.jpg'),
(61624, 4167, 'South Park S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211587.mp4', 'http://timg.bdta.pro/images/f7f0cde11556cb2b3d534c0c0d28ad5a.jpg'),
(61625, 4167, 'South Park S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211588.mp4', 'http://timg.bdta.pro/images/8567922ad2cdfc6050dfa9ce75b3c5bc.jpg'),
(61626, 4167, 'South Park S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211589.mp4', 'http://timg.bdta.pro/images/d22191f395c4629ef8627e7590a3cdab.jpg'),
(61627, 4167, 'South Park S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211590.mp4', 'http://timg.bdta.pro/images/6fd7b20b4adbf632801c7129c7b45358.jpg'),
(61628, 4167, 'South Park S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211591.mp4', 'http://timg.bdta.pro/images/01d10985db2aef55d6a8bca1513dc791.jpg'),
(61629, 4167, 'South Park S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211592.mp4', 'http://timg.bdta.pro/images/2ff392d1b33abe6e27c19c626811608b.jpg'),
(61630, 4167, 'South Park S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211593.mp4', 'http://timg.bdta.pro/images/31d2535b6affc3cc99817d832f7b273e.jpg'),
(61631, 4167, 'South Park S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211594.mp4', 'http://timg.bdta.pro/images/b0c900b9c5cc27b03973a5d280db11c8.jpg'),
(61632, 4167, 'South Park S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211595.mp4', 'http://timg.bdta.pro/images/5b35b9d1a678540eb15497b59bbe3665.jpg'),
(61633, 4167, 'South Park S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211596.mp4', 'http://timg.bdta.pro/images/508c4738668d7f8a81989fa2738e5a17.jpg'),
(61634, 4167, 'South Park S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211597.mp4', 'http://timg.bdta.pro/images/720f1d38a438d7781d77f0dbdd92cf50.jpg'),
(61635, 4167, 'South Park S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211598.mp4', 'http://timg.bdta.pro/images/b62927d7133a236a18a2f474a9062493.jpg'),
(61636, 4167, 'South Park S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/211599.mp4', 'http://timg.bdta.pro/images/8a203c6df097585c79ba958f1156f95f.jpg'),
(61637, 4168, 'South Park S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211600.mp4', 'http://timg.bdta.pro/images/744d9b575566cf50b1061f1e219ae414.jpg'),
(61638, 4168, 'South Park S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211601.mp4', 'http://timg.bdta.pro/images/0633ab0c41d0d8f4d4429f6f45c157db.jpg'),
(61639, 4168, 'South Park S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211602.mp4', 'http://timg.bdta.pro/images/288921f979c332cca0c6081df446415b.jpg'),
(61640, 4168, 'South Park S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211603.mp4', 'http://timg.bdta.pro/images/b874a21bdeb2e65ca797c1ce40c27fce.jpg'),
(61641, 4168, 'South Park S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211604.mp4', 'http://timg.bdta.pro/images/cea408f7e23c86aa7ed9e5fa31850ab2.jpg'),
(61642, 4168, 'South Park S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211605.mp4', 'http://timg.bdta.pro/images/b54d2e60a3973c24cd40fe3dc180e137.jpg'),
(61643, 4168, 'South Park S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211606.mp4', 'http://timg.bdta.pro/images/b9bb30097377e2de15b4001382dbc172.jpg'),
(61644, 4168, 'South Park S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211607.mp4', 'http://timg.bdta.pro/images/c1465e4c0705cd5db0df1032f304bfac.jpg'),
(61645, 4168, 'South Park S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211608.mp4', 'http://timg.bdta.pro/images/09c458abf9860648559bac3845aec2dc.jpg'),
(61646, 4168, 'South Park S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211609.mp4', 'http://timg.bdta.pro/images/befdab472334f1f8ab80a7b1d719518e.jpg'),
(61647, 4168, 'South Park S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211610.mp4', 'http://timg.bdta.pro/images/dc189770d8b215ead50cddb8f58edd2a.jpg'),
(61648, 4168, 'South Park S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211611.mp4', 'http://timg.bdta.pro/images/01608e114116d3902129bdbd69f95c67.jpg'),
(61649, 4168, 'South Park S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211612.mp4', 'http://timg.bdta.pro/images/d4aa52a7ce1c1207fa35ed36e0729825.jpg'),
(61650, 4168, 'South Park S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/211613.mp4', 'http://timg.bdta.pro/images/ddb31f3198d3eee56a42c321234351b2.jpg'),
(61651, 4169, 'South Park S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211614.mp4', 'http://timg.bdta.pro/images/d284384b738e9296529ba547cfb86c44.jpg'),
(61652, 4169, 'South Park S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211615.mp4', 'http://timg.bdta.pro/images/2d458ee116ba5fe8df8fd0560f1e22bc.jpg'),
(61653, 4169, 'South Park S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211616.mp4', 'http://timg.bdta.pro/images/58ff5818422b9b9e7a0a18df05fb3968.jpg'),
(61654, 4169, 'South Park S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211617.mp4', 'http://timg.bdta.pro/images/2aba51f307af3582a8cc6adf69f5dd1e.jpg'),
(61655, 4169, 'South Park S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211618.mp4', 'http://timg.bdta.pro/images/8e466333908ac1cd61c17d98e1f3f76c.jpg'),
(61656, 4169, 'South Park S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211619.mp4', 'http://timg.bdta.pro/images/d35cf11d83e5ca5e0f7c57c608eaa382.jpg'),
(61657, 4169, 'South Park S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211620.mp4', 'http://timg.bdta.pro/images/cd93beeb0a331e7cdfc7928df5268608.jpg'),
(61658, 4169, 'South Park S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211621.mp4', 'http://timg.bdta.pro/images/cd36131a7146c52bdd2136c718fc2b03.jpg'),
(61659, 4169, 'South Park S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211622.mp4', 'http://timg.bdta.pro/images/88a350ae4a5e5e906e756ca7a83eef9d.jpg'),
(61660, 4169, 'South Park S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211623.mp4', 'http://timg.bdta.pro/images/9f9045d668c574ceced41c0dc9934466.jpg'),
(61661, 4169, 'South Park S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211624.mp4', 'http://timg.bdta.pro/images/d6d6553b376ce37f4915356c72f2129c.jpg'),
(61662, 4169, 'South Park S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211625.mp4', 'http://timg.bdta.pro/images/389ec1c390be68726cf70a4222c48c4f.jpg'),
(61663, 4169, 'South Park S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211626.mp4', 'http://timg.bdta.pro/images/63c83c48c6eb1af63ebb13f156bab693.jpg'),
(61664, 4169, 'South Park S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/211627.mp4', 'http://timg.bdta.pro/images/54a473830db13208039d875fa044ceb3.jpg'),
(61665, 4170, 'South Park S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211628.mp4', 'http://timg.bdta.pro/images/aba2d3e54ae4f4cefc3fcdb3a0c6c56b.jpg'),
(61666, 4170, 'South Park S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211629.mp4', 'http://timg.bdta.pro/images/f113972e0938719c5aa08afe9b172d85.jpg'),
(61667, 4170, 'South Park S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211630.mp4', 'http://timg.bdta.pro/images/39bfab4274962711d252212f0eb18cc2.jpg'),
(61668, 4170, 'South Park S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211631.mp4', 'http://timg.bdta.pro/images/0c938e70d79535726c439c9284a8f677.jpg'),
(61669, 4170, 'South Park S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211632.mp4', 'http://timg.bdta.pro/images/a652e20c5298b92606740eaeca07372e.jpg'),
(61670, 4170, 'South Park S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211633.mp4', 'http://timg.bdta.pro/images/e7578f38deed91e50e1ca722c7b5b38a.jpg'),
(61671, 4170, 'South Park S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211634.mp4', 'http://timg.bdta.pro/images/a52f2bf6636eaace220ffb2f508e9f62.jpg'),
(61672, 4170, 'South Park S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211635.mp4', 'http://timg.bdta.pro/images/ca1a16d9a39e9792a53339c800d9b8a3.jpg'),
(61673, 4170, 'South Park S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211636.mp4', 'http://timg.bdta.pro/images/d0e7ba49ddbd99a7eac50cdcfce2ec4a.jpg'),
(61674, 4170, 'South Park S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211637.mp4', 'http://timg.bdta.pro/images/d56a42ba024d7e308b46872b2c6c7d35.jpg'),
(61675, 4170, 'South Park S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211638.mp4', 'http://timg.bdta.pro/images/5d13b0c9782a6c9498a2ec8ed95685a7.jpg'),
(61676, 4170, 'South Park S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211639.mp4', 'http://timg.bdta.pro/images/dfe9001a58bd545372bc1a0d94f579fa.jpg'),
(61677, 4170, 'South Park S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211640.mp4', 'http://timg.bdta.pro/images/45d6a0195de699428d66c9fe8d2f7d0b.jpg'),
(61678, 4170, 'South Park S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/211641.mp4', 'http://timg.bdta.pro/images/9f845a60569da4210f7b6cde06e37fd4.jpg'),
(61679, 4170, 'South Park S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/211642.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61680, 4170, 'South Park S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/211643.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61681, 4170, 'South Park S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/211644.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61682, 4170, 'South Park S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/211645.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61683, 4170, 'South Park S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/211646.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61684, 4170, 'South Park S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/211647.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61685, 4170, 'South Park S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/211648.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61686, 4170, 'South Park S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/211649.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61687, 4170, 'South Park S11 E23', 'http://sinalprivado.info:80/series/1533784/1533784/211650.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61688, 4170, 'South Park S11 E24', 'http://sinalprivado.info:80/series/1533784/1533784/211651.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61689, 4170, 'South Park S11 E25', 'http://sinalprivado.info:80/series/1533784/1533784/211652.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61690, 4170, 'South Park S11 E26', 'http://sinalprivado.info:80/series/1533784/1533784/211653.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61691, 4170, 'South Park S11 E27', 'http://sinalprivado.info:80/series/1533784/1533784/211654.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61692, 4170, 'South Park S11 E28', 'http://sinalprivado.info:80/series/1533784/1533784/211655.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61693, 4171, 'South Park S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211656.mp4', 'http://timg.bdta.pro/images/3e5f70513681a393c57c983ffd4dc5d5.jpg'),
(61694, 4171, 'South Park S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211657.mp4', 'http://timg.bdta.pro/images/ec26711ba74c9df0c6ff2167fcabd462.jpg'),
(61695, 4171, 'South Park S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211658.mp4', 'http://timg.bdta.pro/images/ada51c4d30f453b319e406cd3eef1e4c.jpg'),
(61696, 4171, 'South Park S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211659.mp4', 'http://timg.bdta.pro/images/d470c9de200d80ef0e3d8b95ebb2a0f6.jpg'),
(61697, 4171, 'South Park S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211660.mp4', 'http://timg.bdta.pro/images/f2c6909d047c4b944f590a7e03f95acc.jpg'),
(61698, 4171, 'South Park S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211661.mp4', 'http://timg.bdta.pro/images/3d36ee4eefbc35e3f87dfc5de6fe9162.jpg'),
(61699, 4171, 'South Park S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211662.mp4', 'http://timg.bdta.pro/images/54f46a4e0bb1d34dc9226b624e4915bf.jpg'),
(61700, 4171, 'South Park S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211663.mp4', 'http://timg.bdta.pro/images/a18e911414df3d48cdfdb9ebe2f851f4.jpg'),
(61701, 4171, 'South Park S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211664.mp4', 'http://timg.bdta.pro/images/5012165f044788b509ce3cb61b1142ae.jpg'),
(61702, 4171, 'South Park S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211665.mp4', 'http://timg.bdta.pro/images/946dfdbfbdf36bd3fafb3b16fd3f93f3.jpg'),
(61703, 4171, 'South Park S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211666.mp4', 'http://timg.bdta.pro/images/c3725a2049bd04e724348208fa323b87.jpg'),
(61704, 4171, 'South Park S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211667.mp4', 'http://timg.bdta.pro/images/14fc91ae5d2ab76a2b4415f16f8b026f.jpg'),
(61705, 4171, 'South Park S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211668.mp4', 'http://timg.bdta.pro/images/48ab94d6aa07feb1860528e98f8319ea.jpg'),
(61706, 4171, 'South Park S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/211669.mp4', 'http://timg.bdta.pro/images/4dab908e247cae9262be85f024e347a5.jpg'),
(61707, 4171, 'South Park S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/211670.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61708, 4171, 'South Park S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/211671.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61709, 4172, 'South Park S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211672.mp4', 'http://timg.bdta.pro/images/409a57e3cf26a24e427d6342250f5ac6.jpg'),
(61710, 4172, 'South Park S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211673.mp4', 'http://timg.bdta.pro/images/d5bb1b4c2eb3507fdd73dc033a4e7895.jpg'),
(61711, 4172, 'South Park S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211674.mp4', 'http://timg.bdta.pro/images/b7495efed836effa7ec7190bf4da7d7e.jpg'),
(61712, 4172, 'South Park S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211675.mp4', 'http://timg.bdta.pro/images/b3c83495de5fdce5281f0740a22c4cfc.jpg'),
(61713, 4172, 'South Park S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211676.mp4', 'http://timg.bdta.pro/images/c71ea8e3b661239bbbd8782fd763f830.jpg'),
(61714, 4172, 'South Park S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211677.mp4', 'http://timg.bdta.pro/images/0a25aa5d18086cda99ffef20e2e34ff9.jpg'),
(61715, 4172, 'South Park S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211678.mp4', 'http://timg.bdta.pro/images/7cd9c4a3a639122e3cdfe4007525867e.jpg'),
(61716, 4172, 'South Park S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211679.mp4', 'http://timg.bdta.pro/images/878b93d2e6c6b54e468815de4181c6fd.jpg'),
(61717, 4172, 'South Park S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211680.mp4', 'http://timg.bdta.pro/images/cd8d5c015c8f401eb4e0e0df20220d16.jpg'),
(61718, 4172, 'South Park S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211681.mp4', 'http://timg.bdta.pro/images/52d530c6977608cebeb95d07e6efa030.jpg'),
(61719, 4172, 'South Park S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211682.mp4', 'http://timg.bdta.pro/images/f275efd30b69497e87fd79bcc411502a.jpg'),
(61720, 4172, 'South Park S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211683.mp4', 'http://timg.bdta.pro/images/c490a4145b23982ae118851051095c54.jpg'),
(61721, 4172, 'South Park S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211684.mp4', 'http://timg.bdta.pro/images/dc7a4cfc007522f592ff1ec1eeff1ccd.jpg'),
(61722, 4172, 'South Park S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/211685.mp4', 'http://timg.bdta.pro/images/4bc423897d418b5347270509bd5b2c11.jpg'),
(61723, 4173, 'South Park S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211686.mp4', 'http://timg.bdta.pro/images/8342af1be05b55cf3e3a2bd8d75998e8.jpg'),
(61724, 4173, 'South Park S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211687.mp4', 'http://timg.bdta.pro/images/cba8e6174be793d1b04cef8abc10efb5.jpg'),
(61725, 4173, 'South Park S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211688.mp4', 'http://timg.bdta.pro/images/aaa073f4fe7056803ff17d61dad76f2f.jpg'),
(61726, 4173, 'South Park S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211689.mp4', 'http://timg.bdta.pro/images/cc8bccfb8adb3ed09e1df2b4e26fbbfe.jpg'),
(61727, 4173, 'South Park S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211690.mp4', 'http://timg.bdta.pro/images/244df14d5de0023e302630666d6d8c84.jpg'),
(61728, 4173, 'South Park S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211691.mp4', 'http://timg.bdta.pro/images/1a8aadca6b245bdd5329d90ca2e0025e.jpg'),
(61729, 4173, 'South Park S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211692.mp4', 'http://timg.bdta.pro/images/d73c1d666bde3b729303eb5d088bf402.jpg'),
(61730, 4173, 'South Park S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211693.mp4', 'http://timg.bdta.pro/images/d5a7f253c6091917486d7698353a1226.jpg'),
(61731, 4173, 'South Park S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211694.mp4', 'http://timg.bdta.pro/images/b8acf38a34766536ec024c64d808f1bd.jpg'),
(61732, 4173, 'South Park S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211695.mp4', 'http://timg.bdta.pro/images/193084772f03ad61ee295574f6e1f350.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(61733, 4173, 'South Park S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211696.mp4', 'http://timg.bdta.pro/images/911ca89836754e10bdabefaddce5a627.jpg'),
(61734, 4173, 'South Park S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211697.mp4', 'http://timg.bdta.pro/images/4e10029f7e2f090ba193b0dc60ebd4da.jpg'),
(61735, 4173, 'South Park S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211698.mp4', 'http://timg.bdta.pro/images/985dbeb7b5da343c6ffc3224a15de483.jpg'),
(61736, 4173, 'South Park S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/211699.mp4', 'http://timg.bdta.pro/images/65d8f3914f5f40b756aea03c869aabec.jpg'),
(61737, 4174, 'South Park S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211700.mp4', 'http://timg.bdta.pro/images/cb6d8b37734840291b002ff441eb08ad.jpg'),
(61738, 4174, 'South Park S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211701.mp4', 'http://timg.bdta.pro/images/fcb3d6f8aab0cbe4040ba63f67b9710b.jpg'),
(61739, 4174, 'South Park S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211702.mp4', 'http://timg.bdta.pro/images/bd140507e44f6c6ea7519055de01b54a.jpg'),
(61740, 4174, 'South Park S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211703.mp4', 'http://timg.bdta.pro/images/20290bd675d4431a4e70efbbcb9cb465.jpg'),
(61741, 4174, 'South Park S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211704.mp4', 'http://timg.bdta.pro/images/fd9104ea76437dd2cc41a32d92f70514.jpg'),
(61742, 4174, 'South Park S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211705.mp4', 'http://timg.bdta.pro/images/d419bd4702a938f551880ea345493863.jpg'),
(61743, 4174, 'South Park S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211706.mp4', 'http://timg.bdta.pro/images/dcc1d37a84af6e5f6d569cca1aeeffa5.jpg'),
(61744, 4174, 'South Park S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211707.mp4', 'http://timg.bdta.pro/images/f98793855c853e3028d8c0d96fbb1803.jpg'),
(61745, 4174, 'South Park S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211708.mp4', 'http://timg.bdta.pro/images/b8efc8b58fc960121eac2004456bd004.jpg'),
(61746, 4174, 'South Park S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211709.mp4', 'http://timg.bdta.pro/images/bc50e746eae086cef34a77849057e121.jpg'),
(61747, 4174, 'South Park S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211710.mp4', 'http://timg.bdta.pro/images/a996d5fc4d366649e12a9d1c9df84b2d.jpg'),
(61748, 4174, 'South Park S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211711.mp4', 'http://timg.bdta.pro/images/7c109fddd34ce797f5e4d57a21cec12d.jpg'),
(61749, 4174, 'South Park S15 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211712.mp4', 'http://timg.bdta.pro/images/fd446afb94142667a21d8957235eef91.jpg'),
(61750, 4174, 'South Park S15 E14', 'http://sinalprivado.info:80/series/1533784/1533784/211713.mp4', 'http://timg.bdta.pro/images/b4d4a2e1422da661cab9abfc3ffe43b9.jpg'),
(61751, 4175, 'South Park S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211714.mp4', 'http://timg.bdta.pro/images/0b5f3888abd735e284570d42fc392e83.jpg'),
(61752, 4175, 'South Park S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211715.mp4', 'http://timg.bdta.pro/images/6753da729c811b8c6350dd9de8772312.jpg'),
(61753, 4175, 'South Park S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211716.mp4', 'http://timg.bdta.pro/images/f53ce0ccde3303e7370ec77be3193329.jpg'),
(61754, 4175, 'South Park S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211717.mp4', 'http://timg.bdta.pro/images/2628e0651ca8cedc1db45f96f004e5d8.jpg'),
(61755, 4175, 'South Park S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211718.mp4', 'http://timg.bdta.pro/images/060ab571ebc096669de11f64ddf36f5f.jpg'),
(61756, 4175, 'South Park S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211719.mp4', 'http://timg.bdta.pro/images/407998135fd9cacbcf8a78d90067e780.jpg'),
(61757, 4175, 'South Park S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211720.mp4', 'http://timg.bdta.pro/images/cfadf1c629f56d788600c7a919df6069.jpg'),
(61758, 4175, 'South Park S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211721.mp4', 'http://timg.bdta.pro/images/d31941648702fccb92c2707c0d96fbfd.jpg'),
(61759, 4175, 'South Park S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211722.mp4', 'http://timg.bdta.pro/images/48be670a5441f7f78daa2d46ea4c8a10.jpg'),
(61760, 4175, 'South Park S16 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211723.mp4', 'http://timg.bdta.pro/images/261b684fed665a2a26c3542394ba0f40.jpg'),
(61761, 4175, 'South Park S16 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211724.mp4', 'http://timg.bdta.pro/images/5f8cbe6861f60f956f4fb51ddd4dbb62.jpg'),
(61762, 4175, 'South Park S16 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211725.mp4', 'http://timg.bdta.pro/images/17eb76fbd31d0e186ac3417d3481da0c.jpg'),
(61763, 4175, 'South Park S16 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211726.mp4', 'http://timg.bdta.pro/images/0f4fd988e7aeff236f97ba87aa9fbb05.jpg'),
(61764, 4175, 'South Park S16 E14', 'http://sinalprivado.info:80/series/1533784/1533784/211727.mp4', 'http://timg.bdta.pro/images/b5e94c535b46eb4d31805bccb19efbc4.jpg'),
(61765, 4176, 'South Park S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211728.mp4', 'http://timg.bdta.pro/images/6745d9fcf00f98abfd874a8f3d4f6bd1.jpg'),
(61766, 4176, 'South Park S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211729.mp4', 'http://timg.bdta.pro/images/a080c005c4f2e028bcc5408b171fa9b1.jpg'),
(61767, 4176, 'South Park S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211730.mp4', 'http://timg.bdta.pro/images/63e7324aeab4e74783b317b029c399cd.jpg'),
(61768, 4176, 'South Park S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211731.mp4', 'http://timg.bdta.pro/images/0dd95666bd52b63d189a3fd8ddadbbf7.jpg'),
(61769, 4176, 'South Park S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211732.mp4', 'http://timg.bdta.pro/images/bcaee4e6cc7de2e688d595f213996eaf.jpg'),
(61770, 4176, 'South Park S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211733.mp4', 'http://timg.bdta.pro/images/900f228f1f410c4cc288d8f72fdc4642.jpg'),
(61771, 4176, 'South Park S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211734.mp4', 'http://timg.bdta.pro/images/332b89192c516a70aef422da429fcf44.jpg'),
(61772, 4176, 'South Park S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211735.mp4', 'http://timg.bdta.pro/images/d67a478a48208291fa716c045a7971f8.jpg'),
(61773, 4176, 'South Park S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211736.mp4', 'http://timg.bdta.pro/images/9a5e0fb91f5eebdcc0ce6acc5f192f3a.jpg'),
(61774, 4177, 'South Park S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211737.mp4', 'http://timg.bdta.pro/images/c4c39e813ce739bcbb24678d60dd077c.jpg'),
(61775, 4177, 'South Park S18 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211738.mp4', 'http://timg.bdta.pro/images/a8bf30669c71fdea028b9897a04a44bf.jpg'),
(61776, 4177, 'South Park S18 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211739.mp4', 'http://timg.bdta.pro/images/15cfe7ecb13679b31578126a11b24cc2.jpg'),
(61777, 4177, 'South Park S18 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211740.mp4', 'http://timg.bdta.pro/images/8791465795cdb62ba40a657c84ac3f47.jpg'),
(61778, 4177, 'South Park S18 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211741.mp4', 'http://timg.bdta.pro/images/ad7bde4b2aaffa2674624385cb96a14e.jpg'),
(61779, 4177, 'South Park S18 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211742.mp4', 'http://timg.bdta.pro/images/57858d7586fd84ea60e6cc974fc5ca02.jpg'),
(61780, 4177, 'South Park S18 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211743.mp4', 'http://timg.bdta.pro/images/e839691a31f7d3984313314f0e4ad476.jpg'),
(61781, 4177, 'South Park S18 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211744.mp4', 'http://timg.bdta.pro/images/59ef0518253c12c18cf4b9aa8128f6cf.jpg'),
(61782, 4177, 'South Park S18 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211745.mp4', 'http://timg.bdta.pro/images/f93163c77a8b9ccdbb6ce92bd9a4ec31.jpg'),
(61783, 4177, 'South Park S18 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211746.mp4', 'http://timg.bdta.pro/images/4c9ee1d293f9f3193c9c6f8de63e22ae.jpg'),
(61784, 4178, 'South Park S19 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211747.mp4', 'http://timg.bdta.pro/images/146206591831cd6fd0d05802b932df8e.jpg'),
(61785, 4178, 'South Park S19 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211748.mp4', 'http://timg.bdta.pro/images/73184c1217d328021a2e62a2087a9bd7.jpg'),
(61786, 4178, 'South Park S19 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211749.mp4', 'http://timg.bdta.pro/images/9fff335309b4514ca5e9994ab45a9b98.jpg'),
(61787, 4178, 'South Park S19 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211750.mp4', 'http://timg.bdta.pro/images/5f056f4ab85dab5b39dd127d84c25b76.jpg'),
(61788, 4178, 'South Park S19 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211751.mp4', 'http://timg.bdta.pro/images/00340209793376a06cdc09d88e0f9da9.jpg'),
(61789, 4178, 'South Park S19 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211752.mp4', 'http://timg.bdta.pro/images/3fcdcb807058db3d3774afddc0634d17.jpg'),
(61790, 4178, 'South Park S19 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211753.mp4', 'http://timg.bdta.pro/images/48ce13d6fe98e5d0317344eb18b1d1ac.jpg'),
(61791, 4178, 'South Park S19 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211754.mp4', 'http://timg.bdta.pro/images/f76cf2055d2e4e7340c7c23eb5b0b1cc.jpg'),
(61792, 4178, 'South Park S19 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211755.mp4', 'http://timg.bdta.pro/images/41e4081d48835079231e11681f80d4ac.jpg'),
(61793, 4178, 'South Park S19 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211756.mp4', 'http://timg.bdta.pro/images/e7837f9951fe542ed78c60fe97e8f1b7.jpg'),
(61794, 4179, 'South Park S20 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211757.mp4', 'http://timg.bdta.pro/images/69015e5e3b98db429e7bae707016122c.jpg'),
(61795, 4179, 'South Park S20 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211758.mp4', 'http://timg.bdta.pro/images/93f1ab701dbd14bca4602fb66c9f5147.jpg'),
(61796, 4179, 'South Park S20 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211759.mp4', 'http://timg.bdta.pro/images/a1389926b0347f7a128c7edc1988f64f.jpg'),
(61797, 4179, 'South Park S20 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211760.mp4', 'http://timg.bdta.pro/images/bad27424a283c6deb0902f69cbc9ba26.jpg'),
(61798, 4179, 'South Park S20 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211761.mp4', 'http://timg.bdta.pro/images/dd582cb5ca28a1c0626545d58696931e.jpg'),
(61799, 4179, 'South Park S20 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211762.mp4', 'http://timg.bdta.pro/images/2dc808d588e0d7ac4b90834d2107aafe.jpg'),
(61800, 4179, 'South Park S20 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211763.mp4', 'http://timg.bdta.pro/images/89cb5f8967d8b9e44028e4923bbc2fef.jpg'),
(61801, 4179, 'South Park S20 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211764.mp4', 'http://timg.bdta.pro/images/68fb4a4a407ca6138c98e472e1d39cf7.jpg'),
(61802, 4179, 'South Park S20 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211765.mp4', 'http://timg.bdta.pro/images/6accd58897483e0aff4c632e3312e9c3.jpg'),
(61803, 4179, 'South Park S20 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211766.mp4', 'http://timg.bdta.pro/images/7a88149d7b88de1e25fbb2daab3cf279.jpg'),
(61804, 4180, 'South Park S21 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211767.mp4', 'http://timg.bdta.pro/images/9d5c1935f404ceded8e5a092f8750615.jpg'),
(61805, 4180, 'South Park S21 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211768.mp4', 'http://timg.bdta.pro/images/f82259960fccbb42a7324454244e2dcb.jpg'),
(61806, 4180, 'South Park S21 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211769.mp4', 'http://timg.bdta.pro/images/b412a008e0f61e60cbadff3cfd823766.jpg'),
(61807, 4180, 'South Park S21 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211770.mp4', 'http://timg.bdta.pro/images/f6a54d8a33c18794bfbf0faca193eb6b.jpg'),
(61808, 4180, 'South Park S21 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211771.mp4', 'http://timg.bdta.pro/images/b679b980d9ee967ab0d1f32dfc1f13d9.jpg'),
(61809, 4180, 'South Park S21 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211772.mp4', 'http://timg.bdta.pro/images/4d1efca0af59fb3dc01d72a6461f7978.jpg'),
(61810, 4180, 'South Park S21 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211773.mp4', 'http://timg.bdta.pro/images/3907e6f67121bb09154ce62913840467.jpg'),
(61811, 4180, 'South Park S21 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211774.mp4', 'http://timg.bdta.pro/images/ba0443cccb7aea865a61456dbc7a69d9.jpg'),
(61812, 4180, 'South Park S21 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211775.mp4', 'http://timg.bdta.pro/images/3a039b2b0e7265f8319b7920c92b67ba.jpg'),
(61813, 4180, 'South Park S21 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211776.mp4', 'http://timg.bdta.pro/images/98e87abdf868fb4977fdd46f571c65e7.jpg'),
(61814, 4181, 'South Park S22 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211777.mp4', 'http://timg.bdta.pro/images/7ed3b8eed3dd676d574f51a9e0865abf.jpg'),
(61815, 4181, 'South Park S22 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211778.mp4', 'http://timg.bdta.pro/images/22e1dae27414e12fbfc92178e8acb33e.jpg'),
(61816, 4181, 'South Park S22 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211779.mp4', 'http://timg.bdta.pro/images/8df12934ccd01979306d05cdaee2c9fd.jpg'),
(61817, 4181, 'South Park S22 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211780.mp4', 'http://timg.bdta.pro/images/03c1ca01046b574cec6b5832a8186403.jpg'),
(61818, 4181, 'South Park S22 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211781.mp4', 'http://timg.bdta.pro/images/b237c2c13eed4f773026068d6b4e1701.jpg'),
(61819, 4181, 'South Park S22 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211782.mp4', 'http://timg.bdta.pro/images/b95c5944b38baa06f6dd8bbfee3af43b.jpg'),
(61820, 4181, 'South Park S22 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211783.mp4', 'http://timg.bdta.pro/images/622a5c0d70dfaab4a4a747e185e34580.jpg'),
(61821, 4181, 'South Park S22 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211784.mp4', 'http://timg.bdta.pro/images/43e67bb16208ea3db0c69fa5dc73a44c.jpg'),
(61822, 4181, 'South Park S22 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211785.mp4', 'http://timg.bdta.pro/images/32210a1bf752e1e8c493dad84e53c923.jpg'),
(61823, 4181, 'South Park S22 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211786.mp4', 'http://timg.bdta.pro/images/0d300c0ced809652207ba1cc0a6c406a.jpg'),
(61824, 4182, 'South Park S23 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211787.mp4', 'http://timg.bdta.pro/images/c127c7453e66edb480eb3d9b839c7caa.jpg'),
(61825, 4182, 'South Park S23 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211788.mp4', 'http://timg.bdta.pro/images/2c16aa39d49a59eeeeff5dc9e1c6d4d7.jpg'),
(61826, 4182, 'South Park S23 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211789.mp4', 'http://timg.bdta.pro/images/4f7f32525088e254575bc68364313d11.jpg'),
(61827, 4182, 'South Park S23 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211790.mp4', 'http://timg.bdta.pro/images/9e36111d570416107bd582e3f51a683e.jpg'),
(61828, 4182, 'South Park S23 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211791.mp4', 'http://timg.bdta.pro/images/b0841125b0a3c2e615c14e77f9fdb695.jpg'),
(61829, 4182, 'South Park S23 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211792.mp4', 'http://timg.bdta.pro/images/4696bd2cc1550a5604c31f132890f511.jpg'),
(61830, 4182, 'South Park S23 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211793.mp4', 'http://timg.bdta.pro/images/172b55bf7ce7fca883c4c4e2dce8d07e.jpg'),
(61831, 4182, 'South Park S23 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211794.mp4', 'http://timg.bdta.pro/images/b9ab13dedfa237a153b8a2718a3fc610.jpg'),
(61832, 4182, 'South Park S23 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211795.mp4', 'http://timg.bdta.pro/images/ea8eb380c387f563845a6aed105a0f90.jpg'),
(61833, 4182, 'South Park S23 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211796.mp4', 'http://timg.bdta.pro/images/54d0b17677728c6ad2630c74290a008e.jpg'),
(61834, 4183, 'South Park S24 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211797.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61835, 4183, 'South Park S24 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211798.mp4', 'http://timg.bdta.pro/images/ab83185bccd6816b667e564661c0516b.jpg'),
(61836, 4183, 'South Park S24 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211799.mp4', 'http://timg.bdta.pro/images/4bf2c81a6c2b3cbae82006cc144262ac.jpg'),
(61837, 4184, 'South Park S25 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211800.mp4', 'http://timg.bdta.pro/images/1c00f6bf08fd5107accc7fbf3c885093.jpg'),
(61838, 4184, 'South Park S25 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211801.mp4', 'http://timg.bdta.pro/images/f522704b61198e007bd43ff88d6520bf.jpg'),
(61839, 4184, 'South Park S25 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211802.mp4', 'http://timg.bdta.pro/images/b6cba1e0f9eb86840d50a5f528a859a0.jpg'),
(61840, 4184, 'South Park S25 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211803.mp4', 'http://timg.bdta.pro/images/9b6ed9a6356ffaf2247a9a215ae4167d.jpg'),
(61841, 4184, 'South Park S25 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211804.mp4', 'http://timg.bdta.pro/images/e6a0009a7ea54ecbb8a7e54f2fe31bb6.jpg'),
(61842, 4184, 'South Park S25 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211805.mp4', 'http://timg.bdta.pro/images/1c64ecf14b3eb45ba9f56070d2a729b0.jpg'),
(61843, 4185, 'South Park S26 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211806.mp4', 'http://image.tmdb.org/t/p/w1280/bq0wXlSJfn1egIe6WFrjHG7noc1.jpg'),
(61844, 4185, 'South Park S26 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211807.mp4', 'http://image.tmdb.org/t/p/w1280/yPh6XElpM7MI6GhgCwVu8B5SqEF.jpg'),
(61845, 4185, 'South Park S26 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211808.mp4', 'http://image.tmdb.org/t/p/w1280/2B9Ja0fyQGFfQbcbXmqPAuaEzo1.jpg'),
(61846, 4185, 'South Park S26 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211809.mp4', 'http://image.tmdb.org/t/p/w1280/rScLM159jnQIolM6fXj1OKffSsI.jpg'),
(61847, 4185, 'South Park S26 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211810.mp4', 'http://image.tmdb.org/t/p/w1280/b4JoHQhCdm9ZxIHjgdrPBwp1rqZ.jpg'),
(61848, 4185, 'South Park S26 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211811.mp4', 'http://image.tmdb.org/t/p/w1280/4gD7EPUld7GBGa6vSqaj8ImyUb7.jpg'),
(61849, 4186, 'South Park S27 E01', 'http://sinalprivado.info:80/series/1533784/1533784/880342.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61850, 4186, 'South Park S27 E02', 'http://sinalprivado.info:80/series/1533784/1533784/883022.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61851, 4186, 'South Park S27 E03', 'http://sinalprivado.info:80/series/1533784/1533784/883778.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61852, 4186, 'South Park S27 E04', 'http://sinalprivado.info:80/series/1533784/1533784/886057.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61853, 4186, 'South Park S27 E05', 'http://sinalprivado.info:80/series/1533784/1533784/888139.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61854, 4187, 'South Park S28 E01', 'http://sinalprivado.info:80/series/1533784/1533784/890049.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61855, 4187, 'South Park S28 E02', 'http://sinalprivado.info:80/series/1533784/1533784/893062.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61856, 4187, 'South Park S28 E03', 'http://sinalprivado.info:80/series/1533784/1533784/893564.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61857, 4187, 'South Park S28 E04', 'http://sinalprivado.info:80/series/1533784/1533784/895859.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61858, 4187, 'South Park S28 E05', 'http://sinalprivado.info:80/series/1533784/1533784/897403.mp4', 'http://gstaticontent.com/images/33cd633d28b8bed6e72763c901a50613.jpg'),
(61859, 4188, 'Como Vender Drogas Online (Rápido) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151645.mp4', 'http://timg.bdta.pro/images/9e98a1900336df980c7b71f2e160fb12.jpg'),
(61860, 4188, 'Como Vender Drogas Online (Rápido) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151646.mp4', 'http://timg.bdta.pro/images/a03169b83a2b36fecaa73a5913fd9ff6.jpg'),
(61861, 4188, 'Como Vender Drogas Online (Rápido) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151647.mp4', 'http://timg.bdta.pro/images/0e0e1e869f8ec00f27b769698b56f406.jpg'),
(61862, 4188, 'Como Vender Drogas Online (Rápido) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151648.mp4', 'http://timg.bdta.pro/images/20de95c77d37f7c2aedcbe950e38e477.jpg'),
(61863, 4188, 'Como Vender Drogas Online (Rápido) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151649.mp4', 'http://timg.bdta.pro/images/a55a8882ca89a5f4c2def016ebeae9c6.jpg'),
(61864, 4188, 'Como Vender Drogas Online (Rápido) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151650.mp4', 'http://timg.bdta.pro/images/c92ba0992caf1e05dc7816b4f0c33baa.jpg'),
(61865, 4189, 'Como Vender Drogas Online (Rápido) S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151651.mp4', 'http://timg.bdta.pro/images/81e489e050de89816676aa80b24d2327.jpg'),
(61866, 4189, 'Como Vender Drogas Online (Rápido) S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151652.mp4', 'http://timg.bdta.pro/images/baac1f6963b7c01296f4058852218e28.jpg'),
(61867, 4189, 'Como Vender Drogas Online (Rápido) S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151653.mp4', 'http://timg.bdta.pro/images/91e4b4131a569f23e5a18b328d66481e.jpg'),
(61868, 4189, 'Como Vender Drogas Online (Rápido) S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151654.mp4', 'http://timg.bdta.pro/images/10d3549d6f3940fd7339c399a0536200.jpg'),
(61869, 4189, 'Como Vender Drogas Online (Rápido) S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151655.mp4', 'http://timg.bdta.pro/images/edb8a0c90e71c49c17e088fac0250fa8.jpg'),
(61870, 4189, 'Como Vender Drogas Online (Rápido) S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151656.mp4', 'http://timg.bdta.pro/images/51cec1e831db62c979adfeb95db5cfe8.jpg'),
(61871, 4190, 'Como Vender Drogas Online (Rápido) S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151657.mp4', 'http://timg.bdta.pro/images/c900e8c76157916480c97c4dd0a6dde9.jpg'),
(61872, 4190, 'Como Vender Drogas Online (Rápido) S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151658.mp4', 'http://timg.bdta.pro/images/6e1a166c606084ada22933b77661262f.jpg'),
(61873, 4190, 'Como Vender Drogas Online (Rápido) S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151659.mp4', 'http://timg.bdta.pro/images/4c6ace93df6625fbae30f7e2292ce7b9.jpg'),
(61874, 4190, 'Como Vender Drogas Online (Rápido) S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151660.mp4', 'http://timg.bdta.pro/images/a24ccec710141f8e850d53a7515f85a1.jpg'),
(61875, 4190, 'Como Vender Drogas Online (Rápido) S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151661.mp4', 'http://timg.bdta.pro/images/0adf0efbd0438e0de00943f13429c85c.jpg'),
(61876, 4190, 'Como Vender Drogas Online (Rápido) S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151662.mp4', 'http://timg.bdta.pro/images/b844a5c262c63ca9f6e12930f4699bbc.jpg'),
(61877, 4191, 'Como Vender Drogas Online (Rápido) S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/883943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hgUaUxGcvxA08as9KpQThYxabfh.jpg'),
(61878, 4191, 'Como Vender Drogas Online (Rápido) S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/883944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bmvQUDsa5TWT74PNeDtHJ3ex4Tq.jpg'),
(61879, 4191, 'Como Vender Drogas Online (Rápido) S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/883945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uTmwcHAIHO3X9FIgluI3dfWbP31.jpg'),
(61880, 4191, 'Como Vender Drogas Online (Rápido) S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/883946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f8iB07WbRjxseJi8lEMktFgchit.jpg'),
(61881, 4191, 'Como Vender Drogas Online (Rápido) S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/883947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9PeCju1fAmuGr28cLP2Mz5IQwSP.jpg'),
(61882, 4191, 'Como Vender Drogas Online (Rápido) S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/883948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8WMbJ1phX2JIucG7iwPOR0Pbvhu.jpg'),
(61883, 4192, 'A Pequena Sereia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151528.mp4', 'http://timg.bdta.pro/images/b9f429d4adab3adc513fd2014fb57a77.jpg'),
(61884, 4192, 'A Pequena Sereia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151529.mp4', 'http://timg.bdta.pro/images/8cd1c60ff3e15f25bfa74c23a09dc066.jpg'),
(61885, 4192, 'A Pequena Sereia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151530.mp4', 'http://timg.bdta.pro/images/63a2a32ce50841f45b3804e818437b71.jpg'),
(61886, 4192, 'A Pequena Sereia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151531.mp4', 'http://timg.bdta.pro/images/4be66889919798d6534618e040413ac2.jpg'),
(61887, 4192, 'A Pequena Sereia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151532.mp4', 'http://timg.bdta.pro/images/b0e1cd24d378db2ff5c16aad2262b361.jpg'),
(61888, 4192, 'A Pequena Sereia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151533.mp4', 'http://timg.bdta.pro/images/de7ad8ac79f6f61a4493312c406bc267.jpg'),
(61889, 4192, 'A Pequena Sereia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151534.mp4', 'http://timg.bdta.pro/images/6fa44ffe06ceed67d5351b7a2b8cda5b.jpg'),
(61890, 4192, 'A Pequena Sereia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151535.mp4', 'http://timg.bdta.pro/images/265d2d07751a51a9ae13c11211b14e32.jpg'),
(61891, 4192, 'A Pequena Sereia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151536.mp4', 'http://timg.bdta.pro/images/75a5c40dab09509e1d6d81c2655b3379.jpg'),
(61892, 4192, 'A Pequena Sereia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151537.mp4', 'http://timg.bdta.pro/images/40100fe9ea7da7c7a92df184816d0ace.jpg'),
(61893, 4192, 'A Pequena Sereia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151538.mp4', 'http://timg.bdta.pro/images/4000586abf44dda410922ffa814bd04a.jpg'),
(61894, 4192, 'A Pequena Sereia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151539.mp4', 'http://timg.bdta.pro/images/e8fc98682e272cac96b3215ac07e6b94.jpg'),
(61895, 4192, 'A Pequena Sereia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151540.mp4', 'http://timg.bdta.pro/images/0c67673fc0661133a2ebc0ad67d9ec6f.jpg'),
(61896, 4192, 'A Pequena Sereia S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151541.mp4', 'http://timg.bdta.pro/images/b47ff1f9989bf928488cd1cb1f8e38b4.jpg'),
(61897, 4193, 'A Pequena Sereia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151542.mp4', 'http://timg.bdta.pro/images/7016ec6d7910c2d5ace634045a60557b.jpg'),
(61898, 4193, 'A Pequena Sereia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151543.mp4', 'http://timg.bdta.pro/images/112f7e25f4a66f8bfbd4d84e7766bc0f.jpg'),
(61899, 4193, 'A Pequena Sereia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151544.mp4', 'http://timg.bdta.pro/images/ada15f3d23813dd1e765d44ecae92450.jpg'),
(61900, 4193, 'A Pequena Sereia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151545.mp4', 'http://timg.bdta.pro/images/5017017ffa13c3b79b8f6660b7a2d60b.jpg'),
(61901, 4193, 'A Pequena Sereia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151546.mp4', 'http://timg.bdta.pro/images/3405f935d41bc27e9d3f03c6322966ce.jpg'),
(61902, 4193, 'A Pequena Sereia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151547.mp4', 'http://timg.bdta.pro/images/d05b2ec8c4d81546785b3cebcda5a953.jpg'),
(61903, 4193, 'A Pequena Sereia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151548.mp4', 'http://timg.bdta.pro/images/7a5c595c12676dcbea5bec4588df7d77.jpg'),
(61904, 4193, 'A Pequena Sereia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151549.mp4', 'http://timg.bdta.pro/images/5f0ef5f214a17742d167bf72f2728cc9.jpg'),
(61905, 4193, 'A Pequena Sereia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151550.mp4', 'http://timg.bdta.pro/images/b94386ba930338d412c5afef7f26e088.jpg'),
(61906, 4194, 'A Pequena Sereia S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151551.mp4', 'http://timg.bdta.pro/images/6e5072a4f864494f4cfb588f915b5733.jpg'),
(61907, 4194, 'A Pequena Sereia S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151552.mp4', 'http://timg.bdta.pro/images/dd27f6026deb52e0a0afeba41f67962e.jpg'),
(61908, 4194, 'A Pequena Sereia S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151553.mp4', 'http://timg.bdta.pro/images/a4fb517f10fd80a03dd1fcab1ee71c43.jpg'),
(61909, 4194, 'A Pequena Sereia S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151554.mp4', 'http://timg.bdta.pro/images/154a0b7776ee50be70610c9a1dd7c9ca.jpg'),
(61910, 4194, 'A Pequena Sereia S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151555.mp4', 'http://timg.bdta.pro/images/3da0eb719326e929683c873fd0ca05ff.jpg'),
(61911, 4194, 'A Pequena Sereia S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151556.mp4', 'http://timg.bdta.pro/images/11c28867bc1ea73075fb93f069572e55.jpg'),
(61912, 4194, 'A Pequena Sereia S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151557.mp4', 'http://timg.bdta.pro/images/5972b875b68bf4d7ccb63d5c32ee02be.jpg'),
(61913, 4194, 'A Pequena Sereia S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151558.mp4', 'http://timg.bdta.pro/images/398452190657107afec3e0c578c4cce3.jpg'),
(61914, 4195, 'A Vaca e o Frango S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181646.mp4', 'http://timg.bdta.pro/images/1ef6de1d33c0c8b4321284afe73cc276.jpg'),
(61915, 4195, 'A Vaca e o Frango S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181647.mp4', 'http://timg.bdta.pro/images/ca21c16133f7deba01099cb464e5fc37.jpg'),
(61916, 4195, 'A Vaca e o Frango S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181648.mp4', 'http://timg.bdta.pro/images/333724fdd9bb2e774b33567e9fa0ae1d.jpg'),
(61917, 4195, 'A Vaca e o Frango S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181649.mp4', 'http://timg.bdta.pro/images/87ac3a5485200950ab79b13aae23c2e6.jpg'),
(61918, 4195, 'A Vaca e o Frango S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181650.mp4', 'http://timg.bdta.pro/images/a52b542f51dd33ee3ff997c553972bf8.jpg'),
(61919, 4195, 'A Vaca e o Frango S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181651.mp4', 'http://timg.bdta.pro/images/9070ae9cb177d9d890abae4d435989fb.jpg'),
(61920, 4195, 'A Vaca e o Frango S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181652.mp4', 'http://timg.bdta.pro/images/3a251a9a62ab390825e2f85fd38fcc37.jpg'),
(61921, 4195, 'A Vaca e o Frango S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181653.mp4', 'http://timg.bdta.pro/images/fc36eb2ec329e4ec51512e36830c311d.jpg'),
(61922, 4195, 'A Vaca e o Frango S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181654.mp4', 'http://timg.bdta.pro/images/9bc7c156062e50f4d47ef472b94963da.jpg'),
(61923, 4195, 'A Vaca e o Frango S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181655.mp4', 'http://timg.bdta.pro/images/e85e7263ac65983c7152e2aa8b82dcaa.jpg'),
(61924, 4195, 'A Vaca e o Frango S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/181656.mp4', 'http://timg.bdta.pro/images/7aeb993ec3fed354669f79aaff471308.jpg'),
(61925, 4195, 'A Vaca e o Frango S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/181657.mp4', 'http://timg.bdta.pro/images/5db280a583f318a4c9145b2f7c5a1497.jpg'),
(61926, 4195, 'A Vaca e o Frango S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/181658.mp4', 'http://timg.bdta.pro/images/4e8e327bc75445fe4df5ab63dfc1625e.jpg'),
(61927, 4196, 'A Vaca e o Frango S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181659.mp4', 'http://timg.bdta.pro/images/4498bda4810ec577d919b07d11a4b1ad.jpg'),
(61928, 4196, 'A Vaca e o Frango S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181660.mp4', 'http://timg.bdta.pro/images/40aaa21adb16d63f8f77c1b2048c1d89.jpg'),
(61929, 4196, 'A Vaca e o Frango S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181661.mp4', 'http://timg.bdta.pro/images/b9a2f548ddec4bfd31d2500a78ca7004.jpg'),
(61930, 4196, 'A Vaca e o Frango S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181662.mp4', 'http://timg.bdta.pro/images/d22f8e0e21ab800f9be4cb18202d8c56.jpg'),
(61931, 4196, 'A Vaca e o Frango S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181663.mp4', 'http://timg.bdta.pro/images/4263a539ae137cfec45e2675c775c888.jpg'),
(61932, 4196, 'A Vaca e o Frango S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181664.mp4', 'http://timg.bdta.pro/images/08708d90116a5b69547a797478572c97.jpg'),
(61933, 4196, 'A Vaca e o Frango S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181665.mp4', 'http://timg.bdta.pro/images/1ce17d8ed536f9c4e16cb50149fa898b.jpg'),
(61934, 4196, 'A Vaca e o Frango S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181666.mp4', 'http://timg.bdta.pro/images/7b31fab163c99318d45536cdd6b26595.jpg'),
(61935, 4196, 'A Vaca e o Frango S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181667.mp4', 'http://timg.bdta.pro/images/86923ef3903dcf9427782415f8602e43.jpg'),
(61936, 4196, 'A Vaca e o Frango S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181668.mp4', 'http://timg.bdta.pro/images/634be03092cccc49d6fc83a179032ed8.jpg'),
(61937, 4196, 'A Vaca e o Frango S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/181669.mp4', 'http://timg.bdta.pro/images/0ae65f9d430a1ccce5f27cf25563becb.jpg'),
(61938, 4196, 'A Vaca e o Frango S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/181670.mp4', 'http://timg.bdta.pro/images/47c17c81811744adca081105118b3d30.jpg'),
(61939, 4196, 'A Vaca e o Frango S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/181671.mp4', 'http://timg.bdta.pro/images/cd0d36c3ed3a90bb14ccfe1ea7abe0cf.jpg'),
(61940, 4197, 'A Vaca e o Frango S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181672.mp4', 'http://timg.bdta.pro/images/b90acb2103298a0aeebd14a93a82485b.jpg'),
(61941, 4197, 'A Vaca e o Frango S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181673.mp4', 'http://timg.bdta.pro/images/90326e574def987ee5e141342ce61c34.jpg'),
(61942, 4197, 'A Vaca e o Frango S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181674.mp4', 'http://timg.bdta.pro/images/fc156766b6af5852bc43b8c9143461ce.jpg'),
(61943, 4197, 'A Vaca e o Frango S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181675.mp4', 'http://timg.bdta.pro/images/8be2d49acbfc118ce068a4fc027b20f2.jpg'),
(61944, 4197, 'A Vaca e o Frango S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181676.mp4', 'http://timg.bdta.pro/images/2687fddb66b10a231cb9dd73c45e63b0.jpg'),
(61945, 4197, 'A Vaca e o Frango S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181677.mp4', 'http://timg.bdta.pro/images/88c87343d70f13249edab7a6914dff89.jpg'),
(61946, 4197, 'A Vaca e o Frango S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181678.mp4', 'http://timg.bdta.pro/images/ea7e6bde9b5767064262e118d55b38a3.jpg'),
(61947, 4197, 'A Vaca e o Frango S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181679.mp4', 'http://timg.bdta.pro/images/0dc50018851875f85b958ae9ade89b4c.jpg'),
(61948, 4197, 'A Vaca e o Frango S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181680.mp4', 'http://timg.bdta.pro/images/94e8255e7ac5b8ab8d0873589edf4e79.jpg'),
(61949, 4197, 'A Vaca e o Frango S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181681.mp4', 'http://timg.bdta.pro/images/d7ae0a98d9f311891f906616049f0a80.jpg'),
(61950, 4197, 'A Vaca e o Frango S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/181682.mp4', 'http://timg.bdta.pro/images/c555af50f9441127a196f34af7545201.jpg'),
(61951, 4197, 'A Vaca e o Frango S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/181683.mp4', 'http://timg.bdta.pro/images/de9f441918d45be485ffbfb58d887060.jpg'),
(61952, 4197, 'A Vaca e o Frango S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/181684.mp4', 'http://timg.bdta.pro/images/0113c6f901833ecc713481f7f7da5791.jpg'),
(61953, 4197, 'A Vaca e o Frango S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/181685.mp4', 'http://timg.bdta.pro/images/a89e4a371174c52acee03a9b60e7111a.jpg'),
(61954, 4198, 'A Vaca e o Frango S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181686.mp4', 'http://timg.bdta.pro/images/dc968759d426b177bbf19b7f936a9232.jpg'),
(61955, 4198, 'A Vaca e o Frango S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181687.mp4', 'http://timg.bdta.pro/images/c1a48bc8bdf03a8a014e631da1e0d71c.jpg'),
(61956, 4198, 'A Vaca e o Frango S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181688.mp4', 'http://timg.bdta.pro/images/060d81bec6be0a3c48b43d5c984d0389.jpg'),
(61957, 4198, 'A Vaca e o Frango S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181689.mp4', 'http://timg.bdta.pro/images/9c3d6a691fb145738acda4f744410a22.jpg'),
(61958, 4198, 'A Vaca e o Frango S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181690.mp4', 'http://timg.bdta.pro/images/21f6f49528dd7d60b0ba300ce30ca70d.jpg'),
(61959, 4198, 'A Vaca e o Frango S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181691.mp4', 'http://timg.bdta.pro/images/960c2853beaff3be7bd443c2ed839948.jpg'),
(61960, 4198, 'A Vaca e o Frango S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181692.mp4', 'http://timg.bdta.pro/images/2d1f89a117cc8fc8247a34e7c05a477a.jpg'),
(61961, 4198, 'A Vaca e o Frango S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181693.mp4', 'http://timg.bdta.pro/images/63c8525f3f48ed5498503537e8c032bd.jpg'),
(61962, 4198, 'A Vaca e o Frango S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181694.mp4', 'http://timg.bdta.pro/images/2cd3e030c182efd116529f1a6be90687.jpg'),
(61963, 4198, 'A Vaca e o Frango S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181695.mp4', 'http://timg.bdta.pro/images/c36f19d31da46ece41f5718261aaab42.jpg'),
(61964, 4198, 'A Vaca e o Frango S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/181696.mp4', 'http://timg.bdta.pro/images/db1ef3d97ba7fdfa73de048abf7bd6f5.jpg'),
(61965, 4198, 'A Vaca e o Frango S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/181697.mp4', 'http://timg.bdta.pro/images/545d73f2788b94e3d66c7965b24ddd61.jpg'),
(61966, 4199, 'He-Man e Os Defensores do Universo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151398.mp4', 'http://timg.bdta.pro/images/73765739acbbe9753069e5154d701a98.jpg'),
(61967, 4199, 'He-Man e Os Defensores do Universo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151399.mp4', 'http://timg.bdta.pro/images/31a5add81ad2301999abcf978283a190.jpg'),
(61968, 4199, 'He-Man e Os Defensores do Universo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151400.mp4', 'http://timg.bdta.pro/images/9763322371efa46b16b9d18146106027.jpg'),
(61969, 4199, 'He-Man e Os Defensores do Universo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151401.mp4', 'http://timg.bdta.pro/images/78ee8b71ed4781618a45d39fa077bcd2.jpg'),
(61970, 4199, 'He-Man e Os Defensores do Universo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151402.mp4', 'http://timg.bdta.pro/images/d7de5d63c461fa7c9fc780791e5ff9c3.jpg'),
(61971, 4199, 'He-Man e Os Defensores do Universo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151403.mp4', 'http://timg.bdta.pro/images/df454ab3aca9e34d2e16d6a0f2015013.jpg'),
(61972, 4199, 'He-Man e Os Defensores do Universo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151404.mp4', 'http://timg.bdta.pro/images/c1cd973435a356c232f17fad6ab4b36b.jpg'),
(61973, 4199, 'He-Man e Os Defensores do Universo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151405.mp4', 'http://timg.bdta.pro/images/ed965532413f4d177a16b0328b2a6ab7.jpg'),
(61974, 4199, 'He-Man e Os Defensores do Universo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151406.mp4', 'http://timg.bdta.pro/images/baffdd88babf418bcd666d4ca06d2e80.jpg'),
(61975, 4199, 'He-Man e Os Defensores do Universo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151407.mp4', 'http://timg.bdta.pro/images/ebccac690a66e07c7f19f0f950537d5c.jpg'),
(61976, 4199, 'He-Man e Os Defensores do Universo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151408.mp4', 'http://timg.bdta.pro/images/c00a6791fc64d54fb293a577aaa189fe.jpg'),
(61977, 4199, 'He-Man e Os Defensores do Universo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151409.mp4', 'http://timg.bdta.pro/images/ba2dca86aabf8dfac715733678c00416.jpg'),
(61978, 4199, 'He-Man e Os Defensores do Universo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151410.mp4', 'http://timg.bdta.pro/images/9697bfaa6722b3c0982ca57687ff8f8d.jpg'),
(61979, 4199, 'He-Man e Os Defensores do Universo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151411.mp4', 'http://timg.bdta.pro/images/3c4b9962e2615daf84d999b02e7d0d27.jpg'),
(61980, 4199, 'He-Man e Os Defensores do Universo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/151412.mp4', 'http://timg.bdta.pro/images/378d21a1e9facde29cfdc34aad2fc70c.jpg'),
(61981, 4199, 'He-Man e Os Defensores do Universo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/151413.mp4', 'http://timg.bdta.pro/images/95decdcf0c19c6cf97a67f36943d2842.jpg'),
(61982, 4199, 'He-Man e Os Defensores do Universo S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/151414.mp4', 'http://timg.bdta.pro/images/f246f18be9ed4a78a8e520f1faa194e3.jpg'),
(61983, 4199, 'He-Man e Os Defensores do Universo S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/151415.mp4', 'http://timg.bdta.pro/images/6ccc0068a1f374a4580f264cbd986608.jpg'),
(61984, 4199, 'He-Man e Os Defensores do Universo S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/151416.mp4', 'http://timg.bdta.pro/images/24839661cbe07df75e8fe9f6ad6802b6.jpg'),
(61985, 4199, 'He-Man e Os Defensores do Universo S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/151417.mp4', 'http://timg.bdta.pro/images/c0b30aef4fc7a885cbe7d885543e2007.jpg'),
(61986, 4199, 'He-Man e Os Defensores do Universo S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/151418.mp4', 'http://timg.bdta.pro/images/e7d1a74fde65d591ab82a29970828fe6.jpg'),
(61987, 4199, 'He-Man e Os Defensores do Universo S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/151419.mp4', 'http://timg.bdta.pro/images/0153119f1aaf61f31167949dbb898a66.jpg'),
(61988, 4199, 'He-Man e Os Defensores do Universo S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/151420.mp4', 'http://timg.bdta.pro/images/b9a91d92948d4602f8c0c0dc6dc2f21a.jpg'),
(61989, 4199, 'He-Man e Os Defensores do Universo S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/151421.mp4', 'http://timg.bdta.pro/images/e240afbf88ec2846384a0ae2b4e10b1b.jpg'),
(61990, 4199, 'He-Man e Os Defensores do Universo S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/151422.mp4', 'http://timg.bdta.pro/images/00acb8145a8fb5e2f58690f552fbc415.jpg'),
(61991, 4199, 'He-Man e Os Defensores do Universo S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/151423.mp4', 'http://timg.bdta.pro/images/cc48644ddd204790e9854c56c78abe9e.jpg'),
(61992, 4199, 'He-Man e Os Defensores do Universo S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/151424.mp4', 'http://timg.bdta.pro/images/8725ccb8aa06023f5220366559276e3f.jpg'),
(61993, 4199, 'He-Man e Os Defensores do Universo S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/151425.mp4', 'http://timg.bdta.pro/images/5abf29a27acb087858eddb1b211dcc61.jpg'),
(61994, 4199, 'He-Man e Os Defensores do Universo S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/151426.mp4', 'http://timg.bdta.pro/images/92f2ee5f61b96531a22c7c804359edde.jpg'),
(61995, 4199, 'He-Man e Os Defensores do Universo S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/151427.mp4', 'http://timg.bdta.pro/images/73461d7c0994207a8ff202efcc9260fd.jpg'),
(61996, 4199, 'He-Man e Os Defensores do Universo S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/151428.mp4', 'http://timg.bdta.pro/images/17ccb04a01f1c6dd1bb0eaf15c01fa0d.jpg'),
(61997, 4199, 'He-Man e Os Defensores do Universo S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/151429.mp4', 'http://timg.bdta.pro/images/8f75546ae3ec64d2ee340a8bebd75658.jpg'),
(61998, 4199, 'He-Man e Os Defensores do Universo S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/151430.mp4', 'http://timg.bdta.pro/images/e38dad624620aaa655a001e38a8ba707.jpg'),
(61999, 4199, 'He-Man e Os Defensores do Universo S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/151431.mp4', 'http://timg.bdta.pro/images/ee8c3eec96d3a49533c17a695e6124dc.jpg'),
(62000, 4199, 'He-Man e Os Defensores do Universo S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/151432.mp4', 'http://timg.bdta.pro/images/6b8a2e4f7eb34053c2025cce0847b075.jpg'),
(62001, 4199, 'He-Man e Os Defensores do Universo S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/151433.mp4', 'http://timg.bdta.pro/images/f82ea8933749c0c97fdde6fe67f1704b.jpg'),
(62002, 4199, 'He-Man e Os Defensores do Universo S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/151434.mp4', 'http://timg.bdta.pro/images/c04f885754d927fbac2125c6ad622c21.jpg'),
(62003, 4199, 'He-Man e Os Defensores do Universo S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/151435.mp4', 'http://timg.bdta.pro/images/4484877bf8c91fd9dbd255e5dd729479.jpg'),
(62004, 4199, 'He-Man e Os Defensores do Universo S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/151436.mp4', 'http://timg.bdta.pro/images/76ba61a13f8b5e62f1dd13f25e3d2a7d.jpg'),
(62005, 4199, 'He-Man e Os Defensores do Universo S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/151437.mp4', 'http://timg.bdta.pro/images/554f3cdc41b968abf7715d9888def7dd.jpg'),
(62006, 4199, 'He-Man e Os Defensores do Universo S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/151438.mp4', 'http://timg.bdta.pro/images/b5371035d0e0800a0c6f331389fb35e9.jpg'),
(62007, 4199, 'He-Man e Os Defensores do Universo S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/151439.mp4', 'http://timg.bdta.pro/images/95802ecebce08c28231feec83ef364cf.jpg'),
(62008, 4199, 'He-Man e Os Defensores do Universo S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/151440.mp4', 'http://timg.bdta.pro/images/134aac6a03aad9c724c21bafb51a0512.jpg'),
(62009, 4199, 'He-Man e Os Defensores do Universo S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/151441.mp4', 'http://timg.bdta.pro/images/a3666b061ccad331af0eebd0adaf3d2c.jpg'),
(62010, 4199, 'He-Man e Os Defensores do Universo S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/151442.mp4', 'http://timg.bdta.pro/images/d26d0973f9ed9e6ece28382f4cd3b8b1.jpg'),
(62011, 4199, 'He-Man e Os Defensores do Universo S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/151443.mp4', 'http://timg.bdta.pro/images/68e9a3272b19800d88ac9b648f1b26a5.jpg'),
(62012, 4199, 'He-Man e Os Defensores do Universo S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/151444.mp4', 'http://timg.bdta.pro/images/6c14533ee41e929d70aec73bb2457d19.jpg'),
(62013, 4199, 'He-Man e Os Defensores do Universo S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/151445.mp4', 'http://timg.bdta.pro/images/8f08f94225064df1cb422ae549a8a8b2.jpg'),
(62014, 4199, 'He-Man e Os Defensores do Universo S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/151446.mp4', 'http://timg.bdta.pro/images/ca2837670f608d4466ecd0f9d0031208.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(62015, 4199, 'He-Man e Os Defensores do Universo S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/151447.mp4', 'http://timg.bdta.pro/images/5fd2808c99a205a4cee4888fd751bca7.jpg'),
(62016, 4199, 'He-Man e Os Defensores do Universo S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/151448.mp4', 'http://timg.bdta.pro/images/2b30418597691f7115b6350235b3fc84.jpg'),
(62017, 4199, 'He-Man e Os Defensores do Universo S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/151449.mp4', 'http://timg.bdta.pro/images/a140dc2db5df04a8089399b803173e90.jpg'),
(62018, 4199, 'He-Man e Os Defensores do Universo S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/151450.mp4', 'http://timg.bdta.pro/images/f95f360498563e9659f53190a9e0efe5.jpg'),
(62019, 4199, 'He-Man e Os Defensores do Universo S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/151451.mp4', 'http://timg.bdta.pro/images/ab634ec57ccb2de74eb860bced2dda2f.jpg'),
(62020, 4199, 'He-Man e Os Defensores do Universo S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/151452.mp4', 'http://timg.bdta.pro/images/a4bc6222c819f8d0d9f0c95d32c228c5.jpg'),
(62021, 4199, 'He-Man e Os Defensores do Universo S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/151453.mp4', 'http://timg.bdta.pro/images/369602e2312ee4c2a4956f65a5bcc992.jpg'),
(62022, 4199, 'He-Man e Os Defensores do Universo S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/151454.mp4', 'http://timg.bdta.pro/images/f7aca5bd8177d3b0d21b1647ca34fe38.jpg'),
(62023, 4199, 'He-Man e Os Defensores do Universo S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/151455.mp4', 'http://timg.bdta.pro/images/049461ceb22599d6c2316ed3eb1d98e4.jpg'),
(62024, 4199, 'He-Man e Os Defensores do Universo S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/151456.mp4', 'http://timg.bdta.pro/images/83561e9b8f445104c518cf0fa33e9b50.jpg'),
(62025, 4199, 'He-Man e Os Defensores do Universo S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/151457.mp4', 'http://timg.bdta.pro/images/3765918419535fad296f661131f06463.jpg'),
(62026, 4199, 'He-Man e Os Defensores do Universo S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/151458.mp4', 'http://timg.bdta.pro/images/1ab878cd8f0b96aef576c1ba13282a6b.jpg'),
(62027, 4199, 'He-Man e Os Defensores do Universo S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/151459.mp4', 'http://timg.bdta.pro/images/c5ae1e6bdd1e4b50cab74d405a83d57f.jpg'),
(62028, 4199, 'He-Man e Os Defensores do Universo S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/151460.mp4', 'http://timg.bdta.pro/images/be09c428a750ad084185db08e0b10aaf.jpg'),
(62029, 4199, 'He-Man e Os Defensores do Universo S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/151461.mp4', 'http://timg.bdta.pro/images/2e3bb43d2c8349550eb485fc06e87613.jpg'),
(62030, 4199, 'He-Man e Os Defensores do Universo S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/151462.mp4', 'http://timg.bdta.pro/images/678156b7acceb5b337ebc2fe90570973.jpg'),
(62031, 4200, 'He-Man e Os Defensores do Universo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151463.mp4', 'http://timg.bdta.pro/images/e1d684ab295c6ed540dbb7a9f8ea72c4.jpg'),
(62032, 4200, 'He-Man e Os Defensores do Universo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151464.mp4', 'http://timg.bdta.pro/images/08c48a32bb50d853213d219e96ad342a.jpg'),
(62033, 4200, 'He-Man e Os Defensores do Universo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151465.mp4', 'http://timg.bdta.pro/images/94fb79e39614c688bd1ece8220995177.jpg'),
(62034, 4200, 'He-Man e Os Defensores do Universo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151466.mp4', 'http://timg.bdta.pro/images/f57692f9cc653c93290dba4f7987c7c7.jpg'),
(62035, 4200, 'He-Man e Os Defensores do Universo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151467.mp4', 'http://timg.bdta.pro/images/8b4599ca75d73b869ad69f98bd240dd3.jpg'),
(62036, 4200, 'He-Man e Os Defensores do Universo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151468.mp4', 'http://timg.bdta.pro/images/2c02d1b10d2e8a1b48a2d8cdd687e58b.jpg'),
(62037, 4200, 'He-Man e Os Defensores do Universo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151469.mp4', 'http://timg.bdta.pro/images/b3619bd99ffa5739849bc3166d3d02aa.jpg'),
(62038, 4200, 'He-Man e Os Defensores do Universo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151470.mp4', 'http://timg.bdta.pro/images/b959e0bc87e1745fed1084e35225d893.jpg'),
(62039, 4200, 'He-Man e Os Defensores do Universo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151471.mp4', 'http://timg.bdta.pro/images/d503586c95544cda7981e2a275830330.jpg'),
(62040, 4200, 'He-Man e Os Defensores do Universo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151472.mp4', 'http://timg.bdta.pro/images/be37b2596de7e5e34919e7de9204c53b.jpg'),
(62041, 4200, 'He-Man e Os Defensores do Universo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151473.mp4', 'http://timg.bdta.pro/images/acaabb076f41cf3436e19b95e87abe11.jpg'),
(62042, 4200, 'He-Man e Os Defensores do Universo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151474.mp4', 'http://timg.bdta.pro/images/05ede243794475577d7845dc38496be1.jpg'),
(62043, 4200, 'He-Man e Os Defensores do Universo S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151475.mp4', 'http://timg.bdta.pro/images/fa32a0ddd8c16845c47eb36ec092f49d.jpg'),
(62044, 4200, 'He-Man e Os Defensores do Universo S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151476.mp4', 'http://timg.bdta.pro/images/5f1788ebbf71bc43f7827257a11c1358.jpg'),
(62045, 4200, 'He-Man e Os Defensores do Universo S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/151477.mp4', 'http://timg.bdta.pro/images/3b3735a4f0387f3e568bfb05576409d7.jpg'),
(62046, 4200, 'He-Man e Os Defensores do Universo S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/151478.mp4', 'http://timg.bdta.pro/images/ddbef5395769ab2e074ed427eebdbf63.jpg'),
(62047, 4200, 'He-Man e Os Defensores do Universo S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/151479.mp4', 'http://timg.bdta.pro/images/47fc3132d4914464f2e4febe3a2a67c2.jpg'),
(62048, 4200, 'He-Man e Os Defensores do Universo S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/151480.mp4', 'http://timg.bdta.pro/images/b8bf26473482ec5ee686dce939bf2298.jpg'),
(62049, 4200, 'He-Man e Os Defensores do Universo S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/151481.mp4', 'http://timg.bdta.pro/images/7444d20de368f5d0f581b263eb4c43bf.jpg'),
(62050, 4200, 'He-Man e Os Defensores do Universo S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/151482.mp4', 'http://timg.bdta.pro/images/00c9dae06e01313e10fc90507d054c37.jpg'),
(62051, 4200, 'He-Man e Os Defensores do Universo S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/151483.mp4', 'http://timg.bdta.pro/images/5d063be7ab72411a4bf4e9b6875f449a.jpg'),
(62052, 4200, 'He-Man e Os Defensores do Universo S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/151484.mp4', 'http://timg.bdta.pro/images/45090e06ff635be9caca4a10f822b816.jpg'),
(62053, 4200, 'He-Man e Os Defensores do Universo S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/151485.mp4', 'http://timg.bdta.pro/images/9fc4bf2a5b53280ab6baa4369a7f4864.jpg'),
(62054, 4200, 'He-Man e Os Defensores do Universo S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/151486.mp4', 'http://timg.bdta.pro/images/c275026ed3cf9f2eb5e2275edce3ded2.jpg'),
(62055, 4200, 'He-Man e Os Defensores do Universo S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/151487.mp4', 'http://timg.bdta.pro/images/2ed07fbe8d8150fb5ae2ce97a419d4ed.jpg'),
(62056, 4200, 'He-Man e Os Defensores do Universo S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/151488.mp4', 'http://timg.bdta.pro/images/760d58de3e8e7ce519762985ed0fd134.jpg'),
(62057, 4200, 'He-Man e Os Defensores do Universo S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/151489.mp4', 'http://timg.bdta.pro/images/6c21da26664b991dc1189399a9e05220.jpg'),
(62058, 4200, 'He-Man e Os Defensores do Universo S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/151490.mp4', 'http://timg.bdta.pro/images/e867408e5e5cc13fa61eddf3de1f1f9d.jpg'),
(62059, 4200, 'He-Man e Os Defensores do Universo S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/151491.mp4', 'http://timg.bdta.pro/images/5eace29cd1df7328aa5b4f29654370ca.jpg'),
(62060, 4200, 'He-Man e Os Defensores do Universo S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/151492.mp4', 'http://timg.bdta.pro/images/ca7b656da4de5683673ac6d134d344b6.jpg'),
(62061, 4200, 'He-Man e Os Defensores do Universo S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/151493.mp4', 'http://timg.bdta.pro/images/ebc0c9b2960245cad687e25c162a728f.jpg'),
(62062, 4200, 'He-Man e Os Defensores do Universo S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/151494.mp4', 'http://timg.bdta.pro/images/db306d8f55f5175fb66bb782108e6702.jpg'),
(62063, 4200, 'He-Man e Os Defensores do Universo S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/151495.mp4', 'http://timg.bdta.pro/images/b1235d4a3d230a0d59781051d847d2db.jpg'),
(62064, 4200, 'He-Man e Os Defensores do Universo S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/151496.mp4', 'http://timg.bdta.pro/images/adddbbe83e34e7ab55cb619f45026eeb.jpg'),
(62065, 4200, 'He-Man e Os Defensores do Universo S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/151497.mp4', 'http://timg.bdta.pro/images/7db79cbe1ad4179a245bfcc48db5f201.jpg'),
(62066, 4200, 'He-Man e Os Defensores do Universo S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/151498.mp4', 'http://timg.bdta.pro/images/b4accc2d7b1fae88a647effdf70cd423.jpg'),
(62067, 4200, 'He-Man e Os Defensores do Universo S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/151499.mp4', 'http://timg.bdta.pro/images/2581ee1d738ec2580af5272ea3b7a774.jpg'),
(62068, 4200, 'He-Man e Os Defensores do Universo S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/151500.mp4', 'http://timg.bdta.pro/images/fc3440605f27e6fda8eac838b704e52d.jpg'),
(62069, 4200, 'He-Man e Os Defensores do Universo S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/151501.mp4', 'http://timg.bdta.pro/images/53a3450bc0fd361908e1ca329ac31827.jpg'),
(62070, 4200, 'He-Man e Os Defensores do Universo S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/151502.mp4', 'http://timg.bdta.pro/images/e48bbead986671939c86de637d4a0865.jpg'),
(62071, 4200, 'He-Man e Os Defensores do Universo S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/151503.mp4', 'http://timg.bdta.pro/images/c7d3216d89f3ba26137669dbc6df708e.jpg'),
(62072, 4200, 'He-Man e Os Defensores do Universo S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/151504.mp4', 'http://timg.bdta.pro/images/ea1f089a95739d2afd1087239110c64b.jpg'),
(62073, 4200, 'He-Man e Os Defensores do Universo S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/151505.mp4', 'http://timg.bdta.pro/images/3f41136e910b0a1f26c79c29590c2fd1.jpg'),
(62074, 4200, 'He-Man e Os Defensores do Universo S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/151506.mp4', 'http://timg.bdta.pro/images/1fcbbdc5662553a5c930eb4b709da8d3.jpg'),
(62075, 4200, 'He-Man e Os Defensores do Universo S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/151507.mp4', 'http://timg.bdta.pro/images/11558a99af04d89140b308adf1411146.jpg'),
(62076, 4200, 'He-Man e Os Defensores do Universo S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/151508.mp4', 'http://timg.bdta.pro/images/4af2493e58dbe894af2d3918b40b9094.jpg'),
(62077, 4200, 'He-Man e Os Defensores do Universo S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/151509.mp4', 'http://timg.bdta.pro/images/4ebbe0854566338c999bfe004197b60f.jpg'),
(62078, 4200, 'He-Man e Os Defensores do Universo S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/151510.mp4', 'http://timg.bdta.pro/images/589cf31ebb13e231b674708166bb2bfb.jpg'),
(62079, 4200, 'He-Man e Os Defensores do Universo S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/151511.mp4', 'http://timg.bdta.pro/images/b60b23a3dbeefbd8aa5891d64157013e.jpg'),
(62080, 4200, 'He-Man e Os Defensores do Universo S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/151512.mp4', 'http://timg.bdta.pro/images/2a650e18ba174c524f9a1b10ded1846c.jpg'),
(62081, 4200, 'He-Man e Os Defensores do Universo S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/151513.mp4', 'http://timg.bdta.pro/images/05cd3b7acdafdf14b28908b8b871295d.jpg'),
(62082, 4200, 'He-Man e Os Defensores do Universo S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/151514.mp4', 'http://timg.bdta.pro/images/66b476737172cdb6abd8e12e669626ab.jpg'),
(62083, 4200, 'He-Man e Os Defensores do Universo S02 E53', 'http://sinalprivado.info:80/series/1533784/1533784/151515.mp4', 'http://timg.bdta.pro/images/59fbf6741bb8c0af32ca95bce9cd034c.jpg'),
(62084, 4200, 'He-Man e Os Defensores do Universo S02 E54', 'http://sinalprivado.info:80/series/1533784/1533784/151516.mp4', 'http://timg.bdta.pro/images/120a3365f8f52598c971d1fd90d00444.jpg'),
(62085, 4200, 'He-Man e Os Defensores do Universo S02 E55', 'http://sinalprivado.info:80/series/1533784/1533784/151517.mp4', 'http://timg.bdta.pro/images/15e9c0ed51791a13f40bbb89259901a8.jpg'),
(62086, 4200, 'He-Man e Os Defensores do Universo S02 E56', 'http://sinalprivado.info:80/series/1533784/1533784/151518.mp4', 'http://timg.bdta.pro/images/eb531fb3c1e6332e24caa53554fae5c7.jpg'),
(62087, 4200, 'He-Man e Os Defensores do Universo S02 E57', 'http://sinalprivado.info:80/series/1533784/1533784/151519.mp4', 'http://timg.bdta.pro/images/217ff865eade924e09892ee13cc37d76.jpg'),
(62088, 4200, 'He-Man e Os Defensores do Universo S02 E58', 'http://sinalprivado.info:80/series/1533784/1533784/151520.mp4', 'http://timg.bdta.pro/images/7323b63c4837ba9351027fbda983c5ff.jpg'),
(62089, 4200, 'He-Man e Os Defensores do Universo S02 E59', 'http://sinalprivado.info:80/series/1533784/1533784/151521.mp4', 'http://timg.bdta.pro/images/ab6bf48c354353f99a1195776b4dfdee.jpg'),
(62090, 4200, 'He-Man e Os Defensores do Universo S02 E60', 'http://sinalprivado.info:80/series/1533784/1533784/151522.mp4', 'http://timg.bdta.pro/images/a9f72e7383e6bd2cbc56be24a2ef4425.jpg'),
(62091, 4200, 'He-Man e Os Defensores do Universo S02 E61', 'http://sinalprivado.info:80/series/1533784/1533784/151523.mp4', 'http://timg.bdta.pro/images/bdc88d12c11a3d8eaadfc1b912656827.jpg'),
(62092, 4200, 'He-Man e Os Defensores do Universo S02 E62', 'http://sinalprivado.info:80/series/1533784/1533784/151524.mp4', 'http://timg.bdta.pro/images/f3139060ba75c7ff4a706c6f8a5c158f.jpg'),
(62093, 4200, 'He-Man e Os Defensores do Universo S02 E63', 'http://sinalprivado.info:80/series/1533784/1533784/151525.mp4', 'http://timg.bdta.pro/images/5ba017d27a547aa22ac43e0ea58bf3fd.jpg'),
(62094, 4200, 'He-Man e Os Defensores do Universo S02 E64', 'http://sinalprivado.info:80/series/1533784/1533784/151526.mp4', 'http://timg.bdta.pro/images/03ad33b0f68d86d805f5ed6a3004347f.jpg'),
(62095, 4200, 'He-Man e Os Defensores do Universo S02 E65', 'http://sinalprivado.info:80/series/1533784/1533784/151527.mp4', 'http://timg.bdta.pro/images/0c70a8cae9c76b08fc6ddb520ce1defe.jpg'),
(62096, 4201, 'High School Musical: A Série: O Musical S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230208.mp4', 'http://timg.bdta.pro/images/0aeca558b5fa7e4c693063896c7ae94d.jpg'),
(62097, 4201, 'High School Musical: A Série: O Musical S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230209.mp4', 'http://timg.bdta.pro/images/26feffa703195c62f07d2322b0d8603e.jpg'),
(62098, 4201, 'High School Musical: A Série: O Musical S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230210.mp4', 'http://timg.bdta.pro/images/c36a036046a08c4f3d5869cbb7c4d3e7.jpg'),
(62099, 4201, 'High School Musical: A Série: O Musical S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230211.mp4', 'http://timg.bdta.pro/images/684f5635c9b57790daffa5b9d3e2dca5.jpg'),
(62100, 4201, 'High School Musical: A Série: O Musical S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230212.mp4', 'http://timg.bdta.pro/images/6fcc8a15a6a79c7b711d9804f8b1ac83.jpg'),
(62101, 4201, 'High School Musical: A Série: O Musical S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230213.mp4', 'http://timg.bdta.pro/images/339ea8868af1a4ef6ce5fa02948a2537.jpg'),
(62102, 4201, 'High School Musical: A Série: O Musical S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230214.mp4', 'http://timg.bdta.pro/images/7c2947e9c9a1406da1fa3d3faec82619.jpg'),
(62103, 4201, 'High School Musical: A Série: O Musical S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230215.mp4', 'http://timg.bdta.pro/images/710afccc34a738095c7548e0deeb5aed.jpg'),
(62104, 4201, 'High School Musical: A Série: O Musical S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230216.mp4', 'http://timg.bdta.pro/images/f5211edc7bdebebd53a8d40bca52c6a9.jpg'),
(62105, 4201, 'High School Musical: A Série: O Musical S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230217.mp4', 'http://timg.bdta.pro/images/f95e8c7a58ce710e8cce4a65c950ad6d.jpg'),
(62106, 4202, 'High School Musical: A Série: O Musical S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230218.mp4', 'http://timg.bdta.pro/images/55412055791ec1704d59c2eee8de2ed4.jpg'),
(62107, 4202, 'High School Musical: A Série: O Musical S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230219.mp4', 'http://timg.bdta.pro/images/77cfb7c3675f534f5c3a2a56e17132b9.jpg'),
(62108, 4202, 'High School Musical: A Série: O Musical S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230220.mp4', 'http://timg.bdta.pro/images/5e8f60823d0da8e9dc52ced6732ec477.jpg'),
(62109, 4202, 'High School Musical: A Série: O Musical S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230221.mp4', 'http://timg.bdta.pro/images/6fb4030fc33267c4f22eb7988d8c6412.jpg'),
(62110, 4202, 'High School Musical: A Série: O Musical S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230222.mp4', 'http://timg.bdta.pro/images/f7762a533ad75d8dac2fdb974db6a7ca.jpg'),
(62111, 4202, 'High School Musical: A Série: O Musical S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230223.mp4', 'http://timg.bdta.pro/images/211ce94e1555079b66586f178d4dc493.jpg'),
(62112, 4202, 'High School Musical: A Série: O Musical S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230224.mp4', 'http://timg.bdta.pro/images/170a9ad88ae40333719eaefea9a59a56.jpg'),
(62113, 4202, 'High School Musical: A Série: O Musical S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230225.mp4', 'http://timg.bdta.pro/images/4994b30bcf0241367379d9b40f5cf636.jpg'),
(62114, 4202, 'High School Musical: A Série: O Musical S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230226.mp4', 'http://timg.bdta.pro/images/855f9df99c5bf0ce80abaa85365b6a0f.jpg'),
(62115, 4202, 'High School Musical: A Série: O Musical S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230227.mp4', 'http://timg.bdta.pro/images/88a1933469b6fb080c74059db27f158b.jpg'),
(62116, 4202, 'High School Musical: A Série: O Musical S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230228.mp4', 'http://timg.bdta.pro/images/8b3ca44dc64f03ee8f0a693255ec29f7.jpg'),
(62117, 4202, 'High School Musical: A Série: O Musical S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230229.mp4', 'http://timg.bdta.pro/images/5f9fbda2af83a60bbb952f6f6604c2ce.jpg'),
(62118, 4203, 'High School Musical: A Série: O Musical S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ghBPTsoUvbYRLCtf1Zr622HTFcL.jpg'),
(62119, 4203, 'High School Musical: A Série: O Musical S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wvMLWeDs2RmgOz4QPo4Y5Nyk5xX.jpg'),
(62120, 4203, 'High School Musical: A Série: O Musical S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1JrXbJTCOwArq4lG7B0Gf0dGttS.jpg'),
(62121, 4203, 'High School Musical: A Série: O Musical S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ieQigsKYIzbGmDVnlA2GjMZxKD.jpg'),
(62122, 4203, 'High School Musical: A Série: O Musical S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ryGphQQSlYXktxraDUYnWHrEHeb.jpg'),
(62123, 4203, 'High School Musical: A Série: O Musical S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ohDFfJU5E20oMDeXRO0vEVD9ZDo.jpg'),
(62124, 4203, 'High School Musical: A Série: O Musical S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rRBzdWSt8uCdJ66kq5AYcXnEkKh.jpg'),
(62125, 4203, 'High School Musical: A Série: O Musical S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgKKWPQMa5hvH4T7t3TvGC0Mg4U.jpg'),
(62126, 4204, 'High School Musical: A Série: O Musical S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yLEfVBJAsOloN0SwfvFxCV0J9mS.jpg'),
(62127, 4204, 'High School Musical: A Série: O Musical S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u2PqnNXHGAGTRxXYiSYNi1PfkHF.jpg'),
(62128, 4204, 'High School Musical: A Série: O Musical S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zkjJ55Xa54s4YcXSyhtRk0o7PG1.jpg'),
(62129, 4204, 'High School Musical: A Série: O Musical S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a8d8kSQHymKXT1k4E6DY0qiA3no.jpg'),
(62130, 4204, 'High School Musical: A Série: O Musical S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uF5aXTu4EFMgWgpe4HpOkLNA3Nl.jpg'),
(62131, 4204, 'High School Musical: A Série: O Musical S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdHaxpkne8Nj09vtoSnYCAFXwYI.jpg'),
(62132, 4204, 'High School Musical: A Série: O Musical S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yesPXOCfAhcpwzIh7QzxXu3MRIF.jpg'),
(62133, 4204, 'High School Musical: A Série: O Musical S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/or8rc8eKgnXAUcMZaC6qbczgF9w.jpg'),
(62134, 4205, 'Krypton S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151378.mp4', 'http://timg.bdta.pro/images/4116189999bdfaf5536bdc068a6ffc8f.jpg'),
(62135, 4205, 'Krypton S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151379.mp4', 'http://timg.bdta.pro/images/14d0726395082a13e4838801a779df21.jpg'),
(62136, 4205, 'Krypton S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151380.mp4', 'http://timg.bdta.pro/images/f75f2c3535a99d91b0a9e11af017ca85.jpg'),
(62137, 4205, 'Krypton S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151381.mp4', 'http://timg.bdta.pro/images/7953c875d2105275214a2a7633084335.jpg'),
(62138, 4205, 'Krypton S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151382.mp4', 'http://timg.bdta.pro/images/beba98590c0ba288cbda36be5fb51f91.jpg'),
(62139, 4205, 'Krypton S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151383.mp4', 'http://timg.bdta.pro/images/4b88b44792c94f27e6a5eda7b7f591f6.jpg'),
(62140, 4205, 'Krypton S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151384.mp4', 'http://timg.bdta.pro/images/5c3a1e13868b8bfbded63a329d7b7d32.jpg'),
(62141, 4205, 'Krypton S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151385.mp4', 'http://timg.bdta.pro/images/f225dac7ceb4ca570d59c0b251a67b58.jpg'),
(62142, 4205, 'Krypton S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151386.mp4', 'http://timg.bdta.pro/images/75a5d1d8332bfa42fccdf359d2ec963e.jpg'),
(62143, 4205, 'Krypton S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151387.mp4', 'http://timg.bdta.pro/images/dd8db0493f9d483d1c5e7220a5d2a305.jpg'),
(62144, 4206, 'Krypton S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151388.mp4', 'http://timg.bdta.pro/images/4b2f554fa951e790a0827db83a47049d.jpg'),
(62145, 4206, 'Krypton S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151389.mp4', 'http://timg.bdta.pro/images/4a2c2bd8e7ea7118bd70e3ac6fcc6862.jpg'),
(62146, 4206, 'Krypton S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151390.mp4', 'http://timg.bdta.pro/images/57ea1206d04be6ab3f5c837b35d3b4f0.jpg'),
(62147, 4206, 'Krypton S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151391.mp4', 'http://timg.bdta.pro/images/4d771afad1667097e383e8a07f24d97d.jpg'),
(62148, 4206, 'Krypton S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151392.mp4', 'http://timg.bdta.pro/images/c1c0d585284e02a2e66358039414d5ad.jpg'),
(62149, 4206, 'Krypton S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151393.mp4', 'http://timg.bdta.pro/images/ae7235f282e540a73f15806c46b2bbf4.jpg'),
(62150, 4206, 'Krypton S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151394.mp4', 'http://timg.bdta.pro/images/f266c2ddd0bc62ac4e1a647045a3fdd6.jpg'),
(62151, 4206, 'Krypton S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151395.mp4', 'http://timg.bdta.pro/images/ed30f5942bd1b224fe0fc490673b015a.jpg'),
(62152, 4206, 'Krypton S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151396.mp4', 'http://timg.bdta.pro/images/ebc7f8b41d835afbbf415e6caef53514.jpg'),
(62153, 4206, 'Krypton S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151397.mp4', 'http://timg.bdta.pro/images/f13d8ed2de356ad396483fd9acfbee06.jpg'),
(62154, 4207, 'Mito e Magnata: John Delorean S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151375.mp4', 'http://gstaticontent.com/images/456cf987b0c145224ba8ecf5e36eae26.jpg'),
(62155, 4207, 'Mito e Magnata: John Delorean S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151376.mp4', 'http://gstaticontent.com/images/456cf987b0c145224ba8ecf5e36eae26.jpg'),
(62156, 4207, 'Mito e Magnata: John Delorean S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151377.mp4', 'http://gstaticontent.com/images/456cf987b0c145224ba8ecf5e36eae26.jpg'),
(62157, 4208, 'O Mundo dos Centauros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151365.mp4', 'http://timg.bdta.pro/images/876861f1e3c0891af29aa5516dea775d.jpg'),
(62158, 4208, 'O Mundo dos Centauros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151366.mp4', 'http://timg.bdta.pro/images/2a134b5e6f893465b103ccf09d93371b.jpg'),
(62159, 4208, 'O Mundo dos Centauros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151367.mp4', 'http://timg.bdta.pro/images/5e388413958673795037d89253dbd6ab.jpg'),
(62160, 4208, 'O Mundo dos Centauros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151368.mp4', 'http://timg.bdta.pro/images/5e2206f723c242b3bf831e2bddbbd653.jpg'),
(62161, 4208, 'O Mundo dos Centauros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151369.mp4', 'http://timg.bdta.pro/images/08f6e29cc1865c599c504807c143dbdd.jpg'),
(62162, 4208, 'O Mundo dos Centauros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151370.mp4', 'http://timg.bdta.pro/images/1e7eb5ea15e5c0beb9f670ef9304bc2c.jpg'),
(62163, 4208, 'O Mundo dos Centauros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151371.mp4', 'http://timg.bdta.pro/images/8e8da05048cc2742527b33452005373c.jpg'),
(62164, 4208, 'O Mundo dos Centauros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151372.mp4', 'http://timg.bdta.pro/images/f5962e7bd9368f186fc9957d170f01e6.jpg'),
(62165, 4208, 'O Mundo dos Centauros S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151373.mp4', 'http://timg.bdta.pro/images/86fa1ceb9069c53ff3be9a52c8ce96ec.jpg'),
(62166, 4208, 'O Mundo dos Centauros S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151374.mp4', 'http://timg.bdta.pro/images/76a3a0b322c163576c8ed7c45a715439.jpg'),
(62167, 4209, 'Outer Banks S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209387.mp4', 'http://timg.bdta.pro/images/60a94b9ec2302072921c5798345158ce.jpg'),
(62168, 4209, 'Outer Banks S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209388.mp4', 'http://timg.bdta.pro/images/7498749be4380edec47f2cb9de34b6e9.jpg'),
(62169, 4209, 'Outer Banks S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209389.mp4', 'http://timg.bdta.pro/images/3b9a10fad29a1f68eac728c8a02e0b3d.jpg'),
(62170, 4209, 'Outer Banks S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209390.mp4', 'http://timg.bdta.pro/images/33f93524d53c19a0f320534d416583f7.jpg'),
(62171, 4209, 'Outer Banks S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209391.mp4', 'http://timg.bdta.pro/images/37dc69d30ed176b61cdc85d2515ad4c5.jpg'),
(62172, 4209, 'Outer Banks S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209392.mp4', 'http://timg.bdta.pro/images/089c66df83570aeb3cb49630712eda3b.jpg'),
(62173, 4209, 'Outer Banks S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209393.mp4', 'http://timg.bdta.pro/images/d203df3391b3b3da8ffb804235743ee1.jpg'),
(62174, 4209, 'Outer Banks S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209394.mp4', 'http://timg.bdta.pro/images/250b3ffcdf8cfd289045f71412e657a4.jpg'),
(62175, 4209, 'Outer Banks S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209395.mp4', 'http://timg.bdta.pro/images/1192f12917f9a266997d8106342e50d9.jpg'),
(62176, 4209, 'Outer Banks S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209396.mp4', 'http://timg.bdta.pro/images/586bf65b79078343f4f66b55d534f60f.jpg'),
(62177, 4210, 'Outer Banks S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209397.mp4', 'http://timg.bdta.pro/images/ce25e77bebeff5140febc876686cf746.jpg'),
(62178, 4210, 'Outer Banks S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209398.mp4', 'http://timg.bdta.pro/images/074509e0a823c2b5f590105717106cc9.jpg'),
(62179, 4210, 'Outer Banks S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209399.mp4', 'http://timg.bdta.pro/images/8799e829d1e2f9e3b73ffec024875f5e.jpg'),
(62180, 4210, 'Outer Banks S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209400.mp4', 'http://timg.bdta.pro/images/b380c5d0f9ce0ef41cf949c9170e0c2f.jpg'),
(62181, 4210, 'Outer Banks S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209401.mp4', 'http://timg.bdta.pro/images/a90b69999ba9bbdd4a9f5712935f7e6a.jpg'),
(62182, 4210, 'Outer Banks S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209402.mp4', 'http://timg.bdta.pro/images/a82ca953071f9067382f7f1634e943b1.jpg'),
(62183, 4210, 'Outer Banks S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209403.mp4', 'http://timg.bdta.pro/images/d0692551e882ae2c41b06d8109518192.jpg'),
(62184, 4210, 'Outer Banks S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209404.mp4', 'http://timg.bdta.pro/images/00b059507f10f7f376e08ffda5f25a81.jpg'),
(62185, 4210, 'Outer Banks S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209405.mp4', 'http://timg.bdta.pro/images/a84a350998e9df7b817fe7369281287b.jpg'),
(62186, 4210, 'Outer Banks S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209406.mp4', 'http://timg.bdta.pro/images/9739aa5611a5532dca5dc1b9fe8d5f0f.jpg'),
(62187, 4211, 'Outer Banks S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8inkYcMEFX8rpzhLu3AMDjThSlT.jpg'),
(62188, 4211, 'Outer Banks S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eTLpcjcXRUnXWq4gn2d76BzjMOB.jpg'),
(62189, 4211, 'Outer Banks S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pUYCZLm09aLpTTAQlwuymr7oTzu.jpg'),
(62190, 4211, 'Outer Banks S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/esdTfiSe4FaRiScrZeCKDve1rU4.jpg'),
(62191, 4211, 'Outer Banks S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iLHH5wuyRbxoPyeuvdQsKcEdZQG.jpg'),
(62192, 4211, 'Outer Banks S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/luiMCVcWbw3I6t4anlIH35R7TdE.jpg'),
(62193, 4211, 'Outer Banks S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/imH8pCs7aggJ9ntwDFkZbjVvDBm.jpg'),
(62194, 4211, 'Outer Banks S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPHER8KeV4LTaGkUw8iA4hZ1f09.jpg'),
(62195, 4211, 'Outer Banks S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ZeroNvasld2WpyqXOWJVb3Wgew.jpg'),
(62196, 4211, 'Outer Banks S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Ri5hwieS1bxtiUVcqrlpY816XX.jpg'),
(62197, 4212, 'Outer Banks S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486824.mp4', 'http://gstaticontent.com/images/87f2eb5a5c1a0ec935cac912052d2bdc.jpg'),
(62198, 4212, 'Outer Banks S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486825.mp4', 'http://gstaticontent.com/images/87f2eb5a5c1a0ec935cac912052d2bdc.jpg'),
(62199, 4212, 'Outer Banks S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486826.mp4', 'http://gstaticontent.com/images/87f2eb5a5c1a0ec935cac912052d2bdc.jpg'),
(62200, 4212, 'Outer Banks S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486827.mp4', 'http://gstaticontent.com/images/87f2eb5a5c1a0ec935cac912052d2bdc.jpg'),
(62201, 4212, 'Outer Banks S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486828.mp4', 'http://gstaticontent.com/images/87f2eb5a5c1a0ec935cac912052d2bdc.jpg'),
(62202, 4212, 'Outer Banks S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/507610.mp4', 'http://gstaticontent.com/images/87f2eb5a5c1a0ec935cac912052d2bdc.jpg'),
(62203, 4212, 'Outer Banks S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/507611.mp4', 'http://gstaticontent.com/images/87f2eb5a5c1a0ec935cac912052d2bdc.jpg'),
(62204, 4212, 'Outer Banks S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/507612.mp4', 'http://gstaticontent.com/images/87f2eb5a5c1a0ec935cac912052d2bdc.jpg'),
(62205, 4212, 'Outer Banks S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/507613.mp4', 'http://gstaticontent.com/images/87f2eb5a5c1a0ec935cac912052d2bdc.jpg'),
(62206, 4212, 'Outer Banks S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/507614.mp4', 'http://gstaticontent.com/images/87f2eb5a5c1a0ec935cac912052d2bdc.jpg'),
(62207, 4213, 'Starstruck S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238602.mp4', 'http://timg.bdta.pro/images/f75279c84156c8941d0f861fa1e08bb3.jpg'),
(62208, 4213, 'Starstruck S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238603.mp4', 'http://timg.bdta.pro/images/deab090de999d9e5002ebbde94d96fc7.jpg'),
(62209, 4213, 'Starstruck S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238604.mp4', 'http://timg.bdta.pro/images/fda6536fd184ea87e640a9732bc34569.jpg'),
(62210, 4213, 'Starstruck S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238605.mp4', 'http://timg.bdta.pro/images/dbf516724a295957e841e4b04d609dab.jpg'),
(62211, 4213, 'Starstruck S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238606.mp4', 'http://timg.bdta.pro/images/1a8da75e3fecb492ec3867d25b2d5433.jpg'),
(62212, 4213, 'Starstruck S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238607.mp4', 'http://timg.bdta.pro/images/146a64908a309065dd1c938fd7a003f7.jpg'),
(62213, 4214, 'Starstruck S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238608.mp4', 'http://timg.bdta.pro/images/ea57d25f5fe54773434b73af5c1d4ee5.jpg'),
(62214, 4214, 'Starstruck S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238609.mp4', 'http://timg.bdta.pro/images/95b487ca82a155b67444681b27e5a5f6.jpg'),
(62215, 4214, 'Starstruck S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238610.mp4', 'http://timg.bdta.pro/images/5e4c9bb7d7021fd837ed86d400deaf7c.jpg'),
(62216, 4214, 'Starstruck S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238611.mp4', 'http://timg.bdta.pro/images/c3a72cd01f73a88ef8ea3873e04a5a76.jpg'),
(62217, 4214, 'Starstruck S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238612.mp4', 'http://timg.bdta.pro/images/0caebea698655cf03f3fe93fc0e423f0.jpg'),
(62218, 4214, 'Starstruck S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238613.mp4', 'http://timg.bdta.pro/images/dac0c41cfc39c9569234ac3795d3b199.jpg'),
(62219, 4215, 'Starstruck S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238614.mp4', 'http://gstaticontent.com/images/bcfe0d85ce08f0d9702e68cce95d43cb.jpg'),
(62220, 4215, 'Starstruck S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238615.mp4', 'http://gstaticontent.com/images/bcfe0d85ce08f0d9702e68cce95d43cb.jpg'),
(62221, 4215, 'Starstruck S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238616.mp4', 'http://gstaticontent.com/images/bcfe0d85ce08f0d9702e68cce95d43cb.jpg'),
(62222, 4215, 'Starstruck S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238617.mp4', 'http://gstaticontent.com/images/bcfe0d85ce08f0d9702e68cce95d43cb.jpg'),
(62223, 4215, 'Starstruck S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238618.mp4', 'http://gstaticontent.com/images/bcfe0d85ce08f0d9702e68cce95d43cb.jpg'),
(62224, 4215, 'Starstruck S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238619.mp4', 'http://gstaticontent.com/images/bcfe0d85ce08f0d9702e68cce95d43cb.jpg'),
(62225, 4216, 'The Watch S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151357.mp4', 'http://timg.bdta.pro/images/3c6a3c81cca36d9234e7ce6c3297a865.jpg'),
(62226, 4216, 'The Watch S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151358.mp4', 'http://timg.bdta.pro/images/1f39f1af8990aa052049b74c04139c37.jpg'),
(62227, 4216, 'The Watch S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151359.mp4', 'http://timg.bdta.pro/images/f6d9e82c57108a05aa36bc433b5dd39f.jpg'),
(62228, 4216, 'The Watch S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151360.mp4', 'http://timg.bdta.pro/images/7374660d3e244c7b9734c1c52d5540a9.jpg'),
(62229, 4216, 'The Watch S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151361.mp4', 'http://timg.bdta.pro/images/209efc66e714781641f20dc39d5f69c9.jpg'),
(62230, 4216, 'The Watch S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151362.mp4', 'http://timg.bdta.pro/images/7482278c0b5ca696c16d70566b76dccd.jpg'),
(62231, 4216, 'The Watch S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151363.mp4', 'http://timg.bdta.pro/images/0c57d690ff22a3ec3d76e83308021ed4.jpg'),
(62232, 4216, 'The Watch S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151364.mp4', 'http://timg.bdta.pro/images/bdb80b0ef92236e6aff38c747fb92c78.jpg'),
(62233, 4217, 'Turner e Hooch S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161337.mp4', 'http://timg.bdta.pro/images/71f01da90fd99baea7b28351ebbfec16.jpg'),
(62234, 4217, 'Turner e Hooch S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161338.mp4', 'http://timg.bdta.pro/images/48670029542613f4814fdd4d9750fbcd.jpg'),
(62235, 4217, 'Turner e Hooch S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161339.mp4', 'http://timg.bdta.pro/images/5192ea181cdaff825f55ff9701cd8d18.jpg'),
(62236, 4217, 'Turner e Hooch S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161340.mp4', 'http://timg.bdta.pro/images/990cb0817b939ac09dba9ef81dd8695c.jpg'),
(62237, 4217, 'Turner e Hooch S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161341.mp4', 'http://timg.bdta.pro/images/5965535409d392821561aaf741a887dc.jpg'),
(62238, 4217, 'Turner e Hooch S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161342.mp4', 'http://timg.bdta.pro/images/3aaaf177442792d9efafa8d1121e9210.jpg'),
(62239, 4217, 'Turner e Hooch S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161343.mp4', 'http://timg.bdta.pro/images/d251402f674ef1b39637bd219df9076f.jpg'),
(62240, 4217, 'Turner e Hooch S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161344.mp4', 'http://timg.bdta.pro/images/f67129803d5b5478d98df39d84afe430.jpg'),
(62241, 4217, 'Turner e Hooch S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161345.mp4', 'http://timg.bdta.pro/images/044f8a28048e236e58b3a9cb295cacb3.jpg'),
(62242, 4217, 'Turner e Hooch S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161346.mp4', 'http://image.tmdb.org/t/p/w1280/mjQLvEJFKYJ6VAup8CaTj7dwH63.jpg'),
(62243, 4217, 'Turner e Hooch S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161347.mp4', 'http://image.tmdb.org/t/p/w1280/9l2A00Pqv7EYwjIFitINx9WndrN.jpg'),
(62244, 4217, 'Turner e Hooch S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161348.mp4', 'http://image.tmdb.org/t/p/w1280/1mRCP4FRbJKav3yKUAIvPPKTFeb.jpg'),
(62245, 4218, 'A Rocha Encantada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151261.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62246, 4218, 'A Rocha Encantada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151262.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62247, 4218, 'A Rocha Encantada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151263.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62248, 4218, 'A Rocha Encantada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151264.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62249, 4218, 'A Rocha Encantada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151265.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62250, 4218, 'A Rocha Encantada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151266.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62251, 4218, 'A Rocha Encantada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151267.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62252, 4218, 'A Rocha Encantada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151268.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62253, 4218, 'A Rocha Encantada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151269.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62254, 4218, 'A Rocha Encantada S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151270.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62255, 4218, 'A Rocha Encantada S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151271.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62256, 4218, 'A Rocha Encantada S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151272.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62257, 4218, 'A Rocha Encantada S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151273.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62258, 4218, 'A Rocha Encantada S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151274.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62259, 4218, 'A Rocha Encantada S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/151275.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62260, 4218, 'A Rocha Encantada S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/151276.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62261, 4218, 'A Rocha Encantada S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/151277.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62262, 4218, 'A Rocha Encantada S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/151278.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62263, 4218, 'A Rocha Encantada S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/151279.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62264, 4218, 'A Rocha Encantada S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/151280.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62265, 4218, 'A Rocha Encantada S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/151281.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62266, 4218, 'A Rocha Encantada S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/151282.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62267, 4218, 'A Rocha Encantada S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/151283.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62268, 4218, 'A Rocha Encantada S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/151284.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62269, 4219, 'A Rocha Encantada S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151285.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62270, 4219, 'A Rocha Encantada S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151286.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62271, 4219, 'A Rocha Encantada S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151287.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62272, 4219, 'A Rocha Encantada S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151288.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62273, 4219, 'A Rocha Encantada S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151289.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62274, 4219, 'A Rocha Encantada S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151290.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62275, 4219, 'A Rocha Encantada S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151291.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62276, 4219, 'A Rocha Encantada S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151292.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62277, 4219, 'A Rocha Encantada S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151293.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62278, 4219, 'A Rocha Encantada S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151294.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62279, 4219, 'A Rocha Encantada S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151295.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62280, 4219, 'A Rocha Encantada S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151296.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62281, 4219, 'A Rocha Encantada S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151297.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62282, 4219, 'A Rocha Encantada S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151298.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62283, 4219, 'A Rocha Encantada S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/151299.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62284, 4219, 'A Rocha Encantada S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/151300.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62285, 4219, 'A Rocha Encantada S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/151301.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62286, 4219, 'A Rocha Encantada S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/151302.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(62287, 4219, 'A Rocha Encantada S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/151303.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62288, 4219, 'A Rocha Encantada S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/151304.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62289, 4219, 'A Rocha Encantada S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/151305.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62290, 4219, 'A Rocha Encantada S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/151306.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62291, 4219, 'A Rocha Encantada S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/151307.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62292, 4219, 'A Rocha Encantada S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/151308.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62293, 4220, 'A Rocha Encantada S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151309.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62294, 4220, 'A Rocha Encantada S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151310.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62295, 4220, 'A Rocha Encantada S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151311.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62296, 4220, 'A Rocha Encantada S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151312.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62297, 4220, 'A Rocha Encantada S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151313.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62298, 4220, 'A Rocha Encantada S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151314.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62299, 4220, 'A Rocha Encantada S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151315.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62300, 4220, 'A Rocha Encantada S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151316.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62301, 4220, 'A Rocha Encantada S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151317.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62302, 4220, 'A Rocha Encantada S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151318.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62303, 4220, 'A Rocha Encantada S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151319.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62304, 4220, 'A Rocha Encantada S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151320.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62305, 4220, 'A Rocha Encantada S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151321.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62306, 4220, 'A Rocha Encantada S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151322.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62307, 4220, 'A Rocha Encantada S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/151323.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62308, 4220, 'A Rocha Encantada S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/151324.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62309, 4220, 'A Rocha Encantada S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/151325.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62310, 4220, 'A Rocha Encantada S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/151326.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62311, 4220, 'A Rocha Encantada S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/151327.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62312, 4220, 'A Rocha Encantada S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/151328.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62313, 4220, 'A Rocha Encantada S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/151329.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62314, 4220, 'A Rocha Encantada S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/151330.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62315, 4221, 'A Rocha Encantada S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151331.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62316, 4221, 'A Rocha Encantada S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151332.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62317, 4221, 'A Rocha Encantada S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151333.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62318, 4221, 'A Rocha Encantada S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151334.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62319, 4221, 'A Rocha Encantada S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151335.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62320, 4221, 'A Rocha Encantada S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151336.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62321, 4221, 'A Rocha Encantada S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151337.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62322, 4221, 'A Rocha Encantada S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151338.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62323, 4221, 'A Rocha Encantada S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151339.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62324, 4221, 'A Rocha Encantada S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151340.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62325, 4221, 'A Rocha Encantada S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151341.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62326, 4221, 'A Rocha Encantada S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151342.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62327, 4221, 'A Rocha Encantada S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151343.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62328, 4222, 'A Rocha Encantada S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151344.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62329, 4222, 'A Rocha Encantada S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151345.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62330, 4222, 'A Rocha Encantada S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151346.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62331, 4222, 'A Rocha Encantada S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151347.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62332, 4222, 'A Rocha Encantada S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151348.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62333, 4222, 'A Rocha Encantada S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151349.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62334, 4222, 'A Rocha Encantada S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151350.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62335, 4222, 'A Rocha Encantada S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151351.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62336, 4222, 'A Rocha Encantada S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151352.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62337, 4222, 'A Rocha Encantada S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151353.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62338, 4222, 'A Rocha Encantada S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151354.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62339, 4222, 'A Rocha Encantada S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151355.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62340, 4222, 'A Rocha Encantada S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151356.mp4', 'http://gstaticontent.com/images/774984ee0a84b0b2cdd51910e9575dd1.jpg'),
(62341, 4223, 'IneXplicável América Latina com John Leguizamo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259982.mp4', 'http://timg.bdta.pro/images/76e957a417174285c1bb9436db04a68c.jpg'),
(62342, 4223, 'IneXplicável América Latina com John Leguizamo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259983.mp4', 'http://timg.bdta.pro/images/76e957a417174285c1bb9436db04a68c.jpg'),
(62343, 4223, 'IneXplicável América Latina com John Leguizamo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259984.mp4', 'http://timg.bdta.pro/images/76e957a417174285c1bb9436db04a68c.jpg'),
(62344, 4223, 'IneXplicável América Latina com John Leguizamo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259985.mp4', 'http://timg.bdta.pro/images/76e957a417174285c1bb9436db04a68c.jpg'),
(62345, 4223, 'IneXplicável América Latina com John Leguizamo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259986.mp4', 'http://timg.bdta.pro/images/76e957a417174285c1bb9436db04a68c.jpg'),
(62346, 4223, 'IneXplicável América Latina com John Leguizamo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259987.mp4', 'http://timg.bdta.pro/images/76e957a417174285c1bb9436db04a68c.jpg'),
(62347, 4223, 'IneXplicável América Latina com John Leguizamo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259988.mp4', 'http://timg.bdta.pro/images/76e957a417174285c1bb9436db04a68c.jpg'),
(62348, 4223, 'IneXplicável América Latina com John Leguizamo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259989.mp4', 'http://timg.bdta.pro/images/76e957a417174285c1bb9436db04a68c.jpg'),
(62349, 4224, 'IneXplicável América Latina com John Leguizamo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259990.mp4', 'http://gstaticontent.com/images/045508b1b9b1b38589f54b618be1dea3.jpg'),
(62350, 4224, 'IneXplicável América Latina com John Leguizamo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259991.mp4', 'http://gstaticontent.com/images/045508b1b9b1b38589f54b618be1dea3.jpg'),
(62351, 4224, 'IneXplicável América Latina com John Leguizamo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259992.mp4', 'http://gstaticontent.com/images/045508b1b9b1b38589f54b618be1dea3.jpg'),
(62352, 4224, 'IneXplicável América Latina com John Leguizamo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259993.mp4', 'http://gstaticontent.com/images/045508b1b9b1b38589f54b618be1dea3.jpg'),
(62353, 4224, 'IneXplicável América Latina com John Leguizamo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259994.mp4', 'http://gstaticontent.com/images/045508b1b9b1b38589f54b618be1dea3.jpg'),
(62354, 4224, 'IneXplicável América Latina com John Leguizamo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259995.mp4', 'http://gstaticontent.com/images/045508b1b9b1b38589f54b618be1dea3.jpg'),
(62355, 4224, 'IneXplicável América Latina com John Leguizamo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259996.mp4', 'http://gstaticontent.com/images/045508b1b9b1b38589f54b618be1dea3.jpg'),
(62356, 4224, 'IneXplicável América Latina com John Leguizamo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259997.mp4', 'http://gstaticontent.com/images/045508b1b9b1b38589f54b618be1dea3.jpg'),
(62357, 4225, 'IneXplicável América Latina com John Leguizamo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259998.mp4', 'http://gstaticontent.com/images/045508b1b9b1b38589f54b618be1dea3.jpg'),
(62358, 4225, 'IneXplicável América Latina com John Leguizamo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259999.mp4', 'http://gstaticontent.com/images/045508b1b9b1b38589f54b618be1dea3.jpg'),
(62359, 4225, 'IneXplicável América Latina com John Leguizamo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260000.mp4', 'http://gstaticontent.com/images/045508b1b9b1b38589f54b618be1dea3.jpg'),
(62360, 4225, 'IneXplicável América Latina com John Leguizamo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260001.mp4', 'http://gstaticontent.com/images/045508b1b9b1b38589f54b618be1dea3.jpg'),
(62361, 4225, 'IneXplicável América Latina com John Leguizamo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260002.mp4', 'http://gstaticontent.com/images/045508b1b9b1b38589f54b618be1dea3.jpg'),
(62362, 4225, 'IneXplicável América Latina com John Leguizamo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260003.mp4', 'http://gstaticontent.com/images/045508b1b9b1b38589f54b618be1dea3.jpg'),
(62363, 4225, 'IneXplicável América Latina com John Leguizamo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260004.mp4', 'http://gstaticontent.com/images/045508b1b9b1b38589f54b618be1dea3.jpg'),
(62364, 4225, 'IneXplicável América Latina com John Leguizamo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260005.mp4', 'http://gstaticontent.com/images/045508b1b9b1b38589f54b618be1dea3.jpg'),
(62365, 4225, 'IneXplicável América Latina com John Leguizamo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260006.mp4', 'http://gstaticontent.com/images/045508b1b9b1b38589f54b618be1dea3.jpg'),
(62366, 4225, 'IneXplicável América Latina com John Leguizamo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260007.mp4', 'http://gstaticontent.com/images/045508b1b9b1b38589f54b618be1dea3.jpg'),
(62367, 4226, 'Top Secret: OVNIS S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151255.mp4', 'http://gstaticontent.com/images/fa51c9d4bec56bab5dedfa61c54cd50c.jpg'),
(62368, 4226, 'Top Secret: OVNIS S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151256.mp4', 'http://gstaticontent.com/images/fa51c9d4bec56bab5dedfa61c54cd50c.jpg'),
(62369, 4226, 'Top Secret: OVNIS S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151257.mp4', 'http://gstaticontent.com/images/fa51c9d4bec56bab5dedfa61c54cd50c.jpg'),
(62370, 4226, 'Top Secret: OVNIS S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151258.mp4', 'http://gstaticontent.com/images/fa51c9d4bec56bab5dedfa61c54cd50c.jpg'),
(62371, 4226, 'Top Secret: OVNIS S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151259.mp4', 'http://gstaticontent.com/images/fa51c9d4bec56bab5dedfa61c54cd50c.jpg'),
(62372, 4226, 'Top Secret: OVNIS S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151260.mp4', 'http://gstaticontent.com/images/fa51c9d4bec56bab5dedfa61c54cd50c.jpg'),
(62373, 4227, 'Cocaine Cowboys: The Kings of Miami S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151249.mp4', 'http://gstaticontent.com/images/610d953738e7b936b39e41d76517ee25.jpg'),
(62374, 4227, 'Cocaine Cowboys: The Kings of Miami S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151250.mp4', 'http://gstaticontent.com/images/610d953738e7b936b39e41d76517ee25.jpg'),
(62375, 4227, 'Cocaine Cowboys: The Kings of Miami S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151251.mp4', 'http://gstaticontent.com/images/610d953738e7b936b39e41d76517ee25.jpg'),
(62376, 4227, 'Cocaine Cowboys: The Kings of Miami S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151252.mp4', 'http://gstaticontent.com/images/610d953738e7b936b39e41d76517ee25.jpg'),
(62377, 4227, 'Cocaine Cowboys: The Kings of Miami S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151253.mp4', 'http://gstaticontent.com/images/610d953738e7b936b39e41d76517ee25.jpg'),
(62378, 4227, 'Cocaine Cowboys: The Kings of Miami S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151254.mp4', 'http://gstaticontent.com/images/610d953738e7b936b39e41d76517ee25.jpg'),
(62379, 4228, 'Control Z S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183166.mp4', 'http://timg.bdta.pro/images/f078304924d1dae850d788edb14e9fe2.jpg'),
(62380, 4228, 'Control Z S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183167.mp4', 'http://timg.bdta.pro/images/759f75cfd105dcb87ab1c5ec88c9fd79.jpg'),
(62381, 4228, 'Control Z S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183168.mp4', 'http://timg.bdta.pro/images/bde232bac754b1034b0fb49f55a50ff6.jpg'),
(62382, 4228, 'Control Z S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183169.mp4', 'http://timg.bdta.pro/images/b371c453ad3a62b69632f91e7aa2c17e.jpg'),
(62383, 4228, 'Control Z S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183170.mp4', 'http://timg.bdta.pro/images/e49f57d4b7ab4f3fa234037a2e8400d4.jpg'),
(62384, 4228, 'Control Z S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183171.mp4', 'http://timg.bdta.pro/images/5c4c196739b27ceefa9fd56519860779.jpg'),
(62385, 4228, 'Control Z S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183172.mp4', 'http://timg.bdta.pro/images/afc3e6cd8ed93d559a5a128c67401a9d.jpg'),
(62386, 4228, 'Control Z S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183173.mp4', 'http://timg.bdta.pro/images/fc0b4dd25996aa5f9cd36b37f1d00433.jpg'),
(62387, 4229, 'Control Z S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183174.mp4', 'http://timg.bdta.pro/images/7013d2a7ae4798de4e93ce208ad4c1ef.jpg'),
(62388, 4229, 'Control Z S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183175.mp4', 'http://timg.bdta.pro/images/1bb429e711e1be0735cb84c7dd14f573.jpg'),
(62389, 4229, 'Control Z S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183176.mp4', 'http://timg.bdta.pro/images/29403015fe5c498025c60c0375d63ad5.jpg'),
(62390, 4229, 'Control Z S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183177.mp4', 'http://timg.bdta.pro/images/244b9935f095cf9529ff92147d203555.jpg'),
(62391, 4229, 'Control Z S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183178.mp4', 'http://timg.bdta.pro/images/988133d93fd7bf9be7708f62aad1fb39.jpg'),
(62392, 4229, 'Control Z S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183179.mp4', 'http://timg.bdta.pro/images/da82298668299c23cc48600dac6b500d.jpg'),
(62393, 4229, 'Control Z S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183180.mp4', 'http://timg.bdta.pro/images/c5f69f4756adf27a9c2e4d0439c31b9b.jpg'),
(62394, 4229, 'Control Z S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183181.mp4', 'http://timg.bdta.pro/images/78f7f567ce00a3d0038a9b934d802730.jpg'),
(62395, 4230, 'Control Z S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183182.mp4', 'http://timg.bdta.pro/images/9c5a448f007e5e2a1df13f6092566802.jpg'),
(62396, 4230, 'Control Z S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183183.mp4', 'http://timg.bdta.pro/images/b868e68ed45932e26b59e793caef7b9c.jpg'),
(62397, 4230, 'Control Z S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183184.mp4', 'http://timg.bdta.pro/images/f868532a9571a54f6050ecb34a53a5bd.jpg'),
(62398, 4230, 'Control Z S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183185.mp4', 'http://timg.bdta.pro/images/ef21a2437816550b98bf5f947fb4df5b.jpg'),
(62399, 4230, 'Control Z S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183186.mp4', 'http://timg.bdta.pro/images/f182d73c759f74cc29a28e1adbab6a06.jpg'),
(62400, 4230, 'Control Z S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183187.mp4', 'http://timg.bdta.pro/images/3974dab66abeebc3633b30acbd7f6a9c.jpg'),
(62401, 4230, 'Control Z S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183188.mp4', 'http://timg.bdta.pro/images/f7da26f29689459800ad4573e660c7fa.jpg'),
(62402, 4230, 'Control Z S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183189.mp4', 'http://timg.bdta.pro/images/75017b41a8c80299cd0ee4e161c6990d.jpg'),
(62403, 4231, 'Cozinhando com Paris Hilton S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151243.mp4', 'http://timg.bdta.pro/images/3a494dd4aca6718e1d66325f3e35ca26.jpg'),
(62404, 4231, 'Cozinhando com Paris Hilton S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151244.mp4', 'http://timg.bdta.pro/images/2b838cf94c0aa3900933d5b103d5b28f.jpg'),
(62405, 4231, 'Cozinhando com Paris Hilton S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151245.mp4', 'http://timg.bdta.pro/images/f230aa954b45a322abc84372fd38480d.jpg'),
(62406, 4231, 'Cozinhando com Paris Hilton S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151246.mp4', 'http://timg.bdta.pro/images/e27dde8ecfa73c0e9fbf4cb9459edccd.jpg'),
(62407, 4231, 'Cozinhando com Paris Hilton S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151247.mp4', 'http://timg.bdta.pro/images/674c1c25ebf396b1abf218292140476f.jpg'),
(62408, 4231, 'Cozinhando com Paris Hilton S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151248.mp4', 'http://timg.bdta.pro/images/2b10024cf5f9b1d408e77314d082cce1.jpg'),
(62409, 4232, 'Família Dinossauros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149443.mp4', 'http://timg.bdta.pro/images/54349a204ac25f59382fe4e6d0e43211.jpg'),
(62410, 4232, 'Família Dinossauros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149444.mp4', 'http://timg.bdta.pro/images/7691b2f5dd00ebc87c31dc086f87fe02.jpg'),
(62411, 4232, 'Família Dinossauros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149445.mp4', 'http://timg.bdta.pro/images/893d915246c21395298689ab49d7dae6.jpg'),
(62412, 4232, 'Família Dinossauros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149446.mp4', 'http://timg.bdta.pro/images/723c0bb2b0644a276e535077c0d02bdb.jpg'),
(62413, 4232, 'Família Dinossauros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149447.mp4', 'http://timg.bdta.pro/images/1d8cc6f6c3ad2762fb372d2464808f0c.jpg'),
(62414, 4233, 'Família Dinossauros S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149448.mp4', 'http://timg.bdta.pro/images/825ba1b4572c9e1982885c9d83f83b17.jpg'),
(62415, 4233, 'Família Dinossauros S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149449.mp4', 'http://timg.bdta.pro/images/9d4966e40c23cd0fd4b52398a6abecd2.jpg'),
(62416, 4233, 'Família Dinossauros S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149450.mp4', 'http://timg.bdta.pro/images/fe5105c585638c80c4eec1bf66ec4a2e.jpg'),
(62417, 4233, 'Família Dinossauros S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149451.mp4', 'http://timg.bdta.pro/images/24140c99c04922ba161d2f9dd19e42f3.jpg'),
(62418, 4233, 'Família Dinossauros S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149452.mp4', 'http://timg.bdta.pro/images/336a6095ba7b227786a12a4d75130669.jpg'),
(62419, 4233, 'Família Dinossauros S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149453.mp4', 'http://timg.bdta.pro/images/c951884d8f409962f8c928c88e672afa.jpg'),
(62420, 4233, 'Família Dinossauros S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149454.mp4', 'http://timg.bdta.pro/images/7d451348d3c6b35b39a01a773e81540f.jpg'),
(62421, 4233, 'Família Dinossauros S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149455.mp4', 'http://timg.bdta.pro/images/f1bb54425749e67f98b757097f54b60a.jpg'),
(62422, 4233, 'Família Dinossauros S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149456.mp4', 'http://timg.bdta.pro/images/56bf823aee892ca98c8f5b2b52475d59.jpg'),
(62423, 4233, 'Família Dinossauros S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149457.mp4', 'http://timg.bdta.pro/images/aae8bd425f3e5781a76c48df91209bbb.jpg'),
(62424, 4233, 'Família Dinossauros S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149458.mp4', 'http://timg.bdta.pro/images/ca46b65a7068de1595b7f41a78554325.jpg'),
(62425, 4233, 'Família Dinossauros S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149459.mp4', 'http://timg.bdta.pro/images/62dbb85e00675c9d95ee8a6edc448d6a.jpg'),
(62426, 4233, 'Família Dinossauros S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/149460.mp4', 'http://timg.bdta.pro/images/5d40e0a88803be9ce03d800c3419ea0e.jpg'),
(62427, 4233, 'Família Dinossauros S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/149461.mp4', 'http://timg.bdta.pro/images/96efadc6b8c0e64fe2c1d0c0139e57fa.jpg'),
(62428, 4233, 'Família Dinossauros S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/149462.mp4', 'http://timg.bdta.pro/images/36d4f9aea0fd346354ab392d5ff24d14.jpg'),
(62429, 4233, 'Família Dinossauros S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/149463.mp4', 'http://timg.bdta.pro/images/736d1e19fa9591c53cc397cb7eb8f07b.jpg'),
(62430, 4233, 'Família Dinossauros S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/149464.mp4', 'http://timg.bdta.pro/images/a48448299d5a129002bcd2a35d6c834e.jpg'),
(62431, 4233, 'Família Dinossauros S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/149465.mp4', 'http://timg.bdta.pro/images/2811476ce0f98fab421957ef3d60aa85.jpg'),
(62432, 4233, 'Família Dinossauros S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/149466.mp4', 'http://timg.bdta.pro/images/302084249c28f493a5c28c9630ec7f10.jpg'),
(62433, 4233, 'Família Dinossauros S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/149467.mp4', 'http://timg.bdta.pro/images/eb5f23a4873ee2b8e81fea52a3f0fd66.jpg'),
(62434, 4233, 'Família Dinossauros S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/149468.mp4', 'http://timg.bdta.pro/images/85cc71ee361c03dbf55e2817277e1261.jpg'),
(62435, 4233, 'Família Dinossauros S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/149469.mp4', 'http://timg.bdta.pro/images/248ef61f31257ba0ab8b749c9993e50c.jpg'),
(62436, 4233, 'Família Dinossauros S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/149470.mp4', 'http://timg.bdta.pro/images/28ad63bc34cb0c792a6dc3c018c29bd3.jpg'),
(62437, 4233, 'Família Dinossauros S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/149471.mp4', 'http://timg.bdta.pro/images/063d33adc0df023d6dc1faf8ff4f3e28.jpg'),
(62438, 4234, 'Família Dinossauros S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149472.mp4', 'http://timg.bdta.pro/images/d0555a028e3a85c0d226b929526b9de5.jpg'),
(62439, 4234, 'Família Dinossauros S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149473.mp4', 'http://timg.bdta.pro/images/db07af44fe395212700feed5b68cbeb8.jpg'),
(62440, 4234, 'Família Dinossauros S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149474.mp4', 'http://timg.bdta.pro/images/e1a152988784e151b8c8bb67d53fb5f2.jpg'),
(62441, 4234, 'Família Dinossauros S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149475.mp4', 'http://timg.bdta.pro/images/08328bf12846d7b9fd06a06384ed7587.jpg'),
(62442, 4234, 'Família Dinossauros S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149476.mp4', 'http://timg.bdta.pro/images/3b84fe4c36490620a53e9c45da19f2b9.jpg'),
(62443, 4234, 'Família Dinossauros S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149477.mp4', 'http://timg.bdta.pro/images/d3863b92054d1614bc40140dc5cb9cd8.jpg'),
(62444, 4234, 'Família Dinossauros S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149478.mp4', 'http://timg.bdta.pro/images/82828a5891392c796d1e57b782108535.jpg'),
(62445, 4234, 'Família Dinossauros S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149479.mp4', 'http://timg.bdta.pro/images/94694f399d02d44572e29d8668cccb5f.jpg'),
(62446, 4234, 'Família Dinossauros S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149480.mp4', 'http://timg.bdta.pro/images/b670e27fd9e9e903736dfc526d7aeb5f.jpg'),
(62447, 4234, 'Família Dinossauros S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149481.mp4', 'http://timg.bdta.pro/images/4ccd7cc12cfd925579668bc544501413.jpg'),
(62448, 4234, 'Família Dinossauros S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149482.mp4', 'http://timg.bdta.pro/images/048faf2cd45decef09da02e7ce15b87a.jpg'),
(62449, 4234, 'Família Dinossauros S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149483.mp4', 'http://timg.bdta.pro/images/951c337b8792bb872d4963185aee2a16.jpg'),
(62450, 4234, 'Família Dinossauros S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/149484.mp4', 'http://timg.bdta.pro/images/2925a52d528a4f4a536506ff89980c53.jpg'),
(62451, 4234, 'Família Dinossauros S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/149485.mp4', 'http://timg.bdta.pro/images/a2503d2683aa1a142efee352de3b39ce.jpg'),
(62452, 4234, 'Família Dinossauros S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/149486.mp4', 'http://timg.bdta.pro/images/e24779a6e138c5dd07c28f97c5f29132.jpg'),
(62453, 4234, 'Família Dinossauros S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/149487.mp4', 'http://timg.bdta.pro/images/826fdc3c43822c4a5b1d92e83f98c4e1.jpg'),
(62454, 4234, 'Família Dinossauros S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/149488.mp4', 'http://timg.bdta.pro/images/246ad26463f9d3b19a3c5efac70064a9.jpg'),
(62455, 4234, 'Família Dinossauros S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/149489.mp4', 'http://timg.bdta.pro/images/cee7b00c3e8cecb63868bbf316f71101.jpg'),
(62456, 4234, 'Família Dinossauros S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/149490.mp4', 'http://timg.bdta.pro/images/0ca15eb19a5ac1c19eb4cc9a6c399594.jpg'),
(62457, 4234, 'Família Dinossauros S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/149491.mp4', 'http://timg.bdta.pro/images/9cb156985100de8945483e0778e03dc4.jpg'),
(62458, 4234, 'Família Dinossauros S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/149492.mp4', 'http://timg.bdta.pro/images/32bf3529ebfdc1441a59aea740966da4.jpg'),
(62459, 4234, 'Família Dinossauros S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/149493.mp4', 'http://timg.bdta.pro/images/d5c7aee2129e3bd4c4b74b2d918e461e.jpg'),
(62460, 4235, 'Família Dinossauros S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149494.mp4', 'http://timg.bdta.pro/images/9d662c2240dc438bb4d53cc5abd81ce4.jpg'),
(62461, 4235, 'Família Dinossauros S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149495.mp4', 'http://timg.bdta.pro/images/659888db7c9d90f57e4baf95b0d3748f.jpg'),
(62462, 4235, 'Família Dinossauros S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149496.mp4', 'http://timg.bdta.pro/images/c154d9f2071eebb947ba27ce53e5943a.jpg'),
(62463, 4235, 'Família Dinossauros S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149497.mp4', 'http://timg.bdta.pro/images/61160f048206c13263cf0c8ee248dd4b.jpg'),
(62464, 4235, 'Família Dinossauros S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149498.mp4', 'http://timg.bdta.pro/images/f649c0b5f5b2bb466d45db87d72f0f5d.jpg'),
(62465, 4235, 'Família Dinossauros S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149499.mp4', 'http://timg.bdta.pro/images/0b81dad83248e85ed545fdcfc084c650.jpg'),
(62466, 4235, 'Família Dinossauros S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149500.mp4', 'http://timg.bdta.pro/images/1be289c7bde47f806d8fd9aab4f9d363.jpg'),
(62467, 4235, 'Família Dinossauros S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149501.mp4', 'http://timg.bdta.pro/images/43d8e1b1b004c89b9111ecaa43bda515.jpg'),
(62468, 4235, 'Família Dinossauros S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149502.mp4', 'http://timg.bdta.pro/images/92ecdd82bb32d059359f41e4b5ee9aa6.jpg'),
(62469, 4235, 'Família Dinossauros S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149503.mp4', 'http://timg.bdta.pro/images/e80173d3a2c6814084a531819c41fffd.jpg'),
(62470, 4235, 'Família Dinossauros S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149504.mp4', 'http://timg.bdta.pro/images/3104ccda369ac896e49549cb02fe241a.jpg'),
(62471, 4235, 'Família Dinossauros S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149505.mp4', 'http://timg.bdta.pro/images/afd8a14874512f9611c1b0d8d909edde.jpg'),
(62472, 4235, 'Família Dinossauros S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/149506.mp4', 'http://timg.bdta.pro/images/a16eeb2b7a41f3a91aa724029800b603.jpg'),
(62473, 4235, 'Família Dinossauros S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/149507.mp4', 'http://timg.bdta.pro/images/a92a427449f48e636acdb6821a99e3eb.jpg'),
(62474, 4236, 'Genera+ion S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151070.mp4', 'http://timg.bdta.pro/images/3a4a369a1945156afd5b8f57304d2efa.jpg'),
(62475, 4236, 'Genera+ion S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151071.mp4', 'http://timg.bdta.pro/images/af3493d66947547b9ee2227df421a540.jpg'),
(62476, 4236, 'Genera+ion S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151072.mp4', 'http://timg.bdta.pro/images/729d7664fb3e56752def92e11811fd5d.jpg'),
(62477, 4236, 'Genera+ion S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151073.mp4', 'http://timg.bdta.pro/images/1a1aa231c9de9606e37ce201ea96ed16.jpg'),
(62478, 4236, 'Genera+ion S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151074.mp4', 'http://timg.bdta.pro/images/13b728338983bf817b336b536dfd0108.jpg'),
(62479, 4236, 'Genera+ion S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151075.mp4', 'http://timg.bdta.pro/images/3db92d88d8cb9ff2fffba423a6a1af5b.jpg'),
(62480, 4236, 'Genera+ion S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151076.mp4', 'http://timg.bdta.pro/images/bf7b3119e44ec4127e286c34930fb984.jpg'),
(62481, 4236, 'Genera+ion S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151077.mp4', 'http://timg.bdta.pro/images/2c7a537cdf3ad414ab7a22c151ab9d41.jpg'),
(62482, 4236, 'Genera+ion S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151078.mp4', 'http://timg.bdta.pro/images/6d4fa731d5e7ef8cfe9e42297bd906e7.jpg'),
(62483, 4236, 'Genera+ion S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151079.mp4', 'http://timg.bdta.pro/images/e7e2773aafd33844d5669bb27ad8106f.jpg'),
(62484, 4236, 'Genera+ion S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151080.mp4', 'http://timg.bdta.pro/images/6500534e161dced1c0508bd1f02e3eea.jpg'),
(62485, 4236, 'Genera+ion S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151081.mp4', 'http://timg.bdta.pro/images/ae99f105b42ceae6e3c184358e3fa369.jpg'),
(62486, 4236, 'Genera+ion S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151082.mp4', 'http://timg.bdta.pro/images/e8837456d35c895d9354ba42453d15bc.jpg'),
(62487, 4236, 'Genera+ion S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151083.mp4', 'http://timg.bdta.pro/images/cc3e96abaa69964d158897a9b21c85df.jpg'),
(62488, 4236, 'Genera+ion S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/151084.mp4', 'http://timg.bdta.pro/images/74822d4f124412bdb324d55f896d0aa9.jpg'),
(62489, 4236, 'Genera+ion S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/151085.mp4', 'http://timg.bdta.pro/images/d2e5787d1623b232aba289a330b4f62b.jpg'),
(62490, 4237, 'Hit & Run S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151061.mp4', 'http://timg.bdta.pro/images/4fb006c2845811f43142a2ad351bb961.jpg'),
(62491, 4237, 'Hit & Run S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151062.mp4', 'http://timg.bdta.pro/images/af55a76b254b716f0d3726237e1a4b6d.jpg'),
(62492, 4237, 'Hit & Run S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151063.mp4', 'http://timg.bdta.pro/images/cf59761c55e30cd888d09af05276b78f.jpg'),
(62493, 4237, 'Hit & Run S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151064.mp4', 'http://timg.bdta.pro/images/d4fa13d208e9b911d460b94ba332bc31.jpg'),
(62494, 4237, 'Hit & Run S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151065.mp4', 'http://timg.bdta.pro/images/8a78010755852a18d8d68469499e4359.jpg'),
(62495, 4237, 'Hit & Run S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151066.mp4', 'http://timg.bdta.pro/images/4c63dc5897745d8e52bd1bef30be5f19.jpg'),
(62496, 4237, 'Hit & Run S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151067.mp4', 'http://timg.bdta.pro/images/2993499c9c5b5e424b60716e03d7ce03.jpg'),
(62497, 4237, 'Hit & Run S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151068.mp4', 'http://timg.bdta.pro/images/092406f0f20e26e4d05abb6b4cf8a813.jpg'),
(62498, 4237, 'Hit & Run S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151069.mp4', 'http://timg.bdta.pro/images/1f8797ba5dc4b556398b7159fcbe50b3.jpg'),
(62499, 4238, 'MacGyver - Profissão: Perigo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151104.mp4', 'http://timg.bdta.pro/images/da76f62f9ce99931d6f21e5e8a9959c0.jpg'),
(62500, 4238, 'MacGyver - Profissão: Perigo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151105.mp4', 'http://timg.bdta.pro/images/834fc41a05cada78faab6b91176e3f6e.jpg'),
(62501, 4238, 'MacGyver - Profissão: Perigo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151106.mp4', 'http://timg.bdta.pro/images/98ce39de42db40f2a79b10f8d5cb93be.jpg'),
(62502, 4238, 'MacGyver - Profissão: Perigo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151107.mp4', 'http://timg.bdta.pro/images/bd11a5cb394d01349c48784a0b2f279a.jpg'),
(62503, 4238, 'MacGyver - Profissão: Perigo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151108.mp4', 'http://timg.bdta.pro/images/80620ae84da90c5e8d4578ba27c5dd98.jpg'),
(62504, 4238, 'MacGyver - Profissão: Perigo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151109.mp4', 'http://timg.bdta.pro/images/2d6e1fe4320ace927afd26b291172c43.jpg'),
(62505, 4238, 'MacGyver - Profissão: Perigo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151110.mp4', 'http://timg.bdta.pro/images/88924914d4c36b6ee22426032ef5465f.jpg'),
(62506, 4238, 'MacGyver - Profissão: Perigo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151111.mp4', 'http://timg.bdta.pro/images/9f4e9cf67c391f7d7167282de11aa6f8.jpg'),
(62507, 4238, 'MacGyver - Profissão: Perigo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151112.mp4', 'http://timg.bdta.pro/images/03e41f0e422090954cacf921992bfb5e.jpg'),
(62508, 4238, 'MacGyver - Profissão: Perigo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151113.mp4', 'http://timg.bdta.pro/images/fed9be60ff75fa00807448c797ff74d4.jpg'),
(62509, 4238, 'MacGyver - Profissão: Perigo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151114.mp4', 'http://timg.bdta.pro/images/9294b0ca572c63be006e7c337cc6f1ce.jpg'),
(62510, 4238, 'MacGyver - Profissão: Perigo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151115.mp4', 'http://timg.bdta.pro/images/c9d4e3adb61c793b6d686fb997620e0c.jpg'),
(62511, 4238, 'MacGyver - Profissão: Perigo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151116.mp4', 'http://timg.bdta.pro/images/54fc6253704010130aa30dea0df902e0.jpg'),
(62512, 4238, 'MacGyver - Profissão: Perigo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151117.mp4', 'http://timg.bdta.pro/images/cac7c235ea8b4439cd5e96d2a1162784.jpg'),
(62513, 4238, 'MacGyver - Profissão: Perigo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/151118.mp4', 'http://timg.bdta.pro/images/85da8aef8b47e230d75a073e070bd60e.jpg'),
(62514, 4238, 'MacGyver - Profissão: Perigo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/151119.mp4', 'http://timg.bdta.pro/images/fcb53104737ec2cadd0957cf5c5eb805.jpg'),
(62515, 4238, 'MacGyver - Profissão: Perigo S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/151120.mp4', 'http://timg.bdta.pro/images/7171e5ca4f1b49ea65697cae14695829.jpg'),
(62516, 4238, 'MacGyver - Profissão: Perigo S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/151121.mp4', 'http://timg.bdta.pro/images/e587882096a434af214d8b5fa38b9630.jpg'),
(62517, 4238, 'MacGyver - Profissão: Perigo S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/151122.mp4', 'http://timg.bdta.pro/images/401ed7dca96912980726189c9e1852eb.jpg'),
(62518, 4238, 'MacGyver - Profissão: Perigo S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/151123.mp4', 'http://timg.bdta.pro/images/9c26a206ffdb1afe542e07728f7881e0.jpg'),
(62519, 4238, 'MacGyver - Profissão: Perigo S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/151124.mp4', 'http://timg.bdta.pro/images/a55371ddf4d487a9b59172c981185886.jpg'),
(62520, 4238, 'MacGyver - Profissão: Perigo S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/151125.mp4', 'http://timg.bdta.pro/images/d1e04e3a3e86435491738c87f81ff88b.jpg'),
(62521, 4239, 'MacGyver - Profissão: Perigo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151126.mp4', 'http://timg.bdta.pro/images/6c13e4a970d15710b47333f623635398.jpg'),
(62522, 4239, 'MacGyver - Profissão: Perigo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151127.mp4', 'http://timg.bdta.pro/images/b5b3adcab4aa53e2eeac30c8637fa467.jpg'),
(62523, 4239, 'MacGyver - Profissão: Perigo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151128.mp4', 'http://timg.bdta.pro/images/e62619128ac4374b4ed70cf809172433.jpg'),
(62524, 4239, 'MacGyver - Profissão: Perigo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151129.mp4', 'http://timg.bdta.pro/images/f64857a0d3bda726f38ad42a2bb92da4.jpg'),
(62525, 4239, 'MacGyver - Profissão: Perigo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151130.mp4', 'http://timg.bdta.pro/images/81df32e1c970a67cc22b2e2be227ba1a.jpg'),
(62526, 4239, 'MacGyver - Profissão: Perigo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151131.mp4', 'http://timg.bdta.pro/images/0c5a071bca5e1dcbdf35deb4080d03f9.jpg'),
(62527, 4239, 'MacGyver - Profissão: Perigo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151132.mp4', 'http://timg.bdta.pro/images/e43f59ffa07389426dfea1a3c1486ea9.jpg'),
(62528, 4239, 'MacGyver - Profissão: Perigo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151133.mp4', 'http://timg.bdta.pro/images/cf1fe030bb9c28b390051d50f7c7c0b3.jpg'),
(62529, 4239, 'MacGyver - Profissão: Perigo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151134.mp4', 'http://timg.bdta.pro/images/6baa1151d98c8aab7f296af0f5e4421b.jpg'),
(62530, 4239, 'MacGyver - Profissão: Perigo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151135.mp4', 'http://timg.bdta.pro/images/6589349acbd705d7cbff502ba3558d72.jpg'),
(62531, 4239, 'MacGyver - Profissão: Perigo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151136.mp4', 'http://timg.bdta.pro/images/e36186d2407fc2dbdb626bc593c101a0.jpg'),
(62532, 4239, 'MacGyver - Profissão: Perigo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151137.mp4', 'http://timg.bdta.pro/images/35c4d61e7b51d7f7355d00dbcb6bf39f.jpg'),
(62533, 4239, 'MacGyver - Profissão: Perigo S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151138.mp4', 'http://timg.bdta.pro/images/7edf383f310743e40a291d60ff68e506.jpg'),
(62534, 4239, 'MacGyver - Profissão: Perigo S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151139.mp4', 'http://timg.bdta.pro/images/0d1dc606cef36159d30fd6d315f553b0.jpg'),
(62535, 4239, 'MacGyver - Profissão: Perigo S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/151140.mp4', 'http://timg.bdta.pro/images/17606c4ae23c8e8dca3e880bb739f908.jpg'),
(62536, 4239, 'MacGyver - Profissão: Perigo S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/151141.mp4', 'http://timg.bdta.pro/images/7f85843a40153a4b676fd78471f409a7.jpg'),
(62537, 4239, 'MacGyver - Profissão: Perigo S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/151142.mp4', 'http://timg.bdta.pro/images/89cf5861e44863788c81a42edb1a987b.jpg'),
(62538, 4239, 'MacGyver - Profissão: Perigo S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/151143.mp4', 'http://timg.bdta.pro/images/229cb342bd730ff49a770afbc156c784.jpg'),
(62539, 4239, 'MacGyver - Profissão: Perigo S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/151144.mp4', 'http://timg.bdta.pro/images/0796169f542303eeb7762a4f9ccde452.jpg'),
(62540, 4239, 'MacGyver - Profissão: Perigo S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/151145.mp4', 'http://timg.bdta.pro/images/66ba50be5038c31b067904de28c8762d.jpg'),
(62541, 4239, 'MacGyver - Profissão: Perigo S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/151146.mp4', 'http://timg.bdta.pro/images/a9a509adff52231ff73879d6797d504c.jpg'),
(62542, 4239, 'MacGyver - Profissão: Perigo S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/151147.mp4', 'http://timg.bdta.pro/images/c4a9437dbd598f7118ec91f2057ddd2a.jpg'),
(62543, 4240, 'MacGyver - Profissão: Perigo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151148.mp4', 'http://timg.bdta.pro/images/80947d703912bd08430079d1d481197c.jpg'),
(62544, 4240, 'MacGyver - Profissão: Perigo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151149.mp4', 'http://timg.bdta.pro/images/b2896a25ac0d2ee3d7195f004c0f61d5.jpg'),
(62545, 4240, 'MacGyver - Profissão: Perigo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151150.mp4', 'http://timg.bdta.pro/images/334dcf0c89306397b911819b857a99fc.jpg'),
(62546, 4240, 'MacGyver - Profissão: Perigo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151151.mp4', 'http://timg.bdta.pro/images/5af751bf7844f932114fc8eab2bad147.jpg'),
(62547, 4240, 'MacGyver - Profissão: Perigo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151152.mp4', 'http://timg.bdta.pro/images/dc62c88c611054c179079ff62c75fe46.jpg'),
(62548, 4240, 'MacGyver - Profissão: Perigo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151153.mp4', 'http://timg.bdta.pro/images/0dd965b5853720b72be8a454642f3b13.jpg'),
(62549, 4240, 'MacGyver - Profissão: Perigo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151154.mp4', 'http://timg.bdta.pro/images/a386215080f6de0f00651455e41969f9.jpg'),
(62550, 4240, 'MacGyver - Profissão: Perigo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151155.mp4', 'http://timg.bdta.pro/images/db66bd1412fa2c6852ef0981dc47af63.jpg'),
(62551, 4240, 'MacGyver - Profissão: Perigo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151156.mp4', 'http://timg.bdta.pro/images/e8e52325f290695ee501ebb4586e4f48.jpg'),
(62552, 4240, 'MacGyver - Profissão: Perigo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151157.mp4', 'http://timg.bdta.pro/images/a264e52402777b8a10a1d18cb2919357.jpg'),
(62553, 4240, 'MacGyver - Profissão: Perigo S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151158.mp4', 'http://timg.bdta.pro/images/7c3c6f5d3f7e3dcc6d61b60a3fa63e1e.jpg'),
(62554, 4240, 'MacGyver - Profissão: Perigo S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151159.mp4', 'http://timg.bdta.pro/images/6e83bd8de8e09ee37782d49ef98565b6.jpg'),
(62555, 4240, 'MacGyver - Profissão: Perigo S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151160.mp4', 'http://timg.bdta.pro/images/199b082a87f57fb1fa5fc65a0e152b85.jpg'),
(62556, 4240, 'MacGyver - Profissão: Perigo S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151161.mp4', 'http://timg.bdta.pro/images/dc439ecb4b67a25bc9dcf21ca54e15fc.jpg'),
(62557, 4240, 'MacGyver - Profissão: Perigo S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/151162.mp4', 'http://timg.bdta.pro/images/07b4fc96f3c2c632689291fc5209df99.jpg'),
(62558, 4240, 'MacGyver - Profissão: Perigo S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/151163.mp4', 'http://timg.bdta.pro/images/ee773c6c3316d5229ff846d4bb2ee95e.jpg'),
(62559, 4240, 'MacGyver - Profissão: Perigo S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/151164.mp4', 'http://timg.bdta.pro/images/e33245ae3c987d25ace9b3f5ad0e05bc.jpg'),
(62560, 4240, 'MacGyver - Profissão: Perigo S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/151165.mp4', 'http://timg.bdta.pro/images/ed26988d610decdad5ccd3636fd8475f.jpg'),
(62561, 4240, 'MacGyver - Profissão: Perigo S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/151166.mp4', 'http://timg.bdta.pro/images/d17813ac8508c14e27c749d2f7e488d1.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(62562, 4240, 'MacGyver - Profissão: Perigo S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/151167.mp4', 'http://timg.bdta.pro/images/c64710386517856066ebe7953de73f9b.jpg'),
(62563, 4241, 'MacGyver - Profissão: Perigo S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151168.mp4', 'http://timg.bdta.pro/images/a81e9157bf8c6113b5beedfead1f6534.jpg'),
(62564, 4241, 'MacGyver - Profissão: Perigo S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151169.mp4', 'http://timg.bdta.pro/images/2a22c9366cdef29fea6e3f84803da337.jpg'),
(62565, 4241, 'MacGyver - Profissão: Perigo S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151170.mp4', 'http://timg.bdta.pro/images/35215246ec8aeb4502f890307657060f.jpg'),
(62566, 4241, 'MacGyver - Profissão: Perigo S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151171.mp4', 'http://timg.bdta.pro/images/66d13462c682a5753becd1c80ab6e74f.jpg'),
(62567, 4241, 'MacGyver - Profissão: Perigo S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151172.mp4', 'http://timg.bdta.pro/images/4e795269bc8433952a94c6f0ec47be5c.jpg'),
(62568, 4241, 'MacGyver - Profissão: Perigo S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151173.mp4', 'http://timg.bdta.pro/images/e64c184002920f7d4a20bc9ee4b63887.jpg'),
(62569, 4241, 'MacGyver - Profissão: Perigo S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151174.mp4', 'http://timg.bdta.pro/images/0c698fda6226ef03ed59bd40c7746a7e.jpg'),
(62570, 4241, 'MacGyver - Profissão: Perigo S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151175.mp4', 'http://timg.bdta.pro/images/5fc8c705375aa57458e65ad4e4c3caf4.jpg'),
(62571, 4241, 'MacGyver - Profissão: Perigo S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151176.mp4', 'http://timg.bdta.pro/images/335f6a90660b1b8de2d0e95b1ee67afe.jpg'),
(62572, 4241, 'MacGyver - Profissão: Perigo S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151177.mp4', 'http://timg.bdta.pro/images/e8094bde3d766e261c56c0dbeb549820.jpg'),
(62573, 4241, 'MacGyver - Profissão: Perigo S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151178.mp4', 'http://timg.bdta.pro/images/2cb2b0a8e7a6d1f62a01cdbb7ca76123.jpg'),
(62574, 4241, 'MacGyver - Profissão: Perigo S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151179.mp4', 'http://timg.bdta.pro/images/8056e5d9802907f673a84bf1dad232b0.jpg'),
(62575, 4241, 'MacGyver - Profissão: Perigo S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151180.mp4', 'http://timg.bdta.pro/images/399adb2a61c24745ebe8048b199dd96f.jpg'),
(62576, 4241, 'MacGyver - Profissão: Perigo S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151181.mp4', 'http://timg.bdta.pro/images/2673fd94ceefc5cd6f33674414adff1f.jpg'),
(62577, 4241, 'MacGyver - Profissão: Perigo S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/151182.mp4', 'http://timg.bdta.pro/images/e1cbed42dd91df3370a4e9d15e8a8b97.jpg'),
(62578, 4241, 'MacGyver - Profissão: Perigo S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/151183.mp4', 'http://timg.bdta.pro/images/d578fd737ba1b7ab1c6e09db115842e5.jpg'),
(62579, 4241, 'MacGyver - Profissão: Perigo S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/151184.mp4', 'http://timg.bdta.pro/images/98178b08d1595a923d868c6614ef3acc.jpg'),
(62580, 4241, 'MacGyver - Profissão: Perigo S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/151185.mp4', 'http://timg.bdta.pro/images/885150355529664ba11c5a2da6719f39.jpg'),
(62581, 4241, 'MacGyver - Profissão: Perigo S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/151186.mp4', 'http://timg.bdta.pro/images/91ec2c74e0075a8caa19ff1f0f52783b.jpg'),
(62582, 4242, 'MacGyver - Profissão: Perigo S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151187.mp4', 'http://timg.bdta.pro/images/84718801396edfd183582be8fbe5f3e8.jpg'),
(62583, 4242, 'MacGyver - Profissão: Perigo S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151188.mp4', 'http://timg.bdta.pro/images/db391e41d9300d0a340ddb455171f2e5.jpg'),
(62584, 4242, 'MacGyver - Profissão: Perigo S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151189.mp4', 'http://timg.bdta.pro/images/5603912d821b43ade9b2f199f2467ad4.jpg'),
(62585, 4242, 'MacGyver - Profissão: Perigo S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151190.mp4', 'http://timg.bdta.pro/images/deb1b6b5b0a27ef2efa2b18267f14bd9.jpg'),
(62586, 4242, 'MacGyver - Profissão: Perigo S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151191.mp4', 'http://timg.bdta.pro/images/d8216fcaa2097993edd6b5cdc8c61700.jpg'),
(62587, 4242, 'MacGyver - Profissão: Perigo S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151192.mp4', 'http://timg.bdta.pro/images/6864a9b3fd34c3f3be3dbdedcdd3309c.jpg'),
(62588, 4242, 'MacGyver - Profissão: Perigo S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151193.mp4', 'http://timg.bdta.pro/images/bbc648aaace687ddb3b06a20ad21a22c.jpg'),
(62589, 4242, 'MacGyver - Profissão: Perigo S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151194.mp4', 'http://timg.bdta.pro/images/74970bd4e37a02b12cd749f1428a15fd.jpg'),
(62590, 4242, 'MacGyver - Profissão: Perigo S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151195.mp4', 'http://timg.bdta.pro/images/6b19ae38a5d05f757b500e5226833e8a.jpg'),
(62591, 4242, 'MacGyver - Profissão: Perigo S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151196.mp4', 'http://timg.bdta.pro/images/819da5b610a7a54818a636e50da6b198.jpg'),
(62592, 4242, 'MacGyver - Profissão: Perigo S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151197.mp4', 'http://timg.bdta.pro/images/4ffb044289d4dd144057bb5b966d7ffe.jpg'),
(62593, 4242, 'MacGyver - Profissão: Perigo S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151198.mp4', 'http://timg.bdta.pro/images/d33d5d334a6347e1be1ce500c676dfa6.jpg'),
(62594, 4242, 'MacGyver - Profissão: Perigo S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151199.mp4', 'http://timg.bdta.pro/images/e3f2465ac3a3ad0c86b6d76bdc3bd512.jpg'),
(62595, 4242, 'MacGyver - Profissão: Perigo S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151200.mp4', 'http://timg.bdta.pro/images/1e77439a0bcb0c82003c3b4d137fee22.jpg'),
(62596, 4242, 'MacGyver - Profissão: Perigo S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/151201.mp4', 'http://timg.bdta.pro/images/21866eefeb6278ec8b1b2bf20e968fed.jpg'),
(62597, 4242, 'MacGyver - Profissão: Perigo S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/151202.mp4', 'http://timg.bdta.pro/images/71e54138d233030830114ce28dff571b.jpg'),
(62598, 4242, 'MacGyver - Profissão: Perigo S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/151203.mp4', 'http://timg.bdta.pro/images/e9a98e2d0df7305ef4af62a69e2269b7.jpg'),
(62599, 4242, 'MacGyver - Profissão: Perigo S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/151204.mp4', 'http://timg.bdta.pro/images/bb485f19efbe545e1650228b5337551c.jpg'),
(62600, 4242, 'MacGyver - Profissão: Perigo S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/151205.mp4', 'http://timg.bdta.pro/images/1be7a60808b424aea3366f8715f6ddbc.jpg'),
(62601, 4242, 'MacGyver - Profissão: Perigo S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/151206.mp4', 'http://timg.bdta.pro/images/0295c0cd3e9403e2b3d7e72f1e6e3adf.jpg'),
(62602, 4242, 'MacGyver - Profissão: Perigo S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/151207.mp4', 'http://timg.bdta.pro/images/92cc7b017f1902ff05710614effbe176.jpg'),
(62603, 4243, 'MacGyver - Profissão: Perigo S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151208.mp4', 'http://timg.bdta.pro/images/7ee0b475b29a5c53a03d658ad9f99511.jpg'),
(62604, 4243, 'MacGyver - Profissão: Perigo S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151209.mp4', 'http://timg.bdta.pro/images/7055161e3c3f6f13e1c65875b476f289.jpg'),
(62605, 4243, 'MacGyver - Profissão: Perigo S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151210.mp4', 'http://timg.bdta.pro/images/b5f9635afbc4637324e966e94c74dcb5.jpg'),
(62606, 4243, 'MacGyver - Profissão: Perigo S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151211.mp4', 'http://timg.bdta.pro/images/e3918926629093873af5b35271feecc3.jpg'),
(62607, 4243, 'MacGyver - Profissão: Perigo S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151212.mp4', 'http://timg.bdta.pro/images/aa110500ac36dc20d66e4e42ccbfaa4e.jpg'),
(62608, 4243, 'MacGyver - Profissão: Perigo S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151213.mp4', 'http://timg.bdta.pro/images/28ac3f0de27b07a0c607c607f7703987.jpg'),
(62609, 4243, 'MacGyver - Profissão: Perigo S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151214.mp4', 'http://timg.bdta.pro/images/bddfff725ca1a1d2ebb89d6586a9090c.jpg'),
(62610, 4243, 'MacGyver - Profissão: Perigo S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151215.mp4', 'http://timg.bdta.pro/images/5ccad67038aabb42561b9924bf898cae.jpg'),
(62611, 4243, 'MacGyver - Profissão: Perigo S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151216.mp4', 'http://timg.bdta.pro/images/4cf75046969c550ce0c2a013c7425ba8.jpg'),
(62612, 4243, 'MacGyver - Profissão: Perigo S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151217.mp4', 'http://timg.bdta.pro/images/811d14420ff96e7405b00575ae64e7f7.jpg'),
(62613, 4243, 'MacGyver - Profissão: Perigo S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151218.mp4', 'http://timg.bdta.pro/images/ed2dea107df2d7cf3bdd57bebc9e21ce.jpg'),
(62614, 4243, 'MacGyver - Profissão: Perigo S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151219.mp4', 'http://timg.bdta.pro/images/46f79b609d302ec2609ac0816ac74867.jpg'),
(62615, 4243, 'MacGyver - Profissão: Perigo S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151220.mp4', 'http://timg.bdta.pro/images/27a989ac10b38d7cca7e119a3b89bd17.jpg'),
(62616, 4243, 'MacGyver - Profissão: Perigo S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151221.mp4', 'http://timg.bdta.pro/images/dde5cdc0e9d35064e07bda27bdd1ed94.jpg'),
(62617, 4243, 'MacGyver - Profissão: Perigo S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/151222.mp4', 'http://timg.bdta.pro/images/8fbf37a9f2e18d30f35cd22a38dfcbfe.jpg'),
(62618, 4243, 'MacGyver - Profissão: Perigo S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/151223.mp4', 'http://timg.bdta.pro/images/dac6d8e92afc234201a6fd390c13c2b1.jpg'),
(62619, 4243, 'MacGyver - Profissão: Perigo S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/151224.mp4', 'http://timg.bdta.pro/images/9e36a2bff6eaacdd94112370e625f610.jpg'),
(62620, 4243, 'MacGyver - Profissão: Perigo S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/151225.mp4', 'http://timg.bdta.pro/images/2d4d2301c563bafe450b733af70c091b.jpg'),
(62621, 4243, 'MacGyver - Profissão: Perigo S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/151226.mp4', 'http://timg.bdta.pro/images/0b24dcdbd15111ccd691897b51095eab.jpg'),
(62622, 4243, 'MacGyver - Profissão: Perigo S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/151227.mp4', 'http://timg.bdta.pro/images/f8a9896fea55ac9d2541c78648f2df12.jpg'),
(62623, 4243, 'MacGyver - Profissão: Perigo S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/151228.mp4', 'http://timg.bdta.pro/images/ef2a446ec77a3fd9f9d1e046eb13e288.jpg'),
(62624, 4244, 'MacGyver - Profissão: Perigo S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151229.mp4', 'http://timg.bdta.pro/images/0800ad776b4fa535461367f08476b74a.jpg'),
(62625, 4244, 'MacGyver - Profissão: Perigo S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151230.mp4', 'http://timg.bdta.pro/images/ad14e31e8d5226f58acd3e991e003fb9.jpg'),
(62626, 4244, 'MacGyver - Profissão: Perigo S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151231.mp4', 'http://timg.bdta.pro/images/9ba5415813054b0b3774c03708869737.jpg'),
(62627, 4244, 'MacGyver - Profissão: Perigo S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151232.mp4', 'http://timg.bdta.pro/images/c0ebdf1c0149a30e18f26a65657f5797.jpg'),
(62628, 4244, 'MacGyver - Profissão: Perigo S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151233.mp4', 'http://timg.bdta.pro/images/239382822c53eb2bfb7e0285450b55f9.jpg'),
(62629, 4244, 'MacGyver - Profissão: Perigo S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151234.mp4', 'http://timg.bdta.pro/images/b9f0a961b641e25ad8adb104b91eef91.jpg'),
(62630, 4244, 'MacGyver - Profissão: Perigo S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151235.mp4', 'http://timg.bdta.pro/images/b0a000c4ae521c9410a2f26f77d53d3a.jpg'),
(62631, 4244, 'MacGyver - Profissão: Perigo S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151236.mp4', 'http://timg.bdta.pro/images/798ef3c9992c853c15d0dfe10d2edf40.jpg'),
(62632, 4244, 'MacGyver - Profissão: Perigo S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151237.mp4', 'http://timg.bdta.pro/images/f16cc63095724afbf86bd0ccbe7897c9.jpg'),
(62633, 4244, 'MacGyver - Profissão: Perigo S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151238.mp4', 'http://timg.bdta.pro/images/be7eeb067fc6f7b32aef33abb678569a.jpg'),
(62634, 4244, 'MacGyver - Profissão: Perigo S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151239.mp4', 'http://timg.bdta.pro/images/af1d7a904aee29328b2ada4e3015bf57.jpg'),
(62635, 4244, 'MacGyver - Profissão: Perigo S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151240.mp4', 'http://timg.bdta.pro/images/c436a85e9913c3094b40231451ddab39.jpg'),
(62636, 4244, 'MacGyver - Profissão: Perigo S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151241.mp4', 'http://timg.bdta.pro/images/8fda36be5c18f43fb26e44f9ab8ab6a1.jpg'),
(62637, 4244, 'MacGyver - Profissão: Perigo S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151242.mp4', 'http://timg.bdta.pro/images/28508448473e7f2e5d42fa0aa5c66cb5.jpg'),
(62638, 4245, 'Made for Love S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179813.mp4', 'http://timg.bdta.pro/images/b49b9fa62eb5da517b217c4d83b8a720.jpg'),
(62639, 4245, 'Made for Love S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179814.mp4', 'http://timg.bdta.pro/images/304851be1e74fc3392e8017c4a78987c.jpg'),
(62640, 4245, 'Made for Love S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179815.mp4', 'http://timg.bdta.pro/images/9766dc83e654778631fb33e65b1ed640.jpg'),
(62641, 4245, 'Made for Love S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179816.mp4', 'http://timg.bdta.pro/images/0d6ad44b4e6525a9197244086046e63f.jpg'),
(62642, 4245, 'Made for Love S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179817.mp4', 'http://timg.bdta.pro/images/5651718e7716d3843b8b288ca689c7aa.jpg'),
(62643, 4245, 'Made for Love S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179818.mp4', 'http://timg.bdta.pro/images/3905deb5539f98684f78c9b714341f4d.jpg'),
(62644, 4245, 'Made for Love S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179819.mp4', 'http://timg.bdta.pro/images/16497e0798e5964614ff0de41cf13c90.jpg'),
(62645, 4245, 'Made for Love S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179820.mp4', 'http://timg.bdta.pro/images/d8e5fcaa0ff6a87e8370e2d397f6c4f8.jpg'),
(62646, 4246, 'Made for Love S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179821.mp4', 'http://timg.bdta.pro/images/d8aaa77a48971e7f39d6f591f51b97e7.jpg'),
(62647, 4246, 'Made for Love S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179822.mp4', 'http://timg.bdta.pro/images/5d6e29efb952ab5f7e88e636e1959f50.jpg'),
(62648, 4246, 'Made for Love S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179823.mp4', 'http://timg.bdta.pro/images/15b889f4096b09a373780edc0cf1ecb1.jpg'),
(62649, 4246, 'Made for Love S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179824.mp4', 'http://timg.bdta.pro/images/ae1a12e9be2ec7d3ec1e4ae0e6870e04.jpg'),
(62650, 4246, 'Made for Love S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179825.mp4', 'http://timg.bdta.pro/images/a7cc789ed3f6db19d5110d60f6c00e83.jpg'),
(62651, 4246, 'Made for Love S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179826.mp4', 'http://timg.bdta.pro/images/edea44558101ae7cc7f6f3374526b7e3.jpg'),
(62652, 4246, 'Made for Love S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179827.mp4', 'http://timg.bdta.pro/images/d528662cab2b5da185c0f4e6490309a5.jpg'),
(62653, 4246, 'Made for Love S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179828.mp4', 'http://timg.bdta.pro/images/a1d922c05abd2222cabaef4211f5844c.jpg'),
(62654, 4247, 'Os Herculóides S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/151086.mp4', 'http://timg.bdta.pro/images/466d43f538a42d5e502e86ccebb10002.jpg'),
(62655, 4247, 'Os Herculóides S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/151087.mp4', 'http://timg.bdta.pro/images/d80c9ee496e9be4fdd468a27c1cf06d8.jpg'),
(62656, 4247, 'Os Herculóides S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/151088.mp4', 'http://timg.bdta.pro/images/839bfd97768a5b8211e4d161511d0f64.jpg'),
(62657, 4247, 'Os Herculóides S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/151089.mp4', 'http://timg.bdta.pro/images/6a4d237911edad525f0e245c0032f0fa.jpg'),
(62658, 4247, 'Os Herculóides S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/151090.mp4', 'http://timg.bdta.pro/images/92ef511e4d4243f33b59560067279d5b.jpg'),
(62659, 4247, 'Os Herculóides S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/151091.mp4', 'http://timg.bdta.pro/images/d4d5f0ecfecf21a66e5ff4aa155379ee.jpg'),
(62660, 4247, 'Os Herculóides S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/151092.mp4', 'http://timg.bdta.pro/images/ae453076536db647bd05c33671b6853a.jpg'),
(62661, 4247, 'Os Herculóides S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/151093.mp4', 'http://timg.bdta.pro/images/654c4c2758bf19c7df6a8837b6704a0b.jpg'),
(62662, 4247, 'Os Herculóides S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/151094.mp4', 'http://timg.bdta.pro/images/262c6285df13d3332b977ae42b1d02d6.jpg'),
(62663, 4247, 'Os Herculóides S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/151095.mp4', 'http://timg.bdta.pro/images/512ace883ee33112087fb9f614d36a94.jpg'),
(62664, 4247, 'Os Herculóides S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/151096.mp4', 'http://timg.bdta.pro/images/1ef76ae7c4ee1199ffb3d5081ecfefca.jpg'),
(62665, 4247, 'Os Herculóides S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/151097.mp4', 'http://timg.bdta.pro/images/1849ea7d4984e7236ea97d1cd590d880.jpg'),
(62666, 4247, 'Os Herculóides S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/151098.mp4', 'http://timg.bdta.pro/images/77df1f3c5b8b679eaf7d81004b0ebc4e.jpg'),
(62667, 4247, 'Os Herculóides S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/151099.mp4', 'http://timg.bdta.pro/images/b623bb91e230869e5124c1d10da93b93.jpg'),
(62668, 4247, 'Os Herculóides S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/151100.mp4', 'http://timg.bdta.pro/images/6ad59e49776a5cf671f0979879d6696e.jpg'),
(62669, 4247, 'Os Herculóides S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/151101.mp4', 'http://timg.bdta.pro/images/4536c5293267ee08e20c59634b187ddb.jpg'),
(62670, 4247, 'Os Herculóides S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/151102.mp4', 'http://timg.bdta.pro/images/76dc71c0d799b2f3bcbe4b2a65d03052.jpg'),
(62671, 4247, 'Os Herculóides S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/151103.mp4', 'http://timg.bdta.pro/images/f431e847444d74fe365d1165e46af5c5.jpg'),
(62672, 4248, 'A Casa Mágica da Gabby S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204597.mp4', 'http://timg.bdta.pro/images/76b3483023c2e980fa93231f2670771a.jpg'),
(62673, 4248, 'A Casa Mágica da Gabby S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204598.mp4', 'http://timg.bdta.pro/images/157ea40c824798cda74d4a5f9c3aab16.jpg'),
(62674, 4248, 'A Casa Mágica da Gabby S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204599.mp4', 'http://timg.bdta.pro/images/48be4a57dfa5e8b22ce5070c62e96b65.jpg'),
(62675, 4248, 'A Casa Mágica da Gabby S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204600.mp4', 'http://timg.bdta.pro/images/469acc674ca4801c5fb729c5df736f93.jpg'),
(62676, 4248, 'A Casa Mágica da Gabby S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204601.mp4', 'http://timg.bdta.pro/images/7481601397e7b3a9846626b6b02ca9c8.jpg'),
(62677, 4248, 'A Casa Mágica da Gabby S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204602.mp4', 'http://timg.bdta.pro/images/eeec29ccb6f34c16cd12c4f9ddc13564.jpg'),
(62678, 4248, 'A Casa Mágica da Gabby S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204603.mp4', 'http://timg.bdta.pro/images/706d8b7179128cdc1a882b20732f5f33.jpg'),
(62679, 4248, 'A Casa Mágica da Gabby S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204604.mp4', 'http://timg.bdta.pro/images/8f3a911e12d37aa279a8c00bc382373c.jpg'),
(62680, 4248, 'A Casa Mágica da Gabby S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204605.mp4', 'http://timg.bdta.pro/images/3ffd9cf9983fdb4b96573f6fbf0e7dc1.jpg'),
(62681, 4248, 'A Casa Mágica da Gabby S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204606.mp4', 'http://timg.bdta.pro/images/c486d2321f2b9813544c6a2944376380.jpg'),
(62682, 4249, 'A Casa Mágica da Gabby S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204607.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62683, 4249, 'A Casa Mágica da Gabby S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204608.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62684, 4249, 'A Casa Mágica da Gabby S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204609.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62685, 4249, 'A Casa Mágica da Gabby S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204610.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62686, 4249, 'A Casa Mágica da Gabby S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204611.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62687, 4249, 'A Casa Mágica da Gabby S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204612.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62688, 4249, 'A Casa Mágica da Gabby S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204613.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62689, 4249, 'A Casa Mágica da Gabby S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204614.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62690, 4250, 'A Casa Mágica da Gabby S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204615.mp4', 'http://timg.bdta.pro/images/010f92a9d781b4c3de92ec2d0aaf2488.jpg'),
(62691, 4250, 'A Casa Mágica da Gabby S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204616.mp4', 'http://timg.bdta.pro/images/650ccfca9484cd9419f35a701e80f913.jpg'),
(62692, 4250, 'A Casa Mágica da Gabby S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204617.mp4', 'http://timg.bdta.pro/images/74aba9f944ac2357106ffd36fa20ef86.jpg'),
(62693, 4250, 'A Casa Mágica da Gabby S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204618.mp4', 'http://timg.bdta.pro/images/eb05e88afe757942d6c8d9f8c84e42ff.jpg'),
(62694, 4250, 'A Casa Mágica da Gabby S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204619.mp4', 'http://timg.bdta.pro/images/86d85e1a9012aaadf6615140b965b0dc.jpg'),
(62695, 4250, 'A Casa Mágica da Gabby S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204620.mp4', 'http://timg.bdta.pro/images/4b2ab25bd532e9c3978d4a14bc2fa537.jpg'),
(62696, 4250, 'A Casa Mágica da Gabby S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204621.mp4', 'http://timg.bdta.pro/images/9b9e8a3b3fc1fe995c67384ec665fe75.jpg'),
(62697, 4251, 'A Casa Mágica da Gabby S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204622.mp4', 'http://timg.bdta.pro/images/b74828ba789523367e81eb1ee1249dea.jpg'),
(62698, 4251, 'A Casa Mágica da Gabby S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204623.mp4', 'http://timg.bdta.pro/images/e4adcfc8b88d6afedaec97f2e1ebb343.jpg'),
(62699, 4251, 'A Casa Mágica da Gabby S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204624.mp4', 'http://timg.bdta.pro/images/c3a526861acc0a093e1f5e92a3cba67b.jpg'),
(62700, 4251, 'A Casa Mágica da Gabby S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204625.mp4', 'http://timg.bdta.pro/images/8edca8e41fd5399f0741492b60161bf7.jpg'),
(62701, 4251, 'A Casa Mágica da Gabby S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204626.mp4', 'http://timg.bdta.pro/images/fc80b674a2819a0a16cb3909bf5fe26d.jpg'),
(62702, 4251, 'A Casa Mágica da Gabby S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204627.mp4', 'http://timg.bdta.pro/images/8636500827bd249b98907d0b9c3fe88c.jpg'),
(62703, 4251, 'A Casa Mágica da Gabby S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204628.mp4', 'http://timg.bdta.pro/images/ac2b38fdad196512eb6ddd684bb8f298.jpg'),
(62704, 4251, 'A Casa Mágica da Gabby S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204629.mp4', 'http://timg.bdta.pro/images/5bbdc3484695d34e4f6fd79a8963ac7c.jpg'),
(62705, 4252, 'A Casa Mágica da Gabby S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204630.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62706, 4252, 'A Casa Mágica da Gabby S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204631.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62707, 4252, 'A Casa Mágica da Gabby S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204632.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62708, 4252, 'A Casa Mágica da Gabby S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204633.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62709, 4252, 'A Casa Mágica da Gabby S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204634.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62710, 4252, 'A Casa Mágica da Gabby S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204635.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62711, 4253, 'A Casa Mágica da Gabby S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jRKESZwYmhdl1zntsdRnC4sHseR.jpg'),
(62712, 4253, 'A Casa Mágica da Gabby S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y50F0EOvoMQqh0lDWfArWtNozeV.jpg'),
(62713, 4253, 'A Casa Mágica da Gabby S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lm6ZCjBc2aRoQagM7ZAkool5Hqb.jpg'),
(62714, 4253, 'A Casa Mágica da Gabby S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ZzOVJhxHnODZH15k0JkBAA3aLm.jpg'),
(62715, 4253, 'A Casa Mágica da Gabby S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/frcOYTMYIEi9F944tClzY83vq7z.jpg'),
(62716, 4253, 'A Casa Mágica da Gabby S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ErIcHKPt6FkbZ5gRkTrlkNIYOi.jpg'),
(62717, 4254, 'A Casa Mágica da Gabby S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/346577.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62718, 4254, 'A Casa Mágica da Gabby S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/346578.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62719, 4254, 'A Casa Mágica da Gabby S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/346579.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62720, 4254, 'A Casa Mágica da Gabby S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/346580.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62721, 4254, 'A Casa Mágica da Gabby S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/346581.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62722, 4254, 'A Casa Mágica da Gabby S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/346582.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62723, 4255, 'A Casa Mágica da Gabby S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326400.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62724, 4255, 'A Casa Mágica da Gabby S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326401.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62725, 4255, 'A Casa Mágica da Gabby S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326402.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62726, 4255, 'A Casa Mágica da Gabby S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/326403.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62727, 4255, 'A Casa Mágica da Gabby S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/326404.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62728, 4255, 'A Casa Mágica da Gabby S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/326405.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62729, 4256, 'A Casa Mágica da Gabby S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/325285.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62730, 4256, 'A Casa Mágica da Gabby S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325286.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62731, 4256, 'A Casa Mágica da Gabby S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325287.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62732, 4256, 'A Casa Mágica da Gabby S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325288.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62733, 4256, 'A Casa Mágica da Gabby S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325289.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62734, 4256, 'A Casa Mágica da Gabby S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/325290.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62735, 4257, 'A Casa Mágica da Gabby S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/700358.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62736, 4257, 'A Casa Mágica da Gabby S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/700359.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62737, 4257, 'A Casa Mágica da Gabby S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/700360.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62738, 4257, 'A Casa Mágica da Gabby S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/700361.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62739, 4257, 'A Casa Mágica da Gabby S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/700362.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62740, 4257, 'A Casa Mágica da Gabby S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/700363.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62741, 4258, 'A Casa Mágica da Gabby S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/700364.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62742, 4258, 'A Casa Mágica da Gabby S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/700365.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62743, 4258, 'A Casa Mágica da Gabby S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/700366.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62744, 4258, 'A Casa Mágica da Gabby S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/700367.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62745, 4258, 'A Casa Mágica da Gabby S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/700368.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62746, 4258, 'A Casa Mágica da Gabby S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/700369.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62747, 4259, 'A Casa Mágica da Gabby S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/893401.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62748, 4259, 'A Casa Mágica da Gabby S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/893402.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62749, 4259, 'A Casa Mágica da Gabby S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/893403.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62750, 4259, 'A Casa Mágica da Gabby S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/893404.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62751, 4259, 'A Casa Mágica da Gabby S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/893405.mp4', 'http://gstaticontent.com/images/165d6b4879d3d6133f893172b7b2b191.jpg'),
(62752, 4260, 'A Misteriosa Sociedade Benedict S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204026.mp4', 'http://timg.bdta.pro/images/7655234b17dbd8e44f9622ff72bc596e.jpg'),
(62753, 4260, 'A Misteriosa Sociedade Benedict S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204027.mp4', 'http://timg.bdta.pro/images/eaf71858b39f83640c9cc3bddef03514.jpg'),
(62754, 4260, 'A Misteriosa Sociedade Benedict S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204028.mp4', 'http://timg.bdta.pro/images/456b4ab868151d506fc497b3a20ad198.jpg'),
(62755, 4260, 'A Misteriosa Sociedade Benedict S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204029.mp4', 'http://timg.bdta.pro/images/9717d369d024d23d63ce776cdf47bac2.jpg'),
(62756, 4260, 'A Misteriosa Sociedade Benedict S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204030.mp4', 'http://timg.bdta.pro/images/69468fff5f8a88de7ce35babca84562d.jpg'),
(62757, 4260, 'A Misteriosa Sociedade Benedict S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204031.mp4', 'http://timg.bdta.pro/images/d3ea6beab36ebe3cf5b52e88719a56a4.jpg'),
(62758, 4260, 'A Misteriosa Sociedade Benedict S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204032.mp4', 'http://timg.bdta.pro/images/4de12964705b84eb950d9c84cbe35847.jpg'),
(62759, 4260, 'A Misteriosa Sociedade Benedict S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204033.mp4', 'http://timg.bdta.pro/images/d096aab449cc324b3411315556f14cef.jpg'),
(62760, 4261, 'A Misteriosa Sociedade Benedict S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gFKf9yVC4Bzc8Qpvoz2H9YFxaDx.jpg'),
(62761, 4261, 'A Misteriosa Sociedade Benedict S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i2CoSe9Xy96yqsAlSFlOhO71tWG.jpg'),
(62762, 4261, 'A Misteriosa Sociedade Benedict S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c3WLCwTFFHpzYeJGLl7V61ZTFPm.jpg'),
(62763, 4261, 'A Misteriosa Sociedade Benedict S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204037.mp4', 'http://image.tmdb.org/t/p/w1280/vgkJte45tutkAXOiUtFvpXtcNfg.jpg'),
(62764, 4261, 'A Misteriosa Sociedade Benedict S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r4BluYPHeUxKQMTpbsSHidPPTdQ.jpg'),
(62765, 4261, 'A Misteriosa Sociedade Benedict S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z9OuU3XMGFaNRn19O7vgD9FmKj5.jpg'),
(62766, 4261, 'A Misteriosa Sociedade Benedict S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204040.mp4', 'http://image.tmdb.org/t/p/w1280/idrnD2mtYLavBJ0uRwlJ3mF9lQX.jpg'),
(62767, 4261, 'A Misteriosa Sociedade Benedict S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204041.mp4', 'http://image.tmdb.org/t/p/w1280/6QUocNrWO6D4RU8rnUgndcPf4H.jpg'),
(62768, 4262, 'American Dad! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255554.mp4', 'http://timg.bdta.pro/images/02332a02657d5f0b35a4917973d76393.jpg'),
(62769, 4262, 'American Dad! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255555.mp4', 'http://timg.bdta.pro/images/daaa3b4724603980153719d1fa3d2f7a.jpg'),
(62770, 4262, 'American Dad! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255556.mp4', 'http://timg.bdta.pro/images/efb730b91889fe9d391466a20e536b70.jpg'),
(62771, 4262, 'American Dad! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255557.mp4', 'http://timg.bdta.pro/images/1368b837ac23cd4d2f266ff6455ef6a9.jpg'),
(62772, 4262, 'American Dad! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255558.mp4', 'http://timg.bdta.pro/images/97b48c7405538852db37a7e6a8a7d45c.jpg'),
(62773, 4262, 'American Dad! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255559.mp4', 'http://timg.bdta.pro/images/0bbe0ed48fb3bad0b92b52c9a4d32baa.jpg'),
(62774, 4262, 'American Dad! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255560.mp4', 'http://timg.bdta.pro/images/bf9771d2231e7844e5fdb32535bbdf16.jpg'),
(62775, 4262, 'American Dad! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255561.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62776, 4262, 'American Dad! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255562.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62777, 4262, 'American Dad! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255563.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62778, 4262, 'American Dad! S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255564.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62779, 4262, 'American Dad! S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255565.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62780, 4262, 'American Dad! S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255566.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62781, 4262, 'American Dad! S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255567.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62782, 4262, 'American Dad! S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255568.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62783, 4262, 'American Dad! S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255569.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62784, 4262, 'American Dad! S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255570.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62785, 4262, 'American Dad! S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255571.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62786, 4262, 'American Dad! S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255572.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62787, 4262, 'American Dad! S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255573.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62788, 4262, 'American Dad! S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/255574.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62789, 4262, 'American Dad! S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/255575.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62790, 4262, 'American Dad! S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/255576.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62791, 4263, 'American Dad! S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255577.mp4', 'http://timg.bdta.pro/images/03a6e9e3463dd612322befdb5978d42c.jpg'),
(62792, 4263, 'American Dad! S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255578.mp4', 'http://timg.bdta.pro/images/4f0583354be53d49e0bd60654d106e0b.jpg'),
(62793, 4263, 'American Dad! S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255579.mp4', 'http://timg.bdta.pro/images/5fbc74bb2b22e6d0e52bf1948bac275e.jpg'),
(62794, 4263, 'American Dad! S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255580.mp4', 'http://timg.bdta.pro/images/36337d5600a8ab4b35f58b5989e909f8.jpg'),
(62795, 4263, 'American Dad! S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255581.mp4', 'http://timg.bdta.pro/images/b7f1179bf97f7b38927e1cf9c12ff789.jpg'),
(62796, 4263, 'American Dad! S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255582.mp4', 'http://timg.bdta.pro/images/78459208b0dea3ef7a31000b20066f89.jpg'),
(62797, 4263, 'American Dad! S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255583.mp4', 'http://timg.bdta.pro/images/d55ecf66ae664623c5990ab1761079df.jpg'),
(62798, 4263, 'American Dad! S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255584.mp4', 'http://timg.bdta.pro/images/c8f968ea02ab5ef003d005b84dcf0528.jpg'),
(62799, 4263, 'American Dad! S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255585.mp4', 'http://timg.bdta.pro/images/3425bb877c6b76ddea9bb4ff0b2b8996.jpg'),
(62800, 4263, 'American Dad! S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255586.mp4', 'http://timg.bdta.pro/images/9d2aacbeebd52e41d6c974b557fc5814.jpg'),
(62801, 4263, 'American Dad! S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255587.mp4', 'http://timg.bdta.pro/images/f8871199bb55e664515d4450775f78f9.jpg'),
(62802, 4263, 'American Dad! S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255588.mp4', 'http://timg.bdta.pro/images/27345caafc12d399536c586f1d459823.jpg'),
(62803, 4263, 'American Dad! S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255589.mp4', 'http://timg.bdta.pro/images/f5bdde1d6fbcb773d6b9ab9de068673d.jpg'),
(62804, 4263, 'American Dad! S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255590.mp4', 'http://timg.bdta.pro/images/f558a0649d31cd6f29e89284e0ee455a.jpg'),
(62805, 4263, 'American Dad! S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255591.mp4', 'http://timg.bdta.pro/images/26cc56f01f01658b65eac2df58ae4241.jpg'),
(62806, 4263, 'American Dad! S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255592.mp4', 'http://timg.bdta.pro/images/4a328e130287350ed071e234d28dafe6.jpg'),
(62807, 4263, 'American Dad! S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255593.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62808, 4263, 'American Dad! S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255594.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62809, 4263, 'American Dad! S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255595.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62810, 4264, 'American Dad! S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255596.mp4', 'http://timg.bdta.pro/images/650740491e515a849013caec0a0e548f.jpg'),
(62811, 4264, 'American Dad! S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255597.mp4', 'http://timg.bdta.pro/images/cce2e39fbc04affa6cd70bd50ab8e8a1.jpg'),
(62812, 4264, 'American Dad! S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255598.mp4', 'http://timg.bdta.pro/images/3bc09b682dbdff92458ef0324f03fb82.jpg'),
(62813, 4264, 'American Dad! S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255599.mp4', 'http://timg.bdta.pro/images/f54267e0e61170c2b7b6771a2adf07c9.jpg'),
(62814, 4264, 'American Dad! S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255600.mp4', 'http://timg.bdta.pro/images/42059f367bd490368c424ad1066f7a6c.jpg'),
(62815, 4264, 'American Dad! S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255601.mp4', 'http://timg.bdta.pro/images/b2c1162bb2e7b13e755586b0fbc74120.jpg'),
(62816, 4264, 'American Dad! S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255602.mp4', 'http://timg.bdta.pro/images/9563fe80f1c80910e5bf44213ba20074.jpg'),
(62817, 4264, 'American Dad! S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255603.mp4', 'http://timg.bdta.pro/images/30313c30abb4c1360c6a1efbd8fb9689.jpg'),
(62818, 4264, 'American Dad! S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255604.mp4', 'http://timg.bdta.pro/images/a57b92ca2d52f7893a155a1b073acef5.jpg'),
(62819, 4264, 'American Dad! S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255605.mp4', 'http://timg.bdta.pro/images/3910837ee78cf25b1daee82c32c7e5c1.jpg'),
(62820, 4264, 'American Dad! S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255606.mp4', 'http://timg.bdta.pro/images/2b93a76e1bd9f59502f9c9fecba5399c.jpg'),
(62821, 4264, 'American Dad! S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255607.mp4', 'http://timg.bdta.pro/images/4abf7d28781805d7f5f111ce12368663.jpg'),
(62822, 4264, 'American Dad! S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255608.mp4', 'http://timg.bdta.pro/images/8c7566485c9a4a1dde0ff249ffbbb058.jpg'),
(62823, 4264, 'American Dad! S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255609.mp4', 'http://timg.bdta.pro/images/1327254b590c041dab1801e53e4f5f4d.jpg'),
(62824, 4264, 'American Dad! S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255610.mp4', 'http://timg.bdta.pro/images/7a4ecd2fda127c10700ed618831741d0.jpg'),
(62825, 4264, 'American Dad! S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255611.mp4', 'http://timg.bdta.pro/images/67523b9db2cfe1e7d305c157b5e84d4d.jpg'),
(62826, 4265, 'American Dad! S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255612.mp4', 'http://timg.bdta.pro/images/bff65d49349b715f8e90cea8b6edde72.jpg'),
(62827, 4265, 'American Dad! S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255613.mp4', 'http://timg.bdta.pro/images/7ccb79300001d5c9548a1c80ee1a5359.jpg'),
(62828, 4265, 'American Dad! S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255614.mp4', 'http://timg.bdta.pro/images/0a37093cd116a4df0903ccd36df1daae.jpg'),
(62829, 4265, 'American Dad! S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255615.mp4', 'http://timg.bdta.pro/images/0643d74315be24fd786ee9521f92b3d2.jpg'),
(62830, 4265, 'American Dad! S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255616.mp4', 'http://timg.bdta.pro/images/23678801dcaa709bf9f1990e0288bdad.jpg'),
(62831, 4265, 'American Dad! S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255617.mp4', 'http://timg.bdta.pro/images/37654f36250f044d8019dadcaeaef1b1.jpg'),
(62832, 4265, 'American Dad! S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255618.mp4', 'http://timg.bdta.pro/images/f394586be23aa15a073a96f7c5cb6f6c.jpg'),
(62833, 4265, 'American Dad! S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255619.mp4', 'http://timg.bdta.pro/images/82ce6cf8e56929c6fc3e4c05776ed414.jpg'),
(62834, 4265, 'American Dad! S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255620.mp4', 'http://timg.bdta.pro/images/e3ddc58c923e3bc2930ca0434475ae77.jpg'),
(62835, 4265, 'American Dad! S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255621.mp4', 'http://timg.bdta.pro/images/996e183f25818c3d6694b5ff2b1a45ab.jpg'),
(62836, 4265, 'American Dad! S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255622.mp4', 'http://timg.bdta.pro/images/4f565dcd4ea511ae830b7065e7b5bacf.jpg'),
(62837, 4265, 'American Dad! S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255623.mp4', 'http://timg.bdta.pro/images/3af72c5df1ee865abe3fbebde0e18c1a.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(62838, 4265, 'American Dad! S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255624.mp4', 'http://timg.bdta.pro/images/5323b4d4e1db40c385059eda3f892744.jpg'),
(62839, 4265, 'American Dad! S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255625.mp4', 'http://timg.bdta.pro/images/44cb6e545afb76c8d20c1c28d739e555.jpg'),
(62840, 4265, 'American Dad! S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255626.mp4', 'http://timg.bdta.pro/images/ab3e47ee2566fdc15d9e033f402a488d.jpg'),
(62841, 4265, 'American Dad! S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255627.mp4', 'http://timg.bdta.pro/images/e41d974ac46927ce4efeacad6e64d54d.jpg'),
(62842, 4265, 'American Dad! S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255628.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62843, 4265, 'American Dad! S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255629.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62844, 4265, 'American Dad! S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255630.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62845, 4265, 'American Dad! S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255631.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62846, 4266, 'American Dad! S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255632.mp4', 'http://timg.bdta.pro/images/79c1666f8369e32022f54422c06669ec.jpg'),
(62847, 4266, 'American Dad! S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255633.mp4', 'http://timg.bdta.pro/images/c9a34b166a0c6cf8229259c3f6bae5a9.jpg'),
(62848, 4266, 'American Dad! S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255634.mp4', 'http://timg.bdta.pro/images/37751477254ee095f4d129b95b63a2a3.jpg'),
(62849, 4266, 'American Dad! S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255635.mp4', 'http://timg.bdta.pro/images/6534aa61fab826c88796d3d58f5f1d20.jpg'),
(62850, 4266, 'American Dad! S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255636.mp4', 'http://timg.bdta.pro/images/8ed1f20d600362f8964c7d6cbf16666d.jpg'),
(62851, 4266, 'American Dad! S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255637.mp4', 'http://timg.bdta.pro/images/20932917ed77f53edcd6980b0a194613.jpg'),
(62852, 4266, 'American Dad! S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255638.mp4', 'http://timg.bdta.pro/images/4755f6f2cae66c88979109340338b55e.jpg'),
(62853, 4266, 'American Dad! S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255639.mp4', 'http://timg.bdta.pro/images/fddb59f27856a44183c8d0ed8dbd4090.jpg'),
(62854, 4266, 'American Dad! S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255640.mp4', 'http://timg.bdta.pro/images/d3669634103d302780f825c52d011f1f.jpg'),
(62855, 4266, 'American Dad! S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255641.mp4', 'http://timg.bdta.pro/images/0621fc01313c0081a82ed889cab9ef02.jpg'),
(62856, 4266, 'American Dad! S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255642.mp4', 'http://timg.bdta.pro/images/0df5591440e8d8ca9deb428d71cb88ec.jpg'),
(62857, 4266, 'American Dad! S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255643.mp4', 'http://timg.bdta.pro/images/eda946c263cffc944dfe94821190d2f6.jpg'),
(62858, 4266, 'American Dad! S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255644.mp4', 'http://timg.bdta.pro/images/e1c4e1b9606af98896b3e4e62f450789.jpg'),
(62859, 4266, 'American Dad! S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255645.mp4', 'http://timg.bdta.pro/images/a7c05ddcb11672acd3b4d7be91175226.jpg'),
(62860, 4266, 'American Dad! S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255646.mp4', 'http://timg.bdta.pro/images/0ad41e5cf0c1d164d796cdd44a868b43.jpg'),
(62861, 4266, 'American Dad! S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255647.mp4', 'http://timg.bdta.pro/images/b3eb406a09792c4c0cd13ae96ffffbdd.jpg'),
(62862, 4266, 'American Dad! S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255648.mp4', 'http://timg.bdta.pro/images/ff5da2add15a5f2f5dd43c06641daf3a.jpg'),
(62863, 4266, 'American Dad! S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255649.mp4', 'http://timg.bdta.pro/images/4c7fb34778024c73c062bfe91d13405d.jpg'),
(62864, 4267, 'American Dad! S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255650.mp4', 'http://timg.bdta.pro/images/ea99f02d64d0389130576190c8388b43.jpg'),
(62865, 4267, 'American Dad! S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255651.mp4', 'http://timg.bdta.pro/images/e052327cc2b38a5d617ea5fca246929a.jpg'),
(62866, 4267, 'American Dad! S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255652.mp4', 'http://timg.bdta.pro/images/5602497bb51eecae21fc087e9a6710f4.jpg'),
(62867, 4267, 'American Dad! S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255653.mp4', 'http://timg.bdta.pro/images/8b836ff5fceea86eb220b7f80e5b7758.jpg'),
(62868, 4267, 'American Dad! S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255654.mp4', 'http://timg.bdta.pro/images/4a22ca45d9b30e920e93074f230c0bd5.jpg'),
(62869, 4267, 'American Dad! S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255655.mp4', 'http://timg.bdta.pro/images/148f3a81b2b7cde25dcc1edd98365a94.jpg'),
(62870, 4267, 'American Dad! S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255656.mp4', 'http://timg.bdta.pro/images/289d05dae54ffe99652119ee8d70052f.jpg'),
(62871, 4267, 'American Dad! S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255657.mp4', 'http://timg.bdta.pro/images/416da57847676be92f68c19299b4a8cc.jpg'),
(62872, 4267, 'American Dad! S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255658.mp4', 'http://timg.bdta.pro/images/b3c95564f03b09a5b338af0f1f4dd40a.jpg'),
(62873, 4267, 'American Dad! S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255659.mp4', 'http://timg.bdta.pro/images/791f6cb773766b31ff860d687a567338.jpg'),
(62874, 4267, 'American Dad! S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255660.mp4', 'http://timg.bdta.pro/images/b884eff11a6efa7150356f01066d8a0d.jpg'),
(62875, 4267, 'American Dad! S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255661.mp4', 'http://timg.bdta.pro/images/c4c028ce9d8668d2c259349f3d069aa1.jpg'),
(62876, 4267, 'American Dad! S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255662.mp4', 'http://timg.bdta.pro/images/c6c21dbd030fb89a39bf8f573033a4f2.jpg'),
(62877, 4267, 'American Dad! S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255663.mp4', 'http://timg.bdta.pro/images/7ab20ffa04df91f10bd549921a131ceb.jpg'),
(62878, 4267, 'American Dad! S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255664.mp4', 'http://timg.bdta.pro/images/a6783a25cb9cc0e86314e4056281a2b2.jpg'),
(62879, 4267, 'American Dad! S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255665.mp4', 'http://timg.bdta.pro/images/4106812f99831d3e276bf918dc26d0c0.jpg'),
(62880, 4267, 'American Dad! S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255666.mp4', 'http://timg.bdta.pro/images/048abb7426118087e552f824a5156991.jpg'),
(62881, 4267, 'American Dad! S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255667.mp4', 'http://timg.bdta.pro/images/a6a2ef154962fe3b582e122271778f93.jpg'),
(62882, 4267, 'American Dad! S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255668.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62883, 4268, 'American Dad! S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255669.mp4', 'http://timg.bdta.pro/images/4c01247089d4270c37784fa0b1b872b0.jpg'),
(62884, 4268, 'American Dad! S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255670.mp4', 'http://timg.bdta.pro/images/5b3c3e99916986e84043e43cf885526e.jpg'),
(62885, 4268, 'American Dad! S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255671.mp4', 'http://timg.bdta.pro/images/57e1a0e99b723a715e123096c2604513.jpg'),
(62886, 4268, 'American Dad! S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255672.mp4', 'http://timg.bdta.pro/images/ae21144c32fb4dd95307f926c7293ea4.jpg'),
(62887, 4268, 'American Dad! S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255673.mp4', 'http://timg.bdta.pro/images/fd93a3ff05600278defdbeeaa696b398.jpg'),
(62888, 4268, 'American Dad! S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255674.mp4', 'http://timg.bdta.pro/images/106ccd5ea9baa737c9ebf6c6d47c0477.jpg'),
(62889, 4268, 'American Dad! S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255675.mp4', 'http://timg.bdta.pro/images/b0eaed2e90687ff6e73f2f507f3d707c.jpg'),
(62890, 4268, 'American Dad! S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255676.mp4', 'http://timg.bdta.pro/images/9b05515f3c43d0cae2aeb5307d3ec385.jpg'),
(62891, 4268, 'American Dad! S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255677.mp4', 'http://timg.bdta.pro/images/8298f9067668ad34f2eeb87cd42cb79c.jpg'),
(62892, 4268, 'American Dad! S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255678.mp4', 'http://timg.bdta.pro/images/c56350414c3f9691f323059cae8badd4.jpg'),
(62893, 4268, 'American Dad! S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255679.mp4', 'http://timg.bdta.pro/images/9feb7aaf0ed5721d4d2a6b9e19285a69.jpg'),
(62894, 4268, 'American Dad! S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255680.mp4', 'http://timg.bdta.pro/images/7473e371d89912c543fb4ba5f884b7d9.jpg'),
(62895, 4268, 'American Dad! S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255681.mp4', 'http://timg.bdta.pro/images/b14950525d1ce4f87ed347151d236a75.jpg'),
(62896, 4268, 'American Dad! S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255682.mp4', 'http://timg.bdta.pro/images/79c28896e3908c67a23455362422e9c8.jpg'),
(62897, 4268, 'American Dad! S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255683.mp4', 'http://timg.bdta.pro/images/001f6ec7e04914eb8c5ca882c88fbfa1.jpg'),
(62898, 4268, 'American Dad! S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255684.mp4', 'http://timg.bdta.pro/images/43fc578a44792907f9755658e257da21.jpg'),
(62899, 4268, 'American Dad! S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255685.mp4', 'http://timg.bdta.pro/images/a3442da460d1c6a80fd63d6569df20d7.jpg'),
(62900, 4268, 'American Dad! S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255686.mp4', 'http://timg.bdta.pro/images/06618951eb20cff59a5a898955720073.jpg'),
(62901, 4269, 'American Dad! S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a85aW2hl7vH9UHwjWr0x4GsjvO2.jpg'),
(62902, 4269, 'American Dad! S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/19WZ0KDiIKVTdMBNjavpgu5tkka.jpg'),
(62903, 4269, 'American Dad! S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5D8vPVhHKiAdDTB6G3bdYQgbYop.jpg'),
(62904, 4269, 'American Dad! S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/opsq3gOfBhH4JtDUFULD7qDyrM1.jpg'),
(62905, 4269, 'American Dad! S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pS7luaBjYQYCLUzPO0sEZ2VWB7G.jpg'),
(62906, 4269, 'American Dad! S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w00teUz1tEWAeygshmdQIlc2ciS.jpg'),
(62907, 4269, 'American Dad! S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1QWpKzWYFTxwXoWIu4jgePzKtlP.jpg'),
(62908, 4269, 'American Dad! S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aognWTNHpPm9Z8m1iE6gb0L2Dv7.jpg'),
(62909, 4269, 'American Dad! S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ehyWm78TxpcKWtqS1NIOAnLa1V3.jpg'),
(62910, 4269, 'American Dad! S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/68N84eWSpcPcoZBXfPrSVFe4rSB.jpg'),
(62911, 4269, 'American Dad! S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/leMzKMQYx7T8TzolKVLOC1P2CuL.jpg'),
(62912, 4269, 'American Dad! S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hwCIjW6rNejsb4N2JxvdSUq0RLO.jpg'),
(62913, 4269, 'American Dad! S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lQyzlmqLyo3OqYQTAxeOoec00bu.jpg'),
(62914, 4269, 'American Dad! S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rIrreOIJFQekHC1LS0dQ4ZOLf4N.jpg'),
(62915, 4269, 'American Dad! S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wf2khfyEYyLhVtBmfvpX3f7zvn6.jpg'),
(62916, 4269, 'American Dad! S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z93kQpiLknfxN8cICGZ3bXyejT0.jpg'),
(62917, 4269, 'American Dad! S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jJ7yHiCRR85BP3woQmP1bEZPCJ1.jpg'),
(62918, 4269, 'American Dad! S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o9nBXlb6yQodaJe9P6R20kcrJ7U.jpg'),
(62919, 4269, 'American Dad! S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255705.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62920, 4270, 'American Dad! S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/deJoKqLhC1bjYScks9O5A1yhwwj.jpg'),
(62921, 4270, 'American Dad! S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hUSxsLKsxQMZbp0Pcmxs5NV0peq.jpg'),
(62922, 4270, 'American Dad! S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yiaFsDlDxASGAhtsbw9t58lbSv2.jpg'),
(62923, 4270, 'American Dad! S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vpydoPR2KZittOOH1rZZRJphCkP.jpg'),
(62924, 4270, 'American Dad! S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7NUBCjfvG5DkLhgJO4tay4QbYBD.jpg'),
(62925, 4270, 'American Dad! S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z4VFSgtArlEjrLPKimSAUU789Nu.jpg'),
(62926, 4270, 'American Dad! S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8UxixVov0EYadiIRGDND6RnCUZ5.jpg'),
(62927, 4270, 'American Dad! S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8tcR5jnOMF0lINjk0SbZ7sZM3ZU.jpg'),
(62928, 4270, 'American Dad! S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZjgYINcbd5NTKoeuHrMXd8APLN.jpg'),
(62929, 4270, 'American Dad! S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBtCmVWrUxZj5WXNBxw6mpZVPnX.jpg'),
(62930, 4270, 'American Dad! S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lGnCHhSl6wQycH6nUMVi6AUR0IU.jpg'),
(62931, 4270, 'American Dad! S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qgjr9zRERiEjYn5qk4EV8rzgHVj.jpg'),
(62932, 4270, 'American Dad! S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oSPF9VUP2ePT1fl9wdKDwQ6EJV5.jpg'),
(62933, 4270, 'American Dad! S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zYG5RT75U0kIOPnxjD0nOC4440i.jpg'),
(62934, 4270, 'American Dad! S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t1kVSe6so696DUgzafwO1Puo8st.jpg'),
(62935, 4270, 'American Dad! S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cr9s38AQm8d3CpSxQHfODM73pmU.jpg'),
(62936, 4270, 'American Dad! S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/OrA1edezzOXA1ZEoXV4d1awJN8.jpg'),
(62937, 4270, 'American Dad! S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m0Ze88pQQkDv4WFg5d2fJlR3QZI.jpg'),
(62938, 4270, 'American Dad! S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fbVblIce2hj0DDzXzQuX8rzetUK.jpg'),
(62939, 4270, 'American Dad! S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255725.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62940, 4271, 'American Dad! S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dvdL0Y3iROdAUSrbLYBccee79RM.jpg'),
(62941, 4271, 'American Dad! S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5h9oir31crUlI4Rybf6lRuCn76j.jpg'),
(62942, 4271, 'American Dad! S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dszu6lEiyFy8AFFwD1uY1479qHH.jpg'),
(62943, 4271, 'American Dad! S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mNTCVtwkOE2wpGmGSdFMnze1IFe.jpg'),
(62944, 4271, 'American Dad! S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rtG3w8wjoewwksCy1zXOdMuHIi.jpg'),
(62945, 4271, 'American Dad! S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4vp8vwy5kLWRoCtvw5OhZQH3OvW.jpg'),
(62946, 4271, 'American Dad! S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/df8YUicuPnVWLzPw8G2uMcEtcF3.jpg'),
(62947, 4271, 'American Dad! S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rX21wRcy5MeJyDoMmMmEKWOdjgJ.jpg'),
(62948, 4271, 'American Dad! S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hTYRplYm6niqWXakFqXQiFKn5Jn.jpg'),
(62949, 4271, 'American Dad! S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2q5oXCiCD0WGFH6ZZYKFPR3GPa4.jpg'),
(62950, 4271, 'American Dad! S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xauqZujPnJiNUNU5DoqsuMUPURe.jpg'),
(62951, 4271, 'American Dad! S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8D1orpKaZemFnddWQW4lohiZxNG.jpg'),
(62952, 4271, 'American Dad! S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3zteja4u4UHOIQtJaKjQ1WDpbqA.jpg'),
(62953, 4271, 'American Dad! S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Ob34cDk2QbrG1yRwX10HCqiJGQ.jpg'),
(62954, 4271, 'American Dad! S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOGJSrluWQOqw4D3K7uNWukcP2A.jpg'),
(62955, 4271, 'American Dad! S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m38QiB4it6Xhavnoni8OA2hmrdQ.jpg'),
(62956, 4271, 'American Dad! S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ezrShaldKX5P6XRGDH7sqL5NZ1B.jpg'),
(62957, 4271, 'American Dad! S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a5Rn8thLP78psa4NeCZLPAC0Cg5.jpg'),
(62958, 4271, 'American Dad! S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8a9GKNLlDxXnAp5fh2h6Byqga3x.jpg'),
(62959, 4271, 'American Dad! S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2I6henEMdx5CaHkN0irPrkEFwgI.jpg'),
(62960, 4272, 'American Dad! S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c4tYLCNhOe8zBd2HupA3huZrzqN.jpg'),
(62961, 4272, 'American Dad! S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tWcaZHilwhstmDQxn7oepxHZlXK.jpg'),
(62962, 4272, 'American Dad! S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bdfmgslV2EMDxW6ogtOVh8C3epf.jpg'),
(62963, 4272, 'American Dad! S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255749.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62964, 4272, 'American Dad! S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255750.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62965, 4272, 'American Dad! S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255751.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62966, 4272, 'American Dad! S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255752.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62967, 4272, 'American Dad! S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255753.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62968, 4272, 'American Dad! S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255754.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62969, 4272, 'American Dad! S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255755.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62970, 4272, 'American Dad! S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255756.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62971, 4272, 'American Dad! S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255757.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62972, 4272, 'American Dad! S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255758.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62973, 4272, 'American Dad! S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255759.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62974, 4272, 'American Dad! S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255760.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62975, 4273, 'American Dad! S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g2EvUMlNirkeyJK3jpCa8HN9xZf.jpg'),
(62976, 4273, 'American Dad! S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7AqfxvOVpvfbtnrZbrrhoyAsrq.jpg'),
(62977, 4273, 'American Dad! S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gVjwMpGRISZIOs2we7rkzCJdoIT.jpg'),
(62978, 4273, 'American Dad! S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xiSr9NawOmX8FfWnPzzKsrkJG7K.jpg'),
(62979, 4273, 'American Dad! S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6h6mNKM8ANVIoqlRUEMVTRECgTY.jpg'),
(62980, 4273, 'American Dad! S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkK8dHf5Os9BCLEbcEFZRHiwLbz.jpg'),
(62981, 4273, 'American Dad! S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ulSUZL38NjtHhYxv1KTwT8JFaaq.jpg'),
(62982, 4273, 'American Dad! S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3d3iPzx4NkmgKHGnIyE6zPNhJk.jpg'),
(62983, 4273, 'American Dad! S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4fYWc4Qrc2dfc9r07vqesEDfj1B.jpg'),
(62984, 4273, 'American Dad! S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m358U7z5ixfkj3vtVgYXYdahb3N.jpg'),
(62985, 4273, 'American Dad! S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8lDYm8y2Kzs1n4WvxTpnbd8aXoM.jpg'),
(62986, 4273, 'American Dad! S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eKpRKOrtFQhhbetPvRR9Cp463Ny.jpg'),
(62987, 4273, 'American Dad! S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1FswU3dKrR2GSsmvDJMZPnN5Eez.jpg'),
(62988, 4273, 'American Dad! S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cx0Vh2uzfTnqYk18qcx9Zh5dpPz.jpg'),
(62989, 4273, 'American Dad! S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oAfPvXUCNwbzRiLE54Xm9W0NVzr.jpg'),
(62990, 4273, 'American Dad! S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255776.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62991, 4273, 'American Dad! S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255777.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62992, 4273, 'American Dad! S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255778.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62993, 4273, 'American Dad! S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255779.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62994, 4273, 'American Dad! S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255780.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62995, 4273, 'American Dad! S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/255781.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62996, 4273, 'American Dad! S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/255782.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(62997, 4274, 'American Dad! S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qa5ihXGIOl7NgR0WkU0jBoSnBvo.jpg'),
(62998, 4274, 'American Dad! S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uyJR4XkPqyZVYr9FH4TEbTBntv6.jpg'),
(62999, 4274, 'American Dad! S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gS6hZNRYK7TcLKg065JVNaUgP4z.jpg'),
(63000, 4274, 'American Dad! S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zsFWwzCNxoZdlqMuN6KT2L5NVQw.jpg'),
(63001, 4274, 'American Dad! S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qM4YSxW8C0b7LnE29I71uR2L3iE.jpg'),
(63002, 4274, 'American Dad! S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PleKoMcnVYEvimOnlCvNvpztvu.jpg'),
(63003, 4274, 'American Dad! S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iibkhIZYEcxXHPCRSUM2hbzhxza.jpg'),
(63004, 4274, 'American Dad! S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ncwdxYKEf2ZTT0xg7f6iMkHKQXE.jpg'),
(63005, 4274, 'American Dad! S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzErjJdLHjRW0vG59O11Kv10YOw.jpg'),
(63006, 4274, 'American Dad! S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/plKlCjwSFa06jkE53Lh1U2wjox0.jpg'),
(63007, 4274, 'American Dad! S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ljncMd6AF54X1oeVXu8e2oPtygr.jpg'),
(63008, 4274, 'American Dad! S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bXZBw7cLAVY5vFQ0Z955ADXwx6B.jpg'),
(63009, 4274, 'American Dad! S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/msafjrPa5seqtAm4pEJNOpqo7qq.jpg'),
(63010, 4274, 'American Dad! S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vV7rX6lVyqKULXpVzcEfItyx6iP.jpg'),
(63011, 4274, 'American Dad! S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/la5fozFI3UgaBCkzd2JDqCemxZe.jpg'),
(63012, 4274, 'American Dad! S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2eTkeJcPFLBlbzqBie2HSH0Rv0x.jpg'),
(63013, 4274, 'American Dad! S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9LYVDWPCPXoQoHZ0sN6tPZlXXvb.jpg'),
(63014, 4274, 'American Dad! S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jwenmWdPpGqM9q6gSdwpoAVzgl3.jpg'),
(63015, 4274, 'American Dad! S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8YkQhsAAZzHdIQxfMwEXP9XZlrP.jpg'),
(63016, 4274, 'American Dad! S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o4qlT9kAZOEDsj1DKscJOTY0cMb.jpg'),
(63017, 4274, 'American Dad! S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/255803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8dywugsSif77zoGEWSqs2JjGk4o.jpg'),
(63018, 4274, 'American Dad! S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/255804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4dRxOzRUnMsyWLkmsy9RfJdYlvI.jpg'),
(63019, 4275, 'American Dad! S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zCNEiWfOZo1GCT9e6PeHeldAQON.jpg'),
(63020, 4275, 'American Dad! S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wRx1HeXezkjaAcY9rGI3sjU82aU.jpg'),
(63021, 4275, 'American Dad! S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gRlEVDqcBZIBx3FtthwXIjDgEi2.jpg'),
(63022, 4275, 'American Dad! S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yVHkkOtBZKk1Vl6a6p1U9YxMkQs.jpg'),
(63023, 4275, 'American Dad! S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zsy9iWXBfNyZwcrZHFEM4srZVcR.jpg'),
(63024, 4275, 'American Dad! S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjhCFNK0J7jhomdGCakG3F1JFp7.jpg'),
(63025, 4275, 'American Dad! S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/evtQqAfY3xD22iEEvZNCpM0bKyK.jpg'),
(63026, 4275, 'American Dad! S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQ5iFB9J01ImREjWbxUKM0BzTI4.jpg'),
(63027, 4275, 'American Dad! S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fbcfQQB4EFJ4KfvhWayhzxDkIPH.jpg'),
(63028, 4275, 'American Dad! S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/As6DBs5yNIiXuijQWaejDTrqHOo.jpg'),
(63029, 4275, 'American Dad! S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dFXwvf9E4iEqF2KYEtBNJyoNEd3.jpg'),
(63030, 4275, 'American Dad! S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5UrnZmKDP6ecT1UsxUlo61X7bPS.jpg'),
(63031, 4275, 'American Dad! S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sgjGvm7mqvS3HYS4DAvcFQrT8wZ.jpg'),
(63032, 4275, 'American Dad! S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sNJgcQrou7xPrdwvrdEEsZh303C.jpg'),
(63033, 4275, 'American Dad! S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mFJzUtBV8ORcNHpCgt7cbo00plh.jpg'),
(63034, 4275, 'American Dad! S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tk7iW8Bmzt1c5TpAEtLvdKZZPcd.jpg'),
(63035, 4275, 'American Dad! S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pDaVu37JHT5G2oRztkSbVpOuV2C.jpg'),
(63036, 4275, 'American Dad! S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gsDov9SrLuIB6ZGt9JdqYZ1GKCJ.jpg'),
(63037, 4275, 'American Dad! S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/70wVJMDuRk2CdsSePJdVrtj35Zh.jpg'),
(63038, 4275, 'American Dad! S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v4YhCY8VXhkezleMLbFd89QyrTy.jpg'),
(63039, 4276, 'American Dad! S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7abdwKUgtmXvrV3SeqWElJk3bpv.jpg'),
(63040, 4276, 'American Dad! S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ekxtEi8eW2GAEcuIJ6xpeaEyuUg.jpg'),
(63041, 4276, 'American Dad! S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uzHnEQCXrefDvSkQPOouphPpT9k.jpg'),
(63042, 4276, 'American Dad! S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZvWkY9vsoGSmbSoVSv91InVpQ.jpg'),
(63043, 4276, 'American Dad! S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z5JuZbRD5oTPAz7uKIB8qDJmKim.jpg'),
(63044, 4276, 'American Dad! S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nXp8REuoW2RLiMdXa85NmyPHZ7F.jpg'),
(63045, 4276, 'American Dad! S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hAsrZWArgCLy8R5pAKlVVnPDkfV.jpg'),
(63046, 4276, 'American Dad! S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b4bc5x2n0M5bKX4PGD1dWZ1BVng.jpg'),
(63047, 4276, 'American Dad! S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p1nNO30sjVpuHOenxmHo3v4y6J9.jpg'),
(63048, 4276, 'American Dad! S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x4q4xJjEbteOYfQu3yFX7Q8PT9p.jpg'),
(63049, 4276, 'American Dad! S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hr97Wfw0SchBwtYLp0rN5Oe68Ad.jpg'),
(63050, 4276, 'American Dad! S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aCT5HvJUtECaro88HHSZILMAWjH.jpg'),
(63051, 4276, 'American Dad! S15 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pZUaBqTMcSe8vShTGFGM17y2KAL.jpg'),
(63052, 4276, 'American Dad! S15 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1A3PwgEHSbvuLjDAL0qVQp7qyMb.jpg'),
(63053, 4276, 'American Dad! S15 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lUBb0fXgC06MN5wTagvgl7AKlOY.jpg'),
(63054, 4276, 'American Dad! S15 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6IAljASoyEwTQli45AjwzIabUsR.jpg'),
(63055, 4276, 'American Dad! S15 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8jlR0NM4ghkYFTzPzu3ILy6OUfn.jpg'),
(63056, 4276, 'American Dad! S15 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/atz7f5qgNk0eA6ursA5NjzFtOaz.jpg'),
(63057, 4276, 'American Dad! S15 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i84SHTKmnTcg0b7eW0xcchnKcU0.jpg'),
(63058, 4276, 'American Dad! S15 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/je67v9WKMVTAwkzQmJUpBKJpS0u.jpg'),
(63059, 4276, 'American Dad! S15 E21', 'http://sinalprivado.info:80/series/1533784/1533784/255845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4UXD6LZBFLBVY2XSKIFVpxJV1tW.jpg'),
(63060, 4276, 'American Dad! S15 E22', 'http://sinalprivado.info:80/series/1533784/1533784/255846.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(63061, 4277, 'American Dad! S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/foWkEJOl7drtl9ie6ewwoORv7VM.jpg'),
(63062, 4277, 'American Dad! S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6vxS5rBbLmYGYbAFJQuWQNB5Rs8.jpg'),
(63063, 4277, 'American Dad! S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4NtCda2sbOClsqlQ49nuvX6W6Vu.jpg'),
(63064, 4277, 'American Dad! S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kiI6qguyjJfJ88bkPevIe0KQ7k3.jpg'),
(63065, 4277, 'American Dad! S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6db8SLOyzM45JMm3atKo7WKNcGF.jpg'),
(63066, 4277, 'American Dad! S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/28PTdOMRf2saU5P77rZ4ojzIGKc.jpg'),
(63067, 4277, 'American Dad! S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6VJtjImoObWddVPGHXmx3GHfDEG.jpg'),
(63068, 4277, 'American Dad! S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qGqQs2wxCADpsYGIC356k5GfpYV.jpg'),
(63069, 4277, 'American Dad! S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/boM9u0qjmXdYYe2euOnkseE8o32.jpg'),
(63070, 4277, 'American Dad! S16 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k5HLeR0xAUx8aJgRXLB7GaWzaDI.jpg'),
(63071, 4277, 'American Dad! S16 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q5083dxU07LAYlkpmjslGrMMaFB.jpg'),
(63072, 4277, 'American Dad! S16 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7YYVLj9ae7F92SCxTiikMN0l5fI.jpg'),
(63073, 4277, 'American Dad! S16 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ucARPOS99MpLvObaqGQXThpvf2B.jpg'),
(63074, 4277, 'American Dad! S16 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eHDP1G5LiQjwpLYOFSLY73PicZd.jpg'),
(63075, 4277, 'American Dad! S16 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8fmlOgj76xzcHaXaBb8QLQyEHiU.jpg'),
(63076, 4277, 'American Dad! S16 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qObQbJwKvWqoyH6a91iv81zc1mi.jpg'),
(63077, 4277, 'American Dad! S16 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g60a5Z8G5QwKqAmufzaOkMlgguf.jpg'),
(63078, 4277, 'American Dad! S16 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uL9VgsiDihkF4x06XcNc4LVydXP.jpg'),
(63079, 4277, 'American Dad! S16 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/os8bfs6vK6kPI9tXtgBhqC9h8gg.jpg'),
(63080, 4277, 'American Dad! S16 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/poHJM7aY9hV2YEx317wpIPv5qxU.jpg'),
(63081, 4278, 'American Dad! S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8ZyURL5q88vF7AwEfCwe3M0KHe.jpg'),
(63082, 4278, 'American Dad! S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/33vYkUTDIEeA4yZOQ2HsFxfmuLZ.jpg'),
(63083, 4278, 'American Dad! S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6h2SKW77mVpJYVRK8Ck6KUkhZ6I.jpg'),
(63084, 4278, 'American Dad! S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Qz8MUPAak13wqnwFQlEPuqG31f.jpg'),
(63085, 4278, 'American Dad! S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mPB4pJk86MkFniyQZYFkd2fTNUE.jpg'),
(63086, 4278, 'American Dad! S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ysn0hjC1NjhtZumHP3ShMn13CiB.jpg'),
(63087, 4278, 'American Dad! S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/esSN1r3tZGGtu2VaA1QFWaQWGQJ.jpg'),
(63088, 4278, 'American Dad! S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nu350hlYaLLVXMBgaZxbVV9ftol.jpg'),
(63089, 4278, 'American Dad! S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mPZdPwMlFerLTqZTjlJ2R3kqRIE.jpg'),
(63090, 4278, 'American Dad! S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2T3iWNYWsYEFocHQZI7qBjeucHu.jpg'),
(63091, 4278, 'American Dad! S17 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8I2inb6K831DdZrqv7w1RMMAlVq.jpg'),
(63092, 4278, 'American Dad! S17 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mxMBOZVDUgKy8IZDsty2OYXo2cX.jpg'),
(63093, 4278, 'American Dad! S17 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXI8Yh8gEVSCkiIcOlSSDBgN2Lc.jpg'),
(63094, 4278, 'American Dad! S17 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/axXOpJSjbl4U7mY3YDNJBxFxzLO.jpg'),
(63095, 4278, 'American Dad! S17 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1uUeUiz3IiEY5rsHIK7E7TvQuhD.jpg'),
(63096, 4278, 'American Dad! S17 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6O6L7k0ZQuWcwVozPI5LseyufCa.jpg'),
(63097, 4278, 'American Dad! S17 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tYedINHinyuQWfYQeNDyH4KHiwZ.jpg'),
(63098, 4278, 'American Dad! S17 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xgWf0PF9MXOrUXiGnC6M9Kr4wx0.jpg'),
(63099, 4278, 'American Dad! S17 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2RhpESachzn4e4H523W9KCxwWjk.jpg'),
(63100, 4278, 'American Dad! S17 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Cnw3V526wRC5kMJ7FUWgFPiB3d.jpg'),
(63101, 4278, 'American Dad! S17 E21', 'http://sinalprivado.info:80/series/1533784/1533784/255887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6i4fNH7MVXmKyA8wna0ts9VPhmX.jpg'),
(63102, 4278, 'American Dad! S17 E22', 'http://sinalprivado.info:80/series/1533784/1533784/255888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lDlFD6wYSbRd6cDlgu9KXD3kaH0.jpg'),
(63103, 4278, 'American Dad! S17 E23', 'http://sinalprivado.info:80/series/1533784/1533784/255889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x9IiF7cYJhuNQw0wxrEVITldpon.jpg'),
(63104, 4278, 'American Dad! S17 E24', 'http://sinalprivado.info:80/series/1533784/1533784/255890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x90viiwp30hJO1jkRmcHoOS9IUx.jpg'),
(63105, 4279, 'American Dad! S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255891.mp4', 'http://timg.bdta.pro/images/439f509e766444f2767b06baec742938.jpg'),
(63106, 4279, 'American Dad! S18 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255892.mp4', 'http://timg.bdta.pro/images/c65258e44fbccb647f12e951649d3c63.jpg'),
(63107, 4279, 'American Dad! S18 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255893.mp4', 'http://timg.bdta.pro/images/d7f5030763f9ffeb2ff81d70e1ef85b5.jpg'),
(63108, 4279, 'American Dad! S18 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255894.mp4', 'http://timg.bdta.pro/images/344c6dea92fe75c8f3940b5ba54c8beb.jpg'),
(63109, 4279, 'American Dad! S18 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255895.mp4', 'http://timg.bdta.pro/images/f24e877b7dcf41763f55085a0b553973.jpg'),
(63110, 4279, 'American Dad! S18 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255896.mp4', 'http://timg.bdta.pro/images/dc6c2247f7fca50d8bba4b48b1095cc5.jpg'),
(63111, 4279, 'American Dad! S18 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255897.mp4', 'http://timg.bdta.pro/images/bfd1fb3325d22ccf792c17522d41d869.jpg'),
(63112, 4279, 'American Dad! S18 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255898.mp4', 'http://timg.bdta.pro/images/39a2dc90400b9d3691cc6a33ce1a5e8c.jpg'),
(63113, 4279, 'American Dad! S18 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255899.mp4', 'http://timg.bdta.pro/images/c3b08eda8a5ec24d0d1fa7eff1f3b913.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(63114, 4279, 'American Dad! S18 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255900.mp4', 'http://timg.bdta.pro/images/1cb78dab75b8c4516be08ba20fd3da88.jpg'),
(63115, 4279, 'American Dad! S18 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255901.mp4', 'http://timg.bdta.pro/images/2aeb275fdbfdf8f7fe09b2bb7d47d95d.jpg'),
(63116, 4279, 'American Dad! S18 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255902.mp4', 'http://timg.bdta.pro/images/f287ce902ecb4daeff5a775df785c598.jpg'),
(63117, 4279, 'American Dad! S18 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255903.mp4', 'http://timg.bdta.pro/images/7e1c8671cb893c5e50d3d3be7f8cff55.jpg'),
(63118, 4279, 'American Dad! S18 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255904.mp4', 'http://timg.bdta.pro/images/db5bdc30dea663acafe3ef2f793f949f.jpg'),
(63119, 4279, 'American Dad! S18 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255905.mp4', 'http://timg.bdta.pro/images/a9e7cdfea7b613ec5071ab439ddfaa30.jpg'),
(63120, 4279, 'American Dad! S18 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255906.mp4', 'http://timg.bdta.pro/images/0f38b6d2fd6768ed5bff75149aa10954.jpg'),
(63121, 4279, 'American Dad! S18 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255907.mp4', 'http://timg.bdta.pro/images/692375d8271f62bc2e5198e5b2fb1d36.jpg'),
(63122, 4279, 'American Dad! S18 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255908.mp4', 'http://timg.bdta.pro/images/64b39c0a057729ed29a40565f97007fd.jpg'),
(63123, 4279, 'American Dad! S18 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255909.mp4', 'http://timg.bdta.pro/images/02a06497c59e61e9bec6b44be77e9ef4.jpg'),
(63124, 4279, 'American Dad! S18 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255910.mp4', 'http://timg.bdta.pro/images/6a4e58632c49db46ccc23c084ed180af.jpg'),
(63125, 4279, 'American Dad! S18 E21', 'http://sinalprivado.info:80/series/1533784/1533784/255911.mp4', 'http://timg.bdta.pro/images/048629e3a9f31cfb4e078adf3491b7ab.jpg'),
(63126, 4279, 'American Dad! S18 E22', 'http://sinalprivado.info:80/series/1533784/1533784/255912.mp4', 'http://timg.bdta.pro/images/9597166b857d81830fa4e2d7d49ef263.jpg'),
(63127, 4280, 'American Dad! S19 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255913.mp4', 'http://timg.bdta.pro/images/bc23aba303e5d9cf5218cbf9375dee46.jpg'),
(63128, 4280, 'American Dad! S19 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255914.mp4', 'http://timg.bdta.pro/images/8d3646172d18b36cb835e10b24b793c9.jpg'),
(63129, 4280, 'American Dad! S19 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255915.mp4', 'http://timg.bdta.pro/images/6f62789a87b54f47a06445cd2398eb1d.jpg'),
(63130, 4280, 'American Dad! S19 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255916.mp4', 'http://timg.bdta.pro/images/a930451c9d4d071f96d9943c02918ad6.jpg'),
(63131, 4280, 'American Dad! S19 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255917.mp4', 'http://timg.bdta.pro/images/b38010c51f004cd54cf89f81e2ae4dc5.jpg'),
(63132, 4280, 'American Dad! S19 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255918.mp4', 'http://timg.bdta.pro/images/cc6d840f7cea43e87b5e081bddce36af.jpg'),
(63133, 4280, 'American Dad! S19 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255919.mp4', 'http://timg.bdta.pro/images/9ed0565f1e0cff1858ad80d74d74cd2e.jpg'),
(63134, 4280, 'American Dad! S19 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255920.mp4', 'http://timg.bdta.pro/images/cb629361788b75bf9a616f29d0e93ef4.jpg'),
(63135, 4280, 'American Dad! S19 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255921.mp4', 'http://timg.bdta.pro/images/9db895a3a0aeb9395e4fe614d64afedd.jpg'),
(63136, 4280, 'American Dad! S19 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255922.mp4', 'http://timg.bdta.pro/images/1d3c3e441604e208be4c05a1469e89b8.jpg'),
(63137, 4280, 'American Dad! S19 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255923.mp4', 'http://timg.bdta.pro/images/57e9498b07c0f6afcf718f15bfa79485.jpg'),
(63138, 4280, 'American Dad! S19 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255924.mp4', 'http://timg.bdta.pro/images/307199e7ec0b3bbb55cf79eba1224c8d.jpg'),
(63139, 4280, 'American Dad! S19 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255925.mp4', 'http://timg.bdta.pro/images/7fa0577a8d226123a0821811a2bdbf9e.jpg'),
(63140, 4280, 'American Dad! S19 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255926.mp4', 'http://timg.bdta.pro/images/99ad48d92c083e9eb44a7ccf6992aa71.jpg'),
(63141, 4280, 'American Dad! S19 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255927.mp4', 'http://image.tmdb.org/t/p/w1280/4n3B7KTK4WqrgAm0xk8lpH585H0.jpg'),
(63142, 4280, 'American Dad! S19 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hUgWjotE9I5zqVQYRWoCOnmsdAR.jpg'),
(63143, 4280, 'American Dad! S19 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1JPDNR0tWn4wLWcWocuxFZdBuxP.jpg'),
(63144, 4280, 'American Dad! S19 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/daoMCTPEx5u36eGUSGyjiCVv5u7.jpg'),
(63145, 4280, 'American Dad! S19 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tNBgfdZjYCbqU6tVQoXDw6GRPYx.jpg'),
(63146, 4280, 'American Dad! S19 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255932.mp4', 'http://image.tmdb.org/t/p/w1280/dA2qPT60PSadbjssR7Up7WLk7cm.jpg'),
(63147, 4281, 'American Dad! S20 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255933.mp4', 'http://image.tmdb.org/t/p/w1280/mqw9RAYw53cQlazrargdiZAb8fQ.jpg'),
(63148, 4281, 'American Dad! S20 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255934.mp4', 'http://image.tmdb.org/t/p/w1280/akNugDHpMWISeElsutApjNvrb7s.jpg'),
(63149, 4281, 'American Dad! S20 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255935.mp4', 'http://image.tmdb.org/t/p/w1280/jW8UxsaTBpnQnGMZULnipbENccb.jpg'),
(63150, 4281, 'American Dad! S20 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255936.mp4', 'http://image.tmdb.org/t/p/w1280/EVeEzVZWF9qVwSG5HV71Nmesl7.jpg'),
(63151, 4281, 'American Dad! S20 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255937.mp4', 'http://image.tmdb.org/t/p/w1280/z6YIVXnv6kX2iNSeCkv2zcOSMA4.jpg'),
(63152, 4281, 'American Dad! S20 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255938.mp4', 'http://image.tmdb.org/t/p/w1280/zLzwTmGwQ92LBfrP1fH2JHyBX6W.jpg'),
(63153, 4281, 'American Dad! S20 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255939.mp4', 'http://image.tmdb.org/t/p/w1280/8YsvVnDIK0wdkakbkTwzCJwCUk7.jpg'),
(63154, 4281, 'American Dad! S20 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255940.mp4', 'http://image.tmdb.org/t/p/w1280/2ZAvXh8vMa4DNULt9e8Ocke1XE4.jpg'),
(63155, 4281, 'American Dad! S20 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255941.mp4', 'http://image.tmdb.org/t/p/w1280/r2MxIbF5PIyGgQEAQJ1i1ELmnWr.jpg'),
(63156, 4281, 'American Dad! S20 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255942.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(63157, 4281, 'American Dad! S20 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255943.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(63158, 4281, 'American Dad! S20 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255944.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(63159, 4281, 'American Dad! S20 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255945.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(63160, 4281, 'American Dad! S20 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255946.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(63161, 4281, 'American Dad! S20 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255947.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(63162, 4281, 'American Dad! S20 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255948.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(63163, 4281, 'American Dad! S20 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255949.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(63164, 4281, 'American Dad! S20 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255950.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(63165, 4281, 'American Dad! S20 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255951.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(63166, 4281, 'American Dad! S20 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255952.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(63167, 4281, 'American Dad! S20 E21', 'http://sinalprivado.info:80/series/1533784/1533784/255953.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(63168, 4281, 'American Dad! S20 E22', 'http://sinalprivado.info:80/series/1533784/1533784/255954.mp4', 'http://gstaticontent.com/images/774b94843d651632e69c4ca4306b9a64.jpg'),
(63169, 4282, 'Cruel Summer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230474.mp4', 'http://timg.bdta.pro/images/7ba924b583b1e44fb29232b17429713d.jpg'),
(63170, 4282, 'Cruel Summer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230475.mp4', 'http://timg.bdta.pro/images/21942ba3f1b79d7347731bf5d34659a4.jpg'),
(63171, 4282, 'Cruel Summer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230476.mp4', 'http://timg.bdta.pro/images/a373b755d20776025fe871970c3765f1.jpg'),
(63172, 4282, 'Cruel Summer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230477.mp4', 'http://timg.bdta.pro/images/d70994230780c7491e14faaf16b71d69.jpg'),
(63173, 4282, 'Cruel Summer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230478.mp4', 'http://timg.bdta.pro/images/4248e3a6abbbb01b1ef963ad7d81320d.jpg'),
(63174, 4282, 'Cruel Summer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230479.mp4', 'http://timg.bdta.pro/images/6d18b9679bd1eea7a8d2e8f8bf364820.jpg'),
(63175, 4282, 'Cruel Summer S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230480.mp4', 'http://timg.bdta.pro/images/dd7360c10152d9a0666b8f3f5ef541ff.jpg'),
(63176, 4282, 'Cruel Summer S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230481.mp4', 'http://timg.bdta.pro/images/db3fa0b7e460c1db7ce802e4ae919c28.jpg'),
(63177, 4282, 'Cruel Summer S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230482.mp4', 'http://timg.bdta.pro/images/526532e9feaf3e63c6126b3b5fb059af.jpg'),
(63178, 4282, 'Cruel Summer S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230483.mp4', 'http://timg.bdta.pro/images/9fa32050cb58fe142efda522f329cbe5.jpg'),
(63179, 4283, 'Cruel Summer S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rPJdv82ctGwAsOr3zbEBEHBDyED.jpg'),
(63180, 4283, 'Cruel Summer S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v6D1s4qMjiVseHFIlotpmLf26o5.jpg'),
(63181, 4283, 'Cruel Summer S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJ6FL6wqoWs7NoJYbOGlF44nNmZ.jpg'),
(63182, 4283, 'Cruel Summer S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dg2aU8MIs2s1Z2RCXH9mXPDnHgK.jpg'),
(63183, 4283, 'Cruel Summer S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iNRTXi9z1dyxAaHfRHxhtsF2nuy.jpg'),
(63184, 4283, 'Cruel Summer S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qCC2hlIJs0yUK1kRTtBcLjndKMA.jpg'),
(63185, 4283, 'Cruel Summer S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jJjWQw7O9yDGe7iMkAaxvCWpvv4.jpg'),
(63186, 4283, 'Cruel Summer S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qKkPRn9dUl1WF3tPTtpmr6LrfNV.jpg'),
(63187, 4283, 'Cruel Summer S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kIjcL9jTL4cT4CgUwPw1l2WpMg9.jpg'),
(63188, 4283, 'Cruel Summer S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nA0Ftm4O8qgwumd1wamxcbadgdo.jpg'),
(63189, 4284, 'Lendas da Natureza S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149685.mp4', 'http://gstaticontent.com/images/2704f22e5ee17403bcfe9bee6f599e73.jpg'),
(63190, 4284, 'Lendas da Natureza S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149686.mp4', 'http://gstaticontent.com/images/2704f22e5ee17403bcfe9bee6f599e73.jpg'),
(63191, 4284, 'Lendas da Natureza S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149687.mp4', 'http://gstaticontent.com/images/2704f22e5ee17403bcfe9bee6f599e73.jpg'),
(63192, 4284, 'Lendas da Natureza S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149688.mp4', 'http://gstaticontent.com/images/2704f22e5ee17403bcfe9bee6f599e73.jpg'),
(63193, 4284, 'Lendas da Natureza S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149689.mp4', 'http://gstaticontent.com/images/2704f22e5ee17403bcfe9bee6f599e73.jpg'),
(63194, 4284, 'Lendas da Natureza S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149690.mp4', 'http://gstaticontent.com/images/2704f22e5ee17403bcfe9bee6f599e73.jpg'),
(63195, 4285, 'Pestinha e Feroz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149672.mp4', 'http://gstaticontent.com/images/a2ac1b39c456883c118803c18758cb02.jpg'),
(63196, 4285, 'Pestinha e Feroz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149673.mp4', 'http://gstaticontent.com/images/a2ac1b39c456883c118803c18758cb02.jpg'),
(63197, 4285, 'Pestinha e Feroz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149674.mp4', 'http://gstaticontent.com/images/a2ac1b39c456883c118803c18758cb02.jpg'),
(63198, 4285, 'Pestinha e Feroz S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149675.mp4', 'http://gstaticontent.com/images/a2ac1b39c456883c118803c18758cb02.jpg'),
(63199, 4285, 'Pestinha e Feroz S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149676.mp4', 'http://gstaticontent.com/images/a2ac1b39c456883c118803c18758cb02.jpg'),
(63200, 4285, 'Pestinha e Feroz S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149677.mp4', 'http://gstaticontent.com/images/a2ac1b39c456883c118803c18758cb02.jpg'),
(63201, 4285, 'Pestinha e Feroz S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149678.mp4', 'http://gstaticontent.com/images/a2ac1b39c456883c118803c18758cb02.jpg'),
(63202, 4285, 'Pestinha e Feroz S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149679.mp4', 'http://gstaticontent.com/images/a2ac1b39c456883c118803c18758cb02.jpg'),
(63203, 4285, 'Pestinha e Feroz S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149680.mp4', 'http://gstaticontent.com/images/a2ac1b39c456883c118803c18758cb02.jpg'),
(63204, 4285, 'Pestinha e Feroz S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149681.mp4', 'http://gstaticontent.com/images/a2ac1b39c456883c118803c18758cb02.jpg'),
(63205, 4285, 'Pestinha e Feroz S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149682.mp4', 'http://gstaticontent.com/images/a2ac1b39c456883c118803c18758cb02.jpg'),
(63206, 4285, 'Pestinha e Feroz S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149683.mp4', 'http://gstaticontent.com/images/a2ac1b39c456883c118803c18758cb02.jpg'),
(63207, 4285, 'Pestinha e Feroz S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/149684.mp4', 'http://gstaticontent.com/images/a2ac1b39c456883c118803c18758cb02.jpg'),
(63208, 4286, 'The Masked Singer Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268253.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63209, 4286, 'The Masked Singer Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268254.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63210, 4286, 'The Masked Singer Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268255.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63211, 4286, 'The Masked Singer Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268256.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63212, 4286, 'The Masked Singer Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268257.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63213, 4286, 'The Masked Singer Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268258.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63214, 4286, 'The Masked Singer Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268259.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63215, 4286, 'The Masked Singer Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268260.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63216, 4286, 'The Masked Singer Brasil S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268261.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63217, 4286, 'The Masked Singer Brasil S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268262.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63218, 4287, 'The Masked Singer Brasil S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268263.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63219, 4287, 'The Masked Singer Brasil S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268264.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63220, 4287, 'The Masked Singer Brasil S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268265.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63221, 4287, 'The Masked Singer Brasil S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268266.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63222, 4287, 'The Masked Singer Brasil S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268267.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63223, 4287, 'The Masked Singer Brasil S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268268.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63224, 4287, 'The Masked Singer Brasil S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268269.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63225, 4287, 'The Masked Singer Brasil S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268270.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63226, 4287, 'The Masked Singer Brasil S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268271.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63227, 4287, 'The Masked Singer Brasil S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268272.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63228, 4287, 'The Masked Singer Brasil S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268273.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63229, 4287, 'The Masked Singer Brasil S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268274.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63230, 4287, 'The Masked Singer Brasil S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268275.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63231, 4288, 'The Masked Singer Brasil S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268276.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63232, 4288, 'The Masked Singer Brasil S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268277.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63233, 4288, 'The Masked Singer Brasil S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268278.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63234, 4288, 'The Masked Singer Brasil S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268279.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63235, 4288, 'The Masked Singer Brasil S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268280.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63236, 4288, 'The Masked Singer Brasil S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268281.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63237, 4288, 'The Masked Singer Brasil S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268282.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63238, 4288, 'The Masked Singer Brasil S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268283.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63239, 4288, 'The Masked Singer Brasil S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268284.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63240, 4288, 'The Masked Singer Brasil S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268285.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63241, 4288, 'The Masked Singer Brasil S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268286.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63242, 4288, 'The Masked Singer Brasil S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268287.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63243, 4288, 'The Masked Singer Brasil S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268288.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63244, 4289, 'The Masked Singer Brasil S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268289.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63245, 4289, 'The Masked Singer Brasil S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268290.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63246, 4289, 'The Masked Singer Brasil S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268291.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63247, 4289, 'The Masked Singer Brasil S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/270796.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63248, 4289, 'The Masked Singer Brasil S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274971.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63249, 4289, 'The Masked Singer Brasil S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/288446.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63250, 4289, 'The Masked Singer Brasil S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/297043.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63251, 4289, 'The Masked Singer Brasil S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/297044.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63252, 4289, 'The Masked Singer Brasil S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/307059.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63253, 4289, 'The Masked Singer Brasil S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/307060.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63254, 4289, 'The Masked Singer Brasil S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/313482.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63255, 4289, 'The Masked Singer Brasil S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/320354.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63256, 4290, 'The Masked Singer Brasil S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/660141.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63257, 4290, 'The Masked Singer Brasil S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/669181.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63258, 4290, 'The Masked Singer Brasil S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/697223.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63259, 4290, 'The Masked Singer Brasil S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/697224.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63260, 4290, 'The Masked Singer Brasil S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/697225.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63261, 4290, 'The Masked Singer Brasil S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/703859.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63262, 4290, 'The Masked Singer Brasil S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/720878.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63263, 4290, 'The Masked Singer Brasil S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/720879.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63264, 4290, 'The Masked Singer Brasil S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/720880.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63265, 4290, 'The Masked Singer Brasil S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/734045.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63266, 4290, 'The Masked Singer Brasil S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/750123.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63267, 4290, 'The Masked Singer Brasil S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/750124.mp4', 'http://gstaticontent.com/images/f94e402e12d48a5a7ac5d253c69c9779.jpg'),
(63268, 4291, 'What If...? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255329.mp4', 'http://timg.bdta.pro/images/120289bcdb12f4c87a2d7bd91a4ee3a0.jpg'),
(63269, 4291, 'What If...? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255330.mp4', 'http://timg.bdta.pro/images/b0382372e09c0849398cc25abfa2ef60.jpg'),
(63270, 4291, 'What If...? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255331.mp4', 'http://timg.bdta.pro/images/7b1ef18b5f864a74e623307725d645ca.jpg'),
(63271, 4291, 'What If...? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255332.mp4', 'http://timg.bdta.pro/images/a78910e78cb1de1fd4b5cb3de99cc037.jpg'),
(63272, 4291, 'What If...? S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255333.mp4', 'http://timg.bdta.pro/images/7fd1657c3f3c2378432caf9d8dbd3142.jpg'),
(63273, 4291, 'What If...? S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255334.mp4', 'http://timg.bdta.pro/images/7dca763e349f02b232248977e5db24af.jpg'),
(63274, 4291, 'What If...? S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255335.mp4', 'http://image.tmdb.org/t/p/w1280/8aIDQZd0CS8Yd4LOn2uUcarppMR.jpg'),
(63275, 4291, 'What If...? S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255336.mp4', 'http://image.tmdb.org/t/p/w1280/cAeBSoSch3qUtKgtO1b5ZWzhgqC.jpg'),
(63276, 4291, 'What If...? S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255337.mp4', 'http://image.tmdb.org/t/p/w1280/qsgIiCfnQCi3CF7tQ6M7Nw4lB9O.jpg'),
(63277, 4292, 'What If...? S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255338.mp4', 'http://gstaticontent.com/images/92ef6868fe99b681639b6966e08f5bbd.jpg'),
(63278, 4292, 'What If...? S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255339.mp4', 'http://gstaticontent.com/images/92ef6868fe99b681639b6966e08f5bbd.jpg'),
(63279, 4292, 'What If...? S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255340.mp4', 'http://gstaticontent.com/images/92ef6868fe99b681639b6966e08f5bbd.jpg'),
(63280, 4292, 'What If...? S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255341.mp4', 'http://gstaticontent.com/images/92ef6868fe99b681639b6966e08f5bbd.jpg'),
(63281, 4292, 'What If...? S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255342.mp4', 'http://gstaticontent.com/images/92ef6868fe99b681639b6966e08f5bbd.jpg'),
(63282, 4292, 'What If...? S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255343.mp4', 'http://gstaticontent.com/images/92ef6868fe99b681639b6966e08f5bbd.jpg'),
(63283, 4292, 'What If...? S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255344.mp4', 'http://gstaticontent.com/images/92ef6868fe99b681639b6966e08f5bbd.jpg'),
(63284, 4292, 'What If...? S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255345.mp4', 'http://gstaticontent.com/images/92ef6868fe99b681639b6966e08f5bbd.jpg'),
(63285, 4292, 'What If...? S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255346.mp4', 'http://gstaticontent.com/images/92ef6868fe99b681639b6966e08f5bbd.jpg'),
(63286, 4293, 'What If...? S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637890.mp4', 'http://gstaticontent.com/images/92ef6868fe99b681639b6966e08f5bbd.jpg'),
(63287, 4293, 'What If...? S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/639782.mp4', 'http://gstaticontent.com/images/92ef6868fe99b681639b6966e08f5bbd.jpg'),
(63288, 4293, 'What If...? S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/639783.mp4', 'http://gstaticontent.com/images/92ef6868fe99b681639b6966e08f5bbd.jpg'),
(63289, 4293, 'What If...? S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/639784.mp4', 'http://gstaticontent.com/images/92ef6868fe99b681639b6966e08f5bbd.jpg'),
(63290, 4293, 'What If...? S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/639785.mp4', 'http://gstaticontent.com/images/92ef6868fe99b681639b6966e08f5bbd.jpg'),
(63291, 4293, 'What If...? S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/643377.mp4', 'http://gstaticontent.com/images/92ef6868fe99b681639b6966e08f5bbd.jpg'),
(63292, 4293, 'What If...? S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656522.mp4', 'http://gstaticontent.com/images/92ef6868fe99b681639b6966e08f5bbd.jpg'),
(63293, 4293, 'What If...? S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/656523.mp4', 'http://gstaticontent.com/images/92ef6868fe99b681639b6966e08f5bbd.jpg'),
(63294, 4294, 'AlRawabi School for Girls S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149516.mp4', 'http://timg.bdta.pro/images/bb48de4f5f829884f54913e6f37c1c07.jpg'),
(63295, 4294, 'AlRawabi School for Girls S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149517.mp4', 'http://timg.bdta.pro/images/e0239f13056f23e5375208db98b643ba.jpg'),
(63296, 4294, 'AlRawabi School for Girls S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149518.mp4', 'http://timg.bdta.pro/images/56d91ef2a2aeded53c213c9ddfa123b1.jpg'),
(63297, 4294, 'AlRawabi School for Girls S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149519.mp4', 'http://timg.bdta.pro/images/9e3f4182b59e4319ae5bbb2e1e1ba190.jpg'),
(63298, 4294, 'AlRawabi School for Girls S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149520.mp4', 'http://timg.bdta.pro/images/a8347c79ecf6ed5d8bb2fcde60f3e55e.jpg'),
(63299, 4294, 'AlRawabi School for Girls S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149521.mp4', 'http://timg.bdta.pro/images/8dfd895823230aadc26417de7b43888f.jpg'),
(63300, 4295, 'Deputy: O Novo Xerife S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162048.mp4', 'http://timg.bdta.pro/images/03ebfb504aad787f8560988f85110394.jpg'),
(63301, 4295, 'Deputy: O Novo Xerife S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162049.mp4', 'http://timg.bdta.pro/images/548c11822526eab54d3f89574ee3b4e9.jpg'),
(63302, 4295, 'Deputy: O Novo Xerife S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162050.mp4', 'http://timg.bdta.pro/images/41f317c096e1adbe5444eb4b7a0fb0c5.jpg'),
(63303, 4295, 'Deputy: O Novo Xerife S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162051.mp4', 'http://timg.bdta.pro/images/b65c828e6f699fd5557d0f71e76732ae.jpg'),
(63304, 4295, 'Deputy: O Novo Xerife S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162052.mp4', 'http://timg.bdta.pro/images/b2efe1651615ae92e2d1094e0d562ccc.jpg'),
(63305, 4295, 'Deputy: O Novo Xerife S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162053.mp4', 'http://timg.bdta.pro/images/7417807561cb2d7ad4f9164564e36817.jpg'),
(63306, 4295, 'Deputy: O Novo Xerife S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/162054.mp4', 'http://image.tmdb.org/t/p/w1280/o2zZchEV5ajN30Lmb1JRhFGuJ7H.jpg'),
(63307, 4295, 'Deputy: O Novo Xerife S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/162055.mp4', 'http://image.tmdb.org/t/p/w1280/3mEgF2zHn0W9DJ7AGdX6cO00lgl.jpg'),
(63308, 4295, 'Deputy: O Novo Xerife S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/162056.mp4', 'http://image.tmdb.org/t/p/w1280/8MVYElwXXhr7ranxy5LZgBCG8pj.jpg'),
(63309, 4295, 'Deputy: O Novo Xerife S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/162057.mp4', 'http://image.tmdb.org/t/p/w1280/3TOkzlBKg5OFTCi6MRJuJUp3ccq.jpg'),
(63310, 4295, 'Deputy: O Novo Xerife S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/162058.mp4', 'http://image.tmdb.org/t/p/w1280/fQHOGx6ohVUSbSFy0I0OwwMi4vV.jpg'),
(63311, 4295, 'Deputy: O Novo Xerife S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/162059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vXTq1kYxLTjSchCVZIiRLSwOXWm.jpg'),
(63312, 4295, 'Deputy: O Novo Xerife S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/162060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ko4tqOsH5HteafiaSiupTcBNid1.jpg'),
(63313, 4296, 'Esquadrão de Confeiteiros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205421.mp4', 'http://gstaticontent.com/images/3d1a6e843869f60f390eec7c38035efb.jpg'),
(63314, 4296, 'Esquadrão de Confeiteiros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205422.mp4', 'http://gstaticontent.com/images/3d1a6e843869f60f390eec7c38035efb.jpg'),
(63315, 4296, 'Esquadrão de Confeiteiros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205423.mp4', 'http://gstaticontent.com/images/3d1a6e843869f60f390eec7c38035efb.jpg'),
(63316, 4296, 'Esquadrão de Confeiteiros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205424.mp4', 'http://gstaticontent.com/images/3d1a6e843869f60f390eec7c38035efb.jpg'),
(63317, 4296, 'Esquadrão de Confeiteiros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205425.mp4', 'http://gstaticontent.com/images/3d1a6e843869f60f390eec7c38035efb.jpg'),
(63318, 4296, 'Esquadrão de Confeiteiros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205426.mp4', 'http://gstaticontent.com/images/3d1a6e843869f60f390eec7c38035efb.jpg'),
(63319, 4296, 'Esquadrão de Confeiteiros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205427.mp4', 'http://gstaticontent.com/images/3d1a6e843869f60f390eec7c38035efb.jpg'),
(63320, 4296, 'Esquadrão de Confeiteiros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205428.mp4', 'http://gstaticontent.com/images/3d1a6e843869f60f390eec7c38035efb.jpg'),
(63321, 4297, 'Esquadrão de Confeiteiros S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3YHK4MMvH1rfdnStzKsb9PDI9C4.jpg'),
(63322, 4297, 'Esquadrão de Confeiteiros S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uCLgbXQL3UNJRuQfyZlT26vWJaR.jpg'),
(63323, 4297, 'Esquadrão de Confeiteiros S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mK5dN97uBlGSxciBFm8KSzTxCq2.jpg'),
(63324, 4297, 'Esquadrão de Confeiteiros S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yipWW43n0VGxSyXTNbCN8MlVTLH.jpg'),
(63325, 4297, 'Esquadrão de Confeiteiros S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4G0D9Gkm9NnlcVquvwZCF2f9ofN.jpg'),
(63326, 4297, 'Esquadrão de Confeiteiros S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z2NIyEDNbub4LEy1rhYwGRsSBih.jpg'),
(63327, 4297, 'Esquadrão de Confeiteiros S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tYtlZnBfptAclF7GNExk7LBNGsi.jpg'),
(63328, 4297, 'Esquadrão de Confeiteiros S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aP8akq0JQJ5BZuju7TZXNoRQPB4.jpg'),
(63329, 4298, 'Stargirl S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203018.mp4', 'http://timg.bdta.pro/images/0adc8c353e92de302de63584feddbaad.jpg'),
(63330, 4298, 'Stargirl S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203019.mp4', 'http://timg.bdta.pro/images/0ba19988140cd852ef983a50eac95308.jpg'),
(63331, 4298, 'Stargirl S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203020.mp4', 'http://timg.bdta.pro/images/c3ec28e0204fafd00aca9600152b61cd.jpg'),
(63332, 4298, 'Stargirl S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203021.mp4', 'http://timg.bdta.pro/images/0cf175df470dc3785267fc5cdec49f00.jpg'),
(63333, 4298, 'Stargirl S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203022.mp4', 'http://timg.bdta.pro/images/62a1842ac21578638935cd02481eab9c.jpg'),
(63334, 4298, 'Stargirl S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203023.mp4', 'http://timg.bdta.pro/images/76ea9d121154402a4373d75ef0cf8730.jpg'),
(63335, 4298, 'Stargirl S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203024.mp4', 'http://timg.bdta.pro/images/f40a660796ff958595686c097a603212.jpg'),
(63336, 4298, 'Stargirl S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203025.mp4', 'http://timg.bdta.pro/images/61ecbff2d91fbfccbe5c1f4be9c46aba.jpg'),
(63337, 4298, 'Stargirl S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203026.mp4', 'http://timg.bdta.pro/images/fa40cca7e51b962aadf28b6182a4ef86.jpg'),
(63338, 4298, 'Stargirl S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203027.mp4', 'http://timg.bdta.pro/images/182540ff3fd95d5a7b00a5707dd57efc.jpg'),
(63339, 4298, 'Stargirl S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203028.mp4', 'http://timg.bdta.pro/images/8ee5a4d051bd69c4df04401b64886aea.jpg'),
(63340, 4298, 'Stargirl S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203029.mp4', 'http://timg.bdta.pro/images/a71a860810b47df8fb54a9e5d801426a.jpg'),
(63341, 4298, 'Stargirl S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203030.mp4', 'http://timg.bdta.pro/images/9f886bac46e35bb8ce88cb0ec7967044.jpg'),
(63342, 4299, 'Stargirl S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203031.mp4', 'http://timg.bdta.pro/images/0364ad87978c996f12dec4dca8adf3d8.jpg'),
(63343, 4299, 'Stargirl S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203032.mp4', 'http://timg.bdta.pro/images/960c49cf4f1bff5d179a6ac782bef0eb.jpg'),
(63344, 4299, 'Stargirl S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203033.mp4', 'http://timg.bdta.pro/images/121c52c0890b70763aa9bb3bb4e82c25.jpg'),
(63345, 4299, 'Stargirl S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203034.mp4', 'http://timg.bdta.pro/images/e04e83b6302be00dc5a492450270bb70.jpg'),
(63346, 4299, 'Stargirl S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203035.mp4', 'http://timg.bdta.pro/images/5be52b3b755d8f6912f281416f51ce58.jpg'),
(63347, 4299, 'Stargirl S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203036.mp4', 'http://timg.bdta.pro/images/28a6c5440e6c80853cac9136563d5430.jpg'),
(63348, 4299, 'Stargirl S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203037.mp4', 'http://image.tmdb.org/t/p/w1280/5E9Bl1ZvmzoESyHqy5PZIOAkTC8.jpg'),
(63349, 4299, 'Stargirl S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203038.mp4', 'http://image.tmdb.org/t/p/w1280/93hhZ0pEPOKu2UUhV9ElMlJsvIZ.jpg'),
(63350, 4299, 'Stargirl S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203039.mp4', 'http://image.tmdb.org/t/p/w1280/AgRaK59FBu0ACQOGUHk68JN7SOm.jpg'),
(63351, 4299, 'Stargirl S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203040.mp4', 'http://image.tmdb.org/t/p/w1280/sOQoMKeVDnQKXpSYJrkEsTGul1k.jpg'),
(63352, 4299, 'Stargirl S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eVlmdHnbYLloN5mKhIA7OcvJE1h.jpg'),
(63353, 4299, 'Stargirl S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sawbfuca1b6zO3qxWHCM55NZCd4.jpg'),
(63354, 4299, 'Stargirl S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203043.mp4', 'http://image.tmdb.org/t/p/w1280/1Mwv8tUi9vtszJ8H0zmnCpay6wo.jpg'),
(63355, 4300, 'Stargirl S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203044.mp4', 'http://timg.bdta.pro/images/b75afaaef3b370592f25a32edf9d0df6.jpg'),
(63356, 4300, 'Stargirl S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203045.mp4', 'http://timg.bdta.pro/images/be61258c655462e5856b072160de6ff9.jpg'),
(63357, 4300, 'Stargirl S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203046.mp4', 'http://timg.bdta.pro/images/e5f5ac65d2a7aa3023c63ebdc9ddd92b.jpg'),
(63358, 4300, 'Stargirl S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203047.mp4', 'http://timg.bdta.pro/images/bff04803768e04ecf710d1b77b443295.jpg'),
(63359, 4300, 'Stargirl S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203048.mp4', 'http://timg.bdta.pro/images/073fb9017753466847d59983d10dd13e.jpg'),
(63360, 4300, 'Stargirl S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203049.mp4', 'http://timg.bdta.pro/images/a173b483cd6327b5ca40c5df42c4957c.jpg'),
(63361, 4300, 'Stargirl S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ttuYkKWsH63UsIqVoZf23uMDZJ.jpg'),
(63362, 4300, 'Stargirl S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vn2ZTH8RVgxUprpnmMVn0bmzZLf.jpg'),
(63363, 4300, 'Stargirl S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tayfAL7jgF4KfsbmRjc3NszrN8X.jpg'),
(63364, 4300, 'Stargirl S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qwpk7YBTD60g2ARF99qaRWQSN1H.jpg'),
(63365, 4300, 'Stargirl S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203054.mp4', 'http://image.tmdb.org/t/p/w1280/9rOy5f4RRFGQYo7WCpHIDJu3Ak8.jpg'),
(63366, 4300, 'Stargirl S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203055.mp4', 'http://image.tmdb.org/t/p/w1280/4XOtIeB3pGm7AqAXKY7tZVAwkMD.jpg'),
(63367, 4300, 'Stargirl S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203056.mp4', 'http://image.tmdb.org/t/p/w1280/k00LhKH8A5HTZw7aRSY7uIUpwq5.jpg'),
(63368, 4301, 'Desaparecido para Sempre S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149302.mp4', 'http://timg.bdta.pro/images/4d6e34edd5138acdd2d6b8282d1211ca.jpg'),
(63369, 4301, 'Desaparecido para Sempre S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149303.mp4', 'http://timg.bdta.pro/images/760d5a7066e47cc9bfb5493db5731527.jpg'),
(63370, 4301, 'Desaparecido para Sempre S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149304.mp4', 'http://timg.bdta.pro/images/e6e51ec891cb4919be98e0083867a6ec.jpg'),
(63371, 4301, 'Desaparecido para Sempre S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149305.mp4', 'http://timg.bdta.pro/images/2e1877b3505830963945b3151347be2d.jpg'),
(63372, 4301, 'Desaparecido para Sempre S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149306.mp4', 'http://timg.bdta.pro/images/79f097d3fc308d5dec83a52895e13851.jpg'),
(63373, 4302, 'Mr. Corman S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161441.mp4', 'http://timg.bdta.pro/images/d950af4cb5a945d6e4e0154648bf072d.jpg'),
(63374, 4302, 'Mr. Corman S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161442.mp4', 'http://timg.bdta.pro/images/aab606f96bcad4cc4ba0db2753f120f3.jpg'),
(63375, 4302, 'Mr. Corman S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161443.mp4', 'http://timg.bdta.pro/images/12322cda658648f1db0d9d85e95cdf81.jpg'),
(63376, 4302, 'Mr. Corman S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161444.mp4', 'http://timg.bdta.pro/images/5a74e7cd5078c80db9d89a3def975399.jpg'),
(63377, 4302, 'Mr. Corman S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161445.mp4', 'http://timg.bdta.pro/images/19778d8b0040a233add4a86fa0428c0c.jpg'),
(63378, 4302, 'Mr. Corman S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161446.mp4', 'http://timg.bdta.pro/images/a30288e14ea6a247062e25ddfb0fd02f.jpg'),
(63379, 4302, 'Mr. Corman S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161447.mp4', 'http://timg.bdta.pro/images/df3341875949d9cbfe5b6e6f3b69ba24.jpg'),
(63380, 4302, 'Mr. Corman S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161448.mp4', 'http://timg.bdta.pro/images/8a3b36c808bdea27acb4070687f60a7f.jpg'),
(63381, 4302, 'Mr. Corman S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161449.mp4', 'http://image.tmdb.org/t/p/w1280/tiCa0jKwQiUjO69G4hWHQQnwD7F.jpg'),
(63382, 4302, 'Mr. Corman S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161450.mp4', 'http://image.tmdb.org/t/p/w1280/k2SU08y3pDhBKOKuGjMnI67nKk4.jpg'),
(63383, 4303, 'Vingança Sabor Cereja S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149294.mp4', 'http://timg.bdta.pro/images/8b4720ba2fac924244e60efa30f79b1c.jpg'),
(63384, 4303, 'Vingança Sabor Cereja S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149295.mp4', 'http://timg.bdta.pro/images/c7787cc56223acbec446639b9ac65c48.jpg'),
(63385, 4303, 'Vingança Sabor Cereja S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149296.mp4', 'http://timg.bdta.pro/images/24ad4e5d62372fb1bb42d7e95b893b66.jpg'),
(63386, 4303, 'Vingança Sabor Cereja S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149297.mp4', 'http://timg.bdta.pro/images/c6e9b74ab86378d6b4fd0fd0c2cf631e.jpg'),
(63387, 4303, 'Vingança Sabor Cereja S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149298.mp4', 'http://timg.bdta.pro/images/8a8cbaf995a0f4bda659548c0991ef49.jpg'),
(63388, 4303, 'Vingança Sabor Cereja S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149299.mp4', 'http://timg.bdta.pro/images/2004e2784f8e17f6248fd76c4465edce.jpg'),
(63389, 4303, 'Vingança Sabor Cereja S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149300.mp4', 'http://timg.bdta.pro/images/4ee78b970dc1f6b343108c9e9008ca27.jpg'),
(63390, 4303, 'Vingança Sabor Cereja S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149301.mp4', 'http://timg.bdta.pro/images/0ac1fa90e1e4eec6c709fd9810b52b0d.jpg'),
(63391, 4304, 'Vosso Reino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149286.mp4', 'http://timg.bdta.pro/images/43f3078f5311791a3be6a8df73229fb4.jpg'),
(63392, 4304, 'Vosso Reino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149287.mp4', 'http://timg.bdta.pro/images/7063f6917b3e84f2948ba00d8f1a07a3.jpg'),
(63393, 4304, 'Vosso Reino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149288.mp4', 'http://timg.bdta.pro/images/ac1e0cb6958cf89f1b6c6e4be0f6b22f.jpg'),
(63394, 4304, 'Vosso Reino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149289.mp4', 'http://timg.bdta.pro/images/b699cf90b85d7b9d4e248f8325894efe.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(63395, 4304, 'Vosso Reino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149290.mp4', 'http://timg.bdta.pro/images/6e9207d8693ad5b5ee33def9eb64d3ad.jpg'),
(63396, 4304, 'Vosso Reino S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149291.mp4', 'http://timg.bdta.pro/images/674b064483ea17c8c8e8222292d76106.jpg'),
(63397, 4304, 'Vosso Reino S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149292.mp4', 'http://timg.bdta.pro/images/e72371f18143f0f672775beaf4b44bd9.jpg'),
(63398, 4304, 'Vosso Reino S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149293.mp4', 'http://timg.bdta.pro/images/1a8cebbdd85cf8b8eeb7dc3cbd2e3cc4.jpg'),
(63399, 4305, '100 Code S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149236.mp4', 'http://timg.bdta.pro/images/ed6afd6667c244e6e1bb85bdf374fa5a.jpg'),
(63400, 4305, '100 Code S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149237.mp4', 'http://timg.bdta.pro/images/7806cff970db03091bc27b17d7ae4055.jpg'),
(63401, 4305, '100 Code S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149238.mp4', 'http://timg.bdta.pro/images/c241779255652ed28ea8e6eb2e54c254.jpg'),
(63402, 4305, '100 Code S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149239.mp4', 'http://timg.bdta.pro/images/6d951655a4e12ef0baffc5f8c4a67ff4.jpg'),
(63403, 4305, '100 Code S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149240.mp4', 'http://timg.bdta.pro/images/cfea8c964842a6d729b64f1e526c2941.jpg'),
(63404, 4305, '100 Code S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149241.mp4', 'http://timg.bdta.pro/images/0001ed0f93a8f2db3af1c6103fd58e17.jpg'),
(63405, 4305, '100 Code S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149242.mp4', 'http://timg.bdta.pro/images/1a2f1e3639c99d3b1b5b6dad07b3e519.jpg'),
(63406, 4305, '100 Code S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149243.mp4', 'http://timg.bdta.pro/images/fc025a90b860a12f1eef42cbca247ea0.jpg'),
(63407, 4305, '100 Code S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/149244.mp4', 'http://timg.bdta.pro/images/f5de8d2555ce9b3adcf8982b034137c3.jpg'),
(63408, 4305, '100 Code S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/149245.mp4', 'http://timg.bdta.pro/images/6c2050758eff7b3351af92b70a29e6d9.jpg'),
(63409, 4305, '100 Code S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/149246.mp4', 'http://timg.bdta.pro/images/48cf6a810b0d5378a7963ad2782c27d9.jpg'),
(63410, 4305, '100 Code S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/149247.mp4', 'http://timg.bdta.pro/images/6d6eb70b6570841caf42884ff6b109ff.jpg'),
(63411, 4306, 'Animaniacs S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217870.mp4', 'http://timg.bdta.pro/images/4698bbdd8a3e48f58ea63d7fce66b881.jpg'),
(63412, 4306, 'Animaniacs S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217871.mp4', 'http://timg.bdta.pro/images/df257ccb639bdf6597667647ffdd5cd5.jpg'),
(63413, 4306, 'Animaniacs S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217872.mp4', 'http://timg.bdta.pro/images/05bd618117f59197588bde96076df987.jpg'),
(63414, 4306, 'Animaniacs S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217873.mp4', 'http://timg.bdta.pro/images/69809b55c71e4ad4ac4bf6bb13a55223.jpg'),
(63415, 4306, 'Animaniacs S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217874.mp4', 'http://timg.bdta.pro/images/ba0c0d2143209c4a9448eef87bcfc842.jpg'),
(63416, 4306, 'Animaniacs S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217875.mp4', 'http://timg.bdta.pro/images/131fed0b7bbe1a61373787d0319ef8ca.jpg'),
(63417, 4306, 'Animaniacs S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217876.mp4', 'http://timg.bdta.pro/images/a95d4eb74a3845960c165eac7e10183e.jpg'),
(63418, 4306, 'Animaniacs S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217877.mp4', 'http://timg.bdta.pro/images/66fe982e781ac11d9c9208a6df7cb85c.jpg'),
(63419, 4306, 'Animaniacs S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217878.mp4', 'http://timg.bdta.pro/images/e73281c93063965fa9ee2947a31d6715.jpg'),
(63420, 4306, 'Animaniacs S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217879.mp4', 'http://timg.bdta.pro/images/276224c3cea1b51ab70314aaa7163370.jpg'),
(63421, 4306, 'Animaniacs S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217880.mp4', 'http://timg.bdta.pro/images/179aeb60551231ec3628e5e7db701282.jpg'),
(63422, 4306, 'Animaniacs S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217881.mp4', 'http://timg.bdta.pro/images/2d414e0d5ecbe9c7f61c234965b06223.jpg'),
(63423, 4306, 'Animaniacs S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217882.mp4', 'http://timg.bdta.pro/images/db59bb2b01761ca3654d2c44e01eac65.jpg'),
(63424, 4307, 'Animaniacs S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217883.mp4', 'http://timg.bdta.pro/images/2c4e63c61f93bcb83b8b0664089182c5.jpg'),
(63425, 4307, 'Animaniacs S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217884.mp4', 'http://timg.bdta.pro/images/82a1cb0c54d8e4597f1e4bee0f264ec5.jpg'),
(63426, 4307, 'Animaniacs S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217885.mp4', 'http://timg.bdta.pro/images/573ab9bcec4fc5f34d501719bb5d38e1.jpg'),
(63427, 4307, 'Animaniacs S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217886.mp4', 'http://timg.bdta.pro/images/66813068f4c9366fa98c4d050ba80cdf.jpg'),
(63428, 4307, 'Animaniacs S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217887.mp4', 'http://timg.bdta.pro/images/cd38075dd55522361e8e5ad6e1d2eb2a.jpg'),
(63429, 4307, 'Animaniacs S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217888.mp4', 'http://timg.bdta.pro/images/efa844143ff84a24c9936d4def5955f1.jpg'),
(63430, 4307, 'Animaniacs S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217889.mp4', 'http://timg.bdta.pro/images/0cb23a550f3f3d6b4a4a097f4fb9cc9c.jpg'),
(63431, 4307, 'Animaniacs S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217890.mp4', 'http://timg.bdta.pro/images/0dfb69247ea8f3d0aaf8899b09650d58.jpg'),
(63432, 4307, 'Animaniacs S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217891.mp4', 'http://timg.bdta.pro/images/dbde3b5f7f083736156518e027e70215.jpg'),
(63433, 4307, 'Animaniacs S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217892.mp4', 'http://timg.bdta.pro/images/5c4e4a84220ff853efd360ead53bbee0.jpg'),
(63434, 4307, 'Animaniacs S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217893.mp4', 'http://timg.bdta.pro/images/5fef5992fec832f62b8f5f601bf6d787.jpg'),
(63435, 4307, 'Animaniacs S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217894.mp4', 'http://timg.bdta.pro/images/6788db89b05ee7de63232c6a76b03381.jpg'),
(63436, 4307, 'Animaniacs S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217895.mp4', 'http://timg.bdta.pro/images/c1f2dd1aadf47b249b1a24d8f94c5770.jpg'),
(63437, 4307, 'Animaniacs S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/217896.mp4', 'http://timg.bdta.pro/images/b4f18c74c57f8f66b8d4710ab74ca7e7.jpg'),
(63438, 4307, 'Animaniacs S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/217897.mp4', 'http://timg.bdta.pro/images/5716887590e0ce5dbacef77191cb0c17.jpg'),
(63439, 4307, 'Animaniacs S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/217898.mp4', 'http://timg.bdta.pro/images/a7c1a818c2b146c8bfe252c3385a5387.jpg'),
(63440, 4307, 'Animaniacs S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/217899.mp4', 'http://timg.bdta.pro/images/5f297d7605b485b71596795edc388e7f.jpg'),
(63441, 4307, 'Animaniacs S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/217900.mp4', 'http://timg.bdta.pro/images/ccf4103c54b1ddc0b835da6e98b5397c.jpg'),
(63442, 4308, 'Animaniacs S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mkdzbf0UvP7lmTQFeC8WsJXSy5J.jpg'),
(63443, 4308, 'Animaniacs S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w5FUg3KSl607ldL0AIzLKPj3aaa.jpg'),
(63444, 4308, 'Animaniacs S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mLzq1IQpnXQeOTvbF9DK5NB3Ut6.jpg'),
(63445, 4308, 'Animaniacs S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A7pY9K0Fr7ZQ9ZAu9w9qgTD2VAI.jpg'),
(63446, 4308, 'Animaniacs S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ik8zETsBSNUkiUsNUCSkHQRO5Wu.jpg'),
(63447, 4308, 'Animaniacs S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2mvI231EnwpO9ef5XV1dCQU94Bm.jpg'),
(63448, 4308, 'Animaniacs S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kuVbaHpA2jxVTClxzhdbBPvqQne.jpg'),
(63449, 4308, 'Animaniacs S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fC1fyvZG9mfvu8oyBH7i7ZviC5A.jpg'),
(63450, 4308, 'Animaniacs S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tfgn4skBTVqH1d3Tr4rB04rYgDD.jpg'),
(63451, 4309, 'Belgravia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149230.mp4', 'http://timg.bdta.pro/images/4fb72cb7ed8069674b00dfeded53da4b.jpg'),
(63452, 4309, 'Belgravia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149231.mp4', 'http://timg.bdta.pro/images/9bef25607b1af9f59f44645f8ca3e5d7.jpg'),
(63453, 4309, 'Belgravia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149232.mp4', 'http://timg.bdta.pro/images/856586f02a621cea8e152f0b3c9b00e4.jpg'),
(63454, 4309, 'Belgravia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149233.mp4', 'http://timg.bdta.pro/images/032d32cbbb48f6f4d7d61e1af4bee7d2.jpg'),
(63455, 4309, 'Belgravia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149234.mp4', 'http://timg.bdta.pro/images/5f0c39d18bd8aa6b34f4b6d4c8454a16.jpg'),
(63456, 4309, 'Belgravia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149235.mp4', 'http://timg.bdta.pro/images/18abaac4ee503cc947aec12862a56ebd.jpg'),
(63457, 4310, 'Black Space S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149222.mp4', 'http://timg.bdta.pro/images/6fcfddc30b4f9cbbe88c07757c1e3128.jpg'),
(63458, 4310, 'Black Space S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149223.mp4', 'http://timg.bdta.pro/images/3668b89aaf76fc791eab78e930e0842b.jpg'),
(63459, 4310, 'Black Space S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149224.mp4', 'http://timg.bdta.pro/images/5c0545b6f431bca86420ea5f83e99ac0.jpg'),
(63460, 4310, 'Black Space S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149225.mp4', 'http://timg.bdta.pro/images/764bdaa054c8a344160cfb6177bb868f.jpg'),
(63461, 4310, 'Black Space S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149226.mp4', 'http://timg.bdta.pro/images/5845f07400b05189d6bf8cc337008e3b.jpg'),
(63462, 4310, 'Black Space S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149227.mp4', 'http://timg.bdta.pro/images/66de5efb2c6b4f16b9bdecfe2d963b21.jpg'),
(63463, 4310, 'Black Space S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/149228.mp4', 'http://timg.bdta.pro/images/b9431303d1d6eb6c6cea41565e6f147a.jpg'),
(63464, 4310, 'Black Space S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/149229.mp4', 'http://timg.bdta.pro/images/ca108ca07bd39a304712fd4828f89f25.jpg'),
(63465, 4311, 'Code 404 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181107.mp4', 'http://timg.bdta.pro/images/b5233b77d5fe9ab918bd023fe4c2f39c.jpg'),
(63466, 4311, 'Code 404 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181108.mp4', 'http://timg.bdta.pro/images/2848b334ac3295f2e05b2b830c2bd300.jpg'),
(63467, 4311, 'Code 404 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181109.mp4', 'http://timg.bdta.pro/images/bc0d1872ae1ec46d6c5e5ad56a8eacb4.jpg'),
(63468, 4311, 'Code 404 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181110.mp4', 'http://timg.bdta.pro/images/0d7a87ba12be5f0bb39a687da487e4fd.jpg'),
(63469, 4311, 'Code 404 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181111.mp4', 'http://timg.bdta.pro/images/bb8e8e9bfa2bbd209b26937539c805e8.jpg'),
(63470, 4311, 'Code 404 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181112.mp4', 'http://timg.bdta.pro/images/0b79b03b0c742a64b6aba6d7b3985f7e.jpg'),
(63471, 4312, 'Code 404 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181113.mp4', 'http://timg.bdta.pro/images/7dd9014b2975959f03545e2a3eaf53e8.jpg'),
(63472, 4312, 'Code 404 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181114.mp4', 'http://timg.bdta.pro/images/4f80964bc0285634a6197dd5c62b742d.jpg'),
(63473, 4312, 'Code 404 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181115.mp4', 'http://timg.bdta.pro/images/87e9e80d6b9359598f2a7f83a3be7c5c.jpg'),
(63474, 4312, 'Code 404 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181116.mp4', 'http://timg.bdta.pro/images/b9bac8901e8e53d3ba02e5182d17dc37.jpg'),
(63475, 4312, 'Code 404 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181117.mp4', 'http://timg.bdta.pro/images/46f38e8e1a8bc1acdd347636d492b395.jpg'),
(63476, 4312, 'Code 404 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181118.mp4', 'http://timg.bdta.pro/images/268d3b378832f53921a8f4b484967f9e.jpg'),
(63477, 4313, 'Coyote S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149216.mp4', 'http://timg.bdta.pro/images/d5d7331c2a1a7166ef2707944b678d65.jpg'),
(63478, 4313, 'Coyote S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149217.mp4', 'http://timg.bdta.pro/images/61e554552f123f988382cec0e0672111.jpg'),
(63479, 4313, 'Coyote S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149218.mp4', 'http://timg.bdta.pro/images/7b337c70be5d9bc0c5929d3b20a92804.jpg'),
(63480, 4313, 'Coyote S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149219.mp4', 'http://timg.bdta.pro/images/8b7015d3d7c735a5eb47336f21abab22.jpg'),
(63481, 4313, 'Coyote S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149220.mp4', 'http://timg.bdta.pro/images/b1e8f7010f99ff1e8716b95a42156a90.jpg'),
(63482, 4313, 'Coyote S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149221.mp4', 'http://timg.bdta.pro/images/f49cbf13b0a6ef29eb07f366e79c74c3.jpg'),
(63483, 4314, 'D.C. Reino e Império S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159061.mp4', 'http://timg.bdta.pro/images/65ecbdc7628010492016c4a9309d819a.jpg'),
(63484, 4314, 'D.C. Reino e Império S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159062.mp4', 'http://timg.bdta.pro/images/12096732dc1136d242a979f030102995.jpg'),
(63485, 4314, 'D.C. Reino e Império S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159063.mp4', 'http://timg.bdta.pro/images/493234bc8d8d88eafa5f1c16faf31e6c.jpg'),
(63486, 4314, 'D.C. Reino e Império S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159064.mp4', 'http://timg.bdta.pro/images/038be45326a233df8099643d36a01e6a.jpg'),
(63487, 4314, 'D.C. Reino e Império S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159065.mp4', 'http://timg.bdta.pro/images/a4f015593fe2a76d994dda5a40bcd348.jpg'),
(63488, 4314, 'D.C. Reino e Império S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159066.mp4', 'http://timg.bdta.pro/images/b26462b5f3ec2fce87585c739f6fc10c.jpg'),
(63489, 4314, 'D.C. Reino e Império S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159067.mp4', 'http://timg.bdta.pro/images/1a17536090ad0faaa0a61fed72611daa.jpg'),
(63490, 4314, 'D.C. Reino e Império S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159068.mp4', 'http://timg.bdta.pro/images/88ac72e3146b513d3951f42a786bbeac.jpg'),
(63491, 4314, 'D.C. Reino e Império S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159069.mp4', 'http://timg.bdta.pro/images/00749eb35ecead655310a627fa4aaf4e.jpg'),
(63492, 4314, 'D.C. Reino e Império S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159070.mp4', 'http://timg.bdta.pro/images/ed0fbe09f1b487fadc2f63498b12e647.jpg'),
(63493, 4314, 'D.C. Reino e Império S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159071.mp4', 'http://timg.bdta.pro/images/dead1f8b38031a39814cff3434b13df9.jpg'),
(63494, 4314, 'D.C. Reino e Império S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159072.mp4', 'http://timg.bdta.pro/images/6abc325f0d0830ae64734fb864400950.jpg'),
(63495, 4315, 'Grace and Frankie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207429.mp4', 'http://timg.bdta.pro/images/870bc1cdc4966a9fb9fed7b876827dda.jpg'),
(63496, 4315, 'Grace and Frankie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207430.mp4', 'http://timg.bdta.pro/images/b632d02fea48c78281e9d72af2b1c99f.jpg'),
(63497, 4315, 'Grace and Frankie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207431.mp4', 'http://timg.bdta.pro/images/6bc858e80a15952fc23e39324881a7ab.jpg'),
(63498, 4315, 'Grace and Frankie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207432.mp4', 'http://timg.bdta.pro/images/eff2577dc3b22a655f5466f56f0cbeee.jpg'),
(63499, 4315, 'Grace and Frankie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207433.mp4', 'http://timg.bdta.pro/images/ee11f2ce5a2c2f4b23a8580c839a357b.jpg'),
(63500, 4315, 'Grace and Frankie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207434.mp4', 'http://timg.bdta.pro/images/e51f878417ae8eb196e782310c14f2b5.jpg'),
(63501, 4315, 'Grace and Frankie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207435.mp4', 'http://timg.bdta.pro/images/2c86b0db081e8f793f81a06472a456a9.jpg'),
(63502, 4315, 'Grace and Frankie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207436.mp4', 'http://timg.bdta.pro/images/892a911790947365a208e294dfc0414b.jpg'),
(63503, 4315, 'Grace and Frankie S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207437.mp4', 'http://timg.bdta.pro/images/c08b16c0e0b379e480b958ef024dbac8.jpg'),
(63504, 4315, 'Grace and Frankie S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207438.mp4', 'http://timg.bdta.pro/images/8ca6d9030a022af609e5aad4f826707c.jpg'),
(63505, 4315, 'Grace and Frankie S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207439.mp4', 'http://timg.bdta.pro/images/5a1d5d57096ab86d4c176bcdf486e14a.jpg'),
(63506, 4315, 'Grace and Frankie S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207440.mp4', 'http://timg.bdta.pro/images/35dc4b66fbe546e9cb4e4cabe8e3f73e.jpg'),
(63507, 4315, 'Grace and Frankie S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207441.mp4', 'http://timg.bdta.pro/images/72c2b486afa82b9567e8ff6aab4760a5.jpg'),
(63508, 4316, 'Grace and Frankie S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207442.mp4', 'http://timg.bdta.pro/images/c759660f3f450927028b11925660288b.jpg'),
(63509, 4316, 'Grace and Frankie S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207443.mp4', 'http://timg.bdta.pro/images/8cb9aa01615798cddcbf5c41be3992ce.jpg'),
(63510, 4316, 'Grace and Frankie S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207444.mp4', 'http://timg.bdta.pro/images/901d66ac94a4fa757c245181f6624ee5.jpg'),
(63511, 4316, 'Grace and Frankie S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207445.mp4', 'http://timg.bdta.pro/images/7d721f717ae315b247e4a35a74f67c83.jpg'),
(63512, 4316, 'Grace and Frankie S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207446.mp4', 'http://timg.bdta.pro/images/8f059df576b85ba0725d9d2cee637e81.jpg'),
(63513, 4316, 'Grace and Frankie S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207447.mp4', 'http://timg.bdta.pro/images/85ee1b6a0c516c5ddf6b62f361155bf9.jpg'),
(63514, 4316, 'Grace and Frankie S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207448.mp4', 'http://timg.bdta.pro/images/8845e9c391c762aaa5c79418744752e4.jpg'),
(63515, 4316, 'Grace and Frankie S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207449.mp4', 'http://timg.bdta.pro/images/ac02820d51bf15082e4fe5b6d6625859.jpg'),
(63516, 4316, 'Grace and Frankie S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207450.mp4', 'http://timg.bdta.pro/images/269d9b3630dd2d1a21858f28ea95a6e4.jpg'),
(63517, 4316, 'Grace and Frankie S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207451.mp4', 'http://timg.bdta.pro/images/7f36bd6276be6f6042e4713807f51a01.jpg'),
(63518, 4316, 'Grace and Frankie S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207452.mp4', 'http://timg.bdta.pro/images/9a6943fe870156f3278201e38abd0df2.jpg'),
(63519, 4316, 'Grace and Frankie S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207453.mp4', 'http://timg.bdta.pro/images/5d321c83583d4332446360d723d2793e.jpg'),
(63520, 4316, 'Grace and Frankie S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207454.mp4', 'http://timg.bdta.pro/images/f8ac1f5ff73eeaaeee2543a655025676.jpg'),
(63521, 4317, 'Grace and Frankie S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207455.mp4', 'http://timg.bdta.pro/images/d099115233d528e446c3ce5b19ecedc9.jpg'),
(63522, 4317, 'Grace and Frankie S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207456.mp4', 'http://timg.bdta.pro/images/934ab20c2ae6e093f9f354abef460bd2.jpg'),
(63523, 4317, 'Grace and Frankie S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207457.mp4', 'http://timg.bdta.pro/images/16b1c2c26d82c019134270f70baf4544.jpg'),
(63524, 4317, 'Grace and Frankie S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207458.mp4', 'http://timg.bdta.pro/images/2cd6415033d39bcdbe67fc680d56832f.jpg'),
(63525, 4317, 'Grace and Frankie S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207459.mp4', 'http://timg.bdta.pro/images/26bdf6153c36a7cfda5cb126095e6847.jpg'),
(63526, 4317, 'Grace and Frankie S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207460.mp4', 'http://timg.bdta.pro/images/16e1c2e4f1807246deda174123daf246.jpg'),
(63527, 4317, 'Grace and Frankie S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207461.mp4', 'http://timg.bdta.pro/images/eb70e1c058c27bf341e7f2146b8ce1e8.jpg'),
(63528, 4317, 'Grace and Frankie S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207462.mp4', 'http://timg.bdta.pro/images/43c0c7ce6a8696e88d2755dc530f1019.jpg'),
(63529, 4317, 'Grace and Frankie S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207463.mp4', 'http://timg.bdta.pro/images/969433b147db7a17fa7fd85e8cd0b3aa.jpg'),
(63530, 4317, 'Grace and Frankie S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207464.mp4', 'http://timg.bdta.pro/images/d0963bde6c92391e8832df5130653a0e.jpg'),
(63531, 4317, 'Grace and Frankie S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207465.mp4', 'http://timg.bdta.pro/images/0e79f47c6d27da2f6016835094847601.jpg'),
(63532, 4317, 'Grace and Frankie S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207466.mp4', 'http://timg.bdta.pro/images/c41232052d1368651635082ac60f6415.jpg'),
(63533, 4317, 'Grace and Frankie S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207467.mp4', 'http://timg.bdta.pro/images/233b2ce9b78ed05114190f10d7bc923d.jpg'),
(63534, 4318, 'Grace and Frankie S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207468.mp4', 'http://timg.bdta.pro/images/af30473b24120e8a7c8a09125e13e605.jpg'),
(63535, 4318, 'Grace and Frankie S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207469.mp4', 'http://timg.bdta.pro/images/a3688f2cfe5b04a0f0c31c0fef26df58.jpg'),
(63536, 4318, 'Grace and Frankie S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207470.mp4', 'http://timg.bdta.pro/images/ecf552a0f3cfad31e977afe00d5a3a00.jpg'),
(63537, 4318, 'Grace and Frankie S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207471.mp4', 'http://timg.bdta.pro/images/cf630ed6f495b823d1d725da22623f67.jpg'),
(63538, 4318, 'Grace and Frankie S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207472.mp4', 'http://timg.bdta.pro/images/c17c6c0b3d3373e6b1fc70b281a4b956.jpg'),
(63539, 4318, 'Grace and Frankie S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207473.mp4', 'http://timg.bdta.pro/images/9215f824ab5501acf9c466934c9ddbea.jpg'),
(63540, 4318, 'Grace and Frankie S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207474.mp4', 'http://timg.bdta.pro/images/b662459daaffae0789fa9d830f327ad9.jpg'),
(63541, 4318, 'Grace and Frankie S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207475.mp4', 'http://timg.bdta.pro/images/bb1523adc808211644cbb4885d7caf58.jpg'),
(63542, 4318, 'Grace and Frankie S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207476.mp4', 'http://timg.bdta.pro/images/e4ce73f2b163b39c7835d678f3c42e36.jpg'),
(63543, 4318, 'Grace and Frankie S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207477.mp4', 'http://timg.bdta.pro/images/6997f5f8c188ef5abc1a2d50c7b7a4f2.jpg'),
(63544, 4318, 'Grace and Frankie S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207478.mp4', 'http://timg.bdta.pro/images/2a5bae21e913c77ecaf8b2b0e51d12d0.jpg'),
(63545, 4318, 'Grace and Frankie S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207479.mp4', 'http://timg.bdta.pro/images/084b5318de5789150a6a9d74be57b8de.jpg'),
(63546, 4318, 'Grace and Frankie S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207480.mp4', 'http://timg.bdta.pro/images/ba763c700f9046066226985695e6f175.jpg'),
(63547, 4319, 'Grace and Frankie S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207481.mp4', 'http://timg.bdta.pro/images/9c78cd54b1f14e082617ecb7d032bf94.jpg'),
(63548, 4319, 'Grace and Frankie S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207482.mp4', 'http://timg.bdta.pro/images/d7bfa9ed71088b9e9c7c4713c14ffc96.jpg'),
(63549, 4319, 'Grace and Frankie S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207483.mp4', 'http://timg.bdta.pro/images/500640745f59f10a26425c0ba61f4c3d.jpg'),
(63550, 4319, 'Grace and Frankie S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207484.mp4', 'http://timg.bdta.pro/images/7890fe65a635d32b40689d4d9e25a229.jpg'),
(63551, 4319, 'Grace and Frankie S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207485.mp4', 'http://timg.bdta.pro/images/c729399bd1a7ea63a490f0fc7d69f712.jpg'),
(63552, 4319, 'Grace and Frankie S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207486.mp4', 'http://timg.bdta.pro/images/95e4d8584e4959dc21a5a3b719f967f7.jpg'),
(63553, 4319, 'Grace and Frankie S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207487.mp4', 'http://timg.bdta.pro/images/4c670556e2f31a076e649c2b4d6a9ef9.jpg'),
(63554, 4319, 'Grace and Frankie S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207488.mp4', 'http://timg.bdta.pro/images/fc8b6b9b3d9924ed7f598203140fe505.jpg'),
(63555, 4319, 'Grace and Frankie S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207489.mp4', 'http://timg.bdta.pro/images/61b0b0bac019d6911a5cac56d2106793.jpg'),
(63556, 4319, 'Grace and Frankie S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207490.mp4', 'http://timg.bdta.pro/images/c9c23a90620ec6e0cb6fdb0a217cde86.jpg'),
(63557, 4319, 'Grace and Frankie S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207491.mp4', 'http://timg.bdta.pro/images/0d384357ad09cfa8b940942263e18325.jpg'),
(63558, 4319, 'Grace and Frankie S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207492.mp4', 'http://timg.bdta.pro/images/74b3fa3cbdc1d6f5c873eeecdb618412.jpg'),
(63559, 4319, 'Grace and Frankie S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207493.mp4', 'http://timg.bdta.pro/images/bb40dcffb9619f53743d5fa8f6a69487.jpg'),
(63560, 4320, 'Grace and Frankie S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cFCUZNYRSlNOKk318kdMofkcquE.jpg'),
(63561, 4320, 'Grace and Frankie S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ecUyvRwj7lGLlIzGdUqx8xTqrDJ.jpg'),
(63562, 4320, 'Grace and Frankie S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eTTfwoGfusdpa3f4djw66lQReZ1.jpg'),
(63563, 4320, 'Grace and Frankie S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vvfAp92tTol2QN7AR44VWKmLyLC.jpg'),
(63564, 4320, 'Grace and Frankie S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSkqnPYuHSBCglM4cU7lOl8SG5X.jpg'),
(63565, 4320, 'Grace and Frankie S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dchWlfgEtuPiGImj9KbPJKkoyfg.jpg'),
(63566, 4320, 'Grace and Frankie S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cFu7u0bV7Z6Xp1Pv4WxnF5AmNZ2.jpg'),
(63567, 4320, 'Grace and Frankie S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1AHbhzLFq9q7wF3dcCBDDhMzSl9.jpg'),
(63568, 4320, 'Grace and Frankie S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/izbK7JBJH69OBqXvJ80ZYs5foEM.jpg'),
(63569, 4320, 'Grace and Frankie S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PbPAD70H2ZaMJf5B1mxC8otmZu.jpg'),
(63570, 4320, 'Grace and Frankie S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z2wciTlsnN7cOc853WF8WHbjjPk.jpg'),
(63571, 4320, 'Grace and Frankie S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i0F9GraNwj6Zq0zfNRQLppl6Juz.jpg'),
(63572, 4320, 'Grace and Frankie S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bybHikKtVysGwDaNUWk26ZQ0ryq.jpg'),
(63573, 4321, 'Grace and Frankie S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207507.mp4', 'http://timg.bdta.pro/images/9df4fbc3f938541803d44f2c95a3023d.jpg'),
(63574, 4321, 'Grace and Frankie S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207508.mp4', 'http://timg.bdta.pro/images/3f777cd190d4d1a93a27d0561d73cb7e.jpg'),
(63575, 4321, 'Grace and Frankie S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207509.mp4', 'http://timg.bdta.pro/images/d88c1af067dad47ba2c50cac80bc94c9.jpg'),
(63576, 4321, 'Grace and Frankie S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207510.mp4', 'http://timg.bdta.pro/images/128b4bc739ca242ba5f7fe35f968eaf8.jpg'),
(63577, 4321, 'Grace and Frankie S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bPkeAJ4FSkZ8ZThMujw9EtvTKHT.jpg'),
(63578, 4321, 'Grace and Frankie S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ap8cfxwuAuhOLufkUCGujAJp7wB.jpg'),
(63579, 4321, 'Grace and Frankie S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3oGmmlcGuCW9657ytukio4eZkWb.jpg'),
(63580, 4321, 'Grace and Frankie S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5OcpWqNC1VInlP8DGBV3wtEyHPk.jpg'),
(63581, 4321, 'Grace and Frankie S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fMKtbgieOeZhqZO3OKeARlMFYAr.jpg'),
(63582, 4321, 'Grace and Frankie S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ESl8uLX4TKksZO3bdqyk35nMVx.jpg'),
(63583, 4321, 'Grace and Frankie S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u7Q9djlnctmEnPfgV1GZmdfuJI1.jpg'),
(63584, 4321, 'Grace and Frankie S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5OtBZ8hEOSqn2acH5SiCipqNASN.jpg'),
(63585, 4321, 'Grace and Frankie S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/exbX70pp9uCpR2nFh6POIPwXzly.jpg'),
(63586, 4321, 'Grace and Frankie S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/207520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c28kj1Wlw62atF4js8t6xsFvFlq.jpg'),
(63587, 4321, 'Grace and Frankie S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/207521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dBusawUgVe42fX8SVLkHpYcriN7.jpg'),
(63588, 4321, 'Grace and Frankie S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/207522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lAZcRrWOSgSwVF5QNPpYcpL02jk.jpg'),
(63589, 4322, 'Heels S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159924.mp4', 'http://timg.bdta.pro/images/cddf48ca40f3919d092a82a6c3c54265.jpg'),
(63590, 4322, 'Heels S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159925.mp4', 'http://timg.bdta.pro/images/be751c8ceca45d56570ac64fa899cd25.jpg'),
(63591, 4322, 'Heels S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159926.mp4', 'http://timg.bdta.pro/images/3b649e1447c8525607f6bfdc819617d1.jpg'),
(63592, 4322, 'Heels S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159927.mp4', 'http://timg.bdta.pro/images/2c49016c9acb841ed8ac8d352741111c.jpg'),
(63593, 4322, 'Heels S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159928.mp4', 'http://timg.bdta.pro/images/8f5ba99e0adf72f109afcfe448d513f6.jpg'),
(63594, 4322, 'Heels S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159929.mp4', 'http://image.tmdb.org/t/p/w1280/36EBtROXPFr9glguNUO4fdaNzN5.jpg'),
(63595, 4322, 'Heels S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159930.mp4', 'http://image.tmdb.org/t/p/w1280/47AdV0GnirJOMAfpCeaiItLLCtt.jpg'),
(63596, 4322, 'Heels S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159931.mp4', 'http://image.tmdb.org/t/p/w1280/3wpsaI394R4ILpbLS7jAjcAfX5W.jpg'),
(63597, 4323, 'Heels S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/292536.mp4', 'http://gstaticontent.com/images/bf5c81dc49fc4ca2895cb0444ef1f19c.jpg'),
(63598, 4323, 'Heels S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/292537.mp4', 'http://gstaticontent.com/images/bf5c81dc49fc4ca2895cb0444ef1f19c.jpg'),
(63599, 4323, 'Heels S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/292538.mp4', 'http://gstaticontent.com/images/bf5c81dc49fc4ca2895cb0444ef1f19c.jpg'),
(63600, 4323, 'Heels S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/292539.mp4', 'http://gstaticontent.com/images/bf5c81dc49fc4ca2895cb0444ef1f19c.jpg'),
(63601, 4323, 'Heels S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/292540.mp4', 'http://gstaticontent.com/images/bf5c81dc49fc4ca2895cb0444ef1f19c.jpg'),
(63602, 4323, 'Heels S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/292541.mp4', 'http://gstaticontent.com/images/bf5c81dc49fc4ca2895cb0444ef1f19c.jpg'),
(63603, 4323, 'Heels S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/292542.mp4', 'http://gstaticontent.com/images/bf5c81dc49fc4ca2895cb0444ef1f19c.jpg'),
(63604, 4323, 'Heels S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/292543.mp4', 'http://gstaticontent.com/images/bf5c81dc49fc4ca2895cb0444ef1f19c.jpg'),
(63605, 4324, 'Jojo Nove e Meia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198906.mp4', 'http://timg.bdta.pro/images/6a24434947694fe5edc4b314e147d89f.jpg'),
(63606, 4324, 'Jojo Nove e Meia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198907.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63607, 4324, 'Jojo Nove e Meia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198908.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63608, 4324, 'Jojo Nove e Meia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198909.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63609, 4324, 'Jojo Nove e Meia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198910.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63610, 4324, 'Jojo Nove e Meia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198911.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63611, 4324, 'Jojo Nove e Meia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198912.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63612, 4324, 'Jojo Nove e Meia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198913.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63613, 4325, 'Jojo Nove e Meia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198914.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63614, 4325, 'Jojo Nove e Meia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198915.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63615, 4325, 'Jojo Nove e Meia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198916.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63616, 4325, 'Jojo Nove e Meia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198917.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63617, 4325, 'Jojo Nove e Meia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198918.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63618, 4325, 'Jojo Nove e Meia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198919.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63619, 4325, 'Jojo Nove e Meia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198920.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63620, 4325, 'Jojo Nove e Meia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198921.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63621, 4325, 'Jojo Nove e Meia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198922.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63622, 4325, 'Jojo Nove e Meia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198923.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63623, 4325, 'Jojo Nove e Meia S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/198924.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63624, 4325, 'Jojo Nove e Meia S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/198925.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63625, 4325, 'Jojo Nove e Meia S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/198926.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63626, 4325, 'Jojo Nove e Meia S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/198927.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63627, 4325, 'Jojo Nove e Meia S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/198928.mp4', 'http://gstaticontent.com/images/225b65f5636e8c9d1c55eff05b480e7b.jpg'),
(63628, 4326, 'Leverage: Redemption [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159053.mp4', 'http://timg.bdta.pro/images/3b21b53da224278d7caa4d689cbaea11.jpg'),
(63629, 4326, 'Leverage: Redemption [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159054.mp4', 'http://timg.bdta.pro/images/fbf7003db6bc4743a7662210f1941b74.jpg'),
(63630, 4326, 'Leverage: Redemption [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159055.mp4', 'http://timg.bdta.pro/images/5d1df24a865889553777ca4ad4019d1e.jpg'),
(63631, 4326, 'Leverage: Redemption [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159056.mp4', 'http://timg.bdta.pro/images/a8222e17b1184c30ae13ac9cb346f2d5.jpg'),
(63632, 4326, 'Leverage: Redemption [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159057.mp4', 'http://timg.bdta.pro/images/f1326e5a9d0cb8784ea4e894a58e1afb.jpg'),
(63633, 4326, 'Leverage: Redemption [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159058.mp4', 'http://timg.bdta.pro/images/8f16396c87b3a07addcfd813e26b5070.jpg'),
(63634, 4326, 'Leverage: Redemption [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159059.mp4', 'http://timg.bdta.pro/images/4bc2d844c403f7f1335fd8da897ec5f9.jpg'),
(63635, 4326, 'Leverage: Redemption [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159060.mp4', 'http://timg.bdta.pro/images/4ac74f0f0793bfdb489ba635211fa8a3.jpg'),
(63636, 4327, 'Linha de Combate S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203087.mp4', 'http://timg.bdta.pro/images/68a8312f94bb174ba4c76b6dcf1312f4.jpg'),
(63637, 4327, 'Linha de Combate S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203088.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63638, 4327, 'Linha de Combate S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203089.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63639, 4327, 'Linha de Combate S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203090.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63640, 4327, 'Linha de Combate S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203091.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63641, 4327, 'Linha de Combate S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203092.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63642, 4327, 'Linha de Combate S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203093.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63643, 4327, 'Linha de Combate S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203094.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63644, 4327, 'Linha de Combate S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203095.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63645, 4327, 'Linha de Combate S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203096.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63646, 4327, 'Linha de Combate S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203097.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63647, 4327, 'Linha de Combate S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203098.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63648, 4327, 'Linha de Combate S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203099.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63649, 4327, 'Linha de Combate S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/203100.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63650, 4327, 'Linha de Combate S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/203101.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63651, 4327, 'Linha de Combate S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/203102.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63652, 4327, 'Linha de Combate S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/203103.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63653, 4327, 'Linha de Combate S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/203104.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63654, 4327, 'Linha de Combate S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/203105.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63655, 4327, 'Linha de Combate S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/203106.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63656, 4328, 'Linha de Combate S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203107.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63657, 4328, 'Linha de Combate S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203108.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63658, 4328, 'Linha de Combate S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203109.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63659, 4328, 'Linha de Combate S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203110.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63660, 4328, 'Linha de Combate S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203111.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63661, 4328, 'Linha de Combate S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203112.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63662, 4328, 'Linha de Combate S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203113.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63663, 4328, 'Linha de Combate S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203114.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63664, 4328, 'Linha de Combate S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203115.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63665, 4328, 'Linha de Combate S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203116.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63666, 4328, 'Linha de Combate S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203117.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63667, 4328, 'Linha de Combate S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203118.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63668, 4328, 'Linha de Combate S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203119.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63669, 4328, 'Linha de Combate S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/203120.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63670, 4328, 'Linha de Combate S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/203121.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63671, 4328, 'Linha de Combate S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/203122.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63672, 4328, 'Linha de Combate S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/203123.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63673, 4328, 'Linha de Combate S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/203124.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63674, 4328, 'Linha de Combate S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/203125.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63675, 4328, 'Linha de Combate S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/203126.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63676, 4328, 'Linha de Combate S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/203127.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63677, 4328, 'Linha de Combate S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/203128.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63678, 4328, 'Linha de Combate S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/203129.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63679, 4328, 'Linha de Combate S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/203130.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(63680, 4328, 'Linha de Combate S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/203131.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63681, 4328, 'Linha de Combate S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/203132.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63682, 4328, 'Linha de Combate S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/203133.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63683, 4328, 'Linha de Combate S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/203134.mp4', 'http://gstaticontent.com/images/cc54779751bb75572ba530d0b1f0cdfe.jpg'),
(63684, 4329, 'Love in the Time of Corona S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149212.mp4', 'http://timg.bdta.pro/images/16689b8764b78af0aec7151a9d94fc2e.jpg'),
(63685, 4329, 'Love in the Time of Corona S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149213.mp4', 'http://timg.bdta.pro/images/9ee444900aae904900e782727558d655.jpg'),
(63686, 4329, 'Love in the Time of Corona S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149214.mp4', 'http://timg.bdta.pro/images/9137e0c216d96b2bc49fedc90ee89f5d.jpg'),
(63687, 4329, 'Love in the Time of Corona S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149215.mp4', 'http://timg.bdta.pro/images/3769842246ef1a526e632c34190f33e9.jpg'),
(63688, 4330, 'Sneakerheads S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/149206.mp4', 'http://timg.bdta.pro/images/f5e9f125495cfe63118d8716952919ba.jpg'),
(63689, 4330, 'Sneakerheads S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/149207.mp4', 'http://timg.bdta.pro/images/b4a4989939f51307f1b2d1ee32339bd5.jpg'),
(63690, 4330, 'Sneakerheads S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/149208.mp4', 'http://timg.bdta.pro/images/4900067160e3e091a53eb4f10f466bec.jpg'),
(63691, 4330, 'Sneakerheads S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/149209.mp4', 'http://timg.bdta.pro/images/7477b4ac52b1b1d2370ff48417689e18.jpg'),
(63692, 4330, 'Sneakerheads S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/149210.mp4', 'http://timg.bdta.pro/images/6074b920e06757ef4995b4246bc1d017.jpg'),
(63693, 4330, 'Sneakerheads S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/149211.mp4', 'http://timg.bdta.pro/images/f2ccb0e2d739c65202d613908e3136e0.jpg'),
(63694, 4331, 'Tarcisio e Gloria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159104.mp4', 'http://gstaticontent.com/images/194ca91d5fd5fbc4f1803b849e9aaa21.png'),
(63695, 4331, 'Tarcisio e Gloria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159105.mp4', 'http://gstaticontent.com/images/194ca91d5fd5fbc4f1803b849e9aaa21.png'),
(63696, 4331, 'Tarcisio e Gloria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159106.mp4', 'http://gstaticontent.com/images/194ca91d5fd5fbc4f1803b849e9aaa21.png'),
(63697, 4331, 'Tarcisio e Gloria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159107.mp4', 'http://gstaticontent.com/images/194ca91d5fd5fbc4f1803b849e9aaa21.png'),
(63698, 4331, 'Tarcisio e Gloria S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159108.mp4', 'http://gstaticontent.com/images/194ca91d5fd5fbc4f1803b849e9aaa21.png'),
(63699, 4331, 'Tarcisio e Gloria S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159109.mp4', 'http://gstaticontent.com/images/194ca91d5fd5fbc4f1803b849e9aaa21.png'),
(63700, 4331, 'Tarcisio e Gloria S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159110.mp4', 'http://gstaticontent.com/images/194ca91d5fd5fbc4f1803b849e9aaa21.png'),
(63701, 4331, 'Tarcisio e Gloria S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159111.mp4', 'http://gstaticontent.com/images/194ca91d5fd5fbc4f1803b849e9aaa21.png'),
(63702, 4331, 'Tarcisio e Gloria S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159112.mp4', 'http://gstaticontent.com/images/194ca91d5fd5fbc4f1803b849e9aaa21.png'),
(63703, 4331, 'Tarcisio e Gloria S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159113.mp4', 'http://gstaticontent.com/images/194ca91d5fd5fbc4f1803b849e9aaa21.png'),
(63704, 4331, 'Tarcisio e Gloria S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159114.mp4', 'http://gstaticontent.com/images/194ca91d5fd5fbc4f1803b849e9aaa21.png'),
(63705, 4331, 'Tarcisio e Gloria S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159115.mp4', 'http://gstaticontent.com/images/194ca91d5fd5fbc4f1803b849e9aaa21.png'),
(63706, 4331, 'Tarcisio e Gloria S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159116.mp4', 'http://gstaticontent.com/images/194ca91d5fd5fbc4f1803b849e9aaa21.png'),
(63707, 4332, 'Ugly Americans [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159073.mp4', 'http://timg.bdta.pro/images/917a375760ce532820dc928936946c79.jpg'),
(63708, 4332, 'Ugly Americans [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159074.mp4', 'http://timg.bdta.pro/images/a0068d2a7a6a8b3a047381b950159868.jpg'),
(63709, 4332, 'Ugly Americans [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159075.mp4', 'http://timg.bdta.pro/images/b0fc7c881dac9e9a09c010f15df3a495.jpg'),
(63710, 4332, 'Ugly Americans [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159076.mp4', 'http://timg.bdta.pro/images/aa6c66ee9b3d9be964fe6d46a896e496.jpg'),
(63711, 4332, 'Ugly Americans [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159077.mp4', 'http://timg.bdta.pro/images/f2590d2db0ea8dadef72ce955d19d327.jpg'),
(63712, 4332, 'Ugly Americans [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159078.mp4', 'http://timg.bdta.pro/images/a7ecdb7df1e74a1d6413e179e12dfe31.jpg'),
(63713, 4332, 'Ugly Americans [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159079.mp4', 'http://timg.bdta.pro/images/ac0fb4da718827a519670c12dc70f500.jpg'),
(63714, 4332, 'Ugly Americans [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159080.mp4', 'http://timg.bdta.pro/images/2357963359e93b529d2065017f55dca7.jpg'),
(63715, 4332, 'Ugly Americans [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159081.mp4', 'http://timg.bdta.pro/images/4769283bc51f12839ba7f8741c6b3f40.jpg'),
(63716, 4332, 'Ugly Americans [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159082.mp4', 'http://timg.bdta.pro/images/53987e24f9a5690c4153212916a0783b.jpg'),
(63717, 4332, 'Ugly Americans [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159083.mp4', 'http://timg.bdta.pro/images/ad3f1f3128b3463228a715ea28e7b95d.jpg'),
(63718, 4332, 'Ugly Americans [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159084.mp4', 'http://timg.bdta.pro/images/8f31e75f33ed258ba464991ccb7a0843.jpg'),
(63719, 4332, 'Ugly Americans [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159085.mp4', 'http://timg.bdta.pro/images/f212642746cd93165198d7edf5e15c18.jpg'),
(63720, 4332, 'Ugly Americans [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/159086.mp4', 'http://timg.bdta.pro/images/9cff5d2d63e5ebbee6f90db50ed3ee4d.jpg'),
(63721, 4333, 'Ugly Americans [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159087.mp4', 'http://timg.bdta.pro/images/1305162e0a81e4220785bd4f28e851dc.jpg'),
(63722, 4333, 'Ugly Americans [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159088.mp4', 'http://timg.bdta.pro/images/cba4a204619b344d963bea20b328238f.jpg'),
(63723, 4333, 'Ugly Americans [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159089.mp4', 'http://timg.bdta.pro/images/0eded523dbb3ab22b6da1958f0b9b147.jpg'),
(63724, 4333, 'Ugly Americans [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159090.mp4', 'http://timg.bdta.pro/images/8a92dcaa28a5c143770aa12b05c19735.jpg'),
(63725, 4333, 'Ugly Americans [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159091.mp4', 'http://timg.bdta.pro/images/bb09f17de0ae72fc1cb0b9113768df32.jpg'),
(63726, 4333, 'Ugly Americans [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159092.mp4', 'http://timg.bdta.pro/images/12c6354a4288531e31e4388ff302adad.jpg'),
(63727, 4333, 'Ugly Americans [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159093.mp4', 'http://timg.bdta.pro/images/fdb5fe4d8ccc376f79a69840d47f4e35.jpg'),
(63728, 4333, 'Ugly Americans [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159094.mp4', 'http://timg.bdta.pro/images/1390436d2b3d17325824819ad9398e51.jpg'),
(63729, 4333, 'Ugly Americans [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159095.mp4', 'http://timg.bdta.pro/images/c25237cc9b625879e47372a389767283.jpg'),
(63730, 4333, 'Ugly Americans [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159096.mp4', 'http://timg.bdta.pro/images/6c9cfa5eed587616c4e814bb63e5e22e.jpg'),
(63731, 4333, 'Ugly Americans [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159097.mp4', 'http://timg.bdta.pro/images/9cf13fa9305c4ce5b0fadec168695409.jpg'),
(63732, 4333, 'Ugly Americans [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159098.mp4', 'http://timg.bdta.pro/images/a2c6e58c7921771ba45c38a7a6cb3aac.jpg'),
(63733, 4333, 'Ugly Americans [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159099.mp4', 'http://timg.bdta.pro/images/96b4fd453862d433baf061743378852b.jpg'),
(63734, 4333, 'Ugly Americans [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/159100.mp4', 'http://timg.bdta.pro/images/e5948cdc5a781efedb6e3fbf7e5e5b3f.jpg'),
(63735, 4333, 'Ugly Americans [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/159101.mp4', 'http://timg.bdta.pro/images/aa2a2721d0c59a023977e994eedc7c12.jpg'),
(63736, 4333, 'Ugly Americans [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/159102.mp4', 'http://timg.bdta.pro/images/df3fa17a2a93160829f984d07f34148a.jpg'),
(63737, 4333, 'Ugly Americans [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/159103.mp4', 'http://timg.bdta.pro/images/c96c31eb95658e2b93b95a9201515bd6.jpg'),
(63738, 4334, 'Veneno S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159045.mp4', 'http://timg.bdta.pro/images/b7ac53075fbbb376a8efdc6053ee868a.jpg'),
(63739, 4334, 'Veneno S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159046.mp4', 'http://timg.bdta.pro/images/50fb52a76a3e0eef614b9bb64712cfb3.jpg'),
(63740, 4334, 'Veneno S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159047.mp4', 'http://timg.bdta.pro/images/dc74824cea60d5c0f126efdfa97ae86a.jpg'),
(63741, 4334, 'Veneno S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159048.mp4', 'http://timg.bdta.pro/images/9bdffed0e112911f99755cb8a87448ce.jpg'),
(63742, 4334, 'Veneno S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159049.mp4', 'http://timg.bdta.pro/images/02d52d4a4f20e3dbb6bd5df717ec0dae.jpg'),
(63743, 4334, 'Veneno S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159050.mp4', 'http://timg.bdta.pro/images/91fdb8e02724df64395dce9c8edc90ed.jpg'),
(63744, 4334, 'Veneno S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159051.mp4', 'http://timg.bdta.pro/images/878654067d0b326e234ee28c53a4e639.jpg'),
(63745, 4334, 'Veneno S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159052.mp4', 'http://timg.bdta.pro/images/176939938a4b2749b8668261c01c56a4.jpg'),
(63746, 4335, 'A Amiga Genial S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/158989.mp4', 'http://timg.bdta.pro/images/0ba2beeac0050c4b9c4aa33994c124ba.jpg'),
(63747, 4335, 'A Amiga Genial S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/158990.mp4', 'http://timg.bdta.pro/images/f7afe0b34c3ec3c7a5beaafb54935a13.jpg'),
(63748, 4335, 'A Amiga Genial S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/158991.mp4', 'http://timg.bdta.pro/images/2d9fc75716b83de32d1d63d14f5d561b.jpg'),
(63749, 4335, 'A Amiga Genial S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/158992.mp4', 'http://timg.bdta.pro/images/9f6d4e0a97637a806f3fe51ec1e5624a.jpg'),
(63750, 4335, 'A Amiga Genial S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/158993.mp4', 'http://timg.bdta.pro/images/d0fad38a00ffade0230a89060e7ada82.jpg'),
(63751, 4335, 'A Amiga Genial S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/158994.mp4', 'http://timg.bdta.pro/images/d4b775f04861d9db3cc0079068bd2dd9.jpg'),
(63752, 4335, 'A Amiga Genial S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/158995.mp4', 'http://timg.bdta.pro/images/05118bbd0d40198912599a92df85007c.jpg'),
(63753, 4335, 'A Amiga Genial S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/158996.mp4', 'http://timg.bdta.pro/images/e0426ea96377f824b891440dd82b8672.jpg'),
(63754, 4336, 'A Amiga Genial S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/158997.mp4', 'http://timg.bdta.pro/images/25774c404bb4872d38b2023497a17859.jpg'),
(63755, 4336, 'A Amiga Genial S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/158998.mp4', 'http://timg.bdta.pro/images/d8c4b0ac4f80e54e509542ee302589df.jpg'),
(63756, 4336, 'A Amiga Genial S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/158999.mp4', 'http://timg.bdta.pro/images/58becac05aaac1b6998b0e3d96186b33.jpg'),
(63757, 4336, 'A Amiga Genial S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159000.mp4', 'http://timg.bdta.pro/images/64e26ebe2edb3bc431f54fdbc2eca456.jpg'),
(63758, 4336, 'A Amiga Genial S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159001.mp4', 'http://timg.bdta.pro/images/234fb429ffb387350354651ad6524d43.jpg'),
(63759, 4336, 'A Amiga Genial S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159002.mp4', 'http://timg.bdta.pro/images/3326391a831a63b80b8b08931d8128f1.jpg'),
(63760, 4336, 'A Amiga Genial S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159003.mp4', 'http://timg.bdta.pro/images/ca5e544d8d37659964779fbe2180380c.jpg'),
(63761, 4336, 'A Amiga Genial S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159004.mp4', 'http://timg.bdta.pro/images/4add0d92e1cf50df3ddf1553be2c6b9d.jpg'),
(63762, 4337, 'Nove Desconhecidos [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161708.mp4', 'http://timg.bdta.pro/images/425f12abe6bce79c9abac0b0c0b85aaf.jpg'),
(63763, 4337, 'Nove Desconhecidos [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161709.mp4', 'http://timg.bdta.pro/images/7665588efe496cc33bd00c7135a4b679.jpg'),
(63764, 4337, 'Nove Desconhecidos [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161710.mp4', 'http://timg.bdta.pro/images/678ab6a2c8578f4094dee32c67f7048f.jpg'),
(63765, 4337, 'Nove Desconhecidos [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161711.mp4', 'http://timg.bdta.pro/images/db14cb60f6862b846d39867507e60142.jpg'),
(63766, 4337, 'Nove Desconhecidos [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161712.mp4', 'http://timg.bdta.pro/images/813cf17ca1239897b03a34ae443d974b.jpg'),
(63767, 4337, 'Nove Desconhecidos [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161713.mp4', 'http://timg.bdta.pro/images/01df43ec90abe0312950481c797fe2e2.jpg'),
(63768, 4337, 'Nove Desconhecidos [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161714.mp4', 'http://timg.bdta.pro/images/f8321c0e0c1bfccd7f95fe96b28c432f.jpg'),
(63769, 4337, 'Nove Desconhecidos [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161715.mp4', 'http://image.tmdb.org/t/p/w1280/lpqX3SN1GXy8iBbwxvHfl6ihtPR.jpg'),
(63770, 4338, 'O Mundo dos Animais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/158983.mp4', 'http://timg.bdta.pro/images/b0975f1adb5741516974ae167f1f3974.jpg'),
(63771, 4338, 'O Mundo dos Animais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/158984.mp4', 'http://timg.bdta.pro/images/e9bde58035902b46c85dbb45d4610168.jpg'),
(63772, 4338, 'O Mundo dos Animais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/158985.mp4', 'http://timg.bdta.pro/images/210f759b0200b87c6156de8b80503279.jpg'),
(63773, 4338, 'O Mundo dos Animais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/158986.mp4', 'http://timg.bdta.pro/images/448cf0722f04cb1a27b786c07dc10053.jpg'),
(63774, 4338, 'O Mundo dos Animais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/158987.mp4', 'http://timg.bdta.pro/images/2d6eba8a6c95405d7a8b4e16a7f8dbfc.jpg'),
(63775, 4338, 'O Mundo dos Animais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/158988.mp4', 'http://timg.bdta.pro/images/23c44fff75c21c86bc6100da0402dc94.jpg'),
(63776, 4339, 'O Tempo e o Vento S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/158957.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63777, 4339, 'O Tempo e o Vento S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/158958.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63778, 4339, 'O Tempo e o Vento S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/158959.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63779, 4339, 'O Tempo e o Vento S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/158960.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63780, 4339, 'O Tempo e o Vento S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/158961.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63781, 4339, 'O Tempo e o Vento S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/158962.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63782, 4339, 'O Tempo e o Vento S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/158963.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63783, 4339, 'O Tempo e o Vento S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/158964.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63784, 4339, 'O Tempo e o Vento S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/158965.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63785, 4339, 'O Tempo e o Vento S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/158966.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63786, 4339, 'O Tempo e o Vento S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/158967.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63787, 4339, 'O Tempo e o Vento S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/158968.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63788, 4339, 'O Tempo e o Vento S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/158969.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63789, 4339, 'O Tempo e o Vento S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/158970.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63790, 4339, 'O Tempo e o Vento S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/158971.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63791, 4339, 'O Tempo e o Vento S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/158972.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63792, 4339, 'O Tempo e o Vento S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/158973.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63793, 4339, 'O Tempo e o Vento S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/158974.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63794, 4339, 'O Tempo e o Vento S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/158975.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63795, 4339, 'O Tempo e o Vento S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/158976.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63796, 4339, 'O Tempo e o Vento S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/158977.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63797, 4339, 'O Tempo e o Vento S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/158978.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63798, 4339, 'O Tempo e o Vento S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/158979.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63799, 4339, 'O Tempo e o Vento S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/158980.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63800, 4339, 'O Tempo e o Vento S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/158981.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63801, 4339, 'O Tempo e o Vento S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/158982.mp4', 'http://gstaticontent.com/images/ccc40c27bc81e6f49894c4cbdaabaa8b.jpg'),
(63802, 4340, 'Sombras da Guerra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/158949.mp4', 'http://timg.bdta.pro/images/900a8b33fcb9bd3edee70299fa4237f0.jpg'),
(63803, 4340, 'Sombras da Guerra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/158950.mp4', 'http://timg.bdta.pro/images/cb71209d970ebeed3ffd88a11d1f80e0.jpg'),
(63804, 4340, 'Sombras da Guerra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/158951.mp4', 'http://timg.bdta.pro/images/907e7f6bfb81926810ef51cd8a3f715a.jpg'),
(63805, 4340, 'Sombras da Guerra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/158952.mp4', 'http://timg.bdta.pro/images/5a41a8e40f2f5c0f923cf8f5ac4be085.jpg'),
(63806, 4340, 'Sombras da Guerra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/158953.mp4', 'http://timg.bdta.pro/images/0576f679acd924b8466c46da0a0db90e.jpg'),
(63807, 4340, 'Sombras da Guerra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/158954.mp4', 'http://timg.bdta.pro/images/04a819f91c88522cd3828c83bf7498b9.jpg'),
(63808, 4340, 'Sombras da Guerra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/158955.mp4', 'http://timg.bdta.pro/images/7908b749bc86ebb95722c0c17b92ea27.jpg'),
(63809, 4340, 'Sombras da Guerra S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/158956.mp4', 'http://timg.bdta.pro/images/76f11bbb5a6ca813dc1093c6354a7576.jpg'),
(63810, 4341, 'A Cadeira S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/158943.mp4', 'http://timg.bdta.pro/images/40f6d0c956761ac394335a779a95b0b3.jpg'),
(63811, 4341, 'A Cadeira S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/158944.mp4', 'http://timg.bdta.pro/images/ad461513ba083004563c657edcfbf720.jpg'),
(63812, 4341, 'A Cadeira S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/158945.mp4', 'http://timg.bdta.pro/images/2f0f9c862e39f407b71a0a4df231f111.jpg'),
(63813, 4341, 'A Cadeira S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/158946.mp4', 'http://timg.bdta.pro/images/6e7b5d884a45a4f7baf21bdbc05def77.jpg'),
(63814, 4341, 'A Cadeira S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/158947.mp4', 'http://timg.bdta.pro/images/781efd6952b3386a70ac6bf647e0bed0.jpg'),
(63815, 4341, 'A Cadeira S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/158948.mp4', 'http://timg.bdta.pro/images/2f146b066af58f3c05dc1049436b842e.jpg'),
(63816, 4342, 'A Saída S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157813.mp4', 'http://timg.bdta.pro/images/33fa11f9cf48d8b96bc2d642874cf116.jpg'),
(63817, 4342, 'A Saída S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157814.mp4', 'http://timg.bdta.pro/images/5dd964038c151e1c9da866b4097e1d8c.jpg'),
(63818, 4342, 'A Saída S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157815.mp4', 'http://timg.bdta.pro/images/088ad3c4a271499ab253d493c583f4f2.jpg'),
(63819, 4342, 'A Saída S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157816.mp4', 'http://timg.bdta.pro/images/022d21ef0b6c84288274dc011e2d528b.jpg'),
(63820, 4342, 'A Saída S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/157817.mp4', 'http://timg.bdta.pro/images/c24618f36fd35d24e20f970bef18d1cf.jpg'),
(63821, 4342, 'A Saída S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/157818.mp4', 'http://timg.bdta.pro/images/76123d446aef57e61b119b553cf40d79.jpg'),
(63822, 4343, 'American Horror Stories [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157806.mp4', 'http://timg.bdta.pro/images/5906ac63efe03f7a2e77ed43be26f954.jpg'),
(63823, 4343, 'American Horror Stories [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157807.mp4', 'http://timg.bdta.pro/images/1f1395609f7bed7c7eda405eb7ca9003.jpg'),
(63824, 4343, 'American Horror Stories [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157808.mp4', 'http://timg.bdta.pro/images/f5a011c083e40c883b13b8dd1ea09cf3.jpg'),
(63825, 4343, 'American Horror Stories [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157809.mp4', 'http://timg.bdta.pro/images/07962cf04be6b1dfc549e3c5d81e58bf.jpg'),
(63826, 4343, 'American Horror Stories [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/157810.mp4', 'http://timg.bdta.pro/images/a72c6fd7147d6abbf126163378782f7f.jpg'),
(63827, 4343, 'American Horror Stories [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/157811.mp4', 'http://timg.bdta.pro/images/948f045244c9c207ff3ee2349562c232.jpg'),
(63828, 4343, 'American Horror Stories [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/157812.mp4', 'http://timg.bdta.pro/images/7b0f666e2d5450c3d9d5f067e6377fba.jpg'),
(63829, 4344, 'Call Me Kat S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204271.mp4', 'http://timg.bdta.pro/images/8cd5ad5b73e8b4bbe2ac8de03e9217a7.jpg'),
(63830, 4344, 'Call Me Kat S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204272.mp4', 'http://timg.bdta.pro/images/4e170b0080e63e75d4a40f23d29938b7.jpg'),
(63831, 4344, 'Call Me Kat S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204273.mp4', 'http://timg.bdta.pro/images/b73f74c72c6359533b73ecc421398d42.jpg'),
(63832, 4344, 'Call Me Kat S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204274.mp4', 'http://timg.bdta.pro/images/23f16a5a059dc4935f85a021835095b0.jpg'),
(63833, 4344, 'Call Me Kat S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204275.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(63834, 4344, 'Call Me Kat S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204276.mp4', 'http://timg.bdta.pro/images/a1c305ee13f54c6f6310c5952affb520.jpg'),
(63835, 4344, 'Call Me Kat S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204277.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(63836, 4344, 'Call Me Kat S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204278.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(63837, 4344, 'Call Me Kat S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204279.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(63838, 4344, 'Call Me Kat S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204280.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(63839, 4344, 'Call Me Kat S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204281.mp4', 'http://timg.bdta.pro/images/4ca0777c0da41425e014c834efd114dc.jpg'),
(63840, 4344, 'Call Me Kat S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204282.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(63841, 4344, 'Call Me Kat S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204283.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(63842, 4345, 'Call Me Kat S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204284.mp4', 'http://timg.bdta.pro/images/dd2edbced48ac1175d2b605573d51d1f.jpg'),
(63843, 4345, 'Call Me Kat S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204285.mp4', 'http://timg.bdta.pro/images/84cf587891955261ebdb6e05ee3c4bd2.jpg'),
(63844, 4345, 'Call Me Kat S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204286.mp4', 'http://timg.bdta.pro/images/ec4de23959dfc2b1f30985086979c21c.jpg'),
(63845, 4345, 'Call Me Kat S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204287.mp4', 'http://timg.bdta.pro/images/774eae8a35b4cdf20e3b090399316bc4.jpg'),
(63846, 4345, 'Call Me Kat S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204288.mp4', 'http://timg.bdta.pro/images/1ef899ef2f1d92736ec4959b160f372a.jpg'),
(63847, 4345, 'Call Me Kat S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204289.mp4', 'http://timg.bdta.pro/images/4595ca028b77c29b54d40878240a3ba2.jpg'),
(63848, 4345, 'Call Me Kat S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204290.mp4', 'http://timg.bdta.pro/images/34d19992d73b995c1aed1fa32450def6.jpg'),
(63849, 4345, 'Call Me Kat S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204291.mp4', 'http://timg.bdta.pro/images/6d476c1343e87b4e55537d5417fc50c8.jpg'),
(63850, 4345, 'Call Me Kat S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204292.mp4', 'http://timg.bdta.pro/images/0dd2d85a52ec49d506a1a90698e47c00.jpg'),
(63851, 4345, 'Call Me Kat S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204293.mp4', 'http://timg.bdta.pro/images/61fb208ec59751cf20a551b2c8d50667.jpg'),
(63852, 4345, 'Call Me Kat S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204294.mp4', 'http://timg.bdta.pro/images/97866decc4fa78f9bed5ad7ce6aa1963.jpg'),
(63853, 4345, 'Call Me Kat S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204295.mp4', 'http://timg.bdta.pro/images/77970b7ba1326d8f26779319cbf10672.jpg'),
(63854, 4345, 'Call Me Kat S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204296.mp4', 'http://timg.bdta.pro/images/e34d022e8537ed9943cae8d963d0cfc7.jpg'),
(63855, 4345, 'Call Me Kat S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/204297.mp4', 'http://timg.bdta.pro/images/df0f18b2b3947827d80efb38096d7df9.jpg'),
(63856, 4345, 'Call Me Kat S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/204298.mp4', 'http://timg.bdta.pro/images/7ed3c849b6064a8ab354283c5d4f7558.jpg'),
(63857, 4345, 'Call Me Kat S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/204299.mp4', 'http://timg.bdta.pro/images/8be079a738e030723b223ab7958b153b.jpg'),
(63858, 4345, 'Call Me Kat S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/204300.mp4', 'http://timg.bdta.pro/images/525310bcd8b90217ebd88156a740e4c4.jpg'),
(63859, 4345, 'Call Me Kat S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/204301.mp4', 'http://timg.bdta.pro/images/1192a1cbe339eba28c7e5f7cf095ae72.jpg'),
(63860, 4346, 'Call Me Kat S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h6vwdtlfNtwD5pFdjis0TVtnP23.jpg'),
(63861, 4346, 'Call Me Kat S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24YMcrNUBpaofnuuBlK5zLHa7ZL.jpg'),
(63862, 4346, 'Call Me Kat S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6WZlL2wfVt49dX491KGJ2vWIz14.jpg'),
(63863, 4346, 'Call Me Kat S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sc266gK6fso6ILjB6gFWBe9QuAX.jpg'),
(63864, 4346, 'Call Me Kat S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUDQjfyR92CTgYo7WaB9BgIQfKH.jpg'),
(63865, 4346, 'Call Me Kat S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204307.mp4', 'http://image.tmdb.org/t/p/w1280/eYu8eF9opbAA4PYVYl8dzg2bQW1.jpg'),
(63866, 4346, 'Call Me Kat S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rAY4vWstmOr01u09e0VVsWfCkID.jpg'),
(63867, 4346, 'Call Me Kat S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aSRCRhOgxvIBBGBpJcOfD9SiI5b.jpg'),
(63868, 4346, 'Call Me Kat S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1JkBu1XrIXftRQPSjWJVGMkJnnI.jpg'),
(63869, 4346, 'Call Me Kat S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204311.mp4', 'http://image.tmdb.org/t/p/w1280/xGTgrG2chAxHCOvZCsbOo94YDAs.jpg'),
(63870, 4346, 'Call Me Kat S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204312.mp4', 'http://image.tmdb.org/t/p/w1280/rZQaZf6GvsFCDHaVohO7fAPwYsN.jpg'),
(63871, 4346, 'Call Me Kat S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267979.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(63872, 4346, 'Call Me Kat S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267980.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(63873, 4346, 'Call Me Kat S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267981.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(63874, 4346, 'Call Me Kat S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267982.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(63875, 4346, 'Call Me Kat S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267983.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(63876, 4346, 'Call Me Kat S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267984.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(63877, 4346, 'Call Me Kat S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267985.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(63878, 4346, 'Call Me Kat S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267986.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(63879, 4346, 'Call Me Kat S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267987.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(63880, 4346, 'Call Me Kat S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/267988.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(63881, 4346, 'Call Me Kat S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/267989.mp4', 'http://gstaticontent.com/images/5f700d37d92cee24a734411961ef6f95.jpg'),
(63882, 4347, 'Chapelwaite [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163383.mp4', 'http://timg.bdta.pro/images/6798a4bc5b62c1d61f8b8d90271edb39.jpg'),
(63883, 4347, 'Chapelwaite [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163384.mp4', 'http://timg.bdta.pro/images/0efa17e72ff7b94f010a125a4ddeaa1f.jpg'),
(63884, 4347, 'Chapelwaite [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163385.mp4', 'http://timg.bdta.pro/images/1eef2dee40b29f45be8efe3bec808738.jpg'),
(63885, 4347, 'Chapelwaite [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163386.mp4', 'http://timg.bdta.pro/images/0c7d5d994d72318307693c6589948bba.jpg'),
(63886, 4347, 'Chapelwaite [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163387.mp4', 'http://timg.bdta.pro/images/81086e3a60267ac981378f60f2c8ae43.jpg'),
(63887, 4347, 'Chapelwaite [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163388.mp4', 'http://image.tmdb.org/t/p/w1280/5xj1oWg80sU2PwUoa2kNg5LnpBL.jpg'),
(63888, 4347, 'Chapelwaite [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163389.mp4', 'http://image.tmdb.org/t/p/w1280/a2liGoYZFPnbp3OgfsPwBO4uGBv.jpg'),
(63889, 4347, 'Chapelwaite [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163390.mp4', 'http://image.tmdb.org/t/p/w1280/loxYdKBZyFAjIaSQypI0NGfaX0.jpg'),
(63890, 4347, 'Chapelwaite [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163391.mp4', 'http://image.tmdb.org/t/p/w1280/r1Cg5SiBrwnjIRT3UPUXgKhVP9W.jpg'),
(63891, 4347, 'Chapelwaite [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163392.mp4', 'http://image.tmdb.org/t/p/w1280/LWss4zSQ3AvVTXJntcNNvYLlq4.jpg'),
(63892, 4348, 'Clickbait S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157798.mp4', 'http://timg.bdta.pro/images/72611b48746a4f48df49598e9d495898.jpg'),
(63893, 4348, 'Clickbait S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157799.mp4', 'http://timg.bdta.pro/images/e0e204d616246bd8cce2a7b6e326f482.jpg'),
(63894, 4348, 'Clickbait S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157800.mp4', 'http://timg.bdta.pro/images/0d009338a8d496e12a08655676df45cb.jpg'),
(63895, 4348, 'Clickbait S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157801.mp4', 'http://timg.bdta.pro/images/75e1dbff05e29ae09cee77fa34ac2721.jpg'),
(63896, 4348, 'Clickbait S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/157802.mp4', 'http://timg.bdta.pro/images/83c85c1d03464a08f63a70baadfac970.jpg'),
(63897, 4348, 'Clickbait S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/157803.mp4', 'http://timg.bdta.pro/images/57773ae91221c7893e16c250920d7c3e.jpg'),
(63898, 4348, 'Clickbait S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/157804.mp4', 'http://timg.bdta.pro/images/03ad503d22d1fdc558cb21b66b4fafc5.jpg'),
(63899, 4348, 'Clickbait S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/157805.mp4', 'http://timg.bdta.pro/images/55dcdd18121602c54a508c000bc51c2d.jpg'),
(63900, 4349, 'Hora de Aventura: Terras Distantes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157795.mp4', 'http://timg.bdta.pro/images/22ba67172bca3e2e2277988ec87bd5a3.jpg'),
(63901, 4349, 'Hora de Aventura: Terras Distantes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157796.mp4', 'http://timg.bdta.pro/images/54493b6af1c6c6128a5823619feef1a3.jpg'),
(63902, 4349, 'Hora de Aventura: Terras Distantes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157797.mp4', 'http://timg.bdta.pro/images/54516c9cbfee4561c5b37772fffdbb9e.jpg'),
(63903, 4350, 'Hospital Playlist S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162024.mp4', 'http://timg.bdta.pro/images/c2e19758f994f547a333cae81a3d5ba0.jpg'),
(63904, 4350, 'Hospital Playlist S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162025.mp4', 'http://timg.bdta.pro/images/855ff389b846695e8034faf1b7380ec2.jpg'),
(63905, 4350, 'Hospital Playlist S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162026.mp4', 'http://timg.bdta.pro/images/c0240f663311f75863d524ba27de64cc.jpg'),
(63906, 4350, 'Hospital Playlist S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162027.mp4', 'http://timg.bdta.pro/images/023d113a639ba7089a8dd38becc9086d.jpg'),
(63907, 4350, 'Hospital Playlist S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162028.mp4', 'http://timg.bdta.pro/images/1429991615e067cac860ef2c782f59c5.jpg'),
(63908, 4350, 'Hospital Playlist S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162029.mp4', 'http://timg.bdta.pro/images/bbf17fef777d47c578df19b951cb9351.jpg'),
(63909, 4350, 'Hospital Playlist S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/162030.mp4', 'http://timg.bdta.pro/images/f94d80032a80ff6ae08bffc881440df2.jpg'),
(63910, 4350, 'Hospital Playlist S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/162031.mp4', 'http://timg.bdta.pro/images/6901e90553ae70c955508c3801ffa8d1.jpg'),
(63911, 4350, 'Hospital Playlist S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/162032.mp4', 'http://timg.bdta.pro/images/8588608eeb0e4fd4b5eb5511640735e4.jpg'),
(63912, 4350, 'Hospital Playlist S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/162033.mp4', 'http://timg.bdta.pro/images/6bba491ec657b519ecf3c95af010132a.jpg'),
(63913, 4350, 'Hospital Playlist S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/162034.mp4', 'http://timg.bdta.pro/images/866205386cc6ab9fa8d96c283dfec367.jpg'),
(63914, 4350, 'Hospital Playlist S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/162035.mp4', 'http://timg.bdta.pro/images/e18d5090b75d5f749d9420d39d343017.jpg'),
(63915, 4351, 'Hospital Playlist S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rhuIEUGbxTxxU3eNxQV08o0Q4Dn.jpg'),
(63916, 4351, 'Hospital Playlist S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/un4bH0xXO1NdwXOTC0K752t5U6w.jpg'),
(63917, 4351, 'Hospital Playlist S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ovcvnur9Of1QS8ITTzVwxce35c1.jpg'),
(63918, 4351, 'Hospital Playlist S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lfyjwjw4mm8Ww1RGTmIUqSocoCo.jpg'),
(63919, 4351, 'Hospital Playlist S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ySGBT8parh1Az2o9wZOgN68Tqi.jpg'),
(63920, 4351, 'Hospital Playlist S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x7f0RYeDL13byL8O6mG39teOojm.jpg'),
(63921, 4351, 'Hospital Playlist S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/162042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5GzSK8dq0JKGlfTVWGu70XJhx3.jpg'),
(63922, 4351, 'Hospital Playlist S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/162043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pgHQa91HbSE4m3vtG7nGdgjBJyE.jpg'),
(63923, 4351, 'Hospital Playlist S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/162044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h9HmfQ0TxuVzdWiZOaOMw671EaX.jpg'),
(63924, 4351, 'Hospital Playlist S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/162045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLS2nP1uggmetra51CDbgbiriCv.jpg'),
(63925, 4351, 'Hospital Playlist S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/162046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bQwimJnO2EQzINHAoGQSrhkDikl.jpg'),
(63926, 4351, 'Hospital Playlist S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/162047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7rIQKG6D1m3UCSVeBnSpHtPzaam.jpg'),
(63927, 4352, 'Lois & Clark: As Novas Aventuras do Superman S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157708.mp4', 'http://timg.bdta.pro/images/89aa68226cd094ba23e98654f2ebd4c9.jpg'),
(63928, 4352, 'Lois & Clark: As Novas Aventuras do Superman S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157709.mp4', 'http://timg.bdta.pro/images/dfa72133011a33788d087b5600198650.jpg'),
(63929, 4352, 'Lois & Clark: As Novas Aventuras do Superman S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157710.mp4', 'http://timg.bdta.pro/images/4ad632d8321f190378f8057e71fbd6f9.jpg'),
(63930, 4352, 'Lois & Clark: As Novas Aventuras do Superman S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157711.mp4', 'http://timg.bdta.pro/images/d1b27b6ae27c7689b68bc97195d7c14e.jpg'),
(63931, 4352, 'Lois & Clark: As Novas Aventuras do Superman S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/157712.mp4', 'http://timg.bdta.pro/images/49e6976c34c71150b4c1de7bc8bd11af.jpg'),
(63932, 4352, 'Lois & Clark: As Novas Aventuras do Superman S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/157713.mp4', 'http://timg.bdta.pro/images/7e6c5cfc8dd3d2d3400140b906c3bafa.jpg'),
(63933, 4352, 'Lois & Clark: As Novas Aventuras do Superman S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/157714.mp4', 'http://timg.bdta.pro/images/98c75fc1e4a377924529f8ecec7b43eb.jpg'),
(63934, 4352, 'Lois & Clark: As Novas Aventuras do Superman S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/157715.mp4', 'http://timg.bdta.pro/images/18ef28cb0b1356ac0fda022441bac777.jpg'),
(63935, 4352, 'Lois & Clark: As Novas Aventuras do Superman S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/157716.mp4', 'http://timg.bdta.pro/images/0c490e396c368b89ad8ebc9eb0885f5e.jpg'),
(63936, 4352, 'Lois & Clark: As Novas Aventuras do Superman S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/157717.mp4', 'http://timg.bdta.pro/images/1eff1d84482cb5d9440c9c3c91bcfec8.jpg'),
(63937, 4352, 'Lois & Clark: As Novas Aventuras do Superman S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/157718.mp4', 'http://timg.bdta.pro/images/56fe570b9dc58140c6f800b56fe7fa2a.jpg'),
(63938, 4352, 'Lois & Clark: As Novas Aventuras do Superman S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/157719.mp4', 'http://timg.bdta.pro/images/7c58343f3f6c84bb31c922ce0c4ac485.jpg'),
(63939, 4352, 'Lois & Clark: As Novas Aventuras do Superman S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/157720.mp4', 'http://timg.bdta.pro/images/0eab4d6e6afbfb50773029972d2a66d4.jpg'),
(63940, 4352, 'Lois & Clark: As Novas Aventuras do Superman S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/157721.mp4', 'http://timg.bdta.pro/images/0499fb933f8fbb35e7a7dcc78ec271b3.jpg'),
(63941, 4352, 'Lois & Clark: As Novas Aventuras do Superman S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/157722.mp4', 'http://timg.bdta.pro/images/925062d0e13f40e22ce1ab4955dce869.jpg'),
(63942, 4352, 'Lois & Clark: As Novas Aventuras do Superman S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/157723.mp4', 'http://timg.bdta.pro/images/b96a0481cb157c937afb730d7b765532.jpg'),
(63943, 4352, 'Lois & Clark: As Novas Aventuras do Superman S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/157724.mp4', 'http://timg.bdta.pro/images/79e7cac329824626c1c5c3e293dfb8c4.jpg'),
(63944, 4352, 'Lois & Clark: As Novas Aventuras do Superman S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/157725.mp4', 'http://timg.bdta.pro/images/e9b52f4c43c3bda0fba801d18f3d7ee1.jpg'),
(63945, 4352, 'Lois & Clark: As Novas Aventuras do Superman S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/157726.mp4', 'http://timg.bdta.pro/images/7682873fae6642f6c03ccc85e434915c.jpg'),
(63946, 4352, 'Lois & Clark: As Novas Aventuras do Superman S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/157727.mp4', 'http://timg.bdta.pro/images/8bc98cf0d92aac7132f59a7bb55b8bf3.jpg'),
(63947, 4352, 'Lois & Clark: As Novas Aventuras do Superman S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/157728.mp4', 'http://timg.bdta.pro/images/776b023fb27f76624d1fd4e29169be9e.jpg'),
(63948, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157729.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63949, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157730.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63950, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157731.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63951, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157732.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63952, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/157733.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63953, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/157734.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63954, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/157735.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63955, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/157736.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63956, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/157737.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63957, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/157738.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63958, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/157739.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(63959, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/157740.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63960, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/157741.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63961, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/157742.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63962, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/157743.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63963, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/157744.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63964, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/157745.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63965, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/157746.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63966, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/157747.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63967, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/157748.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63968, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/157749.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63969, 4353, 'Lois & Clark: As Novas Aventuras do Superman S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/157750.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63970, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157751.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63971, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157752.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63972, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157753.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63973, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157754.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63974, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/157755.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63975, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/157756.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63976, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/157757.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63977, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/157758.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63978, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/157759.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63979, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/157760.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63980, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/157761.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63981, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/157762.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63982, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/157763.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63983, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/157764.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63984, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/157765.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63985, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/157766.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63986, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/157767.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63987, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/157768.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63988, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/157769.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63989, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/157770.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63990, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/157771.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63991, 4354, 'Lois & Clark: As Novas Aventuras do Superman S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/157772.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63992, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157773.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63993, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157774.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63994, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157775.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63995, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157776.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63996, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/157777.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63997, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/157778.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63998, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/157779.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(63999, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/157780.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(64000, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/157781.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(64001, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/157782.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(64002, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/157783.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(64003, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/157784.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(64004, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/157785.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(64005, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/157786.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(64006, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/157787.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(64007, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/157788.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(64008, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/157789.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(64009, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/157790.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(64010, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/157791.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(64011, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/157792.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(64012, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/157793.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(64013, 4355, 'Lois & Clark: As Novas Aventuras do Superman S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/157794.mp4', 'http://gstaticontent.com/images/97bb004f33cdc3087618956fbf76d308.jpg'),
(64014, 4356, 'Estilo à Beira da Estrada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157702.mp4', 'http://gstaticontent.com/images/701cf73c12349d77f93ef11320e93511.jpg'),
(64015, 4356, 'Estilo à Beira da Estrada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157703.mp4', 'http://gstaticontent.com/images/701cf73c12349d77f93ef11320e93511.jpg'),
(64016, 4356, 'Estilo à Beira da Estrada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157704.mp4', 'http://gstaticontent.com/images/701cf73c12349d77f93ef11320e93511.jpg'),
(64017, 4356, 'Estilo à Beira da Estrada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157705.mp4', 'http://gstaticontent.com/images/701cf73c12349d77f93ef11320e93511.jpg'),
(64018, 4356, 'Estilo à Beira da Estrada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/157706.mp4', 'http://gstaticontent.com/images/701cf73c12349d77f93ef11320e93511.jpg'),
(64019, 4356, 'Estilo à Beira da Estrada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/157707.mp4', 'http://gstaticontent.com/images/701cf73c12349d77f93ef11320e93511.jpg'),
(64020, 4357, 'Nove Desconhecidos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161716.mp4', 'http://timg.bdta.pro/images/425f12abe6bce79c9abac0b0c0b85aaf.jpg'),
(64021, 4357, 'Nove Desconhecidos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161717.mp4', 'http://timg.bdta.pro/images/7665588efe496cc33bd00c7135a4b679.jpg'),
(64022, 4357, 'Nove Desconhecidos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161718.mp4', 'http://timg.bdta.pro/images/678ab6a2c8578f4094dee32c67f7048f.jpg'),
(64023, 4357, 'Nove Desconhecidos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161719.mp4', 'http://timg.bdta.pro/images/db14cb60f6862b846d39867507e60142.jpg'),
(64024, 4357, 'Nove Desconhecidos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161720.mp4', 'http://timg.bdta.pro/images/813cf17ca1239897b03a34ae443d974b.jpg'),
(64025, 4357, 'Nove Desconhecidos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161721.mp4', 'http://timg.bdta.pro/images/01df43ec90abe0312950481c797fe2e2.jpg'),
(64026, 4357, 'Nove Desconhecidos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161722.mp4', 'http://timg.bdta.pro/images/f8321c0e0c1bfccd7f95fe96b28c432f.jpg'),
(64027, 4357, 'Nove Desconhecidos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161723.mp4', 'http://image.tmdb.org/t/p/w1280/lpqX3SN1GXy8iBbwxvHfl6ihtPR.jpg'),
(64028, 4358, 'Nove Desconhecidos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/809183.mp4', 'http://gstaticontent.com/images/56c3dd80e1daff9e0329d32f10efb90b.jpg'),
(64029, 4358, 'Nove Desconhecidos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/809184.mp4', 'http://gstaticontent.com/images/56c3dd80e1daff9e0329d32f10efb90b.jpg'),
(64030, 4358, 'Nove Desconhecidos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/820780.mp4', 'http://gstaticontent.com/images/56c3dd80e1daff9e0329d32f10efb90b.jpg'),
(64031, 4358, 'Nove Desconhecidos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/828080.mp4', 'http://gstaticontent.com/images/56c3dd80e1daff9e0329d32f10efb90b.jpg'),
(64032, 4358, 'Nove Desconhecidos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/836588.mp4', 'http://gstaticontent.com/images/56c3dd80e1daff9e0329d32f10efb90b.jpg'),
(64033, 4358, 'Nove Desconhecidos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/848559.mp4', 'http://gstaticontent.com/images/56c3dd80e1daff9e0329d32f10efb90b.jpg'),
(64034, 4358, 'Nove Desconhecidos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/854156.mp4', 'http://gstaticontent.com/images/56c3dd80e1daff9e0329d32f10efb90b.jpg'),
(64035, 4358, 'Nove Desconhecidos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/855865.mp4', 'http://gstaticontent.com/images/56c3dd80e1daff9e0329d32f10efb90b.jpg'),
(64036, 4359, 'Post Mortem: Ninguém Morre em Skarnes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157696.mp4', 'http://timg.bdta.pro/images/03e2ad9322e88025d6a74a479f54707a.jpg'),
(64037, 4359, 'Post Mortem: Ninguém Morre em Skarnes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157697.mp4', 'http://timg.bdta.pro/images/deeb49c87ac806fcf46c777c7e591ad5.jpg'),
(64038, 4359, 'Post Mortem: Ninguém Morre em Skarnes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157698.mp4', 'http://timg.bdta.pro/images/b113adeb420b309e561a1fd513589160.jpg'),
(64039, 4359, 'Post Mortem: Ninguém Morre em Skarnes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157699.mp4', 'http://timg.bdta.pro/images/fb01400862820c5eb58c6509bd4805d8.jpg'),
(64040, 4359, 'Post Mortem: Ninguém Morre em Skarnes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/157700.mp4', 'http://timg.bdta.pro/images/ec6d507ac0cc58a8180f6c7869944375.jpg'),
(64041, 4359, 'Post Mortem: Ninguém Morre em Skarnes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/157701.mp4', 'http://timg.bdta.pro/images/01985be8ba999ac662ba6682b246f8e3.jpg'),
(64042, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157671.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64043, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157672.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64044, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157673.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64045, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157674.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64046, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/157675.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64047, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/157676.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64048, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/157677.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64049, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/157678.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64050, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/157679.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64051, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/157680.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64052, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/157681.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64053, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/157682.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64054, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/157683.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64055, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/157684.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64056, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/157685.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64057, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/157686.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64058, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/157687.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64059, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/157688.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64060, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/157689.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64061, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/157690.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64062, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/157691.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64063, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/157692.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64064, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/157693.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64065, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/157694.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64066, 4360, 'Quem Somos Nós? Edição de Colecionador S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/157695.mp4', 'http://gstaticontent.com/images/00e471718c6fd7a8cbe38a9e9c2fb6af.jpg'),
(64067, 4361, 'Todo va a estar bien S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157663.mp4', 'http://timg.bdta.pro/images/b1f676e32013bfa96294384a7b511d80.jpg'),
(64068, 4361, 'Todo va a estar bien S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157664.mp4', 'http://timg.bdta.pro/images/96ec2f399ef0a81187f22b468a683dde.jpg'),
(64069, 4361, 'Todo va a estar bien S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157665.mp4', 'http://timg.bdta.pro/images/86f60b1bc11c2f61218006147fdd1768.jpg'),
(64070, 4361, 'Todo va a estar bien S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157666.mp4', 'http://timg.bdta.pro/images/aefff2fa7c38ac28d52ae20b7f646790.jpg'),
(64071, 4361, 'Todo va a estar bien S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/157667.mp4', 'http://timg.bdta.pro/images/fc2ffa1ab46ed5f4ac6fc72d30e5d729.jpg'),
(64072, 4361, 'Todo va a estar bien S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/157668.mp4', 'http://timg.bdta.pro/images/576b899fab93f5e3eaae4f8470c4dd0c.jpg'),
(64073, 4361, 'Todo va a estar bien S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/157669.mp4', 'http://timg.bdta.pro/images/8843f7ce5be47a4dd457b15361f8e834.jpg'),
(64074, 4361, 'Todo va a estar bien S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/157670.mp4', 'http://timg.bdta.pro/images/f4f69a26b460b7131bae5db2ed0767cf.jpg'),
(64075, 4362, 'UFO S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157659.mp4', 'http://timg.bdta.pro/images/2e7db9def1a38367c3bb52b0cd0536f6.jpg'),
(64076, 4362, 'UFO S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157660.mp4', 'http://gstaticontent.com/images/db0195893c1517d436f4b55a912e4fbf.jpg'),
(64077, 4362, 'UFO S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157661.mp4', 'http://gstaticontent.com/images/db0195893c1517d436f4b55a912e4fbf.jpg'),
(64078, 4362, 'UFO S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157662.mp4', 'http://gstaticontent.com/images/db0195893c1517d436f4b55a912e4fbf.jpg'),
(64079, 4363, 'A Ilha da Fantasia [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171240.mp4', 'http://timg.bdta.pro/images/88cf15b26eb8dbe65bf678785f00d151.jpg'),
(64080, 4363, 'A Ilha da Fantasia [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171241.mp4', 'http://timg.bdta.pro/images/960ab5a6fe895aef274ec6ff4fe89595.jpg'),
(64081, 4363, 'A Ilha da Fantasia [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171242.mp4', 'http://timg.bdta.pro/images/f20453e4cb6182999c59d438db390b4e.jpg'),
(64082, 4363, 'A Ilha da Fantasia [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171243.mp4', 'http://timg.bdta.pro/images/add9bd3e55adb93c59dcc2edc5c1a4ec.jpg'),
(64083, 4363, 'A Ilha da Fantasia [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171244.mp4', 'http://timg.bdta.pro/images/769d9ea93e7cfe1b1c1fe4c34bc1c497.jpg'),
(64084, 4363, 'A Ilha da Fantasia [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171245.mp4', 'http://timg.bdta.pro/images/57f07ede8e216e4cc4d0cc36b6e857e0.jpg'),
(64085, 4363, 'A Ilha da Fantasia [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jAm6cpbOIEXvJKRGj82hI8TvtJs.jpg'),
(64086, 4363, 'A Ilha da Fantasia [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Yml6GV7d8ymGAOmpGuMaCxCvev.jpg'),
(64087, 4363, 'A Ilha da Fantasia [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171248.mp4', 'http://image.tmdb.org/t/p/w1280/jfnRpf0ycjRw497aJuTyd05wKxT.jpg'),
(64088, 4363, 'A Ilha da Fantasia [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171249.mp4', 'http://image.tmdb.org/t/p/w1280/1RAhqUyzcEHV7dMGNmy0Rts03fn.jpg'),
(64089, 4364, 'Deceit [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154416.mp4', 'http://timg.bdta.pro/images/952df4f3cc2bc4adcf2ea75efb2cda65.jpg'),
(64090, 4364, 'Deceit [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154417.mp4', 'http://timg.bdta.pro/images/9aba82068759953b72ef4d61ea395dc6.jpg'),
(64091, 4364, 'Deceit [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154418.mp4', 'http://timg.bdta.pro/images/adb8e3f45b9b2c910f96d78b93fd58f2.jpg'),
(64092, 4364, 'Deceit [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154419.mp4', 'http://timg.bdta.pro/images/33e2e2caff44d0cdfa3829a1e98da140.jpg'),
(64093, 4365, 'Estados Unidos do Al S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179295.mp4', 'http://timg.bdta.pro/images/d6ed245d3255919f020cce2f49429213.jpg'),
(64094, 4365, 'Estados Unidos do Al S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179296.mp4', 'http://timg.bdta.pro/images/8a8c64ac95e0674c1b6b437734b0251b.jpg'),
(64095, 4365, 'Estados Unidos do Al S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179297.mp4', 'http://timg.bdta.pro/images/6bc2822a9d2e839d00537bd0bb3e5188.jpg'),
(64096, 4365, 'Estados Unidos do Al S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179298.mp4', 'http://timg.bdta.pro/images/d43aca48982551416962d27611667adc.jpg'),
(64097, 4365, 'Estados Unidos do Al S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179299.mp4', 'http://timg.bdta.pro/images/b2cd6bb64675162446efdf1bd7b2c3e9.jpg'),
(64098, 4365, 'Estados Unidos do Al S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179300.mp4', 'http://timg.bdta.pro/images/814de4065d8e90dbfac22f3f43cfab15.jpg'),
(64099, 4365, 'Estados Unidos do Al S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179301.mp4', 'http://timg.bdta.pro/images/9cda3255d9db1b3f3bab51f76ed6ee02.jpg'),
(64100, 4365, 'Estados Unidos do Al S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179302.mp4', 'http://timg.bdta.pro/images/04650bbf90dee0a0e830e1a9644688c0.jpg'),
(64101, 4365, 'Estados Unidos do Al S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179303.mp4', 'http://timg.bdta.pro/images/430a18777506ad959deb76e77a24af65.jpg'),
(64102, 4365, 'Estados Unidos do Al S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179304.mp4', 'http://timg.bdta.pro/images/e1adea80d3f72f0d8ad3fccacbc295d6.jpg'),
(64103, 4365, 'Estados Unidos do Al S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179305.mp4', 'http://timg.bdta.pro/images/93364dbccc0ddcd3f0fa408380b5e03b.jpg'),
(64104, 4365, 'Estados Unidos do Al S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179306.mp4', 'http://timg.bdta.pro/images/fe7bc5898790a6fd01b6c38e54edab70.jpg'),
(64105, 4365, 'Estados Unidos do Al S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/179307.mp4', 'http://timg.bdta.pro/images/7ad8de3d8ebecfe7756fa1e9268ca836.jpg'),
(64106, 4366, 'Estados Unidos do Al S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179308.mp4', 'http://timg.bdta.pro/images/e9ac11a5f338d352383cd70312792eb4.jpg'),
(64107, 4366, 'Estados Unidos do Al S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179309.mp4', 'http://timg.bdta.pro/images/a9342a960c55038197f8a50f8395bbef.jpg'),
(64108, 4366, 'Estados Unidos do Al S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179310.mp4', 'http://gstaticontent.com/images/dc30db40e8af4e0a37759958f20e77eb.jpg'),
(64109, 4366, 'Estados Unidos do Al S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179311.mp4', 'http://gstaticontent.com/images/dc30db40e8af4e0a37759958f20e77eb.jpg'),
(64110, 4366, 'Estados Unidos do Al S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179312.mp4', 'http://gstaticontent.com/images/dc30db40e8af4e0a37759958f20e77eb.jpg'),
(64111, 4366, 'Estados Unidos do Al S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179313.mp4', 'http://gstaticontent.com/images/dc30db40e8af4e0a37759958f20e77eb.jpg'),
(64112, 4366, 'Estados Unidos do Al S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179314.mp4', 'http://gstaticontent.com/images/dc30db40e8af4e0a37759958f20e77eb.jpg'),
(64113, 4366, 'Estados Unidos do Al S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179316.mp4', 'http://gstaticontent.com/images/dc30db40e8af4e0a37759958f20e77eb.jpg'),
(64114, 4366, 'Estados Unidos do Al S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179317.mp4', 'http://gstaticontent.com/images/dc30db40e8af4e0a37759958f20e77eb.jpg'),
(64115, 4366, 'Estados Unidos do Al S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179318.mp4', 'http://gstaticontent.com/images/dc30db40e8af4e0a37759958f20e77eb.jpg'),
(64116, 4366, 'Estados Unidos do Al S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179319.mp4', 'http://gstaticontent.com/images/dc30db40e8af4e0a37759958f20e77eb.jpg'),
(64117, 4366, 'Estados Unidos do Al S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179320.mp4', 'http://gstaticontent.com/images/dc30db40e8af4e0a37759958f20e77eb.jpg'),
(64118, 4366, 'Estados Unidos do Al S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/179321.mp4', 'http://gstaticontent.com/images/dc30db40e8af4e0a37759958f20e77eb.jpg'),
(64119, 4366, 'Estados Unidos do Al S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/179322.mp4', 'http://gstaticontent.com/images/dc30db40e8af4e0a37759958f20e77eb.jpg'),
(64120, 4366, 'Estados Unidos do Al S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/179323.mp4', 'http://gstaticontent.com/images/dc30db40e8af4e0a37759958f20e77eb.jpg'),
(64121, 4366, 'Estados Unidos do Al S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/179324.mp4', 'http://gstaticontent.com/images/dc30db40e8af4e0a37759958f20e77eb.jpg'),
(64122, 4366, 'Estados Unidos do Al S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/179325.mp4', 'http://gstaticontent.com/images/dc30db40e8af4e0a37759958f20e77eb.jpg'),
(64123, 4366, 'Estados Unidos do Al S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/179326.mp4', 'http://gstaticontent.com/images/dc30db40e8af4e0a37759958f20e77eb.jpg'),
(64124, 4366, 'Estados Unidos do Al S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/179327.mp4', 'http://gstaticontent.com/images/dc30db40e8af4e0a37759958f20e77eb.jpg'),
(64125, 4366, 'Estados Unidos do Al S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/179328.mp4', 'http://gstaticontent.com/images/dc30db40e8af4e0a37759958f20e77eb.jpg'),
(64126, 4366, 'Estados Unidos do Al S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/179329.mp4', 'http://gstaticontent.com/images/dc30db40e8af4e0a37759958f20e77eb.jpg'),
(64127, 4367, 'Walker S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217172.mp4', 'http://timg.bdta.pro/images/9b76cb11b335c44c91e4f2ee04ea6727.jpg'),
(64128, 4367, 'Walker S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217173.mp4', 'http://timg.bdta.pro/images/7a963661a1374f0f69500fa886511e62.jpg'),
(64129, 4367, 'Walker S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217174.mp4', 'http://timg.bdta.pro/images/caa998de3a79cca10e16bc98998eba73.jpg'),
(64130, 4367, 'Walker S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217175.mp4', 'http://timg.bdta.pro/images/74dd70c5b8101cf8d309e026c8957dc1.jpg'),
(64131, 4367, 'Walker S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217176.mp4', 'http://timg.bdta.pro/images/be9ca0d6d6ffc9bdd009d9c9bdaa8970.jpg'),
(64132, 4367, 'Walker S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217177.mp4', 'http://timg.bdta.pro/images/00cd6497370c6dba629e07a9d27975df.jpg'),
(64133, 4367, 'Walker S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217178.mp4', 'http://timg.bdta.pro/images/78bca63654a1b4eb7279356309be4a16.jpg'),
(64134, 4367, 'Walker S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217179.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64135, 4367, 'Walker S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217180.mp4', 'http://timg.bdta.pro/images/12b9275461616c902c1da49d02729c33.jpg'),
(64136, 4367, 'Walker S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217181.mp4', 'http://timg.bdta.pro/images/5355a61a9656a954d97685fe7ee3a20d.jpg'),
(64137, 4367, 'Walker S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217182.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64138, 4367, 'Walker S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217183.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64139, 4367, 'Walker S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217184.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64140, 4367, 'Walker S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/217185.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64141, 4367, 'Walker S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/217186.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64142, 4367, 'Walker S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/217187.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64143, 4367, 'Walker S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/217188.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64144, 4367, 'Walker S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/217189.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64145, 4368, 'Walker S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217190.mp4', 'http://timg.bdta.pro/images/c1a0b780d3c7d49ea2de4eaa571bcbea.jpg'),
(64146, 4368, 'Walker S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217191.mp4', 'http://timg.bdta.pro/images/d997fc6b5cb536d6ee4e71b37effdae4.jpg'),
(64147, 4368, 'Walker S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217192.mp4', 'http://timg.bdta.pro/images/3afa1cf15c41bf589361786c3d91cb47.jpg'),
(64148, 4368, 'Walker S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217193.mp4', 'http://timg.bdta.pro/images/367e2d203b04187aeae4b1916cd649e7.jpg'),
(64149, 4368, 'Walker S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217194.mp4', 'http://timg.bdta.pro/images/f76546fdc42e8dee9db549b9c348913b.jpg'),
(64150, 4368, 'Walker S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217195.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64151, 4368, 'Walker S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217196.mp4', 'http://timg.bdta.pro/images/88abb1f533b6f0293f73d1625773c76d.jpg'),
(64152, 4368, 'Walker S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217197.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64153, 4368, 'Walker S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217198.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64154, 4368, 'Walker S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217199.mp4', 'http://timg.bdta.pro/images/50efd38d1bc3c1520ed8ae681f5d192f.jpg'),
(64155, 4368, 'Walker S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217200.mp4', 'http://timg.bdta.pro/images/19d464821daf212f96040fa4bc07353a.jpg'),
(64156, 4368, 'Walker S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217201.mp4', 'http://timg.bdta.pro/images/12a2424ece32db8baf15c63c77f3d215.jpg'),
(64157, 4368, 'Walker S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217202.mp4', 'http://timg.bdta.pro/images/8793ae257686cb89bcfb1ac32aa3bafa.jpg'),
(64158, 4368, 'Walker S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/217203.mp4', 'http://timg.bdta.pro/images/5c3a50c6fce97d419965ecb310e817b3.jpg'),
(64159, 4368, 'Walker S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/217204.mp4', 'http://timg.bdta.pro/images/79172d7fdeeb53ab1bdc2e9552e79a39.jpg'),
(64160, 4368, 'Walker S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/217205.mp4', 'http://timg.bdta.pro/images/dfa06a1a93c47df440347f60bd8b4fd1.jpg'),
(64161, 4368, 'Walker S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/217206.mp4', 'http://timg.bdta.pro/images/3d9554019b426448428d780e359ea5eb.jpg'),
(64162, 4368, 'Walker S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/217207.mp4', 'http://timg.bdta.pro/images/d76596f8e6395c2dde4c5f9f8d853ae8.jpg'),
(64163, 4368, 'Walker S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/217208.mp4', 'http://timg.bdta.pro/images/ae8c99cfc6a0090a30c026bbeb481dab.jpg'),
(64164, 4368, 'Walker S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/217209.mp4', 'http://timg.bdta.pro/images/53b74de0eb4f4446bec57268d13bd2b7.jpg'),
(64165, 4369, 'Walker S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217210.mp4', 'http://image.tmdb.org/t/p/w1280/7aMsmq5ZbkrZ2QUSrEejxT41iuY.jpg'),
(64166, 4369, 'Walker S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217211.mp4', 'http://image.tmdb.org/t/p/w1280/ggqgr6DgtUO6Qa1SQf8i1g7oq0P.jpg'),
(64167, 4369, 'Walker S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217212.mp4', 'http://image.tmdb.org/t/p/w1280/bibvpqhQnD1Ka8SWrlYzvviYHpI.jpg'),
(64168, 4369, 'Walker S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217213.mp4', 'http://image.tmdb.org/t/p/w1280/2gKbyLIRa0JYWgFDn1oIsWNhpoz.jpg'),
(64169, 4369, 'Walker S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217214.mp4', 'http://image.tmdb.org/t/p/w1280/9oDBXGfkX0hqhaO3pJ1mLWUuzGZ.jpg'),
(64170, 4369, 'Walker S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217215.mp4', 'http://image.tmdb.org/t/p/w1280/dF11w6minuZTlt0zOsNd3BxDS2e.jpg'),
(64171, 4369, 'Walker S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oLI2yE91qDQCN1lSUJ2wk1XSzDB.jpg'),
(64172, 4369, 'Walker S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/awJw4Mn0POVYw4KvBs5qhDSnOYy.jpg'),
(64173, 4369, 'Walker S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9G1KQiLxESyDeVzuWQtB461NHar.jpg'),
(64174, 4369, 'Walker S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217219.mp4', 'http://image.tmdb.org/t/p/w1280/s7ttwnjqJPq234QXXM3yHI8FIlb.jpg'),
(64175, 4369, 'Walker S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217220.mp4', 'http://image.tmdb.org/t/p/w1280/eccrNUoVb5OvcxIctYAkR0YCPxr.jpg'),
(64176, 4369, 'Walker S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217221.mp4', 'http://image.tmdb.org/t/p/w1280/pOUXPvZg6JW8kt30MM3FAVXynQx.jpg'),
(64177, 4369, 'Walker S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217222.mp4', 'http://image.tmdb.org/t/p/w1280/jfNEC8mmEkjXIPd0kkZYES9Wqjn.jpg'),
(64178, 4369, 'Walker S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/217223.mp4', 'http://image.tmdb.org/t/p/w1280/5YOqoj4zrYjHRUzaQgJP9uDa2gf.jpg'),
(64179, 4369, 'Walker S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/217224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AprXM8aReo1Jgcj4fZ4oeJf1QEX.jpg'),
(64180, 4369, 'Walker S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/217225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hngsdn2XHWlSPDQBgWkupBYYR0H.jpg'),
(64181, 4369, 'Walker S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/217226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v5GpOvYb3goJzBroxlxFP8uAKnn.jpg'),
(64182, 4369, 'Walker S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/217227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mTEvJAXJZ4Wd3ggluZgdF1ALPwg.jpg'),
(64183, 4370, 'Walker S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/451746.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64184, 4370, 'Walker S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/451747.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64185, 4370, 'Walker S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/451748.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64186, 4370, 'Walker S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/451749.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64187, 4370, 'Walker S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/451750.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64188, 4370, 'Walker S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/451751.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64189, 4370, 'Walker S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/451752.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64190, 4370, 'Walker S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/451753.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64191, 4370, 'Walker S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/451754.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64192, 4370, 'Walker S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/451755.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64193, 4370, 'Walker S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/451756.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64194, 4370, 'Walker S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/451757.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64195, 4370, 'Walker S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/451758.mp4', 'http://gstaticontent.com/images/9a7f6f6af9267fe6a2e6663adbe7c050.jpg'),
(64196, 4371, 'As Criancas Que Amamos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157126.mp4', 'http://gstaticontent.com/images/3be3259f326bdb86e88e69ccd214a824.jpg'),
(64197, 4371, 'As Criancas Que Amamos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157127.mp4', 'http://gstaticontent.com/images/3be3259f326bdb86e88e69ccd214a824.jpg'),
(64198, 4371, 'As Criancas Que Amamos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157128.mp4', 'http://gstaticontent.com/images/3be3259f326bdb86e88e69ccd214a824.jpg'),
(64199, 4371, 'As Criancas Que Amamos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157129.mp4', 'http://gstaticontent.com/images/3be3259f326bdb86e88e69ccd214a824.jpg'),
(64200, 4371, 'As Criancas Que Amamos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/157130.mp4', 'http://gstaticontent.com/images/3be3259f326bdb86e88e69ccd214a824.jpg'),
(64201, 4371, 'As Criancas Que Amamos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/157131.mp4', 'http://gstaticontent.com/images/3be3259f326bdb86e88e69ccd214a824.jpg'),
(64202, 4371, 'As Criancas Que Amamos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/157132.mp4', 'http://gstaticontent.com/images/3be3259f326bdb86e88e69ccd214a824.jpg'),
(64203, 4371, 'As Criancas Que Amamos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/157133.mp4', 'http://gstaticontent.com/images/3be3259f326bdb86e88e69ccd214a824.jpg'),
(64204, 4371, 'As Criancas Que Amamos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/157134.mp4', 'http://gstaticontent.com/images/3be3259f326bdb86e88e69ccd214a824.jpg'),
(64205, 4371, 'As Criancas Que Amamos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/157135.mp4', 'http://gstaticontent.com/images/3be3259f326bdb86e88e69ccd214a824.jpg'),
(64206, 4371, 'As Criancas Que Amamos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/157136.mp4', 'http://gstaticontent.com/images/3be3259f326bdb86e88e69ccd214a824.jpg'),
(64207, 4371, 'As Criancas Que Amamos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/157137.mp4', 'http://gstaticontent.com/images/3be3259f326bdb86e88e69ccd214a824.jpg'),
(64208, 4371, 'As Criancas Que Amamos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/157138.mp4', 'http://gstaticontent.com/images/3be3259f326bdb86e88e69ccd214a824.jpg'),
(64209, 4372, 'Cidade dos Campeões S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157118.mp4', 'http://gstaticontent.com/images/101fa3ad5bd6a29eca762d3d85a7815e.jpg'),
(64210, 4372, 'Cidade dos Campeões S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157119.mp4', 'http://gstaticontent.com/images/101fa3ad5bd6a29eca762d3d85a7815e.jpg'),
(64211, 4372, 'Cidade dos Campeões S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157120.mp4', 'http://gstaticontent.com/images/101fa3ad5bd6a29eca762d3d85a7815e.jpg'),
(64212, 4372, 'Cidade dos Campeões S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157121.mp4', 'http://gstaticontent.com/images/101fa3ad5bd6a29eca762d3d85a7815e.jpg'),
(64213, 4372, 'Cidade dos Campeões S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/157122.mp4', 'http://gstaticontent.com/images/101fa3ad5bd6a29eca762d3d85a7815e.jpg'),
(64214, 4372, 'Cidade dos Campeões S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/157123.mp4', 'http://gstaticontent.com/images/101fa3ad5bd6a29eca762d3d85a7815e.jpg'),
(64215, 4372, 'Cidade dos Campeões S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/157124.mp4', 'http://gstaticontent.com/images/101fa3ad5bd6a29eca762d3d85a7815e.jpg'),
(64216, 4372, 'Cidade dos Campeões S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/157125.mp4', 'http://gstaticontent.com/images/101fa3ad5bd6a29eca762d3d85a7815e.jpg'),
(64217, 4373, 'D.P Dog Day S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227289.mp4', 'http://timg.bdta.pro/images/616d99e59c52e15d3f94c8f07cd95ff2.jpg'),
(64218, 4373, 'D.P Dog Day S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227290.mp4', 'http://timg.bdta.pro/images/a84ddf964c0601287233cf56faa89abb.jpg'),
(64219, 4373, 'D.P Dog Day S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227291.mp4', 'http://timg.bdta.pro/images/f46c5216330a13ee2090feee1e22dc70.jpg'),
(64220, 4373, 'D.P Dog Day S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227292.mp4', 'http://timg.bdta.pro/images/3b2f1124e111852d448642f1ff8dfda5.jpg'),
(64221, 4373, 'D.P Dog Day S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227293.mp4', 'http://timg.bdta.pro/images/b4b9284ca24aef74ed07541503fdb957.jpg'),
(64222, 4373, 'D.P Dog Day S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227294.mp4', 'http://timg.bdta.pro/images/e0385d5fbf162ef85bc85e4981986d73.jpg'),
(64223, 4374, 'D.P Dog Day S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uEBBHwJuDfBtVWd2WS7WBOc8kb6.jpg'),
(64224, 4374, 'D.P Dog Day S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iqwtXBKyAB8CGUKOJEkMAxcOEoX.jpg'),
(64225, 4374, 'D.P Dog Day S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vViplqCajOsS0mxEUOuvICgpq7c.jpg'),
(64226, 4374, 'D.P Dog Day S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nZ5GqjIbQ3LpT3zqoFhrO7DuhwE.jpg'),
(64227, 4374, 'D.P Dog Day S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7SA5cHboSw4OSFxrjJuAdz1g7F9.jpg'),
(64228, 4374, 'D.P Dog Day S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sJ4Z4yaDt8evYCg212XvHJcaTb3.jpg'),
(64229, 4375, 'João de Deus: Cura e Crime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157114.mp4', 'http://gstaticontent.com/images/55f354c226c68e17aea65309a17423c7.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(64230, 4375, 'João de Deus: Cura e Crime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157115.mp4', 'http://gstaticontent.com/images/55f354c226c68e17aea65309a17423c7.jpg'),
(64231, 4375, 'João de Deus: Cura e Crime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157116.mp4', 'http://gstaticontent.com/images/55f354c226c68e17aea65309a17423c7.jpg'),
(64232, 4375, 'João de Deus: Cura e Crime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157117.mp4', 'http://gstaticontent.com/images/55f354c226c68e17aea65309a17423c7.jpg'),
(64233, 4376, 'KEVIN CAN F**K HIMSELF S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157106.mp4', 'http://timg.bdta.pro/images/710cde4185622e1ff049d1ba2fda7df1.jpg'),
(64234, 4376, 'KEVIN CAN F**K HIMSELF S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157107.mp4', 'http://timg.bdta.pro/images/03ec8895896eea561bb5d9af212cc9a1.jpg'),
(64235, 4376, 'KEVIN CAN F**K HIMSELF S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157108.mp4', 'http://timg.bdta.pro/images/aaa7ee7f97330df57e04feb0d6a6b8af.jpg'),
(64236, 4376, 'KEVIN CAN F**K HIMSELF S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157109.mp4', 'http://timg.bdta.pro/images/494ff46627e5c2e25267e4195686d671.jpg'),
(64237, 4376, 'KEVIN CAN F**K HIMSELF S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/157110.mp4', 'http://timg.bdta.pro/images/5259bc174bfa3d7714e499a169fbf339.jpg'),
(64238, 4376, 'KEVIN CAN F**K HIMSELF S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/157111.mp4', 'http://timg.bdta.pro/images/b46830ac19fd51714c3dd469c32bc600.jpg'),
(64239, 4376, 'KEVIN CAN F**K HIMSELF S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/157112.mp4', 'http://timg.bdta.pro/images/719c0fb5f45b8ef267a7c95dc960a5b0.jpg'),
(64240, 4376, 'KEVIN CAN F**K HIMSELF S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/157113.mp4', 'http://timg.bdta.pro/images/d30c80159ffc83ca990d7438dd6e4365.jpg'),
(64241, 4377, 'King of Boys: The Return of the King S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157099.mp4', 'http://timg.bdta.pro/images/8bd5967aecd405f4fdd8b095dcea3966.jpg'),
(64242, 4377, 'King of Boys: The Return of the King S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157100.mp4', 'http://timg.bdta.pro/images/a792dad843c1b3e4c8047cea82ca511e.jpg'),
(64243, 4377, 'King of Boys: The Return of the King S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157101.mp4', 'http://timg.bdta.pro/images/4c1793c9e3d15147e1eeead65cbf042e.jpg'),
(64244, 4377, 'King of Boys: The Return of the King S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157102.mp4', 'http://timg.bdta.pro/images/ad41d3c8b5d61fc267c4bf05b42d87ab.jpg'),
(64245, 4377, 'King of Boys: The Return of the King S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/157103.mp4', 'http://timg.bdta.pro/images/df1609e31c14c80920c49c0588466e2e.jpg'),
(64246, 4377, 'King of Boys: The Return of the King S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/157104.mp4', 'http://timg.bdta.pro/images/375889b39a1f176127ebf33505ec788f.jpg'),
(64247, 4377, 'King of Boys: The Return of the King S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/157105.mp4', 'http://timg.bdta.pro/images/5604858b6c0262ebd64276a6c9778fb2.jpg'),
(64248, 4378, 'Laetitia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157098.mp4', 'http://timg.bdta.pro/images/616044ccfd3cce2b993b3bee6ed4e03a.jpg'),
(64249, 4379, 'Only Murders in the Building S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238058.mp4', 'http://timg.bdta.pro/images/b217e3b1607508af2da7e99692efefec.jpg'),
(64250, 4379, 'Only Murders in the Building S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238059.mp4', 'http://timg.bdta.pro/images/d1bd7484b42e30f639a45fa05c7c0005.jpg'),
(64251, 4379, 'Only Murders in the Building S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238060.mp4', 'http://timg.bdta.pro/images/d8385a4bc576499b90a9ddece6366e38.jpg'),
(64252, 4379, 'Only Murders in the Building S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238061.mp4', 'http://timg.bdta.pro/images/d9a8ba103ace709b5a64f59a9e9e4f8e.jpg'),
(64253, 4379, 'Only Murders in the Building S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238062.mp4', 'http://timg.bdta.pro/images/b7ffefdeba82da7fcd70e5c6b04fa5b1.jpg'),
(64254, 4379, 'Only Murders in the Building S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238063.mp4', 'http://image.tmdb.org/t/p/w1280/xGLGTNmrSa1PugNld8FSO1Lz4Tv.jpg'),
(64255, 4379, 'Only Murders in the Building S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238064.mp4', 'http://image.tmdb.org/t/p/w1280/4ptqkNsGitJXokqWOS3UR23Vof0.jpg'),
(64256, 4379, 'Only Murders in the Building S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238065.mp4', 'http://image.tmdb.org/t/p/w1280/8ndIfhvIo5XujYqXGRVLTHhbr2i.jpg'),
(64257, 4379, 'Only Murders in the Building S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3mm1VFhhVlb4QHzLU9t0ObU8P71.jpg'),
(64258, 4379, 'Only Murders in the Building S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g0aKJuopwAJEPFipxeGsljxX5wp.jpg'),
(64259, 4380, 'Only Murders in the Building S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238068.mp4', 'http://timg.bdta.pro/images/6e82014d93edbc1bae7db8480034e56f.jpg'),
(64260, 4380, 'Only Murders in the Building S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238069.mp4', 'http://timg.bdta.pro/images/12518ee6d8b68ecaf6def9caa700864a.jpg'),
(64261, 4380, 'Only Murders in the Building S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238070.mp4', 'http://timg.bdta.pro/images/bc1bda9d5fcc07b8db6aa5b3b003137c.jpg'),
(64262, 4380, 'Only Murders in the Building S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238071.mp4', 'http://timg.bdta.pro/images/1c695676bc195950ea8b3397e26184bd.jpg'),
(64263, 4380, 'Only Murders in the Building S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238072.mp4', 'http://timg.bdta.pro/images/2a4028dda93f1ecca2a0d9ec7ee115f7.jpg'),
(64264, 4380, 'Only Murders in the Building S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238073.mp4', 'http://timg.bdta.pro/images/ee0cdedc2d4b6564a923ceb3916a8d8e.jpg'),
(64265, 4380, 'Only Murders in the Building S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238074.mp4', 'http://timg.bdta.pro/images/d5b31513544d02354d8d67dbe48d37c1.jpg'),
(64266, 4380, 'Only Murders in the Building S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238075.mp4', 'http://timg.bdta.pro/images/5eedb48f2d29870b2476ede57ca607aa.jpg'),
(64267, 4380, 'Only Murders in the Building S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238076.mp4', 'http://timg.bdta.pro/images/833bcd5876d5ad0382c2879069ad3010.jpg'),
(64268, 4380, 'Only Murders in the Building S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238077.mp4', 'http://timg.bdta.pro/images/a8a88dabb4278db7a8aecda9d3622429.jpg'),
(64269, 4381, 'Only Murders in the Building S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238078.mp4', 'http://image.tmdb.org/t/p/w1280/wUZnZpZufyA88DajjKFfj6oRsrV.jpg'),
(64270, 4381, 'Only Murders in the Building S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238079.mp4', 'http://image.tmdb.org/t/p/w1280/xemjE2kJK3dxw7SxDiD953TcsNA.jpg'),
(64271, 4381, 'Only Murders in the Building S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238080.mp4', 'http://image.tmdb.org/t/p/w1280/jRQnxB2Q9ynaaVwMYLGp0bhyjju.jpg'),
(64272, 4381, 'Only Murders in the Building S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238081.mp4', 'http://image.tmdb.org/t/p/w1280/9nJRqSBsaE6FLywKdEX8CMq2GsY.jpg'),
(64273, 4381, 'Only Murders in the Building S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238082.mp4', 'http://image.tmdb.org/t/p/w1280/1EJuHrZtrl9cqc2gx1mbaLOLGUB.jpg'),
(64274, 4381, 'Only Murders in the Building S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238083.mp4', 'http://image.tmdb.org/t/p/w1280/tKqlsT3zyj6qhlKSj7SkxOa2bvd.jpg'),
(64275, 4381, 'Only Murders in the Building S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238084.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64276, 4381, 'Only Murders in the Building S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238085.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64277, 4381, 'Only Murders in the Building S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238086.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64278, 4381, 'Only Murders in the Building S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238087.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64279, 4382, 'Only Murders in the Building S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/441668.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64280, 4382, 'Only Murders in the Building S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445936.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64281, 4382, 'Only Murders in the Building S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/452258.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64282, 4382, 'Only Murders in the Building S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/457422.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64283, 4382, 'Only Murders in the Building S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/464040.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64284, 4382, 'Only Murders in the Building S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/469768.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64285, 4382, 'Only Murders in the Building S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/476116.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64286, 4382, 'Only Murders in the Building S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/481292.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64287, 4382, 'Only Murders in the Building S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/490535.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64288, 4382, 'Only Murders in the Building S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/491970.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64289, 4383, 'Only Murders in the Building S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/883786.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64290, 4383, 'Only Murders in the Building S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/883787.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64291, 4383, 'Only Murders in the Building S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/883788.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64292, 4383, 'Only Murders in the Building S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/885312.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64293, 4383, 'Only Murders in the Building S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/886074.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64294, 4383, 'Only Murders in the Building S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/887557.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64295, 4383, 'Only Murders in the Building S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/888158.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64296, 4383, 'Only Murders in the Building S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/889618.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64297, 4383, 'Only Murders in the Building S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/890678.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64298, 4383, 'Only Murders in the Building S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/890679.mp4', 'http://gstaticontent.com/images/f3da0c7ce523454eb495605034bf28cb.jpg'),
(64299, 4384, 'Os Pilares da Terra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157094.mp4', 'http://timg.bdta.pro/images/ae594dc13e19f4b25f7a570ed5316b4e.jpg'),
(64300, 4384, 'Os Pilares da Terra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157095.mp4', 'http://timg.bdta.pro/images/324548fa9fe55293edf70a9bbe7371fe.jpg'),
(64301, 4384, 'Os Pilares da Terra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157096.mp4', 'http://timg.bdta.pro/images/013817d1f539d8ec7ed6057468716fec.jpg'),
(64302, 4384, 'Os Pilares da Terra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157097.mp4', 'http://timg.bdta.pro/images/179e41057f73f0069f6b8e39d810c04f.jpg'),
(64303, 4385, 'Par de Reis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157025.mp4', 'http://timg.bdta.pro/images/593fadd3aee318ee8743e4937179bb12.jpg'),
(64304, 4385, 'Par de Reis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157026.mp4', 'http://timg.bdta.pro/images/b16b7e3571aa5821dd316f24b154af20.jpg'),
(64305, 4385, 'Par de Reis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157027.mp4', 'http://timg.bdta.pro/images/fd09dae05e7919c15699400e0bb8b4be.jpg'),
(64306, 4385, 'Par de Reis S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157028.mp4', 'http://timg.bdta.pro/images/413d033d910be20d3758307cee4db055.jpg'),
(64307, 4385, 'Par de Reis S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/157029.mp4', 'http://timg.bdta.pro/images/c60a7e4270193a5bbee3407aa214dd3c.jpg'),
(64308, 4385, 'Par de Reis S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/157030.mp4', 'http://timg.bdta.pro/images/86b3a559618800ff785d0d47be1bcbf1.jpg'),
(64309, 4385, 'Par de Reis S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/157031.mp4', 'http://timg.bdta.pro/images/57b4115f6166eddbc1ee02c3cab187dd.jpg'),
(64310, 4385, 'Par de Reis S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/157032.mp4', 'http://timg.bdta.pro/images/421260109e2b4229c4c77a18f02781c5.jpg'),
(64311, 4385, 'Par de Reis S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/157033.mp4', 'http://timg.bdta.pro/images/a8e6e4704e9869c4ce84b1b00191e4d1.jpg'),
(64312, 4385, 'Par de Reis S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/157034.mp4', 'http://timg.bdta.pro/images/16a98db8d9ac174dfcc75f819c4998ce.jpg'),
(64313, 4385, 'Par de Reis S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/157035.mp4', 'http://timg.bdta.pro/images/f17076e9b9e8a43ef1d00e7e46ad2d98.jpg'),
(64314, 4385, 'Par de Reis S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/157036.mp4', 'http://timg.bdta.pro/images/0a419331df1a281c9ad949d280c708f5.jpg'),
(64315, 4385, 'Par de Reis S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/157037.mp4', 'http://timg.bdta.pro/images/60b1da6ce6c1de6b544df5d5150c7eeb.jpg'),
(64316, 4385, 'Par de Reis S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/157038.mp4', 'http://timg.bdta.pro/images/ca22dcfe4b8b7666ea1cbef3ea116582.jpg'),
(64317, 4385, 'Par de Reis S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/157039.mp4', 'http://timg.bdta.pro/images/6a7c284a7784ce3fe395c1720a35cd30.jpg'),
(64318, 4385, 'Par de Reis S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/157040.mp4', 'http://timg.bdta.pro/images/0578d24a6a1509ee915a839a2dc90aa8.jpg'),
(64319, 4385, 'Par de Reis S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/157041.mp4', 'http://timg.bdta.pro/images/5de8340ea7435e0dbe7876dd6ba741d9.jpg'),
(64320, 4385, 'Par de Reis S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/157042.mp4', 'http://timg.bdta.pro/images/0fa815360d31db5fcfdba484338d7844.jpg'),
(64321, 4385, 'Par de Reis S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/157043.mp4', 'http://timg.bdta.pro/images/56da10a7bea1909fded4fe3ac6231436.jpg'),
(64322, 4385, 'Par de Reis S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/157044.mp4', 'http://timg.bdta.pro/images/d506cfdf9be2180a668f21606b23e28b.jpg'),
(64323, 4385, 'Par de Reis S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/157045.mp4', 'http://timg.bdta.pro/images/00a96ed9191f0cf2dea9a6df14f6f685.jpg'),
(64324, 4386, 'Par de Reis S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157046.mp4', 'http://timg.bdta.pro/images/2e9aa356f2c1cd02b25e3897c5746345.jpg'),
(64325, 4386, 'Par de Reis S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157047.mp4', 'http://timg.bdta.pro/images/279ac75d7035f80401db48f0c3ea755b.jpg'),
(64326, 4386, 'Par de Reis S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157048.mp4', 'http://timg.bdta.pro/images/36dd516c30782e86dcd66d004c697476.jpg'),
(64327, 4386, 'Par de Reis S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157049.mp4', 'http://timg.bdta.pro/images/86849176d235777c1ee8f4c5e1bb1557.jpg'),
(64328, 4386, 'Par de Reis S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/157050.mp4', 'http://timg.bdta.pro/images/48e589fcc0ea005f79705f3c2dc2ba90.jpg'),
(64329, 4386, 'Par de Reis S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/157051.mp4', 'http://timg.bdta.pro/images/d14404139884f89c8b11ca4dc709aee1.jpg'),
(64330, 4386, 'Par de Reis S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/157052.mp4', 'http://timg.bdta.pro/images/d64996a33ad9588a3eedb07a7f3b92d0.jpg'),
(64331, 4386, 'Par de Reis S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/157053.mp4', 'http://timg.bdta.pro/images/85fc9a4a4900eba3065cb015e80a30e7.jpg'),
(64332, 4386, 'Par de Reis S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/157054.mp4', 'http://timg.bdta.pro/images/995b65ba51ca933460c2b30d499c7391.jpg'),
(64333, 4386, 'Par de Reis S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/157055.mp4', 'http://timg.bdta.pro/images/4c57c7ec3b97ee0289be8114dbecf334.jpg'),
(64334, 4386, 'Par de Reis S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/157056.mp4', 'http://timg.bdta.pro/images/579dd455046726e8bce50e7a0e07a885.jpg'),
(64335, 4386, 'Par de Reis S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/157057.mp4', 'http://timg.bdta.pro/images/02cc0c99610ab4545725d34f0eb53f38.jpg'),
(64336, 4386, 'Par de Reis S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/157058.mp4', 'http://timg.bdta.pro/images/c9be1db5c435324ce42e6787b27fce79.jpg'),
(64337, 4386, 'Par de Reis S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/157059.mp4', 'http://timg.bdta.pro/images/936998ca561af6281fdc207f9730f5cf.jpg'),
(64338, 4386, 'Par de Reis S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/157060.mp4', 'http://timg.bdta.pro/images/2d7437f9db108ae3e9f5799267c0e99a.jpg'),
(64339, 4386, 'Par de Reis S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/157061.mp4', 'http://timg.bdta.pro/images/29a98e114fcc529fabb8ee238c7d6c73.jpg'),
(64340, 4386, 'Par de Reis S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/157062.mp4', 'http://timg.bdta.pro/images/0c041e31e7215cc5442fe78c799b4ead.jpg'),
(64341, 4386, 'Par de Reis S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/157063.mp4', 'http://timg.bdta.pro/images/ac95731b0ed83ff48b5dbcba08a6001d.jpg'),
(64342, 4386, 'Par de Reis S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/157064.mp4', 'http://timg.bdta.pro/images/fd2e7f417a664fe54fad07880efb64e0.jpg'),
(64343, 4386, 'Par de Reis S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/157065.mp4', 'http://timg.bdta.pro/images/3aea4e0b263117002eb4d8604f576f01.jpg'),
(64344, 4386, 'Par de Reis S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/157066.mp4', 'http://timg.bdta.pro/images/f4e1a5b3646cb4c8ead57d18ba62ef9c.jpg'),
(64345, 4386, 'Par de Reis S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/157067.mp4', 'http://timg.bdta.pro/images/030915cd1cff271e155ca366de6bc820.jpg'),
(64346, 4386, 'Par de Reis S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/157068.mp4', 'http://timg.bdta.pro/images/e1eee4dac0afc133944b838af28c12ac.jpg'),
(64347, 4386, 'Par de Reis S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/157069.mp4', 'http://timg.bdta.pro/images/1039ec5a33ea888fbe6cbf951109438a.jpg'),
(64348, 4386, 'Par de Reis S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/157070.mp4', 'http://timg.bdta.pro/images/c1be86c3413d266fd2a2fed0532f26cf.jpg'),
(64349, 4386, 'Par de Reis S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/157071.mp4', 'http://gstaticontent.com/images/68f360dfe2ed5f9e872537113c8a5929.jpg'),
(64350, 4387, 'Par de Reis S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/157072.mp4', 'http://timg.bdta.pro/images/ff65ba821684e15880034f0ba0194b81.jpg'),
(64351, 4387, 'Par de Reis S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/157073.mp4', 'http://timg.bdta.pro/images/f8a86cb51f40690d8579f43a98fc8e7c.jpg'),
(64352, 4387, 'Par de Reis S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/157074.mp4', 'http://timg.bdta.pro/images/3cb85858cd5b976bedecac6c3cc1300e.jpg'),
(64353, 4387, 'Par de Reis S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/157075.mp4', 'http://timg.bdta.pro/images/bf016e34a1cdd4ac64eee134355f172c.jpg'),
(64354, 4387, 'Par de Reis S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/157076.mp4', 'http://timg.bdta.pro/images/bb572e778f8bc29244fdbdf03eb2fbff.jpg'),
(64355, 4387, 'Par de Reis S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/157077.mp4', 'http://timg.bdta.pro/images/3288e55e12a4b9d713ae0fc12854ed7a.jpg'),
(64356, 4387, 'Par de Reis S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/157078.mp4', 'http://timg.bdta.pro/images/938e4974bbf976ec4d02f1e5018f1f1c.jpg'),
(64357, 4387, 'Par de Reis S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/157079.mp4', 'http://timg.bdta.pro/images/325f74a8e67479a6be934cde7e177cde.jpg'),
(64358, 4387, 'Par de Reis S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/157080.mp4', 'http://timg.bdta.pro/images/97b53ec2226875a998d736bcda11fd18.jpg'),
(64359, 4387, 'Par de Reis S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/157081.mp4', 'http://timg.bdta.pro/images/98e342b4a842b229b4ad908607545ecf.jpg'),
(64360, 4387, 'Par de Reis S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/157082.mp4', 'http://timg.bdta.pro/images/d6cf709f7b2d123dbd15fce964bc3a13.jpg'),
(64361, 4387, 'Par de Reis S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/157083.mp4', 'http://timg.bdta.pro/images/ec06d5cb09dfe26a173ba6097dc17807.jpg'),
(64362, 4387, 'Par de Reis S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/157084.mp4', 'http://timg.bdta.pro/images/9dd6f0fe91c84b500df58747e730f163.jpg'),
(64363, 4387, 'Par de Reis S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/157085.mp4', 'http://timg.bdta.pro/images/cc1467a8f5715358a1a482b8fc8ee5fd.jpg'),
(64364, 4387, 'Par de Reis S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/157086.mp4', 'http://timg.bdta.pro/images/57588a337f39b06be1e2a7dd31d30549.jpg'),
(64365, 4387, 'Par de Reis S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/157087.mp4', 'http://timg.bdta.pro/images/82c128465ff311e8edbe238f8d47cdfd.jpg'),
(64366, 4387, 'Par de Reis S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/157088.mp4', 'http://timg.bdta.pro/images/daaa93b5726dae494cd84e4fc9c75bce.jpg'),
(64367, 4387, 'Par de Reis S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/157089.mp4', 'http://timg.bdta.pro/images/5b6d93d4aedec5e7f5f6701463caac69.jpg'),
(64368, 4387, 'Par de Reis S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/157090.mp4', 'http://timg.bdta.pro/images/9e1e7f7caf130e4dd0f5002045c6556c.jpg'),
(64369, 4387, 'Par de Reis S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/157091.mp4', 'http://timg.bdta.pro/images/bb7019f890c610e04f36105e9b7530b4.jpg'),
(64370, 4387, 'Par de Reis S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/157092.mp4', 'http://timg.bdta.pro/images/39b031dacbd520dfbcbd296de16106df.jpg'),
(64371, 4387, 'Par de Reis S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/157093.mp4', 'http://timg.bdta.pro/images/39b031dacbd520dfbcbd296de16106df.jpg'),
(64372, 4388, 'Twin Peaks S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154368.mp4', 'http://timg.bdta.pro/images/42eb39333d5e40e153f0b5b971e328e8.jpg'),
(64373, 4388, 'Twin Peaks S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154369.mp4', 'http://timg.bdta.pro/images/48b0a8767d855d2ba0f21267f1303ba9.jpg'),
(64374, 4388, 'Twin Peaks S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154370.mp4', 'http://timg.bdta.pro/images/558c680d079638eb077698887b56ca64.jpg'),
(64375, 4388, 'Twin Peaks S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154371.mp4', 'http://timg.bdta.pro/images/6575e96c33356f0a8614477723919220.jpg'),
(64376, 4388, 'Twin Peaks S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154372.mp4', 'http://timg.bdta.pro/images/f8f604dc4fa94c1f554db69baad6b499.jpg'),
(64377, 4388, 'Twin Peaks S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154373.mp4', 'http://timg.bdta.pro/images/07dc0c107b6a03be0854eef07ee3a626.jpg'),
(64378, 4388, 'Twin Peaks S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154374.mp4', 'http://timg.bdta.pro/images/694c73b2b32fab4b8f474569c78c66a4.jpg'),
(64379, 4388, 'Twin Peaks S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154375.mp4', 'http://timg.bdta.pro/images/718af456ee49781894d8f680e9da72d4.jpg'),
(64380, 4389, 'Twin Peaks S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154376.mp4', 'http://timg.bdta.pro/images/a3c3997cfc9347da42c9136c3f4402ec.jpg'),
(64381, 4389, 'Twin Peaks S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154377.mp4', 'http://timg.bdta.pro/images/ed5a30bdc4a60f65016f43672258b708.jpg'),
(64382, 4389, 'Twin Peaks S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154378.mp4', 'http://timg.bdta.pro/images/561c76eadb5659edeb3c5377ab27d5ca.jpg'),
(64383, 4389, 'Twin Peaks S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154379.mp4', 'http://timg.bdta.pro/images/147f6e60a8548c5bf2e3c1e14c2aa53a.jpg'),
(64384, 4389, 'Twin Peaks S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154380.mp4', 'http://timg.bdta.pro/images/0c557398a96144328be231001fa6b354.jpg'),
(64385, 4389, 'Twin Peaks S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154381.mp4', 'http://timg.bdta.pro/images/5b527ca77cc0a024332c401d4cc259e9.jpg'),
(64386, 4389, 'Twin Peaks S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154382.mp4', 'http://timg.bdta.pro/images/2668381a0a722723bcc07b5ad524f2fc.jpg'),
(64387, 4389, 'Twin Peaks S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154383.mp4', 'http://timg.bdta.pro/images/49a293844260d6e00273c579cdee102a.jpg'),
(64388, 4389, 'Twin Peaks S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154384.mp4', 'http://timg.bdta.pro/images/8456de6e69509a140f4544ab7603c1ab.jpg'),
(64389, 4389, 'Twin Peaks S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154385.mp4', 'http://timg.bdta.pro/images/dc2c77e4c644526156a325abbfbc42e4.jpg'),
(64390, 4389, 'Twin Peaks S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/154386.mp4', 'http://timg.bdta.pro/images/a4e853e957b84b045d3ecd5f3c7729a4.jpg'),
(64391, 4389, 'Twin Peaks S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/154387.mp4', 'http://timg.bdta.pro/images/dfb146d47eb8831a0703028774270fd6.jpg'),
(64392, 4389, 'Twin Peaks S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/154388.mp4', 'http://timg.bdta.pro/images/3034afa99e86d1ad51999cfb0630e7e7.jpg'),
(64393, 4389, 'Twin Peaks S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/154389.mp4', 'http://timg.bdta.pro/images/359572099e8c78a4a33fc06aa33691a7.jpg'),
(64394, 4389, 'Twin Peaks S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/154390.mp4', 'http://timg.bdta.pro/images/9a3f765d7f6c53c97c2170f302150b90.jpg'),
(64395, 4389, 'Twin Peaks S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/154391.mp4', 'http://timg.bdta.pro/images/57baef18af39f0d1a12c13de46358fb8.jpg'),
(64396, 4389, 'Twin Peaks S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/154392.mp4', 'http://timg.bdta.pro/images/a89758b2cbfb5dcf5a3bd0acb2635fa6.jpg'),
(64397, 4389, 'Twin Peaks S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/154393.mp4', 'http://timg.bdta.pro/images/2f898ce98eb0b930cbceafafea21112c.jpg'),
(64398, 4389, 'Twin Peaks S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/154394.mp4', 'http://timg.bdta.pro/images/2ae9516eeed2ca9237c3b8c795e510aa.jpg'),
(64399, 4389, 'Twin Peaks S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/154395.mp4', 'http://timg.bdta.pro/images/e33c6e5fc9dcbeb03620e170a2b86933.jpg'),
(64400, 4389, 'Twin Peaks S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/154396.mp4', 'http://timg.bdta.pro/images/c7a7b0d35d94995e93cf9810cc4b3b19.jpg'),
(64401, 4389, 'Twin Peaks S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/154397.mp4', 'http://timg.bdta.pro/images/09fd013b5ed9a02026f56d4973f71b43.jpg'),
(64402, 4390, 'Twin Peaks S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154398.mp4', 'http://timg.bdta.pro/images/8667f60ace7bf27d7940902b0c764649.jpg'),
(64403, 4390, 'Twin Peaks S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154399.mp4', 'http://timg.bdta.pro/images/10e4987a366c4f1f3eb506fd6886c2f8.jpg'),
(64404, 4390, 'Twin Peaks S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154400.mp4', 'http://timg.bdta.pro/images/a28211b841e06572f10b106a7d12f830.jpg'),
(64405, 4390, 'Twin Peaks S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154401.mp4', 'http://timg.bdta.pro/images/d8ffbe39c425321aa9228c0cccb02b2e.jpg'),
(64406, 4390, 'Twin Peaks S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154402.mp4', 'http://timg.bdta.pro/images/bfccb376763be1901223fb67e721c8a0.jpg'),
(64407, 4390, 'Twin Peaks S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154403.mp4', 'http://timg.bdta.pro/images/76a0a797fa9149335afc2b83933ab417.jpg'),
(64408, 4390, 'Twin Peaks S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154404.mp4', 'http://timg.bdta.pro/images/2730687857e262daee02e6de63de633f.jpg'),
(64409, 4390, 'Twin Peaks S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154405.mp4', 'http://timg.bdta.pro/images/4fc73a636314429361df421e12c18f49.jpg'),
(64410, 4390, 'Twin Peaks S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154406.mp4', 'http://timg.bdta.pro/images/53897c44b5c8bebcb6a08a243ec42e4e.jpg'),
(64411, 4390, 'Twin Peaks S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154407.mp4', 'http://timg.bdta.pro/images/45234e139bdfa13fdc868c1d7867973b.jpg'),
(64412, 4390, 'Twin Peaks S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/154408.mp4', 'http://timg.bdta.pro/images/466cc907a13b90d62c91ee79329ece01.jpg'),
(64413, 4390, 'Twin Peaks S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/154409.mp4', 'http://timg.bdta.pro/images/0ab58fb66267fd3ebc086bbbe2e85e02.jpg'),
(64414, 4390, 'Twin Peaks S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/154410.mp4', 'http://timg.bdta.pro/images/46261075c6693c1620773511b2ad5585.jpg'),
(64415, 4390, 'Twin Peaks S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/154411.mp4', 'http://timg.bdta.pro/images/d26f2f113e8caa078a9b377f0cc5aaa9.jpg'),
(64416, 4390, 'Twin Peaks S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/154412.mp4', 'http://timg.bdta.pro/images/d602f95c6ae3481a206b1eebe68ebd7e.jpg'),
(64417, 4390, 'Twin Peaks S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/154413.mp4', 'http://timg.bdta.pro/images/8e68bafffe74876b238ec126e442f315.jpg'),
(64418, 4390, 'Twin Peaks S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/154414.mp4', 'http://timg.bdta.pro/images/8808f8b032f4edfbeb49b1751a37d3f9.jpg'),
(64419, 4390, 'Twin Peaks S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/154415.mp4', 'http://timg.bdta.pro/images/dde3d15300f04dda2d9909a34ba31124.jpg'),
(64420, 4391, 'As Telefonistas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/156547.mp4', 'http://timg.bdta.pro/images/83ce7d34c500b85811ff082af37f3d37.jpg'),
(64421, 4391, 'As Telefonistas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/156548.mp4', 'http://timg.bdta.pro/images/8e709e6e4f214f9ed073b49017421d70.jpg'),
(64422, 4391, 'As Telefonistas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/156549.mp4', 'http://timg.bdta.pro/images/d746939d497819b35a1e0846704c69e7.jpg'),
(64423, 4391, 'As Telefonistas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/156550.mp4', 'http://timg.bdta.pro/images/25a9c6ade8c4966ba0bfbe41cfb011b1.jpg'),
(64424, 4391, 'As Telefonistas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/156551.mp4', 'http://timg.bdta.pro/images/61eb112624b6d12153a3f5efd830512b.jpg'),
(64425, 4391, 'As Telefonistas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/156552.mp4', 'http://timg.bdta.pro/images/aa173607e2f6a91c424dba324fbbe274.jpg'),
(64426, 4391, 'As Telefonistas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/156553.mp4', 'http://timg.bdta.pro/images/39da32442515bbf0e2f7361d3bf41e7c.jpg'),
(64427, 4391, 'As Telefonistas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/156554.mp4', 'http://timg.bdta.pro/images/e5f3617513fb609909835925e3a2370b.jpg'),
(64428, 4392, 'As Telefonistas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/156555.mp4', 'http://timg.bdta.pro/images/1ce94f824c8660db0eb83ee124b309be.jpg'),
(64429, 4392, 'As Telefonistas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/156556.mp4', 'http://timg.bdta.pro/images/dc40b1454592c12cd178f18d31418620.jpg'),
(64430, 4392, 'As Telefonistas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/156557.mp4', 'http://timg.bdta.pro/images/a2382aeac8803ce18982d9b5f1cffd0c.jpg'),
(64431, 4392, 'As Telefonistas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/156558.mp4', 'http://timg.bdta.pro/images/79b4f8fb3294a7edb11a321658ba63c9.jpg'),
(64432, 4392, 'As Telefonistas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/156559.mp4', 'http://timg.bdta.pro/images/73e8672e0bb86c286f624b350da6a6a8.jpg'),
(64433, 4392, 'As Telefonistas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/156560.mp4', 'http://timg.bdta.pro/images/2bb29295064cd9bd201e12a8f0a83934.jpg'),
(64434, 4392, 'As Telefonistas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/156561.mp4', 'http://timg.bdta.pro/images/815960a0f57eac7dfb43b86af58ff72c.jpg'),
(64435, 4392, 'As Telefonistas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/156562.mp4', 'http://timg.bdta.pro/images/e3910ab51f4a9bf26f3e96f887bf8d5f.jpg'),
(64436, 4393, 'As Telefonistas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/156563.mp4', 'http://timg.bdta.pro/images/feecf779b0a45cf8a395ca4988fab49e.jpg'),
(64437, 4393, 'As Telefonistas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/156564.mp4', 'http://timg.bdta.pro/images/91a35d5111893b157730eedd40646e2a.jpg'),
(64438, 4393, 'As Telefonistas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/156565.mp4', 'http://timg.bdta.pro/images/81291078358698e4cd099ee02461f5e5.jpg'),
(64439, 4393, 'As Telefonistas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/156566.mp4', 'http://timg.bdta.pro/images/35beda7a000f58514bb255a985ec20e2.jpg'),
(64440, 4393, 'As Telefonistas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/156567.mp4', 'http://timg.bdta.pro/images/14f471fc2a61c6cb384f280ad2b56df2.jpg'),
(64441, 4393, 'As Telefonistas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/156568.mp4', 'http://timg.bdta.pro/images/fc71a4aa89f30b72027b44e6542754d1.jpg'),
(64442, 4393, 'As Telefonistas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/156569.mp4', 'http://timg.bdta.pro/images/8d409fb31dd774c0ef0f2d3f9e8e1ae3.jpg'),
(64443, 4393, 'As Telefonistas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/156570.mp4', 'http://timg.bdta.pro/images/d234624f920ea604a430ee3f9863f15a.jpg'),
(64444, 4394, 'As Telefonistas S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/156571.mp4', 'http://timg.bdta.pro/images/139dee24fdb85986380be6a78e1c7186.jpg'),
(64445, 4394, 'As Telefonistas S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/156572.mp4', 'http://timg.bdta.pro/images/72bf99566661d53f4e43fa0e2ecb9bba.jpg'),
(64446, 4394, 'As Telefonistas S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/156573.mp4', 'http://timg.bdta.pro/images/572729912df98515801d826d2b08fcaa.jpg'),
(64447, 4394, 'As Telefonistas S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/156574.mp4', 'http://timg.bdta.pro/images/b19a754e3f65254a353701cea18122e6.jpg'),
(64448, 4394, 'As Telefonistas S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/156575.mp4', 'http://timg.bdta.pro/images/3729b1684b01a3969f7f13c27e4e5387.jpg'),
(64449, 4394, 'As Telefonistas S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/156576.mp4', 'http://timg.bdta.pro/images/56fc3fffe6b1f8c1079ebda2aefb43c9.jpg'),
(64450, 4394, 'As Telefonistas S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/156577.mp4', 'http://timg.bdta.pro/images/f180c0ffb1961754fad541621a70cc26.jpg'),
(64451, 4394, 'As Telefonistas S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/156578.mp4', 'http://timg.bdta.pro/images/6407db9e779730ed396f7d9459d6381f.jpg'),
(64452, 4395, 'As Telefonistas S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/156579.mp4', 'http://timg.bdta.pro/images/c773620b20bc76d6e758767b453bcc38.jpg'),
(64453, 4395, 'As Telefonistas S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/156580.mp4', 'http://timg.bdta.pro/images/8048eee1d06d75e23c4d51bae9f6d4f4.jpg'),
(64454, 4395, 'As Telefonistas S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/156581.mp4', 'http://timg.bdta.pro/images/bf893f0bc752df21db6788672ca5db38.jpg'),
(64455, 4395, 'As Telefonistas S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/156582.mp4', 'http://timg.bdta.pro/images/f4a7a827a0f3837eeef754aac6d1b0a5.jpg'),
(64456, 4395, 'As Telefonistas S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/156583.mp4', 'http://timg.bdta.pro/images/b88fb67d720f0164c224d5871442b40c.jpg'),
(64457, 4395, 'As Telefonistas S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/156584.mp4', 'http://timg.bdta.pro/images/493fa0b16b5212caa98230a457d71d04.jpg'),
(64458, 4395, 'As Telefonistas S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/156585.mp4', 'http://timg.bdta.pro/images/9e349da8eacdb12e96171bc745669c77.jpg'),
(64459, 4395, 'As Telefonistas S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/156586.mp4', 'http://timg.bdta.pro/images/a9a146aca13b4f7c83c584248d4962a1.jpg'),
(64460, 4395, 'As Telefonistas S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/156587.mp4', 'http://timg.bdta.pro/images/807bf78c8c1a838dc75ddf62d53e6e75.jpg'),
(64461, 4395, 'As Telefonistas S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/156588.mp4', 'http://timg.bdta.pro/images/84b987df0ea8da355e99c152b42a7990.jpg'),
(64462, 4396, 'Big Sky S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208405.mp4', 'http://timg.bdta.pro/images/be365442da8a6b9691a8600139545e02.jpg'),
(64463, 4396, 'Big Sky S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208406.mp4', 'http://timg.bdta.pro/images/193546851cacfa5bf7c0fa3d01811986.jpg'),
(64464, 4396, 'Big Sky S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208407.mp4', 'http://timg.bdta.pro/images/e27ff17a6b7430062da1e1c06afa4400.jpg'),
(64465, 4396, 'Big Sky S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208408.mp4', 'http://timg.bdta.pro/images/6dc6ff4f7467d2c40bfe82ddb96d7ad8.jpg'),
(64466, 4396, 'Big Sky S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208409.mp4', 'http://timg.bdta.pro/images/64afc022e3b2d6e4e7f99ff28253524b.jpg'),
(64467, 4396, 'Big Sky S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208410.mp4', 'http://timg.bdta.pro/images/c8efa4b1b2ebd5ea89bef3033e3d26ad.jpg'),
(64468, 4396, 'Big Sky S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208411.mp4', 'http://timg.bdta.pro/images/7bb07e9d18254eef75d79412ec247c2e.jpg'),
(64469, 4396, 'Big Sky S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208412.mp4', 'http://timg.bdta.pro/images/f4ed175413cc31a46f75d183b2ca16a9.jpg'),
(64470, 4396, 'Big Sky S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208413.mp4', 'http://timg.bdta.pro/images/7473f600c3ba5acc7b37f7245c77d495.jpg'),
(64471, 4396, 'Big Sky S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208414.mp4', 'http://timg.bdta.pro/images/27296a44a2bd8dc112aecc64b8f48614.jpg'),
(64472, 4396, 'Big Sky S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208415.mp4', 'http://timg.bdta.pro/images/58c96fd58d051bba501677ae98dc79c7.jpg'),
(64473, 4396, 'Big Sky S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208416.mp4', 'http://timg.bdta.pro/images/52cce88da480a5fcc67fec577eb4ef08.jpg'),
(64474, 4396, 'Big Sky S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/208417.mp4', 'http://timg.bdta.pro/images/0ac89688778bc92d12cc9b551aa3deab.jpg'),
(64475, 4396, 'Big Sky S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/208418.mp4', 'http://timg.bdta.pro/images/a5af46b750ddcff1788e7c199a778368.jpg'),
(64476, 4396, 'Big Sky S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/208419.mp4', 'http://timg.bdta.pro/images/dbad65308f4cd64e1515b06c948a3b7e.jpg'),
(64477, 4396, 'Big Sky S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/208420.mp4', 'http://timg.bdta.pro/images/2dd38b1f015b2784a0a4d0770fbf0c11.jpg'),
(64478, 4397, 'Big Sky S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208421.mp4', 'http://timg.bdta.pro/images/c95b54d01a373488095bc43dede3f956.jpg'),
(64479, 4397, 'Big Sky S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208422.mp4', 'http://timg.bdta.pro/images/de14c02a846a516e5f7dca0037fb0af4.jpg'),
(64480, 4397, 'Big Sky S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208423.mp4', 'http://timg.bdta.pro/images/0e1dbc91f20389aeebfd7a73edf1dc7a.jpg'),
(64481, 4397, 'Big Sky S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208424.mp4', 'http://timg.bdta.pro/images/a6d304aaeb9025c7e1ad6da4d96f3e85.jpg'),
(64482, 4397, 'Big Sky S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208425.mp4', 'http://timg.bdta.pro/images/385194b9957ac43f636a65ea5ae2d791.jpg'),
(64483, 4397, 'Big Sky S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208426.mp4', 'http://timg.bdta.pro/images/275ae73d809d6838e2454df5b87912e5.jpg'),
(64484, 4397, 'Big Sky S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208427.mp4', 'http://timg.bdta.pro/images/3b8ea54e6dbaf533fd69992266a4e4e0.jpg'),
(64485, 4397, 'Big Sky S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208428.mp4', 'http://timg.bdta.pro/images/2cfad24bdd0f8bba6036064a71c00c22.jpg'),
(64486, 4397, 'Big Sky S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208429.mp4', 'http://timg.bdta.pro/images/ae11fdebbafe6e0790d75be7ae0f1fb9.jpg'),
(64487, 4397, 'Big Sky S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208430.mp4', 'http://timg.bdta.pro/images/df299444b72fbe82c888605cf2edcc28.jpg'),
(64488, 4397, 'Big Sky S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208431.mp4', 'http://timg.bdta.pro/images/daa3b90ca70bd0e66921146a5971632b.jpg'),
(64489, 4397, 'Big Sky S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208432.mp4', 'http://timg.bdta.pro/images/2aafd98369b1393c8c43af1a58ad5dce.jpg'),
(64490, 4397, 'Big Sky S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/208433.mp4', 'http://timg.bdta.pro/images/9d1969f9a3ff6fa9ba79f741decd50f9.jpg'),
(64491, 4397, 'Big Sky S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/208434.mp4', 'http://timg.bdta.pro/images/fc25dad51b12039e8f1b6efae93a2fbc.jpg'),
(64492, 4397, 'Big Sky S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/208435.mp4', 'http://timg.bdta.pro/images/84ba6cd470e90e247e835910531aa8d3.jpg'),
(64493, 4397, 'Big Sky S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/208436.mp4', 'http://timg.bdta.pro/images/94fb07c7f0db2c9b12e86394526e8d55.jpg'),
(64494, 4397, 'Big Sky S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/208437.mp4', 'http://timg.bdta.pro/images/6081f5ef0c09d505170d82296a77dc4e.jpg'),
(64495, 4397, 'Big Sky S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/208438.mp4', 'http://timg.bdta.pro/images/821fc1fb0ef3bc6d5279eaa521c30cd2.jpg'),
(64496, 4398, 'Big Sky S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208439.mp4', 'http://image.tmdb.org/t/p/w1280/bbeUfqnGFrebDoh7bMvUHcl3gBe.jpg'),
(64497, 4398, 'Big Sky S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5S0jpZqnKyuZNRO7nGzKoxy0hK2.jpg'),
(64498, 4398, 'Big Sky S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d9PG4AzfLhkDKInhNTTCWOUwRPg.jpg'),
(64499, 4398, 'Big Sky S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gDcUrzNj0l2kocVy87Mu8PBc8xI.jpg'),
(64500, 4398, 'Big Sky S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/geezq9zkBWs2gt0Wg13x2OA0Qr1.jpg'),
(64501, 4398, 'Big Sky S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zCL0tHHrJyP6izMu0wGoq0J8n1D.jpg'),
(64502, 4398, 'Big Sky S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iGLu6IIMz0q7tmLHRlQVuquaTF.jpg'),
(64503, 4398, 'Big Sky S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208446.mp4', 'http://image.tmdb.org/t/p/w1280/h48zGdWyZunFi5NwxFuHqA33REa.jpg'),
(64504, 4398, 'Big Sky S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208447.mp4', 'http://image.tmdb.org/t/p/w1280/shSh5xsQZyTvNgmqKUfsHs3xoql.jpg'),
(64505, 4398, 'Big Sky S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208448.mp4', 'http://image.tmdb.org/t/p/w1280/zNDkiyY6bxebGihQISKOqwSpVUW.jpg'),
(64506, 4398, 'Big Sky S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208449.mp4', 'http://image.tmdb.org/t/p/w1280/5IAHEs8baA4rWlNbM8dNoT0XVAV.jpg'),
(64507, 4398, 'Big Sky S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208450.mp4', 'http://image.tmdb.org/t/p/w1280/jbF5g5EkM7pYUGbBXPdskWf7eAn.jpg'),
(64508, 4399, 'Devs S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/156539.mp4', 'http://timg.bdta.pro/images/1541d7bbd07599bd686aa1d4aab2b850.jpg'),
(64509, 4399, 'Devs S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/156540.mp4', 'http://timg.bdta.pro/images/6ab049a42466f4388b72e7b829b7a157.jpg'),
(64510, 4399, 'Devs S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/156541.mp4', 'http://timg.bdta.pro/images/51b95ad9bb722b930afd993440b5254e.jpg'),
(64511, 4399, 'Devs S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/156542.mp4', 'http://timg.bdta.pro/images/1c36ed3c9012fada29b5dbb7154a962a.jpg'),
(64512, 4399, 'Devs S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/156543.mp4', 'http://timg.bdta.pro/images/0af32b495378f75c4469bc2d6190d12d.jpg'),
(64513, 4399, 'Devs S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/156544.mp4', 'http://timg.bdta.pro/images/01a4ac4f9996564591866458da4f0ac3.jpg'),
(64514, 4399, 'Devs S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/156545.mp4', 'http://timg.bdta.pro/images/ae5485e8b48db609b3c038bf70664573.jpg'),
(64515, 4399, 'Devs S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/156546.mp4', 'http://timg.bdta.pro/images/a84707efe3f288b55a2abe8c5ddd5727.jpg'),
(64516, 4400, 'Dive Club S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/156527.mp4', 'http://timg.bdta.pro/images/173c5566bcbc46c054e490abebf0e535.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(64517, 4400, 'Dive Club S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/156528.mp4', 'http://timg.bdta.pro/images/d42176754e65f3f108c9a030a3b6ccc5.jpg'),
(64518, 4400, 'Dive Club S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/156529.mp4', 'http://timg.bdta.pro/images/a14f8ae0b7c356283a7578263fad13ca.jpg'),
(64519, 4400, 'Dive Club S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/156530.mp4', 'http://timg.bdta.pro/images/3099a911c90a790c432e705107338a00.jpg'),
(64520, 4400, 'Dive Club S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/156531.mp4', 'http://timg.bdta.pro/images/fe532254b6da06330a169f4e9885d3b3.jpg'),
(64521, 4400, 'Dive Club S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/156532.mp4', 'http://timg.bdta.pro/images/dd581aca156e9fab203b8c5cae440e5f.jpg'),
(64522, 4400, 'Dive Club S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/156533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWwekr6hjERHQ3UYTei2ftWfBTV.jpg'),
(64523, 4400, 'Dive Club S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/156534.mp4', 'http://timg.bdta.pro/images/54e9bf7249186696d62e341d6b85b03a.jpg'),
(64524, 4400, 'Dive Club S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/156535.mp4', 'http://timg.bdta.pro/images/2b79b43fa485d26bb6e8406598f8538a.jpg'),
(64525, 4400, 'Dive Club S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/156536.mp4', 'http://timg.bdta.pro/images/c3c216acef8dacc6f67c60252af60e54.jpg'),
(64526, 4400, 'Dive Club S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/156537.mp4', 'http://timg.bdta.pro/images/526d7c09d9935e2dfb7622a08a89ffcf.jpg'),
(64527, 4400, 'Dive Club S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/156538.mp4', 'http://timg.bdta.pro/images/1f19cb07c7cc43a82932e417df65b323.jpg'),
(64528, 4401, '86 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/156516.mp4', 'http://timg.bdta.pro/images/5425642ccfd9f817ecd7f053a3cd27fc.jpg'),
(64529, 4401, '86 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/156517.mp4', 'http://timg.bdta.pro/images/94037052e9010a6d357fb1c1930a7dae.jpg'),
(64530, 4401, '86 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/156518.mp4', 'http://timg.bdta.pro/images/2577ab59e25f3540bf12e423894b1578.jpg'),
(64531, 4401, '86 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/156519.mp4', 'http://timg.bdta.pro/images/599f83f149f0439528f1175a12e2537e.jpg'),
(64532, 4401, '86 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/156520.mp4', 'http://timg.bdta.pro/images/fb6e4015d21c4f99700a250703e1cae8.jpg'),
(64533, 4401, '86 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/156521.mp4', 'http://timg.bdta.pro/images/872c6dfd02e40383e04991578b25f174.jpg'),
(64534, 4401, '86 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/156522.mp4', 'http://timg.bdta.pro/images/f76df161a48695399878276704a85ff0.jpg'),
(64535, 4401, '86 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/156523.mp4', 'http://timg.bdta.pro/images/150bc8a8021398346cc241ef585cb3ae.jpg'),
(64536, 4401, '86 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/156524.mp4', 'http://timg.bdta.pro/images/a7b77e60d12095bad270f5ad41d3e334.jpg'),
(64537, 4401, '86 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/156525.mp4', 'http://timg.bdta.pro/images/fd0660e255131f431adcf8b6e6e005eb.jpg'),
(64538, 4401, '86 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/156526.mp4', 'http://timg.bdta.pro/images/e2a7a69f6603c1b079741d033652f7f9.jpg'),
(64539, 4402, 'Nani ka? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/156492.mp4', 'http://timg.bdta.pro/images/01a182e9a73ff0f9d5b901ddf31ddab9.jpg'),
(64540, 4402, 'Nani ka? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/156493.mp4', 'http://timg.bdta.pro/images/7f535ddee154839f58c04f1dfd6dd50a.jpg'),
(64541, 4402, 'Nani ka? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/156494.mp4', 'http://timg.bdta.pro/images/efc741405ce28f70920607b5fb97fa16.jpg'),
(64542, 4402, 'Nani ka? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/156495.mp4', 'http://timg.bdta.pro/images/8fa217092115328be3ddbfb6944ac46a.jpg'),
(64543, 4402, 'Nani ka? S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/156496.mp4', 'http://timg.bdta.pro/images/c707d72ee6780c548ae00acdc1142781.jpg'),
(64544, 4402, 'Nani ka? S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/156497.mp4', 'http://timg.bdta.pro/images/0300b8d1ece03670f9365708ba5c90ba.jpg'),
(64545, 4402, 'Nani ka? S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/156498.mp4', 'http://timg.bdta.pro/images/d9cbfefe0fde95ca50693a93d45b43d1.jpg'),
(64546, 4402, 'Nani ka? S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/156499.mp4', 'http://timg.bdta.pro/images/338ca4b626791173356f8b00bd5b6013.jpg'),
(64547, 4402, 'Nani ka? S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/156500.mp4', 'http://timg.bdta.pro/images/f13df4a437bc5f7307abb6de6e2710ef.jpg'),
(64548, 4402, 'Nani ka? S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/156501.mp4', 'http://timg.bdta.pro/images/e1ac3ab4157f77929720cff4e420ab42.jpg'),
(64549, 4402, 'Nani ka? S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/156502.mp4', 'http://timg.bdta.pro/images/a468e483d10fd3aad27857160356c10d.jpg'),
(64550, 4402, 'Nani ka? S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/156503.mp4', 'http://timg.bdta.pro/images/b88b9a6cb65c8fd24325fa4e1b756f4f.jpg'),
(64551, 4402, 'Nani ka? S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/156504.mp4', 'http://timg.bdta.pro/images/104b03c4156211e3ecca5e4aebcf4d50.jpg'),
(64552, 4402, 'Nani ka? S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/156505.mp4', 'http://timg.bdta.pro/images/a7504f7f26a713e95f43d2af0d6b50bb.jpg'),
(64553, 4402, 'Nani ka? S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/156506.mp4', 'http://timg.bdta.pro/images/496c433c1f850a90597e67f0b842dc8e.jpg'),
(64554, 4402, 'Nani ka? S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/156507.mp4', 'http://timg.bdta.pro/images/1474b7ec4d8072275a3ac841bf92c3dd.jpg'),
(64555, 4402, 'Nani ka? S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/156508.mp4', 'http://timg.bdta.pro/images/15bb058fb8a4a4dda4dff6bd05cf0807.jpg'),
(64556, 4402, 'Nani ka? S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/156509.mp4', 'http://timg.bdta.pro/images/64144720e570b4044de2ed51e433787b.jpg'),
(64557, 4402, 'Nani ka? S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/156510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n8oXNIX6WQAyK0DirFuSFlcvYu2.jpg'),
(64558, 4402, 'Nani ka? S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/156511.mp4', 'http://timg.bdta.pro/images/c6503ad46b444840c32cdc87945588c9.jpg'),
(64559, 4402, 'Nani ka? S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/156512.mp4', 'http://timg.bdta.pro/images/1a38e54b0a813802dc0984989a20440f.jpg'),
(64560, 4402, 'Nani ka? S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/156513.mp4', 'http://timg.bdta.pro/images/ff4efb0173c62f9af46b4b1d573e3465.jpg'),
(64561, 4402, 'Nani ka? S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/156514.mp4', 'http://timg.bdta.pro/images/e301c33b2c1e116a9000d9d32c1dfe8b.jpg'),
(64562, 4402, 'Nani ka? S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/156515.mp4', 'http://timg.bdta.pro/images/9f2c7f8bcc593aba5bca4164c09e3582.jpg'),
(64563, 4403, 'Nurses Plantao Enfermagem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/156472.mp4', 'http://timg.bdta.pro/images/55b695db9d25eadca75304c56b139faa.jpg'),
(64564, 4403, 'Nurses Plantao Enfermagem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/156473.mp4', 'http://timg.bdta.pro/images/ea6c949964d2fc155cd65a582f3bf2fa.jpg'),
(64565, 4403, 'Nurses Plantao Enfermagem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/156474.mp4', 'http://timg.bdta.pro/images/477def265877d40f1ffe1f43941ae638.jpg'),
(64566, 4403, 'Nurses Plantao Enfermagem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/156475.mp4', 'http://timg.bdta.pro/images/f90e5f5d6306db5c98ce44a409a31e94.jpg'),
(64567, 4403, 'Nurses Plantao Enfermagem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/156476.mp4', 'http://timg.bdta.pro/images/e8db6c72e4429bc863bf87312cc1c64f.jpg'),
(64568, 4403, 'Nurses Plantao Enfermagem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/156477.mp4', 'http://timg.bdta.pro/images/effee5a2cc31ca9779115b13ddcc4cd7.jpg'),
(64569, 4403, 'Nurses Plantao Enfermagem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/156478.mp4', 'http://timg.bdta.pro/images/d44d079518cf9c124a9b315c680502a2.jpg'),
(64570, 4403, 'Nurses Plantao Enfermagem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/156479.mp4', 'http://timg.bdta.pro/images/dd28ac6e7d8ba096a90f43ca1ab8002b.jpg'),
(64571, 4403, 'Nurses Plantao Enfermagem S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/156480.mp4', 'http://timg.bdta.pro/images/86bd3140405686d62847d91f3102cc54.jpg'),
(64572, 4403, 'Nurses Plantao Enfermagem S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/156481.mp4', 'http://timg.bdta.pro/images/2879066a5e24218939e9b9386fece213.jpg'),
(64573, 4404, 'Nurses Plantao Enfermagem S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/156482.mp4', 'http://timg.bdta.pro/images/d4f34b4c1b7739f2b9ea6c1468b0c7b5.jpg'),
(64574, 4404, 'Nurses Plantao Enfermagem S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/156483.mp4', 'http://gstaticontent.com/images/41b88476ccee7bd3b384f737cf1d4d74.jpg'),
(64575, 4404, 'Nurses Plantao Enfermagem S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/156484.mp4', 'http://gstaticontent.com/images/41b88476ccee7bd3b384f737cf1d4d74.jpg'),
(64576, 4404, 'Nurses Plantao Enfermagem S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/156485.mp4', 'http://gstaticontent.com/images/41b88476ccee7bd3b384f737cf1d4d74.jpg'),
(64577, 4404, 'Nurses Plantao Enfermagem S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/156486.mp4', 'http://gstaticontent.com/images/41b88476ccee7bd3b384f737cf1d4d74.jpg'),
(64578, 4404, 'Nurses Plantao Enfermagem S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/156487.mp4', 'http://gstaticontent.com/images/41b88476ccee7bd3b384f737cf1d4d74.jpg'),
(64579, 4404, 'Nurses Plantao Enfermagem S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/156488.mp4', 'http://gstaticontent.com/images/41b88476ccee7bd3b384f737cf1d4d74.jpg'),
(64580, 4404, 'Nurses Plantao Enfermagem S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/156489.mp4', 'http://gstaticontent.com/images/41b88476ccee7bd3b384f737cf1d4d74.jpg'),
(64581, 4404, 'Nurses Plantao Enfermagem S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/156490.mp4', 'http://gstaticontent.com/images/41b88476ccee7bd3b384f737cf1d4d74.jpg'),
(64582, 4404, 'Nurses Plantao Enfermagem S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/156491.mp4', 'http://gstaticontent.com/images/41b88476ccee7bd3b384f737cf1d4d74.jpg'),
(64583, 4405, 'Ponto de Virada: 11/9 e a Guerra contra o Terror S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/156467.mp4', 'http://gstaticontent.com/images/ad0d12749937bfeb3e37dbbd45da9188.jpg'),
(64584, 4405, 'Ponto de Virada: 11/9 e a Guerra contra o Terror S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/156468.mp4', 'http://gstaticontent.com/images/ad0d12749937bfeb3e37dbbd45da9188.jpg'),
(64585, 4405, 'Ponto de Virada: 11/9 e a Guerra contra o Terror S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/156469.mp4', 'http://gstaticontent.com/images/ad0d12749937bfeb3e37dbbd45da9188.jpg'),
(64586, 4405, 'Ponto de Virada: 11/9 e a Guerra contra o Terror S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/156470.mp4', 'http://gstaticontent.com/images/ad0d12749937bfeb3e37dbbd45da9188.jpg'),
(64587, 4405, 'Ponto de Virada: 11/9 e a Guerra contra o Terror S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/156471.mp4', 'http://gstaticontent.com/images/ad0d12749937bfeb3e37dbbd45da9188.jpg'),
(64588, 4406, 'Shiranai Uchi ni Level Max ni Nattemashita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/156455.mp4', 'http://timg.bdta.pro/images/7c417ce9dbb9eb36afcb9d977f47837b.jpg'),
(64589, 4406, 'Shiranai Uchi ni Level Max ni Nattemashita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/156456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkOV8AZ6zHsvtING60IloP9lttI.jpg'),
(64590, 4406, 'Shiranai Uchi ni Level Max ni Nattemashita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/156457.mp4', 'http://timg.bdta.pro/images/4488f67db6e7d9b685d46fa68e941150.jpg'),
(64591, 4406, 'Shiranai Uchi ni Level Max ni Nattemashita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/156458.mp4', 'http://timg.bdta.pro/images/1355e93b8bbab8cc0f3ad378fbac077c.jpg'),
(64592, 4406, 'Shiranai Uchi ni Level Max ni Nattemashita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/156459.mp4', 'http://timg.bdta.pro/images/e87277c00b28460c9b8b458f44b570ed.jpg'),
(64593, 4406, 'Shiranai Uchi ni Level Max ni Nattemashita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/156460.mp4', 'http://timg.bdta.pro/images/58bf830f67317cf13e9322a0152deae9.jpg'),
(64594, 4406, 'Shiranai Uchi ni Level Max ni Nattemashita S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/156461.mp4', 'http://timg.bdta.pro/images/5b045a4aaab1e79cf05c1e1f42988661.jpg'),
(64595, 4406, 'Shiranai Uchi ni Level Max ni Nattemashita S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/156462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dykcR4kn2rIGH95QX4udASvAhqN.jpg'),
(64596, 4406, 'Shiranai Uchi ni Level Max ni Nattemashita S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/156463.mp4', 'http://timg.bdta.pro/images/25a7f5118276ff74d92802e592dc4744.jpg'),
(64597, 4406, 'Shiranai Uchi ni Level Max ni Nattemashita S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/156464.mp4', 'http://timg.bdta.pro/images/7bd72f986372e0952034615668f90d84.jpg'),
(64598, 4406, 'Shiranai Uchi ni Level Max ni Nattemashita S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/156465.mp4', 'http://timg.bdta.pro/images/bd8a113d15e3538a00ee22e79e3c7929.jpg'),
(64599, 4406, 'Shiranai Uchi ni Level Max ni Nattemashita S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/156466.mp4', 'http://timg.bdta.pro/images/bfedeba30bfa7644a054a4eaf9ba87d2.jpg'),
(64600, 4407, 'Shiranai Uchi ni Level Max ni Nattemashita S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/878951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQAf2lEzlrl4prYbdsRdUiWkQVN.jpg'),
(64601, 4407, 'Shiranai Uchi ni Level Max ni Nattemashita S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/878952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/prcO26gWNZWOAj5FSMeLKz0xglf.jpg'),
(64602, 4408, 'Tubacão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210768.mp4', 'http://gstaticontent.com/images/c0bc40c177acc7086971ecaf02410d22.jpg'),
(64603, 4408, 'Tubacão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210769.mp4', 'http://gstaticontent.com/images/c0bc40c177acc7086971ecaf02410d22.jpg'),
(64604, 4408, 'Tubacão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210770.mp4', 'http://gstaticontent.com/images/c0bc40c177acc7086971ecaf02410d22.jpg'),
(64605, 4408, 'Tubacão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210771.mp4', 'http://gstaticontent.com/images/c0bc40c177acc7086971ecaf02410d22.jpg'),
(64606, 4408, 'Tubacão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210772.mp4', 'http://gstaticontent.com/images/c0bc40c177acc7086971ecaf02410d22.jpg'),
(64607, 4408, 'Tubacão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210773.mp4', 'http://gstaticontent.com/images/c0bc40c177acc7086971ecaf02410d22.jpg'),
(64608, 4408, 'Tubacão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210774.mp4', 'http://gstaticontent.com/images/c0bc40c177acc7086971ecaf02410d22.jpg'),
(64609, 4409, 'Tubacão S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sEXFjeuOzirP803rVgXFQS2qnh5.jpg'),
(64610, 4409, 'Tubacão S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q9gWO1VoGlvnMV77Tr7VF3tsJ6G.jpg'),
(64611, 4409, 'Tubacão S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jkP1IlWdB2g9XdF5UEiNTFdCb1A.jpg'),
(64612, 4409, 'Tubacão S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uKrZWWJJizlH8J2mPNsfM0GZuzh.jpg'),
(64613, 4409, 'Tubacão S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rUSeMjCqdiwdLvL0nJptwFmuX8x.jpg'),
(64614, 4409, 'Tubacão S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e3j59Wai555Uf5GMGVAijiJL6sg.jpg'),
(64615, 4409, 'Tubacão S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svijyq44XqSlW6S0SJFjoR9pjlk.jpg'),
(64616, 4410, 'Tubacão S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDpBMMyfzIlOsrR5c5HYmo7HcZB.jpg'),
(64617, 4410, 'Tubacão S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5UpOT6mU1AVLFsrktAtV2Q9t3T.jpg'),
(64618, 4410, 'Tubacão S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i9uUBomLw0cmbmrHNbke62tHXwA.jpg'),
(64619, 4410, 'Tubacão S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZr5K1dpfih8EMpmM0FVSfEA9vE.jpg'),
(64620, 4410, 'Tubacão S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kCFMKmXxbIK5fn9sFyxf4b6t1bn.jpg'),
(64621, 4410, 'Tubacão S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mlem7TmCcqVDS1kcThpsRWOHWZs.jpg'),
(64622, 4411, 'You\'re the Worst S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/156393.mp4', 'http://timg.bdta.pro/images/97b9ab973c87f77f30861a85d4d0b6ab.jpg'),
(64623, 4411, 'You\'re the Worst S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/156394.mp4', 'http://timg.bdta.pro/images/d6fe3ca0e37e5fd78cfa201d37e4bade.jpg'),
(64624, 4411, 'You\'re the Worst S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/156395.mp4', 'http://timg.bdta.pro/images/dcf21e92c5c69c7a22935d40569dfdd0.jpg'),
(64625, 4411, 'You\'re the Worst S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/156396.mp4', 'http://timg.bdta.pro/images/67e4e1e0a294c6298d7df10639926d72.jpg'),
(64626, 4411, 'You\'re the Worst S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/156397.mp4', 'http://timg.bdta.pro/images/e0097a690f5401f81369b12017554b9b.jpg'),
(64627, 4411, 'You\'re the Worst S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/156398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kZepvQ5zkHFUotnHLwvNK01JHR.jpg'),
(64628, 4411, 'You\'re the Worst S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/156399.mp4', 'http://timg.bdta.pro/images/36d055a87f5852ef08227e6e4d6f57d4.jpg'),
(64629, 4411, 'You\'re the Worst S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/156400.mp4', 'http://timg.bdta.pro/images/eb038ed62fee79d58fbeaca57e0dd703.jpg'),
(64630, 4411, 'You\'re the Worst S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/156401.mp4', 'http://timg.bdta.pro/images/b14fc4a21e705b06b0834d20976d800c.jpg'),
(64631, 4411, 'You\'re the Worst S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/156402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hV9lkYocjXjWV5VUFQuoMNT2DeP.jpg'),
(64632, 4412, 'You\'re the Worst S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/156403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fNrp2XyX6xkcaJVYCDOoS36YZKt.jpg'),
(64633, 4412, 'You\'re the Worst S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/156404.mp4', 'http://timg.bdta.pro/images/5787e53a51889f7f827a65d2447888fd.jpg'),
(64634, 4412, 'You\'re the Worst S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/156405.mp4', 'http://timg.bdta.pro/images/b3ee24e1ad284f67b0e506e1ed1f48b8.jpg'),
(64635, 4412, 'You\'re the Worst S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/156406.mp4', 'http://timg.bdta.pro/images/b06087dc9e337fcbd5f5708ed767cf35.jpg'),
(64636, 4412, 'You\'re the Worst S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/156407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/msF8jtB6KechlS4zcfAkXadZTO1.jpg'),
(64637, 4412, 'You\'re the Worst S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/156408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7tAxLe18x7yrtLm9pxEuQny2ZDW.jpg'),
(64638, 4412, 'You\'re the Worst S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/156409.mp4', 'http://timg.bdta.pro/images/9cfff4dccb003256770e6e459ee495a1.jpg'),
(64639, 4412, 'You\'re the Worst S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/156410.mp4', 'http://timg.bdta.pro/images/b376f09e4eb30c1dfd1d04cd166e48db.jpg'),
(64640, 4412, 'You\'re the Worst S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/156411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jWGNsi6kM2bXeNyfO1xp0HPKFtZ.jpg'),
(64641, 4412, 'You\'re the Worst S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/156412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mpKMwanMp1EfyKngSZ7aeEYxOpp.jpg'),
(64642, 4412, 'You\'re the Worst S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/156413.mp4', 'http://timg.bdta.pro/images/5ea311276396b6e2d553448d5938f8c8.jpg'),
(64643, 4412, 'You\'re the Worst S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/156414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m83COezrYNCVXO0SwxCiu2Nk1kS.jpg'),
(64644, 4412, 'You\'re the Worst S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/156415.mp4', 'http://timg.bdta.pro/images/3769f67c32e4b42206f0b716b4344a83.jpg'),
(64645, 4413, 'You\'re the Worst S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/156416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Ex5Dz5Z1NxogsepLhxKkUC4E4.jpg'),
(64646, 4413, 'You\'re the Worst S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/156417.mp4', 'http://timg.bdta.pro/images/db2abc200a9261d5d31da0541f64b900.jpg'),
(64647, 4413, 'You\'re the Worst S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/156418.mp4', 'http://timg.bdta.pro/images/f3a24fe45a7c8752c27ed2e3af3baea1.jpg'),
(64648, 4413, 'You\'re the Worst S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/156419.mp4', 'http://timg.bdta.pro/images/9490075db7ea07cf33ed9b64ea34a0bc.jpg'),
(64649, 4413, 'You\'re the Worst S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/156420.mp4', 'http://timg.bdta.pro/images/b2b1ee2261832f037515b5d75fdde13b.jpg'),
(64650, 4413, 'You\'re the Worst S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/156421.mp4', 'http://timg.bdta.pro/images/ea109da320df92fe748e6965cc9b206f.jpg'),
(64651, 4413, 'You\'re the Worst S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/156422.mp4', 'http://timg.bdta.pro/images/5fa794b8a8a30a6f62022d1ce0c15182.jpg'),
(64652, 4413, 'You\'re the Worst S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/156423.mp4', 'http://timg.bdta.pro/images/2bc77661df55ac510566038d45417208.jpg'),
(64653, 4413, 'You\'re the Worst S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/156424.mp4', 'http://timg.bdta.pro/images/162bb621a726b58ef9f9e1098fbd7339.jpg'),
(64654, 4413, 'You\'re the Worst S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/156425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vCgCvUc6p4CuCcE73ZTmEnlzdKN.jpg'),
(64655, 4413, 'You\'re the Worst S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/156426.mp4', 'http://timg.bdta.pro/images/2a0154463b40bcac4f8d1cad7d50e1fc.jpg'),
(64656, 4413, 'You\'re the Worst S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/156427.mp4', 'http://timg.bdta.pro/images/5f0a585faa8d886c7bb09a0049f8d28e.jpg'),
(64657, 4413, 'You\'re the Worst S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/156428.mp4', 'http://timg.bdta.pro/images/07531932a94d425cdc28a9d8c792df16.jpg'),
(64658, 4414, 'You\'re the Worst S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/156429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lChB3z7Oc9IOJ7ngZ77iVbIQ426.jpg'),
(64659, 4414, 'You\'re the Worst S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/156430.mp4', 'http://timg.bdta.pro/images/22f9c92802c79bdb57942e14da33cf7b.jpg'),
(64660, 4414, 'You\'re the Worst S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/156431.mp4', 'http://timg.bdta.pro/images/17dce83bf2d23beea864f590b17d3671.jpg'),
(64661, 4414, 'You\'re the Worst S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/156432.mp4', 'http://timg.bdta.pro/images/59e21641ef930fa1c81cb00664fb9153.jpg'),
(64662, 4414, 'You\'re the Worst S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/156433.mp4', 'http://timg.bdta.pro/images/7803e740d39d7701fbd0d61446e54bd2.jpg'),
(64663, 4414, 'You\'re the Worst S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/156434.mp4', 'http://timg.bdta.pro/images/4a9ae7cfb0037b9f1526c5c1ac46c419.jpg'),
(64664, 4414, 'You\'re the Worst S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/156435.mp4', 'http://timg.bdta.pro/images/d73107fad05664b6073367f1eada5e0e.jpg'),
(64665, 4414, 'You\'re the Worst S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/156436.mp4', 'http://timg.bdta.pro/images/52b1149e5e75444fd4639b97b53f2545.jpg'),
(64666, 4414, 'You\'re the Worst S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/156437.mp4', 'http://timg.bdta.pro/images/7194cb12223db3225725bd6282b2d487.jpg'),
(64667, 4414, 'You\'re the Worst S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/156438.mp4', 'http://timg.bdta.pro/images/d3f2fbc507731969a89ef9fae90ba69e.jpg'),
(64668, 4414, 'You\'re the Worst S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/156439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFr9kIIN8i3BCoTGaOAvYkFH5rg.jpg'),
(64669, 4414, 'You\'re the Worst S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/156440.mp4', 'http://timg.bdta.pro/images/39807eb7c0ad172884d7c88b588120d2.jpg'),
(64670, 4414, 'You\'re the Worst S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/156441.mp4', 'http://timg.bdta.pro/images/8afc3efa0c05ecbb17d03dcba3660e4c.jpg'),
(64671, 4415, 'You\'re the Worst S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/156442.mp4', 'http://timg.bdta.pro/images/16e8419f062503a807e2d4bd62492f4b.jpg'),
(64672, 4415, 'You\'re the Worst S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/156443.mp4', 'http://timg.bdta.pro/images/fac3c70a0150ceb0cec12f1d6b11e5c4.jpg'),
(64673, 4415, 'You\'re the Worst S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/156444.mp4', 'http://timg.bdta.pro/images/a9f0219fc9c5b4d0c720bb79d036d861.jpg'),
(64674, 4415, 'You\'re the Worst S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/156445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y0m859iaHv7q6OdMmVuPe60SXIJ.jpg'),
(64675, 4415, 'You\'re the Worst S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/156446.mp4', 'http://timg.bdta.pro/images/0c3121de6eb69cb737a9d03139f84b1d.jpg'),
(64676, 4415, 'You\'re the Worst S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/156447.mp4', 'http://timg.bdta.pro/images/63a0ea0c1a70e9603277b7eb69cdafc3.jpg'),
(64677, 4415, 'You\'re the Worst S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/156448.mp4', 'http://timg.bdta.pro/images/492da7bbbd543fc906221044f3d5099d.jpg'),
(64678, 4415, 'You\'re the Worst S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/156449.mp4', 'http://timg.bdta.pro/images/ccd23fd97435c77b65d32105ac093343.jpg'),
(64679, 4415, 'You\'re the Worst S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/156450.mp4', 'http://timg.bdta.pro/images/1822de13f9ee3d6f4d19392f97c0a00a.jpg'),
(64680, 4415, 'You\'re the Worst S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/156451.mp4', 'http://timg.bdta.pro/images/27f1fead1cd1a69c326b4575db2a876e.jpg'),
(64681, 4415, 'You\'re the Worst S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/156452.mp4', 'http://timg.bdta.pro/images/3e3673cdce28c5761b3ed8d3407e1fa1.jpg'),
(64682, 4415, 'You\'re the Worst S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/156453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2u5d9Zrl6jPcp7rbyVcPD6jpWhz.jpg'),
(64683, 4415, 'You\'re the Worst S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/156454.mp4', 'http://timg.bdta.pro/images/0fd733c19e7b831968d711780b502d04.jpg'),
(64684, 4416, '100 Days Wild S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155471.mp4', 'http://gstaticontent.com/images/a30302aa15a7550488cbec8d0485a095.jpg'),
(64685, 4416, '100 Days Wild S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155472.mp4', 'http://gstaticontent.com/images/a30302aa15a7550488cbec8d0485a095.jpg'),
(64686, 4416, '100 Days Wild S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155473.mp4', 'http://gstaticontent.com/images/a30302aa15a7550488cbec8d0485a095.jpg'),
(64687, 4416, '100 Days Wild S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155474.mp4', 'http://gstaticontent.com/images/a30302aa15a7550488cbec8d0485a095.jpg'),
(64688, 4416, '100 Days Wild S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155475.mp4', 'http://gstaticontent.com/images/a30302aa15a7550488cbec8d0485a095.jpg'),
(64689, 4416, '100 Days Wild S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155476.mp4', 'http://gstaticontent.com/images/a30302aa15a7550488cbec8d0485a095.jpg'),
(64690, 4416, '100 Days Wild S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/155477.mp4', 'http://gstaticontent.com/images/a30302aa15a7550488cbec8d0485a095.jpg'),
(64691, 4416, '100 Days Wild S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/155478.mp4', 'http://gstaticontent.com/images/a30302aa15a7550488cbec8d0485a095.jpg'),
(64692, 4417, 'À Beira do Caos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155459.mp4', 'http://timg.bdta.pro/images/fabcf67309e76708437700f8fdda3ef4.jpg'),
(64693, 4417, 'À Beira do Caos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155460.mp4', 'http://timg.bdta.pro/images/5a02cbe9cf68f4efe025b2dc39c175d8.jpg'),
(64694, 4417, 'À Beira do Caos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155461.mp4', 'http://timg.bdta.pro/images/328b28b2521508d73fc6c54f9ba79e5c.jpg'),
(64695, 4417, 'À Beira do Caos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155462.mp4', 'http://timg.bdta.pro/images/4c6e4dcacb41b0c9ae3ff28f27b3ef82.jpg'),
(64696, 4417, 'À Beira do Caos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155463.mp4', 'http://timg.bdta.pro/images/5257ad0fb769471f851e764ad4e06bcb.jpg'),
(64697, 4417, 'À Beira do Caos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155464.mp4', 'http://timg.bdta.pro/images/23e498d6377b42df0b5a6c319881c630.jpg'),
(64698, 4417, 'À Beira do Caos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/155465.mp4', 'http://timg.bdta.pro/images/5b2f9378570787187af8f9c85a1c8287.jpg'),
(64699, 4417, 'À Beira do Caos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/155466.mp4', 'http://timg.bdta.pro/images/3d6249c727a4b7e2c2d9498d715a6153.jpg'),
(64700, 4417, 'À Beira do Caos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/155467.mp4', 'http://timg.bdta.pro/images/8aed3f7c332befe863c4d1b6168161a1.jpg'),
(64701, 4417, 'À Beira do Caos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/155468.mp4', 'http://timg.bdta.pro/images/d4d0ebf32020c06684bf2a2d4cf9aa38.jpg'),
(64702, 4417, 'À Beira do Caos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/155469.mp4', 'http://timg.bdta.pro/images/b13098877034458d9f3fc599320f294d.jpg'),
(64703, 4417, 'À Beira do Caos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/155470.mp4', 'http://timg.bdta.pro/images/8477b2bb4edf803133cf51bff1f78c5a.jpg'),
(64704, 4418, 'Agente 86 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155321.mp4', 'http://timg.bdta.pro/images/3f1791a773a2bd6d128fa1b7cb6ffee9.jpg'),
(64705, 4418, 'Agente 86 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155322.mp4', 'http://timg.bdta.pro/images/cf2064554a2c1ea7e3e07efc1eda8ef0.jpg'),
(64706, 4418, 'Agente 86 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155323.mp4', 'http://timg.bdta.pro/images/60a2f11cdddde7ad5127b29b1824489c.jpg'),
(64707, 4418, 'Agente 86 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155324.mp4', 'http://timg.bdta.pro/images/44e566703d0d12b9bc7bb2e6b6df3842.jpg'),
(64708, 4418, 'Agente 86 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155325.mp4', 'http://timg.bdta.pro/images/ec0e9d879c0efe312221edd57c988910.jpg'),
(64709, 4418, 'Agente 86 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155326.mp4', 'http://timg.bdta.pro/images/06bf2b4e59f5f1c5901226c55ae4b66f.jpg'),
(64710, 4418, 'Agente 86 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/155327.mp4', 'http://timg.bdta.pro/images/179f3c0c2bd7c32ccbd35fbe70a2ad06.jpg'),
(64711, 4418, 'Agente 86 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/155328.mp4', 'http://timg.bdta.pro/images/dae98a299edd5b25c2a4874db2b283fb.jpg'),
(64712, 4418, 'Agente 86 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/155329.mp4', 'http://timg.bdta.pro/images/32bbf68b68227ef82cb3f3fdc5cf53e5.jpg'),
(64713, 4418, 'Agente 86 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/155330.mp4', 'http://timg.bdta.pro/images/74ba4ac732ddadbad686f46c851a7847.jpg'),
(64714, 4418, 'Agente 86 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/155331.mp4', 'http://timg.bdta.pro/images/5f8700fde97db6966e3c326116d05c01.jpg'),
(64715, 4418, 'Agente 86 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/155332.mp4', 'http://timg.bdta.pro/images/d2598b46db658cce2dabaf93067dc1d5.jpg'),
(64716, 4418, 'Agente 86 S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/155333.mp4', 'http://timg.bdta.pro/images/5fb2124a0dbb23603cfed84647309156.jpg'),
(64717, 4418, 'Agente 86 S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/155334.mp4', 'http://timg.bdta.pro/images/973879cf572b574e0cb1fc3c9150193d.jpg'),
(64718, 4418, 'Agente 86 S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/155335.mp4', 'http://timg.bdta.pro/images/0af54e7f35c52e6ecf72f7f3c32552ee.jpg'),
(64719, 4418, 'Agente 86 S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/155336.mp4', 'http://timg.bdta.pro/images/e85be5caf080f80f8288f1f71e927764.jpg'),
(64720, 4418, 'Agente 86 S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/155337.mp4', 'http://timg.bdta.pro/images/d8dadb2d8d6460ed1e46451719916bf2.jpg'),
(64721, 4418, 'Agente 86 S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/155338.mp4', 'http://timg.bdta.pro/images/42f71c12036449c2d12bcb1f5b1e3178.jpg'),
(64722, 4418, 'Agente 86 S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/155339.mp4', 'http://timg.bdta.pro/images/166b3cf9b1c86b29a1624d18b2d0b5c3.jpg'),
(64723, 4418, 'Agente 86 S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/155340.mp4', 'http://timg.bdta.pro/images/71d5ba37fde78866595e369c2ab27a9f.jpg'),
(64724, 4418, 'Agente 86 S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/155341.mp4', 'http://timg.bdta.pro/images/d24805c7a85c67eb5b63b2ea37fb6b69.jpg'),
(64725, 4418, 'Agente 86 S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/155342.mp4', 'http://timg.bdta.pro/images/c7ef03ada8668448697e73c499c4fc81.jpg'),
(64726, 4418, 'Agente 86 S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/155343.mp4', 'http://timg.bdta.pro/images/db855058f25f069577957c1656145efd.jpg'),
(64727, 4418, 'Agente 86 S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/155344.mp4', 'http://timg.bdta.pro/images/c992dfd64cb20b28c4667b70db35767c.jpg'),
(64728, 4418, 'Agente 86 S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/155345.mp4', 'http://timg.bdta.pro/images/24c3580931717475b9541c25fe7a54b6.jpg'),
(64729, 4418, 'Agente 86 S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/155346.mp4', 'http://timg.bdta.pro/images/7229612882d21b8995b889444cfb1892.jpg'),
(64730, 4418, 'Agente 86 S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/155347.mp4', 'http://timg.bdta.pro/images/2feacda0b89f4de20118aee17d121674.jpg'),
(64731, 4418, 'Agente 86 S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/155348.mp4', 'http://timg.bdta.pro/images/d7e72e9479db25dee9c1f7f99beb7f2d.jpg'),
(64732, 4418, 'Agente 86 S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/155349.mp4', 'http://timg.bdta.pro/images/37ae00c474823c6cf1bd75a02e608d65.jpg'),
(64733, 4418, 'Agente 86 S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/155350.mp4', 'http://timg.bdta.pro/images/664319694ee7056293e2e7930ea13878.jpg'),
(64734, 4419, 'Agente 86 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155351.mp4', 'http://timg.bdta.pro/images/f356ee1b03644c1308665fbdeb2ca8b0.jpg'),
(64735, 4419, 'Agente 86 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155352.mp4', 'http://timg.bdta.pro/images/c82a7899d0f43cb30f3b882e4981542f.jpg'),
(64736, 4419, 'Agente 86 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155353.mp4', 'http://timg.bdta.pro/images/983301e0edeb78f205d4717428e04be5.jpg'),
(64737, 4419, 'Agente 86 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155354.mp4', 'http://timg.bdta.pro/images/9d976ee7f61776628416e2677993e8ee.jpg'),
(64738, 4419, 'Agente 86 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155355.mp4', 'http://timg.bdta.pro/images/75afd53c6db03a0fe0783b7e8d77746b.jpg'),
(64739, 4419, 'Agente 86 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155356.mp4', 'http://timg.bdta.pro/images/b9ebc8e053e564946368555e77863405.jpg'),
(64740, 4419, 'Agente 86 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/155357.mp4', 'http://timg.bdta.pro/images/1c37c9b6f558c1fd6845abf8cba2ea5e.jpg'),
(64741, 4419, 'Agente 86 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/155358.mp4', 'http://timg.bdta.pro/images/0ad67aa1dbdfd44d8a7ca1c1e436513f.jpg'),
(64742, 4419, 'Agente 86 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/155359.mp4', 'http://timg.bdta.pro/images/9bc23ab3e3e13e4b853ecee292bf8475.jpg'),
(64743, 4419, 'Agente 86 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/155360.mp4', 'http://timg.bdta.pro/images/a2ded260ea9e3af3f4f7ec8c62b66c31.jpg'),
(64744, 4419, 'Agente 86 S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/155361.mp4', 'http://timg.bdta.pro/images/91813037ae8bc62b2686b29cc9387a0a.jpg'),
(64745, 4419, 'Agente 86 S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/155362.mp4', 'http://timg.bdta.pro/images/3788fe00c22dfb9f9060d7ec39b85529.jpg'),
(64746, 4419, 'Agente 86 S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/155363.mp4', 'http://timg.bdta.pro/images/68f9f9771d6175b010b8e3d011c860ab.jpg'),
(64747, 4419, 'Agente 86 S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/155364.mp4', 'http://timg.bdta.pro/images/b2a5a2a6b4b6cd092f17fcc7922c8b6a.jpg'),
(64748, 4419, 'Agente 86 S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/155365.mp4', 'http://timg.bdta.pro/images/12c18f5f192b2a74688b1df0de89b849.jpg'),
(64749, 4419, 'Agente 86 S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/155366.mp4', 'http://timg.bdta.pro/images/12286ae6c6ec49171b3864487f0fe796.jpg'),
(64750, 4419, 'Agente 86 S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/155367.mp4', 'http://timg.bdta.pro/images/4a4c4a8696b20645c5492d79d8439593.jpg'),
(64751, 4419, 'Agente 86 S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/155368.mp4', 'http://timg.bdta.pro/images/1f2dc76022c824262719d57d883be6cf.jpg'),
(64752, 4419, 'Agente 86 S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/155369.mp4', 'http://timg.bdta.pro/images/eeda30da1c0d3cb87778dfc0670963a1.jpg'),
(64753, 4419, 'Agente 86 S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/155370.mp4', 'http://timg.bdta.pro/images/bc58707a708f817afd5e3729193979ac.jpg'),
(64754, 4419, 'Agente 86 S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/155371.mp4', 'http://timg.bdta.pro/images/4cd8e93000bc0b8ea75859626ca68a26.jpg'),
(64755, 4419, 'Agente 86 S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/155372.mp4', 'http://timg.bdta.pro/images/4275c26b0c5f855966a9deb0b4fb93f6.jpg'),
(64756, 4419, 'Agente 86 S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/155373.mp4', 'http://timg.bdta.pro/images/cc23129d862305f9101532f46c284b6b.jpg'),
(64757, 4419, 'Agente 86 S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/155374.mp4', 'http://timg.bdta.pro/images/7d54bf1c95197d8eeaebfbb28aece35c.jpg'),
(64758, 4419, 'Agente 86 S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/155375.mp4', 'http://timg.bdta.pro/images/77404fc64d18a79a071c0a7fe165487f.jpg'),
(64759, 4419, 'Agente 86 S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/155376.mp4', 'http://timg.bdta.pro/images/1af8ff4be37872fe36800ad2da5c106c.jpg'),
(64760, 4419, 'Agente 86 S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/155377.mp4', 'http://timg.bdta.pro/images/7eb5249e24e59adae155d4ccdc132152.jpg'),
(64761, 4419, 'Agente 86 S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/155378.mp4', 'http://timg.bdta.pro/images/9327f3373c3badfc60a5acbac9695d4c.jpg'),
(64762, 4419, 'Agente 86 S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/155379.mp4', 'http://timg.bdta.pro/images/4d0291436b1380f62ea168c6abac1980.jpg'),
(64763, 4419, 'Agente 86 S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/155380.mp4', 'http://timg.bdta.pro/images/c4cbc4fe7b88669199aa011aae3d253e.jpg'),
(64764, 4420, 'Agente 86 S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155381.mp4', 'http://timg.bdta.pro/images/d4606f7b9211290112897bdfe15e9afe.jpg'),
(64765, 4420, 'Agente 86 S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155382.mp4', 'http://timg.bdta.pro/images/75a4dc424fa6c47e5b82efe9f8b3df43.jpg'),
(64766, 4420, 'Agente 86 S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155383.mp4', 'http://timg.bdta.pro/images/78394f82a3790e73ffefad42a536cc56.jpg'),
(64767, 4420, 'Agente 86 S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155384.mp4', 'http://timg.bdta.pro/images/8b495be281c920195281aea4e3862e63.jpg'),
(64768, 4420, 'Agente 86 S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155385.mp4', 'http://timg.bdta.pro/images/3d954e6e25a8b7dd4fec8671d061781b.jpg'),
(64769, 4420, 'Agente 86 S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155386.mp4', 'http://timg.bdta.pro/images/c299d83deffa44d96a839c275a27ec3d.jpg'),
(64770, 4420, 'Agente 86 S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/155387.mp4', 'http://timg.bdta.pro/images/e19eea9fd53efb82737e432912880e2a.jpg'),
(64771, 4420, 'Agente 86 S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/155388.mp4', 'http://timg.bdta.pro/images/276db52b61eec36992a1633401e8e30e.jpg'),
(64772, 4420, 'Agente 86 S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/155389.mp4', 'http://timg.bdta.pro/images/deb919479af30c36c572ea617925440e.jpg'),
(64773, 4420, 'Agente 86 S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/155390.mp4', 'http://timg.bdta.pro/images/53be328f8d96bb0b30927c5f6baf4d96.jpg'),
(64774, 4420, 'Agente 86 S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/155391.mp4', 'http://timg.bdta.pro/images/547a0ebcbc59cf919739d89a090e807b.jpg'),
(64775, 4420, 'Agente 86 S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/155392.mp4', 'http://timg.bdta.pro/images/bffb32577cc8e200926832c08539f48d.jpg'),
(64776, 4420, 'Agente 86 S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/155393.mp4', 'http://timg.bdta.pro/images/70ec9c6b980282f1ea1e3b9a0a3182e8.jpg'),
(64777, 4420, 'Agente 86 S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/155394.mp4', 'http://timg.bdta.pro/images/13ae20017141425837986e30b4e0e9c7.jpg'),
(64778, 4420, 'Agente 86 S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/155395.mp4', 'http://timg.bdta.pro/images/ecea42230ea55e84464fcc2fa3f3c648.jpg'),
(64779, 4420, 'Agente 86 S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/155396.mp4', 'http://timg.bdta.pro/images/5ad35c05993decb7bd7e749418ac8b59.jpg'),
(64780, 4420, 'Agente 86 S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/155397.mp4', 'http://timg.bdta.pro/images/9e29c9705837fc43e2ddcca216bc8204.jpg'),
(64781, 4420, 'Agente 86 S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/155398.mp4', 'http://timg.bdta.pro/images/d38b192c3a6f75d1b94515a5a5e229b4.jpg'),
(64782, 4420, 'Agente 86 S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/155399.mp4', 'http://timg.bdta.pro/images/b6622db55badaae95b050ac1f48b3a09.jpg'),
(64783, 4420, 'Agente 86 S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/155400.mp4', 'http://timg.bdta.pro/images/184d7b2f2f5987dfb481062a67467b46.jpg'),
(64784, 4420, 'Agente 86 S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/155401.mp4', 'http://timg.bdta.pro/images/33ad561a1537e41cf3d80953ce33afac.jpg'),
(64785, 4420, 'Agente 86 S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/155402.mp4', 'http://timg.bdta.pro/images/862e406dae9d76eefd2be8424e62d7f1.jpg'),
(64786, 4420, 'Agente 86 S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/155403.mp4', 'http://timg.bdta.pro/images/8e514fa93f3084920499975e9e259a1a.jpg'),
(64787, 4420, 'Agente 86 S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/155404.mp4', 'http://timg.bdta.pro/images/79d5f3ff38c1acbb31ba34de56aba6ee.jpg'),
(64788, 4420, 'Agente 86 S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/155405.mp4', 'http://timg.bdta.pro/images/ad0c7fbdaa9e18c8456b58097e8b2fbb.jpg'),
(64789, 4420, 'Agente 86 S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/155406.mp4', 'http://timg.bdta.pro/images/ea71d38d6e3a54ab4dd516c3e6f127e8.jpg'),
(64790, 4421, 'Agente 86 S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155407.mp4', 'http://timg.bdta.pro/images/8814b0fe644825a5072c4181ade60df5.jpg'),
(64791, 4421, 'Agente 86 S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155408.mp4', 'http://timg.bdta.pro/images/f1a8f0b1ed4d6e2b6e6a0797313d3c8a.jpg'),
(64792, 4421, 'Agente 86 S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155409.mp4', 'http://timg.bdta.pro/images/134014164e7b0b552bbc6bbf314b20e0.jpg'),
(64793, 4421, 'Agente 86 S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155410.mp4', 'http://timg.bdta.pro/images/63791672ff58bbfad4d8d9f2004a5b8f.jpg'),
(64794, 4421, 'Agente 86 S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155411.mp4', 'http://timg.bdta.pro/images/3151795546cc1609704200cff46a6558.jpg'),
(64795, 4421, 'Agente 86 S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155412.mp4', 'http://timg.bdta.pro/images/aaf28438259407892689ddd7957df9de.jpg'),
(64796, 4421, 'Agente 86 S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/155413.mp4', 'http://timg.bdta.pro/images/6f6972601ee73bb44d5455b85fea93e2.jpg'),
(64797, 4421, 'Agente 86 S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/155414.mp4', 'http://timg.bdta.pro/images/f66ebe00582e0a4bb52a58fe0377ef6f.jpg'),
(64798, 4421, 'Agente 86 S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/155415.mp4', 'http://timg.bdta.pro/images/c80eef24e4933bce242e4de9e084bc31.jpg'),
(64799, 4421, 'Agente 86 S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/155416.mp4', 'http://timg.bdta.pro/images/7a03a60bd8721c0bad911e9b8c8c2aed.jpg'),
(64800, 4421, 'Agente 86 S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/155417.mp4', 'http://timg.bdta.pro/images/39c057781627c8527500bbec7f89118c.jpg'),
(64801, 4421, 'Agente 86 S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/155418.mp4', 'http://timg.bdta.pro/images/cd7f8d458b857b9dcfc2974f3390e69d.jpg'),
(64802, 4421, 'Agente 86 S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/155419.mp4', 'http://timg.bdta.pro/images/0f841a9699746e915126140cf73d1be2.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(64803, 4421, 'Agente 86 S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/155420.mp4', 'http://timg.bdta.pro/images/719ad41223ad1bbede5640b3cc58fa6e.jpg'),
(64804, 4421, 'Agente 86 S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/155421.mp4', 'http://timg.bdta.pro/images/279252c776f778f9b27fcbb4d0283f84.jpg'),
(64805, 4421, 'Agente 86 S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/155422.mp4', 'http://timg.bdta.pro/images/c5f1b3aefb71cc8e2913df199ce0edc9.jpg'),
(64806, 4421, 'Agente 86 S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/155423.mp4', 'http://timg.bdta.pro/images/3dbc5dc05d4ddffa537313fd69b64b02.jpg'),
(64807, 4421, 'Agente 86 S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/155424.mp4', 'http://timg.bdta.pro/images/370a211c042663f59c256623e3b03114.jpg'),
(64808, 4421, 'Agente 86 S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/155425.mp4', 'http://timg.bdta.pro/images/c01c003a000cb425a522641f0f04e813.jpg'),
(64809, 4421, 'Agente 86 S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/155426.mp4', 'http://timg.bdta.pro/images/f4823254eb2dd966c00276611fcee023.jpg'),
(64810, 4421, 'Agente 86 S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/155427.mp4', 'http://timg.bdta.pro/images/ac6c032f49df83397763045c40e5061f.jpg'),
(64811, 4421, 'Agente 86 S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/155428.mp4', 'http://timg.bdta.pro/images/697c827d45fc52d84bc04c3c10b542f1.jpg'),
(64812, 4421, 'Agente 86 S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/155429.mp4', 'http://timg.bdta.pro/images/2ec858e68da9b7c1aef750ae571f9e9e.jpg'),
(64813, 4421, 'Agente 86 S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/155430.mp4', 'http://timg.bdta.pro/images/59e703f5e586b344d6c8d7a923d179c7.jpg'),
(64814, 4421, 'Agente 86 S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/155431.mp4', 'http://timg.bdta.pro/images/fcddc847d918985f534752aea4525eb6.jpg'),
(64815, 4421, 'Agente 86 S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/155432.mp4', 'http://timg.bdta.pro/images/6ca601aba34a7dff8f7e870f15a775f5.jpg'),
(64816, 4422, 'Agente 86 S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155433.mp4', 'http://timg.bdta.pro/images/115c33468cd88b7e5f38bdcf1062839d.jpg'),
(64817, 4422, 'Agente 86 S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155434.mp4', 'http://timg.bdta.pro/images/d2520d5fd7b9b2b81b20eb888226e85c.jpg'),
(64818, 4422, 'Agente 86 S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155435.mp4', 'http://timg.bdta.pro/images/7c84e9e9e574684fcb4b4a0eccb5d146.jpg'),
(64819, 4422, 'Agente 86 S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155436.mp4', 'http://timg.bdta.pro/images/15e52938367d34ff8584f267666ded5f.jpg'),
(64820, 4422, 'Agente 86 S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155437.mp4', 'http://timg.bdta.pro/images/41a60ef06b59e0439543850422679ca5.jpg'),
(64821, 4422, 'Agente 86 S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155438.mp4', 'http://timg.bdta.pro/images/c0cc44ccbd9e68de566904152cee330b.jpg'),
(64822, 4422, 'Agente 86 S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/155439.mp4', 'http://timg.bdta.pro/images/616c9d1fd634767982ad5895340152f7.jpg'),
(64823, 4422, 'Agente 86 S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/155440.mp4', 'http://timg.bdta.pro/images/c63b6ec3b392ab0fd8b6a5fb3a9ad663.jpg'),
(64824, 4422, 'Agente 86 S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/155441.mp4', 'http://timg.bdta.pro/images/8bf6d1bc1cb2d3bab4e6f19de4cb1784.jpg'),
(64825, 4422, 'Agente 86 S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/155442.mp4', 'http://timg.bdta.pro/images/e87341bf4b4a7e26ec9d783f1aa98a6c.jpg'),
(64826, 4422, 'Agente 86 S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/155443.mp4', 'http://timg.bdta.pro/images/e9afe0f8dbb714b8c294550bc37805c5.jpg'),
(64827, 4422, 'Agente 86 S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/155444.mp4', 'http://timg.bdta.pro/images/a97a17ab1ddf1afd4345e277e6a537c6.jpg'),
(64828, 4422, 'Agente 86 S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/155445.mp4', 'http://timg.bdta.pro/images/56edd7bf68c6f474c07dbd8105dad151.jpg'),
(64829, 4422, 'Agente 86 S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/155446.mp4', 'http://timg.bdta.pro/images/e3280116c2d9555a14bf6a4afb73501b.jpg'),
(64830, 4422, 'Agente 86 S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/155447.mp4', 'http://timg.bdta.pro/images/8dd9e543b0206cd56cc5da5dc09fae85.jpg'),
(64831, 4422, 'Agente 86 S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/155448.mp4', 'http://timg.bdta.pro/images/3af8a848d1087e21a7cc207ae9746a45.jpg'),
(64832, 4422, 'Agente 86 S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/155449.mp4', 'http://timg.bdta.pro/images/168e544198c091f1716cca4991820072.jpg'),
(64833, 4422, 'Agente 86 S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/155450.mp4', 'http://timg.bdta.pro/images/36a4dff0ada139db4b8549c9a6ab6393.jpg'),
(64834, 4422, 'Agente 86 S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/155451.mp4', 'http://timg.bdta.pro/images/e5aed8a72cc9aea13b944b70eb572dfb.jpg'),
(64835, 4422, 'Agente 86 S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/155452.mp4', 'http://timg.bdta.pro/images/c76b101f80009729971726149d83f011.jpg'),
(64836, 4422, 'Agente 86 S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/155453.mp4', 'http://timg.bdta.pro/images/ffd90160300295c4b1cbd4402942137a.jpg'),
(64837, 4422, 'Agente 86 S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/155454.mp4', 'http://timg.bdta.pro/images/7c4f0548efd22d00d0d86beda25280ed.jpg'),
(64838, 4422, 'Agente 86 S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/155455.mp4', 'http://timg.bdta.pro/images/7a1ba248785a6ced0a6d1156fb770c0c.jpg'),
(64839, 4422, 'Agente 86 S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/155456.mp4', 'http://timg.bdta.pro/images/28c5f08115539535fc38402d22e58fe7.jpg'),
(64840, 4422, 'Agente 86 S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/155457.mp4', 'http://timg.bdta.pro/images/3b13877d06a43e9854e68855dad29596.jpg'),
(64841, 4422, 'Agente 86 S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/155458.mp4', 'http://timg.bdta.pro/images/31146e3df1a7d68a849e1cfa2b328555.jpg'),
(64842, 4423, 'American Rust [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161922.mp4', 'http://timg.bdta.pro/images/cb452caa1fd80e0f59536650e03f87d1.jpg'),
(64843, 4423, 'American Rust [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161923.mp4', 'http://timg.bdta.pro/images/4939c9f597e47f02f2943f7ff4a6952f.jpg'),
(64844, 4423, 'American Rust [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161924.mp4', 'http://image.tmdb.org/t/p/w1280/xiHAFjw3pYqiNLg1mklyRb6XjFT.jpg'),
(64845, 4423, 'American Rust [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161925.mp4', 'http://image.tmdb.org/t/p/w1280/rJlPUJB3hg4bWRS5BUnzHXf4XDt.jpg'),
(64846, 4423, 'American Rust [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdDn9gjqtzkZsR0D2CeTk5LAcYE.jpg'),
(64847, 4423, 'American Rust [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iGfGHYb7mJGniKfhGb1i7xx1brf.jpg'),
(64848, 4423, 'American Rust [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iV7fI7YeRbEmXebuSmhgajGYPmQ.jpg'),
(64849, 4423, 'American Rust [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFv2KgxZxjdCx7L9YpLwRv7kl56.jpg'),
(64850, 4423, 'American Rust [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iKPcCnsSmNrDxmmMeBWWaCQI7Tf.jpg'),
(64851, 4424, 'American Rust [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/442940.mp4', 'http://gstaticontent.com/images/6d5e686d0b9aa040de55ecded94061e0.jpg'),
(64852, 4424, 'American Rust [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/442941.mp4', 'http://gstaticontent.com/images/6d5e686d0b9aa040de55ecded94061e0.jpg'),
(64853, 4424, 'American Rust [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/442942.mp4', 'http://gstaticontent.com/images/6d5e686d0b9aa040de55ecded94061e0.jpg'),
(64854, 4424, 'American Rust [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/442943.mp4', 'http://gstaticontent.com/images/6d5e686d0b9aa040de55ecded94061e0.jpg'),
(64855, 4424, 'American Rust [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/442944.mp4', 'http://gstaticontent.com/images/6d5e686d0b9aa040de55ecded94061e0.jpg'),
(64856, 4424, 'American Rust [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/442945.mp4', 'http://gstaticontent.com/images/6d5e686d0b9aa040de55ecded94061e0.jpg'),
(64857, 4424, 'American Rust [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/442946.mp4', 'http://gstaticontent.com/images/6d5e686d0b9aa040de55ecded94061e0.jpg'),
(64858, 4424, 'American Rust [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/442947.mp4', 'http://gstaticontent.com/images/6d5e686d0b9aa040de55ecded94061e0.jpg'),
(64859, 4424, 'American Rust [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/442948.mp4', 'http://gstaticontent.com/images/6d5e686d0b9aa040de55ecded94061e0.jpg'),
(64860, 4424, 'American Rust [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/442949.mp4', 'http://gstaticontent.com/images/6d5e686d0b9aa040de55ecded94061e0.jpg'),
(64861, 4425, 'Black Box S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155308.mp4', 'http://timg.bdta.pro/images/4cf307baf431ef202e0e776e479e4ac9.jpg'),
(64862, 4425, 'Black Box S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155309.mp4', 'http://timg.bdta.pro/images/e19279b3f7eda478d2dbc522b45c5c22.jpg'),
(64863, 4425, 'Black Box S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155310.mp4', 'http://timg.bdta.pro/images/33a67c75dd746511e06abe0dd1491f08.jpg'),
(64864, 4425, 'Black Box S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155311.mp4', 'http://timg.bdta.pro/images/c4cd7ebd25f4984557c7522da83d32c5.jpg'),
(64865, 4425, 'Black Box S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155312.mp4', 'http://timg.bdta.pro/images/93c46fae942b98fa96dcfb7703615592.jpg'),
(64866, 4425, 'Black Box S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155313.mp4', 'http://timg.bdta.pro/images/a0d4b836ed52b666116f78ef57545f93.jpg'),
(64867, 4425, 'Black Box S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/155314.mp4', 'http://timg.bdta.pro/images/a37459b5995daef5b727b29d8d8f1611.jpg'),
(64868, 4425, 'Black Box S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/155315.mp4', 'http://timg.bdta.pro/images/ea003460f912648fd84e2731bd261572.jpg'),
(64869, 4425, 'Black Box S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/155316.mp4', 'http://timg.bdta.pro/images/efd9da8e4a383deffdb72a579e8cdc05.jpg'),
(64870, 4425, 'Black Box S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/155317.mp4', 'http://timg.bdta.pro/images/f8c8af8f8bad8f453ea389502677ee3d.jpg'),
(64871, 4425, 'Black Box S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/155318.mp4', 'http://timg.bdta.pro/images/738e534c38cca2371cbc874266594f0d.jpg'),
(64872, 4425, 'Black Box S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/155319.mp4', 'http://timg.bdta.pro/images/e22684699bbc8e47132cff893bdecc5d.jpg'),
(64873, 4425, 'Black Box S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/155320.mp4', 'http://timg.bdta.pro/images/5d3b12dacb757ad414d168af40b5b116.jpg'),
(64874, 4426, 'Doogie Kamealoha: Doutora Precoce S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208673.mp4', 'http://timg.bdta.pro/images/34cdb6e7daac9a2e966cdab92dbba057.jpg'),
(64875, 4426, 'Doogie Kamealoha: Doutora Precoce S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208674.mp4', 'http://timg.bdta.pro/images/ae7ce85569af49cbcd5e440eb8b1cdbd.jpg'),
(64876, 4426, 'Doogie Kamealoha: Doutora Precoce S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208675.mp4', 'http://image.tmdb.org/t/p/w1280/v8iKWlv0e4w0E839CdKX8K5IbgJ.jpg'),
(64877, 4426, 'Doogie Kamealoha: Doutora Precoce S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bPvjs1yFeMKwxY0wgmamcqFkoKB.jpg'),
(64878, 4426, 'Doogie Kamealoha: Doutora Precoce S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9IXqF88IO9VbSR7zT6yCOv8clYi.jpg'),
(64879, 4426, 'Doogie Kamealoha: Doutora Precoce S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uhb3Wo6isuRSHQ8epCg1QHatUD2.jpg'),
(64880, 4426, 'Doogie Kamealoha: Doutora Precoce S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nTS4A0RXlj4CMtUPwWdxoAycDUA.jpg'),
(64881, 4426, 'Doogie Kamealoha: Doutora Precoce S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/veXZQkLhg04DVHGMZg3xebvA4GY.jpg'),
(64882, 4426, 'Doogie Kamealoha: Doutora Precoce S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208681.mp4', 'http://image.tmdb.org/t/p/w1280/rCYDHVhO4EXc8A1HYunVRMMRDtV.jpg'),
(64883, 4426, 'Doogie Kamealoha: Doutora Precoce S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208682.mp4', 'http://image.tmdb.org/t/p/w1280/fOHLxTgrYJ1extnyY5xxfkBExhv.jpg'),
(64884, 4427, 'Doogie Kamealoha: Doutora Precoce S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUCm23jnL9m8TrBAVgm6DJUycgH.jpg'),
(64885, 4427, 'Doogie Kamealoha: Doutora Precoce S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9jDJGo9PWbVRHFmvmSZwv59TepU.jpg'),
(64886, 4427, 'Doogie Kamealoha: Doutora Precoce S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/memRXTd1YWbr0OwgA4UsrnOHFqs.jpg'),
(64887, 4427, 'Doogie Kamealoha: Doutora Precoce S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cCNGbOAWt9SzXxXndSsHP3l9qHr.jpg'),
(64888, 4427, 'Doogie Kamealoha: Doutora Precoce S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/14tFe12H0c5mWyInuuoGX4WiQ3U.jpg'),
(64889, 4427, 'Doogie Kamealoha: Doutora Precoce S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yXIV1St1qoRClxdC7fnRAo4YqN1.jpg'),
(64890, 4427, 'Doogie Kamealoha: Doutora Precoce S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/troqLo6pP6A0L7Bynj5n2qffgiU.jpg'),
(64891, 4427, 'Doogie Kamealoha: Doutora Precoce S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/amoexDhtQi6c9P7RE7EWWmecG3n.jpg'),
(64892, 4427, 'Doogie Kamealoha: Doutora Precoce S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7BN7TUwTgMfa4APAi1MlM0M4yY7.jpg'),
(64893, 4427, 'Doogie Kamealoha: Doutora Precoce S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hZG8dUE1FISwY4B6M5yEgxUwiZp.jpg'),
(64894, 4428, 'Fernando [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155303.mp4', 'http://timg.bdta.pro/images/0ebaafb34c9a8bbf67d5e308f742525c.jpg'),
(64895, 4428, 'Fernando [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155304.mp4', 'http://timg.bdta.pro/images/ad93d413813dd9ce200075f68d552ecf.jpg'),
(64896, 4428, 'Fernando [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155305.mp4', 'http://timg.bdta.pro/images/7ab7f005ec07c1c623f6c3aa78d57d1f.jpg'),
(64897, 4428, 'Fernando [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155306.mp4', 'http://timg.bdta.pro/images/39f683e0dd7c4f74bb8825813d1dba20.jpg'),
(64898, 4428, 'Fernando [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155307.mp4', 'http://timg.bdta.pro/images/f56ef9bab995e51a1d4dcff5828f77ae.jpg'),
(64899, 4429, 'Kid Cosmic S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172837.mp4', 'http://timg.bdta.pro/images/67e9e3695be1818cd188a0aa04147c65.jpg'),
(64900, 4429, 'Kid Cosmic S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172838.mp4', 'http://timg.bdta.pro/images/4b7c53e9d2281432a523ac844a863387.jpg'),
(64901, 4429, 'Kid Cosmic S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172839.mp4', 'http://timg.bdta.pro/images/886208754a68201b46c03490d0756a4c.jpg'),
(64902, 4429, 'Kid Cosmic S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172840.mp4', 'http://timg.bdta.pro/images/ba59305a7587e64e0e628fc700d18191.jpg'),
(64903, 4429, 'Kid Cosmic S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172841.mp4', 'http://timg.bdta.pro/images/f85c5be450092ae6df53df4a4e0115fe.jpg'),
(64904, 4429, 'Kid Cosmic S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172842.mp4', 'http://timg.bdta.pro/images/ca907840af846797b03dc5f72f300274.jpg'),
(64905, 4429, 'Kid Cosmic S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172843.mp4', 'http://timg.bdta.pro/images/8f73a3d528160b14967014f2166fecfe.jpg'),
(64906, 4429, 'Kid Cosmic S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172844.mp4', 'http://timg.bdta.pro/images/77bdcbe465d698b2d41b9a019faf921e.jpg'),
(64907, 4429, 'Kid Cosmic S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172845.mp4', 'http://timg.bdta.pro/images/8c7f594563b3ce457c9c24d24d3d19ca.jpg'),
(64908, 4429, 'Kid Cosmic S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172846.mp4', 'http://timg.bdta.pro/images/a1e38ce511eeec0284f0829378e25d86.jpg'),
(64909, 4430, 'Kid Cosmic S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172847.mp4', 'http://timg.bdta.pro/images/a20ab92fa33d01395184c280dbe96ebf.jpg'),
(64910, 4430, 'Kid Cosmic S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172848.mp4', 'http://timg.bdta.pro/images/923c21461b5f5cdca9ed8668698a0c1d.jpg'),
(64911, 4430, 'Kid Cosmic S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172849.mp4', 'http://timg.bdta.pro/images/06dba4e9ac2531db544b300f7f471995.jpg'),
(64912, 4430, 'Kid Cosmic S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172850.mp4', 'http://timg.bdta.pro/images/bfb867bf850fbe7b12cc1c49c7f078b4.jpg'),
(64913, 4430, 'Kid Cosmic S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172851.mp4', 'http://timg.bdta.pro/images/09acc4d476824108f1861031b077741e.jpg'),
(64914, 4430, 'Kid Cosmic S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172852.mp4', 'http://timg.bdta.pro/images/8dbd6db8414ba41ea5e3d013b1b49abf.jpg'),
(64915, 4430, 'Kid Cosmic S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172853.mp4', 'http://timg.bdta.pro/images/79a78c5a9077d5fe44cdc615e95015da.jpg'),
(64916, 4430, 'Kid Cosmic S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172854.mp4', 'http://timg.bdta.pro/images/4b7300bfb5ff8e87a8dad83ce165dbe7.jpg'),
(64917, 4431, 'Lista Negra: Redenção S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155295.mp4', 'http://timg.bdta.pro/images/e4f4f777a24c6a9ecc79ee41944a6c84.jpg'),
(64918, 4431, 'Lista Negra: Redenção S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155296.mp4', 'http://timg.bdta.pro/images/a4819e97cd6210d78fd91cca43a876cd.jpg'),
(64919, 4431, 'Lista Negra: Redenção S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155297.mp4', 'http://timg.bdta.pro/images/2be8964935c201c5c4e5501382c7a21e.jpg'),
(64920, 4431, 'Lista Negra: Redenção S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155298.mp4', 'http://timg.bdta.pro/images/811f1f11096edfa40b0a420e2ff38267.jpg'),
(64921, 4431, 'Lista Negra: Redenção S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155299.mp4', 'http://timg.bdta.pro/images/f0996370c153db18b43c9d72186c2633.jpg'),
(64922, 4431, 'Lista Negra: Redenção S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155300.mp4', 'http://timg.bdta.pro/images/b8720c23b624e72eb17d89a6dd139a4b.jpg'),
(64923, 4431, 'Lista Negra: Redenção S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/155301.mp4', 'http://timg.bdta.pro/images/951c99603197cc35f7306801accc1a1b.jpg'),
(64924, 4431, 'Lista Negra: Redenção S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/155302.mp4', 'http://timg.bdta.pro/images/d3ce0b5bedb75b5cd9f6d0d8d818fa80.jpg'),
(64925, 4432, 'Noite Adentro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155283.mp4', 'http://timg.bdta.pro/images/6349d807bf8556f6b516fbad7271fe4e.jpg'),
(64926, 4432, 'Noite Adentro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155284.mp4', 'http://timg.bdta.pro/images/b09eea6fddc936471072aa9b56ad0489.jpg'),
(64927, 4432, 'Noite Adentro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155285.mp4', 'http://timg.bdta.pro/images/dbf33d41eaf66520b1c528dff8e90bf4.jpg'),
(64928, 4432, 'Noite Adentro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155286.mp4', 'http://timg.bdta.pro/images/b34c42410af7b631d8eef1a5fa361fb7.jpg'),
(64929, 4432, 'Noite Adentro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155287.mp4', 'http://timg.bdta.pro/images/82b85c6e2f33270d2fe35d130df71763.jpg'),
(64930, 4432, 'Noite Adentro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155288.mp4', 'http://timg.bdta.pro/images/5f0e2725e22790fdb75277d0ccda19bc.jpg'),
(64931, 4433, 'Noite Adentro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155289.mp4', 'http://timg.bdta.pro/images/b861f0370d8627cf70e34fe44dddc3f3.jpg'),
(64932, 4433, 'Noite Adentro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155290.mp4', 'http://timg.bdta.pro/images/316d72f02e141f9954ba402f34206cce.jpg'),
(64933, 4433, 'Noite Adentro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155291.mp4', 'http://timg.bdta.pro/images/35898376bf24c2077d1fffcacec6af5e.jpg'),
(64934, 4433, 'Noite Adentro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155292.mp4', 'http://timg.bdta.pro/images/b4f92671f033eb7052841f7ff3c4f5c5.jpg'),
(64935, 4433, 'Noite Adentro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155293.mp4', 'http://timg.bdta.pro/images/3cdfdfa495cb4a9a5842f8edd72db8c1.jpg'),
(64936, 4433, 'Noite Adentro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155294.mp4', 'http://timg.bdta.pro/images/83a1ea779d4618ec8c8dede51bae16a1.jpg'),
(64937, 4434, 'O Dilema de Suzie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255470.mp4', 'http://timg.bdta.pro/images/75fad1eb0cc8e0e577ebef1cdc692a5b.jpg'),
(64938, 4434, 'O Dilema de Suzie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255471.mp4', 'http://timg.bdta.pro/images/2996669c222f02d69de4aa610748713f.jpg'),
(64939, 4434, 'O Dilema de Suzie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255472.mp4', 'http://timg.bdta.pro/images/dc91c72461d55b41967da860aa7b5e68.jpg'),
(64940, 4434, 'O Dilema de Suzie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255473.mp4', 'http://timg.bdta.pro/images/ce47e374ddb03167d5fa118ef0758ab0.jpg'),
(64941, 4434, 'O Dilema de Suzie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255474.mp4', 'http://timg.bdta.pro/images/83879b0be6e3faf78338911d5874c33d.jpg'),
(64942, 4434, 'O Dilema de Suzie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255475.mp4', 'http://timg.bdta.pro/images/c070b262394f7a3d574b9bde3c75dbc0.jpg'),
(64943, 4434, 'O Dilema de Suzie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255476.mp4', 'http://timg.bdta.pro/images/2f552995efcbbd532fb7ce399d3de91d.jpg'),
(64944, 4434, 'O Dilema de Suzie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255477.mp4', 'http://timg.bdta.pro/images/176674f11e735b01a9c8cbcef62ee873.jpg'),
(64945, 4435, 'O Dilema de Suzie S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255478.mp4', 'http://gstaticontent.com/images/6ea1ffb4356bdf7a2d433aab0b243812.jpg'),
(64946, 4435, 'O Dilema de Suzie S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255479.mp4', 'http://gstaticontent.com/images/6ea1ffb4356bdf7a2d433aab0b243812.jpg'),
(64947, 4435, 'O Dilema de Suzie S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255480.mp4', 'http://gstaticontent.com/images/6ea1ffb4356bdf7a2d433aab0b243812.jpg'),
(64948, 4436, 'Os Thundermans S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182117.mp4', 'http://timg.bdta.pro/images/4e0488b99e2ebf485ec7ee3874027fd3.jpg'),
(64949, 4436, 'Os Thundermans S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182118.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64950, 4436, 'Os Thundermans S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182119.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64951, 4436, 'Os Thundermans S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182120.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64952, 4436, 'Os Thundermans S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182121.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64953, 4436, 'Os Thundermans S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182122.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64954, 4436, 'Os Thundermans S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182123.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64955, 4436, 'Os Thundermans S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182124.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64956, 4436, 'Os Thundermans S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/182125.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64957, 4436, 'Os Thundermans S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/182126.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64958, 4436, 'Os Thundermans S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/182127.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64959, 4436, 'Os Thundermans S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/182128.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64960, 4436, 'Os Thundermans S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/182129.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64961, 4436, 'Os Thundermans S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/182130.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64962, 4436, 'Os Thundermans S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/182131.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64963, 4436, 'Os Thundermans S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/182132.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64964, 4436, 'Os Thundermans S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/182133.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64965, 4436, 'Os Thundermans S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/182134.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64966, 4436, 'Os Thundermans S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/182135.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64967, 4436, 'Os Thundermans S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/182136.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64968, 4437, 'Os Thundermans S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182137.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64969, 4437, 'Os Thundermans S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182138.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64970, 4437, 'Os Thundermans S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182139.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64971, 4437, 'Os Thundermans S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182140.mp4', 'http://timg.bdta.pro/images/8a6b653e8aa1bbbf12242b972beae1bb.jpg'),
(64972, 4437, 'Os Thundermans S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182141.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64973, 4437, 'Os Thundermans S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182142.mp4', 'http://timg.bdta.pro/images/60b83479e88abf9126d076d8b4da451b.jpg'),
(64974, 4437, 'Os Thundermans S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182143.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64975, 4437, 'Os Thundermans S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182144.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64976, 4437, 'Os Thundermans S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/182145.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64977, 4437, 'Os Thundermans S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/182146.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64978, 4437, 'Os Thundermans S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/182147.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64979, 4437, 'Os Thundermans S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/182148.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64980, 4437, 'Os Thundermans S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/182149.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64981, 4437, 'Os Thundermans S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/182150.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64982, 4437, 'Os Thundermans S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/182151.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64983, 4437, 'Os Thundermans S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/182152.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64984, 4437, 'Os Thundermans S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/182153.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64985, 4437, 'Os Thundermans S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/182154.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64986, 4437, 'Os Thundermans S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/182155.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64987, 4437, 'Os Thundermans S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/182156.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64988, 4437, 'Os Thundermans S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/182157.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64989, 4437, 'Os Thundermans S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/182158.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64990, 4437, 'Os Thundermans S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/182159.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64991, 4437, 'Os Thundermans S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/182160.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64992, 4438, 'Os Thundermans S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182161.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64993, 4438, 'Os Thundermans S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182162.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64994, 4438, 'Os Thundermans S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182163.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64995, 4438, 'Os Thundermans S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182164.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64996, 4438, 'Os Thundermans S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182165.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64997, 4438, 'Os Thundermans S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182166.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64998, 4438, 'Os Thundermans S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182167.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(64999, 4438, 'Os Thundermans S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182168.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65000, 4438, 'Os Thundermans S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/182169.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65001, 4438, 'Os Thundermans S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/182170.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65002, 4438, 'Os Thundermans S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/182171.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65003, 4438, 'Os Thundermans S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/182172.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65004, 4438, 'Os Thundermans S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/182173.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65005, 4438, 'Os Thundermans S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/182174.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65006, 4438, 'Os Thundermans S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/182175.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65007, 4438, 'Os Thundermans S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/182176.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65008, 4438, 'Os Thundermans S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/182177.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65009, 4438, 'Os Thundermans S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/182178.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65010, 4438, 'Os Thundermans S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/182179.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65011, 4438, 'Os Thundermans S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/182180.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65012, 4438, 'Os Thundermans S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/182181.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65013, 4438, 'Os Thundermans S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/182182.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65014, 4438, 'Os Thundermans S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/182183.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65015, 4438, 'Os Thundermans S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/182184.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65016, 4438, 'Os Thundermans S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/182185.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65017, 4439, 'Os Thundermans S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182186.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65018, 4439, 'Os Thundermans S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182187.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65019, 4439, 'Os Thundermans S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182188.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65020, 4439, 'Os Thundermans S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182189.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65021, 4439, 'Os Thundermans S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182190.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65022, 4439, 'Os Thundermans S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182191.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65023, 4439, 'Os Thundermans S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182192.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65024, 4439, 'Os Thundermans S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182193.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65025, 4439, 'Os Thundermans S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/182194.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65026, 4439, 'Os Thundermans S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/182195.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65027, 4439, 'Os Thundermans S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/182196.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65028, 4439, 'Os Thundermans S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/182197.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65029, 4439, 'Os Thundermans S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/182198.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65030, 4439, 'Os Thundermans S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/182199.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65031, 4439, 'Os Thundermans S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/182200.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65032, 4439, 'Os Thundermans S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/182201.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65033, 4439, 'Os Thundermans S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/182202.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65034, 4439, 'Os Thundermans S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/182203.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65035, 4439, 'Os Thundermans S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/182204.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65036, 4439, 'Os Thundermans S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/182205.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65037, 4439, 'Os Thundermans S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/182206.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65038, 4439, 'Os Thundermans S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/182207.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65039, 4439, 'Os Thundermans S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/182208.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65040, 4439, 'Os Thundermans S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/182209.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65041, 4439, 'Os Thundermans S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/182210.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65042, 4439, 'Os Thundermans S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/182211.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65043, 4439, 'Os Thundermans S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/182212.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65044, 4439, 'Os Thundermans S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/182213.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65045, 4439, 'Os Thundermans S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/182214.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65046, 4439, 'Os Thundermans S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/182215.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65047, 4439, 'Os Thundermans S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/182216.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65048, 4439, 'Os Thundermans S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/182217.mp4', 'http://gstaticontent.com/images/57d04c4040c328d1dcc4db62dde442c5.jpg'),
(65049, 4440, 'Por Trás da Diversão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/155273.mp4', 'http://timg.bdta.pro/images/5be2dbf725e66e137beb0d9b942c2496.jpg'),
(65050, 4440, 'Por Trás da Diversão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/155274.mp4', 'http://timg.bdta.pro/images/096848694ea186c76361b107b4182dfe.jpg'),
(65051, 4440, 'Por Trás da Diversão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/155275.mp4', 'http://timg.bdta.pro/images/7f5b8a0dc4bd01e8c810d3c05db3ffa2.jpg'),
(65052, 4440, 'Por Trás da Diversão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/155276.mp4', 'http://timg.bdta.pro/images/72a5e6b86461b3522af252040d670dc5.jpg'),
(65053, 4440, 'Por Trás da Diversão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/155277.mp4', 'http://timg.bdta.pro/images/3630b0d00d00fc7814c92131ca352722.jpg'),
(65054, 4440, 'Por Trás da Diversão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/155278.mp4', 'http://timg.bdta.pro/images/b8d4b6f11a33ca52b62afce3291667b9.jpg'),
(65055, 4440, 'Por Trás da Diversão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/155279.mp4', 'http://timg.bdta.pro/images/046242dbe68df4a00d240431d9af95a9.jpg'),
(65056, 4440, 'Por Trás da Diversão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/155280.mp4', 'http://timg.bdta.pro/images/f328b5b52f04938e0195960050b59a77.jpg'),
(65057, 4440, 'Por Trás da Diversão S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/155281.mp4', 'http://timg.bdta.pro/images/b0a96e256d90ad6e6b78befb15aea9cc.jpg'),
(65058, 4440, 'Por Trás da Diversão S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/155282.mp4', 'http://timg.bdta.pro/images/a464bb22f3aa671f24a4397baf23aa86.jpg'),
(65059, 4441, 'Fatmagül: A Força do Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198311.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65060, 4441, 'Fatmagül: A Força do Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198312.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65061, 4441, 'Fatmagül: A Força do Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198313.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65062, 4441, 'Fatmagül: A Força do Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198314.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65063, 4441, 'Fatmagül: A Força do Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198315.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65064, 4441, 'Fatmagül: A Força do Amor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198316.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65065, 4441, 'Fatmagül: A Força do Amor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198317.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65066, 4441, 'Fatmagül: A Força do Amor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198318.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65067, 4441, 'Fatmagül: A Força do Amor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198319.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65068, 4441, 'Fatmagül: A Força do Amor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198320.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65069, 4441, 'Fatmagül: A Força do Amor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/198321.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65070, 4441, 'Fatmagül: A Força do Amor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/198322.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65071, 4441, 'Fatmagül: A Força do Amor S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/198323.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65072, 4441, 'Fatmagül: A Força do Amor S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/198324.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65073, 4441, 'Fatmagül: A Força do Amor S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/198325.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65074, 4441, 'Fatmagül: A Força do Amor S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/198326.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65075, 4441, 'Fatmagül: A Força do Amor S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/198327.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65076, 4441, 'Fatmagül: A Força do Amor S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/198328.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65077, 4441, 'Fatmagül: A Força do Amor S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/198329.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65078, 4441, 'Fatmagül: A Força do Amor S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/198330.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65079, 4441, 'Fatmagül: A Força do Amor S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/198331.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65080, 4441, 'Fatmagül: A Força do Amor S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/198332.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65081, 4441, 'Fatmagül: A Força do Amor S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/198333.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65082, 4441, 'Fatmagül: A Força do Amor S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/198334.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65083, 4441, 'Fatmagül: A Força do Amor S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/198335.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65084, 4441, 'Fatmagül: A Força do Amor S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/198336.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(65085, 4441, 'Fatmagül: A Força do Amor S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/198337.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65086, 4441, 'Fatmagül: A Força do Amor S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/198338.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65087, 4441, 'Fatmagül: A Força do Amor S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/198339.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65088, 4441, 'Fatmagül: A Força do Amor S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/198340.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65089, 4441, 'Fatmagül: A Força do Amor S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/198341.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65090, 4441, 'Fatmagül: A Força do Amor S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/198342.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65091, 4441, 'Fatmagül: A Força do Amor S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/198343.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65092, 4441, 'Fatmagül: A Força do Amor S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/198344.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65093, 4441, 'Fatmagül: A Força do Amor S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/198345.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65094, 4441, 'Fatmagül: A Força do Amor S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/198346.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65095, 4441, 'Fatmagül: A Força do Amor S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/198347.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65096, 4441, 'Fatmagül: A Força do Amor S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/198348.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65097, 4441, 'Fatmagül: A Força do Amor S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/198349.mp4', 'http://timg.bdta.pro/images/e87e8219b39a1a7d45ffe037392a4370.jpg'),
(65098, 4441, 'Fatmagül: A Força do Amor S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/198350.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65099, 4441, 'Fatmagül: A Força do Amor S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/198351.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65100, 4441, 'Fatmagül: A Força do Amor S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/198352.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65101, 4441, 'Fatmagül: A Força do Amor S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/198353.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65102, 4441, 'Fatmagül: A Força do Amor S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/198354.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65103, 4441, 'Fatmagül: A Força do Amor S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/198355.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65104, 4441, 'Fatmagül: A Força do Amor S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/198356.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65105, 4441, 'Fatmagül: A Força do Amor S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/198357.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65106, 4441, 'Fatmagül: A Força do Amor S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/198358.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65107, 4441, 'Fatmagül: A Força do Amor S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/198359.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65108, 4441, 'Fatmagül: A Força do Amor S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/198360.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65109, 4441, 'Fatmagül: A Força do Amor S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/198361.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65110, 4441, 'Fatmagül: A Força do Amor S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/198362.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65111, 4441, 'Fatmagül: A Força do Amor S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/198363.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65112, 4441, 'Fatmagül: A Força do Amor S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/198364.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65113, 4441, 'Fatmagül: A Força do Amor S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/198365.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65114, 4441, 'Fatmagül: A Força do Amor S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/198366.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65115, 4441, 'Fatmagül: A Força do Amor S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/198367.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65116, 4441, 'Fatmagül: A Força do Amor S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/198368.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65117, 4441, 'Fatmagül: A Força do Amor S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/198369.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65118, 4441, 'Fatmagül: A Força do Amor S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/198370.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65119, 4441, 'Fatmagül: A Força do Amor S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/198371.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65120, 4441, 'Fatmagül: A Força do Amor S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/198372.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65121, 4441, 'Fatmagül: A Força do Amor S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/198373.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65122, 4441, 'Fatmagül: A Força do Amor S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/198374.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65123, 4441, 'Fatmagül: A Força do Amor S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/198375.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65124, 4441, 'Fatmagül: A Força do Amor S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/198376.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65125, 4441, 'Fatmagül: A Força do Amor S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/198377.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65126, 4441, 'Fatmagül: A Força do Amor S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/198378.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65127, 4441, 'Fatmagül: A Força do Amor S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/198379.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65128, 4441, 'Fatmagül: A Força do Amor S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/198380.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65129, 4441, 'Fatmagül: A Força do Amor S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/198381.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65130, 4441, 'Fatmagül: A Força do Amor S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/198382.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65131, 4441, 'Fatmagül: A Força do Amor S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/198383.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65132, 4441, 'Fatmagül: A Força do Amor S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/198384.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65133, 4441, 'Fatmagül: A Força do Amor S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/198385.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65134, 4441, 'Fatmagül: A Força do Amor S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/198386.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65135, 4441, 'Fatmagül: A Força do Amor S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/198387.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65136, 4441, 'Fatmagül: A Força do Amor S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/198388.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65137, 4441, 'Fatmagül: A Força do Amor S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/198389.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65138, 4441, 'Fatmagül: A Força do Amor S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/198390.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65139, 4441, 'Fatmagül: A Força do Amor S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/198391.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65140, 4441, 'Fatmagül: A Força do Amor S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/198392.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65141, 4441, 'Fatmagül: A Força do Amor S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/198393.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65142, 4441, 'Fatmagül: A Força do Amor S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/198394.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65143, 4441, 'Fatmagül: A Força do Amor S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/198395.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65144, 4441, 'Fatmagül: A Força do Amor S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/198396.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65145, 4441, 'Fatmagül: A Força do Amor S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/198397.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65146, 4441, 'Fatmagül: A Força do Amor S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/198398.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65147, 4441, 'Fatmagül: A Força do Amor S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/198399.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65148, 4441, 'Fatmagül: A Força do Amor S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/198400.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65149, 4441, 'Fatmagül: A Força do Amor S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/198401.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65150, 4441, 'Fatmagül: A Força do Amor S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/198402.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65151, 4441, 'Fatmagül: A Força do Amor S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/198403.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65152, 4441, 'Fatmagül: A Força do Amor S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/198404.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65153, 4441, 'Fatmagül: A Força do Amor S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/198405.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65154, 4441, 'Fatmagül: A Força do Amor S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/198406.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65155, 4441, 'Fatmagül: A Força do Amor S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/198407.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65156, 4441, 'Fatmagül: A Força do Amor S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/198408.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65157, 4441, 'Fatmagül: A Força do Amor S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/198409.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65158, 4441, 'Fatmagül: A Força do Amor S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/198410.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65159, 4441, 'Fatmagül: A Força do Amor S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/198411.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65160, 4441, 'Fatmagül: A Força do Amor S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/198412.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65161, 4441, 'Fatmagül: A Força do Amor S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/198413.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65162, 4441, 'Fatmagül: A Força do Amor S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/198414.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65163, 4441, 'Fatmagül: A Força do Amor S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/198415.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65164, 4441, 'Fatmagül: A Força do Amor S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/198416.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65165, 4441, 'Fatmagül: A Força do Amor S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/198417.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65166, 4441, 'Fatmagül: A Força do Amor S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/198418.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65167, 4441, 'Fatmagül: A Força do Amor S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/198419.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65168, 4441, 'Fatmagül: A Força do Amor S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/198420.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65169, 4441, 'Fatmagül: A Força do Amor S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/198421.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65170, 4441, 'Fatmagül: A Força do Amor S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/198422.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65171, 4441, 'Fatmagül: A Força do Amor S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/198423.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65172, 4441, 'Fatmagül: A Força do Amor S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/198424.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65173, 4441, 'Fatmagül: A Força do Amor S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/198425.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65174, 4441, 'Fatmagül: A Força do Amor S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/198426.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65175, 4441, 'Fatmagül: A Força do Amor S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/198427.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65176, 4441, 'Fatmagül: A Força do Amor S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/198428.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65177, 4441, 'Fatmagül: A Força do Amor S01 E119', 'http://sinalprivado.info:80/series/1533784/1533784/198429.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65178, 4441, 'Fatmagül: A Força do Amor S01 E120', 'http://sinalprivado.info:80/series/1533784/1533784/198430.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65179, 4441, 'Fatmagül: A Força do Amor S01 E121', 'http://sinalprivado.info:80/series/1533784/1533784/198431.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65180, 4441, 'Fatmagül: A Força do Amor S01 E122', 'http://sinalprivado.info:80/series/1533784/1533784/198432.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65181, 4441, 'Fatmagül: A Força do Amor S01 E123', 'http://sinalprivado.info:80/series/1533784/1533784/198433.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65182, 4441, 'Fatmagül: A Força do Amor S01 E124', 'http://sinalprivado.info:80/series/1533784/1533784/198434.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65183, 4441, 'Fatmagül: A Força do Amor S01 E125', 'http://sinalprivado.info:80/series/1533784/1533784/198435.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65184, 4441, 'Fatmagül: A Força do Amor S01 E126', 'http://sinalprivado.info:80/series/1533784/1533784/198436.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65185, 4441, 'Fatmagül: A Força do Amor S01 E127', 'http://sinalprivado.info:80/series/1533784/1533784/198437.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65186, 4441, 'Fatmagül: A Força do Amor S01 E128', 'http://sinalprivado.info:80/series/1533784/1533784/198438.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65187, 4441, 'Fatmagül: A Força do Amor S01 E129', 'http://sinalprivado.info:80/series/1533784/1533784/198439.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65188, 4441, 'Fatmagül: A Força do Amor S01 E130', 'http://sinalprivado.info:80/series/1533784/1533784/198440.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65189, 4441, 'Fatmagül: A Força do Amor S01 E131', 'http://sinalprivado.info:80/series/1533784/1533784/198441.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65190, 4441, 'Fatmagül: A Força do Amor S01 E132', 'http://sinalprivado.info:80/series/1533784/1533784/198442.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65191, 4441, 'Fatmagül: A Força do Amor S01 E133', 'http://sinalprivado.info:80/series/1533784/1533784/198443.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65192, 4441, 'Fatmagül: A Força do Amor S01 E134', 'http://sinalprivado.info:80/series/1533784/1533784/198444.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65193, 4441, 'Fatmagül: A Força do Amor S01 E135', 'http://sinalprivado.info:80/series/1533784/1533784/198445.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65194, 4441, 'Fatmagül: A Força do Amor S01 E136', 'http://sinalprivado.info:80/series/1533784/1533784/198446.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65195, 4441, 'Fatmagül: A Força do Amor S01 E137', 'http://sinalprivado.info:80/series/1533784/1533784/198447.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65196, 4441, 'Fatmagül: A Força do Amor S01 E138', 'http://sinalprivado.info:80/series/1533784/1533784/198448.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65197, 4441, 'Fatmagül: A Força do Amor S01 E139', 'http://sinalprivado.info:80/series/1533784/1533784/198449.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65198, 4441, 'Fatmagül: A Força do Amor S01 E140', 'http://sinalprivado.info:80/series/1533784/1533784/198450.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65199, 4441, 'Fatmagül: A Força do Amor S01 E141', 'http://sinalprivado.info:80/series/1533784/1533784/198451.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65200, 4441, 'Fatmagül: A Força do Amor S01 E142', 'http://sinalprivado.info:80/series/1533784/1533784/198452.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65201, 4441, 'Fatmagül: A Força do Amor S01 E143', 'http://sinalprivado.info:80/series/1533784/1533784/198453.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65202, 4441, 'Fatmagül: A Força do Amor S01 E144', 'http://sinalprivado.info:80/series/1533784/1533784/198454.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65203, 4441, 'Fatmagül: A Força do Amor S01 E145', 'http://sinalprivado.info:80/series/1533784/1533784/198455.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65204, 4441, 'Fatmagül: A Força do Amor S01 E146', 'http://sinalprivado.info:80/series/1533784/1533784/198456.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65205, 4441, 'Fatmagül: A Força do Amor S01 E147', 'http://sinalprivado.info:80/series/1533784/1533784/198457.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65206, 4441, 'Fatmagül: A Força do Amor S01 E148', 'http://sinalprivado.info:80/series/1533784/1533784/198458.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65207, 4441, 'Fatmagül: A Força do Amor S01 E149', 'http://sinalprivado.info:80/series/1533784/1533784/198459.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65208, 4441, 'Fatmagül: A Força do Amor S01 E150', 'http://sinalprivado.info:80/series/1533784/1533784/198460.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65209, 4441, 'Fatmagül: A Força do Amor S01 E151', 'http://sinalprivado.info:80/series/1533784/1533784/198461.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65210, 4441, 'Fatmagül: A Força do Amor S01 E152', 'http://sinalprivado.info:80/series/1533784/1533784/198462.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65211, 4441, 'Fatmagül: A Força do Amor S01 E153', 'http://sinalprivado.info:80/series/1533784/1533784/198463.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65212, 4441, 'Fatmagül: A Força do Amor S01 E154', 'http://sinalprivado.info:80/series/1533784/1533784/198464.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65213, 4441, 'Fatmagül: A Força do Amor S01 E155', 'http://sinalprivado.info:80/series/1533784/1533784/198465.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65214, 4441, 'Fatmagül: A Força do Amor S01 E156', 'http://sinalprivado.info:80/series/1533784/1533784/198466.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65215, 4441, 'Fatmagül: A Força do Amor S01 E157', 'http://sinalprivado.info:80/series/1533784/1533784/198467.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65216, 4441, 'Fatmagül: A Força do Amor S01 E158', 'http://sinalprivado.info:80/series/1533784/1533784/198468.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65217, 4441, 'Fatmagül: A Força do Amor S01 E159', 'http://sinalprivado.info:80/series/1533784/1533784/198469.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65218, 4441, 'Fatmagül: A Força do Amor S01 E160', 'http://sinalprivado.info:80/series/1533784/1533784/198470.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65219, 4441, 'Fatmagül: A Força do Amor S01 E161', 'http://sinalprivado.info:80/series/1533784/1533784/198471.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65220, 4441, 'Fatmagül: A Força do Amor S01 E162', 'http://sinalprivado.info:80/series/1533784/1533784/198472.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65221, 4441, 'Fatmagül: A Força do Amor S01 E163', 'http://sinalprivado.info:80/series/1533784/1533784/198473.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65222, 4441, 'Fatmagül: A Força do Amor S01 E164', 'http://sinalprivado.info:80/series/1533784/1533784/198474.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65223, 4441, 'Fatmagül: A Força do Amor S01 E165', 'http://sinalprivado.info:80/series/1533784/1533784/198475.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65224, 4441, 'Fatmagül: A Força do Amor S01 E166', 'http://sinalprivado.info:80/series/1533784/1533784/198476.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65225, 4441, 'Fatmagül: A Força do Amor S01 E167', 'http://sinalprivado.info:80/series/1533784/1533784/198477.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65226, 4441, 'Fatmagül: A Força do Amor S01 E168', 'http://sinalprivado.info:80/series/1533784/1533784/198478.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65227, 4441, 'Fatmagül: A Força do Amor S01 E169', 'http://sinalprivado.info:80/series/1533784/1533784/198479.mp4', 'http://gstaticontent.com/images/5f17f4e2e400b597f665a47507ef8f56.jpg'),
(65228, 4442, 'A Culpa é da Carlota S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170568.mp4', 'http://timg.bdta.pro/images/adf842b2968caa6e25761743b64c983d.jpg'),
(65229, 4442, 'A Culpa é da Carlota S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170569.mp4', 'http://timg.bdta.pro/images/bcb55a029d61e3bc018d299a4af7028e.jpg'),
(65230, 4442, 'A Culpa é da Carlota S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170570.mp4', 'http://timg.bdta.pro/images/74f1e7782a2147951a0a431d0f3815ae.jpg'),
(65231, 4442, 'A Culpa é da Carlota S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170571.mp4', 'http://timg.bdta.pro/images/fd594249201e9eb0bbc7d274a1c535be.jpg'),
(65232, 4442, 'A Culpa é da Carlota S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170572.mp4', 'http://timg.bdta.pro/images/8d984e32563d497ab59513dc76097c04.jpg'),
(65233, 4442, 'A Culpa é da Carlota S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170573.mp4', 'http://timg.bdta.pro/images/528c2d818173bcaec08a097e3731302b.jpg'),
(65234, 4442, 'A Culpa é da Carlota S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170574.mp4', 'http://timg.bdta.pro/images/4325033d63f8b0c976dd6fcd400de719.jpg'),
(65235, 4442, 'A Culpa é da Carlota S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170575.mp4', 'http://timg.bdta.pro/images/9e61bbf9527d5aa47d8f6e529c76079f.jpg'),
(65236, 4442, 'A Culpa é da Carlota S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170576.mp4', 'http://gstaticontent.com/images/3a38cd715d2e093ce5d28d24391b01e6.jpg'),
(65237, 4442, 'A Culpa é da Carlota S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170577.mp4', 'http://gstaticontent.com/images/3a38cd715d2e093ce5d28d24391b01e6.jpg'),
(65238, 4442, 'A Culpa é da Carlota S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170578.mp4', 'http://gstaticontent.com/images/3a38cd715d2e093ce5d28d24391b01e6.jpg'),
(65239, 4442, 'A Culpa é da Carlota S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170579.mp4', 'http://gstaticontent.com/images/3a38cd715d2e093ce5d28d24391b01e6.jpg'),
(65240, 4442, 'A Culpa é da Carlota S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/170580.mp4', 'http://gstaticontent.com/images/3a38cd715d2e093ce5d28d24391b01e6.jpg'),
(65241, 4443, 'A Culpa é da Carlota S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170581.mp4', 'http://gstaticontent.com/images/3a38cd715d2e093ce5d28d24391b01e6.jpg'),
(65242, 4443, 'A Culpa é da Carlota S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170582.mp4', 'http://gstaticontent.com/images/3a38cd715d2e093ce5d28d24391b01e6.jpg'),
(65243, 4443, 'A Culpa é da Carlota S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170583.mp4', 'http://gstaticontent.com/images/3a38cd715d2e093ce5d28d24391b01e6.jpg'),
(65244, 4443, 'A Culpa é da Carlota S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170584.mp4', 'http://gstaticontent.com/images/3a38cd715d2e093ce5d28d24391b01e6.jpg'),
(65245, 4443, 'A Culpa é da Carlota S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170585.mp4', 'http://gstaticontent.com/images/3a38cd715d2e093ce5d28d24391b01e6.jpg'),
(65246, 4443, 'A Culpa é da Carlota S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170586.mp4', 'http://gstaticontent.com/images/3a38cd715d2e093ce5d28d24391b01e6.jpg'),
(65247, 4443, 'A Culpa é da Carlota S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170587.mp4', 'http://gstaticontent.com/images/3a38cd715d2e093ce5d28d24391b01e6.jpg'),
(65248, 4443, 'A Culpa é da Carlota S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170588.mp4', 'http://gstaticontent.com/images/3a38cd715d2e093ce5d28d24391b01e6.jpg'),
(65249, 4443, 'A Culpa é da Carlota S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170589.mp4', 'http://gstaticontent.com/images/3a38cd715d2e093ce5d28d24391b01e6.jpg'),
(65250, 4443, 'A Culpa é da Carlota S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170590.mp4', 'http://gstaticontent.com/images/3a38cd715d2e093ce5d28d24391b01e6.jpg'),
(65251, 4443, 'A Culpa é da Carlota S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170591.mp4', 'http://gstaticontent.com/images/3a38cd715d2e093ce5d28d24391b01e6.jpg'),
(65252, 4443, 'A Culpa é da Carlota S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170592.mp4', 'http://gstaticontent.com/images/3a38cd715d2e093ce5d28d24391b01e6.jpg'),
(65253, 4444, 'A Teacher S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154420.mp4', 'http://timg.bdta.pro/images/32b35487e700fde039ae495fbd490574.jpg'),
(65254, 4444, 'A Teacher S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154421.mp4', 'http://timg.bdta.pro/images/a238d6b5e0f6a6c2abdb524926e4f1c5.jpg'),
(65255, 4444, 'A Teacher S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154422.mp4', 'http://timg.bdta.pro/images/954eef22dd0a5eb2b13810a58c49e734.jpg'),
(65256, 4444, 'A Teacher S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154423.mp4', 'http://timg.bdta.pro/images/a918591eb3d95b73b695ec41ac1b7134.jpg'),
(65257, 4444, 'A Teacher S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154424.mp4', 'http://timg.bdta.pro/images/786c5f3cc5fe2f5a4d8002e685143b7f.jpg'),
(65258, 4444, 'A Teacher S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154425.mp4', 'http://timg.bdta.pro/images/7de048a16c1c7701dd9579e34ff9a3de.jpg'),
(65259, 4444, 'A Teacher S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154426.mp4', 'http://timg.bdta.pro/images/2f2072c06dd92021ac3da6d7c63095f2.jpg'),
(65260, 4444, 'A Teacher S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154427.mp4', 'http://timg.bdta.pro/images/3ad97b7d47a7ba0370e55e8c97c0d90b.jpg'),
(65261, 4444, 'A Teacher S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154428.mp4', 'http://timg.bdta.pro/images/a5b86af686fd52b93097a2368991e700.jpg'),
(65262, 4444, 'A Teacher S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154429.mp4', 'http://timg.bdta.pro/images/747f22dd6a0881ccf60478359582a996.jpg'),
(65263, 4445, 'A Tia é Top S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202598.mp4', 'http://gstaticontent.com/images/bf9d923656d18cbefdbcc23ce39c59ba.jpg'),
(65264, 4445, 'A Tia é Top S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202599.mp4', 'http://gstaticontent.com/images/bf9d923656d18cbefdbcc23ce39c59ba.jpg'),
(65265, 4445, 'A Tia é Top S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202600.mp4', 'http://gstaticontent.com/images/bf9d923656d18cbefdbcc23ce39c59ba.jpg'),
(65266, 4445, 'A Tia é Top S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202601.mp4', 'http://gstaticontent.com/images/bf9d923656d18cbefdbcc23ce39c59ba.jpg'),
(65267, 4445, 'A Tia é Top S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202602.mp4', 'http://gstaticontent.com/images/bf9d923656d18cbefdbcc23ce39c59ba.jpg'),
(65268, 4445, 'A Tia é Top S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202603.mp4', 'http://gstaticontent.com/images/bf9d923656d18cbefdbcc23ce39c59ba.jpg'),
(65269, 4445, 'A Tia é Top S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202604.mp4', 'http://gstaticontent.com/images/bf9d923656d18cbefdbcc23ce39c59ba.jpg'),
(65270, 4445, 'A Tia é Top S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202605.mp4', 'http://gstaticontent.com/images/bf9d923656d18cbefdbcc23ce39c59ba.jpg'),
(65271, 4446, 'A Tia é Top S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202606.mp4', 'http://gstaticontent.com/images/bf9d923656d18cbefdbcc23ce39c59ba.jpg'),
(65272, 4446, 'A Tia é Top S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202607.mp4', 'http://gstaticontent.com/images/bf9d923656d18cbefdbcc23ce39c59ba.jpg'),
(65273, 4446, 'A Tia é Top S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202608.mp4', 'http://gstaticontent.com/images/bf9d923656d18cbefdbcc23ce39c59ba.jpg'),
(65274, 4446, 'A Tia é Top S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202609.mp4', 'http://gstaticontent.com/images/bf9d923656d18cbefdbcc23ce39c59ba.jpg'),
(65275, 4446, 'A Tia é Top S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202610.mp4', 'http://gstaticontent.com/images/bf9d923656d18cbefdbcc23ce39c59ba.jpg'),
(65276, 4446, 'A Tia é Top S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202611.mp4', 'http://gstaticontent.com/images/bf9d923656d18cbefdbcc23ce39c59ba.jpg'),
(65277, 4446, 'A Tia é Top S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202612.mp4', 'http://gstaticontent.com/images/bf9d923656d18cbefdbcc23ce39c59ba.jpg'),
(65278, 4446, 'A Tia é Top S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202613.mp4', 'http://gstaticontent.com/images/bf9d923656d18cbefdbcc23ce39c59ba.jpg'),
(65279, 4447, 'Ana Pimentinha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174876.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65280, 4447, 'Ana Pimentinha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174877.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65281, 4447, 'Ana Pimentinha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174878.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65282, 4447, 'Ana Pimentinha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174879.mp4', 'http://timg.bdta.pro/images/44b6935f669fc29ac9d7d064ca731781.jpg'),
(65283, 4447, 'Ana Pimentinha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174880.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65284, 4447, 'Ana Pimentinha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174881.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65285, 4447, 'Ana Pimentinha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174882.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65286, 4447, 'Ana Pimentinha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174883.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65287, 4447, 'Ana Pimentinha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174884.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65288, 4447, 'Ana Pimentinha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174885.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65289, 4447, 'Ana Pimentinha S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/174886.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65290, 4447, 'Ana Pimentinha S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/174887.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65291, 4447, 'Ana Pimentinha S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/174888.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65292, 4448, 'Ana Pimentinha S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174889.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65293, 4448, 'Ana Pimentinha S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174890.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65294, 4448, 'Ana Pimentinha S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174891.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65295, 4448, 'Ana Pimentinha S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174892.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65296, 4448, 'Ana Pimentinha S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174893.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65297, 4448, 'Ana Pimentinha S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174894.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65298, 4448, 'Ana Pimentinha S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174895.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65299, 4448, 'Ana Pimentinha S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174896.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65300, 4448, 'Ana Pimentinha S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174897.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65301, 4448, 'Ana Pimentinha S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174898.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65302, 4448, 'Ana Pimentinha S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/174899.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65303, 4448, 'Ana Pimentinha S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/174900.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65304, 4448, 'Ana Pimentinha S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/174901.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65305, 4449, 'Ana Pimentinha S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174902.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65306, 4449, 'Ana Pimentinha S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174903.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65307, 4449, 'Ana Pimentinha S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174904.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65308, 4449, 'Ana Pimentinha S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174905.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65309, 4449, 'Ana Pimentinha S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174906.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65310, 4449, 'Ana Pimentinha S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174907.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65311, 4449, 'Ana Pimentinha S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174908.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65312, 4449, 'Ana Pimentinha S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174909.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65313, 4449, 'Ana Pimentinha S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174910.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65314, 4449, 'Ana Pimentinha S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174911.mp4', 'http://timg.bdta.pro/images/61faa77e89d56c66fd3e644512495b05.jpg'),
(65315, 4449, 'Ana Pimentinha S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/174912.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65316, 4449, 'Ana Pimentinha S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/174913.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65317, 4449, 'Ana Pimentinha S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/174914.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65318, 4449, 'Ana Pimentinha S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/174915.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65319, 4449, 'Ana Pimentinha S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/174916.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65320, 4449, 'Ana Pimentinha S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/174917.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65321, 4449, 'Ana Pimentinha S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/174918.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65322, 4449, 'Ana Pimentinha S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/174919.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65323, 4450, 'Ana Pimentinha S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174920.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65324, 4450, 'Ana Pimentinha S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174921.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65325, 4450, 'Ana Pimentinha S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174922.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65326, 4450, 'Ana Pimentinha S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174923.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65327, 4450, 'Ana Pimentinha S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174924.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65328, 4450, 'Ana Pimentinha S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174925.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65329, 4450, 'Ana Pimentinha S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174926.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65330, 4450, 'Ana Pimentinha S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174927.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65331, 4450, 'Ana Pimentinha S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174928.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65332, 4450, 'Ana Pimentinha S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174929.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65333, 4450, 'Ana Pimentinha S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/174930.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65334, 4450, 'Ana Pimentinha S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/174931.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65335, 4450, 'Ana Pimentinha S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/174932.mp4', 'http://gstaticontent.com/images/8b82d35a2059c0c3f4c732ef17e7a4f4.jpg'),
(65336, 4451, 'As Aventuras de Jackie Chan S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154430.mp4', 'http://timg.bdta.pro/images/7571abafee90b54a6e9386a30d2d9bc1.jpg'),
(65337, 4451, 'As Aventuras de Jackie Chan S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154431.mp4', 'http://timg.bdta.pro/images/f69f5c25030eda4bb23bb1f567e3fc3d.jpg'),
(65338, 4451, 'As Aventuras de Jackie Chan S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154432.mp4', 'http://timg.bdta.pro/images/cfc73924e3bcc5e68837b85a0cde8a14.jpg'),
(65339, 4451, 'As Aventuras de Jackie Chan S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154433.mp4', 'http://timg.bdta.pro/images/7f65114aa617e2062d9c444315f03332.jpg'),
(65340, 4451, 'As Aventuras de Jackie Chan S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154434.mp4', 'http://timg.bdta.pro/images/f1e2ee646e7cdac9b31199c288f196bd.jpg'),
(65341, 4451, 'As Aventuras de Jackie Chan S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154435.mp4', 'http://timg.bdta.pro/images/4afd91c21ad93ae4ad766cda93e25223.jpg'),
(65342, 4451, 'As Aventuras de Jackie Chan S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154436.mp4', 'http://timg.bdta.pro/images/20485b1eaebfe9eb6448fb1d4aa0295d.jpg'),
(65343, 4451, 'As Aventuras de Jackie Chan S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154437.mp4', 'http://timg.bdta.pro/images/73f884a0ccacfdb3f72cafc09de62c0e.jpg'),
(65344, 4451, 'As Aventuras de Jackie Chan S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154438.mp4', 'http://timg.bdta.pro/images/1d55a0f41cbe33b8c7225b4913ac67aa.jpg'),
(65345, 4451, 'As Aventuras de Jackie Chan S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154439.mp4', 'http://timg.bdta.pro/images/57ae4d9923d07b2c4fe199ad420cdbad.jpg'),
(65346, 4451, 'As Aventuras de Jackie Chan S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/154440.mp4', 'http://timg.bdta.pro/images/9a5b538384613fc117f2ad6151d08655.jpg'),
(65347, 4451, 'As Aventuras de Jackie Chan S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/154441.mp4', 'http://timg.bdta.pro/images/d096578a3eca4068782aad0a47a85b56.jpg'),
(65348, 4451, 'As Aventuras de Jackie Chan S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/154442.mp4', 'http://timg.bdta.pro/images/3888c9d329b336e483b4cfec9774e63c.jpg'),
(65349, 4452, 'As Aventuras de Jackie Chan S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154443.mp4', 'http://timg.bdta.pro/images/acd2120b95df28282634135a399584bb.jpg'),
(65350, 4452, 'As Aventuras de Jackie Chan S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154444.mp4', 'http://timg.bdta.pro/images/8c3f4b46981c698e1d75e731c740d1d6.jpg'),
(65351, 4452, 'As Aventuras de Jackie Chan S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154445.mp4', 'http://timg.bdta.pro/images/8e40b799123962531051c1779fbc9f20.jpg'),
(65352, 4452, 'As Aventuras de Jackie Chan S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154446.mp4', 'http://timg.bdta.pro/images/1eef8c1c87d633f0b6af35337d4e8894.jpg'),
(65353, 4452, 'As Aventuras de Jackie Chan S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154447.mp4', 'http://timg.bdta.pro/images/0fa78102f73ba14b6339b5b903a99135.jpg'),
(65354, 4452, 'As Aventuras de Jackie Chan S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154448.mp4', 'http://timg.bdta.pro/images/d8aa17024567f931fd36ab6e3a22d476.jpg'),
(65355, 4452, 'As Aventuras de Jackie Chan S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154449.mp4', 'http://timg.bdta.pro/images/48b4f921c746e0906cc28d92342d0fc8.jpg'),
(65356, 4452, 'As Aventuras de Jackie Chan S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154450.mp4', 'http://timg.bdta.pro/images/e1c9ebb9ba3f7ac97508d57e819723fa.jpg'),
(65357, 4452, 'As Aventuras de Jackie Chan S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154451.mp4', 'http://timg.bdta.pro/images/16fd178840d2988e150813cce981a76d.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(65358, 4452, 'As Aventuras de Jackie Chan S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154452.mp4', 'http://timg.bdta.pro/images/4b267ab8721cfd986fba5b1549fba200.jpg'),
(65359, 4452, 'As Aventuras de Jackie Chan S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/154453.mp4', 'http://timg.bdta.pro/images/98ccc847000541e82e1e86981a11a953.jpg'),
(65360, 4452, 'As Aventuras de Jackie Chan S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/154454.mp4', 'http://timg.bdta.pro/images/dad0f2b89d0a2f7577d9bcccdbca5eca.jpg'),
(65361, 4452, 'As Aventuras de Jackie Chan S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/154455.mp4', 'http://timg.bdta.pro/images/bec539ed22e399cb9debc2f9c4dce965.jpg'),
(65362, 4452, 'As Aventuras de Jackie Chan S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/154456.mp4', 'http://timg.bdta.pro/images/d06458aa7e0754a59d7e50ffd7dbc7f1.jpg'),
(65363, 4452, 'As Aventuras de Jackie Chan S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/154457.mp4', 'http://timg.bdta.pro/images/5f5e440e10edc3d1a09868099ab5f09a.jpg'),
(65364, 4452, 'As Aventuras de Jackie Chan S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/154458.mp4', 'http://timg.bdta.pro/images/169fb20e50b04f89801eb6695be9f440.jpg'),
(65365, 4452, 'As Aventuras de Jackie Chan S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/154459.mp4', 'http://timg.bdta.pro/images/d4278af0de4cb220187e9e3ac1e86c9b.jpg'),
(65366, 4452, 'As Aventuras de Jackie Chan S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/154460.mp4', 'http://timg.bdta.pro/images/1b207e6342e5efc0e1d5a82f9ac811e4.jpg'),
(65367, 4452, 'As Aventuras de Jackie Chan S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/154461.mp4', 'http://timg.bdta.pro/images/32ae8cfe7c37abca12a3c09db11c2314.jpg'),
(65368, 4452, 'As Aventuras de Jackie Chan S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/154462.mp4', 'http://timg.bdta.pro/images/b0e94c00457022da8714a7b77d804340.jpg'),
(65369, 4452, 'As Aventuras de Jackie Chan S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/154463.mp4', 'http://timg.bdta.pro/images/295355e6ddefa827189efd89daba7c29.jpg'),
(65370, 4452, 'As Aventuras de Jackie Chan S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/154464.mp4', 'http://timg.bdta.pro/images/2405688b704e300b68f376a465f094b6.jpg'),
(65371, 4452, 'As Aventuras de Jackie Chan S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/154465.mp4', 'http://timg.bdta.pro/images/23eae003b5b8d16fb1fe5010254b7b88.jpg'),
(65372, 4452, 'As Aventuras de Jackie Chan S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/154466.mp4', 'http://timg.bdta.pro/images/dea4cd4d7c5ca8e853301564ec371fec.jpg'),
(65373, 4452, 'As Aventuras de Jackie Chan S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/154467.mp4', 'http://timg.bdta.pro/images/d6c515293ec5283c93a685d2967e145d.jpg'),
(65374, 4452, 'As Aventuras de Jackie Chan S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/154468.mp4', 'http://timg.bdta.pro/images/c96bf9d64a5c48b36dbc94d88a02ed46.jpg'),
(65375, 4452, 'As Aventuras de Jackie Chan S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/154469.mp4', 'http://timg.bdta.pro/images/c165c908c3a0104379551484bdd79f94.jpg'),
(65376, 4452, 'As Aventuras de Jackie Chan S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/154470.mp4', 'http://timg.bdta.pro/images/0ee02714a158d1d7088c7d2d82eb5b0e.jpg'),
(65377, 4452, 'As Aventuras de Jackie Chan S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/154471.mp4', 'http://timg.bdta.pro/images/31e81dea4b0783f1d57d33bba83b020d.jpg'),
(65378, 4452, 'As Aventuras de Jackie Chan S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/154472.mp4', 'http://timg.bdta.pro/images/975b6abaf056e5bf8da8c129d02260f5.jpg'),
(65379, 4452, 'As Aventuras de Jackie Chan S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/154473.mp4', 'http://timg.bdta.pro/images/7082b64bc1c6a7a700a364baaa17850a.jpg'),
(65380, 4452, 'As Aventuras de Jackie Chan S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/154474.mp4', 'http://timg.bdta.pro/images/89cd2b9b7538fa11b041210b9dec5f70.jpg'),
(65381, 4452, 'As Aventuras de Jackie Chan S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/154475.mp4', 'http://timg.bdta.pro/images/637a7f16a2bfc4ca517f108b11f2d940.jpg'),
(65382, 4452, 'As Aventuras de Jackie Chan S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/154476.mp4', 'http://timg.bdta.pro/images/a85be7e29cacd79e9a8414061fbbefee.jpg'),
(65383, 4452, 'As Aventuras de Jackie Chan S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/154477.mp4', 'http://timg.bdta.pro/images/4f7ed71505c51f05afcae6410e1b3be7.jpg'),
(65384, 4452, 'As Aventuras de Jackie Chan S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/154478.mp4', 'http://timg.bdta.pro/images/cc80fc3e73a9f64e7e6cd63197349cea.jpg'),
(65385, 4452, 'As Aventuras de Jackie Chan S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/154479.mp4', 'http://timg.bdta.pro/images/0ec745c4b5b337fcd038b3d2d7177290.jpg'),
(65386, 4452, 'As Aventuras de Jackie Chan S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/154480.mp4', 'http://timg.bdta.pro/images/551a48e2ba94a4ce5d1e377ea3b03138.jpg'),
(65387, 4452, 'As Aventuras de Jackie Chan S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/154481.mp4', 'http://timg.bdta.pro/images/636d4ac6dc2c75e413cde25debe0bde3.jpg'),
(65388, 4453, 'As Aventuras de Jackie Chan S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154482.mp4', 'http://timg.bdta.pro/images/3b7ec42ff17340de691025206bc3fa84.jpg'),
(65389, 4453, 'As Aventuras de Jackie Chan S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154483.mp4', 'http://timg.bdta.pro/images/681527d05ec7ab2bf0a74714a696ac8c.jpg'),
(65390, 4453, 'As Aventuras de Jackie Chan S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154484.mp4', 'http://timg.bdta.pro/images/30aef9846f1400f47c2d3dcaa9ab4766.jpg'),
(65391, 4453, 'As Aventuras de Jackie Chan S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154485.mp4', 'http://timg.bdta.pro/images/f84ab0ffbb03e6c9446c7b63703e7ae7.jpg'),
(65392, 4453, 'As Aventuras de Jackie Chan S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154486.mp4', 'http://timg.bdta.pro/images/c6dd116c66f649b380bc2a3a12d23e0d.jpg'),
(65393, 4453, 'As Aventuras de Jackie Chan S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154487.mp4', 'http://timg.bdta.pro/images/66a350a056917839f32f2421c15c2ecd.jpg'),
(65394, 4453, 'As Aventuras de Jackie Chan S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154488.mp4', 'http://timg.bdta.pro/images/143d1df0c7178cb9645b10efff03ddc0.jpg'),
(65395, 4453, 'As Aventuras de Jackie Chan S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154489.mp4', 'http://timg.bdta.pro/images/967a3a4c2619660da94bdfde4cd3f93b.jpg'),
(65396, 4453, 'As Aventuras de Jackie Chan S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154490.mp4', 'http://timg.bdta.pro/images/cc2d154d3512d9981fd24f02ea3cf2ba.jpg'),
(65397, 4453, 'As Aventuras de Jackie Chan S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154491.mp4', 'http://timg.bdta.pro/images/28ff4946355ec6e6dca524ab2f64a954.jpg'),
(65398, 4453, 'As Aventuras de Jackie Chan S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/154492.mp4', 'http://timg.bdta.pro/images/de6b4dd8907805643fe795d1628e79aa.jpg'),
(65399, 4453, 'As Aventuras de Jackie Chan S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/154493.mp4', 'http://timg.bdta.pro/images/bb59a7f5a939de1ec1366a7a08fabaf5.jpg'),
(65400, 4453, 'As Aventuras de Jackie Chan S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/154494.mp4', 'http://timg.bdta.pro/images/a7f6dbfc97d2ad8674d612f817bb5c08.jpg'),
(65401, 4453, 'As Aventuras de Jackie Chan S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/154495.mp4', 'http://timg.bdta.pro/images/22bec8b208790ac69b46fc8c0a71d58d.jpg'),
(65402, 4453, 'As Aventuras de Jackie Chan S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/154496.mp4', 'http://timg.bdta.pro/images/6ff4d536ffb8f77509c1f377b1be3aa6.jpg'),
(65403, 4453, 'As Aventuras de Jackie Chan S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/154497.mp4', 'http://timg.bdta.pro/images/63c03ecbd92ba9d6d1ae03711c555763.jpg'),
(65404, 4453, 'As Aventuras de Jackie Chan S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/154498.mp4', 'http://timg.bdta.pro/images/10d278619266bebff3b4a3ce977fbad6.jpg'),
(65405, 4454, 'As Aventuras de Jackie Chan S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154499.mp4', 'http://timg.bdta.pro/images/bd54974a9545635613c32619cb32b362.jpg'),
(65406, 4454, 'As Aventuras de Jackie Chan S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154500.mp4', 'http://timg.bdta.pro/images/97a3728565666bea33e3a4edceec5c56.jpg'),
(65407, 4454, 'As Aventuras de Jackie Chan S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154501.mp4', 'http://timg.bdta.pro/images/5ee1d96b56de5bcba2a4d16f703e2a65.jpg'),
(65408, 4454, 'As Aventuras de Jackie Chan S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154502.mp4', 'http://timg.bdta.pro/images/0483f64c3d5954d532618309b74d0bf3.jpg'),
(65409, 4454, 'As Aventuras de Jackie Chan S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154503.mp4', 'http://timg.bdta.pro/images/520fe3c046e13811fe83ce1109cb5396.jpg'),
(65410, 4454, 'As Aventuras de Jackie Chan S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154504.mp4', 'http://timg.bdta.pro/images/2d3317c51cbd81bffe927e4f5d281297.jpg'),
(65411, 4454, 'As Aventuras de Jackie Chan S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154505.mp4', 'http://timg.bdta.pro/images/fb6381ece870345684edc69044cc4c6a.jpg'),
(65412, 4454, 'As Aventuras de Jackie Chan S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154506.mp4', 'http://timg.bdta.pro/images/7993c5555cc39fb5569c4979543499c5.jpg'),
(65413, 4454, 'As Aventuras de Jackie Chan S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154507.mp4', 'http://timg.bdta.pro/images/de2d57d9f0d5b2bdaaa32ddfe7d3ad4a.jpg'),
(65414, 4454, 'As Aventuras de Jackie Chan S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154508.mp4', 'http://timg.bdta.pro/images/c4727efff232e99890b52e788f9b200d.jpg'),
(65415, 4454, 'As Aventuras de Jackie Chan S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/154509.mp4', 'http://timg.bdta.pro/images/4229f4bab7b1763290b726119e82e94f.jpg'),
(65416, 4454, 'As Aventuras de Jackie Chan S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/154510.mp4', 'http://timg.bdta.pro/images/5eee9b09a33380171edbe5e77f257b78.jpg'),
(65417, 4454, 'As Aventuras de Jackie Chan S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/154511.mp4', 'http://timg.bdta.pro/images/d3a90d968d23e2443ccbae01f8c5c6cc.jpg'),
(65418, 4455, 'As Aventuras de Jackie Chan S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154512.mp4', 'http://timg.bdta.pro/images/0268ad4e0d3acab495f156e24e333324.jpg'),
(65419, 4455, 'As Aventuras de Jackie Chan S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154513.mp4', 'http://timg.bdta.pro/images/3ba1b8db84445562b21f5333550b6658.jpg'),
(65420, 4455, 'As Aventuras de Jackie Chan S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154514.mp4', 'http://timg.bdta.pro/images/ae0ec5f644188abcc3bd66c6d3f91ded.jpg'),
(65421, 4455, 'As Aventuras de Jackie Chan S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154515.mp4', 'http://timg.bdta.pro/images/6e223626c7321b2e007ab788cbe95018.jpg'),
(65422, 4455, 'As Aventuras de Jackie Chan S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154516.mp4', 'http://timg.bdta.pro/images/ee1ea16cd2efe45f14ea4242eaa69a2a.jpg'),
(65423, 4455, 'As Aventuras de Jackie Chan S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154517.mp4', 'http://timg.bdta.pro/images/d1773787c9cb9f2b0bda272d7210ac01.jpg'),
(65424, 4455, 'As Aventuras de Jackie Chan S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154518.mp4', 'http://timg.bdta.pro/images/1128c219a8fd60d25e7178a1b5c69566.jpg'),
(65425, 4455, 'As Aventuras de Jackie Chan S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154519.mp4', 'http://timg.bdta.pro/images/bd7514053b5d087a83dc1c7c9501dc4e.jpg'),
(65426, 4455, 'As Aventuras de Jackie Chan S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154520.mp4', 'http://timg.bdta.pro/images/8a7dd4777468e4bb05b0c66823e71dd0.jpg'),
(65427, 4455, 'As Aventuras de Jackie Chan S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154521.mp4', 'http://timg.bdta.pro/images/0c7c57f0c830e8b5da0110431325dcad.jpg'),
(65428, 4455, 'As Aventuras de Jackie Chan S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/154522.mp4', 'http://timg.bdta.pro/images/cd87255026d3cd6c74ecdca72a91345a.jpg'),
(65429, 4455, 'As Aventuras de Jackie Chan S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/154523.mp4', 'http://timg.bdta.pro/images/cb4020e738202705c5f186f19ef26e09.jpg'),
(65430, 4455, 'As Aventuras de Jackie Chan S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/154524.mp4', 'http://timg.bdta.pro/images/d703e557c4107acb73306f22ab2bf3d2.jpg'),
(65431, 4456, 'De Volta aos Rafters S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154525.mp4', 'http://timg.bdta.pro/images/98469bd28deb645e659b7aa02adbea01.jpg'),
(65432, 4456, 'De Volta aos Rafters S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154526.mp4', 'http://gstaticontent.com/images/5d7a87cac3496a82fb8fbaeebb607fc1.jpg'),
(65433, 4456, 'De Volta aos Rafters S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154527.mp4', 'http://gstaticontent.com/images/5d7a87cac3496a82fb8fbaeebb607fc1.jpg'),
(65434, 4456, 'De Volta aos Rafters S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154528.mp4', 'http://gstaticontent.com/images/5d7a87cac3496a82fb8fbaeebb607fc1.jpg'),
(65435, 4456, 'De Volta aos Rafters S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154529.mp4', 'http://gstaticontent.com/images/5d7a87cac3496a82fb8fbaeebb607fc1.jpg'),
(65436, 4456, 'De Volta aos Rafters S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154530.mp4', 'http://gstaticontent.com/images/5d7a87cac3496a82fb8fbaeebb607fc1.jpg'),
(65437, 4457, 'o Pimentinha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154531.mp4', 'http://timg.bdta.pro/images/c88d9c91671294c485a2cced2157fd52.jpg'),
(65438, 4457, 'o Pimentinha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154532.mp4', 'http://timg.bdta.pro/images/5fa4f1980d39e039c3e15b8010b892e0.jpg'),
(65439, 4457, 'o Pimentinha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154533.mp4', 'http://timg.bdta.pro/images/12eaf105bcbce03b55813d1b12cdafa7.jpg'),
(65440, 4457, 'o Pimentinha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154534.mp4', 'http://timg.bdta.pro/images/dc39c10e8412033ef4c36fac1f31395b.jpg'),
(65441, 4457, 'o Pimentinha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154535.mp4', 'http://timg.bdta.pro/images/9e3151680d0ce1cdaf6a5383c89608b4.jpg'),
(65442, 4457, 'o Pimentinha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154536.mp4', 'http://timg.bdta.pro/images/300944cce6f3b80ff60d43705faafd35.jpg'),
(65443, 4457, 'o Pimentinha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154537.mp4', 'http://timg.bdta.pro/images/cce98607404831cbc6275416b00df4ac.jpg'),
(65444, 4457, 'o Pimentinha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154538.mp4', 'http://timg.bdta.pro/images/0ccfc4f79517388171031c9f7dc46613.jpg'),
(65445, 4457, 'o Pimentinha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154539.mp4', 'http://timg.bdta.pro/images/e63f7c7e4bd2c48296dcc9ad75199fc4.jpg'),
(65446, 4457, 'o Pimentinha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154540.mp4', 'http://timg.bdta.pro/images/1f9d9aa77beb45929a5b106479dd982b.jpg'),
(65447, 4457, 'o Pimentinha S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/154541.mp4', 'http://timg.bdta.pro/images/fc960b6c517d51e501c8a308da648444.jpg'),
(65448, 4457, 'o Pimentinha S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/154542.mp4', 'http://timg.bdta.pro/images/474490834fcceb19515ab509ec41e248.jpg'),
(65449, 4457, 'o Pimentinha S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/154543.mp4', 'http://timg.bdta.pro/images/ee50f14a373a3e173b2b29b237e3ec8a.jpg'),
(65450, 4458, 'O Terráqueo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154544.mp4', 'http://timg.bdta.pro/images/1f153f20802381e3e5087938c3c11a24.jpg'),
(65451, 4458, 'O Terráqueo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154545.mp4', 'http://timg.bdta.pro/images/db9722e94aa4b898368c63741927513e.jpg'),
(65452, 4458, 'O Terráqueo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154546.mp4', 'http://timg.bdta.pro/images/2110876f625f8a6791addab6a2f5c2dc.jpg'),
(65453, 4458, 'O Terráqueo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154547.mp4', 'http://timg.bdta.pro/images/671aba2d2d023cfc24d21de5b6dbe27c.jpg'),
(65454, 4458, 'O Terráqueo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154548.mp4', 'http://timg.bdta.pro/images/af501c463a0fb16c59a5435a849e081f.jpg'),
(65455, 4458, 'O Terráqueo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154549.mp4', 'http://timg.bdta.pro/images/bd4eb1f53a65e18bbd8fdf30af6a31d4.jpg'),
(65456, 4458, 'O Terráqueo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154550.mp4', 'http://timg.bdta.pro/images/2c7ad4bde5b226da507ac3c49d13c02e.jpg'),
(65457, 4458, 'O Terráqueo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154551.mp4', 'http://timg.bdta.pro/images/b44642fc4f59f6f963c6210478e48bec.jpg'),
(65458, 4458, 'O Terráqueo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154552.mp4', 'http://timg.bdta.pro/images/5ddb4abd64394b2bc12317ff75ea2bed.jpg'),
(65459, 4458, 'O Terráqueo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154553.mp4', 'http://timg.bdta.pro/images/def9bcc306c256e857fb21162cdc2f2e.jpg'),
(65460, 4458, 'O Terráqueo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/154554.mp4', 'http://timg.bdta.pro/images/66db344940cbdaf51719448861d5df79.jpg'),
(65461, 4458, 'O Terráqueo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/154555.mp4', 'http://timg.bdta.pro/images/b39da40ddfedc05e9d769332abde8be6.jpg'),
(65462, 4458, 'O Terráqueo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/154556.mp4', 'http://timg.bdta.pro/images/6e7f6b5e74e9bb265266a3858dca5f2f.jpg'),
(65463, 4458, 'O Terráqueo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/154557.mp4', 'http://timg.bdta.pro/images/5623f89fe271c15be9bf504adec3c04e.jpg'),
(65464, 4458, 'O Terráqueo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/154558.mp4', 'http://timg.bdta.pro/images/6c4b1eb2c152d858c3691af2713ab8d2.jpg'),
(65465, 4458, 'O Terráqueo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/154559.mp4', 'http://timg.bdta.pro/images/8e570a9c4d315a586361e42071d0d9fa.jpg'),
(65466, 4459, 'He-Man e os Mestres do Universo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195381.mp4', 'http://timg.bdta.pro/images/36bb88f0e28d3ef139a3e2e32e2fa235.jpg'),
(65467, 4459, 'He-Man e os Mestres do Universo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195382.mp4', 'http://timg.bdta.pro/images/46c37d70e8a1d6165dffe154509c907c.jpg'),
(65468, 4459, 'He-Man e os Mestres do Universo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195383.mp4', 'http://timg.bdta.pro/images/faeed9931bb3657c1fda368aa3f5f3c8.jpg'),
(65469, 4459, 'He-Man e os Mestres do Universo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195384.mp4', 'http://timg.bdta.pro/images/72aa0f9c033dcb932ac6a5a0f0cc2507.jpg'),
(65470, 4459, 'He-Man e os Mestres do Universo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195385.mp4', 'http://timg.bdta.pro/images/2e120d42067ccdd6952b346218d81267.jpg'),
(65471, 4459, 'He-Man e os Mestres do Universo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195386.mp4', 'http://timg.bdta.pro/images/b336bd7af4478720a0cf58ce42aeb75d.jpg'),
(65472, 4459, 'He-Man e os Mestres do Universo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195387.mp4', 'http://timg.bdta.pro/images/8d8291bc9df57786fa2d9385dd3a1c7b.jpg'),
(65473, 4459, 'He-Man e os Mestres do Universo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195388.mp4', 'http://timg.bdta.pro/images/fd6a93a8474553afb08c4224219f3feb.jpg'),
(65474, 4459, 'He-Man e os Mestres do Universo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195389.mp4', 'http://timg.bdta.pro/images/ed7bd4bd3f57fc51aa24acb256c8fc44.jpg'),
(65475, 4459, 'He-Man e os Mestres do Universo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195390.mp4', 'http://timg.bdta.pro/images/f7d5bf8324f82150465180ee0079564d.jpg'),
(65476, 4460, 'He-Man e os Mestres do Universo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195391.mp4', 'http://gstaticontent.com/images/bb79d993b35b99478ef365731e81e1e9.jpg'),
(65477, 4460, 'He-Man e os Mestres do Universo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195392.mp4', 'http://gstaticontent.com/images/bb79d993b35b99478ef365731e81e1e9.jpg'),
(65478, 4460, 'He-Man e os Mestres do Universo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195393.mp4', 'http://gstaticontent.com/images/bb79d993b35b99478ef365731e81e1e9.jpg'),
(65479, 4460, 'He-Man e os Mestres do Universo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195394.mp4', 'http://gstaticontent.com/images/bb79d993b35b99478ef365731e81e1e9.jpg'),
(65480, 4460, 'He-Man e os Mestres do Universo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195395.mp4', 'http://gstaticontent.com/images/bb79d993b35b99478ef365731e81e1e9.jpg'),
(65481, 4460, 'He-Man e os Mestres do Universo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195396.mp4', 'http://gstaticontent.com/images/bb79d993b35b99478ef365731e81e1e9.jpg'),
(65482, 4460, 'He-Man e os Mestres do Universo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195397.mp4', 'http://gstaticontent.com/images/bb79d993b35b99478ef365731e81e1e9.jpg'),
(65483, 4460, 'He-Man e os Mestres do Universo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195398.mp4', 'http://timg.bdta.pro/images/f431c4f660a140410828bddc9d2ab797.jpg'),
(65484, 4461, 'He-Man e os Mestres do Universo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195399.mp4', 'http://timg.bdta.pro/images/83fa758afdc546175b0c9a0eafc4d46b.jpg'),
(65485, 4461, 'He-Man e os Mestres do Universo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195400.mp4', 'http://timg.bdta.pro/images/df3a2b67fb7fbd90fdbafd66f28b6d6d.jpg'),
(65486, 4461, 'He-Man e os Mestres do Universo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195401.mp4', 'http://timg.bdta.pro/images/959c7cc29bb3aae515a3796f5bc554b2.jpg'),
(65487, 4461, 'He-Man e os Mestres do Universo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195402.mp4', 'http://timg.bdta.pro/images/f325193f2024f0daf3b832d713072476.jpg'),
(65488, 4461, 'He-Man e os Mestres do Universo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195403.mp4', 'http://timg.bdta.pro/images/23de34edc67635ff87d2d25ed6e6d393.jpg'),
(65489, 4461, 'He-Man e os Mestres do Universo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195404.mp4', 'http://timg.bdta.pro/images/60b1925eac95e9b341f99790f746424e.jpg'),
(65490, 4461, 'He-Man e os Mestres do Universo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195405.mp4', 'http://timg.bdta.pro/images/5998b0ec206f6c9f1c216d7a961656f0.jpg'),
(65491, 4461, 'He-Man e os Mestres do Universo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195406.mp4', 'http://timg.bdta.pro/images/eaf2abb4140fcd2254a5f63c3249ad89.jpg'),
(65492, 4462, 'Instituto Voltaire S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154560.mp4', 'http://timg.bdta.pro/images/b47921c96ea42042ed8351e6852cf192.jpg'),
(65493, 4462, 'Instituto Voltaire S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154561.mp4', 'http://timg.bdta.pro/images/92bf4f2a78f522bb75fee419d3828e7b.jpg'),
(65494, 4462, 'Instituto Voltaire S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154562.mp4', 'http://timg.bdta.pro/images/423c7ecc55bc4b74ae873b50b3e481b1.jpg'),
(65495, 4462, 'Instituto Voltaire S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154563.mp4', 'http://timg.bdta.pro/images/8593906e7f858cb346b326aea6bc7922.jpg'),
(65496, 4462, 'Instituto Voltaire S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154564.mp4', 'http://timg.bdta.pro/images/4b9f656b28190e11f753dde2cb767bb3.jpg'),
(65497, 4462, 'Instituto Voltaire S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154565.mp4', 'http://timg.bdta.pro/images/7c3a783d315259848af3ec725f4e5597.jpg'),
(65498, 4462, 'Instituto Voltaire S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154566.mp4', 'http://timg.bdta.pro/images/3c7fa54e2cbaa525a56705ee10680a51.jpg'),
(65499, 4462, 'Instituto Voltaire S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154567.mp4', 'http://timg.bdta.pro/images/7f64ca79b9baec2b9c0480abfbd0b9cd.jpg'),
(65500, 4463, 'Losing Alice S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154568.mp4', 'http://timg.bdta.pro/images/f82bddc4a7fb14cc71fec4c9857a393e.jpg'),
(65501, 4463, 'Losing Alice S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154569.mp4', 'http://timg.bdta.pro/images/d14cf814b003db206c1b391083d67aa4.jpg'),
(65502, 4463, 'Losing Alice S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154570.mp4', 'http://timg.bdta.pro/images/f10de093f541cb0435e8ef0e24e52922.jpg'),
(65503, 4463, 'Losing Alice S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154571.mp4', 'http://timg.bdta.pro/images/b8e06d5bbb666ac7f07889392e0c1072.jpg'),
(65504, 4463, 'Losing Alice S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154572.mp4', 'http://timg.bdta.pro/images/3a1bfbdb73a03f67b577986913d86fa4.jpg'),
(65505, 4463, 'Losing Alice S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154573.mp4', 'http://timg.bdta.pro/images/2379ebef15e8c42f4168ade417c0abd2.jpg'),
(65506, 4463, 'Losing Alice S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154574.mp4', 'http://timg.bdta.pro/images/78ec414b68177ea78d82fa0208f6a5ad.jpg'),
(65507, 4463, 'Losing Alice S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154575.mp4', 'http://timg.bdta.pro/images/c39ddc73fe50689472a81d605eb0c354.jpg'),
(65508, 4464, 'Manda-chuva S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154576.mp4', 'http://timg.bdta.pro/images/bbb680da7793447f1c09d37202c3b66d.jpg'),
(65509, 4464, 'Manda-chuva S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154577.mp4', 'http://timg.bdta.pro/images/c6d47cb7ecf122110183327758a325bb.jpg'),
(65510, 4464, 'Manda-chuva S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154578.mp4', 'http://timg.bdta.pro/images/8ca41cd7b649aa536c4cd0e4c3f8c84f.jpg'),
(65511, 4464, 'Manda-chuva S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154579.mp4', 'http://timg.bdta.pro/images/b2f15e9880e143d91b6693dd9a2ad191.jpg'),
(65512, 4464, 'Manda-chuva S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154580.mp4', 'http://timg.bdta.pro/images/ceb03a474c75d94937035a7eafd499b6.jpg'),
(65513, 4464, 'Manda-chuva S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154581.mp4', 'http://timg.bdta.pro/images/b2417a85bb7f481998995014246c6db4.jpg'),
(65514, 4464, 'Manda-chuva S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154582.mp4', 'http://timg.bdta.pro/images/41ea251ad14d8137ee7e4ac5cc2b8f31.jpg'),
(65515, 4464, 'Manda-chuva S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154583.mp4', 'http://timg.bdta.pro/images/28aaa670282e549d1bb885032db4b305.jpg'),
(65516, 4464, 'Manda-chuva S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154584.mp4', 'http://timg.bdta.pro/images/e085d8577cde8b2f80716a26b8284ee7.jpg'),
(65517, 4464, 'Manda-chuva S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154585.mp4', 'http://timg.bdta.pro/images/4b55a00a70c04d5624d0e63448b7260b.jpg'),
(65518, 4464, 'Manda-chuva S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/154586.mp4', 'http://timg.bdta.pro/images/a1034cf9eed25d72e3ac1a11dab77a7a.jpg'),
(65519, 4464, 'Manda-chuva S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/154587.mp4', 'http://timg.bdta.pro/images/9b379af92e6d72c65faf38a9f513e252.jpg'),
(65520, 4464, 'Manda-chuva S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/154588.mp4', 'http://timg.bdta.pro/images/d3879d0a1816852f1bb24fa8994787de.jpg'),
(65521, 4464, 'Manda-chuva S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/154589.mp4', 'http://timg.bdta.pro/images/46b85cb6aba8a108bb20941a43ab2d23.jpg'),
(65522, 4464, 'Manda-chuva S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/154590.mp4', 'http://timg.bdta.pro/images/ac82889f0c081f7dba9d6392ddd95395.jpg'),
(65523, 4464, 'Manda-chuva S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/154591.mp4', 'http://timg.bdta.pro/images/065d5e200d172d1bcdd78ff7ea2717ac.jpg'),
(65524, 4464, 'Manda-chuva S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/154592.mp4', 'http://timg.bdta.pro/images/82729ce4458cdac017b8a6dd4378f6e3.jpg'),
(65525, 4464, 'Manda-chuva S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/154593.mp4', 'http://timg.bdta.pro/images/d51864fbb1134487b9d698f5d7495c2f.jpg'),
(65526, 4464, 'Manda-chuva S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/154594.mp4', 'http://timg.bdta.pro/images/21c1bd150ab14ecf4534a5c66f4f6a84.jpg'),
(65527, 4464, 'Manda-chuva S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/154595.mp4', 'http://timg.bdta.pro/images/4a7475dd1220bfddf8688abef77e115b.jpg'),
(65528, 4464, 'Manda-chuva S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/154596.mp4', 'http://timg.bdta.pro/images/119e5f783a62360f212298ab2af43b50.jpg'),
(65529, 4464, 'Manda-chuva S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/154597.mp4', 'http://timg.bdta.pro/images/119e5f783a62360f212298ab2af43b50.jpg'),
(65530, 4464, 'Manda-chuva S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/154598.mp4', 'http://timg.bdta.pro/images/6270977b4062108365c464a7cf6b14b4.jpg'),
(65531, 4464, 'Manda-chuva S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/154599.mp4', 'http://timg.bdta.pro/images/db24ceb33c57b2e6fb57afd8f5e372b9.jpg'),
(65532, 4464, 'Manda-chuva S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/154600.mp4', 'http://timg.bdta.pro/images/ffff501f08506e5a1e5fe9531f973e4a.jpg'),
(65533, 4464, 'Manda-chuva S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/154601.mp4', 'http://timg.bdta.pro/images/df84d6fe78ff5b0dec7cfcdbe2e0b554.jpg'),
(65534, 4464, 'Manda-chuva S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/154602.mp4', 'http://timg.bdta.pro/images/87beaf01d6b61ae4fadad5add4cb8505.jpg'),
(65535, 4464, 'Manda-chuva S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/154603.mp4', 'http://timg.bdta.pro/images/02c34ddc45fab446f242117284fe8ad4.jpg'),
(65536, 4464, 'Manda-chuva S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/154604.mp4', 'http://timg.bdta.pro/images/9fd032a8116e84eedc3232a550d888be.jpg'),
(65537, 4464, 'Manda-chuva S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/154605.mp4', 'http://timg.bdta.pro/images/6da6eb6fc4847dd360adeab859189a90.jpg'),
(65538, 4465, 'Marvel 616 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154606.mp4', 'http://timg.bdta.pro/images/4425e4fd9950e55a4901cfcf63e7cef8.jpg'),
(65539, 4465, 'Marvel 616 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154607.mp4', 'http://timg.bdta.pro/images/0265f5e7b9283a28b728f775ea0b6d71.jpg'),
(65540, 4465, 'Marvel 616 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154608.mp4', 'http://timg.bdta.pro/images/1eaa0f8a780a2479efa514cbd71461e0.jpg'),
(65541, 4465, 'Marvel 616 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154609.mp4', 'http://timg.bdta.pro/images/a063496d51328e9e89ef8f4a4a2a11e9.jpg'),
(65542, 4465, 'Marvel 616 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154610.mp4', 'http://timg.bdta.pro/images/5e15060367e20acffd6934830ac40293.jpg'),
(65543, 4465, 'Marvel 616 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154611.mp4', 'http://timg.bdta.pro/images/2b6dea8015479c62a8cc949f6ecad90d.jpg'),
(65544, 4465, 'Marvel 616 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154612.mp4', 'http://timg.bdta.pro/images/8d32e7c998594c49f8d181ed439d8796.jpg'),
(65545, 4465, 'Marvel 616 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154613.mp4', 'http://timg.bdta.pro/images/7096727de233d2c776b4a13c2ada348e.jpg'),
(65546, 4466, 'Mestres de Ferro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154614.mp4', 'http://gstaticontent.com/images/c6564ed4f0c2a2c0f928fba16a0f185f.jpg'),
(65547, 4466, 'Mestres de Ferro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154615.mp4', 'http://gstaticontent.com/images/c6564ed4f0c2a2c0f928fba16a0f185f.jpg'),
(65548, 4466, 'Mestres de Ferro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154616.mp4', 'http://gstaticontent.com/images/c6564ed4f0c2a2c0f928fba16a0f185f.jpg'),
(65549, 4466, 'Mestres de Ferro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154617.mp4', 'http://gstaticontent.com/images/c6564ed4f0c2a2c0f928fba16a0f185f.jpg'),
(65550, 4466, 'Mestres de Ferro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154618.mp4', 'http://gstaticontent.com/images/c6564ed4f0c2a2c0f928fba16a0f185f.jpg'),
(65551, 4466, 'Mestres de Ferro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154619.mp4', 'http://gstaticontent.com/images/c6564ed4f0c2a2c0f928fba16a0f185f.jpg'),
(65552, 4467, 'O Hospital S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154620.mp4', 'http://gstaticontent.com/images/178019c46a6f3a0822d8d02611e1860c.jpg'),
(65553, 4467, 'O Hospital S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154621.mp4', 'http://gstaticontent.com/images/178019c46a6f3a0822d8d02611e1860c.jpg'),
(65554, 4467, 'O Hospital S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154622.mp4', 'http://gstaticontent.com/images/178019c46a6f3a0822d8d02611e1860c.jpg'),
(65555, 4467, 'O Hospital S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154623.mp4', 'http://gstaticontent.com/images/178019c46a6f3a0822d8d02611e1860c.jpg'),
(65556, 4467, 'O Hospital S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154624.mp4', 'http://gstaticontent.com/images/178019c46a6f3a0822d8d02611e1860c.jpg'),
(65557, 4467, 'O Hospital S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154625.mp4', 'http://gstaticontent.com/images/178019c46a6f3a0822d8d02611e1860c.jpg'),
(65558, 4467, 'O Hospital S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154626.mp4', 'http://gstaticontent.com/images/178019c46a6f3a0822d8d02611e1860c.jpg'),
(65559, 4467, 'O Hospital S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154627.mp4', 'http://gstaticontent.com/images/178019c46a6f3a0822d8d02611e1860c.jpg'),
(65560, 4467, 'O Hospital S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154628.mp4', 'http://gstaticontent.com/images/178019c46a6f3a0822d8d02611e1860c.jpg'),
(65561, 4467, 'O Hospital S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154629.mp4', 'http://gstaticontent.com/images/178019c46a6f3a0822d8d02611e1860c.jpg'),
(65562, 4467, 'O Hospital S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/154630.mp4', 'http://gstaticontent.com/images/178019c46a6f3a0822d8d02611e1860c.jpg'),
(65563, 4467, 'O Hospital S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/154631.mp4', 'http://gstaticontent.com/images/178019c46a6f3a0822d8d02611e1860c.jpg'),
(65564, 4468, 'O Hospital S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/880382.mp4', 'http://gstaticontent.com/images/178019c46a6f3a0822d8d02611e1860c.jpg'),
(65565, 4468, 'O Hospital S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/880383.mp4', 'http://gstaticontent.com/images/178019c46a6f3a0822d8d02611e1860c.jpg'),
(65566, 4468, 'O Hospital S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/880384.mp4', 'http://gstaticontent.com/images/178019c46a6f3a0822d8d02611e1860c.jpg'),
(65567, 4468, 'O Hospital S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/880385.mp4', 'http://gstaticontent.com/images/178019c46a6f3a0822d8d02611e1860c.jpg'),
(65568, 4468, 'O Hospital S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/880386.mp4', 'http://gstaticontent.com/images/178019c46a6f3a0822d8d02611e1860c.jpg'),
(65569, 4468, 'O Hospital S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/880387.mp4', 'http://gstaticontent.com/images/178019c46a6f3a0822d8d02611e1860c.jpg'),
(65570, 4469, 'Jornada nas Estrelas: Subalternos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242797.mp4', 'http://timg.bdta.pro/images/8dee0ad390c05454a6bb9cec5739b6ed.jpg'),
(65571, 4469, 'Jornada nas Estrelas: Subalternos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242798.mp4', 'http://timg.bdta.pro/images/55b57c3ba1e72f847302aea3308a968e.jpg'),
(65572, 4469, 'Jornada nas Estrelas: Subalternos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242799.mp4', 'http://timg.bdta.pro/images/150351f5520176bb28b01dd9d6b5dd88.jpg'),
(65573, 4469, 'Jornada nas Estrelas: Subalternos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242800.mp4', 'http://timg.bdta.pro/images/b904999bb7685affedfd2d88ddc984f5.jpg'),
(65574, 4469, 'Jornada nas Estrelas: Subalternos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242801.mp4', 'http://timg.bdta.pro/images/d8c36e664f000d301359fedd588080e6.jpg'),
(65575, 4469, 'Jornada nas Estrelas: Subalternos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242802.mp4', 'http://timg.bdta.pro/images/723afee79d46353d243d443125c28271.jpg'),
(65576, 4469, 'Jornada nas Estrelas: Subalternos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242803.mp4', 'http://timg.bdta.pro/images/7a508a2ba23c5b710a8cb595000da593.jpg'),
(65577, 4469, 'Jornada nas Estrelas: Subalternos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242804.mp4', 'http://timg.bdta.pro/images/991119007bd54d1d72d292a65eb50768.jpg'),
(65578, 4469, 'Jornada nas Estrelas: Subalternos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242805.mp4', 'http://timg.bdta.pro/images/961dc135e5b7061cd446bef080575082.jpg'),
(65579, 4469, 'Jornada nas Estrelas: Subalternos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242806.mp4', 'http://timg.bdta.pro/images/7ce374de1fc1bbae30e8c54f7efb3f2b.jpg'),
(65580, 4470, 'Jornada nas Estrelas: Subalternos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zesRgabB6QBLohnQ97tOvIodwAF.jpg'),
(65581, 4470, 'Jornada nas Estrelas: Subalternos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jAOq6FIv25Tk0oJjQsE5JtpqvqK.jpg'),
(65582, 4470, 'Jornada nas Estrelas: Subalternos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ISFNYYREGb5Z9DwKdRxRZjya4.jpg'),
(65583, 4470, 'Jornada nas Estrelas: Subalternos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBwnEOSziZod2D6XKqOu6vAorMT.jpg'),
(65584, 4470, 'Jornada nas Estrelas: Subalternos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xSoRSb0pXfyKLDE43zI8BSnPayc.jpg'),
(65585, 4470, 'Jornada nas Estrelas: Subalternos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sU7F61UdLmNvVlL4VNdGWJMIzZy.jpg'),
(65586, 4470, 'Jornada nas Estrelas: Subalternos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nWP4Bkv4pCOmTiWFtFpVqavd2l9.jpg'),
(65587, 4470, 'Jornada nas Estrelas: Subalternos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yImQyvFcELANavOwaOj9mInyjKC.jpg'),
(65588, 4470, 'Jornada nas Estrelas: Subalternos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dbNgwjo6rnGQaMtwcGEJ6Y7bh5Y.jpg'),
(65589, 4470, 'Jornada nas Estrelas: Subalternos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c3hk6948lCQ6Kfzr2dxa5Xu30jB.jpg'),
(65590, 4471, 'Jornada nas Estrelas: Subalternos S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7jeFgztTp1NrzjzDTplu8jcnLsB.jpg'),
(65591, 4471, 'Jornada nas Estrelas: Subalternos S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lR7ZHOKR3Sl2pzcSauEf5fw13Cy.jpg'),
(65592, 4471, 'Jornada nas Estrelas: Subalternos S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xX5zqlqVqPXHlqcqVW7UnQwWmvW.jpg'),
(65593, 4471, 'Jornada nas Estrelas: Subalternos S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AuctpWAj1hQt334a4Wna98c4q5z.jpg'),
(65594, 4471, 'Jornada nas Estrelas: Subalternos S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cOMkC7tXkdpVyQ9pTGfeSZ9lbcT.jpg'),
(65595, 4471, 'Jornada nas Estrelas: Subalternos S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AealHSXAmWdGDQwEL6iUOdA2VKe.jpg'),
(65596, 4471, 'Jornada nas Estrelas: Subalternos S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ewWTuxG1d4NXJQaP9iQ8Jljob9d.jpg'),
(65597, 4471, 'Jornada nas Estrelas: Subalternos S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rZlZ7yO1zJr4tiYtnWnj7A8uL0S.jpg'),
(65598, 4471, 'Jornada nas Estrelas: Subalternos S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nYAKgYJHfxwVRTBl0P8e01bpphZ.jpg'),
(65599, 4472, 'Jornada nas Estrelas: Subalternos S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gVVCoxtNtU5fTTyGU1nGwrFl2f.jpg'),
(65600, 4472, 'Jornada nas Estrelas: Subalternos S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gVVCoxtNtU5fTTyGU1nGwrFl2f.jpg'),
(65601, 4472, 'Jornada nas Estrelas: Subalternos S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gVVCoxtNtU5fTTyGU1nGwrFl2f.jpg'),
(65602, 4472, 'Jornada nas Estrelas: Subalternos S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gVVCoxtNtU5fTTyGU1nGwrFl2f.jpg'),
(65603, 4472, 'Jornada nas Estrelas: Subalternos S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gVVCoxtNtU5fTTyGU1nGwrFl2f.jpg'),
(65604, 4472, 'Jornada nas Estrelas: Subalternos S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gVVCoxtNtU5fTTyGU1nGwrFl2f.jpg'),
(65605, 4472, 'Jornada nas Estrelas: Subalternos S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gVVCoxtNtU5fTTyGU1nGwrFl2f.jpg'),
(65606, 4472, 'Jornada nas Estrelas: Subalternos S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gVVCoxtNtU5fTTyGU1nGwrFl2f.jpg'),
(65607, 4472, 'Jornada nas Estrelas: Subalternos S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gVVCoxtNtU5fTTyGU1nGwrFl2f.jpg'),
(65608, 4472, 'Jornada nas Estrelas: Subalternos S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gVVCoxtNtU5fTTyGU1nGwrFl2f.jpg'),
(65609, 4473, 'Jornada nas Estrelas: Subalternos S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/491285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gVVCoxtNtU5fTTyGU1nGwrFl2f.jpg'),
(65610, 4473, 'Jornada nas Estrelas: Subalternos S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/491286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gVVCoxtNtU5fTTyGU1nGwrFl2f.jpg'),
(65611, 4473, 'Jornada nas Estrelas: Subalternos S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/492776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gVVCoxtNtU5fTTyGU1nGwrFl2f.jpg'),
(65612, 4473, 'Jornada nas Estrelas: Subalternos S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/499558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gVVCoxtNtU5fTTyGU1nGwrFl2f.jpg'),
(65613, 4473, 'Jornada nas Estrelas: Subalternos S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gVVCoxtNtU5fTTyGU1nGwrFl2f.jpg'),
(65614, 4473, 'Jornada nas Estrelas: Subalternos S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/509115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gVVCoxtNtU5fTTyGU1nGwrFl2f.jpg'),
(65615, 4473, 'Jornada nas Estrelas: Subalternos S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/515511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gVVCoxtNtU5fTTyGU1nGwrFl2f.jpg'),
(65616, 4473, 'Jornada nas Estrelas: Subalternos S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/523425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gVVCoxtNtU5fTTyGU1nGwrFl2f.jpg'),
(65617, 4473, 'Jornada nas Estrelas: Subalternos S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/523426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gVVCoxtNtU5fTTyGU1nGwrFl2f.jpg'),
(65618, 4473, 'Jornada nas Estrelas: Subalternos S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/639198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gVVCoxtNtU5fTTyGU1nGwrFl2f.jpg'),
(65619, 4474, 'The Circle S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179762.mp4', 'http://timg.bdta.pro/images/37a8f79e4a38ca9900767077668e630e.jpg'),
(65620, 4474, 'The Circle S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179763.mp4', 'http://timg.bdta.pro/images/5cb6c18f781dc13c05d6c58083f75c5f.jpg'),
(65621, 4474, 'The Circle S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179764.mp4', 'http://timg.bdta.pro/images/c502c250acf6fe49d85c5d9c6ccaf6b6.jpg'),
(65622, 4474, 'The Circle S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179765.mp4', 'http://timg.bdta.pro/images/5ba141f58fe83debee547cd56214294e.jpg'),
(65623, 4474, 'The Circle S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179766.mp4', 'http://timg.bdta.pro/images/6e86e96dd213ddff7a10b73258218074.jpg'),
(65624, 4474, 'The Circle S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179767.mp4', 'http://timg.bdta.pro/images/76780bcf185741c27b28771450390a32.jpg'),
(65625, 4474, 'The Circle S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179768.mp4', 'http://timg.bdta.pro/images/31237ea9ebb94a3f6ef24b6d9138db16.jpg'),
(65626, 4474, 'The Circle S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179769.mp4', 'http://timg.bdta.pro/images/1da9eacbdb0f6733ed3056ad3b877eed.jpg'),
(65627, 4474, 'The Circle S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179770.mp4', 'http://timg.bdta.pro/images/88656e181a91fa97cc7b24ca7088c5d7.jpg'),
(65628, 4474, 'The Circle S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179771.mp4', 'http://timg.bdta.pro/images/76780bcf185741c27b28771450390a32.jpg'),
(65629, 4474, 'The Circle S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179772.mp4', 'http://timg.bdta.pro/images/a100a032030a6245afb60a99014ea1a4.jpg'),
(65630, 4474, 'The Circle S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179773.mp4', 'http://timg.bdta.pro/images/ebecc913d9cf8625921312f43f69103a.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(65631, 4475, 'The Circle S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179774.mp4', 'http://timg.bdta.pro/images/4796faeb8d16376f6676b7d8118e8d82.jpg'),
(65632, 4475, 'The Circle S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179775.mp4', 'http://timg.bdta.pro/images/eac6519463ea550290779f6488bf5945.jpg'),
(65633, 4475, 'The Circle S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179776.mp4', 'http://timg.bdta.pro/images/903a9d7341d675376d8e663aab3f6f10.jpg'),
(65634, 4475, 'The Circle S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179777.mp4', 'http://timg.bdta.pro/images/1c076dfd30d6bdedc210495e5a542dd9.jpg'),
(65635, 4475, 'The Circle S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179778.mp4', 'http://timg.bdta.pro/images/816b76d5921b708b58ab4a237bf73555.jpg'),
(65636, 4475, 'The Circle S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179779.mp4', 'http://timg.bdta.pro/images/f3fc00de0e7af7b1af465d8f571265f9.jpg'),
(65637, 4475, 'The Circle S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179780.mp4', 'http://timg.bdta.pro/images/ba251c39557b3a175531fbb8b369b2ef.jpg'),
(65638, 4475, 'The Circle S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179781.mp4', 'http://timg.bdta.pro/images/a54b31aa798b2ce3e0b9c339b80484e6.jpg'),
(65639, 4475, 'The Circle S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179782.mp4', 'http://timg.bdta.pro/images/bd3a294f8f545165756a50629e856712.jpg'),
(65640, 4475, 'The Circle S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179783.mp4', 'http://timg.bdta.pro/images/bcd8496f4c6ef9d0df7c8b930146d3ce.jpg'),
(65641, 4475, 'The Circle S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179784.mp4', 'http://timg.bdta.pro/images/e37ff88976557243aea87e1a3e3f9388.jpg'),
(65642, 4475, 'The Circle S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179785.mp4', 'http://timg.bdta.pro/images/61649249a591dd33327876b40b473d6b.jpg'),
(65643, 4475, 'The Circle S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/179786.mp4', 'http://timg.bdta.pro/images/a04fd68b98329323ed093a1eb5167151.jpg'),
(65644, 4476, 'The Circle S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/252J8FDDpMBjGpxU2mYotuGTlsN.jpg'),
(65645, 4476, 'The Circle S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pdS8DAYedGRrbqdz52vcWRYszXP.jpg'),
(65646, 4476, 'The Circle S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kqNJinA7ETr2z3QtqAibs0Su0Ki.jpg'),
(65647, 4476, 'The Circle S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gtdxj4kcwitGnFZvTWl2JCCyF9l.jpg'),
(65648, 4476, 'The Circle S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cTAkh5001nSMbjvpCXH7c26BkKw.jpg'),
(65649, 4476, 'The Circle S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zGVXwWS4YVrsJg0RWTUPDRRpWDx.jpg'),
(65650, 4476, 'The Circle S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v6nJVM4EFyRopBdTTbKNUk4D8ET.jpg'),
(65651, 4476, 'The Circle S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8mfHmAAKyx0B6O1GrAZBpudBfH.jpg'),
(65652, 4476, 'The Circle S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gettehnkaUem6SY9D1yqyemYAns.jpg'),
(65653, 4476, 'The Circle S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4O69phiNflQdKhxRMG8ACKjqtUi.jpg'),
(65654, 4476, 'The Circle S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Nhjsr6fwsDSDz1c4K38g1jU7Dj.jpg'),
(65655, 4476, 'The Circle S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/88A1LNVbSWQUm9ijOCPpcW81gjR.jpg'),
(65656, 4476, 'The Circle S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/179799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/RTDlA0CGVESBVABxULFNvzhDEL.jpg'),
(65657, 4477, 'The Circle S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179800.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65658, 4477, 'The Circle S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179801.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65659, 4477, 'The Circle S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179802.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65660, 4477, 'The Circle S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179803.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65661, 4477, 'The Circle S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179804.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65662, 4477, 'The Circle S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179805.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65663, 4477, 'The Circle S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179806.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65664, 4477, 'The Circle S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179807.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65665, 4477, 'The Circle S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179808.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65666, 4477, 'The Circle S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179809.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65667, 4477, 'The Circle S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179810.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65668, 4477, 'The Circle S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179811.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65669, 4477, 'The Circle S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/179812.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65670, 4478, 'The Circle S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486781.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65671, 4478, 'The Circle S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486782.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65672, 4478, 'The Circle S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486783.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65673, 4478, 'The Circle S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486784.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65674, 4478, 'The Circle S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486785.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65675, 4478, 'The Circle S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486786.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65676, 4478, 'The Circle S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486787.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65677, 4478, 'The Circle S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486788.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65678, 4478, 'The Circle S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/486789.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65679, 4478, 'The Circle S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/486790.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65680, 4478, 'The Circle S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/486791.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65681, 4478, 'The Circle S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/486792.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65682, 4478, 'The Circle S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/486793.mp4', 'http://gstaticontent.com/images/8159c6dd9c522a813ce60ccfa322e655.jpg'),
(65683, 4479, 'ThunderCats S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154632.mp4', 'http://timg.bdta.pro/images/875562d093d9c202d6822bda9e6f8ff2.jpg'),
(65684, 4479, 'ThunderCats S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154633.mp4', 'http://timg.bdta.pro/images/9a8c3973ab0cbbacdceff1d792138e06.jpg'),
(65685, 4479, 'ThunderCats S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154634.mp4', 'http://timg.bdta.pro/images/371d3b2ae24075f35d8d99f625c936a5.jpg'),
(65686, 4479, 'ThunderCats S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154635.mp4', 'http://timg.bdta.pro/images/964f7f65adf1e3fcc9c015c651e230de.jpg'),
(65687, 4479, 'ThunderCats S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154636.mp4', 'http://timg.bdta.pro/images/df0974b0f7c6273931c9854986d02fca.jpg'),
(65688, 4479, 'ThunderCats S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154637.mp4', 'http://timg.bdta.pro/images/cd81eb8c543f533b900d593636750abd.jpg'),
(65689, 4479, 'ThunderCats S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154638.mp4', 'http://timg.bdta.pro/images/9e01ae885c2d9ff72f9de1b614ea253c.jpg'),
(65690, 4479, 'ThunderCats S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154639.mp4', 'http://timg.bdta.pro/images/5dcc9350efbae5744f044cff0c58212d.jpg'),
(65691, 4479, 'ThunderCats S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154640.mp4', 'http://timg.bdta.pro/images/70ae901586ef2ab2de2d2e95344180e1.jpg'),
(65692, 4479, 'ThunderCats S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154641.mp4', 'http://timg.bdta.pro/images/4be77a88f76a1c5d0a850bcc1bd2ba90.jpg'),
(65693, 4479, 'ThunderCats S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/154642.mp4', 'http://timg.bdta.pro/images/0e6250e677821240ec040a1cf69f2c29.jpg'),
(65694, 4479, 'ThunderCats S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/154643.mp4', 'http://timg.bdta.pro/images/0172cb6704d37b0f73b7517c9fa1a339.jpg'),
(65695, 4479, 'ThunderCats S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/154644.mp4', 'http://timg.bdta.pro/images/92c9dd1350bca169a69f9fa9c28d6982.jpg'),
(65696, 4479, 'ThunderCats S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/154645.mp4', 'http://timg.bdta.pro/images/f234a7a91b480adf251817d012f71af5.jpg'),
(65697, 4479, 'ThunderCats S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/154646.mp4', 'http://timg.bdta.pro/images/17f3ea8380e52727559d430e343fed29.jpg'),
(65698, 4479, 'ThunderCats S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/154647.mp4', 'http://timg.bdta.pro/images/a5bc7ff012a5cadbea03af6a1625d643.jpg'),
(65699, 4479, 'ThunderCats S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/154648.mp4', 'http://timg.bdta.pro/images/835fac238acc16bb71c8493d78f55c34.jpg'),
(65700, 4479, 'ThunderCats S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/154649.mp4', 'http://timg.bdta.pro/images/81ba7b35a68ea0f320b6a81e53e69e83.jpg'),
(65701, 4479, 'ThunderCats S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/154650.mp4', 'http://timg.bdta.pro/images/37e8697d72707d778e0662d944975d08.jpg'),
(65702, 4479, 'ThunderCats S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/154651.mp4', 'http://timg.bdta.pro/images/362477e3c3c1ac84de3b962f7b74ab59.jpg'),
(65703, 4479, 'ThunderCats S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/154652.mp4', 'http://timg.bdta.pro/images/3517e40a025f38079e51b1713777ed71.jpg'),
(65704, 4479, 'ThunderCats S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/154653.mp4', 'http://timg.bdta.pro/images/45dd0259dea29d37bd9adcbd652c2b44.jpg'),
(65705, 4479, 'ThunderCats S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/154654.mp4', 'http://timg.bdta.pro/images/c21c35ec794c41c09cec3dc14b45eeb8.jpg'),
(65706, 4479, 'ThunderCats S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/154655.mp4', 'http://timg.bdta.pro/images/a36b3592a9855be0f084e230303ddd93.jpg'),
(65707, 4479, 'ThunderCats S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/154656.mp4', 'http://timg.bdta.pro/images/f82a96fe0106164342c282ff47bd2276.jpg'),
(65708, 4479, 'ThunderCats S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/154657.mp4', 'http://timg.bdta.pro/images/7a6a0f8b439a63959fba013b21b25c8d.jpg'),
(65709, 4479, 'ThunderCats S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/154658.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65710, 4479, 'ThunderCats S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/154659.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65711, 4479, 'ThunderCats S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/154660.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65712, 4479, 'ThunderCats S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/154661.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65713, 4479, 'ThunderCats S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/154662.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65714, 4479, 'ThunderCats S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/154663.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65715, 4479, 'ThunderCats S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/154664.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65716, 4479, 'ThunderCats S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/154665.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65717, 4479, 'ThunderCats S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/154666.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65718, 4479, 'ThunderCats S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/154667.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65719, 4479, 'ThunderCats S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/154668.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65720, 4479, 'ThunderCats S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/154669.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65721, 4479, 'ThunderCats S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/154670.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65722, 4479, 'ThunderCats S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/154671.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65723, 4479, 'ThunderCats S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/154672.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65724, 4479, 'ThunderCats S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/154673.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65725, 4479, 'ThunderCats S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/154674.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65726, 4479, 'ThunderCats S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/154675.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65727, 4479, 'ThunderCats S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/154676.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65728, 4479, 'ThunderCats S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/154677.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65729, 4479, 'ThunderCats S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/154678.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65730, 4479, 'ThunderCats S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/154679.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65731, 4479, 'ThunderCats S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/154680.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65732, 4479, 'ThunderCats S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/154681.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65733, 4479, 'ThunderCats S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/154682.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65734, 4479, 'ThunderCats S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/154683.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65735, 4479, 'ThunderCats S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/154684.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65736, 4479, 'ThunderCats S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/154685.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65737, 4479, 'ThunderCats S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/154686.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65738, 4479, 'ThunderCats S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/154687.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65739, 4479, 'ThunderCats S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/154688.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65740, 4479, 'ThunderCats S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/154689.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65741, 4479, 'ThunderCats S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/154690.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65742, 4479, 'ThunderCats S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/154691.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65743, 4479, 'ThunderCats S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/154692.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65744, 4479, 'ThunderCats S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/154693.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65745, 4479, 'ThunderCats S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/154694.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65746, 4479, 'ThunderCats S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/154695.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65747, 4479, 'ThunderCats S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/154696.mp4', 'http://gstaticontent.com/images/0547c48cd521701faa8399523536e093.jpg'),
(65748, 4480, '1971: O ano em que a música mudou o mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5zhbwcKEJJeNz0IOAbdFGlyFmaL.jpg'),
(65749, 4480, '1971: O ano em que a música mudou o mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqRniRwwHNdQyRXrhaOsEyTA6Ad.jpg'),
(65750, 4480, '1971: O ano em que a música mudou o mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oEKsOq2flUDEKfp7SIVVpcsXerx.jpg'),
(65751, 4480, '1971: O ano em que a música mudou o mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oe7lzT0X096omyMnKgo0izN4iWh.jpg'),
(65752, 4480, '1971: O ano em que a música mudou o mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ks3Nj7rjpL4P8GLsAkcM3MpcaHr.jpg'),
(65753, 4480, '1971: O ano em que a música mudou o mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bKMtCinF8xRqpREVtmBvUutnV8i.jpg'),
(65754, 4480, '1971: O ano em que a música mudou o mundo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1NP2XpH0UMFRU7fm3n8gtyyqrNy.jpg'),
(65755, 4480, '1971: O ano em que a música mudou o mundo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rwRNw8mrKtlykr0ZxGSLMStlTwb.jpg'),
(65756, 4481, 'As 24 Personalidades de Billy Milligan S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z9JvXXzjbGn0TG0hUGh9cgZ1TcX.jpg'),
(65757, 4481, 'As 24 Personalidades de Billy Milligan S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a2ggK3SFFHb4Svyy6fsSk0mC1r7.jpg'),
(65758, 4481, 'As 24 Personalidades de Billy Milligan S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tlmP3UoDUvZGwS8bFtplFp4BNLr.jpg'),
(65759, 4481, 'As 24 Personalidades de Billy Milligan S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tlO1Gn4vYAfIamlBeNRIkB5AIEY.jpg'),
(65760, 4482, 'As Aventuras do Batman S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipGhCmWeKHMwM5CgXF7mCsspgDV.jpg'),
(65761, 4482, 'As Aventuras do Batman S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipGhCmWeKHMwM5CgXF7mCsspgDV.jpg'),
(65762, 4482, 'As Aventuras do Batman S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipGhCmWeKHMwM5CgXF7mCsspgDV.jpg'),
(65763, 4482, 'As Aventuras do Batman S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipGhCmWeKHMwM5CgXF7mCsspgDV.jpg'),
(65764, 4482, 'As Aventuras do Batman S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipGhCmWeKHMwM5CgXF7mCsspgDV.jpg'),
(65765, 4482, 'As Aventuras do Batman S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipGhCmWeKHMwM5CgXF7mCsspgDV.jpg'),
(65766, 4482, 'As Aventuras do Batman S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipGhCmWeKHMwM5CgXF7mCsspgDV.jpg'),
(65767, 4482, 'As Aventuras do Batman S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipGhCmWeKHMwM5CgXF7mCsspgDV.jpg'),
(65768, 4482, 'As Aventuras do Batman S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipGhCmWeKHMwM5CgXF7mCsspgDV.jpg'),
(65769, 4482, 'As Aventuras do Batman S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipGhCmWeKHMwM5CgXF7mCsspgDV.jpg'),
(65770, 4482, 'As Aventuras do Batman S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/154349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipGhCmWeKHMwM5CgXF7mCsspgDV.jpg'),
(65771, 4482, 'As Aventuras do Batman S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/154350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipGhCmWeKHMwM5CgXF7mCsspgDV.jpg'),
(65772, 4482, 'As Aventuras do Batman S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/154351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipGhCmWeKHMwM5CgXF7mCsspgDV.jpg'),
(65773, 4482, 'As Aventuras do Batman S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/154352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipGhCmWeKHMwM5CgXF7mCsspgDV.jpg'),
(65774, 4482, 'As Aventuras do Batman S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/154353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipGhCmWeKHMwM5CgXF7mCsspgDV.jpg'),
(65775, 4482, 'As Aventuras do Batman S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/154354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipGhCmWeKHMwM5CgXF7mCsspgDV.jpg'),
(65776, 4482, 'As Aventuras do Batman S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/154355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipGhCmWeKHMwM5CgXF7mCsspgDV.jpg'),
(65777, 4483, 'Bangkok no Limite S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qhdNHqEapVtr27Yzp886NFzryiG.jpg'),
(65778, 4483, 'Bangkok no Limite S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qhdNHqEapVtr27Yzp886NFzryiG.jpg'),
(65779, 4483, 'Bangkok no Limite S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qhdNHqEapVtr27Yzp886NFzryiG.jpg'),
(65780, 4483, 'Bangkok no Limite S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qhdNHqEapVtr27Yzp886NFzryiG.jpg'),
(65781, 4483, 'Bangkok no Limite S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qhdNHqEapVtr27Yzp886NFzryiG.jpg'),
(65782, 4483, 'Bangkok no Limite S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qhdNHqEapVtr27Yzp886NFzryiG.jpg'),
(65783, 4484, 'Força-Queer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oKuIgaOFi3h4mW1K7pXRdRMg2ns.jpg'),
(65784, 4484, 'Força-Queer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j8KLxqCKlDO24JE8vDS0JXWDnsU.jpg'),
(65785, 4484, 'Força-Queer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FRsWqnD88xOY58auEOfKtBgcx2.jpg'),
(65786, 4484, 'Força-Queer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/TGSmxnfu7j7hWhFOcDczko3KlT.jpg'),
(65787, 4484, 'Força-Queer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ejrT8HjJPGdwoBHH2sOwPDzHAAA.jpg'),
(65788, 4484, 'Força-Queer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bkTdXZqsWRdA2EYnpuBasj3hjg9.jpg'),
(65789, 4484, 'Força-Queer S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/thAKIkFOuFjU3Xe7kdrbhF1nvFU.jpg'),
(65790, 4484, 'Força-Queer S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/byF5d5QbKVtPwUUSimjlS551SWC.jpg'),
(65791, 4484, 'Força-Queer S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h2ncmNRJYGGGxyN24Nq2sT8NzVj.jpg'),
(65792, 4484, 'Força-Queer S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yJKvl0tt5CgPjFLWItaIp4OQnnp.jpg'),
(65793, 4485, 'Fundação S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fzLVAoOnLbZif4FWtHVliIrCNBe.jpg'),
(65794, 4485, 'Fundação S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uC0BRA2QgSKZnswPAdaw1u5UwWf.jpg'),
(65795, 4485, 'Fundação S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237173.mp4', 'http://image.tmdb.org/t/p/w1280/70IWD1u9jmdoHXhCVPjSl4rSxfY.jpg'),
(65796, 4485, 'Fundação S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237174.mp4', 'http://image.tmdb.org/t/p/w1280/k0sNoraOGogMPnzn68Ws973PtEN.jpg'),
(65797, 4485, 'Fundação S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qtQJ7PaiWFj2ltcvV5ZKl0AJuQ1.jpg'),
(65798, 4485, 'Fundação S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rXnBCt0VI1uGQjHqqNemJrneo8A.jpg'),
(65799, 4485, 'Fundação S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2arZ4Mlq7JcA59f0q1LcbZhYFl6.jpg'),
(65800, 4485, 'Fundação S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lTr4e8NpKN60X3fd24FAxiY32WB.jpg'),
(65801, 4485, 'Fundação S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237179.mp4', 'http://image.tmdb.org/t/p/w1280/zQav4lMy8MIEg1Kgko33JrpRWfc.jpg'),
(65802, 4485, 'Fundação S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237180.mp4', 'http://image.tmdb.org/t/p/w1280/tJXAQitxYZ4QjghdgDJrKPsbJUx.jpg'),
(65803, 4486, 'Fundação S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237181.mp4', 'http://image.tmdb.org/t/p/w1280/tLNS2wdCSAFmPmunZo1P5WQg0Pi.jpg'),
(65804, 4486, 'Fundação S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237182.mp4', 'http://image.tmdb.org/t/p/w1280/hOF35xreGykyz32jsPCZQKiLXNB.jpg'),
(65805, 4486, 'Fundação S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237183.mp4', 'http://image.tmdb.org/t/p/w1280/vuUsc3ROf2fWWcQ1d5Zonm85KmE.jpg'),
(65806, 4486, 'Fundação S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237184.mp4', 'http://image.tmdb.org/t/p/w1280/4yMVqiszhhX38NetKQCKEijcHnq.jpg'),
(65807, 4486, 'Fundação S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/53dsfLChOJKy6Nq7ujzPvCf1wM1.jpg'),
(65808, 4486, 'Fundação S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qH7tvEWcfvt6UrkJAw50cCx0lr7.jpg'),
(65809, 4486, 'Fundação S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Q6kNbwsGUyircoQqe2lV6TnW4m.jpg'),
(65810, 4486, 'Fundação S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFgwBRCzlsFTs9B6PXK3sCyZcQ0.jpg'),
(65811, 4486, 'Fundação S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFgwBRCzlsFTs9B6PXK3sCyZcQ0.jpg'),
(65812, 4486, 'Fundação S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFgwBRCzlsFTs9B6PXK3sCyZcQ0.jpg'),
(65813, 4487, 'Fundação S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/865544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFgwBRCzlsFTs9B6PXK3sCyZcQ0.jpg'),
(65814, 4487, 'Fundação S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/870648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFgwBRCzlsFTs9B6PXK3sCyZcQ0.jpg'),
(65815, 4487, 'Fundação S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/878237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFgwBRCzlsFTs9B6PXK3sCyZcQ0.jpg'),
(65816, 4487, 'Fundação S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/879423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFgwBRCzlsFTs9B6PXK3sCyZcQ0.jpg'),
(65817, 4487, 'Fundação S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/880493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFgwBRCzlsFTs9B6PXK3sCyZcQ0.jpg'),
(65818, 4487, 'Fundação S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/880584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFgwBRCzlsFTs9B6PXK3sCyZcQ0.jpg'),
(65819, 4487, 'Fundação S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/881219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFgwBRCzlsFTs9B6PXK3sCyZcQ0.jpg'),
(65820, 4487, 'Fundação S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/881335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFgwBRCzlsFTs9B6PXK3sCyZcQ0.jpg'),
(65821, 4487, 'Fundação S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/883029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFgwBRCzlsFTs9B6PXK3sCyZcQ0.jpg'),
(65822, 4487, 'Fundação S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/883802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lFgwBRCzlsFTs9B6PXK3sCyZcQ0.jpg'),
(65823, 4488, 'Grandes Investigações: Detetives da Índia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xAcvRZwIZ8Lw3LUxgAVS3zjgPwO.jpg'),
(65824, 4488, 'Grandes Investigações: Detetives da Índia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1rZik32dyXOxkd3BKd6tuqGHjo9.jpg'),
(65825, 4488, 'Grandes Investigações: Detetives da Índia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fvo8wvDRavfw036vEBh2CAFGRQM.jpg'),
(65826, 4488, 'Grandes Investigações: Detetives da Índia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Dn6CPnYhrwxNIpygLUTFX0LTkj.jpg'),
(65827, 4489, 'Jaguar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qC7lweJkh5Uw2ce9GXNWGRAybz5.jpg'),
(65828, 4489, 'Jaguar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6DpKsaVrmjZhXgczOvEfG3a0Gd8.jpg'),
(65829, 4489, 'Jaguar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pXIBAgJv1wsNZoCvz5RqBfobugx.jpg'),
(65830, 4489, 'Jaguar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i3D6wunOO0alck3pFMQ2y9WQWHy.jpg'),
(65831, 4489, 'Jaguar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6uXOz9jVA1Ma1NsR7I5Cdo9jJbc.jpg'),
(65832, 4489, 'Jaguar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhBOA92XkH0SLtcY1V2ex8BBy9K.jpg'),
(65833, 4490, 'Kung Fu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zVVjn7aSMQvaJFYaUMuKjDxklVP.jpg'),
(65834, 4490, 'Kung Fu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2mKezvtivKyGBRnY7us7o283Sd.jpg'),
(65835, 4490, 'Kung Fu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dRrGlPmI5IN7ppjpyVGlpGQsaJ0.jpg'),
(65836, 4490, 'Kung Fu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1cy3S1P6tqoq1UQitOqZVGLAALR.jpg'),
(65837, 4490, 'Kung Fu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oBjZtGfYCrJRnYNdmoBfulOfqem.jpg'),
(65838, 4490, 'Kung Fu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8vToqUrgYnRkw7oQxHgfq60onif.jpg'),
(65839, 4490, 'Kung Fu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2zjRojBk3erv1svujCgE68fHL3r.jpg'),
(65840, 4490, 'Kung Fu S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5qrBsmYXX9feri0n5iSU8cxUySr.jpg'),
(65841, 4490, 'Kung Fu S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/As0LV26u1kOPxLURllHW7I9CmMq.jpg'),
(65842, 4490, 'Kung Fu S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8XOjxi1gVqJSAHyBxxmiMcjfENx.jpg'),
(65843, 4490, 'Kung Fu S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6asMpE99aHY1D3fYciaxHYh5Bui.jpg'),
(65844, 4490, 'Kung Fu S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jGE5B4sZeWCEdmHUjyw3I1JWHyp.jpg'),
(65845, 4490, 'Kung Fu S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aWC7HWl7MexWj60HFKeFajbhb88.jpg'),
(65846, 4491, 'Kung Fu S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204005.mp4', 'http://timg.bdta.pro/images/2074d26e05456eae2b97552afb8dea79.jpg'),
(65847, 4491, 'Kung Fu S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204006.mp4', 'http://timg.bdta.pro/images/38fae38bcd521229ce7404600b406841.jpg'),
(65848, 4491, 'Kung Fu S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204007.mp4', 'http://timg.bdta.pro/images/08a74ab048b5e8d59dc3db4043980530.jpg'),
(65849, 4491, 'Kung Fu S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204008.mp4', 'http://timg.bdta.pro/images/846ff64b07cfd4674c6569845d771565.jpg'),
(65850, 4491, 'Kung Fu S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204009.mp4', 'http://timg.bdta.pro/images/72cc3e4b6cf82f174703dc0e17cfe0bf.jpg'),
(65851, 4491, 'Kung Fu S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204010.mp4', 'http://timg.bdta.pro/images/e629562faa4aa93fc17e70faa4fdffa1.jpg'),
(65852, 4491, 'Kung Fu S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204011.mp4', 'http://timg.bdta.pro/images/7a575d131b31a45460486825d141c8e6.jpg'),
(65853, 4491, 'Kung Fu S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204012.mp4', 'http://timg.bdta.pro/images/544983aa6520fe949bdf8e43be9cd978.jpg'),
(65854, 4491, 'Kung Fu S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204013.mp4', 'http://timg.bdta.pro/images/3b8d150e9633d354549c80c62c642b74.jpg'),
(65855, 4491, 'Kung Fu S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204014.mp4', 'http://timg.bdta.pro/images/1e9cf219b02dad2322384bff51d10429.jpg'),
(65856, 4491, 'Kung Fu S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204015.mp4', 'http://timg.bdta.pro/images/fe58560ec8924bbfefcd08e97ed93f7f.jpg'),
(65857, 4491, 'Kung Fu S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204016.mp4', 'http://timg.bdta.pro/images/2ab4ce5bcf9f6a6b6d4e577bc54c608f.jpg'),
(65858, 4491, 'Kung Fu S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sJbzjaCnGdxlaRUCP7UmJGL1RVZ.jpg'),
(65859, 4492, 'Kung Fu S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3SXPvutBmIJIh44o61aX77HS31M.jpg'),
(65860, 4492, 'Kung Fu S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kjWDJgVDI3l8ssKpvMihPmOGe4.jpg'),
(65861, 4492, 'Kung Fu S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8t4t95hkCIDz3jlOokq3G0WUj6k.jpg'),
(65862, 4492, 'Kung Fu S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hNuGz9hVLNkAZaUDZ6w22nB9x5h.jpg'),
(65863, 4492, 'Kung Fu S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204022.mp4', 'http://image.tmdb.org/t/p/w1280/vPWwIOHwjgIkaPapTut9PTDd9uz.jpg'),
(65864, 4492, 'Kung Fu S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r47twCVD7nVZtCK73JAJ3a6nSF4.jpg'),
(65865, 4492, 'Kung Fu S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sJbzjaCnGdxlaRUCP7UmJGL1RVZ.jpg'),
(65866, 4492, 'Kung Fu S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sJbzjaCnGdxlaRUCP7UmJGL1RVZ.jpg'),
(65867, 4493, 'Memórias do 11 de Setembro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzTGsKnBOQ6FsRQwzhloY2yDO5o.jpg'),
(65868, 4493, 'Memórias do 11 de Setembro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7nokYK6dTP3CkDKK3whinepK6xh.jpg'),
(65869, 4493, 'Memórias do 11 de Setembro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQFkc1Z6yRtrUjQ9drrPStiTjv9.jpg'),
(65870, 4493, 'Memórias do 11 de Setembro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/89eS0y884lfr5TBnAZjtPg24Ldi.jpg'),
(65871, 4493, 'Memórias do 11 de Setembro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/blP3FamIImAMfyw8wiTleaa6kfn.jpg'),
(65872, 4493, 'Memórias do 11 de Setembro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/E4IAyvnSUPVGuuroDCxR6TgDx0.jpg'),
(65873, 4494, 'Noite na Terra em Cores S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6bjmGDFxzSKCGsyd5UJlpmgy5BN.jpg'),
(65874, 4494, 'Noite na Terra em Cores S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQc6VvfYpMD5SalobYcy48vAbO5.jpg'),
(65875, 4494, 'Noite na Terra em Cores S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dMM0HtVWWbrOjiNl0xDueqaz0Vq.jpg'),
(65876, 4494, 'Noite na Terra em Cores S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zVjqcuSpMAxZE01VixpINr0dWfN.jpg'),
(65877, 4494, 'Noite na Terra em Cores S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vmwVxm49SXQwAiBVb3ZvJ6Ngsgq.jpg'),
(65878, 4494, 'Noite na Terra em Cores S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/stpXcb4YhGKBQXXppjZU7tHbPLJ.jpg'),
(65879, 4495, 'Noite na Terra em Cores S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x6RSGcPkJfXKPhhQE36QUTFPnwm.jpg'),
(65880, 4495, 'Noite na Terra em Cores S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lDtbh4jz2Cv6i0lDoglkG1fOXn1.jpg'),
(65881, 4495, 'Noite na Terra em Cores S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rRduj8IllPNCGKFZJIUresobkCQ.jpg'),
(65882, 4495, 'Noite na Terra em Cores S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgncLNNI5guhFMzCvhBK8x3uhF0.jpg'),
(65883, 4495, 'Noite na Terra em Cores S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xMzPE6zSzQvHBa1HNBU82pZzTdU.jpg'),
(65884, 4495, 'Noite na Terra em Cores S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2ru374eXjD0t4oBMPJ8njnz7mR.jpg'),
(65885, 4496, 'O Incrível Hulk S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65886, 4496, 'O Incrível Hulk S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aYlyHD5VmqW4vPq5NiISh2u6DgV.jpg'),
(65887, 4496, 'O Incrível Hulk S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cWVohTCD0ftoiDaIVOVHPTehf9L.jpg'),
(65888, 4496, 'O Incrível Hulk S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sHL8mqomWssOwMQ8X9QrtYIcnIY.jpg'),
(65889, 4496, 'O Incrível Hulk S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ctHmzzwJiK6VhqyTxu3ULwny12.jpg'),
(65890, 4496, 'O Incrível Hulk S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d2f8KO1L2h7qGSYO5jVqO0A9tb8.jpg'),
(65891, 4496, 'O Incrível Hulk S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u1sUhEvgCMGhOt4EaBiXuAx1m5i.jpg'),
(65892, 4496, 'O Incrível Hulk S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iG4DrM0YT8ajwwycZu4RRb9e2zu.jpg'),
(65893, 4496, 'O Incrível Hulk S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/muaPkaQ6PFU46fr492PAu5SXnb3.jpg'),
(65894, 4496, 'O Incrível Hulk S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/akbDt4LlQ6oveT6kNGulI5KXh8h.jpg'),
(65895, 4496, 'O Incrível Hulk S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dsDIUUDGUuIwuO4o5MZMYRjJC8i.jpg'),
(65896, 4496, 'O Incrível Hulk S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xCkynbjeAdNQXRz6SlOwrISNaM2.jpg'),
(65897, 4497, 'O Incrível Hulk S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65898, 4497, 'O Incrível Hulk S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65899, 4497, 'O Incrível Hulk S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jpyHydlmdxDL5cf0MwtJrIJyH49.jpg'),
(65900, 4497, 'O Incrível Hulk S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9mq0xjgt8oPWdxExzymPUGQVAfR.jpg'),
(65901, 4497, 'O Incrível Hulk S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHxSxrhrpkRY3nSirF1iYApSL9E.jpg'),
(65902, 4497, 'O Incrível Hulk S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65903, 4497, 'O Incrível Hulk S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65904, 4497, 'O Incrível Hulk S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65905, 4497, 'O Incrível Hulk S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65906, 4497, 'O Incrível Hulk S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(65907, 4497, 'O Incrível Hulk S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65908, 4497, 'O Incrível Hulk S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65909, 4497, 'O Incrível Hulk S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65910, 4497, 'O Incrível Hulk S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65911, 4497, 'O Incrível Hulk S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65912, 4497, 'O Incrível Hulk S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65913, 4497, 'O Incrível Hulk S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65914, 4497, 'O Incrível Hulk S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65915, 4497, 'O Incrível Hulk S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/161389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65916, 4497, 'O Incrível Hulk S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/161390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65917, 4497, 'O Incrível Hulk S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/161391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65918, 4497, 'O Incrível Hulk S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/161392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65919, 4498, 'O Incrível Hulk S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65920, 4498, 'O Incrível Hulk S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65921, 4498, 'O Incrível Hulk S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65922, 4498, 'O Incrível Hulk S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65923, 4498, 'O Incrível Hulk S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65924, 4498, 'O Incrível Hulk S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65925, 4498, 'O Incrível Hulk S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65926, 4498, 'O Incrível Hulk S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65927, 4498, 'O Incrível Hulk S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65928, 4498, 'O Incrível Hulk S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65929, 4498, 'O Incrível Hulk S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65930, 4498, 'O Incrível Hulk S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65931, 4498, 'O Incrível Hulk S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65932, 4498, 'O Incrível Hulk S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65933, 4498, 'O Incrível Hulk S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65934, 4498, 'O Incrível Hulk S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65935, 4498, 'O Incrível Hulk S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65936, 4498, 'O Incrível Hulk S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65937, 4498, 'O Incrível Hulk S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/161411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65938, 4498, 'O Incrível Hulk S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/161412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65939, 4498, 'O Incrível Hulk S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/161413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65940, 4498, 'O Incrível Hulk S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/161414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65941, 4498, 'O Incrível Hulk S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/161415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65942, 4499, 'O Incrível Hulk S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65943, 4499, 'O Incrível Hulk S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65944, 4499, 'O Incrível Hulk S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65945, 4499, 'O Incrível Hulk S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65946, 4499, 'O Incrível Hulk S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65947, 4499, 'O Incrível Hulk S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65948, 4499, 'O Incrível Hulk S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65949, 4499, 'O Incrível Hulk S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65950, 4499, 'O Incrível Hulk S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65951, 4499, 'O Incrível Hulk S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65952, 4499, 'O Incrível Hulk S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65953, 4499, 'O Incrível Hulk S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65954, 4499, 'O Incrível Hulk S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65955, 4499, 'O Incrível Hulk S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65956, 4499, 'O Incrível Hulk S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65957, 4499, 'O Incrível Hulk S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65958, 4499, 'O Incrível Hulk S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65959, 4499, 'O Incrível Hulk S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65960, 4500, 'O Incrível Hulk S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65961, 4500, 'O Incrível Hulk S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65962, 4500, 'O Incrível Hulk S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65963, 4500, 'O Incrível Hulk S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65964, 4500, 'O Incrível Hulk S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65965, 4500, 'O Incrível Hulk S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65966, 4500, 'O Incrível Hulk S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iByskDYAql50lmEel8NdmAGFSty.jpg'),
(65967, 4501, 'Operação Pacífico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/coBIPerkpww3iL5mJhEGOtPbkrE.jpg'),
(65968, 4501, 'Operação Pacífico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2KWAbY4roG9ojwdWiS158o1uHYH.jpg'),
(65969, 4501, 'Operação Pacífico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eq1HFahdCZkGYvdV1Rrm9bKAuwQ.jpg'),
(65970, 4501, 'Operação Pacífico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ktNAKvZNR2wKnRU4sczNl19OEoJ.jpg'),
(65971, 4501, 'Operação Pacífico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gqnK9kHPutx2hNHGhAbV8ZqqumC.jpg'),
(65972, 4501, 'Operação Pacífico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2EgsqcFM5c1TAE6SsLWdf5rH7qz.jpg'),
(65973, 4501, 'Operação Pacífico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3I2W2iFbUise9VV8ciO3pq9lvTW.jpg'),
(65974, 4501, 'Operação Pacífico S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wzCSV0rJKKKtrVRPzilG0H67rib.jpg'),
(65975, 4501, 'Operação Pacífico S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gMwBn69RKskQaafOiWs8Jt9xYX1.jpg'),
(65976, 4501, 'Operação Pacífico S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/154244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1i3UhU9rxzTIVwlUEA56s9WjCEH.jpg'),
(65977, 4501, 'Operação Pacífico S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/154245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7vII1JyZ5iof3kGQ54KgaE3vbKq.jpg'),
(65978, 4501, 'Operação Pacífico S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/154246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yMqLjc9cDkDueVAvqyr8HouU5yv.jpg'),
(65979, 4501, 'Operação Pacífico S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/154247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qATSO5WmKrz83y7kBPt7YEzrGoh.jpg'),
(65980, 4501, 'Operação Pacífico S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/154248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eosJmTDk6sycMj7FP5WUQICjok6.jpg'),
(65981, 4501, 'Operação Pacífico S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/154249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p1zE4Y69ZSTDeD3ExURAkLhMfh4.jpg'),
(65982, 4501, 'Operação Pacífico S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/154250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MhZc9rimFLINvh4venXDVE8b9K.jpg'),
(65983, 4501, 'Operação Pacífico S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/154251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/obMIoYfVi5NAIbTb3tfC5LjPDvx.jpg'),
(65984, 4501, 'Operação Pacífico S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/154252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gHrUYOjA9Mkl9oW4Ec8ns74jfJs.jpg'),
(65985, 4501, 'Operação Pacífico S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/154253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gvKzEMrohS53DZIURSOc1zBjJFf.jpg'),
(65986, 4501, 'Operação Pacífico S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/154254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/42mKK4g33g9K3ZtSMhEAkmOioxB.jpg'),
(65987, 4501, 'Operação Pacífico S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/154255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yAjbApocrHMVMp6WMpknWSNNIyL.jpg'),
(65988, 4501, 'Operação Pacífico S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/154256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gD1miK7iSiHMWFbDoaVM9guok7V.jpg'),
(65989, 4501, 'Operação Pacífico S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/154257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fxmLanHhnAyrRjT9RUucunR2LWU.jpg'),
(65990, 4501, 'Operação Pacífico S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/154258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fEfbTYexjSSCUgtvDRw0m7NxHty.jpg'),
(65991, 4501, 'Operação Pacífico S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/154259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3cD1qDnlT2jMROVwBrhDcQW08BA.jpg'),
(65992, 4501, 'Operação Pacífico S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/154260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(65993, 4501, 'Operação Pacífico S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/154261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(65994, 4501, 'Operação Pacífico S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/154262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(65995, 4501, 'Operação Pacífico S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/154263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(65996, 4501, 'Operação Pacífico S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/154264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(65997, 4501, 'Operação Pacífico S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/154265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(65998, 4501, 'Operação Pacífico S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/154266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(65999, 4501, 'Operação Pacífico S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/154267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66000, 4501, 'Operação Pacífico S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/154268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66001, 4501, 'Operação Pacífico S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/154269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66002, 4501, 'Operação Pacífico S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/154270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66003, 4501, 'Operação Pacífico S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/154271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66004, 4501, 'Operação Pacífico S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/154272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66005, 4501, 'Operação Pacífico S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/154273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66006, 4501, 'Operação Pacífico S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/154274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66007, 4501, 'Operação Pacífico S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/154275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66008, 4501, 'Operação Pacífico S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/154276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66009, 4501, 'Operação Pacífico S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/154277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66010, 4501, 'Operação Pacífico S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/154278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66011, 4501, 'Operação Pacífico S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/154279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66012, 4501, 'Operação Pacífico S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/154280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66013, 4501, 'Operação Pacífico S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/154281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66014, 4501, 'Operação Pacífico S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/154282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66015, 4501, 'Operação Pacífico S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/154283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66016, 4501, 'Operação Pacífico S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/154284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66017, 4501, 'Operação Pacífico S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/154285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66018, 4501, 'Operação Pacífico S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/154286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66019, 4501, 'Operação Pacífico S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/154287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66020, 4501, 'Operação Pacífico S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/154288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66021, 4501, 'Operação Pacífico S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/154289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66022, 4501, 'Operação Pacífico S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/154290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66023, 4501, 'Operação Pacífico S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/154291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66024, 4501, 'Operação Pacífico S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/154292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66025, 4501, 'Operação Pacífico S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/154293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66026, 4501, 'Operação Pacífico S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/154294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mzWb2cy7iHqqYkG526YLppEEmvP.jpg'),
(66027, 4502, 'Pequenas Maravilhas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eWTOBCw37KPXTB0NLCMCAEhHTbR.jpg'),
(66028, 4502, 'Pequenas Maravilhas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/arbGpq4dJVCa6PsAUPnvXxSmlhH.jpg'),
(66029, 4502, 'Pequenas Maravilhas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/skymRlK6LW5icAlEDaaWNTPkDdm.jpg'),
(66030, 4502, 'Pequenas Maravilhas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/miV1VRlMtnVemZYAMor95x90hEM.jpg'),
(66031, 4502, 'Pequenas Maravilhas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rFpT2uu6rR87toSlj76pKQuu4J4.jpg'),
(66032, 4502, 'Pequenas Maravilhas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Qr80fXBM2bveijvvKBvRDVMhTz.jpg'),
(66033, 4503, 'Pequenas Maravilhas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p7fPWuwmmbzr5PgxH3dQ1XIKyxU.jpg'),
(66034, 4503, 'Pequenas Maravilhas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kqAhrV0rEs4laq0UrKAh8cTAiYk.jpg'),
(66035, 4503, 'Pequenas Maravilhas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ggJJeHEYVJ5lfEww99jJI24qHhu.jpg'),
(66036, 4503, 'Pequenas Maravilhas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qfnsmjHJrnlqU4YokoTA9HRQJjp.jpg'),
(66037, 4503, 'Pequenas Maravilhas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5E1rWTriXLMCH5dl5GX0M3T5feq.jpg'),
(66038, 4503, 'Pequenas Maravilhas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gYS8KJPro08pEKvltLbYFgI3dxR.jpg'),
(66039, 4504, 'Round 6 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/154214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vMFJS9LIUUAmQ1thq4vJ7iHKwRz.jpg'),
(66040, 4504, 'Round 6 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/154215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uacNwki3PqXEFk9Pal9Ng5NwwAI.jpg'),
(66041, 4504, 'Round 6 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/154216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNtgrNEsMXvmRQQtcFuJdbXOjmP.jpg'),
(66042, 4504, 'Round 6 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/154217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9cUGOdLN4gmnf3b9ILArnJsJI8Q.jpg'),
(66043, 4504, 'Round 6 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/154218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2pE9f6drlF7y9rwUw6dh1w6jF5M.jpg'),
(66044, 4504, 'Round 6 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/154219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cohCCQzTe2ncdQczJDUsO0vzxPR.jpg'),
(66045, 4504, 'Round 6 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/154220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4pVfv4HaM5QpFJTHm19p2UI0StN.jpg'),
(66046, 4504, 'Round 6 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/154221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lOgFVmykN9qlpAoiBSIV2lu7XCS.jpg'),
(66047, 4504, 'Round 6 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/154222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sKeQbHeEUQLyoSdopa0QXm604cz.jpg'),
(66048, 4505, 'Round 6 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/639941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yACIAqAkSLkX4coHafpyLWAtQjw.jpg'),
(66049, 4505, 'Round 6 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/639942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yACIAqAkSLkX4coHafpyLWAtQjw.jpg'),
(66050, 4505, 'Round 6 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/639943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yACIAqAkSLkX4coHafpyLWAtQjw.jpg'),
(66051, 4505, 'Round 6 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/639944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yACIAqAkSLkX4coHafpyLWAtQjw.jpg'),
(66052, 4505, 'Round 6 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/639945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yACIAqAkSLkX4coHafpyLWAtQjw.jpg'),
(66053, 4505, 'Round 6 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/639946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yACIAqAkSLkX4coHafpyLWAtQjw.jpg'),
(66054, 4505, 'Round 6 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/639947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yACIAqAkSLkX4coHafpyLWAtQjw.jpg'),
(66055, 4506, 'Round 6 S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/853183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yACIAqAkSLkX4coHafpyLWAtQjw.jpg'),
(66056, 4506, 'Round 6 S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/853184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yACIAqAkSLkX4coHafpyLWAtQjw.jpg'),
(66057, 4506, 'Round 6 S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/853185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yACIAqAkSLkX4coHafpyLWAtQjw.jpg'),
(66058, 4506, 'Round 6 S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/853186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yACIAqAkSLkX4coHafpyLWAtQjw.jpg'),
(66059, 4506, 'Round 6 S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/853187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yACIAqAkSLkX4coHafpyLWAtQjw.jpg'),
(66060, 4506, 'Round 6 S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/853188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yACIAqAkSLkX4coHafpyLWAtQjw.jpg'),
(66061, 4507, 'Scenes from a Marriage S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5bfo4xn0x8dksNmo0rBOBwkdb8l.jpg'),
(66062, 4507, 'Scenes from a Marriage S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wWDN1zodR93ERgi0ResWiwPtUcc.jpg'),
(66063, 4507, 'Scenes from a Marriage S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159832.mp4', 'http://image.tmdb.org/t/p/w1280/6NCCQhkyKkohCZjRqmoyHc8qOir.jpg'),
(66064, 4507, 'Scenes from a Marriage S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159833.mp4', 'http://image.tmdb.org/t/p/w1280/8op4ZPAf01m9iptn0ssZ0zDAuRu.jpg'),
(66065, 4507, 'Scenes from a Marriage S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159834.mp4', 'http://image.tmdb.org/t/p/w1280/oKu4kIfTyCJFuFVG1u8B7D36y0S.jpg'),
(66066, 4508, 'Star Wars: Visions S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2cio9Ojjzp0m8mqckhRYyvG7E7R.jpg'),
(66067, 4508, 'Star Wars: Visions S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sxAxCIUDnEh5SGEAGlwgW3ll0Xg.jpg'),
(66068, 4508, 'Star Wars: Visions S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tT5CJejliDDF4ZjwDIaEjGaIf5X.jpg'),
(66069, 4508, 'Star Wars: Visions S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fTwdz09sK4mVPbbTMFN4oKlQFro.jpg'),
(66070, 4508, 'Star Wars: Visions S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FMrni5u9qYMjzjI9iLwrPDLvRa.jpg'),
(66071, 4508, 'Star Wars: Visions S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Ssgc5g5EFKSDkjp8SYyNuLK2Qx.jpg'),
(66072, 4508, 'Star Wars: Visions S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yhyCfbiuTyr97EubHKOL1gtvSM6.jpg'),
(66073, 4508, 'Star Wars: Visions S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ekSItuKabWSMR1lVwWz4BHf11Tt.jpg'),
(66074, 4508, 'Star Wars: Visions S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gm8eK7ASBgMBhgZIPyA8NxeqIHY.jpg'),
(66075, 4509, 'Vai Dar Tudo Certo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lqm31YtIdp9Tiv9d4S2PWTH16X5.jpg'),
(66076, 4509, 'Vai Dar Tudo Certo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pQ6qhjnuZ64fltpJbqKwQDKQPYC.jpg'),
(66077, 4509, 'Vai Dar Tudo Certo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ecBIsQXcWuTz9kPZFBFfSjZZmMP.jpg'),
(66078, 4509, 'Vai Dar Tudo Certo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jdnThqnoxmPsoB8tJRbemZmjbno.jpg'),
(66079, 4509, 'Vai Dar Tudo Certo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ayx4W4V0J3LltZm1xlJ1Cjm8ry2.jpg'),
(66080, 4509, 'Vai Dar Tudo Certo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vXcui90W4goNYMYADgFblzpR0VX.jpg'),
(66081, 4509, 'Vai Dar Tudo Certo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tSox5kqXNGF0a4RVvgvmaV57tsU.jpg'),
(66082, 4509, 'Vai Dar Tudo Certo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zsyAocjNX4Qqc2ub1PiExM9qjFz.jpg'),
(66083, 4509, 'Vai Dar Tudo Certo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pr3PpaQOTkwbEH532K62WbomIah.jpg'),
(66084, 4509, 'Vai Dar Tudo Certo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/23J65SstvVpNgHBQjByMrU1KVAs.jpg'),
(66085, 4510, 'Vai Dar Tudo Certo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mGF5qF0kgftmfQXUClNHHGX10Zv.jpg'),
(66086, 4510, 'Vai Dar Tudo Certo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dXq0uwU6LheZrPE5p5pwXhqJzy6.jpg'),
(66087, 4510, 'Vai Dar Tudo Certo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1GF4MYKtZZoi996hxADlgUc26P9.jpg'),
(66088, 4510, 'Vai Dar Tudo Certo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vrKHC8UUwROlMjgz5AfU4dEQ7gS.jpg'),
(66089, 4510, 'Vai Dar Tudo Certo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1swt8gt4qdvzlUaJK7RXhKQlOak.jpg'),
(66090, 4510, 'Vai Dar Tudo Certo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tkE35IFPvEgqvudixhjLuf4mPc0.jpg'),
(66091, 4510, 'Vai Dar Tudo Certo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qnviRQhslV3OtoaKUbahLXyrmZe.jpg'),
(66092, 4510, 'Vai Dar Tudo Certo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ofx3vI6KIDjrQmIF8MybxO017kj.jpg'),
(66093, 4510, 'Vai Dar Tudo Certo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y4ZuDGNjtVp31lKuJsJhFGiogIS.jpg'),
(66094, 4510, 'Vai Dar Tudo Certo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4NIZYq7wOXhiWKcldDKDpiKBwrO.jpg'),
(66095, 4511, 'O Símbolo Perdido de Dan Brown S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164358.mp4', 'http://image.tmdb.org/t/p/w1280/9tY1pB4guhQa01u9Rs10IJdaQbp.jpg'),
(66096, 4511, 'O Símbolo Perdido de Dan Brown S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164359.mp4', 'http://image.tmdb.org/t/p/w1280/5DUrbNRxMSjSSh396eT0tLeNnW3.jpg'),
(66097, 4511, 'O Símbolo Perdido de Dan Brown S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164360.mp4', 'http://image.tmdb.org/t/p/w1280/2hSDlLMnQjH6Tfyx9WnimXR6ikQ.jpg'),
(66098, 4511, 'O Símbolo Perdido de Dan Brown S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164361.mp4', 'http://image.tmdb.org/t/p/w1280/uIpQmRPfDD0Na86l6fJ4eFSXyU9.jpg'),
(66099, 4511, 'O Símbolo Perdido de Dan Brown S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fiwwvusZk4wP2cxvHL21tzmTV8M.jpg'),
(66100, 4511, 'O Símbolo Perdido de Dan Brown S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6gXTVBL1Co15xP0wyx1yTHY0Vl6.jpg'),
(66101, 4511, 'O Símbolo Perdido de Dan Brown S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164364.mp4', 'http://image.tmdb.org/t/p/w1280/mp8nwcYEjGERxG3t9tcSp743nvs.jpg'),
(66102, 4511, 'O Símbolo Perdido de Dan Brown S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164365.mp4', 'http://image.tmdb.org/t/p/w1280/sJjtZNaJUfrvjZxBjfwkAdjZx1t.jpg'),
(66103, 4511, 'O Símbolo Perdido de Dan Brown S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164366.mp4', 'http://image.tmdb.org/t/p/w1280/jDFGIO8INbIfkQ18ZvZteZEQIYN.jpg'),
(66104, 4511, 'O Símbolo Perdido de Dan Brown S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164367.mp4', 'http://image.tmdb.org/t/p/w1280/5u0RAE23n9FCT1Bgr9z6cQtX01c.jpg'),
(66105, 4512, 'Missa da Meia-Noite S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rHCH4Kx0MOfFEjF86i5Mb50VtYb.jpg'),
(66106, 4512, 'Missa da Meia-Noite S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/npi7zNI99tKLeRfJXfYU2S3u1Lh.jpg'),
(66107, 4512, 'Missa da Meia-Noite S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/osnjfSuT7vvmkMOLF8Zo3EokhaR.jpg'),
(66108, 4512, 'Missa da Meia-Noite S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eaODLqhH0qdqpLHTa6mD5kOtaCs.jpg'),
(66109, 4512, 'Missa da Meia-Noite S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A9Wnl2QCf9xEKiWNQce0eo5HLSC.jpg'),
(66110, 4512, 'Missa da Meia-Noite S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7optGfjx3oqMJi3vkzQpeadc8jA.jpg'),
(66111, 4512, 'Missa da Meia-Noite S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l1vIEwcMfIvhydegGRaF5EV5LzQ.jpg'),
(66112, 4513, 'Submundo do Crime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2NJnHwvVYUvXJvr1rEeEAbamFUE.jpg'),
(66113, 4513, 'Submundo do Crime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1wsFf0ZWCW78SkkGFPVEkskxG0d.jpg'),
(66114, 4513, 'Submundo do Crime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/euRkIj85DOZJHzPrqA2zmerCVpl.jpg'),
(66115, 4513, 'Submundo do Crime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3PeLxStxM0rqzdPyRlKz5AQMJqc.jpg'),
(66116, 4513, 'Submundo do Crime S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/khmtpjFIZ0JWw1C8z20sy7OILsF.jpg'),
(66117, 4513, 'Submundo do Crime S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h9szXtfrtyuJHY2sAo7aMNCIiBP.jpg'),
(66118, 4514, 'Baki Hanma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eVs6e9mQFMha9WqFG5nyk1oC480.jpg'),
(66119, 4514, 'Baki Hanma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kaTQQR0Ya3tcji5I2vwEU89ndi.jpg'),
(66120, 4514, 'Baki Hanma S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mXGIzhWBua72iglimDO5u6ZXw1p.jpg'),
(66121, 4514, 'Baki Hanma S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7pFpJD9o35OYJR2qeGHcU2bhBQT.jpg'),
(66122, 4514, 'Baki Hanma S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eRhtXwCQpqLsRGqFvtmghngLyJr.jpg'),
(66123, 4514, 'Baki Hanma S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yKKuQvTFfvGHNsVnC499hMPGjSO.jpg'),
(66124, 4514, 'Baki Hanma S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h9Xl5qzHnzbJdIqeVhCShso14hH.jpg'),
(66125, 4514, 'Baki Hanma S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rfIyRdj8teIoYO1XrcN6NnNQkLN.jpg'),
(66126, 4514, 'Baki Hanma S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ffYzbBG5xiQYEznFNJYazveW2fD.jpg'),
(66127, 4514, 'Baki Hanma S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aG9jgWHj7NWmVP7MEiDShDn1FLb.jpg'),
(66128, 4514, 'Baki Hanma S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mpPQodMlw1WzKrQxVnNATS1UoGq.jpg'),
(66129, 4514, 'Baki Hanma S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/227927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8i3KZeca73rrwfOzih5WdbKL3NS.jpg'),
(66130, 4515, 'Baki Hanma S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/52b0kwVohqYzaSRG60Uqz5g2PcF.jpg'),
(66131, 4515, 'Baki Hanma S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ApdKFEQxiExjSFO27P4Vh4WPVrb.jpg'),
(66132, 4515, 'Baki Hanma S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1BT88iLjK7ecnymLJLkyZyCTTKY.jpg'),
(66133, 4515, 'Baki Hanma S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rcPp0JWM3QKxJpcCt96UZpT1G51.jpg'),
(66134, 4515, 'Baki Hanma S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u7ybQ3uw9vBOkcdKEx9t6iPic7V.jpg'),
(66135, 4515, 'Baki Hanma S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5G3oDec7UkmTZDviNXbhweZdDN7.jpg'),
(66136, 4515, 'Baki Hanma S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ujMNnTYhJpYQaDVo4XGsmGaI82c.jpg'),
(66137, 4515, 'Baki Hanma S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n0N1IefjFnvkWrxneLQEl88VTyK.jpg'),
(66138, 4515, 'Baki Hanma S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qXTQg2Tqn12mTcJyprjzLehp8Ki.jpg'),
(66139, 4515, 'Baki Hanma S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eeZBzY6oWIDxCkC87pt3v5VcxQb.jpg'),
(66140, 4515, 'Baki Hanma S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/izbRSdrDmH3rBo7MXLNOvTcO5pg.jpg'),
(66141, 4515, 'Baki Hanma S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/227939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nwvVsoxtqx6NqEIaDqcT71IGJkf.jpg'),
(66142, 4515, 'Baki Hanma S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/227940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yZT28IRhicVDJPvItRC34PQ1w5B.jpg'),
(66143, 4515, 'Baki Hanma S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/227941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dTDHBwhDOgILwOqk0vUPIL3E9NT.jpg'),
(66144, 4515, 'Baki Hanma S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/227942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4fGluGKn5qvzJJBKQhnpZioo8pa.jpg'),
(66145, 4515, 'Baki Hanma S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/227943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Ti0bf7hspmqM4SGbt0a4ST1dwy.jpg'),
(66146, 4515, 'Baki Hanma S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/227944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7PYEmwyZXAVHVg8GQKkgM28aFUa.jpg'),
(66147, 4515, 'Baki Hanma S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/227945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vZHd4ToWNURoRNqwAkLnTALaU15.jpg'),
(66148, 4515, 'Baki Hanma S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/227946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l73iX6yfHde8s9sNRisdwnxYQa7.jpg'),
(66149, 4515, 'Baki Hanma S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/227947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6VqL8Tk8w9jVXODjSj2TRH34iOS.jpg'),
(66150, 4515, 'Baki Hanma S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/227948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5GIYY9t8ur7sPAkryh7fTjFE0pR.jpg'),
(66151, 4515, 'Baki Hanma S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/227949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vete4pDKkIFFFvuSHBMSDNS9xcc.jpg'),
(66152, 4515, 'Baki Hanma S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/227950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fuq8BTmWyaobCbt8xIYyKjyjNZg.jpg'),
(66153, 4515, 'Baki Hanma S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/227951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a4jMGy53oWrAobFmJQDGTEIHKf0.jpg'),
(66154, 4515, 'Baki Hanma S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/227952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkSfy5Vev55uGiG9XTEaTm5Ktim.jpg'),
(66155, 4515, 'Baki Hanma S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/227953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dQWATqWHVwA80yWraEsN9jHB9TY.jpg'),
(66156, 4515, 'Baki Hanma S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/227954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a7S1MZWX68uE0EvSw0yWo7SlVfh.jpg'),
(66157, 4516, 'Entre Homens S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wghGhvLTKKGp4sbNedieirdL8uk.jpg'),
(66158, 4516, 'Entre Homens S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wghGhvLTKKGp4sbNedieirdL8uk.jpg'),
(66159, 4516, 'Entre Homens S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wghGhvLTKKGp4sbNedieirdL8uk.jpg'),
(66160, 4516, 'Entre Homens S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wghGhvLTKKGp4sbNedieirdL8uk.jpg'),
(66161, 4517, 'In the Long Run S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qLnuYtoiJUDQYM5BeuyNmx3YQmo.jpg'),
(66162, 4517, 'In the Long Run S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qLnuYtoiJUDQYM5BeuyNmx3YQmo.jpg'),
(66163, 4517, 'In the Long Run S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qLnuYtoiJUDQYM5BeuyNmx3YQmo.jpg'),
(66164, 4517, 'In the Long Run S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qLnuYtoiJUDQYM5BeuyNmx3YQmo.jpg'),
(66165, 4517, 'In the Long Run S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qLnuYtoiJUDQYM5BeuyNmx3YQmo.jpg'),
(66166, 4517, 'In the Long Run S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qLnuYtoiJUDQYM5BeuyNmx3YQmo.jpg'),
(66167, 4518, 'In the Long Run S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q3k4WV38O7J20EMyrt3StgteYRi.jpg'),
(66168, 4518, 'In the Long Run S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h7YwnT6llOltVEQZAZ7DqR7Hwr4.jpg'),
(66169, 4518, 'In the Long Run S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z3LypXMdmYBxXBqpxbajC07LFce.jpg'),
(66170, 4518, 'In the Long Run S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f8ZUZGMTA0eViLYo9FiCwEWHigW.jpg'),
(66171, 4518, 'In the Long Run S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l7mXVYarZwqwJMwaDduvQHGXRhX.jpg'),
(66172, 4518, 'In the Long Run S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/704CW9x3ojXGwayQudnXiImzmJE.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(66173, 4518, 'In the Long Run S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qLnuYtoiJUDQYM5BeuyNmx3YQmo.jpg'),
(66174, 4519, 'In the Long Run S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qLnuYtoiJUDQYM5BeuyNmx3YQmo.jpg'),
(66175, 4519, 'In the Long Run S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qLnuYtoiJUDQYM5BeuyNmx3YQmo.jpg'),
(66176, 4519, 'In the Long Run S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qLnuYtoiJUDQYM5BeuyNmx3YQmo.jpg'),
(66177, 4519, 'In the Long Run S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qLnuYtoiJUDQYM5BeuyNmx3YQmo.jpg'),
(66178, 4519, 'In the Long Run S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qLnuYtoiJUDQYM5BeuyNmx3YQmo.jpg'),
(66179, 4519, 'In the Long Run S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qLnuYtoiJUDQYM5BeuyNmx3YQmo.jpg'),
(66180, 4520, 'Irmãs de Cela: New Orleans S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pA7urHEBVDSJR7Cn7bANRbhwly7.jpg'),
(66181, 4520, 'Irmãs de Cela: New Orleans S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pA7urHEBVDSJR7Cn7bANRbhwly7.jpg'),
(66182, 4520, 'Irmãs de Cela: New Orleans S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pA7urHEBVDSJR7Cn7bANRbhwly7.jpg'),
(66183, 4521, 'Luna Park S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lVapq8Jf8s2s3PUpHIBRZRjZioG.jpg'),
(66184, 4521, 'Luna Park S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o6XthLlUg5nS2LNRup3eI7Yt7Z2.jpg'),
(66185, 4521, 'Luna Park S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5atkc7RsQnVKmhXtzRqufyzTzYK.jpg'),
(66186, 4521, 'Luna Park S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AcBb0tKcVLMeJyQ71d2WmGOof0T.jpg'),
(66187, 4521, 'Luna Park S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8765qNdwOXqWxCcPWPOis7tasfi.jpg'),
(66188, 4521, 'Luna Park S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lNqV0KKJ2Sh9M7t5zLuGOUob5KK.jpg'),
(66189, 4522, 'O Homem das Castanhas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gtEg68XW1X5r76TzWG3l2zlh9IX.jpg'),
(66190, 4522, 'O Homem das Castanhas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6BFYCAzaw4HONXAqIWkNUUVTQbJ.jpg'),
(66191, 4522, 'O Homem das Castanhas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bL20yd7hEfkdSzntsefHSpe89vr.jpg'),
(66192, 4522, 'O Homem das Castanhas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v4E1xiMv2n217SzDYPR5oxcmi1D.jpg'),
(66193, 4522, 'O Homem das Castanhas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qqg908EB8bkaWLI8MxWKsv4xNDV.jpg'),
(66194, 4522, 'O Homem das Castanhas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lcxEeGhCA8kBjNpuw4nSvdITB57.jpg'),
(66195, 4523, 'O Hóspede Americano [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5n8MHK9WQnzPKOFkJeAEYkEiuC.jpg'),
(66196, 4523, 'O Hóspede Americano [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/awE7lK056PXxALuZR60bFJrFMYd.jpg'),
(66197, 4523, 'O Hóspede Americano [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/awE7lK056PXxALuZR60bFJrFMYd.jpg'),
(66198, 4523, 'O Hóspede Americano [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/awE7lK056PXxALuZR60bFJrFMYd.jpg'),
(66199, 4524, 'O Show do Scooby Doo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l92mcQT15hp8J9go29o2VgUoYwk.jpg'),
(66200, 4524, 'O Show do Scooby Doo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5FBjb0gHIqijoU4FOlusQxkgWen.jpg'),
(66201, 4524, 'O Show do Scooby Doo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tH2s51Y7T1JFIpjKTMlYMNauhb4.jpg'),
(66202, 4524, 'O Show do Scooby Doo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n2RJLn9IBBG2EZOUdYwkq49H6G7.jpg'),
(66203, 4524, 'O Show do Scooby Doo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1M3iQQVJcBDLQKKTPTyHGqYx9l.jpg'),
(66204, 4524, 'O Show do Scooby Doo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l0aX861iWxmveSWxRXg1Aw6aNeQ.jpg'),
(66205, 4524, 'O Show do Scooby Doo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5NMsEkCvoH6iXRKXEP6cOMGMEzf.jpg'),
(66206, 4524, 'O Show do Scooby Doo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7926qA5dsycKIHjgPdxkms50ram.jpg'),
(66207, 4524, 'O Show do Scooby Doo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sDrFVnq5VchmJMLc0LGM1gkEXef.jpg'),
(66208, 4524, 'O Show do Scooby Doo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pSlqaL8VESbiv02yUqRj0JdMLmA.jpg'),
(66209, 4524, 'O Show do Scooby Doo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bEaxmL2B1zMxUe0uPxZaPgZsNO6.jpg'),
(66210, 4524, 'O Show do Scooby Doo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Zgklik5Fb2FCD9j1jZ7SOr6jJr.jpg'),
(66211, 4524, 'O Show do Scooby Doo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7B1O3wBPhldRB1nBAkBYjY5iJl.jpg'),
(66212, 4524, 'O Show do Scooby Doo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9axCmoeEGgOow5gDwD6rCJVKs8C.jpg'),
(66213, 4524, 'O Show do Scooby Doo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j26Rfh6w2HI1dMGcLEDFuHP8YsO.jpg'),
(66214, 4524, 'O Show do Scooby Doo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rcNYf34pKtPos0gBKXDDGuwAztC.jpg'),
(66215, 4525, 'O Show do Scooby Doo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66216, 4525, 'O Show do Scooby Doo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66217, 4525, 'O Show do Scooby Doo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66218, 4525, 'O Show do Scooby Doo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66219, 4525, 'O Show do Scooby Doo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66220, 4525, 'O Show do Scooby Doo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66221, 4525, 'O Show do Scooby Doo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66222, 4525, 'O Show do Scooby Doo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66223, 4526, 'O Show do Scooby Doo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66224, 4526, 'O Show do Scooby Doo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66225, 4526, 'O Show do Scooby Doo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66226, 4526, 'O Show do Scooby Doo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66227, 4526, 'O Show do Scooby Doo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66228, 4526, 'O Show do Scooby Doo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66229, 4526, 'O Show do Scooby Doo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66230, 4526, 'O Show do Scooby Doo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66231, 4526, 'O Show do Scooby Doo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66232, 4526, 'O Show do Scooby Doo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66233, 4526, 'O Show do Scooby Doo S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66234, 4526, 'O Show do Scooby Doo S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66235, 4526, 'O Show do Scooby Doo S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66236, 4526, 'O Show do Scooby Doo S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66237, 4526, 'O Show do Scooby Doo S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66238, 4526, 'O Show do Scooby Doo S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/geO8f6BdJ0E3OcJSzqyS3AakuEx.jpg'),
(66239, 4527, 'Os Cavaleiros do Zodíaco: The Lost Canvas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uKEPP60yMlgJz5gK1ajO2KZiO99.jpg'),
(66240, 4527, 'Os Cavaleiros do Zodíaco: The Lost Canvas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qpSHbpa4J6wkD3qkqLohl9XxB4F.jpg'),
(66241, 4527, 'Os Cavaleiros do Zodíaco: The Lost Canvas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gjEGHd5tSItyxLL2vXQ712CqPq.jpg'),
(66242, 4527, 'Os Cavaleiros do Zodíaco: The Lost Canvas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xEpOWuoJMeWtcwRNC1qLwCRf5Ef.jpg'),
(66243, 4527, 'Os Cavaleiros do Zodíaco: The Lost Canvas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rVcK9NtvdbZdEsoRBgkhmStOpFH.jpg'),
(66244, 4527, 'Os Cavaleiros do Zodíaco: The Lost Canvas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6knduznFZKV0RdvEyIju3i4pSIX.jpg'),
(66245, 4527, 'Os Cavaleiros do Zodíaco: The Lost Canvas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8P3vYIzwsKNsJDH0lJ3AHiJvNkQ.jpg'),
(66246, 4527, 'Os Cavaleiros do Zodíaco: The Lost Canvas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nciNdIU5iEZPeprd0kKye0i26kt.jpg'),
(66247, 4527, 'Os Cavaleiros do Zodíaco: The Lost Canvas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xkF57PV96Mxmti3lZI4K4uK9a3c.jpg'),
(66248, 4527, 'Os Cavaleiros do Zodíaco: The Lost Canvas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zUFNwqRuN4TpRrh2MGdOBUFPm1u.jpg'),
(66249, 4527, 'Os Cavaleiros do Zodíaco: The Lost Canvas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5vhQcVBffOjXg4LbztmfEQVO6wk.jpg'),
(66250, 4527, 'Os Cavaleiros do Zodíaco: The Lost Canvas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nOAD0CsNWmtvRhBwl3IsVT3RPIg.jpg'),
(66251, 4527, 'Os Cavaleiros do Zodíaco: The Lost Canvas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/NgrK3juwLVNVimNAqSvTxxkTM7.jpg'),
(66252, 4528, 'Os Cavaleiros do Zodíaco: The Lost Canvas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2KFlvSkrPVj64PGDzdCYPTiTiMg.jpg'),
(66253, 4528, 'Os Cavaleiros do Zodíaco: The Lost Canvas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2KFlvSkrPVj64PGDzdCYPTiTiMg.jpg'),
(66254, 4528, 'Os Cavaleiros do Zodíaco: The Lost Canvas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2KFlvSkrPVj64PGDzdCYPTiTiMg.jpg'),
(66255, 4528, 'Os Cavaleiros do Zodíaco: The Lost Canvas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2KFlvSkrPVj64PGDzdCYPTiTiMg.jpg'),
(66256, 4528, 'Os Cavaleiros do Zodíaco: The Lost Canvas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2KFlvSkrPVj64PGDzdCYPTiTiMg.jpg'),
(66257, 4528, 'Os Cavaleiros do Zodíaco: The Lost Canvas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2KFlvSkrPVj64PGDzdCYPTiTiMg.jpg'),
(66258, 4528, 'Os Cavaleiros do Zodíaco: The Lost Canvas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2KFlvSkrPVj64PGDzdCYPTiTiMg.jpg'),
(66259, 4528, 'Os Cavaleiros do Zodíaco: The Lost Canvas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2KFlvSkrPVj64PGDzdCYPTiTiMg.jpg'),
(66260, 4528, 'Os Cavaleiros do Zodíaco: The Lost Canvas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2KFlvSkrPVj64PGDzdCYPTiTiMg.jpg'),
(66261, 4528, 'Os Cavaleiros do Zodíaco: The Lost Canvas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2KFlvSkrPVj64PGDzdCYPTiTiMg.jpg'),
(66262, 4528, 'Os Cavaleiros do Zodíaco: The Lost Canvas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2KFlvSkrPVj64PGDzdCYPTiTiMg.jpg'),
(66263, 4528, 'Os Cavaleiros do Zodíaco: The Lost Canvas S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2KFlvSkrPVj64PGDzdCYPTiTiMg.jpg'),
(66264, 4528, 'Os Cavaleiros do Zodíaco: The Lost Canvas S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2KFlvSkrPVj64PGDzdCYPTiTiMg.jpg'),
(66265, 4529, 'Posso Explicar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jb74fDltrFdp6jEAxPTwoLzGUzz.jpg'),
(66266, 4529, 'Posso Explicar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1zkTeR6e2NLRcqgovgurORtBQUj.jpg'),
(66267, 4529, 'Posso Explicar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hpj5YDu8F7itnSHB0EdYY7gUTyW.jpg'),
(66268, 4529, 'Posso Explicar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2maWRCbXMJ0PovPatRLXDmp9NPi.jpg'),
(66269, 4529, 'Posso Explicar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n28dyHKsWy4dDUC6ajc4pt3Yui6.jpg'),
(66270, 4529, 'Posso Explicar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b3ctWqqcFjutQ2bfKoMeC6fTX30.jpg'),
(66271, 4529, 'Posso Explicar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6bKlSbMlVTHFqaM9usXNPptQDvp.jpg'),
(66272, 4529, 'Posso Explicar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AgF6vKKrAkibY2YYKVvC5CdsxWw.jpg'),
(66273, 4529, 'Posso Explicar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/57GswvsJZfQb2rAM21pc60QcT8H.jpg'),
(66274, 4529, 'Posso Explicar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpFLNUPi3lTV6OFhyfkd9y1aZNx.jpg'),
(66275, 4529, 'Posso Explicar S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7i5TuShRFSGNiiUts5bmdzsE2vV.jpg'),
(66276, 4529, 'Posso Explicar S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/esaGl9bO2O6OCptSDo3T2izgMTp.jpg'),
(66277, 4530, 'Vivy: Fluorite Eye’s Song S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wxtuhX3sIw1vrUvb0E5oljEGKTh.jpg'),
(66278, 4530, 'Vivy: Fluorite Eye’s Song S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9TaORqmhi7XHVxDr1uUYSF34fQx.jpg'),
(66279, 4530, 'Vivy: Fluorite Eye’s Song S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wTMcp6oJ55TQBPNkn4Gcfr0VKpH.jpg'),
(66280, 4530, 'Vivy: Fluorite Eye’s Song S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5OtreMOItcMadpAoEIjGmdbIocK.jpg'),
(66281, 4530, 'Vivy: Fluorite Eye’s Song S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4c9sJ0d18hgQFGJbCuX19NjL5Nr.jpg'),
(66282, 4530, 'Vivy: Fluorite Eye’s Song S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/60rzioygAXkhF5PXka8FMEiZiCe.jpg'),
(66283, 4530, 'Vivy: Fluorite Eye’s Song S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTVxaabyUw7KoKz58OoR3f8dXSW.jpg'),
(66284, 4530, 'Vivy: Fluorite Eye’s Song S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhdY2IsZdGWsId6exEj2s3rjAjS.jpg'),
(66285, 4530, 'Vivy: Fluorite Eye’s Song S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/42MCcvrDhtcmDqcZc8ucsWH3wOv.jpg'),
(66286, 4530, 'Vivy: Fluorite Eye’s Song S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oMQTI4viNNIHcO9ucrNwsBa8Dil.jpg'),
(66287, 4530, 'Vivy: Fluorite Eye’s Song S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vWDHdflN5gAow5sn1itkDJKkXfy.jpg'),
(66288, 4530, 'Vivy: Fluorite Eye’s Song S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6osVBJDEqHW981hFieav6uiGb8Q.jpg'),
(66289, 4530, 'Vivy: Fluorite Eye’s Song S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/imCWogN9YrjjEszmtXbkUfUgrEU.jpg'),
(66290, 4531, 'Young Rock S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h5oh77jA6BHtp9cTmfFzlb90Kdh.jpg'),
(66291, 4531, 'Young Rock S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d8kcdxmmqdCoPZ8kTlNLEBfBOAZ.jpg'),
(66292, 4531, 'Young Rock S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13mTDfnpfNMUp5x2VWV7MS3txvP.jpg'),
(66293, 4531, 'Young Rock S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b6AykdONPsfXKdGq884M0kL6Z3n.jpg'),
(66294, 4531, 'Young Rock S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJSYZys3RJ5JzGO4NUU07q9mXy1.jpg'),
(66295, 4531, 'Young Rock S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZjhx0nI2W5BB4KQZCiyNuazU3I.jpg'),
(66296, 4531, 'Young Rock S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dsOZCFdBvZnJYd1cKjgouQNc1rt.jpg'),
(66297, 4531, 'Young Rock S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9u2vSBqBg2DmCs2WSbWcGU62Wvk.jpg'),
(66298, 4531, 'Young Rock S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/168790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AwqommmRuci3SpuCqYJs2pKHhhl.jpg'),
(66299, 4531, 'Young Rock S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/168791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pmbTDdpXaHuRDdPsJhH7JujirSB.jpg'),
(66300, 4531, 'Young Rock S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/168792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vIAXEouyXKUMfjBbh71moskGqHk.jpg'),
(66301, 4532, 'Young Rock S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168793.mp4', 'http://image.tmdb.org/t/p/w1280/42QtcAFHQSxLIFUk5oo9uKqCNDX.jpg'),
(66302, 4532, 'Young Rock S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/882164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66303, 4532, 'Young Rock S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/882165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66304, 4532, 'Young Rock S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/882166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66305, 4532, 'Young Rock S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/882167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66306, 4532, 'Young Rock S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/882168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66307, 4532, 'Young Rock S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/882169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66308, 4532, 'Young Rock S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/882170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66309, 4532, 'Young Rock S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/882171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66310, 4532, 'Young Rock S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/882172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66311, 4532, 'Young Rock S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/882173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66312, 4532, 'Young Rock S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/882174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66313, 4532, 'Young Rock S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/882175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66314, 4533, 'Young Rock S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/882176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66315, 4533, 'Young Rock S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/882177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66316, 4533, 'Young Rock S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/882178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66317, 4533, 'Young Rock S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/882179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66318, 4533, 'Young Rock S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/882180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66319, 4533, 'Young Rock S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/882181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66320, 4533, 'Young Rock S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/882182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66321, 4533, 'Young Rock S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/882183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66322, 4533, 'Young Rock S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/882184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66323, 4533, 'Young Rock S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/882185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66324, 4533, 'Young Rock S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/882186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66325, 4533, 'Young Rock S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/882187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66326, 4533, 'Young Rock S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/882188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hUmSMg5KHJkgeOk9AvbTINYOuEf.jpg'),
(66327, 4534, 'Debris S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xXd9X2AB8vX02E898xQZdGbKWhX.jpg'),
(66328, 4534, 'Debris S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f52PqvzlyaKg4Vy2H7h1wBUiKJM.jpg'),
(66329, 4534, 'Debris S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mUvncZdDU4AcigRPq8nDNz1GvtF.jpg'),
(66330, 4534, 'Debris S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mTU3vMtbCxsZenj9gnv6A3783aj.jpg'),
(66331, 4534, 'Debris S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kG1nWeoybyuKxp1caPsbwKqR9UB.jpg'),
(66332, 4534, 'Debris S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zHJDosNFcLMZtWTGf8A3NCe5Sm0.jpg'),
(66333, 4534, 'Debris S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wuHCqsLf2ZeWqVl3Bao4Tl48upV.jpg'),
(66334, 4534, 'Debris S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lBzwjGA3xniA7CPpKlQmJZEj0uw.jpg'),
(66335, 4534, 'Debris S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gd9FY2eKd0inHVwnmgtyDR4TZGm.jpg'),
(66336, 4534, 'Debris S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kdSZvUAdrLFuJD5YKE9PhbvVETO.jpg'),
(66337, 4534, 'Debris S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5wBRgF0tcM1eYJHKjV2QQ4NRyfF.jpg'),
(66338, 4534, 'Debris S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqnlLUeYAKsdzxDyT34l9p4Okzo.jpg'),
(66339, 4534, 'Debris S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9xN2zCx5uslkdoc2nBkgDnA3bM9.jpg'),
(66340, 4535, 'Maid S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eT1iikHCvdDdK44RJdsaBCvCFES.jpg'),
(66341, 4535, 'Maid S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j7nIfAMiVF88layu4O3oUocLdEy.jpg'),
(66342, 4535, 'Maid S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/G9aF7CouxyHhkoOIafEgFzCSc2.jpg'),
(66343, 4535, 'Maid S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4nXVSsIW7HHr0VxlrTkan2ans2S.jpg'),
(66344, 4535, 'Maid S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zGuBOOED7VZne0JlhBPSqCpx6mB.jpg'),
(66345, 4535, 'Maid S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pWVVfP0Dj3qJfXiHTgxzGAKAxY3.jpg'),
(66346, 4535, 'Maid S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mAEMjStdIDNO0Jb9gOxZXcqUpGq.jpg'),
(66347, 4535, 'Maid S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hsvarVhEVnm58gpavdM3i3xRNnY.jpg'),
(66348, 4535, 'Maid S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cCDqFu6USJapxSSjEb3l3XFKbWM.jpg'),
(66349, 4535, 'Maid S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mym3G9V33BFUP4wPGlRwzUeGFbQ.jpg'),
(66350, 4536, 'A Nova Super Máquina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e93H0P6GYoDUhHR5uCdmfLDAvKt.jpg'),
(66351, 4536, 'A Nova Super Máquina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ob4FHSCWwkzrHAkKSECFaH719Ms.jpg'),
(66352, 4536, 'A Nova Super Máquina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vTFET8Ol9uN9CeOOLyDA4ZEPeff.jpg'),
(66353, 4536, 'A Nova Super Máquina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1uwYyGfu0s5ExghQ2476shtjjR9.jpg'),
(66354, 4536, 'A Nova Super Máquina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gpBW5ihlPBpq2IYUwi8oV5fppkz.jpg'),
(66355, 4536, 'A Nova Super Máquina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5XXExW2q88K926gYlDeJvjI8EF9.jpg'),
(66356, 4536, 'A Nova Super Máquina S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8lMVUmFbmksbz7gv8y3A8nOYvJ.jpg'),
(66357, 4536, 'A Nova Super Máquina S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/msGEGbgFMZ7OAzBMOFmtD1YHdMM.jpg'),
(66358, 4536, 'A Nova Super Máquina S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aEFmhYrLWELWMZOos9CFQX08vU0.jpg'),
(66359, 4536, 'A Nova Super Máquina S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vohEk2jC2qWrZuA3PM5bt1foJYr.jpg'),
(66360, 4536, 'A Nova Super Máquina S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wgC3TWEsX7rgXvg4vgUWkRS7RDa.jpg'),
(66361, 4536, 'A Nova Super Máquina S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oet69nWoVHjW9WbJ8YqkRDHDR46.jpg'),
(66362, 4536, 'A Nova Super Máquina S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rQlo75KLHVUibspfhDTjhZihkcP.jpg'),
(66363, 4536, 'A Nova Super Máquina S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/EchQLIS9iU9gJqDZCSRwZtQapl.jpg'),
(66364, 4536, 'A Nova Super Máquina S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nT0FhPssESP4M4qazMVHSpteQsy.jpg'),
(66365, 4536, 'A Nova Super Máquina S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/suKE5R3PrX7yQM6TbbdJjXSNOX7.jpg'),
(66366, 4536, 'A Nova Super Máquina S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fRnZ29iaejkfP3nDgSqzdecxb6m.jpg'),
(66367, 4536, 'A Nova Super Máquina S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bDL43GrV6iI0I4MQwiWmHyTcgZo.jpg'),
(66368, 4537, 'A Super Máquina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dRg9Z0OjrVHBcTlxQecC10a3wnq.jpg'),
(66369, 4537, 'A Super Máquina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZKoEMsLxKF99WMOeXEXtB8YhZr.jpg'),
(66370, 4537, 'A Super Máquina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m9phpkk8fMDZKBdc84MGx8dMGoa.jpg'),
(66371, 4537, 'A Super Máquina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fBM5cfUanuQVvaLnw69HnmGWeHK.jpg'),
(66372, 4537, 'A Super Máquina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cMgzeme02QGUxQRkLm58rD2yDJu.jpg'),
(66373, 4537, 'A Super Máquina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9p0WqZ42q989QgGJYGox4FFZ2Kg.jpg'),
(66374, 4537, 'A Super Máquina S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ArGdi81ZtOSa3r5BQKnBZUvW7Jq.jpg'),
(66375, 4537, 'A Super Máquina S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5FWEfZPXTDfXDT7xg5xHhXsTlQ3.jpg'),
(66376, 4537, 'A Super Máquina S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cNVw3QgsvECDVPH7KOKCQsrNXmg.jpg'),
(66377, 4537, 'A Super Máquina S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qga7I89F5Px9bDNjlcJOwMoDHJO.jpg'),
(66378, 4537, 'A Super Máquina S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/290VDdWT1svKelRkOmWcuWPKJEX.jpg'),
(66379, 4537, 'A Super Máquina S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/afyPYc3tyYKDuZoo3sHxYXxsauS.jpg'),
(66380, 4537, 'A Super Máquina S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Ri6NjqcCJQabKzdq8PCd1dScFL.jpg'),
(66381, 4537, 'A Super Máquina S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/173634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4FDpIJAtFr8kGsQQ69ovUzw2kk9.jpg'),
(66382, 4537, 'A Super Máquina S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/173635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eEaTqFpzRTM2teMMcyJM9XdwS8N.jpg'),
(66383, 4537, 'A Super Máquina S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/173636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rrFMLvUD9FSEvhIfEocOUS8kTMN.jpg'),
(66384, 4537, 'A Super Máquina S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/173637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f3MKI8M0MIYkKAfZ4kzc5hidFBC.jpg'),
(66385, 4537, 'A Super Máquina S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/173638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cS2sBW8NV2zcPyyyLGDmlonWfyB.jpg'),
(66386, 4537, 'A Super Máquina S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/173639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nRn59eKTS76fVuyhtFspcQt4wJX.jpg'),
(66387, 4537, 'A Super Máquina S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/173640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cwhSppMM22Mu5Asg2dYiYf31kcz.jpg'),
(66388, 4537, 'A Super Máquina S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/173641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bz0eEypQmareCVFqRB3MbahFO2T.jpg'),
(66389, 4538, 'A Super Máquina S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tpjKl4M5vpm8otX2GnHIPG02kMj.jpg'),
(66390, 4538, 'A Super Máquina S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/doffTtnM6NHkGNwCOWKQjtALtUT.jpg'),
(66391, 4538, 'A Super Máquina S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/inDdIvXvD4ca2fKYn3AQ6ok0dj.jpg'),
(66392, 4538, 'A Super Máquina S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b7irvlrd0Bbc3M11Nhw4qrL8Eu1.jpg'),
(66393, 4538, 'A Super Máquina S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/he7EUCD1rfhq7nOLr7yyXwEMXvU.jpg'),
(66394, 4538, 'A Super Máquina S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ykJhXvCLnZyEniwxauVlTruCDaA.jpg'),
(66395, 4538, 'A Super Máquina S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4N9EFK3MKoN5JyTVahwrf5SUqRa.jpg'),
(66396, 4538, 'A Super Máquina S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vnRkLLccJVGKw6P8NqfpqXc4COB.jpg'),
(66397, 4538, 'A Super Máquina S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1pLx6MWKTAdPQRDE3qEaZREXqzD.jpg'),
(66398, 4538, 'A Super Máquina S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hRKsLzgqLBryyCBI7engJSRYiXp.jpg'),
(66399, 4538, 'A Super Máquina S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n2MuSfnd5LxT2bBDda5vnhrouzQ.jpg'),
(66400, 4538, 'A Super Máquina S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rWJSbCnQmW8V0ZmfrNiFdzyTT3X.jpg'),
(66401, 4538, 'A Super Máquina S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sgihXKkd2uR90COEXHo8CRHHIjo.jpg'),
(66402, 4538, 'A Super Máquina S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/173655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xsi1euP2x7ntEnQlmnRbtN1yWjr.jpg'),
(66403, 4538, 'A Super Máquina S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/173656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v8pXBfMWqHFlQ73zXsObKXXXVn6.jpg'),
(66404, 4538, 'A Super Máquina S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/173657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qPcp5ugwMxPuU9N2j7vZXkfGBet.jpg'),
(66405, 4538, 'A Super Máquina S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/173658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8EN7XFgROpQvmRGuV3srjT4ntij.jpg'),
(66406, 4538, 'A Super Máquina S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/173659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nbKLaxLH8Jd5zPv7HaYHeHbuTEQ.jpg'),
(66407, 4538, 'A Super Máquina S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/173660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qY3wjwvoytioqmSDD7DGOky56AB.jpg'),
(66408, 4538, 'A Super Máquina S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/173661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yowMcOpV6m5T06zgBAjTBXd6wpT.jpg'),
(66409, 4538, 'A Super Máquina S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/173662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uhDK40VJb0flzOfA3cipFNCOn1E.jpg'),
(66410, 4539, 'A Super Máquina S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173663.mp4', 'http://timg.bdta.pro/images/09d539a5e45a4d5c09c8d11ca9b07813.jpg'),
(66411, 4539, 'A Super Máquina S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173664.mp4', 'http://timg.bdta.pro/images/e98670ce131880aeacd51963861941e9.jpg'),
(66412, 4539, 'A Super Máquina S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173665.mp4', 'http://timg.bdta.pro/images/61e73edb967e7b37d90ed8c3f4fb76e4.jpg'),
(66413, 4539, 'A Super Máquina S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173666.mp4', 'http://timg.bdta.pro/images/e2389758bddb2d8d3ad6703c3cc07672.jpg'),
(66414, 4539, 'A Super Máquina S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173667.mp4', 'http://timg.bdta.pro/images/1d461108a1771cac01ca6aa828392984.jpg'),
(66415, 4539, 'A Super Máquina S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173668.mp4', 'http://timg.bdta.pro/images/6c10c3ea315c6444ca4cef9ceb0ae689.jpg'),
(66416, 4539, 'A Super Máquina S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173669.mp4', 'http://timg.bdta.pro/images/0e82e5b26d1ca6ef2a25e14f482db724.jpg'),
(66417, 4539, 'A Super Máquina S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173670.mp4', 'http://timg.bdta.pro/images/c0040649157bc25bae13cb49581c317d.jpg'),
(66418, 4539, 'A Super Máquina S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173671.mp4', 'http://timg.bdta.pro/images/0710e78e2ac66e16e0f55e52452853e7.jpg'),
(66419, 4539, 'A Super Máquina S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173672.mp4', 'http://timg.bdta.pro/images/1845b72a88a230cf6ac7f4260357a251.jpg'),
(66420, 4539, 'A Super Máquina S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173673.mp4', 'http://timg.bdta.pro/images/0eb16b947f62fc5dddceceaee6137692.jpg'),
(66421, 4539, 'A Super Máquina S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173674.mp4', 'http://timg.bdta.pro/images/248910c98f5306fd30d2acac3eed9e12.jpg'),
(66422, 4539, 'A Super Máquina S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173675.mp4', 'http://timg.bdta.pro/images/bd3d70d38ca559fb0835303b7a848621.jpg'),
(66423, 4539, 'A Super Máquina S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/173676.mp4', 'http://timg.bdta.pro/images/b11cac254e2ca6456d312bb068bb130a.jpg'),
(66424, 4539, 'A Super Máquina S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/173677.mp4', 'http://timg.bdta.pro/images/655593fe1a20c7aed8cb328946a56e6d.jpg'),
(66425, 4540, 'A Super Máquina S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173678.mp4', 'http://timg.bdta.pro/images/dc224f2fa0f8d46999d608db961704bd.jpg'),
(66426, 4540, 'A Super Máquina S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173679.mp4', 'http://timg.bdta.pro/images/a4fed9851945580da5374b3715115e82.jpg'),
(66427, 4540, 'A Super Máquina S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173680.mp4', 'http://timg.bdta.pro/images/a43e1fbe4462e2108708765fda46918e.jpg'),
(66428, 4540, 'A Super Máquina S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173681.mp4', 'http://timg.bdta.pro/images/de7f94eed8e2945e32327bd74e384138.jpg'),
(66429, 4540, 'A Super Máquina S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173682.mp4', 'http://timg.bdta.pro/images/e8d3031cbd02519f6fa71827a62066a0.jpg'),
(66430, 4540, 'A Super Máquina S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173683.mp4', 'http://timg.bdta.pro/images/31c614935956b588e83a052d916b8052.jpg'),
(66431, 4540, 'A Super Máquina S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173684.mp4', 'http://timg.bdta.pro/images/887b39fe5a960c416b463b2bbd975e30.jpg'),
(66432, 4540, 'A Super Máquina S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173685.mp4', 'http://timg.bdta.pro/images/125d28fdbc530d5a8c63b6ea59b8dc20.jpg'),
(66433, 4540, 'A Super Máquina S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173686.mp4', 'http://timg.bdta.pro/images/44ab0b9f67189c201dc511a3fd3328e8.jpg'),
(66434, 4540, 'A Super Máquina S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173687.mp4', 'http://timg.bdta.pro/images/3aa47f8ab039c0880e321bda2cd9c67b.jpg'),
(66435, 4540, 'A Super Máquina S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173688.mp4', 'http://timg.bdta.pro/images/52a0677252803eeb4b5826c1fe94b5db.jpg'),
(66436, 4540, 'A Super Máquina S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173689.mp4', 'http://timg.bdta.pro/images/0c7327e512062ae87d35bfff22cdee1a.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(66437, 4540, 'A Super Máquina S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173690.mp4', 'http://timg.bdta.pro/images/9ea66810cfc5ae24ca46b3a53e23ebcf.jpg'),
(66438, 4540, 'A Super Máquina S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/173691.mp4', 'http://timg.bdta.pro/images/85a880236c9c72424a44bf84583f096b.jpg'),
(66439, 4540, 'A Super Máquina S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/173692.mp4', 'http://timg.bdta.pro/images/a6fbdc3169189a3d799000f1c60b606e.jpg'),
(66440, 4540, 'A Super Máquina S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/173693.mp4', 'http://timg.bdta.pro/images/2e32e19a448a144cd2a8dde5ee2bd195.jpg'),
(66441, 4540, 'A Super Máquina S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/173694.mp4', 'http://timg.bdta.pro/images/37f4feed5fa0e9c10e6f47d9b09a9cb8.jpg'),
(66442, 4540, 'A Super Máquina S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/173695.mp4', 'http://timg.bdta.pro/images/6e0c5c0cf621c0a9b143310705b660a5.jpg'),
(66443, 4540, 'A Super Máquina S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/173696.mp4', 'http://timg.bdta.pro/images/dd4b092bea10f98f5c1268d45e095fc5.jpg'),
(66444, 4541, 'A Vida de Dug S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lksiSXfkhVkMgJ04kfFkUzXqcYP.jpg'),
(66445, 4541, 'A Vida de Dug S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gS8Gsmn3aSI4nZjPcKgTrZOJd5E.jpg'),
(66446, 4541, 'A Vida de Dug S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZgK1AWw4mPyrSLdftUeRqXCYtQ.jpg'),
(66447, 4541, 'A Vida de Dug S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/657Nk2Wy8Sva2pOZfAsS3BPzS2z.jpg'),
(66448, 4541, 'A Vida de Dug S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lXcU9Cbler2kQu2nTytS1C8fHlw.jpg'),
(66449, 4542, 'A vingança das Juanas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUwQzwV4sny9XCI9XVJWeLUBGuw.jpg'),
(66450, 4542, 'A vingança das Juanas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4tCmoSvbpLqprEpEY8EHCjoFRf4.jpg'),
(66451, 4542, 'A vingança das Juanas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8W4sN5bMi58wOnSQpNPKLxeMS5q.jpg'),
(66452, 4542, 'A vingança das Juanas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqSXMZXSBwZG0wgSHP9cjd0SvWK.jpg'),
(66453, 4542, 'A vingança das Juanas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fkHIjHUyHGSggXNauip3oDspz8k.jpg'),
(66454, 4542, 'A vingança das Juanas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6aKR27TJyEkL852H1wp6nYDlrzc.jpg'),
(66455, 4542, 'A vingança das Juanas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AcLLotaZ3hpH3cEiS94Fj9Z0Hut.jpg'),
(66456, 4542, 'A vingança das Juanas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tEOnroGpSv6BenOZL1A9Aofmdwl.jpg'),
(66457, 4542, 'A vingança das Juanas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDcDtkEkGgfek255B6ZIrTccVQ5.jpg'),
(66458, 4542, 'A vingança das Juanas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8S6iARfo8deD4hl91MsIkYVokvi.jpg'),
(66459, 4542, 'A vingança das Juanas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Cvbuoh0bPeZ3cJqLIYvAgtWW6K.jpg'),
(66460, 4542, 'A vingança das Juanas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/83n1FZoQVYlS3b8JJZY0xebncw6.jpg'),
(66461, 4542, 'A vingança das Juanas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AiDw09uZEy5xIlRCbrobbiCM8V7.jpg'),
(66462, 4542, 'A vingança das Juanas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4enR183e9wTJKPDuJM8LB01vqZf.jpg'),
(66463, 4542, 'A vingança das Juanas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aqSaMy71kLRBhTw0gskBZkMRwSG.jpg'),
(66464, 4542, 'A vingança das Juanas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lA9RCh9Lw0KL2Mwh4CHFgAKCgfc.jpg'),
(66465, 4542, 'A vingança das Juanas S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hbhn2EmC5deoYyKrrkZjSnsdezj.jpg'),
(66466, 4542, 'A vingança das Juanas S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qYnx8A6WcTx2dbSSf4Ebj7v3l6x.jpg'),
(66467, 4543, 'Angel: O Caça Vampiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ftyWrISuty7pqHnAbq5uDm647aY.jpg'),
(66468, 4543, 'Angel: O Caça Vampiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iX5VZDyI6vG6zsH4NhNBJyL9grk.jpg'),
(66469, 4543, 'Angel: O Caça Vampiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5lhwbtF4qrpShvlgQdxmVtx94th.jpg'),
(66470, 4543, 'Angel: O Caça Vampiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n9ZIIOxCSRw4OKE4IJjDInI26VL.jpg'),
(66471, 4543, 'Angel: O Caça Vampiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A7g71gOTU1cBrGthEU7vqwXv9Sf.jpg'),
(66472, 4543, 'Angel: O Caça Vampiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmi7idVYAKFODz7C86UGMsSp9E3.jpg'),
(66473, 4543, 'Angel: O Caça Vampiro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Dnn5hcCJqqXS6QRjoJrgukEfnw.jpg'),
(66474, 4543, 'Angel: O Caça Vampiro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j2vA2nQwp3b6yFVWqN9sn7CqPFm.jpg'),
(66475, 4543, 'Angel: O Caça Vampiro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/djyuK3T5IvL6JKHrfmeJB88L0F9.jpg'),
(66476, 4543, 'Angel: O Caça Vampiro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/psfqCIi3QYtbwrmcGPuIx7OK9tj.jpg'),
(66477, 4543, 'Angel: O Caça Vampiro S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8bGnwhecgFmwyNJspLJbiOu6c9l.jpg'),
(66478, 4543, 'Angel: O Caça Vampiro S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iLhMo0gZjDtZ88rHsSn14VDy0sq.jpg'),
(66479, 4543, 'Angel: O Caça Vampiro S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a54egFsfHfEjMm9kf8XbiT5yI0d.jpg'),
(66480, 4543, 'Angel: O Caça Vampiro S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JheY5jq5b0HBQonUVXvsM4RBt5.jpg'),
(66481, 4543, 'Angel: O Caça Vampiro S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a3RHcehEFmxo4dL9vr59pDgO2Bl.jpg'),
(66482, 4543, 'Angel: O Caça Vampiro S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nU9pUdcfUhI9Rrs7CC3Qv0bAnuj.jpg'),
(66483, 4543, 'Angel: O Caça Vampiro S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wNFw0ayI9hKfxY1hFPupIQ5bJO5.jpg'),
(66484, 4543, 'Angel: O Caça Vampiro S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QbKF1bqOtsSDvinTSseMNTTaVe.jpg'),
(66485, 4543, 'Angel: O Caça Vampiro S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOXR69N2Cc2aOIVk7wvO64szq9k.jpg'),
(66486, 4543, 'Angel: O Caça Vampiro S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCH8xVMzabweLF90jWPsqyZ65WA.jpg'),
(66487, 4543, 'Angel: O Caça Vampiro S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/66anqK48AxATU7VNK7dFdWfWcTD.jpg'),
(66488, 4543, 'Angel: O Caça Vampiro S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/23JZMZ9vUWcLOfwUWRptTaZwEsy.jpg'),
(66489, 4544, 'Angel: O Caça Vampiro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odLr8ckyZLccgclUSArxfE7IEPV.jpg'),
(66490, 4544, 'Angel: O Caça Vampiro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hFf4EgujzjdeKjjxxS9tYzQIHeA.jpg'),
(66491, 4544, 'Angel: O Caça Vampiro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Bw2TF82dpDA9wxQGGAcU2W61Lj.jpg'),
(66492, 4544, 'Angel: O Caça Vampiro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdjF2gMJ5HIFt7gD6b2dfyTJ0t1.jpg'),
(66493, 4544, 'Angel: O Caça Vampiro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1cpzFenzbGNj6XkeK8CJ6xA6Rqy.jpg'),
(66494, 4544, 'Angel: O Caça Vampiro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bpnuqUtXoMWW4OT5IHkv1EHAMEb.jpg'),
(66495, 4544, 'Angel: O Caça Vampiro S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kpT7dOe0se4zb0cClOKLOtg0YcY.jpg'),
(66496, 4544, 'Angel: O Caça Vampiro S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bSNEf8HHF3G3RqPDoH1tJ6scYiu.jpg'),
(66497, 4544, 'Angel: O Caça Vampiro S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6L6Z2GuUxYjFhHD8BoZz1MfU4ke.jpg'),
(66498, 4544, 'Angel: O Caça Vampiro S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oKWoe8VJDX7zTNqxJl6mSbM5Wbo.jpg'),
(66499, 4544, 'Angel: O Caça Vampiro S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHVzfSUv1ZojUXAl1veagRqkPgO.jpg'),
(66500, 4544, 'Angel: O Caça Vampiro S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/phuZJwbTlBvFaYi9KAUH2qC4e6G.jpg'),
(66501, 4544, 'Angel: O Caça Vampiro S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kMOIrEqbCXHTxrQMIqtw2hyURsI.jpg'),
(66502, 4544, 'Angel: O Caça Vampiro S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nNO7uYSpSp2T8afdc87bu1PmOzi.jpg'),
(66503, 4544, 'Angel: O Caça Vampiro S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qE5Tio3hSSQb71XRMS1Yn7EbFqs.jpg'),
(66504, 4544, 'Angel: O Caça Vampiro S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2e7wnnziP5GwNFg0oC526zqUGTu.jpg'),
(66505, 4544, 'Angel: O Caça Vampiro S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7TkGiPLGi3qzAdnJlHXYemlDb5V.jpg'),
(66506, 4544, 'Angel: O Caça Vampiro S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tXspUS4YZ5vFFoiOsu6K7JeOltF.jpg'),
(66507, 4544, 'Angel: O Caça Vampiro S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aenyr3GV5pOVkv5Hvty4whVx8Hb.jpg'),
(66508, 4544, 'Angel: O Caça Vampiro S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wi5d0Z58NF9b9nLqLXmmf0ZxwwM.jpg'),
(66509, 4544, 'Angel: O Caça Vampiro S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s7QijF1JXKUUhJWEY9sSR9sKDwM.jpg'),
(66510, 4544, 'Angel: O Caça Vampiro S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4NweaqZefwO0TIe5znHVpcgHhoF.jpg'),
(66511, 4545, 'Angel: O Caça Vampiro S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/247p28c6b6KyTG4sHPAX6EjiVfs.jpg'),
(66512, 4545, 'Angel: O Caça Vampiro S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ziv71LrzGk8cDquNBwWkLFm9uGd.jpg'),
(66513, 4545, 'Angel: O Caça Vampiro S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bMbRxjUXKFv3eHDzKGhAVeugXNX.jpg'),
(66514, 4545, 'Angel: O Caça Vampiro S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f6Sl7v1G0Ilj13SLRXUcvuFfK7g.jpg'),
(66515, 4545, 'Angel: O Caça Vampiro S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oVtnHSR1p9dxVFrO1NseIrJg87h.jpg'),
(66516, 4545, 'Angel: O Caça Vampiro S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4TIr0giJK44ZJ7TGtnkg7Augjyr.jpg'),
(66517, 4545, 'Angel: O Caça Vampiro S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z6Q07NUsAn5dTkLrFDjA0qfxXtb.jpg'),
(66518, 4545, 'Angel: O Caça Vampiro S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fLmIMyRWiW6ayJMH9TijzkuBHBN.jpg'),
(66519, 4545, 'Angel: O Caça Vampiro S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3N3cVnAzvmxuIXWqMQq1V2VI1Nn.jpg'),
(66520, 4545, 'Angel: O Caça Vampiro S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wVm3wYeOXAoJDPZobo1ylx8HsWN.jpg'),
(66521, 4545, 'Angel: O Caça Vampiro S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dQCbMdWOaHQMsEkLLZk6h6rDq1I.jpg'),
(66522, 4545, 'Angel: O Caça Vampiro S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svhYw6lxsUPF5xn1CazUliSOiZN.jpg'),
(66523, 4545, 'Angel: O Caça Vampiro S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8FyWgzMiIPhQPulNg4dYnWMM65w.jpg'),
(66524, 4545, 'Angel: O Caça Vampiro S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ju5nfs51o3M2tq7yRluMmUrslZB.jpg'),
(66525, 4545, 'Angel: O Caça Vampiro S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/orDGT5e9ra9h3RoKKCrJni672GU.jpg'),
(66526, 4545, 'Angel: O Caça Vampiro S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5FNvvg7Cf3KARdZePfbyaBFuAOA.jpg'),
(66527, 4545, 'Angel: O Caça Vampiro S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2HjAiEHwxbU2WWAlFJ9bAoHyVM.jpg'),
(66528, 4545, 'Angel: O Caça Vampiro S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zHCrJkmWavw7uiKwPJbdwePNpgc.jpg'),
(66529, 4545, 'Angel: O Caça Vampiro S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dHM1UbdEwMrm1lQCHIXRd4371Zv.jpg'),
(66530, 4545, 'Angel: O Caça Vampiro S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1KNLC7d8GrrfyjK3g6x9fMgFZAI.jpg'),
(66531, 4545, 'Angel: O Caça Vampiro S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xXNhfNioEk9z6zXzXqC05gh8UkZ.jpg'),
(66532, 4545, 'Angel: O Caça Vampiro S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vLcSHtQoGjncNrbDYfKY5n2sdJc.jpg'),
(66533, 4546, 'Angel: O Caça Vampiro S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lWfC8WlaIUc6gOdhypAG0lty5YH.jpg'),
(66534, 4546, 'Angel: O Caça Vampiro S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqYoBPqZAMpWtERrDBKsU8rxt0Q.jpg'),
(66535, 4546, 'Angel: O Caça Vampiro S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8f7nypxPFostkCINowi1hHBwus.jpg'),
(66536, 4546, 'Angel: O Caça Vampiro S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/93ZXOyNmCtOgq6ZcM75YJbjeDtI.jpg'),
(66537, 4546, 'Angel: O Caça Vampiro S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVCrMG9NuL60afx8f9OKQ9iSogq.jpg'),
(66538, 4546, 'Angel: O Caça Vampiro S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hGT0yXo9NtzR7MsGhpRT7Bb0Mzc.jpg'),
(66539, 4546, 'Angel: O Caça Vampiro S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uJoZY8M9rTYcZRfTNEhIJFhPaC9.jpg'),
(66540, 4546, 'Angel: O Caça Vampiro S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qMp65SN8z6UDcgysKITDqNE9JQ3.jpg'),
(66541, 4546, 'Angel: O Caça Vampiro S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o4OzXKngUo8v2meIEjD0ha8yDUL.jpg'),
(66542, 4546, 'Angel: O Caça Vampiro S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5OO9EeE1LtgoKsSIrAveal0yCdx.jpg'),
(66543, 4546, 'Angel: O Caça Vampiro S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zm9YpCAsnKY2sf8i1cYlot7Ewqp.jpg'),
(66544, 4546, 'Angel: O Caça Vampiro S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qummsiqiCuFt3mzFRx8zgid6k5j.jpg'),
(66545, 4546, 'Angel: O Caça Vampiro S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AczH5WtdC2YRdCcGrQO5PLEmvcP.jpg'),
(66546, 4546, 'Angel: O Caça Vampiro S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7uTMve9FlZPTqCOpmQ4WixyO44F.jpg'),
(66547, 4546, 'Angel: O Caça Vampiro S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6HMEs0inQyZL38pSrsm1H1ZZZy.jpg'),
(66548, 4546, 'Angel: O Caça Vampiro S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8Uz8rgfV3mh0WpmQhMgTsPccG3.jpg'),
(66549, 4546, 'Angel: O Caça Vampiro S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cAxxLQacfLXldVYY2sRrou59Pyw.jpg'),
(66550, 4546, 'Angel: O Caça Vampiro S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEvOBGXdmD84xnfAbtOzxScHZbN.jpg'),
(66551, 4546, 'Angel: O Caça Vampiro S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/161004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uJYMwU238Vkhx9afdDSiip5Y6uO.jpg'),
(66552, 4546, 'Angel: O Caça Vampiro S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/161005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uLyhQPxuhrcuNBHtaJkg11nO79f.jpg'),
(66553, 4546, 'Angel: O Caça Vampiro S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/161006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b6kKvJve4zUayGabzWBOHcfhVhq.jpg'),
(66554, 4546, 'Angel: O Caça Vampiro S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/161007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rSvpuWypNpaeJt8hyVd95gIjUPD.jpg'),
(66555, 4547, 'Angel: O Caça Vampiro S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vgyvuSJApYA6LNg8VK9BgLgULj.jpg'),
(66556, 4547, 'Angel: O Caça Vampiro S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/64K3G1KPbjmC8fseJekhfx5JYA4.jpg'),
(66557, 4547, 'Angel: O Caça Vampiro S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nWGq5uIne6L1jqh3D1qq01LeEyz.jpg'),
(66558, 4547, 'Angel: O Caça Vampiro S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/haDk48omnUQWeuy2VUH5uoi8pIs.jpg'),
(66559, 4547, 'Angel: O Caça Vampiro S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBJNlXxFbO3d9ZpHFid3POpMyNO.jpg'),
(66560, 4547, 'Angel: O Caça Vampiro S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kZaDI13qktmCO1KCxo2vB4XkwTy.jpg'),
(66561, 4547, 'Angel: O Caça Vampiro S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i3eDIhoyxsDd7IINtOHctxT4kZ1.jpg'),
(66562, 4547, 'Angel: O Caça Vampiro S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iwdshTARGgQghY8WcFqnE15iKTp.jpg'),
(66563, 4547, 'Angel: O Caça Vampiro S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xzZZvSeUrES8UkDjmuQjRVXAaps.jpg'),
(66564, 4547, 'Angel: O Caça Vampiro S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6XeCUSxO3DwjPaCqWaCekWQrgo2.jpg'),
(66565, 4547, 'Angel: O Caça Vampiro S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqiC5XkCtkYXX7yntAOV48Ic8Qb.jpg'),
(66566, 4547, 'Angel: O Caça Vampiro S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i7qaWCVXWXK2KF6nwMbVHiI3diY.jpg'),
(66567, 4547, 'Angel: O Caça Vampiro S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ol1QphFBppcByLkG8QePKKidZF.jpg'),
(66568, 4547, 'Angel: O Caça Vampiro S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zH1IRrb5Exm8ofOt0EHTkPOudGI.jpg'),
(66569, 4547, 'Angel: O Caça Vampiro S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6rY0cHePE0Zsg808WeV9KcnoYns.jpg'),
(66570, 4547, 'Angel: O Caça Vampiro S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fVvoX2QQ8gzb73zy6cTaKzQucR3.jpg'),
(66571, 4547, 'Angel: O Caça Vampiro S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jqaqS9jUBF0tOPwqKeVz5R5ZLZI.jpg'),
(66572, 4547, 'Angel: O Caça Vampiro S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/161025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/chVQxMKsVCH1Lef1S5NcwBbNMmV.jpg'),
(66573, 4547, 'Angel: O Caça Vampiro S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/161026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jwpiNXTc4TsLJATPwFPp9jvxzkX.jpg'),
(66574, 4547, 'Angel: O Caça Vampiro S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/161027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uKK3QFKe07HBiyrDzIxfNwR2dKZ.jpg'),
(66575, 4547, 'Angel: O Caça Vampiro S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/161028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qLqOBw7eVdWWA1fXC6ecgaEzI29.jpg'),
(66576, 4547, 'Angel: O Caça Vampiro S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/161029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4j7Ly1iOdN5HaI5BOHTgzWvd0wR.jpg'),
(66577, 4548, 'Batalha Bilionária: O Caso Google Earth S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iOZ86zrlm2sqXEWCpHhLY3Asfjv.jpg'),
(66578, 4548, 'Batalha Bilionária: O Caso Google Earth S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nHvHntiGG5Rt4CB4X1IRWpKFjaT.jpg'),
(66579, 4548, 'Batalha Bilionária: O Caso Google Earth S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4waqG5GHHlbesA6814V3RkSoI5f.jpg'),
(66580, 4548, 'Batalha Bilionária: O Caso Google Earth S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/60qR5tT7c5DgtozTDkEG8TAnbM4.jpg'),
(66581, 4549, 'BMF (Black Mafia Family) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d5WCSXK8V1wRTTJ1kdVNbNIfQPo.jpg'),
(66582, 4549, 'BMF (Black Mafia Family) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A99DPeN7ccZHZoFOLMvJftCfLjq.jpg'),
(66583, 4549, 'BMF (Black Mafia Family) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209699.mp4', 'http://image.tmdb.org/t/p/w1280/mCKUVtVFNuXZnGDMjfAh1sdSxEb.jpg'),
(66584, 4549, 'BMF (Black Mafia Family) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QEkr5erMcWcpaVQfvK5i0gGGW5.jpg'),
(66585, 4549, 'BMF (Black Mafia Family) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qeQriBYi9iW6FLaqfdKbjYTyXVJ.jpg'),
(66586, 4549, 'BMF (Black Mafia Family) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209702.mp4', 'http://image.tmdb.org/t/p/w1280/qylklALUpnWBLWo9iaiQm7Uxpr1.jpg'),
(66587, 4549, 'BMF (Black Mafia Family) S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209703.mp4', 'http://image.tmdb.org/t/p/w1280/kbZmiq0B9807zB1QW1dDOSM0MNa.jpg'),
(66588, 4549, 'BMF (Black Mafia Family) S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209704.mp4', 'http://image.tmdb.org/t/p/w1280/5WRxleVHCKlzwKJIhN3tDUPysau.jpg'),
(66589, 4550, 'BMF (Black Mafia Family) S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209705.mp4', 'http://image.tmdb.org/t/p/w1280/3LHgb6bBWqE6jP2ElKfrXcp5HMa.jpg'),
(66590, 4550, 'BMF (Black Mafia Family) S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209706.mp4', 'http://image.tmdb.org/t/p/w1280/peLQGa8FMENIks9HCptWNDS87zL.jpg'),
(66591, 4550, 'BMF (Black Mafia Family) S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209707.mp4', 'http://image.tmdb.org/t/p/w1280/fn1Phv354Qzn58ElmlyMJrx83H0.jpg'),
(66592, 4550, 'BMF (Black Mafia Family) S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209708.mp4', 'http://image.tmdb.org/t/p/w1280/wQsoq49ABSZoXo1DqGVkHyWi8EN.jpg'),
(66593, 4550, 'BMF (Black Mafia Family) S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209709.mp4', 'http://image.tmdb.org/t/p/w1280/2n5dm3Js245SMvyTmgqpTUviK6f.jpg'),
(66594, 4550, 'BMF (Black Mafia Family) S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209710.mp4', 'http://image.tmdb.org/t/p/w1280/qkQOuMYOPKjzUnvnOQzXTPduPxL.jpg'),
(66595, 4550, 'BMF (Black Mafia Family) S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209711.mp4', 'http://image.tmdb.org/t/p/w1280/oIkMlhCK1fFqxKwc5fvKs14wuhw.jpg'),
(66596, 4550, 'BMF (Black Mafia Family) S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209712.mp4', 'http://image.tmdb.org/t/p/w1280/fMJX1MZAPpdKz20idXfrnIKT7UJ.jpg'),
(66597, 4550, 'BMF (Black Mafia Family) S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209713.mp4', 'http://image.tmdb.org/t/p/w1280/d1Y107NcJ5OYCOnvbiiLwfJWGKY.jpg'),
(66598, 4550, 'BMF (Black Mafia Family) S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209714.mp4', 'http://image.tmdb.org/t/p/w1280/wrGq5SIAeyTsWpb3AjaR6c0QgcQ.jpg'),
(66599, 4551, 'BMF (Black Mafia Family) S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/323416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hcbRz5D3yRnYjvXXfO1B61TYUqr.jpg'),
(66600, 4551, 'BMF (Black Mafia Family) S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/323417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hcbRz5D3yRnYjvXXfO1B61TYUqr.jpg'),
(66601, 4551, 'BMF (Black Mafia Family) S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/323418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hcbRz5D3yRnYjvXXfO1B61TYUqr.jpg'),
(66602, 4551, 'BMF (Black Mafia Family) S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/323419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hcbRz5D3yRnYjvXXfO1B61TYUqr.jpg'),
(66603, 4551, 'BMF (Black Mafia Family) S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/323420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hcbRz5D3yRnYjvXXfO1B61TYUqr.jpg'),
(66604, 4551, 'BMF (Black Mafia Family) S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/323421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hcbRz5D3yRnYjvXXfO1B61TYUqr.jpg'),
(66605, 4551, 'BMF (Black Mafia Family) S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/339014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hcbRz5D3yRnYjvXXfO1B61TYUqr.jpg'),
(66606, 4551, 'BMF (Black Mafia Family) S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/339015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hcbRz5D3yRnYjvXXfO1B61TYUqr.jpg'),
(66607, 4551, 'BMF (Black Mafia Family) S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/339016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hcbRz5D3yRnYjvXXfO1B61TYUqr.jpg'),
(66608, 4551, 'BMF (Black Mafia Family) S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/349614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hcbRz5D3yRnYjvXXfO1B61TYUqr.jpg'),
(66609, 4552, 'BMF (Black Mafia Family) S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/862186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/MEfe5xVI8DBX19owdsxqLI7XpH.jpg'),
(66610, 4552, 'BMF (Black Mafia Family) S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/862187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pJ11GISnHitRegYpHblL8HykAw6.jpg'),
(66611, 4552, 'BMF (Black Mafia Family) S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/847904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hcbRz5D3yRnYjvXXfO1B61TYUqr.jpg'),
(66612, 4552, 'BMF (Black Mafia Family) S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/859985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hcbRz5D3yRnYjvXXfO1B61TYUqr.jpg'),
(66613, 4552, 'BMF (Black Mafia Family) S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/862190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hcbRz5D3yRnYjvXXfO1B61TYUqr.jpg'),
(66614, 4552, 'BMF (Black Mafia Family) S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/868406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hcbRz5D3yRnYjvXXfO1B61TYUqr.jpg'),
(66615, 4552, 'BMF (Black Mafia Family) S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/878454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hcbRz5D3yRnYjvXXfO1B61TYUqr.jpg'),
(66616, 4552, 'BMF (Black Mafia Family) S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/879042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hcbRz5D3yRnYjvXXfO1B61TYUqr.jpg'),
(66617, 4552, 'BMF (Black Mafia Family) S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/880068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hcbRz5D3yRnYjvXXfO1B61TYUqr.jpg'),
(66618, 4552, 'BMF (Black Mafia Family) S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/880892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hcbRz5D3yRnYjvXXfO1B61TYUqr.jpg'),
(66619, 4553, 'Colônia Dignidade: Uma Seita Nazista no Chile S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oUlkYqUeizYpDegi63lfEWAVSKc.jpg'),
(66620, 4553, 'Colônia Dignidade: Uma Seita Nazista no Chile S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1i3eKVHXjZ0UsN8AwABoLvCP7tL.jpg'),
(66621, 4553, 'Colônia Dignidade: Uma Seita Nazista no Chile S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hRnJ2vYoHz4RyQx9pzi1FlBUj5K.jpg'),
(66622, 4553, 'Colônia Dignidade: Uma Seita Nazista no Chile S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AroPl33bKVSQSI9FN9o4tJKQY4E.jpg'),
(66623, 4553, 'Colônia Dignidade: Uma Seita Nazista no Chile S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h6hFzpxCkEqX6wAa8VRYGOnZZyd.jpg'),
(66624, 4553, 'Colônia Dignidade: Uma Seita Nazista no Chile S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ercG0E8oSGrcYeXsZDN1Y3fCg6H.jpg'),
(66625, 4554, 'Criadas e Malvadas [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3C5XwvIsolByqxuGGTvcxW67fzJ.jpg'),
(66626, 4554, 'Criadas e Malvadas [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7OzIQtFpRCWm2BJKXew8GCqd9Aa.jpg'),
(66627, 4554, 'Criadas e Malvadas [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zQrtkosHp3ZROgnenDh6roGkN9O.jpg'),
(66628, 4554, 'Criadas e Malvadas [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oe7CJoiCnb4nvcCCB5nN0rvA98B.jpg'),
(66629, 4554, 'Criadas e Malvadas [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7FOo5WPVQAHKt1oKnLOzSrFBrLQ.jpg'),
(66630, 4554, 'Criadas e Malvadas [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kCniqnxvhODvBabw62fIWr93VgI.jpg'),
(66631, 4554, 'Criadas e Malvadas [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z8fBmU6ncByoJKMgXI7X2s2fl0m.jpg'),
(66632, 4554, 'Criadas e Malvadas [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/myTuSsqos43Mm1elrawfrsvkSZt.jpg'),
(66633, 4554, 'Criadas e Malvadas [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h0RFP7nw6EkNw24vGMMK7vZwusw.jpg'),
(66634, 4554, 'Criadas e Malvadas [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i61gLgoXPtG61uTR7fcdmsyDf2K.jpg'),
(66635, 4554, 'Criadas e Malvadas [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2YtbaCbtZOI6roIIez8U9dOits0.jpg'),
(66636, 4554, 'Criadas e Malvadas [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oo8WNDEwsObqOiM5wgycfazayFf.jpg'),
(66637, 4554, 'Criadas e Malvadas [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7vC7SGK0uM25YrmKrk6Xponp015.jpg'),
(66638, 4555, 'Desjuntados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5zbRz8bnGm17lG17PVk3OGlW620.jpg'),
(66639, 4555, 'Desjuntados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5zbRz8bnGm17lG17PVk3OGlW620.jpg'),
(66640, 4555, 'Desjuntados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5zbRz8bnGm17lG17PVk3OGlW620.jpg'),
(66641, 4555, 'Desjuntados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5zbRz8bnGm17lG17PVk3OGlW620.jpg'),
(66642, 4555, 'Desjuntados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5zbRz8bnGm17lG17PVk3OGlW620.jpg'),
(66643, 4555, 'Desjuntados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5zbRz8bnGm17lG17PVk3OGlW620.jpg'),
(66644, 4555, 'Desjuntados S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5zbRz8bnGm17lG17PVk3OGlW620.jpg'),
(66645, 4556, 'Gokushufudou: Tatsu Imortal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s4L70h9tiI8KF9GQY07l3CNMZNs.jpg'),
(66646, 4556, 'Gokushufudou: Tatsu Imortal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/butytcTfNdIfPXfFGJ6aChCmqOQ.jpg'),
(66647, 4556, 'Gokushufudou: Tatsu Imortal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q72AEfzM6b0sicuCMtRQ0q0QnbL.jpg'),
(66648, 4556, 'Gokushufudou: Tatsu Imortal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3XulsefOHK7afGQxXjBJaHSeWKC.jpg'),
(66649, 4556, 'Gokushufudou: Tatsu Imortal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kM4B290U7OZLhcIMS97bdVpJfXR.jpg'),
(66650, 4556, 'Gokushufudou: Tatsu Imortal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyErsX3TNEymn9dY4Y5gHw48Bp9.jpg'),
(66651, 4556, 'Gokushufudou: Tatsu Imortal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k8CZjeU6W6JjUJxEbKuIYujU7Qn.jpg'),
(66652, 4556, 'Gokushufudou: Tatsu Imortal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Xf1OJpLmetEtri4vcD283tMqNM.jpg'),
(66653, 4556, 'Gokushufudou: Tatsu Imortal S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8QC4KkoOIsg8zmHzmsHKmVZEcNY.jpg'),
(66654, 4556, 'Gokushufudou: Tatsu Imortal S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/erk5bqp8sdi6RwOvtaT6KOXCDoG.jpg'),
(66655, 4557, 'Jogo Comprado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lst1t3sln5F7p2MsYwFevVNDOJV.jpg'),
(66656, 4557, 'Jogo Comprado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lst1t3sln5F7p2MsYwFevVNDOJV.jpg'),
(66657, 4557, 'Jogo Comprado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lst1t3sln5F7p2MsYwFevVNDOJV.jpg'),
(66658, 4557, 'Jogo Comprado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lst1t3sln5F7p2MsYwFevVNDOJV.jpg'),
(66659, 4557, 'Jogo Comprado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lst1t3sln5F7p2MsYwFevVNDOJV.jpg'),
(66660, 4557, 'Jogo Comprado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lst1t3sln5F7p2MsYwFevVNDOJV.jpg'),
(66661, 4558, 'Madagascar Pequenos Selvagens S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194573.mp4', 'http://timg.bdta.pro/images/cc77ba7693f09ff1b28c81baa9db3b90.jpg'),
(66662, 4558, 'Madagascar Pequenos Selvagens S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194574.mp4', 'http://timg.bdta.pro/images/05fd364577b20b9fa0cd58d09e473d36.jpg'),
(66663, 4558, 'Madagascar Pequenos Selvagens S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194575.mp4', 'http://timg.bdta.pro/images/fa84dd8d1d2fa185a0883f3ebb99f0e8.jpg'),
(66664, 4558, 'Madagascar Pequenos Selvagens S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194576.mp4', 'http://timg.bdta.pro/images/ac4e26c943654433bc8bbcb2ae07fbaa.jpg'),
(66665, 4558, 'Madagascar Pequenos Selvagens S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194577.mp4', 'http://timg.bdta.pro/images/771b99574ba4eb5efb92664754ab923a.jpg'),
(66666, 4558, 'Madagascar Pequenos Selvagens S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194578.mp4', 'http://timg.bdta.pro/images/aa67f5984f70535d5cb5e286685cd973.jpg'),
(66667, 4558, 'Madagascar Pequenos Selvagens S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194579.mp4', 'http://timg.bdta.pro/images/a038c028b9598bd012b25dbb3c94fcb8.jpg'),
(66668, 4558, 'Madagascar Pequenos Selvagens S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knr7OTB5y7p2soiMsDAxj9m4BYe.jpg'),
(66669, 4558, 'Madagascar Pequenos Selvagens S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knr7OTB5y7p2soiMsDAxj9m4BYe.jpg'),
(66670, 4558, 'Madagascar Pequenos Selvagens S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knr7OTB5y7p2soiMsDAxj9m4BYe.jpg'),
(66671, 4558, 'Madagascar Pequenos Selvagens S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knr7OTB5y7p2soiMsDAxj9m4BYe.jpg'),
(66672, 4558, 'Madagascar Pequenos Selvagens S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knr7OTB5y7p2soiMsDAxj9m4BYe.jpg'),
(66673, 4558, 'Madagascar Pequenos Selvagens S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/194585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knr7OTB5y7p2soiMsDAxj9m4BYe.jpg'),
(66674, 4558, 'Madagascar Pequenos Selvagens S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/194586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knr7OTB5y7p2soiMsDAxj9m4BYe.jpg'),
(66675, 4558, 'Madagascar Pequenos Selvagens S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/194587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knr7OTB5y7p2soiMsDAxj9m4BYe.jpg'),
(66676, 4558, 'Madagascar Pequenos Selvagens S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/194588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knr7OTB5y7p2soiMsDAxj9m4BYe.jpg'),
(66677, 4558, 'Madagascar Pequenos Selvagens S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/194589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knr7OTB5y7p2soiMsDAxj9m4BYe.jpg'),
(66678, 4558, 'Madagascar Pequenos Selvagens S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/194590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knr7OTB5y7p2soiMsDAxj9m4BYe.jpg'),
(66679, 4558, 'Madagascar Pequenos Selvagens S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/194591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knr7OTB5y7p2soiMsDAxj9m4BYe.jpg'),
(66680, 4558, 'Madagascar Pequenos Selvagens S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/194592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knr7OTB5y7p2soiMsDAxj9m4BYe.jpg'),
(66681, 4558, 'Madagascar Pequenos Selvagens S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/194593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knr7OTB5y7p2soiMsDAxj9m4BYe.jpg'),
(66682, 4558, 'Madagascar Pequenos Selvagens S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/194594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knr7OTB5y7p2soiMsDAxj9m4BYe.jpg'),
(66683, 4558, 'Madagascar Pequenos Selvagens S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/194595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knr7OTB5y7p2soiMsDAxj9m4BYe.jpg'),
(66684, 4558, 'Madagascar Pequenos Selvagens S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/194596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knr7OTB5y7p2soiMsDAxj9m4BYe.jpg'),
(66685, 4558, 'Madagascar Pequenos Selvagens S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/194597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knr7OTB5y7p2soiMsDAxj9m4BYe.jpg'),
(66686, 4558, 'Madagascar Pequenos Selvagens S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/194598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knr7OTB5y7p2soiMsDAxj9m4BYe.jpg'),
(66687, 4559, 'Madagascar Pequenos Selvagens S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knr7OTB5y7p2soiMsDAxj9m4BYe.jpg'),
(66688, 4559, 'Madagascar Pequenos Selvagens S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194600.mp4', 'http://timg.bdta.pro/images/cf37ccfbc0290b80a112ac4327ca9197.jpg'),
(66689, 4559, 'Madagascar Pequenos Selvagens S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194601.mp4', 'http://timg.bdta.pro/images/d8e3e896ae911d505d148ccdf913f9db.jpg'),
(66690, 4559, 'Madagascar Pequenos Selvagens S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194602.mp4', 'http://timg.bdta.pro/images/d050753cd855acfb896a6360291f1e14.jpg'),
(66691, 4559, 'Madagascar Pequenos Selvagens S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194603.mp4', 'http://timg.bdta.pro/images/bc2fe5bad712ef2ebaaaad7fc580974f.jpg'),
(66692, 4559, 'Madagascar Pequenos Selvagens S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194604.mp4', 'http://timg.bdta.pro/images/d5f06d720ab47bf51bff31d8a8b77ee0.jpg'),
(66693, 4559, 'Madagascar Pequenos Selvagens S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194605.mp4', 'http://timg.bdta.pro/images/53d8ddbf2d1c1ef94669eed317f093bc.jpg'),
(66694, 4560, 'Madagascar Pequenos Selvagens S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194606.mp4', 'http://timg.bdta.pro/images/7a7ea49a65f1290facd03bc634ddc94a.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(66695, 4560, 'Madagascar Pequenos Selvagens S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194607.mp4', 'http://timg.bdta.pro/images/2b643b8ede9a7dcb524c6ef6daf00714.jpg'),
(66696, 4560, 'Madagascar Pequenos Selvagens S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194608.mp4', 'http://timg.bdta.pro/images/6e90b55891164b346a8ee1e6ec324101.jpg'),
(66697, 4560, 'Madagascar Pequenos Selvagens S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194609.mp4', 'http://timg.bdta.pro/images/edd1954c033eb7aa7f4c09a4c73cde0a.jpg'),
(66698, 4560, 'Madagascar Pequenos Selvagens S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194610.mp4', 'http://timg.bdta.pro/images/26fe497c0892d278f8f689d3c2528639.jpg'),
(66699, 4560, 'Madagascar Pequenos Selvagens S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194611.mp4', 'http://timg.bdta.pro/images/8652a2fef958704f2f3ccebc8301bc45.jpg'),
(66700, 4560, 'Madagascar Pequenos Selvagens S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194612.mp4', 'http://timg.bdta.pro/images/5804faec54899dec9a620f565666392c.jpg'),
(66701, 4561, 'Madagascar Pequenos Selvagens S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194613.mp4', 'http://timg.bdta.pro/images/06722ee944323d8a37982355b22feb96.jpg'),
(66702, 4561, 'Madagascar Pequenos Selvagens S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194614.mp4', 'http://timg.bdta.pro/images/3ce695aa1173efc78304234529649253.jpg'),
(66703, 4561, 'Madagascar Pequenos Selvagens S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194615.mp4', 'http://timg.bdta.pro/images/3d27718974f20493439e53d4cab36dc3.jpg'),
(66704, 4561, 'Madagascar Pequenos Selvagens S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194616.mp4', 'http://timg.bdta.pro/images/4c655b629a98419e9248f4e0a20b5a27.jpg'),
(66705, 4561, 'Madagascar Pequenos Selvagens S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194617.mp4', 'http://timg.bdta.pro/images/4c29ee20308dc9f1cf95b8d9da63a75b.jpg'),
(66706, 4561, 'Madagascar Pequenos Selvagens S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194618.mp4', 'http://timg.bdta.pro/images/d5bd23ff3ba26dc4fdaf15724905bc77.jpg'),
(66707, 4562, 'Madagascar Pequenos Selvagens S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knr7OTB5y7p2soiMsDAxj9m4BYe.jpg'),
(66708, 4562, 'Madagascar Pequenos Selvagens S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194620.mp4', 'http://timg.bdta.pro/images/58958ab11063bf8df9987542e5cba3d5.jpg'),
(66709, 4562, 'Madagascar Pequenos Selvagens S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194621.mp4', 'http://timg.bdta.pro/images/a88f5b7f45327b338563a93746ace6b6.jpg'),
(66710, 4562, 'Madagascar Pequenos Selvagens S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194622.mp4', 'http://timg.bdta.pro/images/4e2ae0c9fa6941e54ba7443ba59cf621.jpg'),
(66711, 4562, 'Madagascar Pequenos Selvagens S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194623.mp4', 'http://timg.bdta.pro/images/0b70b02962655b3c3f6b5c968b5b2b0c.jpg'),
(66712, 4562, 'Madagascar Pequenos Selvagens S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194624.mp4', 'http://timg.bdta.pro/images/ff81da05e964e24aca59e08ac06261b6.jpg'),
(66713, 4562, 'Madagascar Pequenos Selvagens S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194625.mp4', 'http://timg.bdta.pro/images/be9886498159b8018cd144df9fbd8b6e.jpg'),
(66714, 4563, 'Madagascar Pequenos Selvagens S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194626.mp4', 'http://timg.bdta.pro/images/2b47556f1cff25f02b3c8a00e73c36ca.jpg'),
(66715, 4563, 'Madagascar Pequenos Selvagens S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194627.mp4', 'http://timg.bdta.pro/images/d4891accd3bab7a6ec675a6359b439ef.jpg'),
(66716, 4563, 'Madagascar Pequenos Selvagens S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194628.mp4', 'http://timg.bdta.pro/images/134ecfa4d49671f5253b6ae66430f013.jpg'),
(66717, 4563, 'Madagascar Pequenos Selvagens S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194629.mp4', 'http://timg.bdta.pro/images/b180cd98eafe929e5db8498f3b7b6211.jpg'),
(66718, 4563, 'Madagascar Pequenos Selvagens S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194630.mp4', 'http://timg.bdta.pro/images/47e4614808cccb6362cc0aa71ee955d4.jpg'),
(66719, 4563, 'Madagascar Pequenos Selvagens S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194631.mp4', 'http://timg.bdta.pro/images/7151e44f832146a8ffbed833bf59e024.jpg'),
(66720, 4564, 'Madagascar Pequenos Selvagens S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194632.mp4', 'http://timg.bdta.pro/images/3bec3590a738ae44b8311f160108149b.jpg'),
(66721, 4564, 'Madagascar Pequenos Selvagens S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194633.mp4', 'http://timg.bdta.pro/images/273829979d62e2624110881b366f41b0.jpg'),
(66722, 4564, 'Madagascar Pequenos Selvagens S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194634.mp4', 'http://timg.bdta.pro/images/92a67655a600cd77ebc896d10045ebfb.jpg'),
(66723, 4564, 'Madagascar Pequenos Selvagens S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194635.mp4', 'http://timg.bdta.pro/images/160a2398c3fbbfd635552d2243912b8a.jpg'),
(66724, 4564, 'Madagascar Pequenos Selvagens S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194636.mp4', 'http://timg.bdta.pro/images/8da132eadad90d8db642a870c0dc5c50.jpg'),
(66725, 4564, 'Madagascar Pequenos Selvagens S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194637.mp4', 'http://timg.bdta.pro/images/868eb5993c904346a875cd4550ceaceb.jpg'),
(66726, 4565, 'Magias & Miados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/25ZpXJlzSMZJfFzkacyGEp3f2ff.jpg'),
(66727, 4565, 'Magias & Miados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bGSa8RCGXNIrb6pS3jzYS188FXM.jpg'),
(66728, 4565, 'Magias & Miados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mfO2XmPmQIw5yAQzsgmh83lhoaK.jpg'),
(66729, 4565, 'Magias & Miados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AsQnyykqE1D8EpK9BybHJ2NEk6p.jpg'),
(66730, 4565, 'Magias & Miados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7AUhFprMh4jlVfcrv1N38BS2xq2.jpg'),
(66731, 4565, 'Magias & Miados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZEO80kTkxQDzggiX8r5JjfIQSV.jpg'),
(66732, 4565, 'Magias & Miados S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aTkNphVtIY2hPbeYwaYcFyafqsU.jpg'),
(66733, 4565, 'Magias & Miados S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ovZpeJccTckpSRwmPE64GNNCpjt.jpg'),
(66734, 4565, 'Magias & Miados S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hdJ54mppnU7AFVjJHIPJvwO8cEB.jpg'),
(66735, 4566, 'Minta Comigo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bTfWQMECcj3OvyBVYOvBOclM0hP.jpg'),
(66736, 4566, 'Minta Comigo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1rjli34zvl2w4QaRT6cW93jixZU.jpg'),
(66737, 4566, 'Minta Comigo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Wq7fb6vv0nIsQTD2pN5pXF5iXq.jpg'),
(66738, 4566, 'Minta Comigo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3vR0HncJOSsYgsvCk8OZF5tmlK.jpg'),
(66739, 4567, 'Mirage S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/seUzcTN4Co2PT9Az2gTMium6HMY.jpg'),
(66740, 4567, 'Mirage S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vLX7T2fIF5dnGLm681t8wsNojUN.jpg'),
(66741, 4567, 'Mirage S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fZZqVdg2r2SLmDxSlKGkToiOEel.jpg'),
(66742, 4567, 'Mirage S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQ2smB1s0pooaHLbyYRKJPULNnH.jpg'),
(66743, 4567, 'Mirage S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sgU5VYNOzngZE5qtEa62Hwt08yG.jpg'),
(66744, 4567, 'Mirage S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4mc7xZsXut5BWSSbyYu5hX6nAE7.jpg'),
(66745, 4568, 'O Rei do Pedaço S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zj1o9VbOydmYOygo4QQzq34hNoI.jpg'),
(66746, 4568, 'O Rei do Pedaço S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l2BDckE0yOseRsfWo6pVeC4STk5.jpg'),
(66747, 4568, 'O Rei do Pedaço S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Uv2HK2mxJOP5QqTaBxioJNgdcd.jpg'),
(66748, 4568, 'O Rei do Pedaço S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f54I5fEF9xOLzGrx68IjaBKreuC.jpg'),
(66749, 4568, 'O Rei do Pedaço S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/htwVSYbYAqs7B1OWGre3joeF5Wd.jpg'),
(66750, 4568, 'O Rei do Pedaço S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aETZJxeTlrGUcYF2GNR8UcnI8gj.jpg'),
(66751, 4568, 'O Rei do Pedaço S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/joKjDPHqrY0paTOqszRVNeoxlf1.jpg'),
(66752, 4568, 'O Rei do Pedaço S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g3vyX9lFMO5gn8eOjJEUG5hXeCM.jpg'),
(66753, 4568, 'O Rei do Pedaço S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zUGT2aUXtBM94eSU47u4YlPZukV.jpg'),
(66754, 4568, 'O Rei do Pedaço S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8BZKycYEcyvMQqe3spujEYFDPnA.jpg'),
(66755, 4568, 'O Rei do Pedaço S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tfXLypQxNcheLkfw2zEE47hRsIO.jpg'),
(66756, 4568, 'O Rei do Pedaço S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7wej5IHsR41FuQqXs1WD6ChtS57.jpg'),
(66757, 4569, 'O Rei do Pedaço S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oSl52rCTfbMHlH3SjGC6Cgo7VKs.jpg'),
(66758, 4569, 'O Rei do Pedaço S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eFYQKxCnUTnjAyGvbRtgJCsmtKT.jpg'),
(66759, 4569, 'O Rei do Pedaço S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oRMt6WphDvlWSBlux09BS7cGQb2.jpg'),
(66760, 4569, 'O Rei do Pedaço S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjV13PcsBmqXT2Shmqso5TPbuHN.jpg'),
(66761, 4569, 'O Rei do Pedaço S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kerkpWmE2Ywl5KS1qJUjnMaAp6P.jpg'),
(66762, 4569, 'O Rei do Pedaço S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yBq1bObsAIMEQqHqilGk13o1tBr.jpg'),
(66763, 4569, 'O Rei do Pedaço S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6aG7VbhL3KRN2BmYlVTDp47eiB.jpg'),
(66764, 4569, 'O Rei do Pedaço S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mAtpqulm8a5xpSukh6p8NSQV1p9.jpg'),
(66765, 4569, 'O Rei do Pedaço S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wg9sI5qsBdnVO77BJlyo5mKBzd1.jpg'),
(66766, 4569, 'O Rei do Pedaço S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bz9s3pDunRBVaSzGIUHR5l2bw9u.jpg'),
(66767, 4569, 'O Rei do Pedaço S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dMuWhzUEe8vZ7HVb6bYirUlMoMW.jpg'),
(66768, 4569, 'O Rei do Pedaço S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bhkvQORSO3UjKKmCyqulK9uH6Dp.jpg'),
(66769, 4569, 'O Rei do Pedaço S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ulqypdwoM4iFoJn3RBfycgmLxlh.jpg'),
(66770, 4569, 'O Rei do Pedaço S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/viDIfdl1oTjbP4DZcz7i4hu1sgH.jpg'),
(66771, 4569, 'O Rei do Pedaço S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5sZHMrWeCPBsenYd1VHKASFbZqK.jpg'),
(66772, 4569, 'O Rei do Pedaço S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzQGcUoXUJvO0dAxPXE2xC2aRIQ.jpg'),
(66773, 4569, 'O Rei do Pedaço S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dYQR9wOfrhZChKFaFgUrWtpHiXw.jpg'),
(66774, 4569, 'O Rei do Pedaço S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5HxlZPTdGBCuV3YzIQHHL6rE9kM.jpg'),
(66775, 4569, 'O Rei do Pedaço S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7wgcnQvPqftG1Q67KNSb5KqT5TG.jpg'),
(66776, 4569, 'O Rei do Pedaço S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zUBXXmh0lL2fxQyUFsJuhgSAumx.jpg'),
(66777, 4569, 'O Rei do Pedaço S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uzmpVAW5GqBNVdyUiuRJgafxScV.jpg'),
(66778, 4569, 'O Rei do Pedaço S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pAwZZfeVmcBbVNHLjSKjETnu59c.jpg'),
(66779, 4569, 'O Rei do Pedaço S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/160801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ipHbFxisAVILyCyrmB7w03E0h3B.jpg'),
(66780, 4570, 'O Rei do Pedaço S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Fkj3rl39bCi9LmiKpqUETnBQ7N.jpg'),
(66781, 4570, 'O Rei do Pedaço S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iXuwsx2jV2cX5VZk69xm2chE0zw.jpg'),
(66782, 4570, 'O Rei do Pedaço S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9agfsDRBbeyHBeePldJc7HYWwPe.jpg'),
(66783, 4570, 'O Rei do Pedaço S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fA2klgRzeZkni34jRbvs7JjPgb7.jpg'),
(66784, 4570, 'O Rei do Pedaço S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wfIMgUdTl5pdzVjta0tw9QNK4PX.jpg'),
(66785, 4570, 'O Rei do Pedaço S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/joNj2xGMpettAIsH3mWOcwvpsTH.jpg'),
(66786, 4570, 'O Rei do Pedaço S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lEhY3hiVE7TMLEqiatO5afUtVAf.jpg'),
(66787, 4570, 'O Rei do Pedaço S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qVu3B7ymTUCgDozilNt5aP83AJw.jpg'),
(66788, 4570, 'O Rei do Pedaço S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vRnZUsvBNJLWRrwccYsgRcBsp67.jpg'),
(66789, 4570, 'O Rei do Pedaço S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3gvVPGRwjyuhNpemR5oQi1VJE83.jpg'),
(66790, 4570, 'O Rei do Pedaço S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gcntkmkAS90z5OswUGdmGqhBUY3.jpg'),
(66791, 4570, 'O Rei do Pedaço S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n0Hu9Cx9j8Rwn2z3zV21LgVtZS.jpg'),
(66792, 4570, 'O Rei do Pedaço S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1eqTDgNbXqUBLHyN1lyz8qgqWVx.jpg'),
(66793, 4570, 'O Rei do Pedaço S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9dWs5kGWJSygy4GKrhYwqHSjV5d.jpg'),
(66794, 4570, 'O Rei do Pedaço S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8SjkaS6b5vUcJDeGGIZS2Amsh3.jpg'),
(66795, 4570, 'O Rei do Pedaço S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDOzKlLhBbbCPPWjOeGnYKtcvf4.jpg'),
(66796, 4570, 'O Rei do Pedaço S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eE3eG7p0x4jE22bzdHDCMBcLsEZ.jpg'),
(66797, 4570, 'O Rei do Pedaço S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b4k7xd13qNoUxtyoycLp5md2Mmb.jpg'),
(66798, 4570, 'O Rei do Pedaço S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9D5sEhZ2DhBUOmbGf76Pwz9pMUl.jpg'),
(66799, 4570, 'O Rei do Pedaço S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sUk0gjlCBTjKyPsyJAf7hPitj1t.jpg'),
(66800, 4570, 'O Rei do Pedaço S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/arfrla7ickgDbpbNuxxyv9EcNz8.jpg'),
(66801, 4570, 'O Rei do Pedaço S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A1r0nlB4i1brGWySuBTHHkmX7fE.jpg'),
(66802, 4570, 'O Rei do Pedaço S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/160824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9dctill0TGzyjDjty7AaqDMHf0P.jpg'),
(66803, 4570, 'O Rei do Pedaço S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/160825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6C9re6g04CnP7DNBiLzn8aa1eKr.jpg'),
(66804, 4570, 'O Rei do Pedaço S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/160826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g3ZZeeNKBxwhrgZTiPhtyNn0UKN.jpg'),
(66805, 4570, 'O Rei do Pedaço S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/160827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wV39o8bAOYMl1iOZAZlBfGXq0b4.jpg'),
(66806, 4570, 'O Rei do Pedaço S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/160828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wV39o8bAOYMl1iOZAZlBfGXq0b4.jpg'),
(66807, 4570, 'O Rei do Pedaço S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/160829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wV39o8bAOYMl1iOZAZlBfGXq0b4.jpg'),
(66808, 4570, 'O Rei do Pedaço S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/160830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wV39o8bAOYMl1iOZAZlBfGXq0b4.jpg'),
(66809, 4571, 'O Rei do Pedaço S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bjNxNzjIUBQuQLFqOiCZ2J6P7HC.jpg'),
(66810, 4571, 'O Rei do Pedaço S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1a4KJ77kme7rbcwQyi2cpOuUHJT.jpg'),
(66811, 4571, 'O Rei do Pedaço S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1HNs63l8S4xTsBNEiwKP0oLLjB.jpg'),
(66812, 4571, 'O Rei do Pedaço S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cX7lITVj5ZUCWSxrpecvKhQiZh.jpg'),
(66813, 4571, 'O Rei do Pedaço S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nE5ojCUsbeCJ0PtTMnpUxiCtgS6.jpg'),
(66814, 4571, 'O Rei do Pedaço S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A5dfYyVODaLlI9w1bcPjriuheWX.jpg'),
(66815, 4571, 'O Rei do Pedaço S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nvoGOFOkzB6b9gLwjvJPs66VkhP.jpg'),
(66816, 4571, 'O Rei do Pedaço S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dw6jhJ7B0fVCFAvDMJ3v8cUg7lN.jpg'),
(66817, 4571, 'O Rei do Pedaço S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9bRPGYcGXrxgageV1RV3GUL9wqX.jpg'),
(66818, 4571, 'O Rei do Pedaço S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/200NOwiTSkqNcukDXGWo1wTwtZg.jpg'),
(66819, 4571, 'O Rei do Pedaço S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/stziL2UBcnffevkumb85XMslNLU.jpg'),
(66820, 4571, 'O Rei do Pedaço S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yziOHLc5qohaIRvr0m6tmV2Zquy.jpg'),
(66821, 4571, 'O Rei do Pedaço S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qRK6iRtgbWdqRwyF4aeOulZf6Bb.jpg'),
(66822, 4571, 'O Rei do Pedaço S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qF8dCbltC6DofJ7GiJGSo8wcajY.jpg'),
(66823, 4571, 'O Rei do Pedaço S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y59BUy1behkiBAiu1fp23e8AVtq.jpg'),
(66824, 4571, 'O Rei do Pedaço S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/clTMwxxn64bRuEB0A1E3kUwzPZi.jpg'),
(66825, 4571, 'O Rei do Pedaço S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4EyPXdfkVURO5v3ElYovyVgymvd.jpg'),
(66826, 4571, 'O Rei do Pedaço S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gANMYB4ZZmfF5hLGIgwSpbC8XIB.jpg'),
(66827, 4571, 'O Rei do Pedaço S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j4donzc1htUryaAHylXuRZY0TUS.jpg'),
(66828, 4571, 'O Rei do Pedaço S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2bKId2Pj7bTwkfXdgCvotC9TkyQ.jpg'),
(66829, 4571, 'O Rei do Pedaço S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aVKIVovA34O4tX2f5IngCxo7ZHQ.jpg'),
(66830, 4571, 'O Rei do Pedaço S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uHINUnXSt8YFtnl9vz2YWtQOJNA.jpg'),
(66831, 4571, 'O Rei do Pedaço S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/160853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k1P7cyDhI8m1xrMATNYLTRJ4gel.jpg'),
(66832, 4571, 'O Rei do Pedaço S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/160854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hBHE3RORr2mYiX5LC0f7rDrfFje.jpg'),
(66833, 4572, 'On My Block S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vLLeiW5jJmBY97wM2VLomTpHlqv.jpg'),
(66834, 4572, 'On My Block S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wygU6ih4r5RkIyPfaWsHYuoV3dd.jpg'),
(66835, 4572, 'On My Block S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2u3fkcOh7JwKdvhZwJ1FB24hzYT.jpg'),
(66836, 4572, 'On My Block S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/igeC5AkQ2Mq34zU1AQcRY1kUxMP.jpg'),
(66837, 4572, 'On My Block S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gUv1PpFcBYrBaDZOuXWhVMLUjyd.jpg'),
(66838, 4572, 'On My Block S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mLiSUtISsxLvzzqLmXcSZKUJTs8.jpg'),
(66839, 4572, 'On My Block S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5RVGwRaLkDo1lc52wPQ93HELdFs.jpg'),
(66840, 4572, 'On My Block S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3aXgp0BTk04iasktpLVTiGTOZmq.jpg'),
(66841, 4572, 'On My Block S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3dBn4yoANuhe3CkFwKL5YPKXsRu.jpg'),
(66842, 4572, 'On My Block S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tcPtJoXLH3UfhqBEJFdPYoHlobz.jpg'),
(66843, 4573, 'On My Block S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kPueiv2wgz0ldXQ0dUHWYfT8IAO.jpg'),
(66844, 4573, 'On My Block S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e79MXPnObWqjVDggGxhMs21H67t.jpg'),
(66845, 4573, 'On My Block S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3nX77BGXjYN91gGa4RyqY3mNXI1.jpg'),
(66846, 4573, 'On My Block S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i3PozG95A1yt5b8fXHnQ2BxfEVr.jpg'),
(66847, 4573, 'On My Block S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bper6WivYUN2VwbCJKE2tq2Ad5I.jpg'),
(66848, 4573, 'On My Block S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iqmzJ8DjmwYU0vQGbi7xCyWXfti.jpg'),
(66849, 4573, 'On My Block S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jq7IyqAvfHEwG1Uhg5s4JX7Hn6m.jpg'),
(66850, 4573, 'On My Block S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5BfXQOhgPVyaJVNTjGPI2EKActV.jpg'),
(66851, 4573, 'On My Block S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e6hYsgU3xBm3oafIgEv9yfIMckh.jpg'),
(66852, 4573, 'On My Block S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fYDE6T6LJadIKjiXUcBTHAIw2Iw.jpg'),
(66853, 4574, 'On My Block S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bvmErdcOwQ56uc2oxig3PhfSCof.jpg'),
(66854, 4574, 'On My Block S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i1YMhVWuD0jktlPUuTRKXkcMHyK.jpg'),
(66855, 4574, 'On My Block S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a4oI5Imn2hUwi1pYQGunAGAmLfd.jpg'),
(66856, 4574, 'On My Block S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kmuaVPthQeAXb10cNZq40SRzMZb.jpg'),
(66857, 4574, 'On My Block S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mUx1XdIhYKjYBOrMV9F4Z2p6cnt.jpg'),
(66858, 4574, 'On My Block S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d2vYLmd8nG45UFRQXFosGnMSfAP.jpg'),
(66859, 4574, 'On My Block S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ZS0WtqqbFvbTEWhm8emFNkKzJx.jpg'),
(66860, 4574, 'On My Block S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5R37du8GPB2aJJw4VZll9DgImTw.jpg'),
(66861, 4575, 'On My Block S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uBHNuYlQT1Xjb9av9lfPxXKVKDw.jpg'),
(66862, 4575, 'On My Block S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l9zQxERrdCg24JnSsqGkLDwQB8R.jpg'),
(66863, 4575, 'On My Block S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZBPrWlYtzsLtkiZPI9fiKv4NrK.jpg'),
(66864, 4575, 'On My Block S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3NpM9VBjGwlJfsRDrcY9I6hOpwx.jpg'),
(66865, 4575, 'On My Block S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dSDVPGEVXpgJ7kRmDCth5E8sSn4.jpg'),
(66866, 4575, 'On My Block S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nKz5RsDmQIaVdKpOGoacHxwgFz3.jpg'),
(66867, 4575, 'On My Block S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2daZ4Vb5bNzFfnLQlkaZsjwO5Wf.jpg'),
(66868, 4575, 'On My Block S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4jiNhLF9cvMDLgivfJIupggjWW9.jpg'),
(66869, 4575, 'On My Block S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1UjaltyQht0QJcIa1lEB5YKaP9.jpg'),
(66870, 4575, 'On My Block S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uaeOrdUQXb9rb2rxcLILuFl420p.jpg'),
(66871, 4576, 'Private Practice S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJWmV6Py5vOMiRPmYAnTL0cDjHV.jpg'),
(66872, 4576, 'Private Practice S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/460fkuLz7xoahZl5ez1AeEP0qbd.jpg'),
(66873, 4576, 'Private Practice S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eL9zbqtyMEuYkSruUhT32Ps0Cpx.jpg'),
(66874, 4576, 'Private Practice S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a4Q2oJjg4UKdWaL9CaoPj9bn4sh.jpg'),
(66875, 4576, 'Private Practice S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gf9Pvcw3IQxKXlNrkrVkW2a9Hov.jpg'),
(66876, 4576, 'Private Practice S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fChoi4mFPqInc2drH8lVb9Lx0OR.jpg'),
(66877, 4576, 'Private Practice S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6cjr5eZX4Rxd0p1UsDURACcXt2W.jpg'),
(66878, 4576, 'Private Practice S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1FdyExkbSXjgsqheUpa33pWDTQm.jpg'),
(66879, 4576, 'Private Practice S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ipsJWMuSmivXZYc4UKWzN2yHA9L.jpg'),
(66880, 4577, 'Private Practice S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uEKZb80kkCS7dD0GeCL5LmidgLD.jpg'),
(66881, 4577, 'Private Practice S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hXHvuIfbS3b06K6wzpZPSYd1c9U.jpg'),
(66882, 4577, 'Private Practice S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kQkBqNkRuF1OPRQqLbeXkVBG4d2.jpg'),
(66883, 4577, 'Private Practice S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n0dJ2QboY2SS0LEG44eSz5ZpG5V.jpg'),
(66884, 4577, 'Private Practice S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jEneMZfk0FfkxUlGbdynGqzbCKT.jpg'),
(66885, 4577, 'Private Practice S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2iuBgpUazcoK5Ts2kFYorquXWoe.jpg'),
(66886, 4577, 'Private Practice S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nrkOnQPPGzwRQDP8QaCVvkbfB2n.jpg'),
(66887, 4577, 'Private Practice S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xKgZTDaHwlPWA5GhP3lO6fzZNiO.jpg'),
(66888, 4577, 'Private Practice S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5E9PBStV1wfEdIzYuViIWKUWhcm.jpg'),
(66889, 4577, 'Private Practice S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3po0ztPenVBHZ3YRYipHRR9SsP.jpg'),
(66890, 4577, 'Private Practice S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cHtx1cse4qkbXipnSvDtCRjfNto.jpg'),
(66891, 4577, 'Private Practice S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJ57f3NHPNsE5i42DePQpvWqtZp.jpg'),
(66892, 4577, 'Private Practice S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pbqCsSOxtZMrtEjcurXX0k3zTaz.jpg'),
(66893, 4577, 'Private Practice S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8F3aC1dZ2G37d5VfTsfaeZ5McA2.jpg'),
(66894, 4577, 'Private Practice S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d4vduDgZusJCKVRocKWanu7KI0f.jpg'),
(66895, 4577, 'Private Practice S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oLhTDD4EMxu7hHRSNf5GevlYmLA.jpg'),
(66896, 4577, 'Private Practice S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mSr09pbZdxXKQzMnCisbf1FXPva.jpg'),
(66897, 4577, 'Private Practice S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xqLi96PnS317OWMuwxfHkqpcUKw.jpg'),
(66898, 4577, 'Private Practice S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ASVgzRSgO1sXArYRJJOf2iQQgA.jpg'),
(66899, 4577, 'Private Practice S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xX1v28CG4uB6esHytxj3CL8XGnq.jpg'),
(66900, 4577, 'Private Practice S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2iFHAkLcGaM07MdsbWcWbqzzfa.jpg'),
(66901, 4577, 'Private Practice S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5M11owOERckEHFgxBqMI4f9MU0h.jpg'),
(66902, 4578, 'Private Practice S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nPGgDbqw4vkPE8qtFfohemt8w1N.jpg'),
(66903, 4578, 'Private Practice S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eQ0kLeOzHTEDNVccoYSdcLB7hxW.jpg'),
(66904, 4578, 'Private Practice S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bctRkUWGwTdgSoksDK7tamS2sGN.jpg'),
(66905, 4578, 'Private Practice S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x4SbUQyUn8eK460fotnbY9DASzM.jpg'),
(66906, 4578, 'Private Practice S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/isEClQoEwgwvUKB2vPtfHlkA1Hs.jpg'),
(66907, 4578, 'Private Practice S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2yHI2vbFr8h1DH5YDG1s3UWuQQa.jpg'),
(66908, 4578, 'Private Practice S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vcIhAUCGo1kuP90miCX6HlOiqgZ.jpg'),
(66909, 4578, 'Private Practice S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8OsVealmKoKkiN0e85QGcjEK65g.jpg'),
(66910, 4578, 'Private Practice S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d4QR8QuA6faporqZb4ZdJR27P97.jpg'),
(66911, 4578, 'Private Practice S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5JQkkzaAhfrCo40x1dsmaVhTpVI.jpg'),
(66912, 4578, 'Private Practice S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/li1UeDN33J4eBAbzvOjjVCQyJgi.jpg'),
(66913, 4578, 'Private Practice S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/14QsxFffStJjK5iFyBUKbCZPXGo.jpg'),
(66914, 4578, 'Private Practice S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fg8DAiTamD9dKngU52h6eD3GRix.jpg'),
(66915, 4578, 'Private Practice S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9mZ1Xl2gZM2Ts3U5iEA3B5otzQ7.jpg'),
(66916, 4578, 'Private Practice S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mzV1cTGVr5J2FLCzf5WkQg5DztC.jpg'),
(66917, 4578, 'Private Practice S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sRfoHDs6vmtPSZY0izR6JCDDq8c.jpg'),
(66918, 4578, 'Private Practice S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zEBOSDwRfrpQyq2YxxcDZK7uBKw.jpg'),
(66919, 4578, 'Private Practice S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1T8iTBVbaZoZsgPVmjgCd6NAKIK.jpg'),
(66920, 4578, 'Private Practice S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/smBSzsBf8Y81QcW7tqrgQEA9l8N.jpg'),
(66921, 4578, 'Private Practice S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/425oSAJKNwBW9hWUrPTYuOsCjUX.jpg'),
(66922, 4578, 'Private Practice S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCa014FnNQEgs89Z6JwRvsdyadz.jpg'),
(66923, 4578, 'Private Practice S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kHPnHEFidnJSFESNCI0Mz6n0Ech.jpg'),
(66924, 4578, 'Private Practice S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/160684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4RvJBGDi3s0uzBHnRufjJg9yzPy.jpg'),
(66925, 4579, 'Private Practice S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gYUaMqR6IXBpDD7HkH2UR0AkWs8.jpg'),
(66926, 4579, 'Private Practice S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6cjr5eZX4Rxd0p1UsDURACcXt2W.jpg'),
(66927, 4579, 'Private Practice S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3bxqqLQfmNm3ehi4ncIWcurg5o9.jpg'),
(66928, 4579, 'Private Practice S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1FYyffnR3m0b8OvarxY9MK0sQNg.jpg'),
(66929, 4579, 'Private Practice S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tR0XIiTcXVFDVTGCCaDDZEO4ylB.jpg'),
(66930, 4579, 'Private Practice S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tolpzUPGfVoRk9bchIDrqC5lLv0.jpg'),
(66931, 4579, 'Private Practice S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lvJIlAEiEVLYRVTTr2TA16F45Jp.jpg'),
(66932, 4579, 'Private Practice S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWsch6Qh3Q46RQEbzjSiSJCOB0L.jpg'),
(66933, 4579, 'Private Practice S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ue6JQ1PIsuUFwDyFPpb1dr8DSq.jpg'),
(66934, 4579, 'Private Practice S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2gb9WV4uLdso0GLf5ddYkEBS7JX.jpg'),
(66935, 4579, 'Private Practice S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vt9hUIVhyFNwxsWCmY6JzQOBBmx.jpg'),
(66936, 4579, 'Private Practice S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oBvKATOkFoFiRPpkDzlRAB26For.jpg'),
(66937, 4579, 'Private Practice S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7wAjSOooC9fUjjkfT865ehXRAFl.jpg'),
(66938, 4579, 'Private Practice S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ZaP2AfpQ2llSuwRx7T0PgjeQec.jpg'),
(66939, 4579, 'Private Practice S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iypkaLtX1fz7Kqsz78yZ9fsegPF.jpg'),
(66940, 4579, 'Private Practice S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wNZdulWg6ufb46iViRwCHs5fMfk.jpg'),
(66941, 4579, 'Private Practice S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tdqsDWAtUKkRkgGiZAGqRd3yrOH.jpg'),
(66942, 4579, 'Private Practice S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cy6JfmUUK8vaxGQzujLDhJNLMde.jpg'),
(66943, 4579, 'Private Practice S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2uCIozlbYLWfH8iFo9TrQYu9bOo.jpg'),
(66944, 4579, 'Private Practice S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/956WBjZz8d9SL9ubuXnmydg0tkW.jpg'),
(66945, 4579, 'Private Practice S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p7XLpPS6wvToKeG8qoaF7bGwNVv.jpg'),
(66946, 4579, 'Private Practice S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jP0ne1h89xnmAExXkOJHwBdDDGA.jpg'),
(66947, 4580, 'Private Practice S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/996DPFvcISNxkrjGmiblwP0x0vH.jpg'),
(66948, 4580, 'Private Practice S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hDg8b9OkphKe7LswmhYzk6f6E06.jpg'),
(66949, 4580, 'Private Practice S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gyhNfnpUdnQDc3sedridSjnQdZ6.jpg'),
(66950, 4580, 'Private Practice S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6cjr5eZX4Rxd0p1UsDURACcXt2W.jpg'),
(66951, 4580, 'Private Practice S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fszCflLgvhfhMqtRUGAp0oo8cKM.jpg'),
(66952, 4580, 'Private Practice S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qOhKTUy21jMwx7mkyHrNfA9CTeq.jpg'),
(66953, 4580, 'Private Practice S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6hRdY4p7IdYZIMSo7z7vDVzBiuM.jpg'),
(66954, 4580, 'Private Practice S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vEhYbAZITxT3nWqGeEX7DG67WWb.jpg'),
(66955, 4580, 'Private Practice S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oPNMOq0ZhQUbkf5WR4jcAAd0S2d.jpg'),
(66956, 4580, 'Private Practice S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDw4OjrGK9mb4HLh9rnp098YJcI.jpg'),
(66957, 4580, 'Private Practice S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sX9imkdGrZJrkVjJJCBPXf20dMP.jpg'),
(66958, 4580, 'Private Practice S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4LvZ542nDCNUFggCBWmu1GRjNjV.jpg'),
(66959, 4580, 'Private Practice S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xRb7O9uqL2OLI9FMZp0OojVsuxs.jpg'),
(66960, 4580, 'Private Practice S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jWzAVztqgjTbG7Clx8eiitAXuY4.jpg'),
(66961, 4580, 'Private Practice S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xW2WdHuKyUA860z6rCzRiQmrt5T.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(66962, 4580, 'Private Practice S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JIFI2aucO6aXq4tLndl8MsoVvk.jpg'),
(66963, 4580, 'Private Practice S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQrNlGqxt0XKyXv0oucb1vRmyGs.jpg'),
(66964, 4580, 'Private Practice S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3sdJorW01OBHaG0cnZOu7mLmxR.jpg'),
(66965, 4580, 'Private Practice S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gDbzNKnLsMEmsVsMwyhYthkyrDx.jpg'),
(66966, 4580, 'Private Practice S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tNXTwluUSUOC6bfaolUMfh6L5ll.jpg'),
(66967, 4580, 'Private Practice S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvoO0woxCYejMTHya6cyGvmEnvd.jpg'),
(66968, 4580, 'Private Practice S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pP48zpNnul1jV6W3ZWymlRFZ1NF.jpg'),
(66969, 4581, 'Psychoville [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v7FRQNEOMvq0Q3wGbgjguv4PgCM.jpg'),
(66970, 4581, 'Psychoville [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3GHyip4oEzt7J6scyQVySSv8tHY.jpg'),
(66971, 4581, 'Psychoville [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1BS6Vwk6POdKEYtL1Z4lkzJzAUs.jpg'),
(66972, 4581, 'Psychoville [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cRrC3qc8TsI4iauqCGh4hBS9VUZ.jpg'),
(66973, 4581, 'Psychoville [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aRapbf2pKpBe4nHEqIHMkF4XlLz.jpg'),
(66974, 4581, 'Psychoville [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sXBpQZZQsgbHfg3g5Pp11E5yYrD.jpg'),
(66975, 4581, 'Psychoville [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2K6A8ywXuIVxAeEgl06puRg26Tl.jpg'),
(66976, 4582, 'Psychoville [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iGAdkXpbangnl2FoKdZQvJRkU0R.jpg'),
(66977, 4582, 'Psychoville [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iGAdkXpbangnl2FoKdZQvJRkU0R.jpg'),
(66978, 4582, 'Psychoville [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iGAdkXpbangnl2FoKdZQvJRkU0R.jpg'),
(66979, 4582, 'Psychoville [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iGAdkXpbangnl2FoKdZQvJRkU0R.jpg'),
(66980, 4582, 'Psychoville [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iGAdkXpbangnl2FoKdZQvJRkU0R.jpg'),
(66981, 4582, 'Psychoville [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iGAdkXpbangnl2FoKdZQvJRkU0R.jpg'),
(66982, 4582, 'Psychoville [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iGAdkXpbangnl2FoKdZQvJRkU0R.jpg'),
(66983, 4583, 'Quando Chama o Coração S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eZcnMmIdADOpmKhWPHole2Gxmhv.jpg'),
(66984, 4583, 'Quando Chama o Coração S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n9fuwve8b1E8fXCcjtbORJamVse.jpg'),
(66985, 4583, 'Quando Chama o Coração S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vjYDVPkN0qWYdBKRMsZZvoMsa5Z.jpg'),
(66986, 4583, 'Quando Chama o Coração S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yJG3Zz89j4mfG4lju5zuAEJ9k76.jpg'),
(66987, 4583, 'Quando Chama o Coração S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wavwFGBW1jwwEgAxCJ2YhDRoBXn.jpg'),
(66988, 4583, 'Quando Chama o Coração S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yzoVeembdsiA6FZHdiX7tefy5so.jpg'),
(66989, 4583, 'Quando Chama o Coração S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rPnUoRLkdPMRTyAYvZZi2SRgzY.jpg'),
(66990, 4583, 'Quando Chama o Coração S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iOqDBV7SGEaNpMPekPhxQBticZN.jpg'),
(66991, 4583, 'Quando Chama o Coração S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/197985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xibNC4wcDyl3RAaMvsZiUPtjBSa.jpg'),
(66992, 4583, 'Quando Chama o Coração S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/197986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7m9XffclwEIuU3eZiyCa05xhD5T.jpg'),
(66993, 4583, 'Quando Chama o Coração S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/197987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hrzg737JCElx0WNS2wY0R3ddRqB.jpg'),
(66994, 4583, 'Quando Chama o Coração S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/197988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t1JsbYDEhEenl62Ukbd03wDIohA.jpg'),
(66995, 4584, 'Quando Chama o Coração S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x0a3dbKHqPLxp0cEqTYN5ra5Eqs.jpg'),
(66996, 4584, 'Quando Chama o Coração S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3bPrqAB1EoZROCJSQvSAkF2Ste1.jpg'),
(66997, 4584, 'Quando Chama o Coração S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hF1yY8taAx5WPMrBlUi2SRmvxSo.jpg'),
(66998, 4584, 'Quando Chama o Coração S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iqbBkG73sxaKHG6weUZyMYAD14N.jpg'),
(66999, 4584, 'Quando Chama o Coração S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4scRVBFq5kRTWonVwWbYP0NddHM.jpg'),
(67000, 4584, 'Quando Chama o Coração S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jtvdqeIGJ7YIUruyZrGTHzgpBlE.jpg'),
(67001, 4584, 'Quando Chama o Coração S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rrUQ9DU6UCjM3kUQWndCuH7omXm.jpg'),
(67002, 4584, 'Quando Chama o Coração S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4VbuR34rwErpaUMfGgjcqXDED9L.jpg'),
(67003, 4584, 'Quando Chama o Coração S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/197997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4VbuR34rwErpaUMfGgjcqXDED9L.jpg'),
(67004, 4584, 'Quando Chama o Coração S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/197998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4VbuR34rwErpaUMfGgjcqXDED9L.jpg'),
(67005, 4585, 'Quando Chama o Coração S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8ugXPQN96jzHzPwwGre3j1y6Lv.jpg'),
(67006, 4585, 'Quando Chama o Coração S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1fJH3YliTgKCtQCsGNvSLrgliub.jpg'),
(67007, 4585, 'Quando Chama o Coração S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ehr5E61oarqMUGWr2nl7AGTuW5P.jpg'),
(67008, 4585, 'Quando Chama o Coração S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oRikqsDrnOzgOGlua3U2ppaA2uO.jpg'),
(67009, 4585, 'Quando Chama o Coração S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/huoV8YajS7pWjOjX5H3oriJt34c.jpg'),
(67010, 4585, 'Quando Chama o Coração S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rM8NxyK7Fbne4kUa7JEqfk75Yy4.jpg'),
(67011, 4585, 'Quando Chama o Coração S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bwc5wwFYxMUUE0hyfb3FEeym9Ke.jpg'),
(67012, 4585, 'Quando Chama o Coração S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yO2kv7vRrRiv7RZIp12ifLoKOs8.jpg'),
(67013, 4585, 'Quando Chama o Coração S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pal0ZnZLdG2ZGbgJXjrPqhMkFtG.jpg'),
(67014, 4585, 'Quando Chama o Coração S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4VbuR34rwErpaUMfGgjcqXDED9L.jpg'),
(67015, 4586, 'Quando Chama o Coração S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Gl7zBj9Td1fgb81TtNYJ2ZWyoH.jpg'),
(67016, 4586, 'Quando Chama o Coração S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4hfT7t3CbnQEWuVJYZgQWd3jms9.jpg'),
(67017, 4586, 'Quando Chama o Coração S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyVqkGOuIo07vgB0i8QuPAscd3p.jpg'),
(67018, 4586, 'Quando Chama o Coração S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k3Mvt5IBq82bw7W91xECX7md54O.jpg'),
(67019, 4586, 'Quando Chama o Coração S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/61S0dwNhCMeiWU6VXitfjekz6eY.jpg'),
(67020, 4586, 'Quando Chama o Coração S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t1LLFXB46DA6Up7SAzZK8m9RKIR.jpg'),
(67021, 4586, 'Quando Chama o Coração S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6zJaSgmnYHMp2MISoZmk4CFaRta.jpg'),
(67022, 4586, 'Quando Chama o Coração S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oTGv9SdgnKW6lvJHWDXqG0ob7Ml.jpg'),
(67023, 4586, 'Quando Chama o Coração S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/waK2hGwZrj8j3hQgWPl37vBbpyX.jpg'),
(67024, 4586, 'Quando Chama o Coração S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z0QBQa2C5nLmgbqVhIf8srL6J2n.jpg'),
(67025, 4586, 'Quando Chama o Coração S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/198019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4VbuR34rwErpaUMfGgjcqXDED9L.jpg'),
(67026, 4586, 'Quando Chama o Coração S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/198020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4VbuR34rwErpaUMfGgjcqXDED9L.jpg'),
(67027, 4587, 'Quando Chama o Coração S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w9fdTp0CMqqNCkbsReZcDTYH5VY.jpg'),
(67028, 4587, 'Quando Chama o Coração S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ewyvzwsAUoH1EMVX2vNtYeOKeyj.jpg'),
(67029, 4587, 'Quando Chama o Coração S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2CMc7utleL7A0PSBCuFtPt5eRk.jpg'),
(67030, 4587, 'Quando Chama o Coração S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJdX1oX0VFgCxknRQPOMPjoNoDF.jpg'),
(67031, 4587, 'Quando Chama o Coração S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nMTC38iQTuu92rhEsSDUmkWUsxT.jpg'),
(67032, 4587, 'Quando Chama o Coração S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qOmhYCrLjtWjaZTBsk9swTDp6En.jpg'),
(67033, 4587, 'Quando Chama o Coração S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pX1h5mfVFrS1R0QLT8RMwEZ7Jzb.jpg'),
(67034, 4587, 'Quando Chama o Coração S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cU3s1d2EhUL21wBykgmzR7yikLa.jpg'),
(67035, 4587, 'Quando Chama o Coração S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z65P5QWZXnF77zitZ43XTlFQqLo.jpg'),
(67036, 4587, 'Quando Chama o Coração S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUcLLwdc5eJUE9njzHibjCv3A8c.jpg'),
(67037, 4587, 'Quando Chama o Coração S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/198031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4VbuR34rwErpaUMfGgjcqXDED9L.jpg'),
(67038, 4587, 'Quando Chama o Coração S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/198032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4VbuR34rwErpaUMfGgjcqXDED9L.jpg'),
(67039, 4588, 'Quando Chama o Coração S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3OwAwTmpra4OxarT4O6avfjCrd1.jpg'),
(67040, 4588, 'Quando Chama o Coração S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjoyQui2BnFKJHB8jaEWfoF1Qn4.jpg'),
(67041, 4588, 'Quando Chama o Coração S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhMw55kKV4N2OVWjebctYyY6xm5.jpg'),
(67042, 4588, 'Quando Chama o Coração S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g9h4KXgEAwS2KvVKNDfNox0Gedc.jpg'),
(67043, 4588, 'Quando Chama o Coração S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvtqpV3J5o3ZPAHCLwWwnDugaM3.jpg'),
(67044, 4588, 'Quando Chama o Coração S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0LO5ujVfb6v40ilEVlSMgRhEu7.jpg'),
(67045, 4588, 'Quando Chama o Coração S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/baIK6fWLYa5rGYmAbox8xwHUQXm.jpg'),
(67046, 4588, 'Quando Chama o Coração S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pGLj9b2WtARzbVuUuHeGUJIU1SS.jpg'),
(67047, 4588, 'Quando Chama o Coração S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4VbuR34rwErpaUMfGgjcqXDED9L.jpg'),
(67048, 4588, 'Quando Chama o Coração S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4VbuR34rwErpaUMfGgjcqXDED9L.jpg'),
(67049, 4588, 'Quando Chama o Coração S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/198043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4VbuR34rwErpaUMfGgjcqXDED9L.jpg'),
(67050, 4589, 'Quando Chama o Coração S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198044.mp4', 'http://timg.bdta.pro/images/8b08970f2dbca9294a6f5e460c9ed892.jpg'),
(67051, 4589, 'Quando Chama o Coração S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198045.mp4', 'http://timg.bdta.pro/images/358267f9ed51909a31c39ddd284f3300.jpg'),
(67052, 4589, 'Quando Chama o Coração S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198046.mp4', 'http://timg.bdta.pro/images/6daf06a3157a06f88cf71ce520306294.jpg'),
(67053, 4589, 'Quando Chama o Coração S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198047.mp4', 'http://timg.bdta.pro/images/9c0d624a9edc184dada7ef8c4d74c2d3.jpg'),
(67054, 4589, 'Quando Chama o Coração S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198048.mp4', 'http://timg.bdta.pro/images/6cd952541b03be5209e4c132b82a5625.jpg'),
(67055, 4589, 'Quando Chama o Coração S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198049.mp4', 'http://timg.bdta.pro/images/c2e998cdd09109e3450f06ffb607f2fe.jpg'),
(67056, 4589, 'Quando Chama o Coração S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198050.mp4', 'http://timg.bdta.pro/images/8c1c768ed56ed644b9855cddcf9460be.jpg'),
(67057, 4589, 'Quando Chama o Coração S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198051.mp4', 'http://timg.bdta.pro/images/e686f0d8ff16b3ba4e0a552a9485a765.jpg'),
(67058, 4589, 'Quando Chama o Coração S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198052.mp4', 'http://timg.bdta.pro/images/641f2be154ddb3fae70ff358d2ca1f72.jpg'),
(67059, 4589, 'Quando Chama o Coração S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198053.mp4', 'http://timg.bdta.pro/images/fbda8613a5b858b75aaef40d5d53bf3f.jpg'),
(67060, 4589, 'Quando Chama o Coração S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/198054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4VbuR34rwErpaUMfGgjcqXDED9L.jpg'),
(67061, 4590, 'Quando Chama o Coração S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198055.mp4', 'http://timg.bdta.pro/images/d00158a9f2e19d16e874cea75c3994f9.jpg'),
(67062, 4590, 'Quando Chama o Coração S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198056.mp4', 'http://timg.bdta.pro/images/63d63e16b634cc2f5534db95a744d169.jpg'),
(67063, 4590, 'Quando Chama o Coração S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198057.mp4', 'http://timg.bdta.pro/images/bd5f575ffc0cfcc86ff68c9fd2fd26b2.jpg'),
(67064, 4590, 'Quando Chama o Coração S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198058.mp4', 'http://timg.bdta.pro/images/c2f710950f352d906b2a0eb059c6cf3b.jpg'),
(67065, 4590, 'Quando Chama o Coração S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198059.mp4', 'http://timg.bdta.pro/images/50d6cb29d1a97a85b660378588d99df5.jpg'),
(67066, 4590, 'Quando Chama o Coração S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198060.mp4', 'http://timg.bdta.pro/images/23a9d3df6f6da91a5bb5d2a995a39c57.jpg'),
(67067, 4590, 'Quando Chama o Coração S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198061.mp4', 'http://timg.bdta.pro/images/c873acf2e4d5e62d522e5c451ea62634.jpg'),
(67068, 4590, 'Quando Chama o Coração S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198062.mp4', 'http://timg.bdta.pro/images/68a895cb40dc1cceed29be74a3c482c0.jpg'),
(67069, 4590, 'Quando Chama o Coração S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198063.mp4', 'http://timg.bdta.pro/images/f68f154272c3884f88756990276954b4.jpg'),
(67070, 4590, 'Quando Chama o Coração S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198064.mp4', 'http://timg.bdta.pro/images/0b7c89940d46c0e7cb660d09a934e762.jpg'),
(67071, 4590, 'Quando Chama o Coração S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/198065.mp4', 'http://timg.bdta.pro/images/8c6adeebd494d16605f23c7500c1abd3.jpg'),
(67072, 4590, 'Quando Chama o Coração S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/198066.mp4', 'http://timg.bdta.pro/images/af6512b7a2e680a63de1dc8372aeadb5.jpg'),
(67073, 4591, 'Rumo às Estrelas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1KzinGfqrATF9T7kR1IU1iK1DWV.jpg'),
(67074, 4591, 'Rumo às Estrelas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mgNpg0PkfFMP1b3UDZOAi0Ji3Dh.jpg'),
(67075, 4591, 'Rumo às Estrelas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9TlwtWeGOoezcBvY1PJiJ5oc0YP.jpg'),
(67076, 4591, 'Rumo às Estrelas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ah1iHEOxY6nNLhaGIfChVJJ8Iqa.jpg'),
(67077, 4591, 'Rumo às Estrelas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ifaZMBDhdum492nsAP2AKQpzNEh.jpg'),
(67078, 4591, 'Rumo às Estrelas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8M2eCH07V2UsaO27HKd9Xka1g12.jpg'),
(67079, 4592, 'Scooby-Doo! Mistério S/A S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rKz3pHWucvxPi2eWn4eB07eGJLa.jpg'),
(67080, 4592, 'Scooby-Doo! Mistério S/A S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3kvZXfMpqJSXESbLmiUht8qmWSA.jpg'),
(67081, 4592, 'Scooby-Doo! Mistério S/A S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aK3KxfNNoc43pyh4OjCBTqxKPP9.jpg'),
(67082, 4592, 'Scooby-Doo! Mistério S/A S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vprx4TSNGT4Xm3CAbU3zPKC5lVX.jpg'),
(67083, 4592, 'Scooby-Doo! Mistério S/A S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nnqfBCX2g9Frkx43Rl6hpUSFH9M.jpg'),
(67084, 4592, 'Scooby-Doo! Mistério S/A S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Hon7VSM8Y1DC0CyFhxII4EWtDU.jpg'),
(67085, 4592, 'Scooby-Doo! Mistério S/A S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gEy1ZLXglOUZFQVOzCXSgrxyOsA.jpg'),
(67086, 4592, 'Scooby-Doo! Mistério S/A S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8uymmWz2s8y5KuyLOv5YkDHrVLc.jpg'),
(67087, 4592, 'Scooby-Doo! Mistério S/A S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/32ZHdJcW9fsaCRwoNSxo4rR3zEu.jpg'),
(67088, 4592, 'Scooby-Doo! Mistério S/A S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3EZQ0D0S8BCkEYJRUQfAANeVFoz.jpg'),
(67089, 4592, 'Scooby-Doo! Mistério S/A S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/noig7eRTfUSsgkvmNBaF1YCXhmR.jpg'),
(67090, 4592, 'Scooby-Doo! Mistério S/A S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hRBzHj9Teo5vVgbvMtfKqzGRSbW.jpg'),
(67091, 4592, 'Scooby-Doo! Mistério S/A S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/LAytlNIBcR7dzK6XbjudVk21tp.jpg'),
(67092, 4592, 'Scooby-Doo! Mistério S/A S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gT72cJFflRKaUg7PRDJTML8LWdF.jpg'),
(67093, 4592, 'Scooby-Doo! Mistério S/A S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hTzsTlaWVI37zKB7fcjeYDJLjBQ.jpg'),
(67094, 4592, 'Scooby-Doo! Mistério S/A S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cHW0X0IJ6JCIgKt4Ahf0JqJPKL1.jpg'),
(67095, 4592, 'Scooby-Doo! Mistério S/A S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FmTAqihEOS8lBt3F2nTPpcS4Jr.jpg'),
(67096, 4592, 'Scooby-Doo! Mistério S/A S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xsy4Q3q6QvdqLnfT51tHCeKpDHk.jpg'),
(67097, 4592, 'Scooby-Doo! Mistério S/A S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aRBrCb5QXIcZZ0bG58lgSeOFvDh.jpg'),
(67098, 4592, 'Scooby-Doo! Mistério S/A S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/buksTJtjxDqeqVIIz5lLd6L0Ye5.jpg'),
(67099, 4592, 'Scooby-Doo! Mistério S/A S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3h8UugR24wolNgh38R55EzRbzg.jpg'),
(67100, 4592, 'Scooby-Doo! Mistério S/A S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/taEQfCtWrawtMVU9xX6tOEw4Q0g.jpg'),
(67101, 4592, 'Scooby-Doo! Mistério S/A S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/160581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vKSIiD52Ocrr3xG4SeGaWPW2tDj.jpg'),
(67102, 4592, 'Scooby-Doo! Mistério S/A S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/160582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aAPzdmgbf7arfWvEU6HNBoWi0dh.jpg'),
(67103, 4592, 'Scooby-Doo! Mistério S/A S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/160583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/acrqciz6nrVZJ8db8cFYDtEYmoR.jpg'),
(67104, 4592, 'Scooby-Doo! Mistério S/A S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/160584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ewcNZjJe7nh1QA2IjJVxeeZQgpV.jpg'),
(67105, 4593, 'Scooby-Doo! Mistério S/A S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/okGIlc2jUYkFmn0THR47dZBnea.jpg'),
(67106, 4593, 'Scooby-Doo! Mistério S/A S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6S5Ni5PFTUI0Cnw7pZMpkS4ZGlm.jpg'),
(67107, 4593, 'Scooby-Doo! Mistério S/A S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lQhOd5g9UlO9b7flCVmGr1hsWsh.jpg'),
(67108, 4593, 'Scooby-Doo! Mistério S/A S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9NCD9A3SW1LduToUSv86f4DHZlr.jpg'),
(67109, 4593, 'Scooby-Doo! Mistério S/A S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jMPwl4o4jdU7JBjRFnRwgjgE9zi.jpg'),
(67110, 4593, 'Scooby-Doo! Mistério S/A S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6X5hCqAoFIiAmM4UXSPt2scn7n.jpg'),
(67111, 4593, 'Scooby-Doo! Mistério S/A S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ymwufvZkMroEhJ3Ab66alae7MlO.jpg'),
(67112, 4593, 'Scooby-Doo! Mistério S/A S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/etUztJ4U9C92KaVqQXp0NZuepZ5.jpg'),
(67113, 4593, 'Scooby-Doo! Mistério S/A S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qmxyPkwU1o5jmPVfEiuOnoQjRK6.jpg'),
(67114, 4593, 'Scooby-Doo! Mistério S/A S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r4KwECMjl0abCq6FMba83vg3MWj.jpg'),
(67115, 4593, 'Scooby-Doo! Mistério S/A S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Jf13G7GMjlXAObjg3k0UmEwFUf.jpg'),
(67116, 4593, 'Scooby-Doo! Mistério S/A S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lHzeFO927s63nccgaqf4quBzEsa.jpg'),
(67117, 4593, 'Scooby-Doo! Mistério S/A S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6P0IFIxUyLpH5d9SocrUGykTAIG.jpg'),
(67118, 4593, 'Scooby-Doo! Mistério S/A S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yxHCWawO2mokM9P69MJgL1pHzDw.jpg'),
(67119, 4593, 'Scooby-Doo! Mistério S/A S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3SjnbbcdqOCWcoLJAyMVWTcQyLU.jpg'),
(67120, 4593, 'Scooby-Doo! Mistério S/A S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3H8v0QaTINppMxcSu65IYBwHDCg.jpg'),
(67121, 4593, 'Scooby-Doo! Mistério S/A S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tSUCRq2QUUv7U0hD7UuYjwgdtJx.jpg'),
(67122, 4593, 'Scooby-Doo! Mistério S/A S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/66hgOBckW4w44OxxyS7tOPzKLnl.jpg'),
(67123, 4593, 'Scooby-Doo! Mistério S/A S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uS9WzUAirOiJvpxnhUhxQ3ajTJV.jpg'),
(67124, 4593, 'Scooby-Doo! Mistério S/A S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s7KI5xkEikAFI43l092rLdcZ4uP.jpg'),
(67125, 4593, 'Scooby-Doo! Mistério S/A S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kDgpX2o7UrCZKLXHL9993F3E2Xa.jpg'),
(67126, 4593, 'Scooby-Doo! Mistério S/A S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ufpcrNAldCxtDzjZr8cuntxzsOM.jpg'),
(67127, 4593, 'Scooby-Doo! Mistério S/A S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/160607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p1f4lj72V1pVUsZN1GSNRBZXpFK.jpg'),
(67128, 4593, 'Scooby-Doo! Mistério S/A S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/160608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nm4kuRKV62F60OavMxnZbY0403v.jpg'),
(67129, 4593, 'Scooby-Doo! Mistério S/A S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/160609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8enRwi1JC3Am2ndvrEoKMim8PEO.jpg'),
(67130, 4593, 'Scooby-Doo! Mistério S/A S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/160610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bUEONQMdknVpzRH9gZHYqB31olW.jpg'),
(67131, 4594, 'Tapas & Beijos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67132, 4594, 'Tapas & Beijos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67133, 4594, 'Tapas & Beijos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67134, 4594, 'Tapas & Beijos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67135, 4594, 'Tapas & Beijos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67136, 4594, 'Tapas & Beijos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67137, 4594, 'Tapas & Beijos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67138, 4594, 'Tapas & Beijos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67139, 4594, 'Tapas & Beijos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67140, 4594, 'Tapas & Beijos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67141, 4594, 'Tapas & Beijos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67142, 4594, 'Tapas & Beijos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67143, 4594, 'Tapas & Beijos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67144, 4594, 'Tapas & Beijos S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67145, 4594, 'Tapas & Beijos S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67146, 4594, 'Tapas & Beijos S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67147, 4594, 'Tapas & Beijos S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67148, 4594, 'Tapas & Beijos S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67149, 4594, 'Tapas & Beijos S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67150, 4594, 'Tapas & Beijos S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67151, 4594, 'Tapas & Beijos S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67152, 4594, 'Tapas & Beijos S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67153, 4594, 'Tapas & Beijos S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/160412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67154, 4594, 'Tapas & Beijos S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/160413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67155, 4594, 'Tapas & Beijos S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/160414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67156, 4594, 'Tapas & Beijos S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/160415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67157, 4594, 'Tapas & Beijos S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/160416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67158, 4594, 'Tapas & Beijos S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/160417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67159, 4594, 'Tapas & Beijos S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/160418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67160, 4594, 'Tapas & Beijos S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/160419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67161, 4594, 'Tapas & Beijos S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/160420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67162, 4594, 'Tapas & Beijos S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/160421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67163, 4594, 'Tapas & Beijos S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/160422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67164, 4594, 'Tapas & Beijos S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/160423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67165, 4594, 'Tapas & Beijos S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/160424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67166, 4594, 'Tapas & Beijos S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/160425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67167, 4595, 'Tapas & Beijos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67168, 4595, 'Tapas & Beijos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67169, 4595, 'Tapas & Beijos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67170, 4595, 'Tapas & Beijos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67171, 4595, 'Tapas & Beijos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67172, 4595, 'Tapas & Beijos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67173, 4595, 'Tapas & Beijos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67174, 4595, 'Tapas & Beijos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67175, 4595, 'Tapas & Beijos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67176, 4595, 'Tapas & Beijos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67177, 4595, 'Tapas & Beijos S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67178, 4595, 'Tapas & Beijos S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67179, 4595, 'Tapas & Beijos S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67180, 4595, 'Tapas & Beijos S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67181, 4595, 'Tapas & Beijos S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67182, 4595, 'Tapas & Beijos S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67183, 4595, 'Tapas & Beijos S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67184, 4595, 'Tapas & Beijos S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67185, 4595, 'Tapas & Beijos S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67186, 4595, 'Tapas & Beijos S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67187, 4595, 'Tapas & Beijos S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67188, 4595, 'Tapas & Beijos S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67189, 4595, 'Tapas & Beijos S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/160448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67190, 4595, 'Tapas & Beijos S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/160449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67191, 4595, 'Tapas & Beijos S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/160450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67192, 4595, 'Tapas & Beijos S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/160451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67193, 4595, 'Tapas & Beijos S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/160452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67194, 4595, 'Tapas & Beijos S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/160453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67195, 4595, 'Tapas & Beijos S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/160454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67196, 4595, 'Tapas & Beijos S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/160455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67197, 4595, 'Tapas & Beijos S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/160456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67198, 4595, 'Tapas & Beijos S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/160457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67199, 4595, 'Tapas & Beijos S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/160458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67200, 4595, 'Tapas & Beijos S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/160459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67201, 4595, 'Tapas & Beijos S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/160460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67202, 4595, 'Tapas & Beijos S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/160461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67203, 4595, 'Tapas & Beijos S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/160462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67204, 4595, 'Tapas & Beijos S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/160463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67205, 4596, 'Tapas & Beijos S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67206, 4596, 'Tapas & Beijos S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67207, 4596, 'Tapas & Beijos S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67208, 4596, 'Tapas & Beijos S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67209, 4596, 'Tapas & Beijos S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67210, 4596, 'Tapas & Beijos S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67211, 4596, 'Tapas & Beijos S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67212, 4596, 'Tapas & Beijos S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67213, 4596, 'Tapas & Beijos S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67214, 4596, 'Tapas & Beijos S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67215, 4596, 'Tapas & Beijos S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67216, 4596, 'Tapas & Beijos S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67217, 4596, 'Tapas & Beijos S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67218, 4596, 'Tapas & Beijos S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67219, 4596, 'Tapas & Beijos S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67220, 4596, 'Tapas & Beijos S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67221, 4596, 'Tapas & Beijos S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67222, 4596, 'Tapas & Beijos S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(67223, 4596, 'Tapas & Beijos S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67224, 4596, 'Tapas & Beijos S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67225, 4596, 'Tapas & Beijos S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67226, 4596, 'Tapas & Beijos S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67227, 4596, 'Tapas & Beijos S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/160486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67228, 4596, 'Tapas & Beijos S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/160487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67229, 4596, 'Tapas & Beijos S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/160488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67230, 4596, 'Tapas & Beijos S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/160489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67231, 4596, 'Tapas & Beijos S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/160490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67232, 4596, 'Tapas & Beijos S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/160491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67233, 4596, 'Tapas & Beijos S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/160492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67234, 4596, 'Tapas & Beijos S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/160493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67235, 4596, 'Tapas & Beijos S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/160494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67236, 4596, 'Tapas & Beijos S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/160495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67237, 4596, 'Tapas & Beijos S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/160496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67238, 4596, 'Tapas & Beijos S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/160497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67239, 4596, 'Tapas & Beijos S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/160498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67240, 4596, 'Tapas & Beijos S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/160499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67241, 4596, 'Tapas & Beijos S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/160500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67242, 4597, 'Tapas & Beijos S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67243, 4597, 'Tapas & Beijos S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67244, 4597, 'Tapas & Beijos S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67245, 4597, 'Tapas & Beijos S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67246, 4597, 'Tapas & Beijos S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67247, 4597, 'Tapas & Beijos S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67248, 4597, 'Tapas & Beijos S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67249, 4597, 'Tapas & Beijos S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67250, 4597, 'Tapas & Beijos S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67251, 4597, 'Tapas & Beijos S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67252, 4597, 'Tapas & Beijos S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67253, 4597, 'Tapas & Beijos S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67254, 4597, 'Tapas & Beijos S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67255, 4597, 'Tapas & Beijos S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67256, 4597, 'Tapas & Beijos S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67257, 4597, 'Tapas & Beijos S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67258, 4597, 'Tapas & Beijos S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67259, 4597, 'Tapas & Beijos S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67260, 4597, 'Tapas & Beijos S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67261, 4597, 'Tapas & Beijos S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67262, 4597, 'Tapas & Beijos S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67263, 4597, 'Tapas & Beijos S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67264, 4597, 'Tapas & Beijos S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/160523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67265, 4597, 'Tapas & Beijos S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/160524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67266, 4597, 'Tapas & Beijos S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/160525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67267, 4597, 'Tapas & Beijos S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/160526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67268, 4597, 'Tapas & Beijos S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/160527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67269, 4597, 'Tapas & Beijos S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/160528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67270, 4597, 'Tapas & Beijos S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/160529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67271, 4597, 'Tapas & Beijos S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/160530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67272, 4597, 'Tapas & Beijos S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/160531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67273, 4597, 'Tapas & Beijos S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/160532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67274, 4597, 'Tapas & Beijos S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/160533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67275, 4597, 'Tapas & Beijos S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/160534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67276, 4597, 'Tapas & Beijos S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/160535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67277, 4597, 'Tapas & Beijos S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/160536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67278, 4598, 'Tapas & Beijos S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67279, 4598, 'Tapas & Beijos S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67280, 4598, 'Tapas & Beijos S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67281, 4598, 'Tapas & Beijos S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67282, 4598, 'Tapas & Beijos S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67283, 4598, 'Tapas & Beijos S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67284, 4598, 'Tapas & Beijos S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67285, 4598, 'Tapas & Beijos S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67286, 4598, 'Tapas & Beijos S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67287, 4598, 'Tapas & Beijos S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67288, 4598, 'Tapas & Beijos S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67289, 4598, 'Tapas & Beijos S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67290, 4598, 'Tapas & Beijos S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67291, 4598, 'Tapas & Beijos S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67292, 4598, 'Tapas & Beijos S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67293, 4598, 'Tapas & Beijos S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67294, 4598, 'Tapas & Beijos S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67295, 4598, 'Tapas & Beijos S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67296, 4598, 'Tapas & Beijos S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67297, 4598, 'Tapas & Beijos S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67298, 4598, 'Tapas & Beijos S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67299, 4598, 'Tapas & Beijos S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eiN4I8sN5BvptOy7CJ8qvl2JHAI.jpg'),
(67300, 4599, 'The Cleveland Show S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gRC4zWllPgPCTCbMmYJl7KsTxXJ.jpg'),
(67301, 4599, 'The Cleveland Show S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYxZ0yaN5eSKosD9vBywKOsQmlF.jpg'),
(67302, 4599, 'The Cleveland Show S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8MU8Kk08Dihhrax1dwnooCEg341.jpg'),
(67303, 4599, 'The Cleveland Show S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oApYgsvSZw3MrfskLgG2OoSlpne.jpg'),
(67304, 4599, 'The Cleveland Show S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xjU1nnaCkN0vC46CwTLeeL3h9Fa.jpg'),
(67305, 4599, 'The Cleveland Show S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rd2w0nWmaL1qqWI23T2Bd1q3J9H.jpg'),
(67306, 4599, 'The Cleveland Show S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1IfhUAOk29jAYsIbkkAhvCWhKew.jpg'),
(67307, 4599, 'The Cleveland Show S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iS5acKlcXQQXg6UM29YtlJd5Wbp.jpg'),
(67308, 4599, 'The Cleveland Show S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qFHOAxcc8WSAdJV84B9TBYJJ2re.jpg'),
(67309, 4599, 'The Cleveland Show S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iztOBCMoYZgg7I4GuqEsei3BCyY.jpg'),
(67310, 4599, 'The Cleveland Show S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3NEMFEsL2nekluAvB7ODMkxt9Xs.jpg'),
(67311, 4599, 'The Cleveland Show S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xaXo8y8EPPNMTqO8JnUi2GOqnKC.jpg'),
(67312, 4599, 'The Cleveland Show S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/51c8RM7upqdqaPUnoskZUyCVpH9.jpg'),
(67313, 4599, 'The Cleveland Show S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dszeEfU8IsbSN35No1sy9bYJM29.jpg'),
(67314, 4599, 'The Cleveland Show S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/poAJupCZSMyVEp8f1cTIVtKm6Na.jpg'),
(67315, 4599, 'The Cleveland Show S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ahy2aJ5Ep5keLPeraQgDfzIR4Xf.jpg'),
(67316, 4599, 'The Cleveland Show S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jQJKMAxujIedogC4JCmYN6qvBBB.jpg'),
(67317, 4599, 'The Cleveland Show S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9AzX1M5m2c5Y3onPJpeykjI6hZt.jpg'),
(67318, 4599, 'The Cleveland Show S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zXHiA2QNyBLYVT8eBYMeGXRMQlu.jpg'),
(67319, 4599, 'The Cleveland Show S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aLhtPPLxVgRSzBNTkFCfm0MiqUO.jpg'),
(67320, 4599, 'The Cleveland Show S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fly0EzU3D7GeGodKsmU0lNQjuiK.jpg'),
(67321, 4600, 'The Cleveland Show S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fVDu2YTFEByDpnOnDQWikXaahw2.jpg'),
(67322, 4600, 'The Cleveland Show S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDhwPdHcXYPDHWzG3i4ogKYTDko.jpg'),
(67323, 4600, 'The Cleveland Show S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6bdqW5jhwu1zM746YaaYMg1awBP.jpg'),
(67324, 4600, 'The Cleveland Show S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/enJpvlBtwg6fFeFuDUHYqMKqGLN.jpg'),
(67325, 4600, 'The Cleveland Show S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jenHTUJSr7SsiRHLYinjhXA26cc.jpg'),
(67326, 4600, 'The Cleveland Show S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2gE4YtT4gP7FUWApmfetVxVTYiq.jpg'),
(67327, 4600, 'The Cleveland Show S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vPLoTmh3b797MChEvVStU9xFMGF.jpg'),
(67328, 4600, 'The Cleveland Show S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g9vstF4pIOI7Pq94fORhiGvfLtA.jpg'),
(67329, 4600, 'The Cleveland Show S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEq3PE5D6PPmZPnATi1b7TkeLK1.jpg'),
(67330, 4600, 'The Cleveland Show S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iqLXzfpi2FGakNMGv5ytbUSW7dZ.jpg'),
(67331, 4600, 'The Cleveland Show S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/42gzRQdAIN9l22wLqY37TLSTrr5.jpg'),
(67332, 4600, 'The Cleveland Show S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ppio3B3WnoDRC42EBui4bxCGCUB.jpg'),
(67333, 4600, 'The Cleveland Show S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/quwarrlVNqMgEtJwaxyrgUn7T1J.jpg'),
(67334, 4600, 'The Cleveland Show S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9B6nCroWQFPDARcgS7t3NmRtOIn.jpg'),
(67335, 4600, 'The Cleveland Show S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mPyuhZFPiLpLobCQteOY4YfDaCF.jpg'),
(67336, 4600, 'The Cleveland Show S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lEGTVMhzxUezLYh0bVmhbsiMmZW.jpg'),
(67337, 4600, 'The Cleveland Show S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x6INaGzUDXvMchmBUkBqrmNbShM.jpg'),
(67338, 4600, 'The Cleveland Show S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gdLBftiiE91trqqwKTgAkReMQzh.jpg'),
(67339, 4600, 'The Cleveland Show S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yyeMwbgHs8PyPyNDbp1BOUCcKb8.jpg'),
(67340, 4600, 'The Cleveland Show S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hON5tUaOMi22mLjs8F9TCAzHXg1.jpg'),
(67341, 4600, 'The Cleveland Show S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dw6DnsBjnLtrsFBa8oABx4Sh13t.jpg'),
(67342, 4600, 'The Cleveland Show S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tv5EbPLMlD6TTWqsFB0luPlZDHS.jpg'),
(67343, 4601, 'The Cleveland Show S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/owO43DOTgkGyXVwUm2qehQmNeZS.jpg'),
(67344, 4601, 'The Cleveland Show S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6xHBSOI8cAdEUJOwKM9jZ33M79D.jpg'),
(67345, 4601, 'The Cleveland Show S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hVBnDafzj8zFW6HOrppbhjvuK2W.jpg'),
(67346, 4601, 'The Cleveland Show S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iCO4H2YDgGZ80TkYLtNq40ouEHM.jpg'),
(67347, 4601, 'The Cleveland Show S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iYAivCw5UG82DqRSBRdAWD0NwBn.jpg'),
(67348, 4601, 'The Cleveland Show S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o8Td44uqRSkZJTb96dOXTgGYnWQ.jpg'),
(67349, 4601, 'The Cleveland Show S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3gHJtJbTHZwlTLEEN6UJ9IZjqQH.jpg'),
(67350, 4601, 'The Cleveland Show S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4xVHuFFLc2IoIIa9apDUAVRWkid.jpg'),
(67351, 4601, 'The Cleveland Show S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rFqOjfHGbr9B5Spg6MsFKu6XvXA.jpg'),
(67352, 4601, 'The Cleveland Show S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2StX9J4dBBypmV0ZElHffpJULDx.jpg'),
(67353, 4601, 'The Cleveland Show S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kyp5yix7e13BsO55HtNSbl7zjvc.jpg'),
(67354, 4601, 'The Cleveland Show S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCfdnaMWEypSXz9iOQe2UCsBdC2.jpg'),
(67355, 4601, 'The Cleveland Show S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eFWj7jgvXi0izlY2ssm9TCLns2l.jpg'),
(67356, 4601, 'The Cleveland Show S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zwcPdHy5lOnEwXDz31KgojJUnWG.jpg'),
(67357, 4601, 'The Cleveland Show S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c7uevcqK4b3EQWat90j0aDFOlK8.jpg'),
(67358, 4601, 'The Cleveland Show S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ppGjZL3yKVvXF2fj3MndmMHq7sP.jpg'),
(67359, 4601, 'The Cleveland Show S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pbKQAzoO5xxEo8yrCiptLYWulPT.jpg'),
(67360, 4601, 'The Cleveland Show S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AwcmP11uoimoJlO7wNJpD8g82GN.jpg'),
(67361, 4601, 'The Cleveland Show S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8FVNqQiidYAL3hSBmooabmgJBHe.jpg'),
(67362, 4601, 'The Cleveland Show S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hkpbtoFE15gsyAdTepnm1LK5KMh.jpg'),
(67363, 4601, 'The Cleveland Show S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uyZwQ3TAoZLoPgyDu8cHqaVRB18.jpg'),
(67364, 4601, 'The Cleveland Show S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yAHA4CNjBuFzwpPqj4LcaMS3Aoy.jpg'),
(67365, 4602, 'The Cleveland Show S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3NCQ6pLlsis525v5XnYraZM3TPY.jpg'),
(67366, 4602, 'The Cleveland Show S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3doRWVIWKCOpvrdtSVurphELQzl.jpg'),
(67367, 4602, 'The Cleveland Show S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xSW7u8uLIhWzc0hFiI7OtNLilAq.jpg'),
(67368, 4602, 'The Cleveland Show S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11bJbQ88cbncFzuUtOeSZF215b2.jpg'),
(67369, 4602, 'The Cleveland Show S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nH5GgYRRv3nsA2Mbpx7wzzHEogD.jpg'),
(67370, 4602, 'The Cleveland Show S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uDXwKpeoYfEz6tIWhxLOhhfeCsi.jpg'),
(67371, 4602, 'The Cleveland Show S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3h7RVsalgmTEcTffwxgdflV4duq.jpg'),
(67372, 4602, 'The Cleveland Show S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMzkYRD2jhXuYHktxcF4ZQY0vcc.jpg'),
(67373, 4602, 'The Cleveland Show S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gthC1yu5gn1Xksh40T0tctnOQgu.jpg'),
(67374, 4602, 'The Cleveland Show S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rUwELqrp9BxWF1O7uIhCTIYPoXe.jpg'),
(67375, 4602, 'The Cleveland Show S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lu7lTTLZgyLyPbIEykgEew4HSQc.jpg'),
(67376, 4602, 'The Cleveland Show S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AgcPLWycbpExuvUqeH6FdYQPF2u.jpg'),
(67377, 4602, 'The Cleveland Show S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/og2dk5yvdlVLV0wea6KTeIjkd6O.jpg'),
(67378, 4602, 'The Cleveland Show S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Tjr6Rr0o6ivlsOiLB4MS5QP8ou.jpg'),
(67379, 4602, 'The Cleveland Show S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3kwmfSXbH7waWvdZvqHD9MXErsx.jpg'),
(67380, 4602, 'The Cleveland Show S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7oe6fAwRWGl34x0PmFUwFfet7ua.jpg'),
(67381, 4602, 'The Cleveland Show S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tH5jq8n2NXZBkfnL6sD2ELxrI8R.jpg'),
(67382, 4602, 'The Cleveland Show S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2urCaIeGAXRGPqBNyrUbI4dJmZ.jpg'),
(67383, 4602, 'The Cleveland Show S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3GYUw1cRb42x6cgM4t7mp2PNd87.jpg'),
(67384, 4602, 'The Cleveland Show S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/da5ZtZDtHronINB2wEDVGZ4S3UC.jpg'),
(67385, 4602, 'The Cleveland Show S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uYnoXbvzNyGq0CP2Fg96HtzYFWo.jpg'),
(67386, 4602, 'The Cleveland Show S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kpzaiw6tQ9KzZC1vHUFwRWCHiNv.jpg'),
(67387, 4602, 'The Cleveland Show S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/160389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBGAZvmRH4usBuDMJlmr6Fa0USo.jpg'),
(67388, 4603, 'The Last Journey of The Vikings [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3W1dZ1Qg6YHMKo8WI8RLr1NlE53.jpg'),
(67389, 4603, 'The Last Journey of The Vikings [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3W1dZ1Qg6YHMKo8WI8RLr1NlE53.jpg'),
(67390, 4603, 'The Last Journey of The Vikings [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3W1dZ1Qg6YHMKo8WI8RLr1NlE53.jpg'),
(67391, 4603, 'The Last Journey of The Vikings [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3W1dZ1Qg6YHMKo8WI8RLr1NlE53.jpg'),
(67392, 4604, 'Mary & Mike S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vQwj6i9bZKpZilP5gLz8f8epXyx.jpg'),
(67393, 4604, 'Mary & Mike S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3673d3ZtB3f3gmDpaqzuW2zhHNN.jpg'),
(67394, 4604, 'Mary & Mike S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/avHszwngi6u0NQIjtuHSRmQss1e.jpg'),
(67395, 4604, 'Mary & Mike S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eU2735Fv05njBLlBVK8ADakY1V1.jpg'),
(67396, 4604, 'Mary & Mike S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A21EM8gUEJ9S4HyPDHe0Loht4lg.jpg'),
(67397, 4604, 'Mary & Mike S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yuuybhCsUjmOMGKcn4NpYUBZNxQ.jpg'),
(67398, 4605, 'Minta Comigo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bTfWQMECcj3OvyBVYOvBOclM0hP.jpg'),
(67399, 4605, 'Minta Comigo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1rjli34zvl2w4QaRT6cW93jixZU.jpg'),
(67400, 4605, 'Minta Comigo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Wq7fb6vv0nIsQTD2pN5pXF5iXq.jpg'),
(67401, 4605, 'Minta Comigo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3vR0HncJOSsYgsvCk8OZF5tmlK.jpg'),
(67402, 4606, 'O Mistério das Mortes de Burari S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wE6xyAgGocd3KiWfnOJgyBvQEoP.jpg'),
(67403, 4606, 'O Mistério das Mortes de Burari S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s59kq7JffooNX87e2BYQQQq24Xf.jpg'),
(67404, 4606, 'O Mistério das Mortes de Burari S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4MSNjYuVLnM676cTLyk8HXy0fjv.jpg'),
(67405, 4607, 'Breaking Bad: A Química do Mal [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ydlY3iPfeOAvu8gVqrxPoMvzNCn.jpg'),
(67406, 4607, 'Breaking Bad: A Química do Mal [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjDNvbokPLtEnpFyFPyXMOd6Zr1.jpg'),
(67407, 4607, 'Breaking Bad: A Química do Mal [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2kBeBlxGqBOdWlKwzAxiwkfU5on.jpg'),
(67408, 4607, 'Breaking Bad: A Química do Mal [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i5BAJVhuIWfkoSqDID6FnQNCTVc.jpg'),
(67409, 4607, 'Breaking Bad: A Química do Mal [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/82G3wZgEvZLKcte6yoZJahUWBtx.jpg'),
(67410, 4607, 'Breaking Bad: A Química do Mal [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hyYwqbmcHn3fuxWE3h4IhZZbkU3.jpg'),
(67411, 4607, 'Breaking Bad: A Química do Mal [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1dgFAsajUpUT7DLXgAxHb9GyXHH.jpg'),
(67412, 4608, 'Breaking Bad: A Química do Mal [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7vVujNqjP23MtPqUTBNITIW3DDA.jpg'),
(67413, 4608, 'Breaking Bad: A Química do Mal [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vWcFcwMUfeBN8FZEdSSPHGQYrna.jpg'),
(67414, 4608, 'Breaking Bad: A Química do Mal [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p69fPkpnnxUmevhupJiDeYfQxxl.jpg'),
(67415, 4608, 'Breaking Bad: A Química do Mal [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9xi18yhtCLrrJ2plZjXgfGqeTjU.jpg'),
(67416, 4608, 'Breaking Bad: A Química do Mal [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k3qcDOGo6C39EsUBYdS3RsT3TkI.jpg'),
(67417, 4608, 'Breaking Bad: A Química do Mal [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/avu1h4hzWumE9B0nTo14Lfp4E9i.jpg'),
(67418, 4608, 'Breaking Bad: A Química do Mal [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ng5NKNLM3mEUxHKN3Ava1PcZhSs.jpg'),
(67419, 4608, 'Breaking Bad: A Química do Mal [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/itKNfQ3Nm6Qkjdp0hew5jvqbB8p.jpg'),
(67420, 4608, 'Breaking Bad: A Química do Mal [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j92CoMwArTeQwnGVl12SJaKlI0J.jpg'),
(67421, 4608, 'Breaking Bad: A Química do Mal [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qJvm57aPMMEraJ62bDb79O0XXG9.jpg'),
(67422, 4608, 'Breaking Bad: A Química do Mal [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yeQAQsV4WPTmKWTyuDhF3DAna1x.jpg'),
(67423, 4608, 'Breaking Bad: A Química do Mal [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2fzm9JKgaLPL2U01xROTpBXE4m.jpg'),
(67424, 4608, 'Breaking Bad: A Química do Mal [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xdSWJjptnLAvFnh5Is6iJPlH1ds.jpg'),
(67425, 4609, 'Breaking Bad: A Química do Mal [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDigUBnlR20e3xItmW3foEIRzCD.jpg'),
(67426, 4609, 'Breaking Bad: A Química do Mal [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h3k5PoJ0RuKBH7OLnT8IbcFWz80.jpg'),
(67427, 4609, 'Breaking Bad: A Química do Mal [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jH2nkMFxuX5tXc832jyDNU4AjKq.jpg'),
(67428, 4609, 'Breaking Bad: A Química do Mal [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Se5PpvIgUey9MgXmrKkgO8HVye.jpg'),
(67429, 4609, 'Breaking Bad: A Química do Mal [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2cipfAKEdLR4MIZKA3EiOcTYiZ.jpg'),
(67430, 4609, 'Breaking Bad: A Química do Mal [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sl5zRr0u0kYcIyCdQjOTsexq4bL.jpg'),
(67431, 4609, 'Breaking Bad: A Química do Mal [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AoRbX7ezyWTA6kADtQlL4cyRuLd.jpg'),
(67432, 4609, 'Breaking Bad: A Química do Mal [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/edBDR59bzVWdMtCawimRzOMgrlW.jpg'),
(67433, 4609, 'Breaking Bad: A Química do Mal [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zfUECD3RhKQ72cXE3JZTpPW5lEL.jpg'),
(67434, 4609, 'Breaking Bad: A Química do Mal [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qbS9P6UvZXdiF9SEhEdDuYakXDz.jpg'),
(67435, 4609, 'Breaking Bad: A Química do Mal [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/SaUy7OBZCKDuHWSHxf4lIfwySR.jpg'),
(67436, 4609, 'Breaking Bad: A Química do Mal [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eO3zAuQzIU6yCLrr2GUh8943jyr.jpg'),
(67437, 4609, 'Breaking Bad: A Química do Mal [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mDUs18asTVVfqd56scRQ7W9r781.jpg'),
(67438, 4610, 'Breaking Bad: A Química do Mal [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2g6dLvOrLE7tpJatonCchLDkDyF.jpg'),
(67439, 4610, 'Breaking Bad: A Química do Mal [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ozWpAgU14sMmjliqPtBG5gN0yJd.jpg'),
(67440, 4610, 'Breaking Bad: A Química do Mal [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ac0wu93r4LaZk07wa7PiWpNOOru.jpg'),
(67441, 4610, 'Breaking Bad: A Química do Mal [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1yxpr4hff0HpblG9ZW5DQQbImQ2.jpg'),
(67442, 4610, 'Breaking Bad: A Química do Mal [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fG0B2tcRYR60JzmKaPUGl8RYDrq.jpg'),
(67443, 4610, 'Breaking Bad: A Química do Mal [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9noIu7JCbpfNrENPD3G2qeylllC.jpg'),
(67444, 4610, 'Breaking Bad: A Química do Mal [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/duDEbjD1ZCs1eH74QkzJhSSwNLk.jpg'),
(67445, 4610, 'Breaking Bad: A Química do Mal [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kWtsoaPAdfPXEfqufwA44tr9bp6.jpg'),
(67446, 4610, 'Breaking Bad: A Química do Mal [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qvwD4XVrL1nQO1CjWAFEuF6Dv8V.jpg'),
(67447, 4610, 'Breaking Bad: A Química do Mal [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bo5DfMtWPaNYhw7OIUkk9MLal7S.jpg'),
(67448, 4610, 'Breaking Bad: A Química do Mal [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xMR8o7N4ZBacim1druJ6PanTlPQ.jpg'),
(67449, 4610, 'Breaking Bad: A Química do Mal [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFdRtTqVsQBCp24B7CHue423StJ.jpg'),
(67450, 4610, 'Breaking Bad: A Química do Mal [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nu1DTIu2EqiKsODpMYGSrkXSKMy.jpg'),
(67451, 4611, 'Breaking Bad: A Química do Mal [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uShB5dWoA3xIivZ9jvwWnGCVvt4.jpg'),
(67452, 4611, 'Breaking Bad: A Química do Mal [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gf7ipzUCJq20Oxrt3aOafUrjgFU.jpg'),
(67453, 4611, 'Breaking Bad: A Química do Mal [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l84H1dZVkQGgFVomKHc67RKaEC2.jpg'),
(67454, 4611, 'Breaking Bad: A Química do Mal [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vH91E7z5Ma5yLOoi5xU5x6Bcos3.jpg'),
(67455, 4611, 'Breaking Bad: A Química do Mal [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dbIuVQUxCZakcWbDNknPfaCxZAI.jpg'),
(67456, 4611, 'Breaking Bad: A Química do Mal [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vleQ03cr0fb5DBmvLY0WGxfs8wj.jpg'),
(67457, 4611, 'Breaking Bad: A Química do Mal [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2NA7ti9jsWnG4xreMEFwbq4DH1f.jpg'),
(67458, 4611, 'Breaking Bad: A Química do Mal [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uTAPBgAah14jQbV98Sw7iqJD4W7.jpg'),
(67459, 4611, 'Breaking Bad: A Química do Mal [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jKohdOg1yVjXNNyxbAGX27vchIq.jpg'),
(67460, 4611, 'Breaking Bad: A Química do Mal [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0aRvTXslQgJpCmmcmoYqS9MsIB.jpg'),
(67461, 4611, 'Breaking Bad: A Química do Mal [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/75lrTEzbUh4iZlMs0aN4mKisD4C.jpg'),
(67462, 4611, 'Breaking Bad: A Química do Mal [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5VkI8lm7Xcmlxk92pWRyW341d70.jpg'),
(67463, 4611, 'Breaking Bad: A Química do Mal [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z2E4Rq7D5TmAdzS9D6Wije3sGI3.jpg'),
(67464, 4611, 'Breaking Bad: A Química do Mal [L] S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s9QORY5rrwzQpTCTgNdBRyKehtL.jpg'),
(67465, 4611, 'Breaking Bad: A Química do Mal [L] S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yxldDE4a2NZa9vrBWvTa9OAZpVc.jpg'),
(67466, 4611, 'Breaking Bad: A Química do Mal [L] S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pA0YwyhvdDXP3BEGL2grrIhq8aM.jpg'),
(67467, 4612, 'Sobrenatural [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nGUD5H2wU7bYBqpqDPTybTWunrR.jpg'),
(67468, 4612, 'Sobrenatural [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9SsuC4koeryryoUNgnQYAwkKGAV.jpg'),
(67469, 4612, 'Sobrenatural [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sNMPGr6wOY0K8ryzU78Z4YbHWgg.jpg'),
(67470, 4612, 'Sobrenatural [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBYBulN95fJLOP5lixXoIMIE4F.jpg'),
(67471, 4612, 'Sobrenatural [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jUZ8ni4qGRV2cOcZpjLnlC4luyj.jpg'),
(67472, 4612, 'Sobrenatural [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fyCKr3B3nJejxnKsp2cOk5aOjZG.jpg'),
(67473, 4612, 'Sobrenatural [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/162949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iBMkAHb3PaMmTCaorSAKJVoIsio.jpg'),
(67474, 4612, 'Sobrenatural [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/162950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Li4EY0ccNPyCwKmPBQ4NavS8fe.jpg'),
(67475, 4612, 'Sobrenatural [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/162951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jeOq4SZVtEK1wgwZvmGApvT76xC.jpg'),
(67476, 4612, 'Sobrenatural [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/162952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nKtUaiCz9K6kh0PQlb22VvfyrdH.jpg'),
(67477, 4612, 'Sobrenatural [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/162953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oolec0MS18b2PhBlT3BGiKsXCQs.jpg'),
(67478, 4612, 'Sobrenatural [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/162954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/FwKYN4eAgBdtNXw3gMANIlglL6.jpg'),
(67479, 4612, 'Sobrenatural [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/162955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nVP1dEu0xSw4fV5jwlizE0dCXTP.jpg'),
(67480, 4612, 'Sobrenatural [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/162956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8oh7cOoBqZDSVgJOH3K8euALHzj.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(67481, 4612, 'Sobrenatural [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/162957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fA9X8nyIxNFqMGfCRsHWv8de0wh.jpg'),
(67482, 4612, 'Sobrenatural [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/162958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7bXHOxR6IRvUDiUJ4brZaugihMl.jpg'),
(67483, 4612, 'Sobrenatural [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/162959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5UDwyjNnus6MMCBEn5ZMCVKYMP6.jpg'),
(67484, 4612, 'Sobrenatural [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/162960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hj8SJmZUFKKn0AHfeiy4BuidO2w.jpg'),
(67485, 4612, 'Sobrenatural [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/162961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1LLOdZUxTP47Vb9Ye2sqo31cRv9.jpg'),
(67486, 4612, 'Sobrenatural [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/162962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fm2weYzFs2PFYlMyldjo0hSAS6k.jpg'),
(67487, 4612, 'Sobrenatural [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/162963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5XDZhKseFBfvOfJ7SL8C2td0yL.jpg'),
(67488, 4612, 'Sobrenatural [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/162964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zFTdWTX0D2orgTPkPz0ITymiZ8A.jpg'),
(67489, 4613, 'Sobrenatural [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7piX0XC1XBI1HT2Oy5yODkttHTL.jpg'),
(67490, 4613, 'Sobrenatural [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/48rq4jhuFIXd7WvFxQ9zZzsTuIr.jpg'),
(67491, 4613, 'Sobrenatural [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e7citrj6ZFHv6xXhCtKrrEkogeI.jpg'),
(67492, 4613, 'Sobrenatural [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lQAGfQL81Oidq7oRuYLotdLRsHa.jpg'),
(67493, 4613, 'Sobrenatural [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kOvCHuvW8KHf6WBEX8dAIYCi8sp.jpg'),
(67494, 4613, 'Sobrenatural [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xmPI86n8Ch6uT19u78V6fBNJv3A.jpg'),
(67495, 4613, 'Sobrenatural [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/162971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/FXjhHxBAUD32guOsldk98fBRVa.jpg'),
(67496, 4613, 'Sobrenatural [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/162972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i5fLVXPjIOPiK0mzHQ6qeoHztgN.jpg'),
(67497, 4613, 'Sobrenatural [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/162973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/doyUNeP4ApJDm03g8OduOWAXDk5.jpg'),
(67498, 4613, 'Sobrenatural [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/162974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4YxF2DoLb1PQ6c03h2v8brsmFSq.jpg'),
(67499, 4613, 'Sobrenatural [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/162975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eVvMgdpST9VgcjpvV7U0Z7lCZAW.jpg'),
(67500, 4613, 'Sobrenatural [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/162976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t3YzNnMnVm1tprvZcbqetNkgvlQ.jpg'),
(67501, 4613, 'Sobrenatural [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/162977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2DVBbVZQEEtleV7rwutXhiv8n0O.jpg'),
(67502, 4613, 'Sobrenatural [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/162978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tf0rFhJdsIU3a26m4rJgTBB5qQO.jpg'),
(67503, 4613, 'Sobrenatural [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/162979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCud2WAqclfTw2zGyHh665qDuWZ.jpg'),
(67504, 4613, 'Sobrenatural [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/162980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lM7rteSY9hXUmlM4rPmCrJ8XVbT.jpg'),
(67505, 4613, 'Sobrenatural [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/162981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWd7ia97zKyxeQNxzXL2FhEzrOJ.jpg'),
(67506, 4613, 'Sobrenatural [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/162982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AqzN3cLSs2cfLwYK5XoFD1jbXx0.jpg'),
(67507, 4613, 'Sobrenatural [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/162983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6krWeBzF4VnXyrlfv65CqYzEYuz.jpg'),
(67508, 4613, 'Sobrenatural [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/162984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bB3PZ6JwmyGTri6lLhJWyzK7XHK.jpg'),
(67509, 4613, 'Sobrenatural [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/162985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qf6LWrMZ819qZLSII6pDMCro5sH.jpg'),
(67510, 4613, 'Sobrenatural [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/162986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yO1ffOU0rxca1ZvcsGhAWuWkWou.jpg'),
(67511, 4614, 'Sobrenatural [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2SUb37U6g54dCBsspblgTM6YcR7.jpg'),
(67512, 4614, 'Sobrenatural [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eC0suKIchk9ACQpAmP2eRAxfUNR.jpg'),
(67513, 4614, 'Sobrenatural [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/EESdOeKac6FZa792fD41HIDLW9.jpg'),
(67514, 4614, 'Sobrenatural [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Ft0MNXtjLKvDlfJKZ64YeWTrGO.jpg'),
(67515, 4614, 'Sobrenatural [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xv0Eb9OaL1CgT1mQN8HJUHQUVRF.jpg'),
(67516, 4614, 'Sobrenatural [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wEamrhMwVZ66PVraDiz7IUnX1aN.jpg'),
(67517, 4614, 'Sobrenatural [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/162993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t92hq7AK5egv1ZYVwv7o1NxUDZ0.jpg'),
(67518, 4614, 'Sobrenatural [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/162994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bkXijc5t4FNaPu9tAuoY3t4FsOK.jpg'),
(67519, 4614, 'Sobrenatural [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/162995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sE5l8x1pnWKY5KTCaOuI7zJCX2Q.jpg'),
(67520, 4614, 'Sobrenatural [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/162996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5187ehizxyyD5ZgFnPmeS7FMza0.jpg'),
(67521, 4614, 'Sobrenatural [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/162997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rn7s7Tc5tnlnOGB38Tafn1lF7qB.jpg'),
(67522, 4614, 'Sobrenatural [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/162998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bNCl1Lfh1OulCfdiC1JvPNh3a8W.jpg'),
(67523, 4614, 'Sobrenatural [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/162999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ilBZzbPRQAewweUuMYC8m40LXTy.jpg'),
(67524, 4614, 'Sobrenatural [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pUG7nFN5SoNoNh4P5Aadny2ksU9.jpg'),
(67525, 4614, 'Sobrenatural [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mD3rsYMBvL5VRUqAiffHa7RUgi0.jpg'),
(67526, 4614, 'Sobrenatural [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/strQlXZst5hWpNSd6KmuUjdeHUQ.jpg'),
(67527, 4615, 'Sobrenatural [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aRQe9Zcu1PUZwhUFb9zFuH8TbQ3.jpg'),
(67528, 4615, 'Sobrenatural [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJL9tnfa6nmYGilbEbqBxCGSds6.jpg'),
(67529, 4615, 'Sobrenatural [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y6j0ysz5FYjfJhl7l8IFBak2mBs.jpg'),
(67530, 4615, 'Sobrenatural [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lVhs82keFW6ijDErlSG6XD5n9f1.jpg'),
(67531, 4615, 'Sobrenatural [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nQWwxx7O3g45f5Cqb6g3ZVNwofz.jpg'),
(67532, 4615, 'Sobrenatural [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/meJqu1QlTNOdc5zlFXyO88lEeaL.jpg'),
(67533, 4615, 'Sobrenatural [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iQpGVcgG2ooorTmks0fMPhQP6Nl.jpg'),
(67534, 4615, 'Sobrenatural [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e8xpnJZYkMDVmjIj7jVV0idb6vx.jpg'),
(67535, 4615, 'Sobrenatural [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i7V5U8oWw71DLP7CMBQMwIactov.jpg'),
(67536, 4615, 'Sobrenatural [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pePXMvdasG5ATYTXHW0tIPGtbhA.jpg'),
(67537, 4615, 'Sobrenatural [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMDQqN7KIERCdgMV2wcy17FcMBe.jpg'),
(67538, 4615, 'Sobrenatural [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2dT1aBx9kJPd3Ekkmwu4QPRTOvt.jpg'),
(67539, 4615, 'Sobrenatural [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w9p7z8B3mccqM6gOCqLiFBbRORF.jpg'),
(67540, 4615, 'Sobrenatural [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kGNDO9wtCxFXvykL9ZttFo3IY8X.jpg'),
(67541, 4615, 'Sobrenatural [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iyNE7NjyYftDrAZP03f5FgZI7N9.jpg'),
(67542, 4615, 'Sobrenatural [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r4DESZDYV372UJhwkKLdgVRVuXw.jpg'),
(67543, 4615, 'Sobrenatural [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Ur4sC3hnBQImxiyhI3uTjeoiG9.jpg'),
(67544, 4615, 'Sobrenatural [L] S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rp3992eCMZlN8Ydv6lghXvK074X.jpg'),
(67545, 4615, 'Sobrenatural [L] S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e9cYV8mXhmHwX5tfxsOMDaVuexj.jpg'),
(67546, 4615, 'Sobrenatural [L] S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ae3zStFwcnLenyly2zyav8hrlZe.jpg'),
(67547, 4615, 'Sobrenatural [L] S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/163023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/irwkKlgAUw03iGX98S3KSH8N4lh.jpg'),
(67548, 4615, 'Sobrenatural [L] S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/163024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jM8JbXHdi2dZTZxOpKNC1gmkVk3.jpg'),
(67549, 4616, 'Sobrenatural [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z3NlH5V5mHJq64DEUv6HgCs8Q3L.jpg'),
(67550, 4616, 'Sobrenatural [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zbg59Zmvi4Xq9C9LHlQB0ycXqY4.jpg'),
(67551, 4616, 'Sobrenatural [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wdHktf8ZJzfD90GzgxfYgVQaVYi.jpg'),
(67552, 4616, 'Sobrenatural [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qxeXaPFRbKekNwCQ9EEQRkJVjGV.jpg'),
(67553, 4616, 'Sobrenatural [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xuXTS1duu6SoMDT9aOCiwyb5z0l.jpg'),
(67554, 4616, 'Sobrenatural [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/urp4CiPRizT5J9Te9LebqygYBf2.jpg'),
(67555, 4616, 'Sobrenatural [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bFdS6TBqWiqMfWQV2yCaAlhVXGs.jpg'),
(67556, 4616, 'Sobrenatural [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/usvIzJkllJnXiXVYwo7FrjeYpkH.jpg'),
(67557, 4616, 'Sobrenatural [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m355bMYt9xXYZ1E6iYqiBZG5S03.jpg'),
(67558, 4616, 'Sobrenatural [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zoQuRWQYWuYWzyLkBASkJBpIBhn.jpg'),
(67559, 4616, 'Sobrenatural [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wi4fRvxKGLV0xQk7GlPNMRy9td0.jpg'),
(67560, 4616, 'Sobrenatural [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nF4jsjW2IgWhzCY8rypCJM2oymB.jpg'),
(67561, 4616, 'Sobrenatural [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1I0PY0ohOio8jwnsHmK8yOoZ7P.jpg'),
(67562, 4616, 'Sobrenatural [L] S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/grQZ5hbyUfmIpFHfau5UOPkqaM8.jpg'),
(67563, 4616, 'Sobrenatural [L] S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/agfAeeU0v8vOmpS5ah0twWPX5hG.jpg'),
(67564, 4616, 'Sobrenatural [L] S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fkyumgRMt9eXkE5j6Xmn92gyJRc.jpg'),
(67565, 4616, 'Sobrenatural [L] S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y4vuqoeu26fSUC3lO7B08UxDdZM.jpg'),
(67566, 4616, 'Sobrenatural [L] S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6DjJfadh9oYWdNl3kxEAvB3nWV2.jpg'),
(67567, 4616, 'Sobrenatural [L] S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xFOUg92GOUKvL5ZO8XONCVQo01K.jpg'),
(67568, 4616, 'Sobrenatural [L] S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8PGSyQUTF6yPfNza2WyW28mZ8sf.jpg'),
(67569, 4616, 'Sobrenatural [L] S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/163045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yqw0x6CftJt480u9HSXhIgVAn7k.jpg'),
(67570, 4616, 'Sobrenatural [L] S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/163046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tUbTbLw8kjYT8qTARN1z7C294id.jpg'),
(67571, 4617, 'Sobrenatural [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/42XjNVTdladJWBtSn5peAR4GGcl.jpg'),
(67572, 4617, 'Sobrenatural [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8gGq8Kd7Mu75UTq6lETyJpC2F4o.jpg'),
(67573, 4617, 'Sobrenatural [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/knG1A5dVLrHGwbpdnS2PQqyPrz6.jpg'),
(67574, 4617, 'Sobrenatural [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aMSYhwdADlrr7s3Ei39Bux5CB3M.jpg'),
(67575, 4617, 'Sobrenatural [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7GrOA9i8ReonksgNZB5EuCBPH9s.jpg'),
(67576, 4617, 'Sobrenatural [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2g2Ew4iZktsiq5N8eVLkClQR46A.jpg'),
(67577, 4617, 'Sobrenatural [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aph8STLFBFSBkba6yaLtq24dPLB.jpg'),
(67578, 4617, 'Sobrenatural [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Yb6CFruX7jL3fuCbzys0bT11i2.jpg'),
(67579, 4617, 'Sobrenatural [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vIQ5M527YAPaLOm4QdyIPcaQlPI.jpg'),
(67580, 4617, 'Sobrenatural [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wx83fxcEeH9MGsLZSEuqJrPfYyV.jpg'),
(67581, 4617, 'Sobrenatural [L] S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oT8x1r5S5QYGGUNqaZ9IIBS81s2.jpg'),
(67582, 4617, 'Sobrenatural [L] S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8BWXD92id32hAQpqSg2Z8MGiBls.jpg'),
(67583, 4617, 'Sobrenatural [L] S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Z5Yoidc29qWi55vI46HuHHEjom.jpg'),
(67584, 4617, 'Sobrenatural [L] S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uf5N4VK9OJFPR0XF4OshdI9hTTx.jpg'),
(67585, 4617, 'Sobrenatural [L] S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gyUCL26zwN6pluHPw8Cf3wvnLUr.jpg'),
(67586, 4617, 'Sobrenatural [L] S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnP5KNnzhLojzuDYT9vGHkWHnP2.jpg'),
(67587, 4617, 'Sobrenatural [L] S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2hMzLmEWMe7xcAPedtXbg1DF5.jpg'),
(67588, 4617, 'Sobrenatural [L] S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sU1Ns6LP2s6VO3FW9D7K5GAOhdj.jpg'),
(67589, 4617, 'Sobrenatural [L] S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ems2oXgwo9xpbyjCV0D5guuKt0Q.jpg'),
(67590, 4617, 'Sobrenatural [L] S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zkOiHHIQ3WyzItcoIKW3h2xVScq.jpg'),
(67591, 4617, 'Sobrenatural [L] S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/163067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bcLUjpLb9lA54VGazRrqbMQTbL0.jpg'),
(67592, 4617, 'Sobrenatural [L] S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/163068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfoif31k4RGXLtoN5HuZb8Ctl0r.jpg'),
(67593, 4618, 'Sobrenatural [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k96IfYNrybKIMN4rHOD0awVVpbZ.jpg'),
(67594, 4618, 'Sobrenatural [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mcEnoyH1aLuRr36NiujPcNeW1WY.jpg'),
(67595, 4618, 'Sobrenatural [L] S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9awtgqgk1BGIbU0zurOgsZq6GPk.jpg'),
(67596, 4618, 'Sobrenatural [L] S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3RIHs3MfHS2b9jx69nL7gfKpEmB.jpg'),
(67597, 4618, 'Sobrenatural [L] S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yV7HWIhPg2pzNKOAwQ1Kfe1mS45.jpg'),
(67598, 4618, 'Sobrenatural [L] S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vVv1BUxRYreI9NKRmgGu8frgjqt.jpg'),
(67599, 4618, 'Sobrenatural [L] S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oohqDDMe3fW2TAJKQExz8FM1RRq.jpg'),
(67600, 4618, 'Sobrenatural [L] S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AwpwvHyYyP2ABBVhxRfwkZbtxc4.jpg'),
(67601, 4618, 'Sobrenatural [L] S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/27EAXsUzckMPM7fyOyN41oUjTGC.jpg'),
(67602, 4618, 'Sobrenatural [L] S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fsQ7GeSnbtO9M4m5HT1hS3yAHLO.jpg'),
(67603, 4618, 'Sobrenatural [L] S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u8KFsM0A5cEadGoma30AKHtNmVy.jpg'),
(67604, 4618, 'Sobrenatural [L] S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xMGZcJHRAkHmN1R66yigSZjQcG4.jpg'),
(67605, 4618, 'Sobrenatural [L] S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5NXjengE4L4wtihPqygTPEss7yz.jpg'),
(67606, 4618, 'Sobrenatural [L] S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7mZb4muB5x3orDjIDIBaGokKDrO.jpg'),
(67607, 4618, 'Sobrenatural [L] S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zXnR90o7GtyLQjJXwv393i1y7x0.jpg'),
(67608, 4618, 'Sobrenatural [L] S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sIyDmOc51yraPCEGO4OFJEkir4e.jpg'),
(67609, 4618, 'Sobrenatural [L] S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h8Mf2KafoYqwfAcO0GTA0T2rMc1.jpg'),
(67610, 4618, 'Sobrenatural [L] S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3HN3KungWkletGjrZZocOvOm12M.jpg'),
(67611, 4618, 'Sobrenatural [L] S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gtzgxM1IHbWubhZ8PbYvUWRI5z6.jpg'),
(67612, 4618, 'Sobrenatural [L] S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJhKD6pPTW5VII5v2v5CQuvbb05.jpg'),
(67613, 4618, 'Sobrenatural [L] S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/163089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4pK1YTFq1F3TqK5kuC4HD3glgt1.jpg'),
(67614, 4618, 'Sobrenatural [L] S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/163090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mKpQ3E5lzXzKpBCKRLDMSgjAATQ.jpg'),
(67615, 4618, 'Sobrenatural [L] S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/163091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6buPcBOZolekwRnFbwiMsF0NPoy.jpg'),
(67616, 4619, 'Sobrenatural [L] S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sm3cYFZiimCspfwScThtxDSJLA.jpg'),
(67617, 4619, 'Sobrenatural [L] S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQgdJ8VBsyZkWigCJWC4xnz7PoT.jpg'),
(67618, 4619, 'Sobrenatural [L] S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jXXlCIgYVmgb7RsYSbsSL0P5RUh.jpg'),
(67619, 4619, 'Sobrenatural [L] S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g6Ux0sdNQYzDN5fLacomvc6vL4S.jpg'),
(67620, 4619, 'Sobrenatural [L] S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/km81KqRKLNR0PJf19z7iHNkYShJ.jpg'),
(67621, 4619, 'Sobrenatural [L] S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gpwtxPAQDKTLhbKkDLdaQOiFLKc.jpg'),
(67622, 4619, 'Sobrenatural [L] S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5pyjyfQjEay7BPAsNGDPvbARv54.jpg'),
(67623, 4619, 'Sobrenatural [L] S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gauAXS0bJXiFDaaCmXYQIv3exMC.jpg'),
(67624, 4619, 'Sobrenatural [L] S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oIS17PZObrUzz2pKxWyoXcG4BVb.jpg'),
(67625, 4619, 'Sobrenatural [L] S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2QcJJhz2LwYPMaBhizFph8CUAa.jpg'),
(67626, 4619, 'Sobrenatural [L] S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5JDXxZaIJLOfu16MUv5heAfoQuf.jpg'),
(67627, 4619, 'Sobrenatural [L] S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4B6D36FV80GNWBgAvwJJfcIEOqb.jpg'),
(67628, 4619, 'Sobrenatural [L] S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1MkALJ8n3Z1isgMggwnKJtkMeS.jpg'),
(67629, 4619, 'Sobrenatural [L] S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d3RLsrBGr59fQazbmxZYj1YooTT.jpg'),
(67630, 4619, 'Sobrenatural [L] S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3xg3uc1t5S78QcS6nrSwMT1k1sR.jpg'),
(67631, 4619, 'Sobrenatural [L] S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sk1JiXEEWraWPrzrLUvojdwJfY2.jpg'),
(67632, 4619, 'Sobrenatural [L] S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A6I7cm05s0IDaW1mohp8MUsPkFs.jpg'),
(67633, 4619, 'Sobrenatural [L] S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bvDziRPBewfYYPL1vclrRcvidSy.jpg'),
(67634, 4619, 'Sobrenatural [L] S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vxOmu58HLlIuTB81AEXOzP0DtMU.jpg'),
(67635, 4619, 'Sobrenatural [L] S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t0aVl4D3DtODJjCAq8APALJwLDC.jpg'),
(67636, 4619, 'Sobrenatural [L] S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/163112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyKWFDN6RymTMD1fsYC5JiFALEc.jpg'),
(67637, 4619, 'Sobrenatural [L] S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/163113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hAQcwUP8HeX5gNWwV07w9WWsK29.jpg'),
(67638, 4619, 'Sobrenatural [L] S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/163114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9YUVfe5guUUv9EvTZXt3hDf743.jpg'),
(67639, 4620, 'Sobrenatural [L] S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/reLKD5eh5O4fbipDVwcJPvEkvdW.jpg'),
(67640, 4620, 'Sobrenatural [L] S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bEzDP2L6o8RTUD1alZYnqFLDfjW.jpg'),
(67641, 4620, 'Sobrenatural [L] S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zIFT1uSKYkoBILI722X55q49MQI.jpg'),
(67642, 4620, 'Sobrenatural [L] S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5wWRxfhP3ltDL6yrni4wl4Uge3n.jpg'),
(67643, 4620, 'Sobrenatural [L] S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qpkFWE7CkiSwc01l0zpHU7rHDvl.jpg'),
(67644, 4620, 'Sobrenatural [L] S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eElfGjjgGDkIU3rViaeU8Ib19qO.jpg'),
(67645, 4620, 'Sobrenatural [L] S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bMdR1StV7FOYOS6EXORaPQUsAZn.jpg'),
(67646, 4620, 'Sobrenatural [L] S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2OCivrX3cXuJrYWT69M59neBuxN.jpg'),
(67647, 4620, 'Sobrenatural [L] S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aV6u3vliPBR3OXBy6eC8GDq2N27.jpg'),
(67648, 4620, 'Sobrenatural [L] S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jc00f9ujVgojMD63GzC2wz1jeA0.jpg'),
(67649, 4620, 'Sobrenatural [L] S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ldKmxvcMvYnii3JJV8yH5bWmGg0.jpg'),
(67650, 4620, 'Sobrenatural [L] S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bG3J8PvtvQotjRNpAOyO6RygUaJ.jpg'),
(67651, 4620, 'Sobrenatural [L] S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gy7q5eMaQ6nhZ6NwBn64YtY968u.jpg'),
(67652, 4620, 'Sobrenatural [L] S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/30435oZsIhRdgpIE2o72szAW5kj.jpg'),
(67653, 4620, 'Sobrenatural [L] S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bGaN7wqd3T1CgXlmg5UGqarjHWz.jpg'),
(67654, 4620, 'Sobrenatural [L] S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWyLgjF8bq9l0uENb7GutJflNfQ.jpg'),
(67655, 4620, 'Sobrenatural [L] S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ltt0EDsI1wA4AZk5MPWOOX0nNeD.jpg'),
(67656, 4620, 'Sobrenatural [L] S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ijnzYR5meOFtbZW9vtEHWh7Apkj.jpg'),
(67657, 4620, 'Sobrenatural [L] S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9gpoKobvuUizxqBpQSKjQYgl1sP.jpg'),
(67658, 4620, 'Sobrenatural [L] S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wPfhsvZFi2MimQYLsA1nIXnJNTP.jpg'),
(67659, 4620, 'Sobrenatural [L] S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/163135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4b1WptG12AOpojexhg9783lWsgN.jpg'),
(67660, 4620, 'Sobrenatural [L] S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/163136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSfohnhNh0lnddmFXc8LFEdPyjm.jpg'),
(67661, 4620, 'Sobrenatural [L] S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/163137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9vlbX0RUxQuBLB32KSV4dVmivum.jpg'),
(67662, 4621, 'Sobrenatural [L] S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kjrtS0Vc72EoGqvTQj3aUXGW3Mf.jpg'),
(67663, 4621, 'Sobrenatural [L] S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sGAePN7qjJDP9rIfJMBue3Ak2KJ.jpg'),
(67664, 4621, 'Sobrenatural [L] S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6W3SKMKw73jUclhMvyfD40TiL7V.jpg'),
(67665, 4621, 'Sobrenatural [L] S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f82fAQdRRZekM5ql5shB5BwOHtn.jpg'),
(67666, 4621, 'Sobrenatural [L] S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFQ3C48Sj7PFHkgCnPOBR3CcBf9.jpg'),
(67667, 4621, 'Sobrenatural [L] S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ydhahWtCx3f75400nmVLblZAkim.jpg'),
(67668, 4621, 'Sobrenatural [L] S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m0pQslopygerfdD4e7DGa7kOo43.jpg'),
(67669, 4621, 'Sobrenatural [L] S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y3Nk4fAxJnTstODKEVTI85kUAiK.jpg'),
(67670, 4621, 'Sobrenatural [L] S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qDVYqCL1s4o6ZwRbIUMu1AUMxSZ.jpg'),
(67671, 4621, 'Sobrenatural [L] S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pHahkeWYBdAJK8IOWaUy3yxdqeT.jpg'),
(67672, 4621, 'Sobrenatural [L] S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gdybjLeUHGZF0hxB0fOJtIFJ1xX.jpg'),
(67673, 4621, 'Sobrenatural [L] S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x8sS9tFtu0c8nKMKYqDs1ly1MIQ.jpg'),
(67674, 4621, 'Sobrenatural [L] S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3vOeCup6NCjiYux2m8L9CyFIb38.jpg'),
(67675, 4621, 'Sobrenatural [L] S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bInyjYWNo3ovguO6JKEoAEVhCLL.jpg'),
(67676, 4621, 'Sobrenatural [L] S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkxIrqg9IYylL9fRckjRadVTvfa.jpg'),
(67677, 4621, 'Sobrenatural [L] S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sm1cksE1sTlrEgkhVxpept7fqIU.jpg'),
(67678, 4621, 'Sobrenatural [L] S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jWyEhBgSXi261GnjLDnzNLH4niy.jpg'),
(67679, 4621, 'Sobrenatural [L] S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iYvCxIm2a4dcVtvRXRpd5Og47FS.jpg'),
(67680, 4621, 'Sobrenatural [L] S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xabLZiDXLQ2wKZdbPhdjhXmaQyr.jpg'),
(67681, 4621, 'Sobrenatural [L] S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFiINFox0HISkDuHa9A0ftiu9CE.jpg'),
(67682, 4621, 'Sobrenatural [L] S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/163158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vxIrCejWpuPqE1ZKvDpKc9iPCd8.jpg'),
(67683, 4621, 'Sobrenatural [L] S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/163159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aiHs8O6jVvfGk6j7R85pRXvQ2HQ.jpg'),
(67684, 4621, 'Sobrenatural [L] S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/163160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1rNqxT80PTUDa024jsZS00jITey.jpg'),
(67685, 4621, 'Sobrenatural [L] S10 E24', 'http://sinalprivado.info:80/series/1533784/1533784/163161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ovFzkkKknAo2SbM2DfOabxRvzmy.jpg'),
(67686, 4622, 'Sobrenatural [L] S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/et4wg0U4ZcXdCTVTJH1KLinjOzN.jpg'),
(67687, 4622, 'Sobrenatural [L] S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5E2iqdvFEmQSWggXym0rj4bs9M.jpg'),
(67688, 4622, 'Sobrenatural [L] S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6tjGWIxQDLmTj99asNWkApCz65g.jpg'),
(67689, 4622, 'Sobrenatural [L] S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yfScje9w75eG2sxuMOMOhYyMw0I.jpg'),
(67690, 4622, 'Sobrenatural [L] S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mwkHyNrfZzEixxdhvuACkUspcws.jpg'),
(67691, 4622, 'Sobrenatural [L] S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZPedFKFg29AK2VLIzDw1z68zXb.jpg'),
(67692, 4622, 'Sobrenatural [L] S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n9rzWIWj8vn0dQL0nQK7niEIu6v.jpg'),
(67693, 4622, 'Sobrenatural [L] S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dBvmYEJ1qbWLjyPEBmhrN0xu1bN.jpg'),
(67694, 4622, 'Sobrenatural [L] S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtpfPDXAnWh4pnUQAMsp14MtSMX.jpg'),
(67695, 4622, 'Sobrenatural [L] S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyp4eygcDNzzVILu0kJxYM3ylT.jpg'),
(67696, 4622, 'Sobrenatural [L] S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rPUsKp4QijOinjq5RLPqcT0c9KE.jpg'),
(67697, 4622, 'Sobrenatural [L] S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sLkl16kyH6G8TJzZdGdR1VCQpse.jpg'),
(67698, 4622, 'Sobrenatural [L] S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9keI65dTUkRFBziKCxZSFf4r2V0.jpg'),
(67699, 4622, 'Sobrenatural [L] S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h2W5doNhVev2bsioRR63YegGpc3.jpg'),
(67700, 4622, 'Sobrenatural [L] S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dtGY55mqofeLWOULzOI06UCjeDQ.jpg'),
(67701, 4622, 'Sobrenatural [L] S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVZDBsDYWuXy9yQlUwOeZk6kOPP.jpg'),
(67702, 4622, 'Sobrenatural [L] S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cn10gcZW0PRnkgx7HkEYlRr6Js1.jpg'),
(67703, 4622, 'Sobrenatural [L] S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iazKVzJUbnRLbubB7LdZN9G1MQZ.jpg'),
(67704, 4622, 'Sobrenatural [L] S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zFOEfOJ7E9J99kX8XC6doXtBVRr.jpg'),
(67705, 4622, 'Sobrenatural [L] S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7y7YnAQoE2COuYPCwKAbclhA6cO.jpg'),
(67706, 4622, 'Sobrenatural [L] S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/163182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3zzzre0zHqcsSogECSJEUbVUJ4.jpg'),
(67707, 4622, 'Sobrenatural [L] S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/163183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g12CYzsU4YTgpfONU7NnVd6jLvO.jpg'),
(67708, 4622, 'Sobrenatural [L] S11 E23', 'http://sinalprivado.info:80/series/1533784/1533784/163184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z56RwqT5AUS6nfqNVlrhffRl5wa.jpg'),
(67709, 4623, 'Sobrenatural [L] S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kkC090DloV9Gt1UL5e9VAoT20hG.jpg'),
(67710, 4623, 'Sobrenatural [L] S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSjm8KvK3UUU33hqKU8570AvaOW.jpg'),
(67711, 4623, 'Sobrenatural [L] S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVBD4ptxZjnS0d4g4JO3NVMZarL.jpg'),
(67712, 4623, 'Sobrenatural [L] S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b3yzp8TKrSWnZv4IWmJTXQXFFpY.jpg'),
(67713, 4623, 'Sobrenatural [L] S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4n1aCD9MeOl6mxp24glAFhubMDt.jpg'),
(67714, 4623, 'Sobrenatural [L] S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8LhfYudv1zgr04ziFz3rX3PM8W.jpg'),
(67715, 4623, 'Sobrenatural [L] S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/20VAXuvcwKMgRxhNYohAHpupyXf.jpg'),
(67716, 4623, 'Sobrenatural [L] S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nMaVXiiGoNOgjIGfKrkzoKfIiXZ.jpg'),
(67717, 4623, 'Sobrenatural [L] S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Qc4xpudV5Q9c976GfFYXknKBD0.jpg'),
(67718, 4623, 'Sobrenatural [L] S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FX6ejptbTyxGpfK1GWI1vhj2WS.jpg'),
(67719, 4623, 'Sobrenatural [L] S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mb9y3B7rNs9BJZ6sE4NcG2XO8Gn.jpg'),
(67720, 4623, 'Sobrenatural [L] S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gnrPC2RNDvopoOwQClkwA8KvTtm.jpg'),
(67721, 4623, 'Sobrenatural [L] S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iad32u3l7D3OLXUg5XzwVJpUL9s.jpg'),
(67722, 4623, 'Sobrenatural [L] S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ympOe0aTXssXY1CxZHveEF1f7SK.jpg'),
(67723, 4623, 'Sobrenatural [L] S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8hyHbg3PAtuzkv5DpO6EMoQlnV0.jpg'),
(67724, 4623, 'Sobrenatural [L] S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u9oGI4uldjvJVtnPhqu0Kt2FNJu.jpg'),
(67725, 4623, 'Sobrenatural [L] S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/adf1CAcUnvo2gikRtswORgivIQh.jpg'),
(67726, 4623, 'Sobrenatural [L] S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dP7g38SwQRKqHATLmXIYH0RVue.jpg'),
(67727, 4623, 'Sobrenatural [L] S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hzPCbrmtklGRbVIBn584cCJlZuy.jpg'),
(67728, 4623, 'Sobrenatural [L] S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/28MfSp7aJs1PsesJKY7u3Yz9qY6.jpg'),
(67729, 4623, 'Sobrenatural [L] S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/163205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cSRKU8VGm5qXw5cUHHmSt7y1f5u.jpg'),
(67730, 4623, 'Sobrenatural [L] S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/163206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/10KczbZQDLVcYBulIKHKIuZHsw8.jpg'),
(67731, 4623, 'Sobrenatural [L] S12 E23', 'http://sinalprivado.info:80/series/1533784/1533784/163207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uxmhXLFOo1LfSo9UIk0tmp7dPlw.jpg'),
(67732, 4624, 'Sobrenatural [L] S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tg6KW03bMd4pbG2xKtDXoig6eoe.jpg'),
(67733, 4624, 'Sobrenatural [L] S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rXYi5BuU8CeYcN3cABJupUnFI8h.jpg'),
(67734, 4624, 'Sobrenatural [L] S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2dtmuhfPKL0Most3hDKPNYTOTx.jpg'),
(67735, 4624, 'Sobrenatural [L] S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l4Cbi7sQNzA9uWyTVpY1gPJxESt.jpg'),
(67736, 4624, 'Sobrenatural [L] S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iA4IsmX6sThD82893as6bDnlHZA.jpg'),
(67737, 4624, 'Sobrenatural [L] S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/atYbcuhfAv9sYpsFXJXlkb2u3Wz.jpg'),
(67738, 4624, 'Sobrenatural [L] S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/NG2i00MWSlri2d2ZMSze6rV4Ec.jpg'),
(67739, 4624, 'Sobrenatural [L] S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7T2uQmUMnKCZ3BTcehRNr6JlWah.jpg'),
(67740, 4624, 'Sobrenatural [L] S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yxQ2wZrzkiqdaHvNMHwItrrvVdo.jpg'),
(67741, 4624, 'Sobrenatural [L] S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uvwsgMxFdeP9KTOnhMMujf9daK3.jpg'),
(67742, 4624, 'Sobrenatural [L] S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a48yKCJXcqECP1JermfFMZTwnH7.jpg'),
(67743, 4624, 'Sobrenatural [L] S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cvKnyPE0nOdvmsfoocmijknvaRV.jpg'),
(67744, 4624, 'Sobrenatural [L] S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oTlyAcBl3TLgXdwbSbElcPIlTdm.jpg'),
(67745, 4624, 'Sobrenatural [L] S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kCnrpmpB7oVNEquGmkkksLxuvT7.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(67746, 4624, 'Sobrenatural [L] S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e7Rf351ZWiRqcBjAe47txA6jkLM.jpg'),
(67747, 4624, 'Sobrenatural [L] S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xzRt7jgHvN5Ci2BrynzARsC1oHQ.jpg'),
(67748, 4624, 'Sobrenatural [L] S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3AKhafdiKPZCg7QvlaVjMT0KpvU.jpg'),
(67749, 4624, 'Sobrenatural [L] S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iWrHjid38fV1ebrXdQK8j4L2xOY.jpg'),
(67750, 4624, 'Sobrenatural [L] S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13eoBfvtTpu2a0mvkhMxdXaBMzD.jpg'),
(67751, 4624, 'Sobrenatural [L] S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AfkiTPNFYZgsnENUpRIIvFLmuPS.jpg'),
(67752, 4624, 'Sobrenatural [L] S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/163228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ASsAXVIFtFJ9Rjk03kuViVkI7N.jpg'),
(67753, 4624, 'Sobrenatural [L] S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/163229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dm4L93LmaZn544sFRP0bv5KTmdX.jpg'),
(67754, 4624, 'Sobrenatural [L] S13 E23', 'http://sinalprivado.info:80/series/1533784/1533784/163230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBQaHEIXeGqJB7STG1arnrhRoFx.jpg'),
(67755, 4625, 'Sobrenatural [L] S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvaNg9xftwoSeIbYgLCHpS5zMkO.jpg'),
(67756, 4625, 'Sobrenatural [L] S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/luJZctaTqSmcFAO4rn44X5cGkmL.jpg'),
(67757, 4625, 'Sobrenatural [L] S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6c9xhU2rrUcpq1UAzPghSt5BU7E.jpg'),
(67758, 4625, 'Sobrenatural [L] S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/21KM2qFdjK3f06TKhbtZHZdwCnV.jpg'),
(67759, 4625, 'Sobrenatural [L] S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v2k2tG7UxfC6YVJchnV1yzDwiUa.jpg'),
(67760, 4625, 'Sobrenatural [L] S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/idFzbCRziHeCVma5IuO5CuMieWW.jpg'),
(67761, 4625, 'Sobrenatural [L] S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8uqoHeWFl2tLGg7xTsyPvD1BUnQ.jpg'),
(67762, 4625, 'Sobrenatural [L] S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kqFjHrEMk9bd0EUM18WhMDxCyCY.jpg'),
(67763, 4625, 'Sobrenatural [L] S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTN6TgJRprjzkF1z9eoDmpPqAZd.jpg'),
(67764, 4625, 'Sobrenatural [L] S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eyiuWNSpHFhk5f3sq4Lb9Kalzvm.jpg'),
(67765, 4625, 'Sobrenatural [L] S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0rKwKuz0boMVjRkQPmtT4fgYah.jpg'),
(67766, 4625, 'Sobrenatural [L] S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9jEB0ZLDpQAi8CxSm227WR6Vgyh.jpg'),
(67767, 4625, 'Sobrenatural [L] S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bFEYwpF3ErAYu3fbol9b1Oekawm.jpg'),
(67768, 4625, 'Sobrenatural [L] S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fP3fai8vEfCnHtyZqDuFutGRrhf.jpg'),
(67769, 4625, 'Sobrenatural [L] S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24HLpGuTzZ0QMFMWf3XpM7G6HA9.jpg'),
(67770, 4625, 'Sobrenatural [L] S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2b2ZykCAvOuI5fshy1XUR4pCca8.jpg'),
(67771, 4625, 'Sobrenatural [L] S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7cosSom3XC8jYPKV1x4RUthLmQ.jpg'),
(67772, 4625, 'Sobrenatural [L] S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/90GLDB79EifULn0WhGQk2JK25nS.jpg'),
(67773, 4625, 'Sobrenatural [L] S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ma6XhWpDHDmD41LeU7eo5pQnf8r.jpg'),
(67774, 4625, 'Sobrenatural [L] S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aWZZHwuaRRD6DFyeIYvKZPC5V5.jpg'),
(67775, 4626, 'Sobrenatural [L] S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gOdsgcvRqK11e0c9eL3ILEke1pn.jpg'),
(67776, 4626, 'Sobrenatural [L] S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eJS5KPXfa0vuaSLXNV9wnQxQMQJ.jpg'),
(67777, 4626, 'Sobrenatural [L] S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9OOdt8aGA2G5UNJWc2j5HhzqjMo.jpg'),
(67778, 4626, 'Sobrenatural [L] S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zukePbvG2FUgnPEvTGcIVM4FKWc.jpg'),
(67779, 4626, 'Sobrenatural [L] S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vDocJPyJIfIhJzGCgXlkhQCZGur.jpg'),
(67780, 4626, 'Sobrenatural [L] S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1Um35J4ml4L1KLCsOnOYOSttQe.jpg'),
(67781, 4626, 'Sobrenatural [L] S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3A47t2hckQe0RB4PnKVHLRBYOaN.jpg'),
(67782, 4626, 'Sobrenatural [L] S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kClbqTOPyNQer5FIblkPoHcI5aJ.jpg'),
(67783, 4626, 'Sobrenatural [L] S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cfCv6navhRZQBQPuEY83DRQJfo8.jpg'),
(67784, 4626, 'Sobrenatural [L] S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kAxxgHbnfAavbZaJIkB6Rb4tDu3.jpg'),
(67785, 4626, 'Sobrenatural [L] S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4BN8JV7kn6b7GD2OqI2LIOzgGEV.jpg'),
(67786, 4626, 'Sobrenatural [L] S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AtZkIR0Azy6klwJleZ7ugX7xDTG.jpg'),
(67787, 4626, 'Sobrenatural [L] S15 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2WQwdohqH9h6Qr94XMfo5HhT5QQ.jpg'),
(67788, 4626, 'Sobrenatural [L] S15 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7PaAID5SU5mBuNnMg88m845YXdp.jpg'),
(67789, 4626, 'Sobrenatural [L] S15 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFkF4KkPsgUb72NcuV7eSZgGmRM.jpg'),
(67790, 4626, 'Sobrenatural [L] S15 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2rZMzoDJlbnGRhw1WMVQUgvoYF.jpg'),
(67791, 4626, 'Sobrenatural [L] S15 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFynBN8uxKfYKW2aoRqVhPNEp5p.jpg'),
(67792, 4626, 'Sobrenatural [L] S15 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sdBnjJxoitWamhnrjstuXx0R3Mb.jpg'),
(67793, 4626, 'Sobrenatural [L] S15 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wUuwkiLKd2peA1YLfKMW4EifCTd.jpg'),
(67794, 4626, 'Sobrenatural [L] S15 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/frpiXDldkh3P2VtNPxetsRawbpm.jpg'),
(67795, 4627, 'Buffy: A Caça-Vampiros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zPyNtKPl7S4IAGzohTjvOHGoti5.jpg'),
(67796, 4627, 'Buffy: A Caça-Vampiros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fSf6RYFjt5PaJv1i5ZOSu76uzQc.jpg'),
(67797, 4627, 'Buffy: A Caça-Vampiros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6JmR2tHUuFOMQWKH9rQY6nk6WpE.jpg'),
(67798, 4627, 'Buffy: A Caça-Vampiros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jn6Pcp90LG7DpALsLyrjoGrz9o7.jpg'),
(67799, 4627, 'Buffy: A Caça-Vampiros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uEZNSfCsUqO3nim8MArdk62KUsD.jpg'),
(67800, 4627, 'Buffy: A Caça-Vampiros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bX0QTl7cxFlFLrlqsF9Fjq1THzr.jpg'),
(67801, 4627, 'Buffy: A Caça-Vampiros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2DEME20GSK3L7bioFqI3AvS8Sso.jpg'),
(67802, 4627, 'Buffy: A Caça-Vampiros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ddzn20xbzgUXKZsRIYBCNGtw13W.jpg'),
(67803, 4627, 'Buffy: A Caça-Vampiros S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v3RPMAnIdxi0TrJI9O8D0aOM42I.jpg'),
(67804, 4627, 'Buffy: A Caça-Vampiros S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hkvy9YJiDbGaoRdUVsDHpsSBW6H.jpg'),
(67805, 4627, 'Buffy: A Caça-Vampiros S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i3dIY6fcm3FVn9M5r3pJ2dXRWKE.jpg'),
(67806, 4627, 'Buffy: A Caça-Vampiros S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zH3xi8DPZU3jdB3JfTleQ4LiYMF.jpg'),
(67807, 4628, 'Buffy: A Caça-Vampiros S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mNQjSaz3IaWizrU0YNHiCEmnJQU.jpg'),
(67808, 4628, 'Buffy: A Caça-Vampiros S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gS27RTXMXAwFvXD4dSGne9Pe9nD.jpg'),
(67809, 4628, 'Buffy: A Caça-Vampiros S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/59PDZdtM0Jpl8PJQLCEubQco8xV.jpg'),
(67810, 4628, 'Buffy: A Caça-Vampiros S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xq4bcfmTbVuUsDtwOHzde1dqPAr.jpg'),
(67811, 4628, 'Buffy: A Caça-Vampiros S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNVIdRQz6zYbPXgPalHsMuSkt1o.jpg'),
(67812, 4628, 'Buffy: A Caça-Vampiros S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z5jnWdxcKgM83y5QwpMGAYpO7aY.jpg'),
(67813, 4628, 'Buffy: A Caça-Vampiros S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4OIsSti8CGPynj2KcxbaEiEc9tB.jpg'),
(67814, 4628, 'Buffy: A Caça-Vampiros S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kLMZDKMxrWbwysuK7QSYrJwqPaE.jpg'),
(67815, 4628, 'Buffy: A Caça-Vampiros S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cw8gzJAPCNRG381EVVAVQGT9rK.jpg'),
(67816, 4628, 'Buffy: A Caça-Vampiros S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfNp76oMVRPrS5eyN8NM7j5FyT3.jpg'),
(67817, 4628, 'Buffy: A Caça-Vampiros S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fywXyH5uHP30nGLpdXtYRkF8JTw.jpg'),
(67818, 4628, 'Buffy: A Caça-Vampiros S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5c3IaAcN868gehK1BvodWU6grJ.jpg'),
(67819, 4628, 'Buffy: A Caça-Vampiros S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9VgzHK1x3ITg3NHZoozQUVmNgAr.jpg'),
(67820, 4628, 'Buffy: A Caça-Vampiros S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jCqZrES4ePu4kqmanbqqAGNWoQw.jpg'),
(67821, 4628, 'Buffy: A Caça-Vampiros S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oG9u8zCafCH5w4IOqcdwvaLImYO.jpg'),
(67822, 4628, 'Buffy: A Caça-Vampiros S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yrzlSS3whVHdxj5UI3pLsrfoiVt.jpg'),
(67823, 4628, 'Buffy: A Caça-Vampiros S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1pnlKr9lNPOGrJhuIJj3T8iG9jZ.jpg'),
(67824, 4628, 'Buffy: A Caça-Vampiros S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wrMbQMsBl4wbGdm4a2cjCZE7ndf.jpg'),
(67825, 4628, 'Buffy: A Caça-Vampiros S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p1v3IAhrzsOJAvdf7T25ZcmrPOT.jpg'),
(67826, 4628, 'Buffy: A Caça-Vampiros S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8IftbK2tZb22LRDKFeOVbXkuWa9.jpg'),
(67827, 4628, 'Buffy: A Caça-Vampiros S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cBnJj1U0uEY3XiVXtfRKE1FebZT.jpg'),
(67828, 4628, 'Buffy: A Caça-Vampiros S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tYWVSEXenQFelxNkmiVNJ9vhJ2y.jpg'),
(67829, 4629, 'Buffy: A Caça-Vampiros S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a8xQegPDjFcdVuIxRAeEheqfvwC.jpg'),
(67830, 4629, 'Buffy: A Caça-Vampiros S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xbW5t0nQLJrvdd0R8rUslNRmj88.jpg'),
(67831, 4629, 'Buffy: A Caça-Vampiros S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fY90LCei1m8g4lakigMjW1TW4fy.jpg'),
(67832, 4629, 'Buffy: A Caça-Vampiros S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nlJC4xgagtJv0T6Z8TYEhXALQvx.jpg'),
(67833, 4629, 'Buffy: A Caça-Vampiros S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wckoL8NI5Tq8XijjitFiDAqJivU.jpg'),
(67834, 4629, 'Buffy: A Caça-Vampiros S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8u2VYfxHDpQhuQknmgkBh0gx0Oo.jpg'),
(67835, 4629, 'Buffy: A Caça-Vampiros S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/QGtZCZAvLkg4f1Ur3QX1NNgLJp.jpg'),
(67836, 4629, 'Buffy: A Caça-Vampiros S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jVP1E30I8WhLoRjemKrC9pLOsat.jpg'),
(67837, 4629, 'Buffy: A Caça-Vampiros S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/niiB37Zmp7k198AJJm5TFIdvrqc.jpg'),
(67838, 4629, 'Buffy: A Caça-Vampiros S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5OycMIBqx6mjRj4lzta4OJHDDis.jpg'),
(67839, 4629, 'Buffy: A Caça-Vampiros S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sIp40cDg7cXryMpc6A2rE1eXHwJ.jpg'),
(67840, 4629, 'Buffy: A Caça-Vampiros S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e2p28ecjtWh87Am2rDV0t9JgYGi.jpg'),
(67841, 4629, 'Buffy: A Caça-Vampiros S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2DJw4r0K8B4fhcESJ3tbSazeah3.jpg'),
(67842, 4629, 'Buffy: A Caça-Vampiros S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/acQGp979CaDDmHvxWYwJFJCb94W.jpg'),
(67843, 4629, 'Buffy: A Caça-Vampiros S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qicrXiTxWWAkjOBCTMf2eYjyo09.jpg'),
(67844, 4629, 'Buffy: A Caça-Vampiros S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8WlOoG14X4MVoIRwIWKBXSz9KVZ.jpg'),
(67845, 4629, 'Buffy: A Caça-Vampiros S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6tfmIGfgpOrGHIYPO7tCChCeGJZ.jpg'),
(67846, 4629, 'Buffy: A Caça-Vampiros S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yp2zt8NPaT1Jj2NPxiUha7uWT8f.jpg'),
(67847, 4629, 'Buffy: A Caça-Vampiros S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/de03LgN8zr6RXSWJbw0LhHrcxZn.jpg'),
(67848, 4629, 'Buffy: A Caça-Vampiros S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mz05DUG1lk5YOvqNAIWAYjnRmUb.jpg'),
(67849, 4629, 'Buffy: A Caça-Vampiros S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pIkWZ44fHbX8NEuRWI8RAl9EXTz.jpg'),
(67850, 4629, 'Buffy: A Caça-Vampiros S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJPJVep12Zay6eW4JfPEDY4FmYz.jpg'),
(67851, 4630, 'Buffy: A Caça-Vampiros S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fQjH38AoYFuts4bLqCX1ep2Zl5f.jpg'),
(67852, 4630, 'Buffy: A Caça-Vampiros S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3WxkbbZINKt6WCRm9QaEi8vDfwC.jpg'),
(67853, 4630, 'Buffy: A Caça-Vampiros S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bZuebbRzEVV7snffPsOLnWgDHlY.jpg'),
(67854, 4630, 'Buffy: A Caça-Vampiros S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a75JZnKRZX5LTSs8bxzk2GJV6Sc.jpg'),
(67855, 4630, 'Buffy: A Caça-Vampiros S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cy282Kg6ecBDk9jTyjavkydPwJV.jpg'),
(67856, 4630, 'Buffy: A Caça-Vampiros S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ujO4SJu5V6YYtnBe4441H658TLL.jpg'),
(67857, 4630, 'Buffy: A Caça-Vampiros S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jLaxNmVueJACgJx9t5r1x1U36i0.jpg'),
(67858, 4630, 'Buffy: A Caça-Vampiros S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aYLvBvOQSmKwl9FfspwG8Kn3VJZ.jpg'),
(67859, 4630, 'Buffy: A Caça-Vampiros S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/szE1l8QavgGapRqSAoxPcSHk6NC.jpg'),
(67860, 4630, 'Buffy: A Caça-Vampiros S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/syYQt3pSSgkAqBv1Fsc9rAQFyZQ.jpg'),
(67861, 4630, 'Buffy: A Caça-Vampiros S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tb4lBgc4TEonuN2zUzIqW7xnHHn.jpg'),
(67862, 4630, 'Buffy: A Caça-Vampiros S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7acBLaZucNSkcjDcrOh5gZWZc6s.jpg'),
(67863, 4630, 'Buffy: A Caça-Vampiros S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/31D6OfuzXX7Chw3unVs70myNfXL.jpg'),
(67864, 4630, 'Buffy: A Caça-Vampiros S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yIFR9eBUFei7n1fnanS7qMlZCHu.jpg'),
(67865, 4630, 'Buffy: A Caça-Vampiros S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k7o4MRS8NolWsalQrQWD4jU85WR.jpg'),
(67866, 4630, 'Buffy: A Caça-Vampiros S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wytKtOJwUo4gFbgDJEYwA8LOgFR.jpg'),
(67867, 4630, 'Buffy: A Caça-Vampiros S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dND9H1Fw3FY09s7qeVEQVDYsBgF.jpg'),
(67868, 4630, 'Buffy: A Caça-Vampiros S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ggdRogAZIV4GjT1i9y5Wpy8w0rL.jpg'),
(67869, 4630, 'Buffy: A Caça-Vampiros S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hnBzxkT3HIQFT2sK9LoRKtYuljq.jpg'),
(67870, 4630, 'Buffy: A Caça-Vampiros S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k7TRAKEZkHCs3qODR1zxB7rrRkn.jpg'),
(67871, 4630, 'Buffy: A Caça-Vampiros S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rEeMeY33ffWQibhJTgMuF7V4yns.jpg'),
(67872, 4630, 'Buffy: A Caça-Vampiros S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xN6rLfDR7ATzRkXoAlMWSviRMTP.jpg'),
(67873, 4631, 'Buffy: A Caça-Vampiros S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7LrezlL7drYPZfwPbDRJelDGVX4.jpg'),
(67874, 4631, 'Buffy: A Caça-Vampiros S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aHMr8GcqF6iXcZEMb5DAB2CFMSo.jpg'),
(67875, 4631, 'Buffy: A Caça-Vampiros S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3bE4BJp6uQv8J8KhcdenHIx5m9b.jpg'),
(67876, 4631, 'Buffy: A Caça-Vampiros S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ZBKFD59pvMGocwXH1j0QllmwWF.jpg'),
(67877, 4631, 'Buffy: A Caça-Vampiros S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJDEAetGrswj2lMG7LPFSVXEIQp.jpg'),
(67878, 4631, 'Buffy: A Caça-Vampiros S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tUE66WDk5IVGoF78tGFMjQV4oW.jpg'),
(67879, 4631, 'Buffy: A Caça-Vampiros S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2SI0nex2tJcpm4TmmPWcw5pCwNp.jpg'),
(67880, 4631, 'Buffy: A Caça-Vampiros S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzo0MOa0dm88C4wrafSnOWiPzgJ.jpg'),
(67881, 4631, 'Buffy: A Caça-Vampiros S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nWIKg8i2sSyh3FbCYwSBbE6wTV3.jpg'),
(67882, 4631, 'Buffy: A Caça-Vampiros S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vqKptmgpGDWdPBXP5GRGagimwev.jpg'),
(67883, 4631, 'Buffy: A Caça-Vampiros S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7f46CLXGkWErjesrcni0gZix85c.jpg'),
(67884, 4631, 'Buffy: A Caça-Vampiros S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lK7k2ARtT3CtyMPxqbXkAMpJic6.jpg'),
(67885, 4631, 'Buffy: A Caça-Vampiros S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/olSQyxVp6MWGyaGMxXd3bAXkJBx.jpg'),
(67886, 4631, 'Buffy: A Caça-Vampiros S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zGsbZxmoHWOYiGVu0UwQ5yEPeuT.jpg'),
(67887, 4631, 'Buffy: A Caça-Vampiros S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/25ltbmhUduNtIZCGczQjsLnd1gL.jpg'),
(67888, 4631, 'Buffy: A Caça-Vampiros S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cq8Xqf1oWyQTX5jDNfFGOUoZzZe.jpg'),
(67889, 4631, 'Buffy: A Caça-Vampiros S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4YeHC40JNx6pUbHUEoFROteGeGJ.jpg'),
(67890, 4631, 'Buffy: A Caça-Vampiros S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iyvsJ5zohjutFXq3IeQrFJyqiWx.jpg'),
(67891, 4631, 'Buffy: A Caça-Vampiros S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCYnfArnRRkGf9eWvsiP7FPYfVy.jpg'),
(67892, 4631, 'Buffy: A Caça-Vampiros S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mLrc6Q0fAfIUb79us6Kt92KyPJt.jpg'),
(67893, 4631, 'Buffy: A Caça-Vampiros S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8TMlvHBCDuvHJ4npBsaB8zbdE7i.jpg'),
(67894, 4631, 'Buffy: A Caça-Vampiros S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e0AdCWD9LGfnke7UDI183vtJgMr.jpg'),
(67895, 4632, 'Buffy: A Caça-Vampiros S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aTRuduBkykdTZlMu1ezmeh5TWsY.jpg'),
(67896, 4632, 'Buffy: A Caça-Vampiros S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cbZCOABOcJJhO9Up05fTRFns0iA.jpg'),
(67897, 4632, 'Buffy: A Caça-Vampiros S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wWKXH0RxkzlhQTP7qx2OSv41VV8.jpg'),
(67898, 4632, 'Buffy: A Caça-Vampiros S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rIwhEPI6khuOHmDjX0jPgx4buYG.jpg'),
(67899, 4632, 'Buffy: A Caça-Vampiros S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ugqRb0G98ypiArQFAb1Wy8d4ziQ.jpg'),
(67900, 4632, 'Buffy: A Caça-Vampiros S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/upgFsjYce8k4JsTQA6tabkvCCee.jpg'),
(67901, 4632, 'Buffy: A Caça-Vampiros S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pFyRlUjsF2EF52UnS7SeNS3Mxxy.jpg'),
(67902, 4632, 'Buffy: A Caça-Vampiros S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g44MSCA0Z5mA8Yr7arkowa4hDRJ.jpg'),
(67903, 4632, 'Buffy: A Caça-Vampiros S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3jUToSvkuHWMtbACIdM7pTE3jqs.jpg'),
(67904, 4632, 'Buffy: A Caça-Vampiros S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bDjoO4ebG0UYZwJyGLJKBWDt3ad.jpg'),
(67905, 4632, 'Buffy: A Caça-Vampiros S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpTt7C5rdut8inmOoNLOSltSo1X.jpg'),
(67906, 4632, 'Buffy: A Caça-Vampiros S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6fknp0yn5gH00x9NTVitfS7mWqk.jpg'),
(67907, 4632, 'Buffy: A Caça-Vampiros S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/axHu1Jvu4g3oMGVAliNjnLLXv4F.jpg'),
(67908, 4632, 'Buffy: A Caça-Vampiros S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zmRlR0o4jk2Yga5GFzXDOc6usRP.jpg'),
(67909, 4632, 'Buffy: A Caça-Vampiros S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sqKWT5Yk4rqnh5EJ7RS1sp2UkFH.jpg'),
(67910, 4632, 'Buffy: A Caça-Vampiros S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mlkHAdRrUJ79NtMYnrRcA92oJpD.jpg'),
(67911, 4632, 'Buffy: A Caça-Vampiros S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A7vOaodA3NihPm6sSSSSNLtBvEO.jpg'),
(67912, 4632, 'Buffy: A Caça-Vampiros S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wf8eWvOomS7nXzxl01lodyyhWak.jpg'),
(67913, 4632, 'Buffy: A Caça-Vampiros S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/srLZ73oAYc4vhb5s9SPH2VGUWkH.jpg'),
(67914, 4632, 'Buffy: A Caça-Vampiros S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dUS5olJiGdULJqBpioq1OLdrqJu.jpg'),
(67915, 4632, 'Buffy: A Caça-Vampiros S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tyFqwqILQBiDPCbIsJWqsSpR9AH.jpg'),
(67916, 4632, 'Buffy: A Caça-Vampiros S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aO3bGgRM1XieB2fRP8HjM7zorJ.jpg'),
(67917, 4633, 'Evil: Contatos Sobrenaturais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8qDc2vA3rKnMNrK1NDFaDuhpR9u.jpg'),
(67918, 4633, 'Evil: Contatos Sobrenaturais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c0dKGOSwxnu7C7ApvMgfynpmJgn.jpg'),
(67919, 4633, 'Evil: Contatos Sobrenaturais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aEDNyzyFc2FfFtJam0u9hWkN3da.jpg'),
(67920, 4633, 'Evil: Contatos Sobrenaturais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tkiJq1To7k8e8ls0SAoD3NxRtpQ.jpg'),
(67921, 4633, 'Evil: Contatos Sobrenaturais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wTGYau0Jkc4w9ZAeKNNicq9hTgA.jpg'),
(67922, 4633, 'Evil: Contatos Sobrenaturais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aTj1XN09B4PrO2YbYFjqLgrkUuV.jpg'),
(67923, 4633, 'Evil: Contatos Sobrenaturais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xh2XdvDLhVpa41sbzd6rgfFPzG0.jpg'),
(67924, 4633, 'Evil: Contatos Sobrenaturais S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iPsgD7F7jme9gEex8DmDeZHsVmV.jpg'),
(67925, 4633, 'Evil: Contatos Sobrenaturais S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQlOYsVwFBx85uCnQxaCIpNnITq.jpg'),
(67926, 4633, 'Evil: Contatos Sobrenaturais S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ncEJ13MJ9YuXIdYEWAq6RuSZllR.jpg'),
(67927, 4633, 'Evil: Contatos Sobrenaturais S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dgVSBAd7YLEABxhzLqV3O3NahTk.jpg'),
(67928, 4633, 'Evil: Contatos Sobrenaturais S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yAh2H7mjjidI4FxeKYsX9xbTZhi.jpg'),
(67929, 4633, 'Evil: Contatos Sobrenaturais S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/194068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7HKF7qE1LnR6jBIfBjALYwc31Su.jpg'),
(67930, 4634, 'Evil: Contatos Sobrenaturais S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nu35wUO68RbONguT6DPKDBInvZE.jpg'),
(67931, 4634, 'Evil: Contatos Sobrenaturais S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kOLP92gl6cF8M11udhE4KbK2nwz.jpg'),
(67932, 4634, 'Evil: Contatos Sobrenaturais S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qGS8hedCQtsWglXqyVNUqsNElzk.jpg'),
(67933, 4634, 'Evil: Contatos Sobrenaturais S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pLu3FNeMpnLucmHvTpVQVORx7hu.jpg'),
(67934, 4634, 'Evil: Contatos Sobrenaturais S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wkEKps25ebsnnub6O7HsY3ZhyFk.jpg'),
(67935, 4634, 'Evil: Contatos Sobrenaturais S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hF3PvxSIOghnvvlcVHScYTPT5So.jpg'),
(67936, 4634, 'Evil: Contatos Sobrenaturais S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lYPvOrLMWfIg05owUMJqcqRfuSg.jpg'),
(67937, 4634, 'Evil: Contatos Sobrenaturais S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dRtxT6kil0UqoxRNuRkImcPgY8v.jpg'),
(67938, 4634, 'Evil: Contatos Sobrenaturais S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ti50ygSDEcaMxAQBAKnfNq1krTQ.jpg'),
(67939, 4634, 'Evil: Contatos Sobrenaturais S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/reizAVHhoXahgUg8aenDffxBmJ3.jpg'),
(67940, 4634, 'Evil: Contatos Sobrenaturais S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zXnmZkQzSVCszToRXdgv9QkWAmO.jpg'),
(67941, 4634, 'Evil: Contatos Sobrenaturais S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zK8Eqtqus9l0snNGYU91kTS6L6h.jpg'),
(67942, 4634, 'Evil: Contatos Sobrenaturais S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/194081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gWO2EZDCQxHGPj5eYVuCl1Q8Quj.jpg'),
(67943, 4635, 'Evil: Contatos Sobrenaturais S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194082.mp4', 'http://timg.bdta.pro/images/7045e1a94a37e3d49f73e2fd0327ae65.jpg'),
(67944, 4635, 'Evil: Contatos Sobrenaturais S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194083.mp4', 'http://timg.bdta.pro/images/75566b1b8cffc63e8f82b6cd30e30e0b.jpg'),
(67945, 4635, 'Evil: Contatos Sobrenaturais S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194084.mp4', 'http://timg.bdta.pro/images/a3cbcd0df5c2c0323f69849fc886a551.jpg'),
(67946, 4635, 'Evil: Contatos Sobrenaturais S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194085.mp4', 'http://timg.bdta.pro/images/b4a45f15c2606500157627ee36cd4f57.jpg'),
(67947, 4635, 'Evil: Contatos Sobrenaturais S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194086.mp4', 'http://timg.bdta.pro/images/10fa79687fe62622083ad915cbed045a.jpg'),
(67948, 4635, 'Evil: Contatos Sobrenaturais S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194087.mp4', 'http://timg.bdta.pro/images/cb7a9f25a35e0f08f0d5c06b1ac5d23e.jpg'),
(67949, 4635, 'Evil: Contatos Sobrenaturais S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194088.mp4', 'http://timg.bdta.pro/images/373838192a304ae526f22f543e23f50f.jpg'),
(67950, 4635, 'Evil: Contatos Sobrenaturais S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194089.mp4', 'http://timg.bdta.pro/images/a7ae93ad489744e31d93d0cfa330f183.jpg'),
(67951, 4635, 'Evil: Contatos Sobrenaturais S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194090.mp4', 'http://timg.bdta.pro/images/1baee5247d3a90c6a24d103885c71fce.jpg'),
(67952, 4635, 'Evil: Contatos Sobrenaturais S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194091.mp4', 'http://timg.bdta.pro/images/16bd02cc82f802deacb617f875028147.jpg'),
(67953, 4636, 'Evil: Contatos Sobrenaturais S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/442770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gyQRudrRU276fvkXMq4JNq3hzB.jpg'),
(67954, 4636, 'Evil: Contatos Sobrenaturais S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/442771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gyQRudrRU276fvkXMq4JNq3hzB.jpg'),
(67955, 4636, 'Evil: Contatos Sobrenaturais S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/442772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gyQRudrRU276fvkXMq4JNq3hzB.jpg'),
(67956, 4636, 'Evil: Contatos Sobrenaturais S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/442773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gyQRudrRU276fvkXMq4JNq3hzB.jpg'),
(67957, 4636, 'Evil: Contatos Sobrenaturais S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/442774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gyQRudrRU276fvkXMq4JNq3hzB.jpg'),
(67958, 4636, 'Evil: Contatos Sobrenaturais S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/442775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gyQRudrRU276fvkXMq4JNq3hzB.jpg'),
(67959, 4636, 'Evil: Contatos Sobrenaturais S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/442776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gyQRudrRU276fvkXMq4JNq3hzB.jpg'),
(67960, 4636, 'Evil: Contatos Sobrenaturais S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/442777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gyQRudrRU276fvkXMq4JNq3hzB.jpg'),
(67961, 4636, 'Evil: Contatos Sobrenaturais S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/442778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gyQRudrRU276fvkXMq4JNq3hzB.jpg'),
(67962, 4636, 'Evil: Contatos Sobrenaturais S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/442779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gyQRudrRU276fvkXMq4JNq3hzB.jpg'),
(67963, 4636, 'Evil: Contatos Sobrenaturais S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/448058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gyQRudrRU276fvkXMq4JNq3hzB.jpg'),
(67964, 4636, 'Evil: Contatos Sobrenaturais S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/448059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gyQRudrRU276fvkXMq4JNq3hzB.jpg'),
(67965, 4636, 'Evil: Contatos Sobrenaturais S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/448060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gyQRudrRU276fvkXMq4JNq3hzB.jpg'),
(67966, 4636, 'Evil: Contatos Sobrenaturais S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/448061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2gyQRudrRU276fvkXMq4JNq3hzB.jpg'),
(67967, 4637, 'Ghost Whisperer [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vcJ3ewbS6iJTXQR5UegxsE1tyP1.jpg'),
(67968, 4637, 'Ghost Whisperer [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sESm50IJoutpTJZGLwdHsJNe7bY.jpg'),
(67969, 4637, 'Ghost Whisperer [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/37Ptnm4SEj4VbM3tWL3AJNVnK6X.jpg'),
(67970, 4637, 'Ghost Whisperer [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ayB4wimCO98J8XjyZfScaE2IiD.jpg'),
(67971, 4637, 'Ghost Whisperer [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBQpCWiaDnOtkEP5UBxn26XJhKE.jpg'),
(67972, 4637, 'Ghost Whisperer [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MuOo2neDMDyASZ8e2jvE7VPNkf.jpg'),
(67973, 4637, 'Ghost Whisperer [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lsukbRbkumgBmF9Vpyxv80QEgAe.jpg'),
(67974, 4637, 'Ghost Whisperer [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Ab0rILdorUnqUZt8y2LQ6ZqvNV.jpg'),
(67975, 4637, 'Ghost Whisperer [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hV9vgHnxj42lGIyGuEoYbBiGwJ7.jpg'),
(67976, 4637, 'Ghost Whisperer [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3CpCf2vfANf04sjQLTtgE5wuSx6.jpg'),
(67977, 4637, 'Ghost Whisperer [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bkPDZbr2eFOX9l91Y6QydXFjcGc.jpg'),
(67978, 4637, 'Ghost Whisperer [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mmMahbHi0Etj2x0OFxamtJNU8iJ.jpg'),
(67979, 4637, 'Ghost Whisperer [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5pJYn3xlu8ncIIF233C2nCteqF2.jpg'),
(67980, 4637, 'Ghost Whisperer [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/159971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lFa4uDWbAwmLIWCFjXW8Wr5rYvp.jpg'),
(67981, 4637, 'Ghost Whisperer [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/159972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b6xhTjpUCXuiwAuQVqvU2dvK9MZ.jpg'),
(67982, 4637, 'Ghost Whisperer [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/159973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sIupS3wJ3P5GHgzPF32mJ4l1Aka.jpg'),
(67983, 4637, 'Ghost Whisperer [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/159974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rRegzWdwHONegZuYaQUWCPKh9Am.jpg'),
(67984, 4637, 'Ghost Whisperer [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/159975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCLAHlUEPJiMZPreWdNhgzH48aK.jpg'),
(67985, 4637, 'Ghost Whisperer [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/159976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yZr0mwmlTaa8TYmJGL4QZpMG5bo.jpg'),
(67986, 4637, 'Ghost Whisperer [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/159977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8oOW1czhJNZpBlW3nPklrb9eTQ2.jpg'),
(67987, 4637, 'Ghost Whisperer [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/159978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9DLGprsXP6YTL1Pt0t7p8J8tV5S.jpg'),
(67988, 4637, 'Ghost Whisperer [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/159979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Kj5WZ7T7wC00i8bAhfIgOqLZFq.jpg'),
(67989, 4638, 'Ghost Whisperer [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1a3RWuOBT1nJ4y0ciYTWY6c97yh.jpg'),
(67990, 4638, 'Ghost Whisperer [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aHbYgsMDqifYe5TcBqsrzsmaB8o.jpg'),
(67991, 4638, 'Ghost Whisperer [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/81gKlqMwHXqXOpFpGvVqixLokic.jpg'),
(67992, 4638, 'Ghost Whisperer [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fWbi2AqR3l9lhAiTNRx0biyKymY.jpg'),
(67993, 4638, 'Ghost Whisperer [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ibo6RFkSsBCexZjHllYI7PKruSj.jpg'),
(67994, 4638, 'Ghost Whisperer [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2g6aQmpqM0TR68eaAeG6R0Tco0i.jpg'),
(67995, 4638, 'Ghost Whisperer [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lGdLQ2MpNMCOmHqTUozvvq1f1fF.jpg'),
(67996, 4638, 'Ghost Whisperer [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1W7e2c3GbiovRbtUftTkquUhwHG.jpg'),
(67997, 4638, 'Ghost Whisperer [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yS6H49nHgpPRPP7jBmAC6AIF5xK.jpg'),
(67998, 4638, 'Ghost Whisperer [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4hV0ebAby3jH9BtTdlJ2FBgg9Vb.jpg'),
(67999, 4638, 'Ghost Whisperer [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o6PdDljznD6lQ75jQq93mFV20eB.jpg'),
(68000, 4638, 'Ghost Whisperer [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Adg692igxYbpSAaUDpC9A9bkSHE.jpg'),
(68001, 4638, 'Ghost Whisperer [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lYz3gK3jceL1VWJiimuEltPPK4h.jpg'),
(68002, 4638, 'Ghost Whisperer [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/159993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4jbHyjWNUh0HpWiSS03FK0a3rLF.jpg'),
(68003, 4638, 'Ghost Whisperer [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/159994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xtAsrjZVQh4i9kmxIMs1qYr7wZL.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(68004, 4638, 'Ghost Whisperer [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/159995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5fD4LlH8Kzcsu36UIgHwnv8GrUs.jpg'),
(68005, 4638, 'Ghost Whisperer [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/159996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2PfNVvL83OzeY1vxnt1HGV4LYSz.jpg'),
(68006, 4638, 'Ghost Whisperer [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/159997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZWU7sO299uvmYr2gMu5N1g4rA7.jpg'),
(68007, 4638, 'Ghost Whisperer [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/159998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Qb7wCCxa2ekFOSE0Z7Vg0keNPf.jpg'),
(68008, 4638, 'Ghost Whisperer [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/159999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ezWAqcJ5JujUGuLvgpU0MttIDNU.jpg'),
(68009, 4638, 'Ghost Whisperer [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tvzGnmMibQw9DwQgIgvs4bAaauE.jpg'),
(68010, 4638, 'Ghost Whisperer [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2GFbDFUX1NcgCNLjeRcEdvPqKR.jpg'),
(68011, 4639, 'Ghost Whisperer [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oGUGxb5cm7SBkZhX14C3VonL0zW.jpg'),
(68012, 4639, 'Ghost Whisperer [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tE0dOixtEZ0shzsYpqvm05IeLWE.jpg'),
(68013, 4639, 'Ghost Whisperer [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5sXUojUPXnSWi1SXcYK2Cui1xDX.jpg'),
(68014, 4639, 'Ghost Whisperer [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aq4pe468PmXjs7qaBQJeKkgYaxO.jpg'),
(68015, 4639, 'Ghost Whisperer [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nNHCkdcFjJqDAQRJlpMlO09bvRY.jpg'),
(68016, 4639, 'Ghost Whisperer [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1hNzTRbrvBQIaWhoY6S8U72iRsh.jpg'),
(68017, 4639, 'Ghost Whisperer [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l8hTrHwBYACbXhKeWJENQ2ZHcxr.jpg'),
(68018, 4639, 'Ghost Whisperer [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/59gS7CQNLKzce5HgTYd5cUxuoHa.jpg'),
(68019, 4639, 'Ghost Whisperer [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1SzT6tguCOzAPWDpHE7ig0hZGfL.jpg'),
(68020, 4639, 'Ghost Whisperer [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gMdHEycd4wfOxpgs1cKJbyTDbjm.jpg'),
(68021, 4639, 'Ghost Whisperer [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hVzC97avsAXyNAX5yAOyzOKwsaR.jpg'),
(68022, 4639, 'Ghost Whisperer [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5qdB55eF5euyQNN6Jw0nnqVYl77.jpg'),
(68023, 4639, 'Ghost Whisperer [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tUzfEumo0JKbIjgOc9ROLgVJHxy.jpg'),
(68024, 4639, 'Ghost Whisperer [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbRQVzkFh4f4GLyyVGr9boG7RBu.jpg'),
(68025, 4639, 'Ghost Whisperer [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6KkR9wdfPp3KRAf3XINfDWMpKi.jpg'),
(68026, 4639, 'Ghost Whisperer [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8OkMGNossXSTcMSaYsETSPVFaI4.jpg'),
(68027, 4639, 'Ghost Whisperer [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2yEmEFkTvaS9cpHhGb8eXS0VUo.jpg'),
(68028, 4639, 'Ghost Whisperer [L] S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wfbVZ4EZSakze5nL6u7lMqyUJXm.jpg'),
(68029, 4640, 'Ghost Whisperer [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g0EB7joRjNBnzfVmL6D0OY3uFwH.jpg'),
(68030, 4640, 'Ghost Whisperer [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybNJJZUECJmAT1qYMk6St4gERoY.jpg'),
(68031, 4640, 'Ghost Whisperer [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/muXoktxdisYrrx3suQjfxlTXtZ.jpg'),
(68032, 4640, 'Ghost Whisperer [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vQQmfXwHBHe6wAkwQ1371cYhMD8.jpg'),
(68033, 4640, 'Ghost Whisperer [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yZY85hy0JVYxlMDgIRJqT7Zfnu2.jpg'),
(68034, 4640, 'Ghost Whisperer [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1CpN3Fn1Ew7aI9hZOecHffSzO2Q.jpg'),
(68035, 4640, 'Ghost Whisperer [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hOxfDpE4Fp6bk8dWLgSMKAXnJ2t.jpg'),
(68036, 4640, 'Ghost Whisperer [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ehnNrrSyRzMnxpfCCYBkOGrIsbd.jpg'),
(68037, 4640, 'Ghost Whisperer [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tSWVEl7Ez8OXoHjrUrQVXSnjfxN.jpg'),
(68038, 4640, 'Ghost Whisperer [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zAOA8mggR2qBj6ZJ4tkjXK8gGFr.jpg'),
(68039, 4640, 'Ghost Whisperer [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lMrlehRZMvTOPREVRd7GlLV4UNu.jpg'),
(68040, 4640, 'Ghost Whisperer [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMMuwSwE2kPsXEoopl1KhYpJnLY.jpg'),
(68041, 4640, 'Ghost Whisperer [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2wmAFU7ZhGavXPwLMY64ZvyTCps.jpg'),
(68042, 4640, 'Ghost Whisperer [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eh5SoTZ0gDfFPkVocxkv4zlLlwg.jpg'),
(68043, 4640, 'Ghost Whisperer [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5bh4OBAxNQsTIUfkWHGVjPHGim.jpg'),
(68044, 4640, 'Ghost Whisperer [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cSHhL8Sc0Q4yYatLZpc60IbAsz7.jpg'),
(68045, 4640, 'Ghost Whisperer [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oUW8rzoCrbjVQhWk8wpv4T3GeTi.jpg'),
(68046, 4640, 'Ghost Whisperer [L] S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q69nzTmn6aOEmzGFaHhOO79eii8.jpg'),
(68047, 4640, 'Ghost Whisperer [L] S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gYcgkWxGgZK8zYQqgfhzMOmYfTF.jpg'),
(68048, 4640, 'Ghost Whisperer [L] S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zlp0PBBjAu17Crs1S578PUmAQzl.jpg'),
(68049, 4640, 'Ghost Whisperer [L] S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cCdtgBKkO8Tg0oMyiAStAsrjqyZ.jpg'),
(68050, 4640, 'Ghost Whisperer [L] S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vcf1sB53dYhgYZSm4ogAKGeTcWO.jpg'),
(68051, 4640, 'Ghost Whisperer [L] S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/160042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6dyVFGjLjvAwlQHAurgldD0xFn8.jpg'),
(68052, 4641, 'Ghost Whisperer [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/160043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gixCTMe7M2P0qgdk2x0TfCKJLQ.jpg'),
(68053, 4641, 'Ghost Whisperer [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/160044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6CSqxxQyztGizBUNhicIr4XLAMs.jpg'),
(68054, 4641, 'Ghost Whisperer [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/160045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lhu4f4V7U50N0lYdL1B41rIhRnm.jpg'),
(68055, 4641, 'Ghost Whisperer [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/160046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1zMYOhqXm0jmgndO2aIYMy64gLB.jpg'),
(68056, 4641, 'Ghost Whisperer [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/160047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fHyt2dHY2P2fp5yZNYtHkNGtDZj.jpg'),
(68057, 4641, 'Ghost Whisperer [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/160048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/71khTrBUptzJXzKknUQn6GnCuDl.jpg'),
(68058, 4641, 'Ghost Whisperer [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/160049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oxTzbgJZ0nCWjkb44WGxsyz6gwJ.jpg'),
(68059, 4641, 'Ghost Whisperer [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/160050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ofdEZl8suRrZMserBP0UAlUbxJR.jpg'),
(68060, 4641, 'Ghost Whisperer [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/160051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/af8Oi1VOxRECviyNC7XXLHQJTej.jpg'),
(68061, 4641, 'Ghost Whisperer [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/160052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xDi04uCA9LUY4QdUzIcFthLgNKO.jpg'),
(68062, 4641, 'Ghost Whisperer [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/160053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2sLrFdSXZ38UqJfQgvLJyRZjCfN.jpg'),
(68063, 4641, 'Ghost Whisperer [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/160054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ROnCcGrEEBQEY0qqdKCevgGRic.jpg'),
(68064, 4641, 'Ghost Whisperer [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/160055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4tGropWdFYk9futpaGl9kVSvtPa.jpg'),
(68065, 4641, 'Ghost Whisperer [L] S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/160056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/54WlEoRBqjRUWTduhqUbQ0Wmy3A.jpg'),
(68066, 4641, 'Ghost Whisperer [L] S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/160057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eyowzZ2LwYep477SprfsUxTSKn2.jpg'),
(68067, 4641, 'Ghost Whisperer [L] S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/160058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1WKSS8wGA3vBtqQJfEDkxNJhKU.jpg'),
(68068, 4641, 'Ghost Whisperer [L] S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/160059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jhPpHJKwWivEwUSm9zyKH1Ntym9.jpg'),
(68069, 4641, 'Ghost Whisperer [L] S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/160060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfT0SitjMLSoHTc7f9UigFMUSUb.jpg'),
(68070, 4641, 'Ghost Whisperer [L] S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/160061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shDFWMBUM6AwAihdZi3pUaX4sP4.jpg'),
(68071, 4641, 'Ghost Whisperer [L] S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/160062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3GNHpZViDVsqMLQYjoa6jzh0MQi.jpg'),
(68072, 4641, 'Ghost Whisperer [L] S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/160063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dyOFvm3ufAfxXUWhTk2drM48d0q.jpg'),
(68073, 4641, 'Ghost Whisperer [L] S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/160064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sRXmSdHUW7wtlCBHsPUITe9i9vh.jpg'),
(68074, 4642, 'Teatro dos Contos de Fada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68075, 4642, 'Teatro dos Contos de Fada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68076, 4643, 'Teatro dos Contos de Fada S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68077, 4643, 'Teatro dos Contos de Fada S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68078, 4643, 'Teatro dos Contos de Fada S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68079, 4643, 'Teatro dos Contos de Fada S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68080, 4643, 'Teatro dos Contos de Fada S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68081, 4643, 'Teatro dos Contos de Fada S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68082, 4644, 'Teatro dos Contos de Fada S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68083, 4644, 'Teatro dos Contos de Fada S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68084, 4644, 'Teatro dos Contos de Fada S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68085, 4644, 'Teatro dos Contos de Fada S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68086, 4644, 'Teatro dos Contos de Fada S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68087, 4644, 'Teatro dos Contos de Fada S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68088, 4644, 'Teatro dos Contos de Fada S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68089, 4645, 'Teatro dos Contos de Fada S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68090, 4645, 'Teatro dos Contos de Fada S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68091, 4645, 'Teatro dos Contos de Fada S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68092, 4645, 'Teatro dos Contos de Fada S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68093, 4645, 'Teatro dos Contos de Fada S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68094, 4645, 'Teatro dos Contos de Fada S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68095, 4646, 'Teatro dos Contos de Fada S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68096, 4646, 'Teatro dos Contos de Fada S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68097, 4647, 'Teatro dos Contos de Fada S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68098, 4647, 'Teatro dos Contos de Fada S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68099, 4647, 'Teatro dos Contos de Fada S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5pKkikAvKfyiAmxwkw1HHb2z2Za.jpg'),
(68100, 4648, 'Um Maluco no Pedaço S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d1xvUW6ucukJE0xVlE2SVurSyHD.jpg'),
(68101, 4648, 'Um Maluco no Pedaço S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x6HCdjM5wMU4N1e72oq7cQRVUjh.jpg'),
(68102, 4648, 'Um Maluco no Pedaço S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bM81YQfLo3XV4tUiAjNHWmKyanq.jpg'),
(68103, 4648, 'Um Maluco no Pedaço S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9xcqTuSwx71glpUAb51JCjdEA8.jpg'),
(68104, 4648, 'Um Maluco no Pedaço S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6i7MlV5hmQcsDaow4sxuqxeeFRP.jpg'),
(68105, 4648, 'Um Maluco no Pedaço S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gk9AkieYW7EpJitfN9hnsJkPm8T.jpg'),
(68106, 4648, 'Um Maluco no Pedaço S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rWdVwomUsOML2QfIXTSoP6Wc0Gy.jpg'),
(68107, 4648, 'Um Maluco no Pedaço S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yea3DGqmx29O7xbzYy5enJM78Q6.jpg'),
(68108, 4648, 'Um Maluco no Pedaço S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aHL7AS1SFDkKFRMCWEc1XraBxeO.jpg'),
(68109, 4648, 'Um Maluco no Pedaço S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a41BCHSYHCUPNv1o4bE5MyWPD7b.jpg'),
(68110, 4648, 'Um Maluco no Pedaço S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bdqVeAw8RcMRL0kVUqJ6geiysQS.jpg'),
(68111, 4648, 'Um Maluco no Pedaço S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kY1agjaM1nOMJJiiFhGnz3f1oWk.jpg'),
(68112, 4648, 'Um Maluco no Pedaço S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kY1agjaM1nOMJJiiFhGnz3f1oWk.jpg'),
(68113, 4648, 'Um Maluco no Pedaço S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/159695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7GjTBjUAJpawPsh1fyx7Asz9bHl.jpg'),
(68114, 4648, 'Um Maluco no Pedaço S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/159696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7pVmDdsF8wS8q8yidmSyRnL9Ufr.jpg'),
(68115, 4648, 'Um Maluco no Pedaço S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/159697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t16Ko9t6doUMcNW5N2QKlr7P5OC.jpg'),
(68116, 4648, 'Um Maluco no Pedaço S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/159698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qi7uQq2TcxJP1T9Oti15NSBO6Zv.jpg'),
(68117, 4648, 'Um Maluco no Pedaço S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/159699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q3WGl5guZyeUq4RjodepmuJ8Ruo.jpg'),
(68118, 4648, 'Um Maluco no Pedaço S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/159700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iYZegQOtj6e2RKvl80xM9urGDr1.jpg'),
(68119, 4648, 'Um Maluco no Pedaço S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/159701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6qLv2xauoYf1FwxGUziBM5K3yXB.jpg'),
(68120, 4648, 'Um Maluco no Pedaço S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/159702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yea3DGqmx29O7xbzYy5enJM78Q6.jpg'),
(68121, 4648, 'Um Maluco no Pedaço S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/159703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rWdVwomUsOML2QfIXTSoP6Wc0Gy.jpg'),
(68122, 4648, 'Um Maluco no Pedaço S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/159704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/94r0aMtVOeoN5JIOiVZ7RfX5Edp.jpg'),
(68123, 4648, 'Um Maluco no Pedaço S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/159705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n3UWdEVAtBpGWgeZyrKSDZMyWjO.jpg'),
(68124, 4648, 'Um Maluco no Pedaço S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/159706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fXCfqkkQgQJIjC0cpwqq049agk3.jpg'),
(68125, 4649, 'Um Maluco no Pedaço S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fVm2oTF46lofsJsEdZxa053KhMN.jpg'),
(68126, 4649, 'Um Maluco no Pedaço S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i8VZoVnDVx6JRpR73fN3oaeM6Ra.jpg'),
(68127, 4649, 'Um Maluco no Pedaço S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/embkswjPvsPMoLDpV4Ijs67Zi3k.jpg'),
(68128, 4649, 'Um Maluco no Pedaço S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/idtPOcYgTpdMbEjnnGSie440d3h.jpg'),
(68129, 4649, 'Um Maluco no Pedaço S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dfABpO4qIKBIKywkz0kNBgyug19.jpg'),
(68130, 4649, 'Um Maluco no Pedaço S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8L42VvXNVDw0O3k1KMd8sqiD6VU.jpg'),
(68131, 4649, 'Um Maluco no Pedaço S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h0LGvw1zWId54qWLQ6ldgUI65ZH.jpg'),
(68132, 4649, 'Um Maluco no Pedaço S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBnBMiSLnw4mRtOSddHGADVf0Mx.jpg'),
(68133, 4649, 'Um Maluco no Pedaço S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9N6PbZAcmSZk6huT6pmbgEphBIj.jpg'),
(68134, 4649, 'Um Maluco no Pedaço S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/94aAz0KKkIu5wLs8u0oTQAmfr77.jpg'),
(68135, 4649, 'Um Maluco no Pedaço S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/598iSzyW0ByG62RtfENq2x2CjKX.jpg'),
(68136, 4649, 'Um Maluco no Pedaço S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pijYpQD15GTEZ1p1IuYRnJt07E6.jpg'),
(68137, 4649, 'Um Maluco no Pedaço S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTysmPPjhMl2fJIjwOPXCiriFbi.jpg'),
(68138, 4649, 'Um Maluco no Pedaço S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/159720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ueoRUQC27J2jnToFRcDw85XVCYI.jpg'),
(68139, 4649, 'Um Maluco no Pedaço S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/159721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tE9OAxIY5BfHLSzuR7wwqCmvVc6.jpg'),
(68140, 4649, 'Um Maluco no Pedaço S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/159722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aqq2C7d8GRSyCK9n5ZwtS1agCIP.jpg'),
(68141, 4649, 'Um Maluco no Pedaço S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/159723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/neAW4vf4SY6gkmb8f1DOoo38Zig.jpg'),
(68142, 4649, 'Um Maluco no Pedaço S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/159724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5UjYV51H5hOdQL0dsTkvapH5dUi.jpg'),
(68143, 4649, 'Um Maluco no Pedaço S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/159725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0Duj09LuT09ZGcqHUSJCgg2rwi.jpg'),
(68144, 4649, 'Um Maluco no Pedaço S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/159726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qGD4tEdNnnXsQJLsrXFw4faqGUt.jpg'),
(68145, 4649, 'Um Maluco no Pedaço S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/159727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eEO4MlgfTvFdl1pVXWLPeTXTpRo.jpg'),
(68146, 4649, 'Um Maluco no Pedaço S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/159728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/siHHUueQWoF1IUSqTkPSsNRF71G.jpg'),
(68147, 4649, 'Um Maluco no Pedaço S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/159729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nrHJdhS6dPopPrqNMGjcX4lpm01.jpg'),
(68148, 4649, 'Um Maluco no Pedaço S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/159730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/92RH6ZKfX3Pu8TyI87xVCiLVIWd.jpg'),
(68149, 4650, 'Um Maluco no Pedaço S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLcs4eq4LnQDMCam25yv3HkZHSp.jpg'),
(68150, 4650, 'Um Maluco no Pedaço S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Yd0jkUuxjNpxNMQV6xqvck4bzy.jpg'),
(68151, 4650, 'Um Maluco no Pedaço S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g3gvqPhstICPj9mgPa8pSVxYFuk.jpg'),
(68152, 4650, 'Um Maluco no Pedaço S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pTsvHzjrzBWJmGC04vdATGi4iap.jpg'),
(68153, 4650, 'Um Maluco no Pedaço S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xmgva3aIr4776vmqSN9jFHg4cHy.jpg'),
(68154, 4650, 'Um Maluco no Pedaço S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ovBEZixXvugq49Yi98i442cC4n.jpg'),
(68155, 4650, 'Um Maluco no Pedaço S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFwvCOl9hO9mvWhLYimWMYgovxc.jpg'),
(68156, 4650, 'Um Maluco no Pedaço S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bN0ZExD6u8hlp7k07L8WQOXgdpM.jpg'),
(68157, 4650, 'Um Maluco no Pedaço S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mgIkl298AxYES4m4agWwjG85XeH.jpg'),
(68158, 4650, 'Um Maluco no Pedaço S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/39bLD1H3r87Etd1VhbGXX14i6Sf.jpg'),
(68159, 4650, 'Um Maluco no Pedaço S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j84QnUio5Tol42L5AWGe1x5QsL9.jpg'),
(68160, 4650, 'Um Maluco no Pedaço S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHciNsvAyD2WQk2vmzfA4iQfqvD.jpg'),
(68161, 4650, 'Um Maluco no Pedaço S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AfruXYINwisxJiVW5UU5yQLMHu4.jpg'),
(68162, 4650, 'Um Maluco no Pedaço S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/159744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hA3MKiCDeOIX4LhE2pNk8Dca4MC.jpg'),
(68163, 4650, 'Um Maluco no Pedaço S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/159745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dbC4uN40Y3BSFkFGqmBGmDsNGny.jpg'),
(68164, 4650, 'Um Maluco no Pedaço S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/159746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9OW6wcu5WmvFNHD0ZfwjRcJKtvM.jpg'),
(68165, 4650, 'Um Maluco no Pedaço S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/159747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/23l4vDRaKTFA40M3peRiJgRk5Qv.jpg'),
(68166, 4650, 'Um Maluco no Pedaço S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/159748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/abIvmxQc6kkruMlypGwVEuPW3ex.jpg'),
(68167, 4650, 'Um Maluco no Pedaço S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/159749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tp5ZduolFisrEwCXzMmhUTyAZjl.jpg'),
(68168, 4650, 'Um Maluco no Pedaço S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/159750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3heUzNENLcKXPsrvd0WFI73A0e.jpg'),
(68169, 4650, 'Um Maluco no Pedaço S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/159751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mLUSKyxx7anec4c7SWZLDU6szMW.jpg'),
(68170, 4650, 'Um Maluco no Pedaço S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/159752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zCsirEZWQ0OJe3b9tBVaBJ3ihPA.jpg'),
(68171, 4650, 'Um Maluco no Pedaço S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/159753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yMAtPSiyOQcgViMK1iGkhL2kOrF.jpg'),
(68172, 4650, 'Um Maluco no Pedaço S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/159754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/td2YucuSYqMUYJi5Ft3pHqVR0WO.jpg'),
(68173, 4651, 'Um Maluco no Pedaço S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2JbPHgnQtSOD5WOPWaSeBAARoOj.jpg'),
(68174, 4651, 'Um Maluco no Pedaço S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nj8WM0xkvSfis4o59OzXVHgIu8d.jpg'),
(68175, 4651, 'Um Maluco no Pedaço S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8E1WNduBQ8MDErsAY9e8MM7zmM6.jpg'),
(68176, 4651, 'Um Maluco no Pedaço S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pi9JfWoNzwBtDVR3NGvyxceftBK.jpg'),
(68177, 4651, 'Um Maluco no Pedaço S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOt8UTU9pJcXAA9jhCtRPySdqO8.jpg'),
(68178, 4651, 'Um Maluco no Pedaço S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5N4rpRufYI9qztYfRarGiKQMDfS.jpg'),
(68179, 4651, 'Um Maluco no Pedaço S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gH54DD9rkgYR3AhaESmj0wNguup.jpg'),
(68180, 4651, 'Um Maluco no Pedaço S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n5uqMpik60V8renGld1SxIIqahr.jpg'),
(68181, 4651, 'Um Maluco no Pedaço S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mnXycA7BoAinlW4vkm0tBo8n9AY.jpg'),
(68182, 4651, 'Um Maluco no Pedaço S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w9hcfx4yivRZqYEpbjcQBoo7M6e.jpg'),
(68183, 4651, 'Um Maluco no Pedaço S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bKjG6eHIFNFrwAlfkuG8tEi4YZS.jpg'),
(68184, 4651, 'Um Maluco no Pedaço S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3M6QmoNN1IjQ2mQCGeoK2taNh4s.jpg'),
(68185, 4651, 'Um Maluco no Pedaço S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p4r5FmhcnfnhnPUBMBLbGS4jdih.jpg'),
(68186, 4651, 'Um Maluco no Pedaço S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/159768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uloPwgpfeI7iMQDm3WuKL1py9nW.jpg'),
(68187, 4651, 'Um Maluco no Pedaço S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/159769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/81CDleIjt9ZefXetdzkdNosO9Rz.jpg'),
(68188, 4651, 'Um Maluco no Pedaço S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/159770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhudf25oSUjavgzKGuXWbdfc2ve.jpg'),
(68189, 4651, 'Um Maluco no Pedaço S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/159771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdHJZfb8fJu8eEnsmL0Alhzem19.jpg'),
(68190, 4651, 'Um Maluco no Pedaço S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/159772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eBshKRqtqg1Cj2MMPJUDDQPgyoU.jpg'),
(68191, 4651, 'Um Maluco no Pedaço S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/159773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/14iqbRa8yQXs2FGESSDXhSUn4O2.jpg'),
(68192, 4651, 'Um Maluco no Pedaço S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/159774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/16kSwtzAN06fhhXlPaFnDT1LwVN.jpg'),
(68193, 4651, 'Um Maluco no Pedaço S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/159775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lEC2qBa0brkBeT0VtozxN6D2PmV.jpg'),
(68194, 4651, 'Um Maluco no Pedaço S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/159776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/arIaArtWAoj31kTgyqe04m7yk1B.jpg'),
(68195, 4651, 'Um Maluco no Pedaço S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/159777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q5Yr66L2CjLbfKjUV9HFcQ2GQDq.jpg'),
(68196, 4651, 'Um Maluco no Pedaço S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/159778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wtyVijMchSn0dsUCrkQHgLlNH0H.jpg'),
(68197, 4651, 'Um Maluco no Pedaço S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/159779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uIn5YlvFQa8NLV6Ak02emy6q13P.jpg'),
(68198, 4651, 'Um Maluco no Pedaço S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/159780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2yinzeZsSwJHt6ripg1d3d2iisx.jpg'),
(68199, 4652, 'Um Maluco no Pedaço S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqdPGuc1fLjr2fO12MPdhsBDqEb.jpg'),
(68200, 4652, 'Um Maluco no Pedaço S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ywFmRLKhutCxOZUgLDH7XaDEQmj.jpg'),
(68201, 4652, 'Um Maluco no Pedaço S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1DM7ekk8Wm6BAmtA2VyZRXsi5J.jpg'),
(68202, 4652, 'Um Maluco no Pedaço S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e2nrfUHu7wzTxnfGMeqKm2gRcwB.jpg'),
(68203, 4652, 'Um Maluco no Pedaço S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wH7wMl7BlTgdfZAKVqCPOohzICd.jpg'),
(68204, 4652, 'Um Maluco no Pedaço S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mx0EViLfNMwMWgPDyP0EUOy3rMt.jpg'),
(68205, 4652, 'Um Maluco no Pedaço S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1Yeyzcz7umG9ofkQsH67nhIuHt.jpg'),
(68206, 4652, 'Um Maluco no Pedaço S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/89HIcYvUc5s6yPlyivgq7NLmGE9.jpg'),
(68207, 4652, 'Um Maluco no Pedaço S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AeDkKBAVCSUxtVtrjaJ580hJRNU.jpg'),
(68208, 4652, 'Um Maluco no Pedaço S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lMxTlxNvwmP5Z69dIfF5ffFWZN.jpg'),
(68209, 4652, 'Um Maluco no Pedaço S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f5CmbE6unIzGhE4flcForkK2C1b.jpg'),
(68210, 4652, 'Um Maluco no Pedaço S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kV9TRukw0Y64Zx96eZhahwN77jn.jpg'),
(68211, 4652, 'Um Maluco no Pedaço S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQ38qex2gntivN1Yqv3Z1pRgqba.jpg'),
(68212, 4652, 'Um Maluco no Pedaço S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/159794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pWAfYwnAeD45yGzjOUUtobE5dVP.jpg'),
(68213, 4652, 'Um Maluco no Pedaço S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/159795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hCLuVBT5mwtQn7PPUTsj6ZIkEL2.jpg'),
(68214, 4652, 'Um Maluco no Pedaço S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/159796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0WWzvzsjdqC5c0A30rvTZTr6Wr.jpg'),
(68215, 4652, 'Um Maluco no Pedaço S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/159797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wzxHy7IfVb1At176xVIlFkcSHHq.jpg'),
(68216, 4652, 'Um Maluco no Pedaço S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/159798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/baKpIF2Dbb3rU8cygV4RyIxGATm.jpg'),
(68217, 4652, 'Um Maluco no Pedaço S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/159799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nRb4chpAO3yuS8xigh9P0clVkux.jpg'),
(68218, 4652, 'Um Maluco no Pedaço S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/159800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5R9gbyYVG6pNYYuz5LoUzgsXqOJ.jpg'),
(68219, 4652, 'Um Maluco no Pedaço S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/159801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b3YdN7an7SjhE6WtVf7gDtcsSvt.jpg'),
(68220, 4652, 'Um Maluco no Pedaço S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/159802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97m2w0fqMJzSZkrqOMLUR5P3U9c.jpg'),
(68221, 4652, 'Um Maluco no Pedaço S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/159803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1IHARIa9jTEt4CgF0kHCNT5Aqsw.jpg'),
(68222, 4652, 'Um Maluco no Pedaço S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/159804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1sjyw0yMcfGJYwhAs1dG3lCJ7hz.jpg'),
(68223, 4652, 'Um Maluco no Pedaço S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/159805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lxh3bBZwUMotZFQralWUvF2wVpW.jpg'),
(68224, 4653, 'Um Maluco no Pedaço S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3uegjeFXC2m0L8w9onP0fN1T6x.jpg'),
(68225, 4653, 'Um Maluco no Pedaço S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lT9ZPNqSfplxYdKKydfVgT4K7CJ.jpg'),
(68226, 4653, 'Um Maluco no Pedaço S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZGaN9OTKgGNffPWnNv8Lfbb4X0.jpg'),
(68227, 4653, 'Um Maluco no Pedaço S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hTkOu2NJiPQ7xOBjKeuEekPjFWi.jpg'),
(68228, 4653, 'Um Maluco no Pedaço S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tw6rTD7ARuTBQFQRmO0iMOS3Eaf.jpg'),
(68229, 4653, 'Um Maluco no Pedaço S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xEeTB1Og3f9J3Q3DEvDJ912CGYm.jpg'),
(68230, 4653, 'Um Maluco no Pedaço S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mcvR6bwVJAHp0BzYXmvAOLNq1eS.jpg'),
(68231, 4653, 'Um Maluco no Pedaço S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4gp882bEwaT3s996jYHd4AhxiDc.jpg'),
(68232, 4653, 'Um Maluco no Pedaço S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ujLnrLD87uXcpdM2GC1FRNudHMI.jpg'),
(68233, 4653, 'Um Maluco no Pedaço S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t8ZQLsVGcKeuV3NZhWcbxAT87DB.jpg'),
(68234, 4653, 'Um Maluco no Pedaço S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/atP4WfdpPBZldkpx67tLFimXWWT.jpg'),
(68235, 4653, 'Um Maluco no Pedaço S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4EnSNy3s7U8vEMUu0QCVGfiFjLX.jpg'),
(68236, 4653, 'Um Maluco no Pedaço S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cMyPLOflI5pQbLFvHJx6TrceD5a.jpg'),
(68237, 4653, 'Um Maluco no Pedaço S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/159819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m7RAxmStAk3mJob8pfozHqgWcwo.jpg'),
(68238, 4653, 'Um Maluco no Pedaço S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/159820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fSJUxc5odrX2MJKAkM7DoUlqOsA.jpg'),
(68239, 4653, 'Um Maluco no Pedaço S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/159821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aptm3ALb5hBGagtIKgVES6Zne4u.jpg'),
(68240, 4653, 'Um Maluco no Pedaço S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/159822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2pziatUguvdTiFg9eDg68dYyjL8.jpg'),
(68241, 4653, 'Um Maluco no Pedaço S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/159823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3oWyodRAfbU4aFdeCG6pGqMbkqg.jpg'),
(68242, 4653, 'Um Maluco no Pedaço S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/159824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mmd3UlhjkUiWWojnB0q4w9Mr12u.jpg'),
(68243, 4653, 'Um Maluco no Pedaço S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/159825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x6WrNUq2htybOYGpSstYk4OUrK4.jpg'),
(68244, 4653, 'Um Maluco no Pedaço S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/159826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/55UCCrRgGkGI0KbxQaM3enLzyeo.jpg'),
(68245, 4653, 'Um Maluco no Pedaço S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/159827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZEVsnUz8tb5el0IQNCZk3wmuVf.jpg'),
(68246, 4653, 'Um Maluco no Pedaço S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/159828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t9H6oQlP4J0DCT62RLlYFUrNL9.jpg'),
(68247, 4653, 'Um Maluco no Pedaço S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/159829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eV2Tl8fIKEmWnlgepWZnUkyRT3S.jpg'),
(68248, 4654, 'Um Maluco no Pedaço [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d1xvUW6ucukJE0xVlE2SVurSyHD.jpg'),
(68249, 4654, 'Um Maluco no Pedaço [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x6HCdjM5wMU4N1e72oq7cQRVUjh.jpg'),
(68250, 4654, 'Um Maluco no Pedaço [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bM81YQfLo3XV4tUiAjNHWmKyanq.jpg'),
(68251, 4654, 'Um Maluco no Pedaço [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9xcqTuSwx71glpUAb51JCjdEA8.jpg'),
(68252, 4654, 'Um Maluco no Pedaço [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6i7MlV5hmQcsDaow4sxuqxeeFRP.jpg'),
(68253, 4654, 'Um Maluco no Pedaço [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gk9AkieYW7EpJitfN9hnsJkPm8T.jpg'),
(68254, 4654, 'Um Maluco no Pedaço [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rWdVwomUsOML2QfIXTSoP6Wc0Gy.jpg'),
(68255, 4654, 'Um Maluco no Pedaço [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yea3DGqmx29O7xbzYy5enJM78Q6.jpg'),
(68256, 4654, 'Um Maluco no Pedaço [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aHL7AS1SFDkKFRMCWEc1XraBxeO.jpg'),
(68257, 4654, 'Um Maluco no Pedaço [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a41BCHSYHCUPNv1o4bE5MyWPD7b.jpg'),
(68258, 4654, 'Um Maluco no Pedaço [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bdqVeAw8RcMRL0kVUqJ6geiysQS.jpg'),
(68259, 4654, 'Um Maluco no Pedaço [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kY1agjaM1nOMJJiiFhGnz3f1oWk.jpg'),
(68260, 4654, 'Um Maluco no Pedaço [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kY1agjaM1nOMJJiiFhGnz3f1oWk.jpg'),
(68261, 4654, 'Um Maluco no Pedaço [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/159547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7GjTBjUAJpawPsh1fyx7Asz9bHl.jpg'),
(68262, 4654, 'Um Maluco no Pedaço [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/159548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7pVmDdsF8wS8q8yidmSyRnL9Ufr.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(68263, 4654, 'Um Maluco no Pedaço [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/159549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t16Ko9t6doUMcNW5N2QKlr7P5OC.jpg'),
(68264, 4654, 'Um Maluco no Pedaço [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/159550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qi7uQq2TcxJP1T9Oti15NSBO6Zv.jpg'),
(68265, 4654, 'Um Maluco no Pedaço [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/159551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q3WGl5guZyeUq4RjodepmuJ8Ruo.jpg'),
(68266, 4654, 'Um Maluco no Pedaço [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/159552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iYZegQOtj6e2RKvl80xM9urGDr1.jpg'),
(68267, 4654, 'Um Maluco no Pedaço [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/159553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6qLv2xauoYf1FwxGUziBM5K3yXB.jpg'),
(68268, 4654, 'Um Maluco no Pedaço [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/159554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yea3DGqmx29O7xbzYy5enJM78Q6.jpg'),
(68269, 4654, 'Um Maluco no Pedaço [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/159555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rWdVwomUsOML2QfIXTSoP6Wc0Gy.jpg'),
(68270, 4654, 'Um Maluco no Pedaço [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/159556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/94r0aMtVOeoN5JIOiVZ7RfX5Edp.jpg'),
(68271, 4654, 'Um Maluco no Pedaço [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/159557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n3UWdEVAtBpGWgeZyrKSDZMyWjO.jpg'),
(68272, 4654, 'Um Maluco no Pedaço [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/159558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fXCfqkkQgQJIjC0cpwqq049agk3.jpg'),
(68273, 4655, 'Um Maluco no Pedaço [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fVm2oTF46lofsJsEdZxa053KhMN.jpg'),
(68274, 4655, 'Um Maluco no Pedaço [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i8VZoVnDVx6JRpR73fN3oaeM6Ra.jpg'),
(68275, 4655, 'Um Maluco no Pedaço [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/embkswjPvsPMoLDpV4Ijs67Zi3k.jpg'),
(68276, 4655, 'Um Maluco no Pedaço [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/idtPOcYgTpdMbEjnnGSie440d3h.jpg'),
(68277, 4655, 'Um Maluco no Pedaço [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dfABpO4qIKBIKywkz0kNBgyug19.jpg'),
(68278, 4655, 'Um Maluco no Pedaço [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8L42VvXNVDw0O3k1KMd8sqiD6VU.jpg'),
(68279, 4655, 'Um Maluco no Pedaço [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h0LGvw1zWId54qWLQ6ldgUI65ZH.jpg'),
(68280, 4655, 'Um Maluco no Pedaço [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBnBMiSLnw4mRtOSddHGADVf0Mx.jpg'),
(68281, 4655, 'Um Maluco no Pedaço [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9N6PbZAcmSZk6huT6pmbgEphBIj.jpg'),
(68282, 4655, 'Um Maluco no Pedaço [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/94aAz0KKkIu5wLs8u0oTQAmfr77.jpg'),
(68283, 4655, 'Um Maluco no Pedaço [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/598iSzyW0ByG62RtfENq2x2CjKX.jpg'),
(68284, 4655, 'Um Maluco no Pedaço [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pijYpQD15GTEZ1p1IuYRnJt07E6.jpg'),
(68285, 4655, 'Um Maluco no Pedaço [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTysmPPjhMl2fJIjwOPXCiriFbi.jpg'),
(68286, 4655, 'Um Maluco no Pedaço [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/159572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ueoRUQC27J2jnToFRcDw85XVCYI.jpg'),
(68287, 4655, 'Um Maluco no Pedaço [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/159573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tE9OAxIY5BfHLSzuR7wwqCmvVc6.jpg'),
(68288, 4655, 'Um Maluco no Pedaço [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/159574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aqq2C7d8GRSyCK9n5ZwtS1agCIP.jpg'),
(68289, 4655, 'Um Maluco no Pedaço [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/159575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/neAW4vf4SY6gkmb8f1DOoo38Zig.jpg'),
(68290, 4655, 'Um Maluco no Pedaço [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/159576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5UjYV51H5hOdQL0dsTkvapH5dUi.jpg'),
(68291, 4655, 'Um Maluco no Pedaço [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/159577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0Duj09LuT09ZGcqHUSJCgg2rwi.jpg'),
(68292, 4655, 'Um Maluco no Pedaço [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/159578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qGD4tEdNnnXsQJLsrXFw4faqGUt.jpg'),
(68293, 4655, 'Um Maluco no Pedaço [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/159579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eEO4MlgfTvFdl1pVXWLPeTXTpRo.jpg'),
(68294, 4655, 'Um Maluco no Pedaço [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/159580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/siHHUueQWoF1IUSqTkPSsNRF71G.jpg'),
(68295, 4655, 'Um Maluco no Pedaço [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/159581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nrHJdhS6dPopPrqNMGjcX4lpm01.jpg'),
(68296, 4655, 'Um Maluco no Pedaço [L] S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/159582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/92RH6ZKfX3Pu8TyI87xVCiLVIWd.jpg'),
(68297, 4656, 'Um Maluco no Pedaço [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLcs4eq4LnQDMCam25yv3HkZHSp.jpg'),
(68298, 4656, 'Um Maluco no Pedaço [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Yd0jkUuxjNpxNMQV6xqvck4bzy.jpg'),
(68299, 4656, 'Um Maluco no Pedaço [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g3gvqPhstICPj9mgPa8pSVxYFuk.jpg'),
(68300, 4656, 'Um Maluco no Pedaço [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pTsvHzjrzBWJmGC04vdATGi4iap.jpg'),
(68301, 4656, 'Um Maluco no Pedaço [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xmgva3aIr4776vmqSN9jFHg4cHy.jpg'),
(68302, 4656, 'Um Maluco no Pedaço [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ovBEZixXvugq49Yi98i442cC4n.jpg'),
(68303, 4656, 'Um Maluco no Pedaço [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFwvCOl9hO9mvWhLYimWMYgovxc.jpg'),
(68304, 4656, 'Um Maluco no Pedaço [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bN0ZExD6u8hlp7k07L8WQOXgdpM.jpg'),
(68305, 4656, 'Um Maluco no Pedaço [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mgIkl298AxYES4m4agWwjG85XeH.jpg'),
(68306, 4656, 'Um Maluco no Pedaço [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/39bLD1H3r87Etd1VhbGXX14i6Sf.jpg'),
(68307, 4656, 'Um Maluco no Pedaço [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j84QnUio5Tol42L5AWGe1x5QsL9.jpg'),
(68308, 4656, 'Um Maluco no Pedaço [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHciNsvAyD2WQk2vmzfA4iQfqvD.jpg'),
(68309, 4656, 'Um Maluco no Pedaço [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AfruXYINwisxJiVW5UU5yQLMHu4.jpg'),
(68310, 4656, 'Um Maluco no Pedaço [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/159596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hA3MKiCDeOIX4LhE2pNk8Dca4MC.jpg'),
(68311, 4656, 'Um Maluco no Pedaço [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/159597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dbC4uN40Y3BSFkFGqmBGmDsNGny.jpg'),
(68312, 4656, 'Um Maluco no Pedaço [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/159598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9OW6wcu5WmvFNHD0ZfwjRcJKtvM.jpg'),
(68313, 4656, 'Um Maluco no Pedaço [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/159599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/23l4vDRaKTFA40M3peRiJgRk5Qv.jpg'),
(68314, 4656, 'Um Maluco no Pedaço [L] S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/159600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/abIvmxQc6kkruMlypGwVEuPW3ex.jpg'),
(68315, 4656, 'Um Maluco no Pedaço [L] S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/159601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tp5ZduolFisrEwCXzMmhUTyAZjl.jpg'),
(68316, 4656, 'Um Maluco no Pedaço [L] S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/159602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3heUzNENLcKXPsrvd0WFI73A0e.jpg'),
(68317, 4656, 'Um Maluco no Pedaço [L] S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/159603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mLUSKyxx7anec4c7SWZLDU6szMW.jpg'),
(68318, 4656, 'Um Maluco no Pedaço [L] S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/159604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zCsirEZWQ0OJe3b9tBVaBJ3ihPA.jpg'),
(68319, 4656, 'Um Maluco no Pedaço [L] S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/159605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yMAtPSiyOQcgViMK1iGkhL2kOrF.jpg'),
(68320, 4656, 'Um Maluco no Pedaço [L] S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/159606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/td2YucuSYqMUYJi5Ft3pHqVR0WO.jpg'),
(68321, 4657, 'Um Maluco no Pedaço [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2JbPHgnQtSOD5WOPWaSeBAARoOj.jpg'),
(68322, 4657, 'Um Maluco no Pedaço [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nj8WM0xkvSfis4o59OzXVHgIu8d.jpg'),
(68323, 4657, 'Um Maluco no Pedaço [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8E1WNduBQ8MDErsAY9e8MM7zmM6.jpg'),
(68324, 4657, 'Um Maluco no Pedaço [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pi9JfWoNzwBtDVR3NGvyxceftBK.jpg'),
(68325, 4657, 'Um Maluco no Pedaço [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOt8UTU9pJcXAA9jhCtRPySdqO8.jpg'),
(68326, 4657, 'Um Maluco no Pedaço [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5N4rpRufYI9qztYfRarGiKQMDfS.jpg'),
(68327, 4657, 'Um Maluco no Pedaço [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gH54DD9rkgYR3AhaESmj0wNguup.jpg'),
(68328, 4657, 'Um Maluco no Pedaço [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n5uqMpik60V8renGld1SxIIqahr.jpg'),
(68329, 4657, 'Um Maluco no Pedaço [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mnXycA7BoAinlW4vkm0tBo8n9AY.jpg'),
(68330, 4657, 'Um Maluco no Pedaço [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w9hcfx4yivRZqYEpbjcQBoo7M6e.jpg'),
(68331, 4657, 'Um Maluco no Pedaço [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bKjG6eHIFNFrwAlfkuG8tEi4YZS.jpg'),
(68332, 4657, 'Um Maluco no Pedaço [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3M6QmoNN1IjQ2mQCGeoK2taNh4s.jpg'),
(68333, 4657, 'Um Maluco no Pedaço [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p4r5FmhcnfnhnPUBMBLbGS4jdih.jpg'),
(68334, 4657, 'Um Maluco no Pedaço [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/159620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uloPwgpfeI7iMQDm3WuKL1py9nW.jpg'),
(68335, 4657, 'Um Maluco no Pedaço [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/159621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/81CDleIjt9ZefXetdzkdNosO9Rz.jpg'),
(68336, 4657, 'Um Maluco no Pedaço [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/159622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhudf25oSUjavgzKGuXWbdfc2ve.jpg'),
(68337, 4657, 'Um Maluco no Pedaço [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/159623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdHJZfb8fJu8eEnsmL0Alhzem19.jpg'),
(68338, 4657, 'Um Maluco no Pedaço [L] S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/159624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eBshKRqtqg1Cj2MMPJUDDQPgyoU.jpg'),
(68339, 4657, 'Um Maluco no Pedaço [L] S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/159625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/14iqbRa8yQXs2FGESSDXhSUn4O2.jpg'),
(68340, 4657, 'Um Maluco no Pedaço [L] S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/159626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/16kSwtzAN06fhhXlPaFnDT1LwVN.jpg'),
(68341, 4657, 'Um Maluco no Pedaço [L] S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/159627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lEC2qBa0brkBeT0VtozxN6D2PmV.jpg'),
(68342, 4657, 'Um Maluco no Pedaço [L] S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/159628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/arIaArtWAoj31kTgyqe04m7yk1B.jpg'),
(68343, 4657, 'Um Maluco no Pedaço [L] S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/159629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q5Yr66L2CjLbfKjUV9HFcQ2GQDq.jpg'),
(68344, 4657, 'Um Maluco no Pedaço [L] S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/159630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wtyVijMchSn0dsUCrkQHgLlNH0H.jpg'),
(68345, 4657, 'Um Maluco no Pedaço [L] S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/159631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uIn5YlvFQa8NLV6Ak02emy6q13P.jpg'),
(68346, 4657, 'Um Maluco no Pedaço [L] S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/159632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2yinzeZsSwJHt6ripg1d3d2iisx.jpg'),
(68347, 4658, 'Um Maluco no Pedaço [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqdPGuc1fLjr2fO12MPdhsBDqEb.jpg'),
(68348, 4658, 'Um Maluco no Pedaço [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ywFmRLKhutCxOZUgLDH7XaDEQmj.jpg'),
(68349, 4658, 'Um Maluco no Pedaço [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1DM7ekk8Wm6BAmtA2VyZRXsi5J.jpg'),
(68350, 4658, 'Um Maluco no Pedaço [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e2nrfUHu7wzTxnfGMeqKm2gRcwB.jpg'),
(68351, 4658, 'Um Maluco no Pedaço [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wH7wMl7BlTgdfZAKVqCPOohzICd.jpg'),
(68352, 4658, 'Um Maluco no Pedaço [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mx0EViLfNMwMWgPDyP0EUOy3rMt.jpg'),
(68353, 4658, 'Um Maluco no Pedaço [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1Yeyzcz7umG9ofkQsH67nhIuHt.jpg'),
(68354, 4658, 'Um Maluco no Pedaço [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/89HIcYvUc5s6yPlyivgq7NLmGE9.jpg'),
(68355, 4658, 'Um Maluco no Pedaço [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AeDkKBAVCSUxtVtrjaJ580hJRNU.jpg'),
(68356, 4658, 'Um Maluco no Pedaço [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lMxTlxNvwmP5Z69dIfF5ffFWZN.jpg'),
(68357, 4658, 'Um Maluco no Pedaço [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f5CmbE6unIzGhE4flcForkK2C1b.jpg'),
(68358, 4658, 'Um Maluco no Pedaço [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kV9TRukw0Y64Zx96eZhahwN77jn.jpg'),
(68359, 4658, 'Um Maluco no Pedaço [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQ38qex2gntivN1Yqv3Z1pRgqba.jpg'),
(68360, 4658, 'Um Maluco no Pedaço [L] S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/159646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pWAfYwnAeD45yGzjOUUtobE5dVP.jpg'),
(68361, 4658, 'Um Maluco no Pedaço [L] S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/159647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hCLuVBT5mwtQn7PPUTsj6ZIkEL2.jpg'),
(68362, 4658, 'Um Maluco no Pedaço [L] S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/159648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0WWzvzsjdqC5c0A30rvTZTr6Wr.jpg'),
(68363, 4658, 'Um Maluco no Pedaço [L] S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/159649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wzxHy7IfVb1At176xVIlFkcSHHq.jpg'),
(68364, 4658, 'Um Maluco no Pedaço [L] S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/159650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/baKpIF2Dbb3rU8cygV4RyIxGATm.jpg'),
(68365, 4658, 'Um Maluco no Pedaço [L] S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/159651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nRb4chpAO3yuS8xigh9P0clVkux.jpg'),
(68366, 4658, 'Um Maluco no Pedaço [L] S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/159652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5R9gbyYVG6pNYYuz5LoUzgsXqOJ.jpg'),
(68367, 4658, 'Um Maluco no Pedaço [L] S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/159653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b3YdN7an7SjhE6WtVf7gDtcsSvt.jpg'),
(68368, 4658, 'Um Maluco no Pedaço [L] S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/159654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97m2w0fqMJzSZkrqOMLUR5P3U9c.jpg'),
(68369, 4658, 'Um Maluco no Pedaço [L] S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/159655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1IHARIa9jTEt4CgF0kHCNT5Aqsw.jpg'),
(68370, 4658, 'Um Maluco no Pedaço [L] S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/159656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1sjyw0yMcfGJYwhAs1dG3lCJ7hz.jpg'),
(68371, 4658, 'Um Maluco no Pedaço [L] S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/159657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lxh3bBZwUMotZFQralWUvF2wVpW.jpg'),
(68372, 4659, 'Um Maluco no Pedaço [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3uegjeFXC2m0L8w9onP0fN1T6x.jpg'),
(68373, 4659, 'Um Maluco no Pedaço [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lT9ZPNqSfplxYdKKydfVgT4K7CJ.jpg'),
(68374, 4659, 'Um Maluco no Pedaço [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZGaN9OTKgGNffPWnNv8Lfbb4X0.jpg'),
(68375, 4659, 'Um Maluco no Pedaço [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hTkOu2NJiPQ7xOBjKeuEekPjFWi.jpg'),
(68376, 4659, 'Um Maluco no Pedaço [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tw6rTD7ARuTBQFQRmO0iMOS3Eaf.jpg'),
(68377, 4659, 'Um Maluco no Pedaço [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xEeTB1Og3f9J3Q3DEvDJ912CGYm.jpg'),
(68378, 4659, 'Um Maluco no Pedaço [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mcvR6bwVJAHp0BzYXmvAOLNq1eS.jpg'),
(68379, 4659, 'Um Maluco no Pedaço [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4gp882bEwaT3s996jYHd4AhxiDc.jpg'),
(68380, 4659, 'Um Maluco no Pedaço [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ujLnrLD87uXcpdM2GC1FRNudHMI.jpg'),
(68381, 4659, 'Um Maluco no Pedaço [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t8ZQLsVGcKeuV3NZhWcbxAT87DB.jpg'),
(68382, 4659, 'Um Maluco no Pedaço [L] S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/atP4WfdpPBZldkpx67tLFimXWWT.jpg'),
(68383, 4659, 'Um Maluco no Pedaço [L] S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4EnSNy3s7U8vEMUu0QCVGfiFjLX.jpg'),
(68384, 4659, 'Um Maluco no Pedaço [L] S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cMyPLOflI5pQbLFvHJx6TrceD5a.jpg'),
(68385, 4659, 'Um Maluco no Pedaço [L] S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/159671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m7RAxmStAk3mJob8pfozHqgWcwo.jpg'),
(68386, 4659, 'Um Maluco no Pedaço [L] S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/159672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fSJUxc5odrX2MJKAkM7DoUlqOsA.jpg'),
(68387, 4659, 'Um Maluco no Pedaço [L] S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/159673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aptm3ALb5hBGagtIKgVES6Zne4u.jpg'),
(68388, 4659, 'Um Maluco no Pedaço [L] S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/159674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2pziatUguvdTiFg9eDg68dYyjL8.jpg'),
(68389, 4659, 'Um Maluco no Pedaço [L] S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/159675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3oWyodRAfbU4aFdeCG6pGqMbkqg.jpg'),
(68390, 4659, 'Um Maluco no Pedaço [L] S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/159676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mmd3UlhjkUiWWojnB0q4w9Mr12u.jpg'),
(68391, 4659, 'Um Maluco no Pedaço [L] S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/159677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x6WrNUq2htybOYGpSstYk4OUrK4.jpg'),
(68392, 4659, 'Um Maluco no Pedaço [L] S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/159678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/55UCCrRgGkGI0KbxQaM3enLzyeo.jpg'),
(68393, 4659, 'Um Maluco no Pedaço [L] S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/159679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZEVsnUz8tb5el0IQNCZk3wmuVf.jpg'),
(68394, 4659, 'Um Maluco no Pedaço [L] S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/159680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t9H6oQlP4J0DCT62RLlYFUrNL9.jpg'),
(68395, 4659, 'Um Maluco no Pedaço [L] S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/159681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eV2Tl8fIKEmWnlgepWZnUkyRT3S.jpg'),
(68396, 4660, 'A Culpa e do Cabral Na Estrada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/P9SsAeEvzAnBdK0aJb5aJtrFiS.jpg'),
(68397, 4660, 'A Culpa e do Cabral Na Estrada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/P9SsAeEvzAnBdK0aJb5aJtrFiS.jpg'),
(68398, 4660, 'A Culpa e do Cabral Na Estrada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/P9SsAeEvzAnBdK0aJb5aJtrFiS.jpg'),
(68399, 4660, 'A Culpa e do Cabral Na Estrada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/P9SsAeEvzAnBdK0aJb5aJtrFiS.jpg'),
(68400, 4660, 'A Culpa e do Cabral Na Estrada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/P9SsAeEvzAnBdK0aJb5aJtrFiS.jpg'),
(68401, 4660, 'A Culpa e do Cabral Na Estrada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/P9SsAeEvzAnBdK0aJb5aJtrFiS.jpg'),
(68402, 4660, 'A Culpa e do Cabral Na Estrada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/P9SsAeEvzAnBdK0aJb5aJtrFiS.jpg'),
(68403, 4660, 'A Culpa e do Cabral Na Estrada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/P9SsAeEvzAnBdK0aJb5aJtrFiS.jpg'),
(68404, 4660, 'A Culpa e do Cabral Na Estrada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/P9SsAeEvzAnBdK0aJb5aJtrFiS.jpg'),
(68405, 4660, 'A Culpa e do Cabral Na Estrada S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/P9SsAeEvzAnBdK0aJb5aJtrFiS.jpg'),
(68406, 4660, 'A Culpa e do Cabral Na Estrada S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/P9SsAeEvzAnBdK0aJb5aJtrFiS.jpg'),
(68407, 4661, 'Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYBxTpP3BM7fe57AS0nYudKyBSj.jpg'),
(68408, 4661, 'Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJtqI4b1TPPItfUXQj1E4lP6Wst.jpg'),
(68409, 4661, 'Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6VlQBeCha4cCGwFICCTk0zdtteG.jpg'),
(68410, 4661, 'Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cSy6suoiWuO9QVKCse9LKTgFtEH.jpg'),
(68411, 4661, 'Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4HGTwRks00LZ3a5fT37wnzqlVbc.jpg'),
(68412, 4661, 'Amor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jsGc68VTOMfId8jG3cVm3atQfNU.jpg'),
(68413, 4661, 'Amor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8mn94PtISrawo1xfrR6WTGVFFuH.jpg'),
(68414, 4661, 'Amor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rnBCEr8lzViW3iQLzeaeJFze665.jpg'),
(68415, 4661, 'Amor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/km2bs0NpdxhPCOBrvMGXgDLzc3c.jpg'),
(68416, 4661, 'Amor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/guTR5bxcz9StwNv1LxuEWdNJOub.jpg'),
(68417, 4662, 'Assassino Sem Passado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i93CP963ymnKJGaZ03RcOPPM7vI.jpg'),
(68418, 4662, 'Assassino Sem Passado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e6aX6M2v5SNirrHzZGgtDVOMUZE.jpg'),
(68419, 4662, 'Assassino Sem Passado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fC8qIUqGJd7shCQG2vEHU5ldWVg.jpg'),
(68420, 4662, 'Assassino Sem Passado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oq0KzEwNPXOzI3wgZ3wRqXIVZmt.jpg'),
(68421, 4662, 'Assassino Sem Passado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vWaYaASnodX9Mvkse5yNb7nIUIt.jpg'),
(68422, 4662, 'Assassino Sem Passado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qTD2PrisYvDo4YWpaTDn2D4F8I8.jpg'),
(68423, 4662, 'Assassino Sem Passado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pM89MxojKGniDgJAlI81tG47JDW.jpg'),
(68424, 4662, 'Assassino Sem Passado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bDKYTJK2CZcF3IKmTKYFKze1vGG.jpg'),
(68425, 4662, 'Assassino Sem Passado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/frST7kboTKGa62pLG2SI48m78Wa.jpg'),
(68426, 4662, 'Assassino Sem Passado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i5bu72Jfii7CFOZHKwqkpULc78z.jpg'),
(68427, 4663, 'Central de Bicos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9nqDCUDmVfkbFLkjcyKAq6djAmA.jpg'),
(68428, 4663, 'Central de Bicos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68429, 4663, 'Central de Bicos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68430, 4663, 'Central de Bicos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68431, 4663, 'Central de Bicos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68432, 4663, 'Central de Bicos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68433, 4663, 'Central de Bicos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68434, 4663, 'Central de Bicos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68435, 4663, 'Central de Bicos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68436, 4663, 'Central de Bicos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68437, 4663, 'Central de Bicos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68438, 4663, 'Central de Bicos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68439, 4663, 'Central de Bicos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/194154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68440, 4663, 'Central de Bicos S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/194155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68441, 4663, 'Central de Bicos S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/194156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68442, 4663, 'Central de Bicos S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/194157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68443, 4663, 'Central de Bicos S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/194158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68444, 4663, 'Central de Bicos S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/194159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68445, 4663, 'Central de Bicos S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/194160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68446, 4663, 'Central de Bicos S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/194161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68447, 4664, 'Central de Bicos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68448, 4664, 'Central de Bicos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68449, 4664, 'Central de Bicos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68450, 4664, 'Central de Bicos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68451, 4664, 'Central de Bicos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68452, 4664, 'Central de Bicos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68453, 4664, 'Central de Bicos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68454, 4664, 'Central de Bicos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68455, 4664, 'Central de Bicos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68456, 4664, 'Central de Bicos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68457, 4664, 'Central de Bicos S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68458, 4664, 'Central de Bicos S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68459, 4664, 'Central de Bicos S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/194174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68460, 4664, 'Central de Bicos S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/194175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68461, 4664, 'Central de Bicos S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/194176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68462, 4664, 'Central de Bicos S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/194177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68463, 4664, 'Central de Bicos S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/194178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68464, 4664, 'Central de Bicos S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/194179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68465, 4664, 'Central de Bicos S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/194180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68466, 4664, 'Central de Bicos S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/194181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61v8yXSzdxPF6hq7WDwz3EChhKQ.jpg'),
(68467, 4665, 'Extracurricular S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a9d2o5gyH5WKX3A6T9QZhiVYDuN.jpg'),
(68468, 4665, 'Extracurricular S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zoy8QTamdjZx7JwIEohAYnb7scF.jpg'),
(68469, 4665, 'Extracurricular S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qWOVxe6Wur98UX8tojcNfx1Gszs.jpg'),
(68470, 4665, 'Extracurricular S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8eeCkHbyjoSSmCPtdJ4xR2lbGTX.jpg'),
(68471, 4665, 'Extracurricular S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qe5rCkHfTCn48Oz4Gq5qYqQlIVF.jpg'),
(68472, 4665, 'Extracurricular S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1sNwSO1wH5cVGUg38P219SS23GH.jpg'),
(68473, 4665, 'Extracurricular S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uYHLfC2kKvKih4MCytPr4s3jwR1.jpg'),
(68474, 4665, 'Extracurricular S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fGhUyfyXQ6IF39UdK05jukFuDKN.jpg'),
(68475, 4665, 'Extracurricular S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rwUYaJNlTlz4nRg6gDT5gsJdnZQ.jpg'),
(68476, 4665, 'Extracurricular S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cwWBgM75tDLlux5NbibNzyuGqr7.jpg'),
(68477, 4666, 'Galera FC S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l9fWTPIzPISwTmtEYwzHFoSiZ6q.jpg'),
(68478, 4666, 'Galera FC S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6JikX9DJOf51beqwoB0184oTWUK.jpg'),
(68479, 4666, 'Galera FC S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/51gOoEQvEZBbMsRE1ssmptqY3fd.jpg'),
(68480, 4666, 'Galera FC S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fLOJbFtILrSLV01NJt3oec1aJ3G.jpg'),
(68481, 4666, 'Galera FC S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dqUPoakm060EXoSyclekq5vIbkf.jpg'),
(68482, 4666, 'Galera FC S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/enFgkU7OMuWW1VAgZIngcSmgT9f.jpg'),
(68483, 4666, 'Galera FC S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vuVX22HaUpfaIH7pf2z1haVw3zR.jpg'),
(68484, 4666, 'Galera FC S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHLmU8eWkOfMa9JZO7vTkoRY2MS.jpg'),
(68485, 4667, 'Law & Order: Crime Organizado [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDVqhraEF3PInGokpn4WApkqyko.jpg'),
(68486, 4667, 'Law & Order: Crime Organizado [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AevkLn3cDytNA5NoA2GLIHJPYwK.jpg'),
(68487, 4667, 'Law & Order: Crime Organizado [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6CI8kmqTopou6hnRokeXh8GZ15o.jpg'),
(68488, 4667, 'Law & Order: Crime Organizado [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2V3gSicFibeOELK3wW42ftHZAS.jpg'),
(68489, 4667, 'Law & Order: Crime Organizado [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hwx3UXPbYz7OXXsmy4MsuM4R3Ap.jpg'),
(68490, 4667, 'Law & Order: Crime Organizado [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rgINc6nrCR0ZTnuqwI97K7pRPAr.jpg'),
(68491, 4667, 'Law & Order: Crime Organizado [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fwVAgLOzbxZHbwgFO09aCf3Zeb9.jpg'),
(68492, 4667, 'Law & Order: Crime Organizado [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nv7IQzXdb3GVdch69HlfFr15N3q.jpg'),
(68493, 4668, 'Law & Order: Crime Organizado [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjtPr33dnrkRgNaI5u8v87liGuZ.jpg'),
(68494, 4668, 'Law & Order: Crime Organizado [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/taKhY7JNW597Fi50SYJdPzbCU53.jpg'),
(68495, 4668, 'Law & Order: Crime Organizado [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lqS977Y7iDdJZyYkJCBuYeIxr7R.jpg'),
(68496, 4668, 'Law & Order: Crime Organizado [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289957.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68497, 4668, 'Law & Order: Crime Organizado [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289958.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68498, 4668, 'Law & Order: Crime Organizado [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289959.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68499, 4668, 'Law & Order: Crime Organizado [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289960.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68500, 4668, 'Law & Order: Crime Organizado [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289961.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68501, 4668, 'Law & Order: Crime Organizado [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/289962.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68502, 4668, 'Law & Order: Crime Organizado [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/289963.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68503, 4668, 'Law & Order: Crime Organizado [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/289964.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68504, 4668, 'Law & Order: Crime Organizado [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/289965.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68505, 4668, 'Law & Order: Crime Organizado [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/289966.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68506, 4668, 'Law & Order: Crime Organizado [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/289967.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68507, 4668, 'Law & Order: Crime Organizado [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/289968.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68508, 4668, 'Law & Order: Crime Organizado [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/289969.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68509, 4668, 'Law & Order: Crime Organizado [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/289970.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68510, 4668, 'Law & Order: Crime Organizado [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/289971.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68511, 4668, 'Law & Order: Crime Organizado [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/289972.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68512, 4668, 'Law & Order: Crime Organizado [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/289973.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68513, 4668, 'Law & Order: Crime Organizado [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/289974.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68514, 4668, 'Law & Order: Crime Organizado [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/289975.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68515, 4669, 'Law & Order: Crime Organizado [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289976.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68516, 4669, 'Law & Order: Crime Organizado [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289977.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68517, 4669, 'Law & Order: Crime Organizado [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289978.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68518, 4669, 'Law & Order: Crime Organizado [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289979.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68519, 4669, 'Law & Order: Crime Organizado [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289980.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68520, 4669, 'Law & Order: Crime Organizado [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289981.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(68521, 4669, 'Law & Order: Crime Organizado [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289982.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68522, 4669, 'Law & Order: Crime Organizado [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289983.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68523, 4669, 'Law & Order: Crime Organizado [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/289984.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68524, 4669, 'Law & Order: Crime Organizado [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/289985.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68525, 4669, 'Law & Order: Crime Organizado [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/289986.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68526, 4669, 'Law & Order: Crime Organizado [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/289987.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68527, 4669, 'Law & Order: Crime Organizado [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/289988.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68528, 4669, 'Law & Order: Crime Organizado [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/289989.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68529, 4669, 'Law & Order: Crime Organizado [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/289990.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68530, 4669, 'Law & Order: Crime Organizado [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/289991.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68531, 4669, 'Law & Order: Crime Organizado [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/289992.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68532, 4669, 'Law & Order: Crime Organizado [L] S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/289993.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68533, 4669, 'Law & Order: Crime Organizado [L] S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/289994.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68534, 4669, 'Law & Order: Crime Organizado [L] S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/289995.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68535, 4669, 'Law & Order: Crime Organizado [L] S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/289996.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68536, 4669, 'Law & Order: Crime Organizado [L] S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/289997.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68537, 4670, 'Law & Order: Crime Organizado [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289998.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68538, 4670, 'Law & Order: Crime Organizado [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289999.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68539, 4670, 'Law & Order: Crime Organizado [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290000.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68540, 4670, 'Law & Order: Crime Organizado [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290001.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68541, 4670, 'Law & Order: Crime Organizado [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/290002.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68542, 4670, 'Law & Order: Crime Organizado [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/290003.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68543, 4670, 'Law & Order: Crime Organizado [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/304350.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68544, 4670, 'Law & Order: Crime Organizado [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/308680.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68545, 4670, 'Law & Order: Crime Organizado [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/327706.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68546, 4670, 'Law & Order: Crime Organizado [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/332530.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68547, 4670, 'Law & Order: Crime Organizado [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/356352.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68548, 4670, 'Law & Order: Crime Organizado [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/356353.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68549, 4670, 'Law & Order: Crime Organizado [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/368229.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68550, 4671, 'Law & Order: Crime Organizado [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/775685.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68551, 4671, 'Law & Order: Crime Organizado [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/775686.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68552, 4671, 'Law & Order: Crime Organizado [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/783242.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68553, 4671, 'Law & Order: Crime Organizado [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/796480.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68554, 4671, 'Law & Order: Crime Organizado [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/796481.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68555, 4671, 'Law & Order: Crime Organizado [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/808362.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68556, 4671, 'Law & Order: Crime Organizado [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/808363.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68557, 4671, 'Law & Order: Crime Organizado [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/823126.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68558, 4671, 'Law & Order: Crime Organizado [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/834502.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68559, 4671, 'Law & Order: Crime Organizado [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/840849.mp4', 'http://gstaticontent.com/images/b96cd44a74cc068649d4dcdc4e2baa01.jpg'),
(68560, 4672, 'O Clube das Babás S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5RaWUop11DuVFQFe7SAHKzbpADB.jpg'),
(68561, 4672, 'O Clube das Babás S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yco4ny3KYFNa61fl3LHq3iFWZs.jpg'),
(68562, 4672, 'O Clube das Babás S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/plka9A4Xhq8vjy0uB7kD5x0NtJS.jpg'),
(68563, 4672, 'O Clube das Babás S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ueCgFpmDgwaHj9SgIbT049bWHGc.jpg'),
(68564, 4672, 'O Clube das Babás S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bJXAA0KHcxIyHD2xbcUbeLmXetH.jpg'),
(68565, 4672, 'O Clube das Babás S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3bYCdVkCBI4WtfZfIwsZ3a3liqD.jpg'),
(68566, 4672, 'O Clube das Babás S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lX9FFAYEYwDcWDG9SCcNUdXXnIT.jpg'),
(68567, 4672, 'O Clube das Babás S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/be3wTpj6CkQAFVdxe3aInrfFo8V.jpg'),
(68568, 4672, 'O Clube das Babás S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aJWEV3ZwMezMrpQVZnw6ULjyr5m.jpg'),
(68569, 4672, 'O Clube das Babás S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tasg8YqHfc7QwTYlqpVAqYtfbE9.jpg'),
(68570, 4673, 'O Clube das Babás S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eK1xqtMoAPHnIlhXOxG0BsZfrt6.jpg'),
(68571, 4673, 'O Clube das Babás S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ra6FH4im7jhKat8TNBGr9kMOKJV.jpg'),
(68572, 4673, 'O Clube das Babás S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pk3YFjatx860e47ZW4ZdUQvPpAc.jpg'),
(68573, 4673, 'O Clube das Babás S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h40RF4Almo4vTcRZVSyJNypKT2k.jpg'),
(68574, 4673, 'O Clube das Babás S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iR88ThMSOiRt2diw8Iqeu6SiVrY.jpg'),
(68575, 4673, 'O Clube das Babás S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yXBfwjDRs9LqoSS3qodlz2SL7aK.jpg'),
(68576, 4673, 'O Clube das Babás S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zGHLjPZ8BWGigv3YmBiTHPuWSbW.jpg'),
(68577, 4673, 'O Clube das Babás S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bcDN1Gi24FQCS8JKpQDkFAi2STv.jpg'),
(68578, 4674, 'Pretty Smart S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c2SGChDcE84O6pUjrX21AqJqHyU.jpg'),
(68579, 4674, 'Pretty Smart S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8MgZeXHx2EsvP21ELEvwxgGf22C.jpg'),
(68580, 4674, 'Pretty Smart S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cuxyFgWmPykqyP3ObLsHasdbkvY.jpg'),
(68581, 4674, 'Pretty Smart S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wVgoj8McgNOjrCdZ0f824zdrUVP.jpg'),
(68582, 4674, 'Pretty Smart S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ikV2oVeiS5veUlwcr5RFswYlJeA.jpg'),
(68583, 4674, 'Pretty Smart S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wO1VvaRrm0Dxk95naSBs7ecuMhZ.jpg'),
(68584, 4674, 'Pretty Smart S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5oiHH6XHbiVLzsAeqEkzekylnfZ.jpg'),
(68585, 4674, 'Pretty Smart S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/35EyyMji4Zj1lbRPdfRzewxdslB.jpg'),
(68586, 4674, 'Pretty Smart S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jLea9gCPOj35wPBWevGpayVcilv.jpg'),
(68587, 4674, 'Pretty Smart S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kj7CVYBzvsXTfGM3QVZGqEJlFxP.jpg'),
(68588, 4675, 'Sereno: O Panda Zen S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ZmT9eOjHXaEdQkpVTxAzbf5oyl.jpg'),
(68589, 4675, 'Sereno: O Panda Zen S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uo1yQXsS1HQQTDWBEUm3ZPxVj5x.jpg'),
(68590, 4675, 'Sereno: O Panda Zen S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yyP40GU8fPMO4tCn7TYx44uZc86.jpg'),
(68591, 4675, 'Sereno: O Panda Zen S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xev63JO6jFJJCNuSloARoqANdfF.jpg'),
(68592, 4675, 'Sereno: O Panda Zen S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jC23z6NDZ9YvT4WTSVO2Wu7Aj92.jpg'),
(68593, 4675, 'Sereno: O Panda Zen S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xkKbusSOEiARu3c47YjqFEAELEx.jpg'),
(68594, 4675, 'Sereno: O Panda Zen S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n3x860sjXh8o1wIoUiCjyKCrmeZ.jpg'),
(68595, 4675, 'Sereno: O Panda Zen S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7TO7DMIY4kf7zgsmbYtJu4dtUCM.jpg'),
(68596, 4675, 'Sereno: O Panda Zen S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7B2D60jS0r9WwVpUtHPZDMAtWNj.jpg'),
(68597, 4675, 'Sereno: O Panda Zen S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7B2D60jS0r9WwVpUtHPZDMAtWNj.jpg'),
(68598, 4675, 'Sereno: O Panda Zen S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zvpJznvl5FXC2U8RvcclB2Eh3cJ.jpg'),
(68599, 4675, 'Sereno: O Panda Zen S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hFvYDuR1lzm8HFMb12NWZ1ZvPEU.jpg'),
(68600, 4676, 'Um Conto Sombrio dos Grimm S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pNPumu77VpawFoMlCghJNjy8Qfq.jpg'),
(68601, 4676, 'Um Conto Sombrio dos Grimm S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Fdlpv1KkTOojlzpDM7TwBdWrfr.jpg'),
(68602, 4676, 'Um Conto Sombrio dos Grimm S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yjMc6WlzwVvPGJf7ixgyKu06ury.jpg'),
(68603, 4676, 'Um Conto Sombrio dos Grimm S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dxkqh2teyxAlXTEgA24DdtY2LYc.jpg'),
(68604, 4676, 'Um Conto Sombrio dos Grimm S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kZcoSAttwxHNN7qfXZx7PukWPiL.jpg'),
(68605, 4676, 'Um Conto Sombrio dos Grimm S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4eFRJW9sFGNqfuZEfOeIGzkzS9C.jpg'),
(68606, 4676, 'Um Conto Sombrio dos Grimm S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cOGWMg69JYJspt1iwLZqWJec0kp.jpg'),
(68607, 4676, 'Um Conto Sombrio dos Grimm S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7ZG4xlsAb9hcaBmOug3jy15tlK.jpg'),
(68608, 4676, 'Um Conto Sombrio dos Grimm S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kPiENUjWmGZWXNI6YapWvXqsR05.jpg'),
(68609, 4676, 'Um Conto Sombrio dos Grimm S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/GjTnyAkvHNnHfZviITFl528V1h.jpg'),
(68610, 4677, 'Uma Conspiração Sueca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x99f94eGqQOKCAkZbbRkwwIIm8B.jpg'),
(68611, 4677, 'Uma Conspiração Sueca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/HK6b7V7jSpSF9Kg9VlHRachphA.jpg'),
(68612, 4677, 'Uma Conspiração Sueca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nvBsKSZ3cVWp2o7O9ydaCCuQ3N3.jpg'),
(68613, 4677, 'Uma Conspiração Sueca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aH591Yfahu5sYGNLuk7K4maM6wr.jpg'),
(68614, 4677, 'Uma Conspiração Sueca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2EPg1Sz5G0Tk7zqrtufpFDOUZDL.jpg'),
(68615, 4677, 'Uma Conspiração Sueca S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rxDhpcGPr0ieh3oJS3V03zrKNYc.jpg'),
(68616, 4678, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9NJLwPvyRK6RmESDv7QWJgoTpq8.jpg'),
(68617, 4678, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mvqmtWIPcd1kJZNZZaMuGp2vyd7.jpg'),
(68618, 4678, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzzewwWCqtGXXqLZwlOMUj1P2uG.jpg'),
(68619, 4678, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ouBx9N8wMDLbIQJvZmU3G0A7fi7.jpg'),
(68620, 4678, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2vPYlQDay35v60Y9jf9jakYrWgn.jpg'),
(68621, 4678, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6hxfwDzT4UuEStoI6aokJYdnyzv.jpg'),
(68622, 4678, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uybsDwFmkBXcVkpdg782ujIsobu.jpg'),
(68623, 4678, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g79dkYvyV47cuUeaWXskWQMtctl.jpg'),
(68624, 4678, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dm6TXdcWO4L6MtrnXGY2FeZZpJP.jpg'),
(68625, 4678, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wasCtQtCCEXrhjLu5rRU0OpSVFo.jpg'),
(68626, 4678, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ua7E97xiNPCkEnjz04wfitj51Q6.jpg'),
(68627, 4678, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1yIvm0MXPyFhcRH67lERqprXN0.jpg'),
(68628, 4679, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j74lmOPIkATgai4htjOJuMlS1jr.jpg'),
(68629, 4679, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ggEF5YSXch2Kb9u67j6khATgJma.jpg'),
(68630, 4679, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x6afoBeorRGILf2oJKmSw5OLkCT.jpg'),
(68631, 4679, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfrjuWQZwNyGWa439aPHvoKM0SK.jpg'),
(68632, 4679, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/54kdy9Nbx0RkQa5xK1WPyvqhJ9v.jpg'),
(68633, 4679, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4M7b5PWq5AVL9hGX4J4B8TqVryH.jpg'),
(68634, 4679, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1VquId0PP7sYMfj0kQtQhH19aA2.jpg'),
(68635, 4679, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h7tYDiWHccgpMOfoLGRloNEOQeQ.jpg'),
(68636, 4679, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ccKuJPFDNprIsH13JF7juQEqL0Y.jpg'),
(68637, 4679, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sHAp1LZFSrX477w0MivQ1ZKfHVH.jpg'),
(68638, 4679, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ssibSGgyk8dGdFhKTkEv8PQlOO5.jpg'),
(68639, 4679, '100-man No Inochi No Ue Ni Ore Wa Tatteiru S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jmUkdl1fSxXCbIPcdhpagTrh0mu.jpg'),
(68640, 4680, 'A Escola do Alem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kkcOfSKLS4qP3PkDkkFZkgjnCuJ.jpg'),
(68641, 4680, 'A Escola do Alem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/soVAXwnS82TChi04bsORWCmNYOd.jpg'),
(68642, 4680, 'A Escola do Alem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/99NKzpQftf6swwAUBolV8QZrKyd.jpg'),
(68643, 4680, 'A Escola do Alem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vOgZ2j4m7zEdsTOhJdEj8F8W2DR.jpg'),
(68644, 4680, 'A Escola do Alem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1QwjMElt92mWhUbcZaCvfxRrkXi.jpg'),
(68645, 4680, 'A Escola do Alem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h4qt7GatXA92ieEyVZAI5c5tQdo.jpg'),
(68646, 4680, 'A Escola do Alem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xWxnVrpytFSrXxG58D9cQZrHFNm.jpg'),
(68647, 4680, 'A Escola do Alem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f6nM4I1GBjSDda6yvbAUKvbDLjJ.jpg'),
(68648, 4681, 'B Positive S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uOYwTvHhnhxyPbm4NtHLCJxJrD2.jpg'),
(68649, 4681, 'B Positive S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gY1tuciFNqOQDYC1QLI6zCP2ftG.jpg'),
(68650, 4681, 'B Positive S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lvKB4RkpmxukwWfnrKYaj0OJ7X.jpg'),
(68651, 4681, 'B Positive S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xSGBZISQPWrrNuaukgCn7ErJZEf.jpg'),
(68652, 4681, 'B Positive S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/90wgEhBuC7QeE0GWXlZ55z0nlvc.jpg'),
(68653, 4681, 'B Positive S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o5SLczuwnskiWzJ2h13yZGLYDQm.jpg'),
(68654, 4681, 'B Positive S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/olTyB6jNeKqoVvVxdomA38QsjDB.jpg'),
(68655, 4681, 'B Positive S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g8801bqGip0ehmVMP5IZcfEKdXu.jpg'),
(68656, 4681, 'B Positive S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5VL6zS64HvWumSZuYymYip0hgsC.jpg'),
(68657, 4681, 'B Positive S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ivh6DTgzBhdz1Vl7yFxUSIMbHI.jpg'),
(68658, 4681, 'B Positive S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nwP8aXn1HuJfBiabThwR6meUaod.jpg'),
(68659, 4681, 'B Positive S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7RMNBz6NYjW6eTXnDbmLi3ui1p.jpg'),
(68660, 4681, 'B Positive S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/177957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fZ5Cx8ZCW7a3oDeufkoyZaN8Ma.jpg'),
(68661, 4681, 'B Positive S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/177958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oXJ29xMfrfVlw0zyxkiNm0ID8Rj.jpg'),
(68662, 4681, 'B Positive S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/177959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDZn9FnJpDhTUXykwBcApDoEBSG.jpg'),
(68663, 4681, 'B Positive S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/177960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qOYFJ6msmJYmrkzz2sKhbKm7DsE.jpg'),
(68664, 4681, 'B Positive S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/177961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Q6x59wg0uZlFjNyjpOZ4bQRMG4.jpg'),
(68665, 4681, 'B Positive S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/177962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6xKhFbC988N5LnYsEUX27Ubsoni.jpg'),
(68666, 4682, 'B Positive S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177963.mp4', 'http://timg.bdta.pro/images/222e3acb4e76dc262edeb59c877d731d.jpg'),
(68667, 4682, 'B Positive S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177964.mp4', 'http://timg.bdta.pro/images/3649dd8f12d782bc2abb7dc4a8a64da4.jpg'),
(68668, 4682, 'B Positive S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177965.mp4', 'http://timg.bdta.pro/images/4edcdd7d712bbfb58574af33ee482f92.jpg'),
(68669, 4682, 'B Positive S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177966.mp4', 'http://timg.bdta.pro/images/224b99ecced60189d85e717b586ff957.jpg'),
(68670, 4682, 'B Positive S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177967.mp4', 'http://timg.bdta.pro/images/7216791d70cb8ff852679fe48ff1fac5.jpg'),
(68671, 4682, 'B Positive S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177968.mp4', 'http://timg.bdta.pro/images/689df77835e51f9b34ac21cde72963ee.jpg'),
(68672, 4682, 'B Positive S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177969.mp4', 'http://timg.bdta.pro/images/6f355e1b62b92f5db16f66bae501b54f.jpg'),
(68673, 4682, 'B Positive S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177970.mp4', 'http://timg.bdta.pro/images/01df850349ce059c97576ed5274f1609.jpg'),
(68674, 4682, 'B Positive S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177971.mp4', 'http://timg.bdta.pro/images/77b0a725b8aa99e8602b7ba48c764bcd.jpg'),
(68675, 4682, 'B Positive S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177972.mp4', 'http://timg.bdta.pro/images/de235af45da9ed4d8c3805a742386e81.jpg'),
(68676, 4682, 'B Positive S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kpahHIuvaUJgTSiNMhz3yjgsAtq.jpg'),
(68677, 4682, 'B Positive S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kpahHIuvaUJgTSiNMhz3yjgsAtq.jpg'),
(68678, 4682, 'B Positive S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/177975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kpahHIuvaUJgTSiNMhz3yjgsAtq.jpg'),
(68679, 4682, 'B Positive S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/177976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kpahHIuvaUJgTSiNMhz3yjgsAtq.jpg'),
(68680, 4682, 'B Positive S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/177977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kpahHIuvaUJgTSiNMhz3yjgsAtq.jpg'),
(68681, 4682, 'B Positive S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/177978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kpahHIuvaUJgTSiNMhz3yjgsAtq.jpg'),
(68682, 4683, 'Corrida ao Redor da Terra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uJXM4HAo2XsH1M4lZDdfbzKFtrE.jpg'),
(68683, 4683, 'Corrida ao Redor da Terra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wuGoU57E9J9nuIwtA1QDtBDBaMe.jpg'),
(68684, 4683, 'Corrida ao Redor da Terra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mEFkya0XoeXdvaBgXia8YyUjEjN.jpg'),
(68685, 4683, 'Corrida ao Redor da Terra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2SSKR3vYeCEyNhKvKhj4J3yvvo3.jpg'),
(68686, 4683, 'Corrida ao Redor da Terra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l5NF7n9tZsmuikyFDMBiJrOSJwf.jpg'),
(68687, 4683, 'Corrida ao Redor da Terra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zlYEsLOO3PEojbbu4LrbgvdXcer.jpg'),
(68688, 4683, 'Corrida ao Redor da Terra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v5DtYmY3WjgJALyoZX982HT85yT.jpg'),
(68689, 4684, 'Craftopia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v0EnN6ypPUuecxfumzrjzRbMkaS.jpg'),
(68690, 4684, 'Craftopia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/doWqsIvMzYEJuFKuhihwbPFB2uP.jpg'),
(68691, 4684, 'Craftopia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A6XVEGup4i0hNYAGa4aGB888yIu.jpg'),
(68692, 4684, 'Craftopia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9LPU6Zt6jMSa9qDdPCG7LhHO4d5.jpg'),
(68693, 4684, 'Craftopia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p8Ujw3uEfFeIMmWh9KY1g7DhN9w.jpg'),
(68694, 4684, 'Craftopia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2zzNFkg9Kua8k3WgESjr6V0OebO.jpg'),
(68695, 4684, 'Craftopia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A7BWVWCKeT0uqlix6mW2ytMpVm9.jpg'),
(68696, 4684, 'Craftopia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgtsPurBDIdgNt59G2xS94ceZMw.jpg'),
(68697, 4684, 'Craftopia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kP7ZHDaCW45EeuupA8XhZWtCs68.jpg'),
(68698, 4684, 'Craftopia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vKbvFkdFoZsGlhSzzRb4s36TKGY.jpg'),
(68699, 4684, 'Craftopia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/44MzEvOYnrxw5DtJLNuakzk7Jrm.jpg'),
(68700, 4684, 'Craftopia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5jink1jHPvku2KAIEd0hjuNkBwz.jpg'),
(68701, 4685, 'Eu Sei o Que Vocês Fizeram no Verão Passado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/71R2G1bfIoThjlQ0lBVpImb8QVL.jpg'),
(68702, 4685, 'Eu Sei o Que Vocês Fizeram no Verão Passado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ruigqjr6xcfZjUnnp7hdTXEzGb.jpg'),
(68703, 4685, 'Eu Sei o Que Vocês Fizeram no Verão Passado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Y6sK5lRIWAuXlnqErYIq9IXegJ.jpg'),
(68704, 4685, 'Eu Sei o Que Vocês Fizeram no Verão Passado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yIxBgAiRjkkWfll8oOrc5C8diSM.jpg'),
(68705, 4685, 'Eu Sei o Que Vocês Fizeram no Verão Passado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167704.mp4', 'http://image.tmdb.org/t/p/w1280/hpN43ULSe7BrIONniBIFfxPQPq7.jpg'),
(68706, 4685, 'Eu Sei o Que Vocês Fizeram no Verão Passado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2mH9EpncprfSc1DxXHZ1NALHwRG.jpg'),
(68707, 4685, 'Eu Sei o Que Vocês Fizeram no Verão Passado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ayAdRQ5ZWztPvEKTUXKR6zWfe33.jpg'),
(68708, 4685, 'Eu Sei o Que Vocês Fizeram no Verão Passado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167707.mp4', 'http://image.tmdb.org/t/p/w1280/5EGt3rlQDGfxs87RdQLajRFdR6g.jpg'),
(68709, 4686, 'Eu Sei o Que Vocês Fizeram no Verão Passado [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/71R2G1bfIoThjlQ0lBVpImb8QVL.jpg'),
(68710, 4686, 'Eu Sei o Que Vocês Fizeram no Verão Passado [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ruigqjr6xcfZjUnnp7hdTXEzGb.jpg'),
(68711, 4686, 'Eu Sei o Que Vocês Fizeram no Verão Passado [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Y6sK5lRIWAuXlnqErYIq9IXegJ.jpg'),
(68712, 4686, 'Eu Sei o Que Vocês Fizeram no Verão Passado [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yIxBgAiRjkkWfll8oOrc5C8diSM.jpg'),
(68713, 4686, 'Eu Sei o Que Vocês Fizeram no Verão Passado [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167696.mp4', 'http://image.tmdb.org/t/p/w1280/hpN43ULSe7BrIONniBIFfxPQPq7.jpg'),
(68714, 4686, 'Eu Sei o Que Vocês Fizeram no Verão Passado [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2mH9EpncprfSc1DxXHZ1NALHwRG.jpg'),
(68715, 4686, 'Eu Sei o Que Vocês Fizeram no Verão Passado [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ayAdRQ5ZWztPvEKTUXKR6zWfe33.jpg'),
(68716, 4686, 'Eu Sei o Que Vocês Fizeram no Verão Passado [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5EGt3rlQDGfxs87RdQLajRFdR6g.jpg'),
(68717, 4687, 'Q: No Olho da Tempestade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2cIcrUzA7UhEHc7oDhF1V19AdIJ.jpg'),
(68718, 4687, 'Q: No Olho da Tempestade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2YY2Rj5nAkSTDBFSeuxLOADx2dy.jpg'),
(68719, 4687, 'Q: No Olho da Tempestade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/95hXM156XmQOIYYnHXjJZO1G9GB.jpg'),
(68720, 4687, 'Q: No Olho da Tempestade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Abcvh00hQKo4ILrQ8KnSaEwZaU5.jpg'),
(68721, 4687, 'Q: No Olho da Tempestade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3iFImmylWVRQuu3xQdjcHEBPESL.jpg'),
(68722, 4687, 'Q: No Olho da Tempestade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zd6EhTTQIuj9aCc0trFPyuQRuCM.jpg'),
(68723, 4688, 'The Great North S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4YHn83H2lDuXePKPZxxkuXhdHHc.jpg'),
(68724, 4688, 'The Great North S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oLCopn1ay9xg9lvbcPMqGHcEg8g.jpg'),
(68725, 4688, 'The Great North S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qKjf2ZCiPLCCZ2kzphB8Y0ctoeI.jpg'),
(68726, 4688, 'The Great North S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kKtXqDFszAwttfnbJyNChYzm0r.jpg'),
(68727, 4688, 'The Great North S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sLaYwYGzfkAvZQ63D4EHcfwDWqz.jpg'),
(68728, 4688, 'The Great North S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f70ZQKs4jbrNwba89zWlq47TWcp.jpg'),
(68729, 4688, 'The Great North S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/14MImHpmB5yjfAUPiDADD2ZP6y8.jpg'),
(68730, 4688, 'The Great North S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xyc7NW0aN7bUee611jg4bL7nUem.jpg'),
(68731, 4688, 'The Great North S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4mRrzptAl25iNH7Dd7gy6iUMi59.jpg'),
(68732, 4688, 'The Great North S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mi0wFHpLwumQgNZ81qb8s7FWxks.jpg'),
(68733, 4688, 'The Great North S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e4EtkUD6vbYWI9HvHbCRNrEoMBQ.jpg'),
(68734, 4689, 'The Great North S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220435.mp4', 'http://timg.bdta.pro/images/8ecce2f734ca955f3da5912aed851412.jpg'),
(68735, 4689, 'The Great North S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220436.mp4', 'http://timg.bdta.pro/images/8327b946bb2b395a27427c3c6acfaf0b.jpg'),
(68736, 4689, 'The Great North S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220437.mp4', 'http://timg.bdta.pro/images/2f8d9293c9de491040db2bda0e99397e.jpg'),
(68737, 4689, 'The Great North S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220438.mp4', 'http://timg.bdta.pro/images/a575fb4365579b51c1716390d94f082f.jpg'),
(68738, 4689, 'The Great North S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220439.mp4', 'http://timg.bdta.pro/images/f5bb36bf896c2ec0ebf96b145d508ab0.jpg'),
(68739, 4689, 'The Great North S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220440.mp4', 'http://timg.bdta.pro/images/3f95137096865d3bc4858fb50df03c31.jpg'),
(68740, 4689, 'The Great North S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220441.mp4', 'http://timg.bdta.pro/images/16278a17fd16b99ec3fbbe3ac8e5a2cb.jpg'),
(68741, 4689, 'The Great North S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220442.mp4', 'http://timg.bdta.pro/images/ba5d7d14fa3b3c472478c810467a9b38.jpg'),
(68742, 4689, 'The Great North S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220443.mp4', 'http://timg.bdta.pro/images/27a20ca44ab69a653a202d2c8244bb73.jpg'),
(68743, 4689, 'The Great North S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220444.mp4', 'http://timg.bdta.pro/images/78b4e41379615c1e271e0d79d37fc9b6.jpg'),
(68744, 4689, 'The Great North S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220445.mp4', 'http://timg.bdta.pro/images/bbb0ac9be43b8c804fbaba5c017e5a80.jpg'),
(68745, 4689, 'The Great North S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220446.mp4', 'http://timg.bdta.pro/images/f44588fd9893684f2e5df86aa0b4afa0.jpg'),
(68746, 4689, 'The Great North S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220447.mp4', 'http://timg.bdta.pro/images/f968c2ed482a4c87f5bc15d702814f36.jpg'),
(68747, 4689, 'The Great North S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220448.mp4', 'http://timg.bdta.pro/images/95b1599d04e491420f33f13e24fb1e66.jpg'),
(68748, 4689, 'The Great North S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220449.mp4', 'http://timg.bdta.pro/images/3b506afd34d630c5348083079793ebe5.jpg'),
(68749, 4689, 'The Great North S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220450.mp4', 'http://timg.bdta.pro/images/1fa8e6238cc00c5bdc6e5bd8c78567d1.jpg'),
(68750, 4689, 'The Great North S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/220451.mp4', 'http://timg.bdta.pro/images/b8f041982b82034a84b557c67afd75c6.jpg'),
(68751, 4689, 'The Great North S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/220452.mp4', 'http://timg.bdta.pro/images/a1f0a066b68a48543306f364bb19fadb.jpg'),
(68752, 4689, 'The Great North S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/220453.mp4', 'http://timg.bdta.pro/images/64afc6ff7e1f896a978f728aaa037688.jpg'),
(68753, 4689, 'The Great North S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/220454.mp4', 'http://timg.bdta.pro/images/cb34e8ec06b75bfb882c600926466983.jpg'),
(68754, 4689, 'The Great North S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/220455.mp4', 'http://timg.bdta.pro/images/e033e0c2fe70b2169800f7104f5eb881.jpg'),
(68755, 4689, 'The Great North S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/220456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68756, 4690, 'The Great North S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jugINpYeoZNA3RVx83bNMjnQgkJ.jpg'),
(68757, 4690, 'The Great North S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/85YOtFu5Z1V6xURLOPgPlELOXab.jpg'),
(68758, 4690, 'The Great North S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4u01BGVlM11WQjROYXzmr91TQiV.jpg'),
(68759, 4690, 'The Great North S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9l1RDR9547cP2JiCXJxUxaHC6TQ.jpg'),
(68760, 4690, 'The Great North S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qPIZxneWke9HpsrGHucZWUmbfe4.jpg'),
(68761, 4690, 'The Great North S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qehUpI5zukwNRFhy5e4grn2qXk1.jpg'),
(68762, 4690, 'The Great North S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eZ6XL6jo6UB2YP6XV9QZuc7XWXo.jpg'),
(68763, 4690, 'The Great North S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/TFN6JY27pSKDr32SoXj5CIvXOX.jpg'),
(68764, 4690, 'The Great North S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220465.mp4', 'http://image.tmdb.org/t/p/w1280/acxw1TVsEu2OqQqm8b4LE1sce9N.jpg'),
(68765, 4690, 'The Great North S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220466.mp4', 'http://image.tmdb.org/t/p/w1280/1TUNJOTeBtPfQfbHTxYCdFe0n97.jpg'),
(68766, 4690, 'The Great North S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220467.mp4', 'http://image.tmdb.org/t/p/w1280/g8gdMEBepYa8ze83X9jrBdxHYkn.jpg'),
(68767, 4690, 'The Great North S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68768, 4690, 'The Great North S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68769, 4690, 'The Great North S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68770, 4690, 'The Great North S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68771, 4690, 'The Great North S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68772, 4690, 'The Great North S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/220473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68773, 4690, 'The Great North S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/220474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68774, 4690, 'The Great North S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/220475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68775, 4690, 'The Great North S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/220476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68776, 4690, 'The Great North S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/220477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68777, 4690, 'The Great North S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/220478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68778, 4691, 'The Great North S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/270672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68779, 4691, 'The Great North S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/277482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68780, 4691, 'The Great North S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/288205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68781, 4691, 'The Great North S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/351082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lU8ker3itM5MUIWVlpHSsNC69e8.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(68782, 4691, 'The Great North S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/299029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68783, 4691, 'The Great North S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/303875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68784, 4691, 'The Great North S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/307121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68785, 4691, 'The Great North S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/320416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68786, 4691, 'The Great North S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/326665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68787, 4691, 'The Great North S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/326666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68788, 4691, 'The Great North S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/332127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68789, 4691, 'The Great North S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/336947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68790, 4691, 'The Great North S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/342838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68791, 4691, 'The Great North S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/351092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68792, 4691, 'The Great North S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/372828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68793, 4691, 'The Great North S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/457126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68794, 4691, 'The Great North S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/457127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68795, 4691, 'The Great North S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/457128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68796, 4691, 'The Great North S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/457129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68797, 4691, 'The Great North S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/457130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68798, 4692, 'The Great North S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/667340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68799, 4692, 'The Great North S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/708800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68800, 4692, 'The Great North S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/723040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68801, 4692, 'The Great North S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/734124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68802, 4692, 'The Great North S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/757902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68803, 4692, 'The Great North S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/778581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68804, 4692, 'The Great North S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/778582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68805, 4692, 'The Great North S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/785512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68806, 4692, 'The Great North S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/876965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68807, 4692, 'The Great North S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/876966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68808, 4692, 'The Great North S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/876967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68809, 4692, 'The Great North S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/876968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68810, 4692, 'The Great North S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/876969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68811, 4692, 'The Great North S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/876970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68812, 4692, 'The Great North S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/876971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68813, 4692, 'The Great North S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/876972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68814, 4692, 'The Great North S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/879879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68815, 4692, 'The Great North S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/888137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68816, 4692, 'The Great North S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/892191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68817, 4692, 'The Great North S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/892192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68818, 4692, 'The Great North S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/892193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68819, 4692, 'The Great North S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/892194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugOLSKCV4EicJ13kXfSNJXQSqQW.jpg'),
(68820, 4693, 'Tico e Teco: Vida no Parque S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hYGwNvHAwB0AlcZ0DumdlUp7NWD.jpg'),
(68821, 4693, 'Tico e Teco: Vida no Parque S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXrdr6zutJyr0r2yDWOlhYqIk5t.jpg'),
(68822, 4693, 'Tico e Teco: Vida no Parque S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXrdr6zutJyr0r2yDWOlhYqIk5t.jpg'),
(68823, 4693, 'Tico e Teco: Vida no Parque S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXrdr6zutJyr0r2yDWOlhYqIk5t.jpg'),
(68824, 4693, 'Tico e Teco: Vida no Parque S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXrdr6zutJyr0r2yDWOlhYqIk5t.jpg'),
(68825, 4693, 'Tico e Teco: Vida no Parque S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXrdr6zutJyr0r2yDWOlhYqIk5t.jpg'),
(68826, 4693, 'Tico e Teco: Vida no Parque S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXrdr6zutJyr0r2yDWOlhYqIk5t.jpg'),
(68827, 4693, 'Tico e Teco: Vida no Parque S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXrdr6zutJyr0r2yDWOlhYqIk5t.jpg'),
(68828, 4693, 'Tico e Teco: Vida no Parque S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXrdr6zutJyr0r2yDWOlhYqIk5t.jpg'),
(68829, 4693, 'Tico e Teco: Vida no Parque S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXrdr6zutJyr0r2yDWOlhYqIk5t.jpg'),
(68830, 4693, 'Tico e Teco: Vida no Parque S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rNzqbdaorEaoOM2sh3ajuVay20.jpg'),
(68831, 4693, 'Tico e Teco: Vida no Parque S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXrdr6zutJyr0r2yDWOlhYqIk5t.jpg'),
(68832, 4694, 'À Procura do Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v1BHgPyfBMlHCQKzHMDlVDZ8HvY.jpg'),
(68833, 4694, 'À Procura do Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rqULtDoNrWwgHU1t702nlxwP41I.jpg'),
(68834, 4694, 'À Procura do Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/FpFbEiMwdUDWgFKwfzoPgUvoB5.jpg'),
(68835, 4695, 'American Gothic [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6gw9T29LzmxgDZ6O66vtP5EBJph.jpg'),
(68836, 4695, 'American Gothic [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9T9ICd59Xl4aES9Vqh3SJ3QPo7O.jpg'),
(68837, 4695, 'American Gothic [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rdtVaVkZQ2vfEvgnZzzJIA9bTE1.jpg'),
(68838, 4695, 'American Gothic [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o441iUmcNSS8jfahGu1KVBZIrrj.jpg'),
(68839, 4695, 'American Gothic [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vrCbbfnPsAhkmU31dN0O4h9fv0l.jpg'),
(68840, 4695, 'American Gothic [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wr3qYKSinUD1alZppqOVKcsGr8x.jpg'),
(68841, 4695, 'American Gothic [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nh5xSHCLFw5X52pzJ7UXOguHvdk.jpg'),
(68842, 4695, 'American Gothic [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jQlrmZ5EbVSYVnUeAPVXnY6CJNg.jpg'),
(68843, 4695, 'American Gothic [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fj0YLHd1LtlJNcg434utzGGAShs.jpg'),
(68844, 4695, 'American Gothic [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xIR7CUSQcrehKpJZvsGlJuP2FEq.jpg'),
(68845, 4695, 'American Gothic [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fi0PToLxA78JNGzSEZiBBAglrNd.jpg'),
(68846, 4695, 'American Gothic [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4YwvLHttO53e2IDk5yp2V7O5inF.jpg'),
(68847, 4695, 'American Gothic [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3M3NCNZXb3Dlth9LajGpnrKn7fY.jpg'),
(68848, 4696, 'American Horror Stories S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mqHMrPiTDrE7wPlCFmlASS1aBhe.jpg'),
(68849, 4696, 'American Horror Stories S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kECJcX6a9EBylGuh6kxwJzdiDXv.jpg'),
(68850, 4696, 'American Horror Stories S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVgenF9p4Eg3UB76IHVA80F7n6g.jpg'),
(68851, 4696, 'American Horror Stories S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sxpExSiylQzGE3GZ1KHaV2GnBDh.jpg'),
(68852, 4696, 'American Horror Stories S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7iUkFRiMWRUVxJ2WmfpmBskLup.jpg'),
(68853, 4696, 'American Horror Stories S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8htU1QMf2GD4rFiLxjs47BdSI9f.jpg'),
(68854, 4696, 'American Horror Stories S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nSksRvEUA9UqX7RJ2XVBB89uLUA.jpg'),
(68855, 4697, 'American Horror Stories S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249811.mp4', 'http://timg.bdta.pro/images/93a1e51de00a8aa158f4eefdbd32909e.jpg'),
(68856, 4697, 'American Horror Stories S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249812.mp4', 'http://timg.bdta.pro/images/367f5ff99843cb62b9196ca8ee0b2108.jpg'),
(68857, 4697, 'American Horror Stories S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249813.mp4', 'http://timg.bdta.pro/images/d9937ba95a7bda9899df3e06b2c2d8bd.jpg'),
(68858, 4697, 'American Horror Stories S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249814.mp4', 'http://timg.bdta.pro/images/afcc470c0809662fa05198971d75c9cd.jpg'),
(68859, 4697, 'American Horror Stories S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249815.mp4', 'http://timg.bdta.pro/images/68a970a0595511238793aab2ae774b85.jpg'),
(68860, 4697, 'American Horror Stories S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249816.mp4', 'http://timg.bdta.pro/images/22aeefa6c5549c56927731a7c9447938.jpg'),
(68861, 4697, 'American Horror Stories S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249817.mp4', 'http://timg.bdta.pro/images/b19b197d21f3e6d640dfffc01ee6d6ae.jpg'),
(68862, 4697, 'American Horror Stories S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249818.mp4', 'http://timg.bdta.pro/images/3a83a2fd048bc77d74bff67335624670.jpg'),
(68863, 4698, 'American Horror Stories S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/50AuXrycD7Q61o0Kppby5DTVOKP.jpg'),
(68864, 4698, 'American Horror Stories S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/50AuXrycD7Q61o0Kppby5DTVOKP.jpg'),
(68865, 4698, 'American Horror Stories S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/50AuXrycD7Q61o0Kppby5DTVOKP.jpg'),
(68866, 4698, 'American Horror Stories S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/50AuXrycD7Q61o0Kppby5DTVOKP.jpg'),
(68867, 4698, 'American Horror Stories S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/50AuXrycD7Q61o0Kppby5DTVOKP.jpg'),
(68868, 4698, 'American Horror Stories S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/50AuXrycD7Q61o0Kppby5DTVOKP.jpg'),
(68869, 4698, 'American Horror Stories S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/50AuXrycD7Q61o0Kppby5DTVOKP.jpg'),
(68870, 4698, 'American Horror Stories S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/508585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/50AuXrycD7Q61o0Kppby5DTVOKP.jpg'),
(68871, 4698, 'American Horror Stories S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/508586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/50AuXrycD7Q61o0Kppby5DTVOKP.jpg'),
(68872, 4699, 'As Novas Aventuras do Superman S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rTxgUc1yDLD27DrgI2ATZ2pL1ko.jpg'),
(68873, 4699, 'As Novas Aventuras do Superman S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1PI9oubkFAjGhHoEYPG00o4Gl6x.jpg'),
(68874, 4699, 'As Novas Aventuras do Superman S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fATS90FjAilkF24tRciB0r0is4B.jpg'),
(68875, 4699, 'As Novas Aventuras do Superman S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ej2LZAtpIO5JSDRSAGvhjrlIFPl.jpg'),
(68876, 4699, 'As Novas Aventuras do Superman S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vplrwOSaL1sKaW0FKxpPxCSSbsz.jpg'),
(68877, 4699, 'As Novas Aventuras do Superman S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m6Wh7QN3u1SPtneNcCBfTFn2VzD.jpg'),
(68878, 4699, 'As Novas Aventuras do Superman S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6NMEmzXep5FHL2rEJiwWZc1RUBU.jpg'),
(68879, 4699, 'As Novas Aventuras do Superman S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Z3Vpv0GckNKOsZRAOSdXGN478c.jpg'),
(68880, 4699, 'As Novas Aventuras do Superman S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Wygc1rwo1JzubB5iU0bz6jngdA.jpg'),
(68881, 4699, 'As Novas Aventuras do Superman S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fA2ZBERezRxoW2YtzWa2D3uTwBm.jpg'),
(68882, 4699, 'As Novas Aventuras do Superman S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/daTfLUH8xWEJfffjoCIG6ADWYBm.jpg'),
(68883, 4699, 'As Novas Aventuras do Superman S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jeNvSZ1tZFvVOr66OFwUD8Jecxc.jpg'),
(68884, 4699, 'As Novas Aventuras do Superman S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1UMDQXmNfKyLJaw0H7v2lGtyoNf.jpg'),
(68885, 4699, 'As Novas Aventuras do Superman S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/159336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nU35B9R18Kgpm0VPGDT9HEEeaZP.jpg'),
(68886, 4699, 'As Novas Aventuras do Superman S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/159337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t57B39QCr2lTn4pv9jlbbzXXZiQ.jpg'),
(68887, 4699, 'As Novas Aventuras do Superman S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/159338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4kMCb7uWCq6MSF8Io2LKB9WUdvg.jpg'),
(68888, 4699, 'As Novas Aventuras do Superman S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/159339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bBGvHN8xBEr8s6DJBzAXSGazi36.jpg'),
(68889, 4699, 'As Novas Aventuras do Superman S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/159340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hkY8kCQTKwVCp8tAfEIkdExsFpu.jpg'),
(68890, 4700, 'As Novas Aventuras do Superman S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(68891, 4700, 'As Novas Aventuras do Superman S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(68892, 4700, 'As Novas Aventuras do Superman S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(68893, 4700, 'As Novas Aventuras do Superman S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(68894, 4700, 'As Novas Aventuras do Superman S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(68895, 4700, 'As Novas Aventuras do Superman S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(68896, 4700, 'As Novas Aventuras do Superman S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(68897, 4700, 'As Novas Aventuras do Superman S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(68898, 4701, 'As Novas Aventuras do Superman S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(68899, 4701, 'As Novas Aventuras do Superman S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(68900, 4701, 'As Novas Aventuras do Superman S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(68901, 4701, 'As Novas Aventuras do Superman S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(68902, 4701, 'As Novas Aventuras do Superman S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(68903, 4701, 'As Novas Aventuras do Superman S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(68904, 4701, 'As Novas Aventuras do Superman S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(68905, 4701, 'As Novas Aventuras do Superman S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(68906, 4702, 'Beartown S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ePNMlQvgvYvNEvDWEmc7UnMTLi.jpg'),
(68907, 4702, 'Beartown S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jdljjICliAAcny7aRJydkltqpUz.jpg'),
(68908, 4702, 'Beartown S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gvEWuz2f7gCPSI8CMGuyGlN6ftv.jpg'),
(68909, 4702, 'Beartown S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sQ9hV2yk2kWZ5EHee1ExZX8D1q1.jpg'),
(68910, 4702, 'Beartown S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjg4McYoamD8eSNJlhBH5jfAwkK.jpg'),
(68911, 4703, 'Casamento às Cegas: Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68912, 4703, 'Casamento às Cegas: Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68913, 4703, 'Casamento às Cegas: Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68914, 4703, 'Casamento às Cegas: Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68915, 4703, 'Casamento às Cegas: Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68916, 4703, 'Casamento às Cegas: Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68917, 4703, 'Casamento às Cegas: Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68918, 4703, 'Casamento às Cegas: Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68919, 4703, 'Casamento às Cegas: Brasil S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68920, 4703, 'Casamento às Cegas: Brasil S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68921, 4704, 'Casamento às Cegas: Brasil S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f7uRNZPXhIzs4WT5SgpomhUpKxX.jpg'),
(68922, 4704, 'Casamento às Cegas: Brasil S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/duptBlXzqmKT4IQDTu3z5NFoua5.jpg'),
(68923, 4704, 'Casamento às Cegas: Brasil S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5geN8AtisYbz7f3mnc3k3c9b77j.jpg'),
(68924, 4704, 'Casamento às Cegas: Brasil S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZuSEXXxzGAGqzBGhEuJfXrburV.jpg'),
(68925, 4704, 'Casamento às Cegas: Brasil S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rPy7WR6UineNX7TgAruwrlUv4IP.jpg'),
(68926, 4704, 'Casamento às Cegas: Brasil S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jdsS9oWQfjc1GU7AfnnxbwPxOpk.jpg'),
(68927, 4704, 'Casamento às Cegas: Brasil S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5RsGj2G0705sxOFOLPFdGWZy1a.jpg'),
(68928, 4704, 'Casamento às Cegas: Brasil S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vl5PYpGZaz5xdEvS9HLJs5QaASv.jpg'),
(68929, 4704, 'Casamento às Cegas: Brasil S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6pAfZC5xWvnpr7v8uQERjeOaf53.jpg'),
(68930, 4704, 'Casamento às Cegas: Brasil S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jT8GTVtaydKPCV4FVXKrKIgFMWv.jpg'),
(68931, 4704, 'Casamento às Cegas: Brasil S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68932, 4705, 'Casamento às Cegas: Brasil S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dvi1mlPiXPIc1tWxr65TOaHSX54.jpg'),
(68933, 4705, 'Casamento às Cegas: Brasil S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qvkkXixNVdlefdCEQDwTdOhXaAq.jpg'),
(68934, 4705, 'Casamento às Cegas: Brasil S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3NN052ZMmP0mgKF3gfmx2Wyiyv.jpg'),
(68935, 4705, 'Casamento às Cegas: Brasil S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xkiebB1Db8QUbOz5Ab4zSWbBhRE.jpg'),
(68936, 4705, 'Casamento às Cegas: Brasil S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68937, 4705, 'Casamento às Cegas: Brasil S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68938, 4705, 'Casamento às Cegas: Brasil S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68939, 4705, 'Casamento às Cegas: Brasil S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68940, 4705, 'Casamento às Cegas: Brasil S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217867.mp4', 'http://image.tmdb.org/t/p/w1280/jFCdrQgcEgl6YnVOTCWbEovmrBs.jpg'),
(68941, 4705, 'Casamento às Cegas: Brasil S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217868.mp4', 'http://image.tmdb.org/t/p/w1280/gT5aBITCVMOWXbi8TN0sh00gGsI.jpg'),
(68942, 4705, 'Casamento às Cegas: Brasil S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68943, 4706, 'Casamento às Cegas: Brasil S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/392746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68944, 4706, 'Casamento às Cegas: Brasil S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/392747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68945, 4706, 'Casamento às Cegas: Brasil S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/392748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68946, 4706, 'Casamento às Cegas: Brasil S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/392749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68947, 4706, 'Casamento às Cegas: Brasil S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/397858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68948, 4706, 'Casamento às Cegas: Brasil S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/397859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68949, 4706, 'Casamento às Cegas: Brasil S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/397860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68950, 4706, 'Casamento às Cegas: Brasil S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/397861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68951, 4706, 'Casamento às Cegas: Brasil S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/401229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68952, 4706, 'Casamento às Cegas: Brasil S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/401230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68953, 4706, 'Casamento às Cegas: Brasil S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/409299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68954, 4707, 'Casamento às Cegas: Brasil S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/885163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68955, 4707, 'Casamento às Cegas: Brasil S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/885164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68956, 4707, 'Casamento às Cegas: Brasil S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/885165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68957, 4707, 'Casamento às Cegas: Brasil S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/885166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68958, 4707, 'Casamento às Cegas: Brasil S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/885167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68959, 4707, 'Casamento às Cegas: Brasil S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/885168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68960, 4707, 'Casamento às Cegas: Brasil S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/885169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68961, 4707, 'Casamento às Cegas: Brasil S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/885170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68962, 4707, 'Casamento às Cegas: Brasil S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/885171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68963, 4707, 'Casamento às Cegas: Brasil S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/885172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68964, 4707, 'Casamento às Cegas: Brasil S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/886099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68965, 4707, 'Casamento às Cegas: Brasil S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/886100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68966, 4707, 'Casamento às Cegas: Brasil S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/886101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4IUe4Uzt398Z7QdjU5dWkAm5FWQ.jpg'),
(68967, 4708, 'Departamento de Conspirações S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pbKu5AwKXLhzqvWuEKAisokeJ4v.jpg'),
(68968, 4708, 'Departamento de Conspirações S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4PuvPV36Ls5NXMJzVSz22LrD7E3.jpg'),
(68969, 4708, 'Departamento de Conspirações S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qsvCAONp2pSz0gF55TdN7wkR8TQ.jpg'),
(68970, 4708, 'Departamento de Conspirações S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9uVOt9WIfiErBXoa0zzNpbI5NHB.jpg'),
(68971, 4708, 'Departamento de Conspirações S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1E43XtcAkn9ikdVj4E3NKtcTJQh.jpg'),
(68972, 4708, 'Departamento de Conspirações S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6S2teXTb9Kudv0CpIDMjocmzH1x.jpg'),
(68973, 4708, 'Departamento de Conspirações S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ijPTLSfR8s0VPt3AlmzwIcTM3j1.jpg'),
(68974, 4708, 'Departamento de Conspirações S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i1yt0NvjOPNYNNEbQTFWKtwiEUm.jpg'),
(68975, 4708, 'Departamento de Conspirações S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8wYcFWYpOgUQemirFdDNJDgZg8X.jpg'),
(68976, 4708, 'Departamento de Conspirações S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vZOPdjXxo0xSGnmj4MmjhfWbvsy.jpg'),
(68977, 4709, 'Departamento de Conspirações S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/onf4RsFiu9ZkitnkXN4tto6Kjyd.jpg'),
(68978, 4709, 'Departamento de Conspirações S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/onf4RsFiu9ZkitnkXN4tto6Kjyd.jpg'),
(68979, 4709, 'Departamento de Conspirações S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/onf4RsFiu9ZkitnkXN4tto6Kjyd.jpg'),
(68980, 4709, 'Departamento de Conspirações S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/onf4RsFiu9ZkitnkXN4tto6Kjyd.jpg'),
(68981, 4709, 'Departamento de Conspirações S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/onf4RsFiu9ZkitnkXN4tto6Kjyd.jpg'),
(68982, 4709, 'Departamento de Conspirações S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/onf4RsFiu9ZkitnkXN4tto6Kjyd.jpg'),
(68983, 4709, 'Departamento de Conspirações S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/onf4RsFiu9ZkitnkXN4tto6Kjyd.jpg'),
(68984, 4709, 'Departamento de Conspirações S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/onf4RsFiu9ZkitnkXN4tto6Kjyd.jpg'),
(68985, 4710, 'Deslocados: A Série S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b4yZokKeWZlCf45aQeXeU2iDZ7s.jpg'),
(68986, 4710, 'Deslocados: A Série S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qCkADwulyziNzGNf9NW9jbgiCS7.jpg'),
(68987, 4710, 'Deslocados: A Série S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hUw9xG4lidRivP3yslcjRewDvpl.jpg'),
(68988, 4710, 'Deslocados: A Série S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7cV93S1KeeFphwtJToO6CbDfnrj.jpg'),
(68989, 4710, 'Deslocados: A Série S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5SYruXHTHGco9mJjmO07QgngCeo.jpg'),
(68990, 4710, 'Deslocados: A Série S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/itCXFt9dISWThrOLxHSEmqXNotb.jpg'),
(68991, 4710, 'Deslocados: A Série S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2PFyt9jPUFqylaybx2zR8Bm9SUr.jpg'),
(68992, 4710, 'Deslocados: A Série S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/olm3DHFG4mSdlcb7vnwZokMi88X.jpg'),
(68993, 4711, 'Eu Terei Sumido na Escuridão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dn8UQMomqbUFLXWVz5Orwwyt5n4.jpg'),
(68994, 4711, 'Eu Terei Sumido na Escuridão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lJqN8iSD5R7Ysm2yuR8oSXRakEh.jpg'),
(68995, 4711, 'Eu Terei Sumido na Escuridão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3VcvmxK1tPi5cDikmsPjVDPadYj.jpg'),
(68996, 4711, 'Eu Terei Sumido na Escuridão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gRVNpc5qtEwAnY7gkDxNGlcgoGY.jpg'),
(68997, 4711, 'Eu Terei Sumido na Escuridão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A2qq0brCqaFwmFB7WA9geKihLAt.jpg'),
(68998, 4711, 'Eu Terei Sumido na Escuridão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fvoNzBpSZMtginKMoMeXD4ze89k.jpg'),
(68999, 4712, 'Fumetsu no Anata e S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7I7ZaR4t0IZPad6nOrqtskGp2AN.jpg'),
(69000, 4712, 'Fumetsu no Anata e S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDCBEiFclASI02BFNNhGHjL98EK.jpg'),
(69001, 4712, 'Fumetsu no Anata e S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1DKHi9R464qyVW5vG3aq4aPcnzn.jpg'),
(69002, 4712, 'Fumetsu no Anata e S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rBSO7mNBeH0dJztuPtOYRbg9jkX.jpg'),
(69003, 4712, 'Fumetsu no Anata e S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/scI4GstmxgEFXpJbh5zxjpwtePb.jpg'),
(69004, 4712, 'Fumetsu no Anata e S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Nt20riwDVCfjv9yErnJE50XdFj.jpg'),
(69005, 4712, 'Fumetsu no Anata e S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iHD2HVVTcae9VhgCWCF4UiFWOcj.jpg'),
(69006, 4712, 'Fumetsu no Anata e S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8oxUAabeKIhGMO8Q5In3iActcjr.jpg'),
(69007, 4712, 'Fumetsu no Anata e S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/20c3twjcRFrnpJd02Au0gBRE2gM.jpg'),
(69008, 4712, 'Fumetsu no Anata e S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zgT3gazaBflMti45ohJnJxwDNxk.jpg'),
(69009, 4712, 'Fumetsu no Anata e S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v0cs01RHxnM4kVp7BWv29AGcV5J.jpg'),
(69010, 4712, 'Fumetsu no Anata e S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iZoBCiZmhfgY2IxRxhWqIHSuhzl.jpg'),
(69011, 4712, 'Fumetsu no Anata e S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/159296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iraGif9VlIKHx05XbNX6gA57a4H.jpg'),
(69012, 4712, 'Fumetsu no Anata e S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/159297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A5lO9ZWwR74nGLomTKFF9WP2E31.jpg'),
(69013, 4712, 'Fumetsu no Anata e S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/159298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oWl54Hw7nldID9TMRMuYWvlwF4C.jpg'),
(69014, 4712, 'Fumetsu no Anata e S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/159299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l6KckV6wTteqaDh57a0OS2Texee.jpg'),
(69015, 4712, 'Fumetsu no Anata e S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/159300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zC1rXcZsIhUVQol2CB2RYfEQEvq.jpg'),
(69016, 4712, 'Fumetsu no Anata e S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/159301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pG6rPPfStzd53NPOmLLZrNajxNB.jpg'),
(69017, 4712, 'Fumetsu no Anata e S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/159302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/znWzYaWNZl6JdCZy6JFNi4Z9Cas.jpg'),
(69018, 4712, 'Fumetsu no Anata e S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/159303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rFLHtQ4K4U2nxOo4JwjZo4UDJ8e.jpg'),
(69019, 4713, 'Fumetsu no Anata e S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/890167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/brSB8Q9e06x5dLaOfNZRiClguJ4.jpg'),
(69020, 4713, 'Fumetsu no Anata e S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/890168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iiugiKb145GE0HgzZErp3XXPf50.jpg'),
(69021, 4713, 'Fumetsu no Anata e S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/890169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gdO4tq8YjtFQRPHNVsSWVpUiova.jpg'),
(69022, 4713, 'Fumetsu no Anata e S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/890170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jjtdWR850qomTKXCem8DIJJ8coJ.jpg'),
(69023, 4713, 'Fumetsu no Anata e S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/890171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYeTk98G71hWgw3fE7UFu6YlpY0.jpg'),
(69024, 4713, 'Fumetsu no Anata e S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/890172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pKeezGU5xqHyH3DRTvKZabhFSB.jpg'),
(69025, 4713, 'Fumetsu no Anata e S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/890173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cIRr4CRmVsjAYmcujxcZPdqZ9RK.jpg'),
(69026, 4713, 'Fumetsu no Anata e S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/890174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2tdK6a03NLeGqfawNBP5ZFTjWIp.jpg'),
(69027, 4713, 'Fumetsu no Anata e S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/890175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fZPldLmW6qxpSxijfxHmR3hE9Lj.jpg'),
(69028, 4713, 'Fumetsu no Anata e S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/890176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzyNpYYuhB0QJWA4SJkVmYbaTwH.jpg'),
(69029, 4713, 'Fumetsu no Anata e S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/890177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5yS3BjfWxcKDI13NM4FxLxsMFWW.jpg'),
(69030, 4713, 'Fumetsu no Anata e S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/890178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtNqtmS47lWK7TuS229W4fmIplD.jpg'),
(69031, 4713, 'Fumetsu no Anata e S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/890179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fYWr14PMjX6z9IRYG2TSBgltTEH.jpg'),
(69032, 4713, 'Fumetsu no Anata e S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/890180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cBpJEr0nOZV6fWGP62EPa1QfWyq.jpg'),
(69033, 4713, 'Fumetsu no Anata e S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/890181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktWC0GSd29i4tOBWcUOkaVdOPeE.jpg'),
(69034, 4713, 'Fumetsu no Anata e S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/890182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gJuOeJR6AToYU3ofPpNYC8PLmhJ.jpg'),
(69035, 4713, 'Fumetsu no Anata e S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/890183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yo0ieiTUiRIwmjMxnwZjLNReYsm.jpg'),
(69036, 4713, 'Fumetsu no Anata e S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/890184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bpNUaiqSWGyRUfGqOZbSJfsrNTt.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(69037, 4713, 'Fumetsu no Anata e S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/890185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iULxL88y37dgzQDGPO5pxMJt31O.jpg'),
(69038, 4713, 'Fumetsu no Anata e S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/890186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qwee6sGwSZ7DDRfeI48djsV87I7.jpg'),
(69039, 4714, 'Fumetsu no Anata e S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/890187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2EDnxdkuBek59k2mq44R3234aCM.jpg'),
(69040, 4714, 'Fumetsu no Anata e S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/890188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/83lEmIYWEaF9FxQbRfEZ5fVHEvV.jpg'),
(69041, 4714, 'Fumetsu no Anata e S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/890189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/keKevc79prTTvYyHz3UG0kI6LvE.jpg'),
(69042, 4715, 'Goop: Muito Além do Prazer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ygYQGnH2IkIVqmPsfY0vkAahp9T.jpg'),
(69043, 4715, 'Goop: Muito Além do Prazer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/21MJB7U2ekIETiaEJVjwaZ1gKuj.jpg'),
(69044, 4715, 'Goop: Muito Além do Prazer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A6wfQVYvDIbVd9jF2E04BPzElIw.jpg'),
(69045, 4715, 'Goop: Muito Além do Prazer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lnckYsF0ULMI6hVB0nvwcrP04Bp.jpg'),
(69046, 4715, 'Goop: Muito Além do Prazer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5GYP1jgNbqW4fbdTRufE3ptaSoP.jpg'),
(69047, 4715, 'Goop: Muito Além do Prazer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9OwWtncejNvlrsCZWKJBW8CHGbG.jpg'),
(69048, 4716, 'Guia astrológico para corações partidos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2qqrYVLibU92hxKFSh2CEicuqb4.jpg'),
(69049, 4716, 'Guia astrológico para corações partidos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z8jBYi4neVO22g3VQTwGEOpbhiG.jpg'),
(69050, 4716, 'Guia astrológico para corações partidos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b66jcXNuizZTgP5Dd0JLTF2cl8w.jpg'),
(69051, 4716, 'Guia astrológico para corações partidos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/exWRSdIG7XcJHYABk0mGm4pK0WF.jpg'),
(69052, 4716, 'Guia astrológico para corações partidos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2KMtRxcJT0DriCoUCYpABND3yEN.jpg'),
(69053, 4716, 'Guia astrológico para corações partidos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2XX2mJSN85MpkhhtqVSRjndWkCg.jpg'),
(69054, 4717, 'Guia astrológico para corações partidos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178303.mp4', 'http://timg.bdta.pro/images/2fcc6ffcd753f59916a5f85c1c308434.jpg'),
(69055, 4717, 'Guia astrológico para corações partidos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178304.mp4', 'http://timg.bdta.pro/images/dccd830a8540d4f77b9679017d0a38c5.jpg'),
(69056, 4717, 'Guia astrológico para corações partidos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178305.mp4', 'http://timg.bdta.pro/images/9942f63c5f65b9854bdba0cae9178db0.jpg'),
(69057, 4717, 'Guia astrológico para corações partidos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178306.mp4', 'http://timg.bdta.pro/images/9c6f68a002cfb481efeacee86fa8cb89.jpg'),
(69058, 4717, 'Guia astrológico para corações partidos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178307.mp4', 'http://timg.bdta.pro/images/d559680afb9016fb9259fdaa996db1b1.jpg'),
(69059, 4717, 'Guia astrológico para corações partidos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178308.mp4', 'http://timg.bdta.pro/images/ec796ff0f102d49561050ef51bdc9cac.jpg'),
(69060, 4718, 'Hometown Cha Cha Cha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/btvuH9SsoTQbKddlv5JvkFmyHhO.jpg'),
(69061, 4718, 'Hometown Cha Cha Cha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8cfgDvovEY3HlU5Njc0VRZRnkv2.jpg'),
(69062, 4718, 'Hometown Cha Cha Cha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1aWY6Wr59z4llVbuCcQqGhRcoj0.jpg'),
(69063, 4718, 'Hometown Cha Cha Cha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9US6dRZjhsNqS2n8uu2uH9DuQFO.jpg'),
(69064, 4718, 'Hometown Cha Cha Cha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iQTUvhMosMpCSrwDMoqz9nQxctl.jpg'),
(69065, 4718, 'Hometown Cha Cha Cha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bfgYZbOKx2B9kv4CGK5PFRM7bDX.jpg'),
(69066, 4718, 'Hometown Cha Cha Cha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63klONX3Ixja6hmD3HtL0iBjnmd.jpg'),
(69067, 4718, 'Hometown Cha Cha Cha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wzcRAKXf2X2FCFnV8Zp1tY0mLE0.jpg'),
(69068, 4718, 'Hometown Cha Cha Cha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e00AJlbBXnDhBauap7EaBWQcgYh.jpg'),
(69069, 4718, 'Hometown Cha Cha Cha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8JQAeSmGLJbUrjkvTicNRykjcH6.jpg'),
(69070, 4718, 'Hometown Cha Cha Cha S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1aXyGKeuAElOBdJuO0Y6PdyBva4.jpg'),
(69071, 4718, 'Hometown Cha Cha Cha S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1IOtHdDghC4NpDhgJXyRBHyylDf.jpg'),
(69072, 4718, 'Hometown Cha Cha Cha S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/164002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1hZlecrXuS8ZpoTyiRg59ozdca.jpg'),
(69073, 4718, 'Hometown Cha Cha Cha S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/164003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uM4dtbsnteA40w3saOYQHZDg8bC.jpg'),
(69074, 4718, 'Hometown Cha Cha Cha S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/164004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kQWy9mBcvubw0JWpD7BAAV4Cb6X.jpg'),
(69075, 4718, 'Hometown Cha Cha Cha S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/164005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/we4XCoVs1exfnyUswkLQ0CMMOvj.jpg'),
(69076, 4719, 'Insiders S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tGnryIXHVXFSWx7pq2geuEgKAAE.jpg'),
(69077, 4719, 'Insiders S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A2pKPY0oETE7W02YbCsOMeFSFl4.jpg'),
(69078, 4719, 'Insiders S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vSk0jYRVREdXCnMAM9KcLtkYQRY.jpg'),
(69079, 4719, 'Insiders S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kv6aaoMEkg76PifcXJcUCTiijCs.jpg'),
(69080, 4719, 'Insiders S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3qv6azuADwJEX4WtJXNUjVExCZy.jpg'),
(69081, 4719, 'Insiders S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lXslHlRkUlsgFr5ZVl9zhsvbrE9.jpg'),
(69082, 4719, 'Insiders S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hpo0iJKr55OT8OkuhNZGRXMvnt5.jpg'),
(69083, 4720, 'Insiders S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179836.mp4', 'http://timg.bdta.pro/images/0e76e81bac7580637ddf925e03b36382.jpg'),
(69084, 4720, 'Insiders S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179837.mp4', 'http://timg.bdta.pro/images/9caaa2ab0c571fc2178a21eb60844782.jpg'),
(69085, 4720, 'Insiders S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179838.mp4', 'http://timg.bdta.pro/images/c0c493c5763d921f5a6a562967ab6940.jpg'),
(69086, 4720, 'Insiders S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179839.mp4', 'http://timg.bdta.pro/images/95c157885e7bd0f1767170af03814e84.jpg'),
(69087, 4720, 'Insiders S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179840.mp4', 'http://timg.bdta.pro/images/e422f3284570524e36ce73ad7989e771.jpg'),
(69088, 4720, 'Insiders S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179841.mp4', 'http://timg.bdta.pro/images/5bb8af955b78b5c0d7059b12c478242c.jpg'),
(69089, 4720, 'Insiders S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179842.mp4', 'http://timg.bdta.pro/images/560c136e897c79acc8980e95ce8901eb.jpg'),
(69090, 4721, 'Invasão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n3PDSh5qDWM4YAjPVoL0ahcHcaP.jpg'),
(69091, 4721, 'Invasão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHGRdzZNZM8slCNvrIYa3qDii5j.jpg'),
(69092, 4721, 'Invasão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4nnxJb7HDiP8m3X5lBIXxxD9WXl.jpg'),
(69093, 4721, 'Invasão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOlVwr5mileTTfyyxdxQcgG6YRk.jpg'),
(69094, 4721, 'Invasão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9hCkWgDeo46tMVEjXz7swBVdDya.jpg'),
(69095, 4721, 'Invasão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243918.mp4', 'http://image.tmdb.org/t/p/w1280/xiJifDS2YdaDDEINe0XG9WNxJ2F.jpg'),
(69096, 4721, 'Invasão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243919.mp4', 'http://image.tmdb.org/t/p/w1280/pC9HNLY06QYD9CIkOCRl3qkUdXI.jpg'),
(69097, 4721, 'Invasão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243920.mp4', 'http://image.tmdb.org/t/p/w1280/aR8DHaU0ahUSNbHE1dReLGdxm0z.jpg'),
(69098, 4721, 'Invasão S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243921.mp4', 'http://image.tmdb.org/t/p/w1280/7hlyzNudRtFBmA9KOe2QIyS9cmK.jpg'),
(69099, 4721, 'Invasão S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243922.mp4', 'http://image.tmdb.org/t/p/w1280/6gE55Dd3fVaQtlEUJlcOUk87JAg.jpg'),
(69100, 4722, 'Invasão S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243923.mp4', 'http://image.tmdb.org/t/p/w1280/aapdWdEDs2Mgc4EXll42becxWGq.jpg'),
(69101, 4722, 'Invasão S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243924.mp4', 'http://image.tmdb.org/t/p/w1280/rhLSA2etybKCwmUyfwIlGji6sgy.jpg'),
(69102, 4722, 'Invasão S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243925.mp4', 'http://image.tmdb.org/t/p/w1280/tAKFCs4c9IRlHVf0TIYb933KI6D.jpg'),
(69103, 4722, 'Invasão S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2faxNZj5iHQOiDdPzCHCDvjTEnW.jpg'),
(69104, 4722, 'Invasão S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2faxNZj5iHQOiDdPzCHCDvjTEnW.jpg'),
(69105, 4722, 'Invasão S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2faxNZj5iHQOiDdPzCHCDvjTEnW.jpg'),
(69106, 4722, 'Invasão S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2faxNZj5iHQOiDdPzCHCDvjTEnW.jpg'),
(69107, 4722, 'Invasão S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2faxNZj5iHQOiDdPzCHCDvjTEnW.jpg'),
(69108, 4722, 'Invasão S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2faxNZj5iHQOiDdPzCHCDvjTEnW.jpg'),
(69109, 4722, 'Invasão S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2faxNZj5iHQOiDdPzCHCDvjTEnW.jpg'),
(69110, 4723, 'Invasão S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/881217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2faxNZj5iHQOiDdPzCHCDvjTEnW.jpg'),
(69111, 4723, 'Invasão S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/881334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2faxNZj5iHQOiDdPzCHCDvjTEnW.jpg'),
(69112, 4723, 'Invasão S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/883028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2faxNZj5iHQOiDdPzCHCDvjTEnW.jpg'),
(69113, 4723, 'Invasão S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/883800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2faxNZj5iHQOiDdPzCHCDvjTEnW.jpg'),
(69114, 4723, 'Invasão S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/885160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2faxNZj5iHQOiDdPzCHCDvjTEnW.jpg'),
(69115, 4723, 'Invasão S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/886080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2faxNZj5iHQOiDdPzCHCDvjTEnW.jpg'),
(69116, 4723, 'Invasão S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/887590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2faxNZj5iHQOiDdPzCHCDvjTEnW.jpg'),
(69117, 4723, 'Invasão S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/888204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2faxNZj5iHQOiDdPzCHCDvjTEnW.jpg'),
(69118, 4723, 'Invasão S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/889631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2faxNZj5iHQOiDdPzCHCDvjTEnW.jpg'),
(69119, 4723, 'Invasão S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/890076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2faxNZj5iHQOiDdPzCHCDvjTEnW.jpg'),
(69120, 4724, 'Maya e os 3 Guerreiros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p0csgSPSWe65BcsULAzjEmIAMAU.jpg'),
(69121, 4724, 'Maya e os 3 Guerreiros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fMmENffsfLbullRhic7CWHVJ3de.jpg'),
(69122, 4724, 'Maya e os 3 Guerreiros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7we2QHNXqIvUewVTcpayO10NOfJ.jpg'),
(69123, 4724, 'Maya e os 3 Guerreiros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/85BncX6lwuZIloLMscP7lgSrSCC.jpg'),
(69124, 4724, 'Maya e os 3 Guerreiros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mNxnyNMLP92HAVeez0XiDYAAFMr.jpg'),
(69125, 4724, 'Maya e os 3 Guerreiros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xin5Yd1ZJREttUw01yPxfQA1shJ.jpg'),
(69126, 4724, 'Maya e os 3 Guerreiros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xphi8zH4hCDdKWnrESTSNWAud1.jpg'),
(69127, 4724, 'Maya e os 3 Guerreiros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nIZq5T2WFLIO9NCT0lNcGdjJDvf.jpg'),
(69128, 4724, 'Maya e os 3 Guerreiros S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uv9LXjMFSAf26CuJu2K6qlCOix0.jpg'),
(69129, 4725, 'Mil Colmilhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4uVJU5YU8T75KWJQzCh991dPyg4.jpg'),
(69130, 4725, 'Mil Colmilhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qp2rMvXSCNVcmPaDH6viQR8h6rM.jpg'),
(69131, 4725, 'Mil Colmilhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i8KuhvC4OoGECRNJrHaxHvQMDYO.jpg'),
(69132, 4725, 'Mil Colmilhos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/no33SgHR3MlAzSLsFNR1Jg3oBKF.jpg'),
(69133, 4725, 'Mil Colmilhos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3w8IvqR3BsKvGdwTbJXXY8zvVWw.jpg'),
(69134, 4725, 'Mil Colmilhos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pew9so2414hwxZuAmpzhlwtDOeN.jpg'),
(69135, 4725, 'Mil Colmilhos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2BjXpzQqyalFjHVIVGxEPlSGSD.jpg'),
(69136, 4726, 'My Name S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yt5GGkLxakkGdGXoSFgVARuNTNS.jpg'),
(69137, 4726, 'My Name S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0XkfFALa6w4HSZfbZwq9ak9HZC.jpg'),
(69138, 4726, 'My Name S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jSwwHULmMBbB6O2QrIuTgHsPih.jpg'),
(69139, 4726, 'My Name S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nbDApLaF8BcGFcUewLS75SHhJpZ.jpg'),
(69140, 4726, 'My Name S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aWea9cyjvvr3t0TDSXT61bS2Mp4.jpg'),
(69141, 4726, 'My Name S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xazVycQz6uXiFqzpQkZuwj7CA7t.jpg'),
(69142, 4726, 'My Name S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xihwa7x4Ymu539OFVEx9MfFkAHf.jpg'),
(69143, 4726, 'My Name S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gMd5kdYVf4QCXSbwWcSeAVwhfwb.jpg'),
(69144, 4727, 'O Assassino da Capa de Chuva: Caça ao Serial Killer Coreano S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Hjvk8ZRL5vovRpPTwVxjbruSsq.jpg'),
(69145, 4727, 'O Assassino da Capa de Chuva: Caça ao Serial Killer Coreano S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Hjvk8ZRL5vovRpPTwVxjbruSsq.jpg'),
(69146, 4727, 'O Assassino da Capa de Chuva: Caça ao Serial Killer Coreano S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Hjvk8ZRL5vovRpPTwVxjbruSsq.jpg'),
(69147, 4728, 'O Desconhecido Mundo Animal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/drRzj5fCk5ndIhQmS2dH0R4OLKG.jpg'),
(69148, 4728, 'O Desconhecido Mundo Animal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/drRzj5fCk5ndIhQmS2dH0R4OLKG.jpg'),
(69149, 4728, 'O Desconhecido Mundo Animal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/drRzj5fCk5ndIhQmS2dH0R4OLKG.jpg'),
(69150, 4728, 'O Desconhecido Mundo Animal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/drRzj5fCk5ndIhQmS2dH0R4OLKG.jpg'),
(69151, 4728, 'O Desconhecido Mundo Animal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/drRzj5fCk5ndIhQmS2dH0R4OLKG.jpg'),
(69152, 4728, 'O Desconhecido Mundo Animal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/drRzj5fCk5ndIhQmS2dH0R4OLKG.jpg'),
(69153, 4728, 'O Desconhecido Mundo Animal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/drRzj5fCk5ndIhQmS2dH0R4OLKG.jpg'),
(69154, 4728, 'O Desconhecido Mundo Animal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/drRzj5fCk5ndIhQmS2dH0R4OLKG.jpg'),
(69155, 4728, 'O Desconhecido Mundo Animal S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/drRzj5fCk5ndIhQmS2dH0R4OLKG.jpg'),
(69156, 4728, 'O Desconhecido Mundo Animal S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/drRzj5fCk5ndIhQmS2dH0R4OLKG.jpg'),
(69157, 4728, 'O Desconhecido Mundo Animal S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/drRzj5fCk5ndIhQmS2dH0R4OLKG.jpg'),
(69158, 4728, 'O Desconhecido Mundo Animal S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/drRzj5fCk5ndIhQmS2dH0R4OLKG.jpg'),
(69159, 4729, 'One of Us Is Lying [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sVDSz9yuGt5utbKzWFsFZ2BJ6hy.jpg'),
(69160, 4729, 'One of Us Is Lying [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vim6lkNijCQ7u4Un24smLZyX076.jpg'),
(69161, 4729, 'One of Us Is Lying [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lumnYzvdfU5FQOrnTPuow8Z6uv.jpg'),
(69162, 4729, 'One of Us Is Lying [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AePU6CSXYvWQdqOU5xaVehrmtIs.jpg'),
(69163, 4729, 'One of Us Is Lying [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jJv6FKdIKMiz8HybJnRbcw467LO.jpg'),
(69164, 4729, 'One of Us Is Lying [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u4AgUrEv2G6Z9svusyKhJRXxeS5.jpg'),
(69165, 4729, 'One of Us Is Lying [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jvNZZNaCKSrtDRaZ4aujJyQEw4W.jpg'),
(69166, 4729, 'One of Us Is Lying [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cuoUndYBim95oK0cYJJUvKxl7Yi.jpg'),
(69167, 4730, 'Paraíso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kEaECKmLH7o7UQrGQe7BoslJHOO.jpg'),
(69168, 4730, 'Paraíso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eXDYpFr6F29JuL7lpSvtHbqHPQa.jpg'),
(69169, 4730, 'Paraíso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l2iJA6mX35NNTEP7ZvBseMyIWWx.jpg'),
(69170, 4730, 'Paraíso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vZqKpnY06JobOqB200Odm9Zr7L.jpg'),
(69171, 4730, 'Paraíso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rul8ifF4Jl1luCIGDOOSFf0xtEA.jpg'),
(69172, 4730, 'Paraíso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oXfj3gsoLAJhBqYvH4gacJ4PBvR.jpg'),
(69173, 4730, 'Paraíso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ps541zVLADwHcM128CAl9HbZkCx.jpg'),
(69174, 4731, 'Paraíso S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u48JaoHS1l8mFtK1J2fTrO3hGtZ.jpg'),
(69175, 4731, 'Paraíso S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7f8SNrt3lPz43D5PzgGw9s0WYJC.jpg'),
(69176, 4731, 'Paraíso S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2dxa5SmUQtgaJGxW2zFJvpFs5OP.jpg'),
(69177, 4731, 'Paraíso S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/830fJTxFTtuF9IAzk10eZXOJVlz.jpg'),
(69178, 4731, 'Paraíso S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yxvo84TmSZ7lpJcUEAM4Qrq2Qdf.jpg'),
(69179, 4731, 'Paraíso S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AbXmgj58lAXGvmsdUMP5kzjLDJL.jpg'),
(69180, 4731, 'Paraíso S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nLeo7Hp0bNfHgbX0nGhDXki9Z4o.jpg'),
(69181, 4731, 'Paraíso S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pvVtVuXQzIHXzV6NszJxRUmVacr.jpg'),
(69182, 4732, 'Resident Alien S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mLSp6C3ZDr5eEypEZGgFG6bbqBz.jpg'),
(69183, 4732, 'Resident Alien S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iwmPz3aXEsPyGuKeqehZHviHPH.jpg'),
(69184, 4732, 'Resident Alien S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dAH9iV57b7Rp3LHqQpjfrtoAc4N.jpg'),
(69185, 4732, 'Resident Alien S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iyasC2QMKHDbcXMLm4gQZ3Dsps1.jpg'),
(69186, 4732, 'Resident Alien S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eq7z4SD6q37BH1KL4sSdYfg5bh9.jpg'),
(69187, 4732, 'Resident Alien S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkiPNT1OR6M35L9tY84AXow8qts.jpg'),
(69188, 4732, 'Resident Alien S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cPN0PuzfbqRb6IpmRSi0e6ReEPR.jpg'),
(69189, 4732, 'Resident Alien S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xwO3nFAzPHdLqOyGfT6WQMBJdMY.jpg'),
(69190, 4732, 'Resident Alien S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zI0T3oS60Mua5RmKOwXt6a4SbuH.jpg'),
(69191, 4732, 'Resident Alien S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wndKBEBFC5D4bMhmei4GJROJvkp.jpg'),
(69192, 4733, 'Resident Alien S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203836.mp4', 'http://timg.bdta.pro/images/b853fcbac508c87ac6bd6fe2bc48dfce.jpg'),
(69193, 4733, 'Resident Alien S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203837.mp4', 'http://timg.bdta.pro/images/f2dea0ecf0a6bd981e7dd35edc5534cf.jpg'),
(69194, 4733, 'Resident Alien S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203838.mp4', 'http://timg.bdta.pro/images/eab37c98d5303c5f3f48dce4f36c46b0.jpg'),
(69195, 4733, 'Resident Alien S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203839.mp4', 'http://timg.bdta.pro/images/47554d768a05258da111a96896c82e04.jpg'),
(69196, 4733, 'Resident Alien S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203840.mp4', 'http://timg.bdta.pro/images/5800d0f4d887082bb39c2b92c3525de7.jpg'),
(69197, 4733, 'Resident Alien S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203841.mp4', 'http://timg.bdta.pro/images/ac4f7bb9120abf63b08aff774bd8d515.jpg'),
(69198, 4733, 'Resident Alien S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203842.mp4', 'http://timg.bdta.pro/images/0e431c61da5e66088305563c4302a793.jpg'),
(69199, 4733, 'Resident Alien S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203843.mp4', 'http://timg.bdta.pro/images/1186977dd55d9a2d733776daf740c28c.jpg'),
(69200, 4733, 'Resident Alien S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5tsDW07SvAoJ4XquYAqKowxrOzk.jpg'),
(69201, 4733, 'Resident Alien S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i3GXwrVkr3GGlMple8Q9EsIqbsO.jpg'),
(69202, 4733, 'Resident Alien S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e3T5SSMp4n1mppFqTzZDVgLTqcY.jpg'),
(69203, 4733, 'Resident Alien S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gfIoPr5U09sYFIdYFX2143kWARj.jpg'),
(69204, 4733, 'Resident Alien S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAEfV5kgjIUH9KsOkyLHymrTewG.jpg'),
(69205, 4733, 'Resident Alien S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/203849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFjoSCzBcd7CHCVfKUYO2ZyOYQD.jpg'),
(69206, 4733, 'Resident Alien S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/203850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odnkwmxHM0GKDxELqkyqMJtUDaR.jpg'),
(69207, 4733, 'Resident Alien S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/203851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rEeJWH1UOojBKXjJhRoMinGbwcH.jpg'),
(69208, 4734, 'Resident Alien S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/452007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bG5aqfT5lTHuSbcQofNHtH0RyyP.jpg'),
(69209, 4734, 'Resident Alien S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/452008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bG5aqfT5lTHuSbcQofNHtH0RyyP.jpg'),
(69210, 4734, 'Resident Alien S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/452009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bG5aqfT5lTHuSbcQofNHtH0RyyP.jpg'),
(69211, 4734, 'Resident Alien S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/452010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bG5aqfT5lTHuSbcQofNHtH0RyyP.jpg'),
(69212, 4734, 'Resident Alien S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/452011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bG5aqfT5lTHuSbcQofNHtH0RyyP.jpg'),
(69213, 4734, 'Resident Alien S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/452012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bG5aqfT5lTHuSbcQofNHtH0RyyP.jpg'),
(69214, 4734, 'Resident Alien S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/452013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bG5aqfT5lTHuSbcQofNHtH0RyyP.jpg'),
(69215, 4734, 'Resident Alien S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/452014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bG5aqfT5lTHuSbcQofNHtH0RyyP.jpg'),
(69216, 4735, 'SOS Cachorrinhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kaIZeHFS0cfmwoMWWZXO1AlwpBy.jpg'),
(69217, 4735, 'SOS Cachorrinhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l8gt4IcINR1hkcVbYY20r7X8z6j.jpg'),
(69218, 4735, 'SOS Cachorrinhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2qpleJ8AgUKPv20YusLnjgaks09.jpg'),
(69219, 4735, 'SOS Cachorrinhos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sqjiSqsUeyUDYMzmkYcI2RI0oax.jpg'),
(69220, 4735, 'SOS Cachorrinhos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rotYhulKaAxcDc1ui8Dxj2P5d5v.jpg'),
(69221, 4735, 'SOS Cachorrinhos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7QsP2m0wYExlUlC4UXkxQFjswMi.jpg'),
(69222, 4735, 'SOS Cachorrinhos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ud58NBfMUyBFAaGe3TOtVPojAQy.jpg'),
(69223, 4735, 'SOS Cachorrinhos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ySuKbaj9Vc5IDsOov8PcKrVkdti.jpg'),
(69224, 4736, 'SOS Cachorrinhos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ohsRJwwovNRnXn0xYpSTnCK01EY.jpg'),
(69225, 4736, 'SOS Cachorrinhos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dFYOj66tv0LP0nNbSaNska5L65g.jpg'),
(69226, 4736, 'SOS Cachorrinhos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aDUfdmfkHBj8qbO8ZKupTiOZs7q.jpg'),
(69227, 4736, 'SOS Cachorrinhos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3S8PxiBGIycjW4Xpltb0p6AHNPY.jpg'),
(69228, 4736, 'SOS Cachorrinhos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sBDzG56EXORoCo2dJMZVGzu44GP.jpg'),
(69229, 4736, 'SOS Cachorrinhos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vTMjmPp3UVz1QehwIENuowiW7bR.jpg'),
(69230, 4736, 'SOS Cachorrinhos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f01pIAV3KCGxmEph8vtNasIB8zE.jpg'),
(69231, 4736, 'SOS Cachorrinhos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1o5Heqq4D2s9JOJqEBUveUPS8OT.jpg'),
(69232, 4737, 'Skins - Juventude à flor da pele [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qS9xfSXblIV6eEf2C1PDVdqM69r.jpg'),
(69233, 4737, 'Skins - Juventude à flor da pele [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jmABqpOKu6rOUOuLq4JfVWQpJqc.jpg'),
(69234, 4737, 'Skins - Juventude à flor da pele [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/VbpaBOZ2RISXR3vAE1L6UWv8eK.jpg'),
(69235, 4737, 'Skins - Juventude à flor da pele [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yASjej0736wPC7WS7xsmYdAwZSF.jpg'),
(69236, 4737, 'Skins - Juventude à flor da pele [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svRtWDt4BLk8L9iyWkP4yvOi5Xr.jpg'),
(69237, 4737, 'Skins - Juventude à flor da pele [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aEiQj239nYNjeWROoUmTKSMyg4p.jpg'),
(69238, 4737, 'Skins - Juventude à flor da pele [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1hN6UmXRyoAXAipE6f5eqB7WrlZ.jpg'),
(69239, 4737, 'Skins - Juventude à flor da pele [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z7LNLczJKUMaKiANvRH0YZ1cCNy.jpg'),
(69240, 4737, 'Skins - Juventude à flor da pele [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1wbUQcKDnHRIlRxt1HkvBbZu68G.jpg'),
(69241, 4738, 'Skins - Juventude à flor da pele [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sQGDVIxU7CUcfEsBlFuJHdHXHuK.jpg'),
(69242, 4738, 'Skins - Juventude à flor da pele [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7h3KtOvqZASCXex6an7bLoUrHhw.jpg'),
(69243, 4738, 'Skins - Juventude à flor da pele [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4OxXw0yXPQglfdpgVGAruQwYLEj.jpg'),
(69244, 4738, 'Skins - Juventude à flor da pele [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJGUJjcVVBOAxg18aP4PX0UTUug.jpg'),
(69245, 4738, 'Skins - Juventude à flor da pele [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i7qKpP7z6Gs7sd0UUAjyxJ9HXys.jpg'),
(69246, 4738, 'Skins - Juventude à flor da pele [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/21ryM0zQYItS6m7h5ljix9vKYID.jpg'),
(69247, 4738, 'Skins - Juventude à flor da pele [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w1YuuaD2ozr84euhiXirlhTpCX9.jpg'),
(69248, 4738, 'Skins - Juventude à flor da pele [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kF9yCalgtDMuPF0RabdFyTyZJ0F.jpg'),
(69249, 4738, 'Skins - Juventude à flor da pele [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzf7ofuuVOOXY81LmjrXLqDFXhC.jpg'),
(69250, 4738, 'Skins - Juventude à flor da pele [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c2l8K0wIA0V6Om1dLyCDeFDTgrZ.jpg'),
(69251, 4739, 'Skins - Juventude à flor da pele [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1wxMQsVVtoDPiRpmnd1ma4Ixr1V.jpg'),
(69252, 4739, 'Skins - Juventude à flor da pele [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gmcQDXGQSpec4Sq58eCotctm6wq.jpg'),
(69253, 4739, 'Skins - Juventude à flor da pele [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/19D3ShFTsT0rcJGPI3LaxBEKm3G.jpg'),
(69254, 4739, 'Skins - Juventude à flor da pele [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2XXJOCPYbC09J4Xy3lW6ewhByFF.jpg'),
(69255, 4739, 'Skins - Juventude à flor da pele [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tNdiW3ROAJYFysNg3P9WycCx1k7.jpg'),
(69256, 4739, 'Skins - Juventude à flor da pele [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oJMiBPBfFxcpNBWPFhBIPZdj6Xq.jpg'),
(69257, 4739, 'Skins - Juventude à flor da pele [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bH8NfvqyE36s8oC83OtVa6SNrVt.jpg'),
(69258, 4739, 'Skins - Juventude à flor da pele [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9hS5kjvaBE88Dfq8XQZl8IQAP8U.jpg'),
(69259, 4739, 'Skins - Juventude à flor da pele [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Umbi5NkzHnr6b0MFAY4xB6Ey3C.jpg'),
(69260, 4739, 'Skins - Juventude à flor da pele [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8CQBk34CWneOMcTROviZTGLlmuo.jpg'),
(69261, 4740, 'Skins - Juventude à flor da pele [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vaH8XK00HPrEER0XwmZdrmILD6L.jpg'),
(69262, 4740, 'Skins - Juventude à flor da pele [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xLFFu4YdlezsiwBmTRwDw3h1g7p.jpg'),
(69263, 4740, 'Skins - Juventude à flor da pele [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Z222mEAGkeRDi5CLNqg144rj9E.jpg'),
(69264, 4740, 'Skins - Juventude à flor da pele [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Ung7c97QQKjqz4ToLtR5CyzCta.jpg'),
(69265, 4740, 'Skins - Juventude à flor da pele [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iLdpzyxqtiCM6fJzgT1rUkk7Ys1.jpg'),
(69266, 4740, 'Skins - Juventude à flor da pele [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mVVIewRbotynB6kfvn6ziegJHZu.jpg'),
(69267, 4740, 'Skins - Juventude à flor da pele [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJLXNxE6mDg9BhMAmpKsYrQvq1c.jpg'),
(69268, 4740, 'Skins - Juventude à flor da pele [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1XRWVfmWit0YhCU16MV1ESiR1iH.jpg'),
(69269, 4741, 'Skins - Juventude à flor da pele [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gRovOBa3sXveWPbdbCTGkrdh2VP.jpg'),
(69270, 4741, 'Skins - Juventude à flor da pele [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5gioFPRVP8hOBmhfRSysQBV5DVn.jpg'),
(69271, 4741, 'Skins - Juventude à flor da pele [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6iYu7kAf8jAuB7gY4SJ1aw802jX.jpg'),
(69272, 4741, 'Skins - Juventude à flor da pele [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cAN7LLBPr0G3vdWfXiUApS0kgjj.jpg'),
(69273, 4741, 'Skins - Juventude à flor da pele [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mL0VSadqxJrflZlJMkfK3jWABMP.jpg'),
(69274, 4741, 'Skins - Juventude à flor da pele [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/neKVYgdn1dSOWJuQQQGqvtd4ovt.jpg'),
(69275, 4741, 'Skins - Juventude à flor da pele [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bGtkniWnZUPYKBasDLXQ7wQAsj3.jpg'),
(69276, 4741, 'Skins - Juventude à flor da pele [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jyQQBP5qYGnDcrx5jNlcGKKxojd.jpg'),
(69277, 4742, 'Skins - Juventude à flor da pele [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6C6mXhoqPtZaXbDsttMEU8JKjr8.jpg'),
(69278, 4742, 'Skins - Juventude à flor da pele [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/TQA2w6PBdA3Qoc3fN696PqclDa.jpg'),
(69279, 4742, 'Skins - Juventude à flor da pele [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iv464QoOClPSYIBObunXKc2FQXR.jpg'),
(69280, 4742, 'Skins - Juventude à flor da pele [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pbZSt888fid7eEWh9fvm2eLqwq1.jpg'),
(69281, 4742, 'Skins - Juventude à flor da pele [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nngOpagpkkgRa4vMI2Wf4FifQvO.jpg'),
(69282, 4742, 'Skins - Juventude à flor da pele [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gBrXFpTmvll1ToOl06yBKWoPcy1.jpg'),
(69283, 4742, 'Skins - Juventude à flor da pele [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wsgL8ZMXk7dLvA5L1x4MbpHG08H.jpg'),
(69284, 4742, 'Skins - Juventude à flor da pele [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u3i0xkk7gy3dB9uysx5QXdZfdKn.jpg'),
(69285, 4742, 'Skins - Juventude à flor da pele [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tdYDFeNAsTMBSoL2gf6ziXZAylv.jpg'),
(69286, 4742, 'Skins - Juventude à flor da pele [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rUNKl2sb2SRBouTPaEiVX9u7Ix5.jpg'),
(69287, 4743, 'Skins - Juventude à flor da pele [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXStS10jyS8uvDX9QGJbIBxrmId.jpg'),
(69288, 4743, 'Skins - Juventude à flor da pele [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AkyfZo2NEpYqR6XL6p7JNGPxdxT.jpg'),
(69289, 4743, 'Skins - Juventude à flor da pele [L] S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8AGRc9g4w6js6bISJHMcTMAqooc.jpg'),
(69290, 4743, 'Skins - Juventude à flor da pele [L] S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tIJFn0MXuQta6qeBlTwZ42WlMx.jpg'),
(69291, 4743, 'Skins - Juventude à flor da pele [L] S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pcbHMCYRXT7IGx83TPPGA4IXO0U.jpg'),
(69292, 4743, 'Skins - Juventude à flor da pele [L] S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8HdTz8EBACi19VMzWTPdUUpGAAt.jpg'),
(69293, 4744, 'The Musketeers [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3AgRylD15ofMEptxMJicPNEzsC.jpg'),
(69294, 4744, 'The Musketeers [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cs4FOEsIKupaxdB5mKvM32fwAbR.jpg'),
(69295, 4744, 'The Musketeers [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jV222wDHCPPYetMF5JQFnfCgSMW.jpg'),
(69296, 4744, 'The Musketeers [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fMK6Vf2oYIe9DClp0rYqYQnMvqj.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(69297, 4744, 'The Musketeers [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vG7RZ0wk7j3XQFmbAXQ7C8sodKb.jpg'),
(69298, 4744, 'The Musketeers [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/osfj1yxrsDlsJDkmrO0BvRDLh4a.jpg'),
(69299, 4744, 'The Musketeers [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xpthJ568Da4aFNnggJZGig8IFYL.jpg'),
(69300, 4744, 'The Musketeers [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/89rRW36NWJTmqJcQwpUhS6NbtSN.jpg'),
(69301, 4744, 'The Musketeers [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQBN8RZjr1bSnYwdwuGrfp0nVSl.jpg'),
(69302, 4744, 'The Musketeers [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lDFCY9EYx6ael1tGaImI1KmOcAY.jpg'),
(69303, 4745, 'The Musketeers [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ioBkBbDMjxmV1LzKssUt4kPNypk.jpg'),
(69304, 4745, 'The Musketeers [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sdn8EwEjbjw3Sw0iJS4cGYq9O97.jpg'),
(69305, 4745, 'The Musketeers [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7TL17t5VcHKoHtHc9gwdYwzw3yc.jpg'),
(69306, 4745, 'The Musketeers [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/awvTQS6Xqp8dq3oNHQxUHTAly9I.jpg'),
(69307, 4745, 'The Musketeers [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t6h0J1yxN15554PGWENBZBFB3lo.jpg'),
(69308, 4745, 'The Musketeers [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ofDYZSmnMVwA1wNq7m32V54ARf6.jpg'),
(69309, 4745, 'The Musketeers [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMSJbheVhY6TA9wbezs1sLTzRtU.jpg'),
(69310, 4745, 'The Musketeers [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1tzABPYph77ZEO9Y4XmwIR0mRin.jpg'),
(69311, 4745, 'The Musketeers [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ziR1P1OmpfVaHYABcdavNBOsJ73.jpg'),
(69312, 4745, 'The Musketeers [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dN08Ru3XiriK6QuERWElk0mMaQB.jpg'),
(69313, 4746, 'The Musketeers [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ejOukWcsoCdavqxiG76nbJDurOi.jpg'),
(69314, 4746, 'The Musketeers [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eTwnCZyCvsA56e7VVyDg903J66W.jpg'),
(69315, 4746, 'The Musketeers [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ej2jIGVA4sjtHNAerk7UUeyDglk.jpg'),
(69316, 4746, 'The Musketeers [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ebB7IYHrSOQJspcunkMuVSYDHy.jpg'),
(69317, 4746, 'The Musketeers [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4daz9TQP7GPCFpYVtyGdeyOwzyH.jpg'),
(69318, 4746, 'The Musketeers [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/66hXKpIb41AWYdoLnak9ACtzXvj.jpg'),
(69319, 4746, 'The Musketeers [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cScdnOTGmDyU49z841Krz1c8OiU.jpg'),
(69320, 4746, 'The Musketeers [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7LVa2Bdd6QHkZOZn6JfNtbf8o3y.jpg'),
(69321, 4746, 'The Musketeers [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pYFE2apLQV0YJ3xR5YnmbUlraKK.jpg'),
(69322, 4746, 'The Musketeers [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Ft5Of8EFsMgRrryCGJ0n2l6J7.jpg'),
(69323, 4747, 'True Life Crime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9beKdlPSKkIrNEcZGrPIhSOJrCa.jpg'),
(69324, 4747, 'True Life Crime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ux0mv3RyYASZVXhRf1BD0Qir29q.jpg'),
(69325, 4747, 'True Life Crime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ux0mv3RyYASZVXhRf1BD0Qir29q.jpg'),
(69326, 4747, 'True Life Crime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ux0mv3RyYASZVXhRf1BD0Qir29q.jpg'),
(69327, 4747, 'True Life Crime S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ux0mv3RyYASZVXhRf1BD0Qir29q.jpg'),
(69328, 4747, 'True Life Crime S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ux0mv3RyYASZVXhRf1BD0Qir29q.jpg'),
(69329, 4747, 'True Life Crime S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ux0mv3RyYASZVXhRf1BD0Qir29q.jpg'),
(69330, 4747, 'True Life Crime S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ux0mv3RyYASZVXhRf1BD0Qir29q.jpg'),
(69331, 4748, 'True Life Crime S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ux0mv3RyYASZVXhRf1BD0Qir29q.jpg'),
(69332, 4748, 'True Life Crime S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ux0mv3RyYASZVXhRf1BD0Qir29q.jpg'),
(69333, 4748, 'True Life Crime S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ux0mv3RyYASZVXhRf1BD0Qir29q.jpg'),
(69334, 4748, 'True Life Crime S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ux0mv3RyYASZVXhRf1BD0Qir29q.jpg'),
(69335, 4748, 'True Life Crime S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ux0mv3RyYASZVXhRf1BD0Qir29q.jpg'),
(69336, 4748, 'True Life Crime S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ux0mv3RyYASZVXhRf1BD0Qir29q.jpg'),
(69337, 4748, 'True Life Crime S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ux0mv3RyYASZVXhRf1BD0Qir29q.jpg'),
(69338, 4748, 'True Life Crime S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ux0mv3RyYASZVXhRf1BD0Qir29q.jpg'),
(69339, 4748, 'True Life Crime S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ux0mv3RyYASZVXhRf1BD0Qir29q.jpg'),
(69340, 4748, 'True Life Crime S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ux0mv3RyYASZVXhRf1BD0Qir29q.jpg'),
(69341, 4749, 'Valley of Tears S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8J7P2OsC31PcNF9pwmGYABKipmU.jpg'),
(69342, 4749, 'Valley of Tears S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jIau9J5r3AI6iZKT0ARHPyvvEZc.jpg'),
(69343, 4749, 'Valley of Tears S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1BxCMznZwP3m3WyQOpIqJU542an.jpg'),
(69344, 4749, 'Valley of Tears S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/suuQwBTrx8LdjtxIGoaI2nLsT0W.jpg'),
(69345, 4749, 'Valley of Tears S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l68kWVYwUAxda0dIuIJPFVhqLWw.jpg'),
(69346, 4749, 'Valley of Tears S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dCP51iCEbFkVUlmAiGJjSHCbKAp.jpg'),
(69347, 4749, 'Valley of Tears S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i8mri59JNroStwKp5sAVZlgWeyf.jpg'),
(69348, 4749, 'Valley of Tears S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fKerVgh6Ai6IHGznK6wdzBoBkXL.jpg'),
(69349, 4749, 'Valley of Tears S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wkZh4MN2iQlPfCVOWY1jja2GliI.jpg'),
(69350, 4749, 'Valley of Tears S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vaTyNeDsWtjIzEe8AzZHaWnljUY.jpg'),
(69351, 4750, 'Vanitas no Carte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/159118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fxnc6WqwzexfVu33t0Fn12f8PFr.jpg'),
(69352, 4750, 'Vanitas no Carte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/159119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v1fRc8ChV7x8V9OOJOa8cUORlw3.jpg'),
(69353, 4750, 'Vanitas no Carte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/159120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/94rM9faQkJZtCUengJ1plGvswpF.jpg'),
(69354, 4750, 'Vanitas no Carte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/159121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y0H2fdZ9Yu4hm3XcDsnGWADNoic.jpg'),
(69355, 4750, 'Vanitas no Carte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/159122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rafH7Pdv4IK5Jg64cpEzhB6OMgu.jpg'),
(69356, 4750, 'Vanitas no Carte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/159123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/atwQ3hZ6mWCQMrKtVzmbB3cYLdd.jpg'),
(69357, 4750, 'Vanitas no Carte S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/159124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3CbiU6Mzomc0KOYyFEL3PT75YD.jpg'),
(69358, 4750, 'Vanitas no Carte S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/159125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AbiTpk3dT831v3au4sdlqsz7YgE.jpg'),
(69359, 4750, 'Vanitas no Carte S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/159126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tHvvL3EQlMZ7xw2lGapns9L63dp.jpg'),
(69360, 4750, 'Vanitas no Carte S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/159127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pTjwAuz4kDajRPQPJSEmSly91Iy.jpg'),
(69361, 4750, 'Vanitas no Carte S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/159128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nU6HTSrAhMJ9FCPI7blusF66eJD.jpg'),
(69362, 4750, 'Vanitas no Carte S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/159129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tobG6djRnC7FhYYsrGr4y7XpWaS.jpg'),
(69363, 4751, 'Verdades Secretas 2 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d3jQgo7c2eSGJkvLJ63l65MhVSr.jpg'),
(69364, 4751, 'Verdades Secretas 2 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rhERNHgRpyZXac3jJMU2tVLrDfP.jpg'),
(69365, 4751, 'Verdades Secretas 2 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nkgyj3etcKRLQ7JexBwShfBQvgh.jpg'),
(69366, 4751, 'Verdades Secretas 2 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6fKmK7f3Axc7qouJR8w5TrZmV8I.jpg'),
(69367, 4751, 'Verdades Secretas 2 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vjIjssgxyZIqAkapQOLEgefLVol.jpg'),
(69368, 4751, 'Verdades Secretas 2 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zjWw4uyoYClnDngbeXfnTVXOo8p.jpg'),
(69369, 4751, 'Verdades Secretas 2 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97gXfrXybi8HuwVuhw3Qr6YkEM0.jpg'),
(69370, 4751, 'Verdades Secretas 2 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8v3gucmoq2SHbcciIlvnIoHVkOX.jpg'),
(69371, 4751, 'Verdades Secretas 2 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tmnfbqgECcPcJX0yPxIY9Um06dp.jpg'),
(69372, 4751, 'Verdades Secretas 2 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hd5MxzevTqzSLNlJLnYW9hohHzG.jpg'),
(69373, 4751, 'Verdades Secretas 2 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/169149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69374, 4751, 'Verdades Secretas 2 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/169150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69375, 4751, 'Verdades Secretas 2 S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/169151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69376, 4751, 'Verdades Secretas 2 S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/169152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69377, 4751, 'Verdades Secretas 2 S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/169153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69378, 4751, 'Verdades Secretas 2 S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/169154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69379, 4751, 'Verdades Secretas 2 S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/169155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69380, 4751, 'Verdades Secretas 2 S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/169156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69381, 4751, 'Verdades Secretas 2 S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/169157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69382, 4751, 'Verdades Secretas 2 S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/169158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69383, 4751, 'Verdades Secretas 2 S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/169159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69384, 4751, 'Verdades Secretas 2 S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/169160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69385, 4751, 'Verdades Secretas 2 S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/169161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69386, 4751, 'Verdades Secretas 2 S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/169162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69387, 4751, 'Verdades Secretas 2 S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/169163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69388, 4751, 'Verdades Secretas 2 S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/169164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69389, 4751, 'Verdades Secretas 2 S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/169165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69390, 4751, 'Verdades Secretas 2 S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/169166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69391, 4751, 'Verdades Secretas 2 S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/169167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69392, 4751, 'Verdades Secretas 2 S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/169168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69393, 4751, 'Verdades Secretas 2 S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/169169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69394, 4751, 'Verdades Secretas 2 S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/169170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69395, 4751, 'Verdades Secretas 2 S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/169171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69396, 4751, 'Verdades Secretas 2 S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/169172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69397, 4751, 'Verdades Secretas 2 S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/169173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69398, 4751, 'Verdades Secretas 2 S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/169174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69399, 4751, 'Verdades Secretas 2 S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/169175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69400, 4751, 'Verdades Secretas 2 S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/169176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69401, 4751, 'Verdades Secretas 2 S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/169177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69402, 4751, 'Verdades Secretas 2 S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/169178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69403, 4751, 'Verdades Secretas 2 S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/169179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69404, 4751, 'Verdades Secretas 2 S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/169180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69405, 4751, 'Verdades Secretas 2 S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/169181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69406, 4751, 'Verdades Secretas 2 S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/169182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69407, 4751, 'Verdades Secretas 2 S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/169183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69408, 4751, 'Verdades Secretas 2 S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/169184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69409, 4751, 'Verdades Secretas 2 S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/169185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69410, 4751, 'Verdades Secretas 2 S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/169186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69411, 4751, 'Verdades Secretas 2 S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/169187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69412, 4751, 'Verdades Secretas 2 S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/169188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69413, 4751, 'Verdades Secretas 2 S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/169189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p20gDJQIF9gR94KByQXbHFjFAIi.jpg'),
(69414, 4752, 'Você é Minha Primavera S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wQ2JazBZa47PZOqDoO4cTu4kUui.jpg'),
(69415, 4752, 'Você é Minha Primavera S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kXHWZE3NiKLdjYRKflCkuqd1geP.jpg'),
(69416, 4752, 'Você é Minha Primavera S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qNYx9H89CxvpDjeyJfdrov9Dol4.jpg'),
(69417, 4752, 'Você é Minha Primavera S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmChGm9TqlcBz0TdU5pgP5uzgyi.jpg'),
(69418, 4752, 'Você é Minha Primavera S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hyY4L1uxhZo1PpqARfZWWRleX2U.jpg'),
(69419, 4752, 'Você é Minha Primavera S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/71X2CNfN3ToTCWgJDVtMeEc17dr.jpg'),
(69420, 4752, 'Você é Minha Primavera S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/83svglgLuyZZiG8yqV8lhuWmX7G.jpg'),
(69421, 4752, 'Você é Minha Primavera S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A0q6jNgneJSclshB1V1RzRtOCPP.jpg'),
(69422, 4752, 'Você é Minha Primavera S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/154MvoZNJtZz7PeknMqiYbHs6kU.jpg'),
(69423, 4752, 'Você é Minha Primavera S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hRyDWUaQ5OzNt4PzkOTLlYHl6ut.jpg'),
(69424, 4752, 'Você é Minha Primavera S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5aeJxYrDaH6AIJDnh8xa78OIzaz.jpg'),
(69425, 4752, 'Você é Minha Primavera S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i4lk29xSNkOs1HAEEDGxn3SYBY3.jpg'),
(69426, 4752, 'Você é Minha Primavera S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dTp91QkdnY6Bm6jri92H1hcwZDJ.jpg'),
(69427, 4752, 'Você é Minha Primavera S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9pQrdhoVaNCvAyeJw8uaBcvNb4v.jpg'),
(69428, 4752, 'Você é Minha Primavera S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5uOyQAFgFxy6GB04sVaifjLX86z.jpg'),
(69429, 4752, 'Você é Minha Primavera S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cP1O4rE02Q4gJfeh6etgENzI8j4.jpg'),
(69430, 4753, 'Chuck Norris: O Homem da Lei S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/69HTeQ7w8ZY8rFtLFNJYWRKfO9R.jpg'),
(69431, 4753, 'Chuck Norris: O Homem da Lei S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fD6knUVfKYyE6Vj1toCn1KXdDvv.jpg'),
(69432, 4753, 'Chuck Norris: O Homem da Lei S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l4KUSM4Sm8mBydHwmuJHnhkPINf.jpg'),
(69433, 4754, 'Chuck Norris: O Homem da Lei S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w37e6gcUux4RiUHkLnLqwcKj8Sg.jpg'),
(69434, 4754, 'Chuck Norris: O Homem da Lei S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zZU0anmudGaChvGXQJ9Vj8Xwk7z.jpg'),
(69435, 4754, 'Chuck Norris: O Homem da Lei S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbrHseULDPqgLVEhyKag8MLn6ko.jpg'),
(69436, 4754, 'Chuck Norris: O Homem da Lei S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bsYp5b3vNZMiHOPAumpnxwF3yES.jpg'),
(69437, 4754, 'Chuck Norris: O Homem da Lei S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uPfqHd5YSFuNrSe0fwmMSeEXLsI.jpg'),
(69438, 4754, 'Chuck Norris: O Homem da Lei S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1iAKflFd4zmcXprs3zniuVxUjc.jpg'),
(69439, 4754, 'Chuck Norris: O Homem da Lei S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOpi4IaapOr3SFzbKm4IEGsAcqY.jpg'),
(69440, 4754, 'Chuck Norris: O Homem da Lei S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a4md8xhima0KZ7ioyiTQ6lmnXk6.jpg'),
(69441, 4754, 'Chuck Norris: O Homem da Lei S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iF2Iw07c9iObfc8ZH34gVXumJcI.jpg'),
(69442, 4754, 'Chuck Norris: O Homem da Lei S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzHqzcGLPR72fSo2WzWzpEP6I3B.jpg'),
(69443, 4754, 'Chuck Norris: O Homem da Lei S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fvXDwaNS2L0HdM5fgNHd7fcWMLE.jpg'),
(69444, 4754, 'Chuck Norris: O Homem da Lei S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4nsODhuvsBwdhOm1nF3PvZUUaWq.jpg'),
(69445, 4754, 'Chuck Norris: O Homem da Lei S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mq2JQcLqDBEox5RSqfdCQ1MydPK.jpg'),
(69446, 4754, 'Chuck Norris: O Homem da Lei S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/203214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHlhXSrLQHWqV31qNETrQsAXjoD.jpg'),
(69447, 4754, 'Chuck Norris: O Homem da Lei S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/203215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/noFXfWbPahjKPEYGeykyeZk8qUE.jpg'),
(69448, 4754, 'Chuck Norris: O Homem da Lei S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/203216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUDn0Z8wSp0QAA3CrhN2gDBkB9O.jpg'),
(69449, 4754, 'Chuck Norris: O Homem da Lei S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/203217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5lNM1dmYMHqD4PJjl1CLkkw8zNj.jpg'),
(69450, 4754, 'Chuck Norris: O Homem da Lei S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/203218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69451, 4754, 'Chuck Norris: O Homem da Lei S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/203219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wUri5l8cNaMsg2XVFhhgyDQ2Sa0.jpg'),
(69452, 4754, 'Chuck Norris: O Homem da Lei S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/203220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vyQ3eQ46LgedOYeMEnic26sr0aH.jpg'),
(69453, 4754, 'Chuck Norris: O Homem da Lei S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/203221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wkyY11YLpNNeNZNIFHTCxIzAf8g.jpg'),
(69454, 4754, 'Chuck Norris: O Homem da Lei S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/203222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ePBfdlHoqLufeolTWpLFOa4TQT.jpg'),
(69455, 4754, 'Chuck Norris: O Homem da Lei S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/203223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oWOOQAwDxTST6GZLJuDrqISjPEN.jpg'),
(69456, 4755, 'Chuck Norris: O Homem da Lei S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69457, 4755, 'Chuck Norris: O Homem da Lei S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69458, 4755, 'Chuck Norris: O Homem da Lei S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69459, 4755, 'Chuck Norris: O Homem da Lei S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69460, 4755, 'Chuck Norris: O Homem da Lei S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69461, 4755, 'Chuck Norris: O Homem da Lei S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69462, 4755, 'Chuck Norris: O Homem da Lei S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69463, 4755, 'Chuck Norris: O Homem da Lei S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69464, 4755, 'Chuck Norris: O Homem da Lei S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69465, 4755, 'Chuck Norris: O Homem da Lei S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69466, 4755, 'Chuck Norris: O Homem da Lei S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69467, 4755, 'Chuck Norris: O Homem da Lei S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69468, 4755, 'Chuck Norris: O Homem da Lei S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69469, 4755, 'Chuck Norris: O Homem da Lei S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/203237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69470, 4755, 'Chuck Norris: O Homem da Lei S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/203238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69471, 4755, 'Chuck Norris: O Homem da Lei S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/203239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69472, 4755, 'Chuck Norris: O Homem da Lei S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/203240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69473, 4755, 'Chuck Norris: O Homem da Lei S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/203241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69474, 4755, 'Chuck Norris: O Homem da Lei S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/203242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69475, 4755, 'Chuck Norris: O Homem da Lei S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/203243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69476, 4755, 'Chuck Norris: O Homem da Lei S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/203244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69477, 4756, 'Chuck Norris: O Homem da Lei S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69478, 4756, 'Chuck Norris: O Homem da Lei S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69479, 4756, 'Chuck Norris: O Homem da Lei S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69480, 4756, 'Chuck Norris: O Homem da Lei S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69481, 4756, 'Chuck Norris: O Homem da Lei S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69482, 4756, 'Chuck Norris: O Homem da Lei S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69483, 4756, 'Chuck Norris: O Homem da Lei S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69484, 4756, 'Chuck Norris: O Homem da Lei S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69485, 4756, 'Chuck Norris: O Homem da Lei S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69486, 4756, 'Chuck Norris: O Homem da Lei S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69487, 4756, 'Chuck Norris: O Homem da Lei S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69488, 4756, 'Chuck Norris: O Homem da Lei S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69489, 4756, 'Chuck Norris: O Homem da Lei S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69490, 4756, 'Chuck Norris: O Homem da Lei S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/203258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69491, 4756, 'Chuck Norris: O Homem da Lei S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/203259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69492, 4756, 'Chuck Norris: O Homem da Lei S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/203260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69493, 4756, 'Chuck Norris: O Homem da Lei S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/203261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69494, 4756, 'Chuck Norris: O Homem da Lei S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/203262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69495, 4756, 'Chuck Norris: O Homem da Lei S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/203263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69496, 4756, 'Chuck Norris: O Homem da Lei S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/203264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69497, 4756, 'Chuck Norris: O Homem da Lei S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/203265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69498, 4756, 'Chuck Norris: O Homem da Lei S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/203266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69499, 4756, 'Chuck Norris: O Homem da Lei S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/203267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69500, 4756, 'Chuck Norris: O Homem da Lei S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/203268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69501, 4756, 'Chuck Norris: O Homem da Lei S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/203269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69502, 4757, 'Chuck Norris: O Homem da Lei S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69503, 4757, 'Chuck Norris: O Homem da Lei S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69504, 4757, 'Chuck Norris: O Homem da Lei S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69505, 4757, 'Chuck Norris: O Homem da Lei S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69506, 4757, 'Chuck Norris: O Homem da Lei S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69507, 4757, 'Chuck Norris: O Homem da Lei S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69508, 4757, 'Chuck Norris: O Homem da Lei S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69509, 4757, 'Chuck Norris: O Homem da Lei S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69510, 4757, 'Chuck Norris: O Homem da Lei S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69511, 4757, 'Chuck Norris: O Homem da Lei S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69512, 4757, 'Chuck Norris: O Homem da Lei S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69513, 4757, 'Chuck Norris: O Homem da Lei S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69514, 4757, 'Chuck Norris: O Homem da Lei S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69515, 4757, 'Chuck Norris: O Homem da Lei S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/203283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69516, 4757, 'Chuck Norris: O Homem da Lei S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/203284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69517, 4757, 'Chuck Norris: O Homem da Lei S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/203285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69518, 4757, 'Chuck Norris: O Homem da Lei S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/203286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69519, 4757, 'Chuck Norris: O Homem da Lei S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/203287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69520, 4757, 'Chuck Norris: O Homem da Lei S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/203288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69521, 4757, 'Chuck Norris: O Homem da Lei S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/203289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69522, 4757, 'Chuck Norris: O Homem da Lei S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/203290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69523, 4757, 'Chuck Norris: O Homem da Lei S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/203291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69524, 4757, 'Chuck Norris: O Homem da Lei S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/203292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69525, 4757, 'Chuck Norris: O Homem da Lei S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/203293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69526, 4757, 'Chuck Norris: O Homem da Lei S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/203294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69527, 4757, 'Chuck Norris: O Homem da Lei S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/203295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69528, 4757, 'Chuck Norris: O Homem da Lei S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/203296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69529, 4758, 'Chuck Norris: O Homem da Lei S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69530, 4758, 'Chuck Norris: O Homem da Lei S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69531, 4758, 'Chuck Norris: O Homem da Lei S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69532, 4758, 'Chuck Norris: O Homem da Lei S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69533, 4758, 'Chuck Norris: O Homem da Lei S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69534, 4758, 'Chuck Norris: O Homem da Lei S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69535, 4758, 'Chuck Norris: O Homem da Lei S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69536, 4758, 'Chuck Norris: O Homem da Lei S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69537, 4758, 'Chuck Norris: O Homem da Lei S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69538, 4758, 'Chuck Norris: O Homem da Lei S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69539, 4758, 'Chuck Norris: O Homem da Lei S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69540, 4758, 'Chuck Norris: O Homem da Lei S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69541, 4758, 'Chuck Norris: O Homem da Lei S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69542, 4758, 'Chuck Norris: O Homem da Lei S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/203310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69543, 4758, 'Chuck Norris: O Homem da Lei S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/203311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69544, 4758, 'Chuck Norris: O Homem da Lei S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/203312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69545, 4758, 'Chuck Norris: O Homem da Lei S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/203313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69546, 4758, 'Chuck Norris: O Homem da Lei S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/203314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69547, 4758, 'Chuck Norris: O Homem da Lei S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/203315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69548, 4758, 'Chuck Norris: O Homem da Lei S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/203316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69549, 4758, 'Chuck Norris: O Homem da Lei S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/203317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69550, 4758, 'Chuck Norris: O Homem da Lei S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/203318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(69551, 4758, 'Chuck Norris: O Homem da Lei S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/203319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69552, 4758, 'Chuck Norris: O Homem da Lei S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/203320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69553, 4758, 'Chuck Norris: O Homem da Lei S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/203321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69554, 4759, 'Chuck Norris: O Homem da Lei S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69555, 4759, 'Chuck Norris: O Homem da Lei S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69556, 4759, 'Chuck Norris: O Homem da Lei S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69557, 4759, 'Chuck Norris: O Homem da Lei S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69558, 4759, 'Chuck Norris: O Homem da Lei S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69559, 4759, 'Chuck Norris: O Homem da Lei S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69560, 4759, 'Chuck Norris: O Homem da Lei S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69561, 4759, 'Chuck Norris: O Homem da Lei S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69562, 4759, 'Chuck Norris: O Homem da Lei S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69563, 4759, 'Chuck Norris: O Homem da Lei S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69564, 4759, 'Chuck Norris: O Homem da Lei S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69565, 4759, 'Chuck Norris: O Homem da Lei S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69566, 4759, 'Chuck Norris: O Homem da Lei S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69567, 4759, 'Chuck Norris: O Homem da Lei S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/203335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69568, 4759, 'Chuck Norris: O Homem da Lei S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/203336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69569, 4759, 'Chuck Norris: O Homem da Lei S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/203337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69570, 4759, 'Chuck Norris: O Homem da Lei S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/203338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69571, 4759, 'Chuck Norris: O Homem da Lei S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/203339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69572, 4759, 'Chuck Norris: O Homem da Lei S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/203340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69573, 4759, 'Chuck Norris: O Homem da Lei S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/203341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69574, 4759, 'Chuck Norris: O Homem da Lei S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/203342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69575, 4759, 'Chuck Norris: O Homem da Lei S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/203343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69576, 4759, 'Chuck Norris: O Homem da Lei S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/203344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69577, 4760, 'Chuck Norris: O Homem da Lei S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69578, 4760, 'Chuck Norris: O Homem da Lei S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69579, 4760, 'Chuck Norris: O Homem da Lei S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69580, 4760, 'Chuck Norris: O Homem da Lei S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69581, 4760, 'Chuck Norris: O Homem da Lei S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69582, 4760, 'Chuck Norris: O Homem da Lei S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69583, 4760, 'Chuck Norris: O Homem da Lei S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69584, 4760, 'Chuck Norris: O Homem da Lei S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69585, 4760, 'Chuck Norris: O Homem da Lei S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69586, 4760, 'Chuck Norris: O Homem da Lei S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69587, 4760, 'Chuck Norris: O Homem da Lei S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69588, 4760, 'Chuck Norris: O Homem da Lei S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69589, 4760, 'Chuck Norris: O Homem da Lei S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69590, 4760, 'Chuck Norris: O Homem da Lei S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/203358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69591, 4760, 'Chuck Norris: O Homem da Lei S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/203359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69592, 4760, 'Chuck Norris: O Homem da Lei S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/203360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69593, 4760, 'Chuck Norris: O Homem da Lei S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/203361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69594, 4760, 'Chuck Norris: O Homem da Lei S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/203362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69595, 4760, 'Chuck Norris: O Homem da Lei S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/203363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69596, 4760, 'Chuck Norris: O Homem da Lei S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/203364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69597, 4760, 'Chuck Norris: O Homem da Lei S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/203365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69598, 4760, 'Chuck Norris: O Homem da Lei S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/203366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69599, 4760, 'Chuck Norris: O Homem da Lei S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/203367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69600, 4760, 'Chuck Norris: O Homem da Lei S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/203368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69601, 4761, 'Chuck Norris: O Homem da Lei S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69602, 4761, 'Chuck Norris: O Homem da Lei S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69603, 4761, 'Chuck Norris: O Homem da Lei S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69604, 4761, 'Chuck Norris: O Homem da Lei S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69605, 4761, 'Chuck Norris: O Homem da Lei S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69606, 4761, 'Chuck Norris: O Homem da Lei S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69607, 4761, 'Chuck Norris: O Homem da Lei S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69608, 4761, 'Chuck Norris: O Homem da Lei S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69609, 4761, 'Chuck Norris: O Homem da Lei S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69610, 4761, 'Chuck Norris: O Homem da Lei S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69611, 4761, 'Chuck Norris: O Homem da Lei S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69612, 4761, 'Chuck Norris: O Homem da Lei S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69613, 4761, 'Chuck Norris: O Homem da Lei S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69614, 4761, 'Chuck Norris: O Homem da Lei S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/203382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69615, 4761, 'Chuck Norris: O Homem da Lei S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/203383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69616, 4761, 'Chuck Norris: O Homem da Lei S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/203384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69617, 4761, 'Chuck Norris: O Homem da Lei S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/203385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69618, 4761, 'Chuck Norris: O Homem da Lei S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/203386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69619, 4761, 'Chuck Norris: O Homem da Lei S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/203387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69620, 4761, 'Chuck Norris: O Homem da Lei S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/203388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69621, 4761, 'Chuck Norris: O Homem da Lei S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/203389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69622, 4761, 'Chuck Norris: O Homem da Lei S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/203390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69623, 4761, 'Chuck Norris: O Homem da Lei S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/203391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lldKpGEOlHJXMkb1pi7s7xCExmX.jpg'),
(69624, 4762, 'Welcome to Utmark S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kQ1u7aWA9FPLZzYC3mAC4EJJRzl.jpg'),
(69625, 4762, 'Welcome to Utmark S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7OptnGrNwF6u2kfIL3ON7nhMxag.jpg'),
(69626, 4762, 'Welcome to Utmark S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ayWFks4YZHV0lpBUEjJuIu7czg2.jpg'),
(69627, 4762, 'Welcome to Utmark S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gkz3WT6KzEPspBKhcDWmmmxq6it.jpg'),
(69628, 4762, 'Welcome to Utmark S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tD4Gll60xvx7Hold7VL0BULzMKj.jpg'),
(69629, 4762, 'Welcome to Utmark S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3bul0lKHHEWNpBzogJpGT2jt9xu.jpg'),
(69630, 4762, 'Welcome to Utmark S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ZZJHRbC2Dsv4mozmQieByKiuVO.jpg'),
(69631, 4762, 'Welcome to Utmark S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u7S7kHzePJvBFhXusNgqRn5GxTl.jpg'),
(69632, 4763, 'Big Bang: A Teoria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rxWlBXZhGWhumbLB8gAHyyW3ITD.jpg'),
(69633, 4763, 'Big Bang: A Teoria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Itgr82yyAEtwegAZgMm30UqJXK.jpg'),
(69634, 4763, 'Big Bang: A Teoria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eDyDC7cwKz9ZTA4CX44eKuHjPgZ.jpg'),
(69635, 4763, 'Big Bang: A Teoria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bk8aIjAyS6XDG3I3otseP0jaR4x.jpg'),
(69636, 4763, 'Big Bang: A Teoria S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zO3CSyb13PQyzWICp4mmZEUeExp.jpg'),
(69637, 4763, 'Big Bang: A Teoria S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4P20QdmB6QL8aa0b8dKR8sHK1iW.jpg'),
(69638, 4763, 'Big Bang: A Teoria S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4y5rvzPZF5ukM3vtktqWTp9MhyH.jpg'),
(69639, 4763, 'Big Bang: A Teoria S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rbVfuB7vBrrXygo0d8qhk9FhmAd.jpg'),
(69640, 4763, 'Big Bang: A Teoria S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8MvMEvZzZPBkgQZIVk9KvF8nLH5.jpg'),
(69641, 4763, 'Big Bang: A Teoria S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6dssfbhNv1g3FFqKWKJhNqaqSQH.jpg'),
(69642, 4763, 'Big Bang: A Teoria S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0E0GNUMHWZDNKbygCjKJGiFc9G.jpg'),
(69643, 4763, 'Big Bang: A Teoria S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wlo6NGvrpo58hnUztkAmdDBPj2D.jpg'),
(69644, 4763, 'Big Bang: A Teoria S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w1Et8tW5En8a2ieEWRlolAVkyED.jpg'),
(69645, 4763, 'Big Bang: A Teoria S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/205938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sktEOfZVIBnyW6MeZlGXbcdp6vO.jpg'),
(69646, 4763, 'Big Bang: A Teoria S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/205939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBlf2PEd6RDGnyOip6ZPJ825AMw.jpg'),
(69647, 4763, 'Big Bang: A Teoria S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/205940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jnI6qR3y9Hfn7hA1uCUJhYMkIAv.jpg'),
(69648, 4763, 'Big Bang: A Teoria S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/205941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3RCfgXjtRcWRt1ci7RIYi3JzJQ9.jpg'),
(69649, 4764, 'Big Bang: A Teoria S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y9cFxQyFRBOewwVvkMl6SaH2om0.jpg'),
(69650, 4764, 'Big Bang: A Teoria S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c0GdwSQIzxSERM0zhtHoPzPeonO.jpg'),
(69651, 4764, 'Big Bang: A Teoria S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/flYDcIFiTrqj3y5zMx1ICw43H10.jpg'),
(69652, 4764, 'Big Bang: A Teoria S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AvCiGNJqqaowpZlBdoO6Bp2hIdp.jpg'),
(69653, 4764, 'Big Bang: A Teoria S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vlXdkJITQZu6UlzKYQatLZ0oLu8.jpg'),
(69654, 4764, 'Big Bang: A Teoria S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aKBbzJ48BHOLtk2JLCOmKVlumrP.jpg'),
(69655, 4764, 'Big Bang: A Teoria S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Ua2Md9npwPVIOlGw7o9472PgOu.jpg'),
(69656, 4764, 'Big Bang: A Teoria S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AlvHVY7gvBHfQvMLAvB9PODeYQw.jpg'),
(69657, 4764, 'Big Bang: A Teoria S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/26vsq4NjK2SBrsfOxS4Y2zk2BPZ.jpg'),
(69658, 4764, 'Big Bang: A Teoria S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z4HgaR4ZiktSGuZwPQQu7kQED1Y.jpg'),
(69659, 4764, 'Big Bang: A Teoria S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUh7k8uTCSjnlFqQZ4HVKZ8N7rA.jpg'),
(69660, 4764, 'Big Bang: A Teoria S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdo2epxMfOhpAWJ3EWplioQakRK.jpg'),
(69661, 4764, 'Big Bang: A Teoria S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9q49iyMGcO9EIk9vWbnBZgfGNSF.jpg'),
(69662, 4764, 'Big Bang: A Teoria S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/205955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wC2YMYgyCnEixzO1ztYx1LUAndL.jpg'),
(69663, 4764, 'Big Bang: A Teoria S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/205956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cShchuw3099TXbfav7e9XU6qCoV.jpg'),
(69664, 4764, 'Big Bang: A Teoria S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/205957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/egK4v3alm6G7cm0CmMRGR3p8Yx3.jpg'),
(69665, 4764, 'Big Bang: A Teoria S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/205958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uorhUtKMHkx7EokhUcSBl3q6GRt.jpg'),
(69666, 4764, 'Big Bang: A Teoria S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/205959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fkaYEuDqCyBsODp0XYMAZrLULYs.jpg'),
(69667, 4764, 'Big Bang: A Teoria S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/205960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8LL0P42Z8mwyFXfnF3jnaabSZYt.jpg'),
(69668, 4764, 'Big Bang: A Teoria S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/205961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/otMgg5qrM4XfHwbGnpWhPy8R2yD.jpg'),
(69669, 4764, 'Big Bang: A Teoria S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/205962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AoONkeffM4zSOV7gA2jXCHQvewp.jpg'),
(69670, 4764, 'Big Bang: A Teoria S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/205963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2HlnIUMDfXHHt5MMbtJ9VPIOPkl.jpg'),
(69671, 4764, 'Big Bang: A Teoria S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/205964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5NiLbb4TXeiiAjTPyqP08Swu8w5.jpg'),
(69672, 4765, 'Big Bang: A Teoria S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4MFmDclUoXHM0se1IM9jKRhHp6n.jpg'),
(69673, 4765, 'Big Bang: A Teoria S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uVhcEHlKSzV29jrozrfT7Upl9CS.jpg'),
(69674, 4765, 'Big Bang: A Teoria S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gVJgi08zLaHaksdlBJaBXTnRtVD.jpg'),
(69675, 4765, 'Big Bang: A Teoria S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ooKlhHysYeBILB1vdgOp8386ZuC.jpg'),
(69676, 4765, 'Big Bang: A Teoria S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqQqkfuRr7v8tggXIiK6HuGV3gT.jpg'),
(69677, 4765, 'Big Bang: A Teoria S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yLX4EAeyh3qmsTsyqbJnn5xANTJ.jpg'),
(69678, 4765, 'Big Bang: A Teoria S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jF7zs6f8RUWm0XRFVc5mi1nvl3z.jpg'),
(69679, 4765, 'Big Bang: A Teoria S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5UQl8U8UfY5anCF5fvSTxUTShOp.jpg'),
(69680, 4765, 'Big Bang: A Teoria S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x9hd50SQpxiZ1nLXeyhHeeAnT8x.jpg'),
(69681, 4765, 'Big Bang: A Teoria S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmpF9foIp6gbaDS53HNARDOcrkO.jpg'),
(69682, 4765, 'Big Bang: A Teoria S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqkp5j4wWyyqf5PLNdzb53VMUkV.jpg'),
(69683, 4765, 'Big Bang: A Teoria S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/10LmyJHk8tUvAdJDAsaaMmPcU7d.jpg'),
(69684, 4765, 'Big Bang: A Teoria S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5GbZ08Qs7lXPNns9FVvDStYnsWK.jpg'),
(69685, 4765, 'Big Bang: A Teoria S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/205978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMnI5T5aBIt16j4pzEMXdgwUTVV.jpg'),
(69686, 4765, 'Big Bang: A Teoria S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/205979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3S2CGr8IrP5u7TPttsSnVs1upTe.jpg'),
(69687, 4765, 'Big Bang: A Teoria S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/205980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dhAZ1dKdbxhQAs2FmQzA9rbUtlA.jpg'),
(69688, 4765, 'Big Bang: A Teoria S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/205981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qwBvS3JV40nWZQOBhxTMhWoSk0Q.jpg'),
(69689, 4765, 'Big Bang: A Teoria S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/205982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xwAZ3Yh8Goq6URZees94Yyy3Mhz.jpg'),
(69690, 4765, 'Big Bang: A Teoria S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/205983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dTGHzzGhkbzKh0idjkzdVOyfOaS.jpg'),
(69691, 4765, 'Big Bang: A Teoria S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/205984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wztaQvhy4aNNgJmJhs201Qv8zXm.jpg'),
(69692, 4765, 'Big Bang: A Teoria S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/205985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cppyrsh201R39yrlQrBk7ShYpQ3.jpg'),
(69693, 4765, 'Big Bang: A Teoria S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/205986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cGQf2br0gTknsDtj71CGrrX1Gg6.jpg'),
(69694, 4765, 'Big Bang: A Teoria S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/205987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8qiIzoYt24oqoYu5W6Zl1NLdkeM.jpg'),
(69695, 4766, 'Big Bang: A Teoria S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iDXzeiDFCoa1voKqjbLeQO7ZdhM.jpg'),
(69696, 4766, 'Big Bang: A Teoria S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/78CArSQpsk6Tp30E3iCY6uFtPCL.jpg'),
(69697, 4766, 'Big Bang: A Teoria S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hyTO2DzzYLKgQforOnnYl1RmDiF.jpg'),
(69698, 4766, 'Big Bang: A Teoria S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/isCe5dxkG0Ufi4cNRfmCr2HsoJd.jpg'),
(69699, 4766, 'Big Bang: A Teoria S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r55GrliuOnABnS12VZhx3eyVgO0.jpg'),
(69700, 4766, 'Big Bang: A Teoria S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nZlDWPTzz8op0GK3UBSPJ9iDtCk.jpg'),
(69701, 4766, 'Big Bang: A Teoria S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4dwublTmQPJgsKV1P5G72To4geg.jpg'),
(69702, 4766, 'Big Bang: A Teoria S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p64YIVVg7FOocc9hj8MRgFOo9gP.jpg'),
(69703, 4766, 'Big Bang: A Teoria S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A5p9jS9XLeeoBYkfkPPJzaJ5NH5.jpg'),
(69704, 4766, 'Big Bang: A Teoria S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4SZIoejudZ0QEDPVC3fdUkpuHFt.jpg'),
(69705, 4766, 'Big Bang: A Teoria S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ApLpkPHmKg3rGUCwbEB10P1j95x.jpg'),
(69706, 4766, 'Big Bang: A Teoria S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhiVs3YJsOhEoXq4xqYSQlvrjwz.jpg'),
(69707, 4766, 'Big Bang: A Teoria S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBn5BgSSycxwPf5WDZr1ek2xTqu.jpg'),
(69708, 4766, 'Big Bang: A Teoria S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDy6HJoVXD7DHbZSJiNUXxud9th.jpg'),
(69709, 4766, 'Big Bang: A Teoria S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ygbDoCEIqg2LyJeG69CZWMSvKcP.jpg'),
(69710, 4766, 'Big Bang: A Teoria S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gcvAKaRQORWFz6b2dMHf7iHThQ7.jpg'),
(69711, 4766, 'Big Bang: A Teoria S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/206004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/waFlLkW5vTHor85fOdBrT4pT6iO.jpg'),
(69712, 4766, 'Big Bang: A Teoria S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/206005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lxpNNW7buxaTnWDtPAnqpc6ly7g.jpg'),
(69713, 4766, 'Big Bang: A Teoria S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/206006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uQSqSBo4KxF35yXRZqqThxWoowW.jpg'),
(69714, 4766, 'Big Bang: A Teoria S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/206007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eIxfInM3Aog4waoqArtqg6RmI4B.jpg'),
(69715, 4766, 'Big Bang: A Teoria S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/206008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v6uyjP4ZmENVXvPNjMqLPORZpOw.jpg'),
(69716, 4766, 'Big Bang: A Teoria S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/206009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vawJtmb10SDOSNSCx8U9gjGWSIk.jpg'),
(69717, 4766, 'Big Bang: A Teoria S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/206010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hp8XofpW3py0mN9nlunsbJnlby2.jpg'),
(69718, 4766, 'Big Bang: A Teoria S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/206011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6s0jCxiefhGm9H0ZK5qOH6I7BNB.jpg'),
(69719, 4767, 'Big Bang: A Teoria S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/IJvS3oG8jiFb7Vrdf1oK4zUEC8.jpg'),
(69720, 4767, 'Big Bang: A Teoria S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nam7XE9k4u8h88CGmc3mctlmlHQ.jpg'),
(69721, 4767, 'Big Bang: A Teoria S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tc4zZqhIfWB9F7zb75aAJf2v7BY.jpg'),
(69722, 4767, 'Big Bang: A Teoria S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/so0RhfCvlac3rdHeyjtAj9VDhbR.jpg'),
(69723, 4767, 'Big Bang: A Teoria S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/esyUQnGgTgAnKhAIHdgfO48PUEk.jpg'),
(69724, 4767, 'Big Bang: A Teoria S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wF1So7qvo5q8Dljs9nsgFyMMJZ9.jpg'),
(69725, 4767, 'Big Bang: A Teoria S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n49ns37Lk2Ucek967PcF2O0oXCZ.jpg'),
(69726, 4767, 'Big Bang: A Teoria S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Y8us3iVf2jWp8ReDrms8NLLlQ9.jpg'),
(69727, 4767, 'Big Bang: A Teoria S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g2dgEcCVHgcEPFNNtU7uZKBtsKR.jpg'),
(69728, 4767, 'Big Bang: A Teoria S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sf1FDxLxinOqyY05Uk3MRZzlP1V.jpg'),
(69729, 4767, 'Big Bang: A Teoria S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ayPfXo1MTo7s3L16qdDc1ELHF1C.jpg'),
(69730, 4767, 'Big Bang: A Teoria S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dROWDe3GIucgFvYIQa71Utt5Vyz.jpg'),
(69731, 4767, 'Big Bang: A Teoria S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/92zFLmItlFgbu1IsAChlnkANotm.jpg'),
(69732, 4767, 'Big Bang: A Teoria S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/suO4XRXxcBNv5Z0XgsAN0WwRNWl.jpg'),
(69733, 4767, 'Big Bang: A Teoria S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1sUJWTpRxgtTF0teDwKape0958u.jpg'),
(69734, 4767, 'Big Bang: A Teoria S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4WC4byycJC6RyY6BAI57XW2gsv4.jpg'),
(69735, 4767, 'Big Bang: A Teoria S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/206028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wRwpnqqpCAWKfReVjrwh9PcuaJJ.jpg'),
(69736, 4767, 'Big Bang: A Teoria S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/206029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1FxJEMcSRTpVKNNL9rxP6ylHjYL.jpg'),
(69737, 4767, 'Big Bang: A Teoria S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/206030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oV7kx2yUpQW9J1EtoOCzjg0ImrQ.jpg'),
(69738, 4767, 'Big Bang: A Teoria S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/206031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ypKnCvnFhLVXJvm7oH9ZrSOIE0m.jpg'),
(69739, 4767, 'Big Bang: A Teoria S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/206032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aIvV1RM6nwaBmE5VzNp1cRU0epL.jpg'),
(69740, 4767, 'Big Bang: A Teoria S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/206033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/679tvCfRg6YHN2ra4JOWeCyZCcU.jpg'),
(69741, 4767, 'Big Bang: A Teoria S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/206034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4dWKBE5jyEqJAq8UQBxqsmPyPUg.jpg'),
(69742, 4767, 'Big Bang: A Teoria S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/206035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jpmBnWyw7tiE2MMIssuo3fJdf88.jpg'),
(69743, 4768, 'Big Bang: A Teoria S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5vy4ZXE00Qs3gpIaotsywRIBhno.jpg'),
(69744, 4768, 'Big Bang: A Teoria S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cWvn5xNB9ejBB7ExiImyutoJzUK.jpg'),
(69745, 4768, 'Big Bang: A Teoria S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f1RKpjzdgCTHej3MjXiZUpnKSLC.jpg'),
(69746, 4768, 'Big Bang: A Teoria S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/18VwkmYXdZrAhlziplhVCslRfN8.jpg'),
(69747, 4768, 'Big Bang: A Teoria S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1VLar3TGjOW9hT7s7XVdjrDWc18.jpg'),
(69748, 4768, 'Big Bang: A Teoria S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2D9P9WXMhLkb5A4AIPHKXlVXBfC.jpg'),
(69749, 4768, 'Big Bang: A Teoria S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8txKxtvCOWK94bNYC6Bm68ndRoa.jpg'),
(69750, 4768, 'Big Bang: A Teoria S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uA6mbAgcXFkMM0mOyp1VQbqARct.jpg'),
(69751, 4768, 'Big Bang: A Teoria S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/270qB7kEnFGXx1WZoCS0Hk1KdR7.jpg'),
(69752, 4768, 'Big Bang: A Teoria S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1v11KeF9iGcsMIyoubWxn2PUiMt.jpg'),
(69753, 4768, 'Big Bang: A Teoria S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nPOucbTVMxh3Vk7G11JQs6M0wKs.jpg'),
(69754, 4768, 'Big Bang: A Teoria S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1CHGM1ilOLONoCLljqr87GUf3qJ.jpg'),
(69755, 4768, 'Big Bang: A Teoria S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/92c2zsSkCx8Cr0c6TGnRYiiAbFy.jpg'),
(69756, 4768, 'Big Bang: A Teoria S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/49L8kp4S5KG8F51jWhnVqiROU7o.jpg'),
(69757, 4768, 'Big Bang: A Teoria S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jaZBFzMD1IOMNJNI6PvPyF5K0Pq.jpg'),
(69758, 4768, 'Big Bang: A Teoria S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l5Hfix96TTSLqPJcPB8EtFwN75R.jpg'),
(69759, 4768, 'Big Bang: A Teoria S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/206052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dqVFsvzeFKPmInYTFcHB29spOUT.jpg'),
(69760, 4768, 'Big Bang: A Teoria S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/206053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qYTkHDZ4UFb8AmoAfdWnA2qMqGA.jpg'),
(69761, 4768, 'Big Bang: A Teoria S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/206054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yhZCWMcav9KbvmSMi7jfEz3Yyv5.jpg'),
(69762, 4768, 'Big Bang: A Teoria S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/206055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/edWS9RrzI1LfrYeUn58xIjrgL0L.jpg'),
(69763, 4768, 'Big Bang: A Teoria S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/206056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eXEySGfJfXfCb8K6Ag6UjXnGewu.jpg'),
(69764, 4768, 'Big Bang: A Teoria S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/206057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cd1F6bJeh8ZShiN6kg4A86rrCQC.jpg'),
(69765, 4768, 'Big Bang: A Teoria S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/206058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tr6SA0xPwZ2vuTXQeccPplkxBcD.jpg'),
(69766, 4768, 'Big Bang: A Teoria S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/206059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rvBROuNdOHLsDSWmNT0lx3m1sce.jpg'),
(69767, 4769, 'Big Bang: A Teoria S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iPi2YpnIqON7ZQhn3QprEeKgME7.jpg'),
(69768, 4769, 'Big Bang: A Teoria S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vr0YARnNNOQI8xjVkPKHnZmvbON.jpg'),
(69769, 4769, 'Big Bang: A Teoria S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m71kn4aV5SJ0w8i4eOaxAG7BXmy.jpg'),
(69770, 4769, 'Big Bang: A Teoria S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/epyF2nyBQYRc0y5n0GxOwU2VJfV.jpg'),
(69771, 4769, 'Big Bang: A Teoria S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7kueaQBaPIEo4WFvp4WuwdUSRJo.jpg'),
(69772, 4769, 'Big Bang: A Teoria S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k16itq0M19LDqrQ1NCUQsyFANSl.jpg'),
(69773, 4769, 'Big Bang: A Teoria S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4L1ypmSdPjuGYJwtxxgXEnauQsD.jpg'),
(69774, 4769, 'Big Bang: A Teoria S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cncUlcRacYm5INv6siAjw2GXefg.jpg'),
(69775, 4769, 'Big Bang: A Teoria S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4EeNrddDPVA2OY8n3Uz3Pxlhdpt.jpg'),
(69776, 4769, 'Big Bang: A Teoria S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ycbx0CPvPibIOnVOzP5YyU2YstV.jpg'),
(69777, 4769, 'Big Bang: A Teoria S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyR37OqELuDhKPQDtQIK5TZVJGJ.jpg'),
(69778, 4769, 'Big Bang: A Teoria S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vLr0jz0C8ngi4NNG5PaBlfE3r5I.jpg'),
(69779, 4769, 'Big Bang: A Teoria S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5R6RSO2ifz8J6QwJ59u3AuI9ucB.jpg'),
(69780, 4769, 'Big Bang: A Teoria S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/klVbxVnbTNXPv7jiXaRGkqXq41z.jpg'),
(69781, 4769, 'Big Bang: A Teoria S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LYPNN85VA3B7nzrpwEyIMW8nos.jpg'),
(69782, 4769, 'Big Bang: A Teoria S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQDnxCPLBsx3yqWkXxon5xUSKHT.jpg'),
(69783, 4769, 'Big Bang: A Teoria S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/206076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ag73vlMncS0hYSpjbYZMM712CNe.jpg'),
(69784, 4769, 'Big Bang: A Teoria S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/206077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QbH1E7lYWhn0V1tQfldiJmUAvV.jpg'),
(69785, 4769, 'Big Bang: A Teoria S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/206078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cNhpx051SfpdrmVXTEqcIoGruuJ.jpg'),
(69786, 4769, 'Big Bang: A Teoria S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/206079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/scNSDVUvVMAhK3bdViIKa3MoCdA.jpg'),
(69787, 4769, 'Big Bang: A Teoria S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/206080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ikhkakBWFAc3wnPTJ95ocsH6V7Z.jpg'),
(69788, 4769, 'Big Bang: A Teoria S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/206081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mTOX0QJ4S4XJZRTLgNv7ph1H2Cl.jpg'),
(69789, 4769, 'Big Bang: A Teoria S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/206082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhcQnZ5ZsDlVBHePHnJwYjs3xWt.jpg'),
(69790, 4769, 'Big Bang: A Teoria S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/206083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2SlmcV4djrxeKoi9aM093TWUweF.jpg'),
(69791, 4770, 'Big Bang: A Teoria S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eiknk78qNy9yYtmwjBZYLURhR19.jpg'),
(69792, 4770, 'Big Bang: A Teoria S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gzDRKQVGyX4FTKv51CWFqVc34TG.jpg'),
(69793, 4770, 'Big Bang: A Teoria S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eHuRYLXpxZATwCJrqubQelPEjHs.jpg'),
(69794, 4770, 'Big Bang: A Teoria S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fxyeZcehNMkV7o8qtuv2tMzI2pn.jpg'),
(69795, 4770, 'Big Bang: A Teoria S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/psYPKikZStDFT6OqFLp3TKvqQbI.jpg'),
(69796, 4770, 'Big Bang: A Teoria S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nh5DYUzf3waIHJAO7Ircv7MnMHj.jpg'),
(69797, 4770, 'Big Bang: A Teoria S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/34TSv9Gzanl0bnbeAiVBgQ7nAZl.jpg'),
(69798, 4770, 'Big Bang: A Teoria S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4j2EMbHRVvimywvBwZQ5q7O3wOS.jpg'),
(69799, 4770, 'Big Bang: A Teoria S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ywnhAABDYKUpdxfn9vz1oH4zBee.jpg'),
(69800, 4770, 'Big Bang: A Teoria S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24ShQB4KKIoBy0jIy9pdYt7GnPE.jpg'),
(69801, 4770, 'Big Bang: A Teoria S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r9WIq3OcYVeBxTEzCKgB4lGOEhd.jpg'),
(69802, 4770, 'Big Bang: A Teoria S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDT0ktiJ5h7N2LoH4PD7YERuMyp.jpg'),
(69803, 4770, 'Big Bang: A Teoria S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nQB2Pa1TXKQjSR4coCDRmox9UoE.jpg'),
(69804, 4770, 'Big Bang: A Teoria S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kRpSOJmWA0ek6Qyua4pn3zYEvfr.jpg'),
(69805, 4770, 'Big Bang: A Teoria S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uDHVXadIwiUvYENRrzFyCJoSjFw.jpg'),
(69806, 4770, 'Big Bang: A Teoria S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jkeyB0XEMgiFuQuXojQjKa4FNCO.jpg'),
(69807, 4770, 'Big Bang: A Teoria S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/206100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Jh4pXXaagHSb9Ap40rQBDefRFl.jpg'),
(69808, 4770, 'Big Bang: A Teoria S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/206101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qRNOiaPWO6m5gR5STlrGjSSS0Cv.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(69809, 4770, 'Big Bang: A Teoria S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/206102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6O7dxVBPOFKp2cdfFIl5Lf0mys2.jpg'),
(69810, 4770, 'Big Bang: A Teoria S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/206103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1VqKU1CVOkLDRoYnognbKuXTlBn.jpg'),
(69811, 4770, 'Big Bang: A Teoria S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/206104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ApopO3nNzWkFgE7ATs1jMOOaAzF.jpg'),
(69812, 4770, 'Big Bang: A Teoria S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/206105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/54TfSCfz5kMrQH81oppiCT6dqZl.jpg'),
(69813, 4770, 'Big Bang: A Teoria S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/206106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHVsK60TKWghadrtZ2G9MEsqIWd.jpg'),
(69814, 4770, 'Big Bang: A Teoria S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/206107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qhmAkhpkWpZnOPzTFbNfuvgot09.jpg'),
(69815, 4771, 'Big Bang: A Teoria S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/za6BAvh7hGFooEcANqJC5srF1FA.jpg'),
(69816, 4771, 'Big Bang: A Teoria S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n0uM0N3qz0kp51ad2lPajyt9Rhm.jpg'),
(69817, 4771, 'Big Bang: A Teoria S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZZhA9UBAmE0cu1qCfm8M7MfM53.jpg'),
(69818, 4771, 'Big Bang: A Teoria S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sJil2kjShboUXna44vBml70Xbj7.jpg'),
(69819, 4771, 'Big Bang: A Teoria S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eDOUvJIpKqK276AfbdnzrBC2XJR.jpg'),
(69820, 4771, 'Big Bang: A Teoria S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tqZH3yGasgJiW9WEuq7AG019Jot.jpg'),
(69821, 4771, 'Big Bang: A Teoria S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6p5E2E4ldD8Y3xLXm0amyGmqIn1.jpg'),
(69822, 4771, 'Big Bang: A Teoria S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2kduB25FNPL7V8uuTIdGbT9vaO.jpg'),
(69823, 4771, 'Big Bang: A Teoria S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uYdqPZZGn6bsJMl9ib8NmPlin9z.jpg'),
(69824, 4771, 'Big Bang: A Teoria S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Dysz0BIRSEWTnSxUKvzstaTVuS.jpg'),
(69825, 4771, 'Big Bang: A Teoria S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wXuaZNFFTzSnCyIzHJX8cpDPv7A.jpg'),
(69826, 4771, 'Big Bang: A Teoria S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4DnDFLbjiljaQuK2u7gv8ZP56lB.jpg'),
(69827, 4771, 'Big Bang: A Teoria S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ge9x2mL8kKRlAuaULVy5cNS1t98.jpg'),
(69828, 4771, 'Big Bang: A Teoria S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e4KZVnhg3UyZSAZIB6d3m38ToJz.jpg'),
(69829, 4771, 'Big Bang: A Teoria S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w93H4gv8LIb9nlITuGpR9ndDUk8.jpg'),
(69830, 4771, 'Big Bang: A Teoria S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cybOS60LRof6PljKrYXAyCh8637.jpg'),
(69831, 4771, 'Big Bang: A Teoria S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/206124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aCCxCIQjlFmlS97jCIzd2uameQl.jpg'),
(69832, 4771, 'Big Bang: A Teoria S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/206125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jUOKCbKMhg2jEarqXnuy0rdcLXO.jpg'),
(69833, 4771, 'Big Bang: A Teoria S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/206126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kl5SoKzqxhwK9irTvarRHOmTvi6.jpg'),
(69834, 4771, 'Big Bang: A Teoria S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/206127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eL2nmkRYtWcvXUVfx4SQGJeDULl.jpg'),
(69835, 4771, 'Big Bang: A Teoria S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/206128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/layOKctrtjUcwKZ1ofk1vuF65L5.jpg'),
(69836, 4771, 'Big Bang: A Teoria S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/206129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lUwn0Uxldc3B76B26Yd8aIPj4uM.jpg'),
(69837, 4771, 'Big Bang: A Teoria S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/206130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFmeHdgLoNVyRYv4omvrSoe9yLO.jpg'),
(69838, 4771, 'Big Bang: A Teoria S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/206131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/18nmVxxyu7jlKxqwn088P2hkQ4J.jpg'),
(69839, 4772, 'Big Bang: A Teoria S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9DPH88iL7f0GEFq8BggmOc6L0vk.jpg'),
(69840, 4772, 'Big Bang: A Teoria S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/chN747cMwRMuxm1JL1YKsKOsu9O.jpg'),
(69841, 4772, 'Big Bang: A Teoria S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sPTHeziA20nRw3NqA9j8FchsVdS.jpg'),
(69842, 4772, 'Big Bang: A Teoria S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dUEDKR7xxWcmGeKtfqI7e9fyQAw.jpg'),
(69843, 4772, 'Big Bang: A Teoria S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sXpnjSU96ED3yYVrm9BqYhgf4eG.jpg'),
(69844, 4772, 'Big Bang: A Teoria S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yEDSHVRQiHtIWQ3fcLutr2CSgVC.jpg'),
(69845, 4772, 'Big Bang: A Teoria S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kj7XGHGwP2rAr9SZQl0361rc1Q8.jpg'),
(69846, 4772, 'Big Bang: A Teoria S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/txfP3RGQrH975I1mVohAUOxYkjh.jpg'),
(69847, 4772, 'Big Bang: A Teoria S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lkrG22IN1cDzQUik3DSE0Gizkro.jpg'),
(69848, 4772, 'Big Bang: A Teoria S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gdmbxOWVmc35uryPjQdGeIFYhbU.jpg'),
(69849, 4772, 'Big Bang: A Teoria S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3FkVpR8xDoXlJ4E07JpwkTknaWK.jpg'),
(69850, 4772, 'Big Bang: A Teoria S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e0nr2JM5ZgLXtJejueg1uTIti6H.jpg'),
(69851, 4772, 'Big Bang: A Teoria S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yik9SnRIwGbJcbLKDdN64z796rl.jpg'),
(69852, 4772, 'Big Bang: A Teoria S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Dx0gT8VsA9iC9migoWFiepWMQf.jpg'),
(69853, 4772, 'Big Bang: A Teoria S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTNAUYH3FVQjdljPhsKWryYYjWW.jpg'),
(69854, 4772, 'Big Bang: A Teoria S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vu8eDZ7MiefrZxX2OhFbda6noB2.jpg'),
(69855, 4772, 'Big Bang: A Teoria S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/206148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wv69h7bKeHblo3taVkPhHLnCxk4.jpg'),
(69856, 4772, 'Big Bang: A Teoria S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/206149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4iPNBT5dpaBzRrylQPx6j7dI3nT.jpg'),
(69857, 4772, 'Big Bang: A Teoria S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/206150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/XqD2Q7kM5lrTjDRwkKK7s3OzGz.jpg'),
(69858, 4772, 'Big Bang: A Teoria S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/206151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJJ7LLPDRHUQYVaeaxXSrdmWt34.jpg'),
(69859, 4772, 'Big Bang: A Teoria S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/206152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYnc1Ypn8Cdbme8hpe13RLEB0Ud.jpg'),
(69860, 4772, 'Big Bang: A Teoria S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/206153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dvyGCnhsCDaMTQl8fLW9hu343iB.jpg'),
(69861, 4772, 'Big Bang: A Teoria S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/206154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1iG6nwkQb75R8zxsypJL5xVqpxy.jpg'),
(69862, 4772, 'Big Bang: A Teoria S10 E24', 'http://sinalprivado.info:80/series/1533784/1533784/206155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zz9pvqUVLq9OWoei50kYXfVXccH.jpg'),
(69863, 4773, 'Big Bang: A Teoria S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oBOVgg2gIryBkWg2XtSr0svsO3a.jpg'),
(69864, 4773, 'Big Bang: A Teoria S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c82DYxLLoxwPKWQ0Evgmtphmleq.jpg'),
(69865, 4773, 'Big Bang: A Teoria S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mycjsvb91uw1WG6zqld9DEozlAB.jpg'),
(69866, 4773, 'Big Bang: A Teoria S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zNPtqkWh19br721s6IBwLOaoe22.jpg'),
(69867, 4773, 'Big Bang: A Teoria S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jHDHHiJbPIjJLPTpD31pAFgKhXc.jpg'),
(69868, 4773, 'Big Bang: A Teoria S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/57CoA3eyykJU9q0dkOcJ1WkZaKV.jpg'),
(69869, 4773, 'Big Bang: A Teoria S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lM1VwTSFT5IOLqfHBcImibCNDcR.jpg'),
(69870, 4773, 'Big Bang: A Teoria S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AlDl3puuYZqQHIsZDypJCAoXtFP.jpg'),
(69871, 4773, 'Big Bang: A Teoria S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sUeYryl4noJ1ZeoygZki5mVSEAF.jpg'),
(69872, 4773, 'Big Bang: A Teoria S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/661iWFo3pdIjCRN8iqHTF5UPmNe.jpg'),
(69873, 4773, 'Big Bang: A Teoria S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pax2p8RTOa1cyOy8RdYBLLvBQcU.jpg'),
(69874, 4773, 'Big Bang: A Teoria S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ak6A2V7tiXV5hU0UIRNupFUyThz.jpg'),
(69875, 4773, 'Big Bang: A Teoria S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/twXUFhbnn9xuoBwzwHZzyi6qAtk.jpg'),
(69876, 4773, 'Big Bang: A Teoria S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aKGQFSnqc5r9mWCUcRjWYi5SiWc.jpg'),
(69877, 4773, 'Big Bang: A Teoria S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AnGIz9QR5vd1BvfaLKIavRYVdAx.jpg'),
(69878, 4773, 'Big Bang: A Teoria S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y8cPPUKibxpbGlo9feqkWHae4Gk.jpg'),
(69879, 4773, 'Big Bang: A Teoria S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/206172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zDdcH0sQ3cRXbXolXrXpBcRBIv.jpg'),
(69880, 4773, 'Big Bang: A Teoria S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/206173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eXK5rWsLFCznTnclbcKlhtVYd6Z.jpg'),
(69881, 4773, 'Big Bang: A Teoria S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/206174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/noQkLOIcY439DTVA1mcqi07B2SW.jpg'),
(69882, 4773, 'Big Bang: A Teoria S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/206175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4onNHSndrG9u2DrkFI3Bw5ZEicl.jpg'),
(69883, 4773, 'Big Bang: A Teoria S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/206176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bRcRtDtinAA0q4OEGq68VF6GyQz.jpg'),
(69884, 4773, 'Big Bang: A Teoria S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/206177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bh6HEOeXk2hCrpt31wudk0wXGJu.jpg'),
(69885, 4773, 'Big Bang: A Teoria S11 E23', 'http://sinalprivado.info:80/series/1533784/1533784/206178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6wr77OIGHkAPK57HMpALaejKaS.jpg'),
(69886, 4773, 'Big Bang: A Teoria S11 E24', 'http://sinalprivado.info:80/series/1533784/1533784/206179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/890dUzmmaeMdHOoih4hhQrMQwFQ.jpg'),
(69887, 4774, 'Big Bang: A Teoria S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tH6udsYfheFElUCMtc10PoxzhHH.jpg'),
(69888, 4774, 'Big Bang: A Teoria S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6dkPSJozX9LPiNpv1nUfPSkCCZy.jpg'),
(69889, 4774, 'Big Bang: A Teoria S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l44ODD3iKdq06UT3MwVb5eAfgtl.jpg'),
(69890, 4774, 'Big Bang: A Teoria S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/llMnVr3aHN87ehC7NjFoXrZJC6u.jpg'),
(69891, 4774, 'Big Bang: A Teoria S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uXk8oplxCvrXnMDillhjPdjAz1c.jpg'),
(69892, 4774, 'Big Bang: A Teoria S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xo7XJKGKLBcymivyVeRawWDDHtP.jpg'),
(69893, 4774, 'Big Bang: A Teoria S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/14abiXaAjOnkYMke8WOPYfJb2Ud.jpg'),
(69894, 4774, 'Big Bang: A Teoria S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u2Fvvq2DwjnmgCLXM3XKpZHtJUQ.jpg'),
(69895, 4774, 'Big Bang: A Teoria S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7QzKWzJZ5nhRIHy8ffYRAHsSDb.jpg'),
(69896, 4774, 'Big Bang: A Teoria S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ifZjvUR7qrzRFeMidPv3WQIPX0n.jpg'),
(69897, 4774, 'Big Bang: A Teoria S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g9aR3enICwN7QF3RZ8KTgKVhvi3.jpg'),
(69898, 4774, 'Big Bang: A Teoria S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yk9ngrWh99IferzYCzkzgmV4Y8H.jpg'),
(69899, 4774, 'Big Bang: A Teoria S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ikoSMAv9hEQHnk3dEg3qerNxsso.jpg'),
(69900, 4774, 'Big Bang: A Teoria S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6A3l7dDqA9nA94pZNzJ8Fsv3Bp4.jpg'),
(69901, 4774, 'Big Bang: A Teoria S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ZKXKQvrlWTyjEe6VYjpsHaaOZa.jpg'),
(69902, 4774, 'Big Bang: A Teoria S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v9o9lIGgrKn3CVC3VqjXsOxiDBu.jpg'),
(69903, 4774, 'Big Bang: A Teoria S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/206196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ibeFZjHPpdLLCsM9Ul4QZGU5Bns.jpg'),
(69904, 4774, 'Big Bang: A Teoria S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/206197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNLmPBFzi9nGTtBsaQJNnbsDrwx.jpg'),
(69905, 4774, 'Big Bang: A Teoria S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/206198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hX1cQjB1uoCEBveWwx7ArPX2GKB.jpg'),
(69906, 4774, 'Big Bang: A Teoria S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/206199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6EwGVgvBRPX6huHhj80whNK3aXD.jpg'),
(69907, 4774, 'Big Bang: A Teoria S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/206200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Adw0tiCkOOBfQv0DGcxgopuWpYJ.jpg'),
(69908, 4774, 'Big Bang: A Teoria S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/206201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zxueWbIZiI8697miw4l7iBDB5DR.jpg'),
(69909, 4774, 'Big Bang: A Teoria S12 E23', 'http://sinalprivado.info:80/series/1533784/1533784/206202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x422znm59wC6RnRFH8nUxVfbsH2.jpg'),
(69910, 4774, 'Big Bang: A Teoria S12 E24', 'http://sinalprivado.info:80/series/1533784/1533784/206203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eaC2VG6Iy63vIor6mfOfCZTDw3g.jpg'),
(69911, 4775, 'Aquaman: King of Atlantis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gPBiSDvT0BznDi0l5vLHyBnWIQA.jpg'),
(69912, 4775, 'Aquaman: King of Atlantis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zul0J1N61ukHkgcjFCylfor5ENV.jpg'),
(69913, 4775, 'Aquaman: King of Atlantis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mWVGlB8VUuSSrT7BYylkPXbw3od.jpg'),
(69914, 4776, 'Chucky: A Série S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hBRb6VZBbGD4Faz1VK2HH9ihqX8.jpg'),
(69915, 4776, 'Chucky: A Série S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jx3G2ApN8YNIVQm4jg6fll754iU.jpg'),
(69916, 4776, 'Chucky: A Série S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242401.mp4', 'http://image.tmdb.org/t/p/w1280/eXCmi5JdIIN8kCFU4TqBreOMlZQ.jpg'),
(69917, 4776, 'Chucky: A Série S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242402.mp4', 'http://image.tmdb.org/t/p/w1280/mKoMTuXFFqAa8YIJIPMKjq9NwMo.jpg'),
(69918, 4776, 'Chucky: A Série S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242403.mp4', 'http://image.tmdb.org/t/p/w1280/zajMvMCFkimagQE0ZiA91EnTcAS.jpg'),
(69919, 4776, 'Chucky: A Série S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242404.mp4', 'http://image.tmdb.org/t/p/w1280/h10NuLB2Ce9gLt2bbqvDAHFFrkw.jpg'),
(69920, 4776, 'Chucky: A Série S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242405.mp4', 'http://image.tmdb.org/t/p/w1280/xv4iaHZem8rOs3KEOWuFlwQBm56.jpg'),
(69921, 4776, 'Chucky: A Série S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242406.mp4', 'http://image.tmdb.org/t/p/w1280/b1QKImjnIzXVwV3v3Ank41BdlmH.jpg'),
(69922, 4777, 'Chucky: A Série S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pu7KuseuX1OW2DT8NJrqdpRb8lQ.jpg'),
(69923, 4777, 'Chucky: A Série S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pl1oQqukZ7rCREANAZ2sjmIDP0D.jpg'),
(69924, 4777, 'Chucky: A Série S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wpUl7PTrOb7iYTdSur1MLoexJav.jpg'),
(69925, 4777, 'Chucky: A Série S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242410.mp4', 'http://image.tmdb.org/t/p/w1280/uUUDaLtr6hwaWTLuFI1YyNMMRHr.jpg'),
(69926, 4777, 'Chucky: A Série S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gEHgr4Ezq0FxV7qqXb9dCvu4n0e.jpg'),
(69927, 4777, 'Chucky: A Série S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ueUaJzguBxyw1KPq4QkL9gTGIXC.jpg'),
(69928, 4777, 'Chucky: A Série S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242413.mp4', 'http://image.tmdb.org/t/p/w1280/nsKFHIVZZrmLHdvgwBKWZYxrWpq.jpg'),
(69929, 4777, 'Chucky: A Série S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242414.mp4', 'http://image.tmdb.org/t/p/w1280/mRvwTN7ov8o2dRd0fVRACHgK9N4.jpg'),
(69930, 4778, 'Chucky: A Série S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iF8ai2QLNiHV4anwY1TuSGZXqfN.jpg'),
(69931, 4778, 'Chucky: A Série S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iF8ai2QLNiHV4anwY1TuSGZXqfN.jpg'),
(69932, 4778, 'Chucky: A Série S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iF8ai2QLNiHV4anwY1TuSGZXqfN.jpg'),
(69933, 4778, 'Chucky: A Série S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iF8ai2QLNiHV4anwY1TuSGZXqfN.jpg'),
(69934, 4778, 'Chucky: A Série S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iF8ai2QLNiHV4anwY1TuSGZXqfN.jpg'),
(69935, 4778, 'Chucky: A Série S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/333226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iF8ai2QLNiHV4anwY1TuSGZXqfN.jpg'),
(69936, 4778, 'Chucky: A Série S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/345703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iF8ai2QLNiHV4anwY1TuSGZXqfN.jpg'),
(69937, 4778, 'Chucky: A Série S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/349531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iF8ai2QLNiHV4anwY1TuSGZXqfN.jpg'),
(69938, 4779, 'Colin em Preto e Branco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sIlFFhwLB4FYk57J6lGTzqS9jJ5.jpg'),
(69939, 4779, 'Colin em Preto e Branco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hzR7g22zvo7Mma6qsU9XwBG5I9G.jpg'),
(69940, 4779, 'Colin em Preto e Branco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zvEuWFAg52OHvsDttulGCNPvntg.jpg'),
(69941, 4779, 'Colin em Preto e Branco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ecrNLLmtesWwbzZJPn82qmuCG5B.jpg'),
(69942, 4779, 'Colin em Preto e Branco S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xtvyaxRp2l6wkV87XFIiQyr8QjP.jpg'),
(69943, 4779, 'Colin em Preto e Branco S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQudw9X6Ko59DgSb42bFoYtoQzg.jpg'),
(69944, 4780, 'Dr. Death S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rBi9d8BJdt6UdDyJ0MgnIYBoxTY.jpg'),
(69945, 4780, 'Dr. Death S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y0H5UtWqUtHbXiASmWEWoPQrmCa.jpg'),
(69946, 4780, 'Dr. Death S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/woCQD7xrMzbwT9JXOjPrnb0Ru9n.jpg'),
(69947, 4780, 'Dr. Death S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nVomvwPJdaA7yCH9LEt117wn16r.jpg'),
(69948, 4780, 'Dr. Death S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/10Ubvso4y1SPwCeeJvM55rNDBuE.jpg'),
(69949, 4780, 'Dr. Death S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bzg4p7jvbJElXfxzoI575PNmy3J.jpg'),
(69950, 4780, 'Dr. Death S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/162251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8anFWPJbe8ZuYREhunAa2VfeJg.jpg'),
(69951, 4780, 'Dr. Death S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/162252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sBvrxXY4jvTznrixP57EbcLCXP3.jpg'),
(69952, 4781, 'Dr. Death S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/356665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4xPIBtOWHzigSNTqbxftzAZS5uT.jpg'),
(69953, 4781, 'Dr. Death S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/356666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4xPIBtOWHzigSNTqbxftzAZS5uT.jpg'),
(69954, 4781, 'Dr. Death S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/359677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4xPIBtOWHzigSNTqbxftzAZS5uT.jpg'),
(69955, 4781, 'Dr. Death S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/369029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4xPIBtOWHzigSNTqbxftzAZS5uT.jpg'),
(69956, 4781, 'Dr. Death S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/384322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4xPIBtOWHzigSNTqbxftzAZS5uT.jpg'),
(69957, 4781, 'Dr. Death S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/384323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4xPIBtOWHzigSNTqbxftzAZS5uT.jpg'),
(69958, 4781, 'Dr. Death S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/384324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4xPIBtOWHzigSNTqbxftzAZS5uT.jpg'),
(69959, 4781, 'Dr. Death S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/397098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4xPIBtOWHzigSNTqbxftzAZS5uT.jpg'),
(69960, 4782, 'Fairfax S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1L820cNMiENctzkcclnQQgzZAT.jpg'),
(69961, 4782, 'Fairfax S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2O41gskD7yKgiUOS2TkTAnHeI24.jpg'),
(69962, 4782, 'Fairfax S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vmAsN94rAkFpfSxJkDFgm3QD2Mt.jpg'),
(69963, 4782, 'Fairfax S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lrM5ByUMHbFtP6iJfncByaxrPvX.jpg'),
(69964, 4782, 'Fairfax S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbsYVgj5bpZHsvt821kgbAfCGM9.jpg'),
(69965, 4782, 'Fairfax S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e93hbtIbNcG4hdtWAODNnPZdhS.jpg'),
(69966, 4782, 'Fairfax S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wRUAOVUZcAi60C0Rsa6okyvwCjd.jpg'),
(69967, 4782, 'Fairfax S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i7GlKWtq7yXlh5sD6DtZCWjmJc9.jpg'),
(69968, 4783, 'Fairfax S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179578.mp4', 'http://timg.bdta.pro/images/4c894ecfb118a763620ee7ea262381c7.jpg'),
(69969, 4783, 'Fairfax S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179579.mp4', 'http://timg.bdta.pro/images/2a8e6d198b31df0b3901beca21714b25.jpg'),
(69970, 4783, 'Fairfax S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179580.mp4', 'http://timg.bdta.pro/images/d25d8c85c7679b9a2f22d879e6869230.jpg'),
(69971, 4783, 'Fairfax S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179581.mp4', 'http://timg.bdta.pro/images/743bd68736493c4edce73a795924f244.jpg'),
(69972, 4783, 'Fairfax S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179582.mp4', 'http://timg.bdta.pro/images/a53e6751342033235da93facd9f3acd2.jpg'),
(69973, 4783, 'Fairfax S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179583.mp4', 'http://timg.bdta.pro/images/833f3ee5997a9f5b133d77b348213e40.jpg'),
(69974, 4783, 'Fairfax S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179584.mp4', 'http://timg.bdta.pro/images/4d589a226bac7a6a8bcf7137a9a8d261.jpg'),
(69975, 4783, 'Fairfax S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179585.mp4', 'http://timg.bdta.pro/images/17e7da0779dcc5faf308223e488c1a2e.jpg'),
(69976, 4349, 'Hora de Aventura: Terras Distantes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iONBFiLE3wxAo6GL0Y7j8zbFjmQ.jpg'),
(69977, 4349, 'Hora de Aventura: Terras Distantes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHDZ48QJGFVh7zZKh46VEhu9qlJ.jpg'),
(69978, 4349, 'Hora de Aventura: Terras Distantes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7OVsyA5Bpvth7fa7xaUCbVzx4Xu.jpg'),
(69979, 4349, 'Hora de Aventura: Terras Distantes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4wjfKOI3cn5EcFKlU5nZ73bs6xC.jpg'),
(69980, 4784, 'Maradona: Conquista de um Sonho S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lXkxT6fR75SBKVwbRUKTtAglSmw.jpg'),
(69981, 4784, 'Maradona: Conquista de um Sonho S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zCKoFzWMBCeei9ByBbcyhBLj3R5.jpg'),
(69982, 4784, 'Maradona: Conquista de um Sonho S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8xwxupFObtDCYND8t2zNSWADyqQ.jpg'),
(69983, 4784, 'Maradona: Conquista de um Sonho S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oT0AvUy4Sb9D6ni02dDbwRgJ8aO.jpg'),
(69984, 4784, 'Maradona: Conquista de um Sonho S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kDgDxvt4p3GUdwIBGW9Bx2ndyCF.jpg'),
(69985, 4784, 'Maradona: Conquista de um Sonho S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6D1Nd4oLFzgFR0t4HXNh0xEGtv0.jpg'),
(69986, 4784, 'Maradona: Conquista de um Sonho S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e8oVWrBWhAEdMt1ymST1G90UO7J.jpg'),
(69987, 4784, 'Maradona: Conquista de um Sonho S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gqyWVRDJddbFHRah4IpoydTi3we.jpg'),
(69988, 4784, 'Maradona: Conquista de um Sonho S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164324.mp4', 'http://image.tmdb.org/t/p/w1280/r6BcC4QaElhzNkAqiFC6cKNbWIv.jpg'),
(69989, 4784, 'Maradona: Conquista de um Sonho S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164325.mp4', 'http://image.tmdb.org/t/p/w1280/hdBpyPrTGHagCj5PEPkRKu1Vd9S.jpg'),
(69990, 4785, 'Marvel\'s M.O.D.O.K. S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q3mZDFtSh7Slb0486FuwkEZQHRB.jpg'),
(69991, 4785, 'Marvel\'s M.O.D.O.K. S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAzZXEY6uqSHeZ7ugxz9FqCfAkg.jpg'),
(69992, 4785, 'Marvel\'s M.O.D.O.K. S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wVVduYQCD2hmwiAYhMgcOI9A91u.jpg'),
(69993, 4785, 'Marvel\'s M.O.D.O.K. S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9b6nizaj6uCYCRNtVeJ1SUT4do1.jpg'),
(69994, 4785, 'Marvel\'s M.O.D.O.K. S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rH2yyoRCnfxtslUTFVLekTdN4r9.jpg'),
(69995, 4785, 'Marvel\'s M.O.D.O.K. S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3etIjrMDx8WaStneURCwYlPv6P8.jpg'),
(69996, 4785, 'Marvel\'s M.O.D.O.K. S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/162237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eVwsD0TbJ1fzpCgNZweIJhO9L36.jpg'),
(69997, 4785, 'Marvel\'s M.O.D.O.K. S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/162238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4fsxiicymbbeKYFJOb3tQtCjg0Z.jpg'),
(69998, 4785, 'Marvel\'s M.O.D.O.K. S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/162239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5sgCzbxKUHZZ6HyAS7a76q1i9vf.jpg'),
(69999, 4785, 'Marvel\'s M.O.D.O.K. S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/162240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hDt1Z56j2YR2gjbAq51hkowYP1J.jpg'),
(70000, 4786, 'Na Cola dos Assassinos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jI8G702UgrY2O7r4pFXA1TetPeR.jpg'),
(70001, 4786, 'Na Cola dos Assassinos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jI8G702UgrY2O7r4pFXA1TetPeR.jpg'),
(70002, 4786, 'Na Cola dos Assassinos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jI8G702UgrY2O7r4pFXA1TetPeR.jpg'),
(70003, 4786, 'Na Cola dos Assassinos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jI8G702UgrY2O7r4pFXA1TetPeR.jpg'),
(70004, 4787, 'Na Cola dos Assassinos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jI8G702UgrY2O7r4pFXA1TetPeR.jpg'),
(70005, 4787, 'Na Cola dos Assassinos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jI8G702UgrY2O7r4pFXA1TetPeR.jpg'),
(70006, 4787, 'Na Cola dos Assassinos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jI8G702UgrY2O7r4pFXA1TetPeR.jpg'),
(70007, 4787, 'Na Cola dos Assassinos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jI8G702UgrY2O7r4pFXA1TetPeR.jpg'),
(70008, 4788, 'O Mundo de Karma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fO0HxGRP8vEMr4PpzgDIUmAgL4L.jpg'),
(70009, 4788, 'O Mundo de Karma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tNxhST0JIG5r9GgOmFEr17OvFDz.jpg'),
(70010, 4788, 'O Mundo de Karma S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vwazRD0fYeoETUYeA8CIS34NlRk.jpg'),
(70011, 4788, 'O Mundo de Karma S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9q2UH3z1H82dJLZZsZtPKelXK5p.jpg'),
(70012, 4788, 'O Mundo de Karma S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/12kJHtlA6uBA7tuF1w9CUwXGuel.jpg'),
(70013, 4788, 'O Mundo de Karma S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gjhQj0SLJQNz1FZvHIxC0VOuolj.jpg'),
(70014, 4788, 'O Mundo de Karma S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/162222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iRKqHxLjYlWENukpQph2BkEn5AO.jpg'),
(70015, 4788, 'O Mundo de Karma S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/162223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1QOrtYwdSNezPMSxEVd0vGnWqTr.jpg'),
(70016, 4788, 'O Mundo de Karma S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/162224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l8Fgx2X5NNJKzop8sM2lwBowa9c.jpg'),
(70017, 4788, 'O Mundo de Karma S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/162225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/exGkm0nP1JB2y0EiRX79yDVn4Sq.jpg'),
(70018, 4788, 'O Mundo de Karma S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/162226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cZPflAFiV0h2JBOee0qWdAKB6qz.jpg'),
(70019, 4788, 'O Mundo de Karma S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/162227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v34iZVk2q6mNfcna5SaEYSGx6EH.jpg'),
(70020, 4788, 'O Mundo de Karma S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/162228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fNjbJkGlECrM0RjYXsrrG7hCdxz.jpg'),
(70021, 4788, 'O Mundo de Karma S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/162229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k7G1Vh16d2Ol4FUVmd1bbjRSzra.jpg'),
(70022, 4788, 'O Mundo de Karma S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/162230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ffrzvwMqefHzEGXApUDM4pugeTv.jpg'),
(70023, 4789, 'O Tempo Que Te Dou S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1PZ8bZ5KIRsa113gkZTREM5zmMI.jpg'),
(70024, 4789, 'O Tempo Que Te Dou S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iiWwv5nFUwuj9jrMgeIRYeFF7DP.jpg'),
(70025, 4789, 'O Tempo Que Te Dou S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ezypwigZZFkONbQnbDOM9KWoJRj.jpg'),
(70026, 4789, 'O Tempo Que Te Dou S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iPskQ6ZOEF4RpwqYJsR8DKPLvzO.jpg'),
(70027, 4789, 'O Tempo Que Te Dou S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5VItovb8qWRriFLIYUwnF7XvP9q.jpg'),
(70028, 4789, 'O Tempo Que Te Dou S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dM8LP45NfJUQnemG8wseaP0wabL.jpg'),
(70029, 4789, 'O Tempo Que Te Dou S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/162212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vjh1hZayjC2OxwdT1vkO2rJdu7a.jpg'),
(70030, 4789, 'O Tempo Que Te Dou S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/162213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lMYg11JXXDsmx2Dn4uhhwmFlDU6.jpg'),
(70031, 4789, 'O Tempo Que Te Dou S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/162214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBOLT8Nu5agBmMTA21DqOWQR3a9.jpg'),
(70032, 4789, 'O Tempo Que Te Dou S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/162215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aiuNe9aWZHIa07KfgzP6dJkSfPN.jpg'),
(70033, 4790, 'Os Smurfs S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v6ArH4IgtvUrJPduV35DZ6ZE2d0.jpg'),
(70034, 4790, 'Os Smurfs S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gVgSafFkHfaLGpoR1Tp6gdDxn7q.jpg'),
(70035, 4790, 'Os Smurfs S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yOIcoWYxK7My5cQ0sKwm5u3U7p5.jpg'),
(70036, 4790, 'Os Smurfs S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bxOxWZkqqREMLNo9MEDF0ulHEsk.jpg'),
(70037, 4790, 'Os Smurfs S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d8emKL230qIle9iNc8S6huBHYE0.jpg'),
(70038, 4790, 'Os Smurfs S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/llQMRG3nuF6Mh4K5TAiTWrBbtzP.jpg'),
(70039, 4790, 'Os Smurfs S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/amDAefpvxHAFyGiy4WnKDo2twXI.jpg'),
(70040, 4790, 'Os Smurfs S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4SfbQgUScQRoKV0Q6Z3SBZXbMYz.jpg'),
(70041, 4790, 'Os Smurfs S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uiOT3X9p9eB1V5QQeSP0yAIP5gV.jpg'),
(70042, 4790, 'Os Smurfs S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uiOT3X9p9eB1V5QQeSP0yAIP5gV.jpg'),
(70043, 4791, 'Os Smurfs S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uiOT3X9p9eB1V5QQeSP0yAIP5gV.jpg'),
(70044, 4791, 'Os Smurfs S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uiOT3X9p9eB1V5QQeSP0yAIP5gV.jpg'),
(70045, 4791, 'Os Smurfs S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uiOT3X9p9eB1V5QQeSP0yAIP5gV.jpg'),
(70046, 4791, 'Os Smurfs S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uiOT3X9p9eB1V5QQeSP0yAIP5gV.jpg'),
(70047, 4791, 'Os Smurfs S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uiOT3X9p9eB1V5QQeSP0yAIP5gV.jpg'),
(70048, 4792, 'Por Que Matei Minha Familia? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUl3WDHBjAQn0Wsf4zUeE7XHSRt.jpg'),
(70049, 4792, 'Por Que Matei Minha Familia? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUl3WDHBjAQn0Wsf4zUeE7XHSRt.jpg'),
(70050, 4792, 'Por Que Matei Minha Familia? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUl3WDHBjAQn0Wsf4zUeE7XHSRt.jpg'),
(70051, 4792, 'Por Que Matei Minha Familia? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUl3WDHBjAQn0Wsf4zUeE7XHSRt.jpg'),
(70052, 4793, 'Quilos Mortais S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70053, 4793, 'Quilos Mortais S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70054, 4793, 'Quilos Mortais S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70055, 4793, 'Quilos Mortais S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70056, 4793, 'Quilos Mortais S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70057, 4793, 'Quilos Mortais S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70058, 4793, 'Quilos Mortais S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70059, 4793, 'Quilos Mortais S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70060, 4794, 'Quilos Mortais S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mRhejz3HgmqW4s7kLdYQe7pe4n.jpg'),
(70061, 4794, 'Quilos Mortais S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtqNTpzM7iVBwNEynivHFUcI84I.jpg'),
(70062, 4794, 'Quilos Mortais S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1rycmH7LYsAMYGppkBpG1XgwZMk.jpg'),
(70063, 4794, 'Quilos Mortais S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gPKkkPujVggNlUO2R0zByDH4tfm.jpg'),
(70064, 4794, 'Quilos Mortais S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dQzkOyniyBYtxcOH2HcqCGPHgL2.jpg'),
(70065, 4794, 'Quilos Mortais S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fKFM9wJffkffxme0vgchbBBgjRk.jpg'),
(70066, 4794, 'Quilos Mortais S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7WPYnHeS2X7nUbUcqsBP28oQqLL.jpg'),
(70067, 4794, 'Quilos Mortais S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a1ZUO5oWG4ma1ICZb81JEtkTaWP.jpg'),
(70068, 4794, 'Quilos Mortais S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJUCDCS6Vux8Hx9cSb8oDAyooEb.jpg'),
(70069, 4794, 'Quilos Mortais S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1zDb0IuokmtXVkftewiHEyA9HXS.jpg'),
(70070, 4795, 'Quilos Mortais S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70071, 4795, 'Quilos Mortais S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aSGwXwuAPK7sr1scR5orYD1sKv0.jpg'),
(70072, 4795, 'Quilos Mortais S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/av7L6EDn0pmzuyxYTnBPcmvkwrp.jpg'),
(70073, 4795, 'Quilos Mortais S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nCDwThy8HaD39TBNPg4X4rpgNr.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(70074, 4795, 'Quilos Mortais S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/252DqBeXy2ERbBsYGbf1r8tOkoS.jpg'),
(70075, 4795, 'Quilos Mortais S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hL300vsYeqUZxHesLawoF3NbwsV.jpg'),
(70076, 4795, 'Quilos Mortais S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lqmHgYSyVjTy88JL5iFXkGrOYzV.jpg'),
(70077, 4795, 'Quilos Mortais S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pwDoJDo3CQOpFhGq89WqiTHhmpN.jpg'),
(70078, 4795, 'Quilos Mortais S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uAvZm06sPPf6H74xzO2cwIdJKzB.jpg'),
(70079, 4795, 'Quilos Mortais S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lewFnpWHQyyjY6U2QgDvVh1kASW.jpg'),
(70080, 4795, 'Quilos Mortais S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1iqKMVEX0YJHYktJ7BDCwO60eJR.jpg'),
(70081, 4795, 'Quilos Mortais S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t10O1o97sLEdybxs90Oi3GykMrm.jpg'),
(70082, 4795, 'Quilos Mortais S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rhicUf3R3hSAQnqMh0Hvc39iKDz.jpg'),
(70083, 4796, 'Quilos Mortais S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y6mxhanoz4mCI1XrrsUnO6xDXRX.jpg'),
(70084, 4796, 'Quilos Mortais S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sCcfBzbCwvPVKD2lXDRdI9JoyoL.jpg'),
(70085, 4796, 'Quilos Mortais S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g4dunoroyVoNnptJLFgwnP7BwR3.jpg'),
(70086, 4796, 'Quilos Mortais S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o7uGA364dRgOwTeXmP6QsPUdcwZ.jpg'),
(70087, 4796, 'Quilos Mortais S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7LdUzjzEzjVXmCdJpiXB3Injs8f.jpg'),
(70088, 4796, 'Quilos Mortais S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Apr73Co7Uy8biq1522O2mRPHBQc.jpg'),
(70089, 4796, 'Quilos Mortais S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AhZKpFzwZRaRn0uqLsubWIhG4EL.jpg'),
(70090, 4796, 'Quilos Mortais S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHlF3piDQHRn3ZfynKNgdUzziqG.jpg'),
(70091, 4796, 'Quilos Mortais S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hEMw95FOoYO5Fq3aCNbeSO9Ehgb.jpg'),
(70092, 4796, 'Quilos Mortais S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8SMqZAn2poxktLKFvdT9gAFkEfQ.jpg'),
(70093, 4796, 'Quilos Mortais S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yYFJAB8Mj2Ujt1dCiHIr71gQs3b.jpg'),
(70094, 4796, 'Quilos Mortais S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kh8r1k0FqxqC4gszvrnVvAXA5dK.jpg'),
(70095, 4796, 'Quilos Mortais S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7CXyf3jMzWm87HEaSDHkY1J6CQv.jpg'),
(70096, 4796, 'Quilos Mortais S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/luos9iWJBD6XnpTrhs3bvjEY0OB.jpg'),
(70097, 4797, 'Quilos Mortais S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70098, 4797, 'Quilos Mortais S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70099, 4797, 'Quilos Mortais S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70100, 4797, 'Quilos Mortais S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70101, 4797, 'Quilos Mortais S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70102, 4797, 'Quilos Mortais S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70103, 4797, 'Quilos Mortais S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70104, 4797, 'Quilos Mortais S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70105, 4797, 'Quilos Mortais S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70106, 4797, 'Quilos Mortais S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70107, 4797, 'Quilos Mortais S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70108, 4797, 'Quilos Mortais S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70109, 4797, 'Quilos Mortais S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70110, 4797, 'Quilos Mortais S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70111, 4798, 'Quilos Mortais S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70112, 4798, 'Quilos Mortais S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70113, 4798, 'Quilos Mortais S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70114, 4798, 'Quilos Mortais S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70115, 4798, 'Quilos Mortais S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70116, 4798, 'Quilos Mortais S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70117, 4798, 'Quilos Mortais S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70118, 4798, 'Quilos Mortais S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70119, 4798, 'Quilos Mortais S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70120, 4798, 'Quilos Mortais S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70121, 4798, 'Quilos Mortais S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70122, 4798, 'Quilos Mortais S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70123, 4798, 'Quilos Mortais S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70124, 4798, 'Quilos Mortais S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70125, 4798, 'Quilos Mortais S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70126, 4798, 'Quilos Mortais S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/226664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70127, 4798, 'Quilos Mortais S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/226665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70128, 4798, 'Quilos Mortais S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/226666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70129, 4798, 'Quilos Mortais S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/226667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70130, 4798, 'Quilos Mortais S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/226668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70131, 4799, 'Quilos Mortais S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70132, 4799, 'Quilos Mortais S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70133, 4799, 'Quilos Mortais S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70134, 4799, 'Quilos Mortais S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70135, 4799, 'Quilos Mortais S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70136, 4799, 'Quilos Mortais S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70137, 4799, 'Quilos Mortais S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70138, 4799, 'Quilos Mortais S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70139, 4799, 'Quilos Mortais S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70140, 4799, 'Quilos Mortais S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70141, 4799, 'Quilos Mortais S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70142, 4799, 'Quilos Mortais S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70143, 4799, 'Quilos Mortais S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70144, 4800, 'Quilos Mortais S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70145, 4800, 'Quilos Mortais S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70146, 4800, 'Quilos Mortais S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70147, 4800, 'Quilos Mortais S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70148, 4800, 'Quilos Mortais S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70149, 4800, 'Quilos Mortais S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70150, 4800, 'Quilos Mortais S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70151, 4800, 'Quilos Mortais S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70152, 4800, 'Quilos Mortais S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70153, 4800, 'Quilos Mortais S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70154, 4800, 'Quilos Mortais S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70155, 4800, 'Quilos Mortais S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70156, 4800, 'Quilos Mortais S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70157, 4801, 'Quilos Mortais S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70158, 4801, 'Quilos Mortais S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70159, 4801, 'Quilos Mortais S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70160, 4801, 'Quilos Mortais S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70161, 4801, 'Quilos Mortais S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70162, 4801, 'Quilos Mortais S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70163, 4801, 'Quilos Mortais S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70164, 4801, 'Quilos Mortais S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70165, 4801, 'Quilos Mortais S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70166, 4801, 'Quilos Mortais S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70167, 4801, 'Quilos Mortais S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70168, 4801, 'Quilos Mortais S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70169, 4801, 'Quilos Mortais S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70170, 4801, 'Quilos Mortais S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70171, 4801, 'Quilos Mortais S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70172, 4802, 'Quilos Mortais S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70173, 4802, 'Quilos Mortais S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70174, 4802, 'Quilos Mortais S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70175, 4802, 'Quilos Mortais S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70176, 4802, 'Quilos Mortais S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70177, 4802, 'Quilos Mortais S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70178, 4802, 'Quilos Mortais S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70179, 4802, 'Quilos Mortais S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70180, 4803, 'Quilos Mortais S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/420889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70181, 4803, 'Quilos Mortais S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/420890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70182, 4803, 'Quilos Mortais S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/420891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70183, 4803, 'Quilos Mortais S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/420892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70184, 4803, 'Quilos Mortais S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/420893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70185, 4803, 'Quilos Mortais S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/426702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70186, 4803, 'Quilos Mortais S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/428998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70187, 4804, 'Quilos Mortais S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/863969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70188, 4804, 'Quilos Mortais S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/863970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70189, 4804, 'Quilos Mortais S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/869808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70190, 4804, 'Quilos Mortais S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/873604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70191, 4804, 'Quilos Mortais S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/878857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70192, 4804, 'Quilos Mortais S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/879972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70193, 4804, 'Quilos Mortais S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/880363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmS6nrKAscKwt91OM6KcOal8DO6.jpg'),
(70194, 4805, 'Smother S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/QIIYey7pzkIkfT3vvaeOXHKFAs.jpg'),
(70195, 4805, 'Smother S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vrm35fqfSMj5ro83ZxV0PiXOLYb.jpg'),
(70196, 4805, 'Smother S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2IG8bpD5oQMU2fGZXbVzOrw8Zam.jpg'),
(70197, 4805, 'Smother S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cqkqAwFYkS8YJzHjNLT9mPV0BFW.jpg'),
(70198, 4805, 'Smother S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/liE0KylYp5uzqONbDT07bVUUNUa.jpg'),
(70199, 4805, 'Smother S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/liE0KylYp5uzqONbDT07bVUUNUa.jpg'),
(70200, 4806, 'The Bite S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n4BNav8lJGbwF45kwi1D9OTUTWI.jpg'),
(70201, 4806, 'The Bite S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/29aD1ZZlkV38gRvax53qECJdHrY.jpg'),
(70202, 4806, 'The Bite S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZ7VMxxmxR92aLKVHINmi9GkDZG.jpg'),
(70203, 4806, 'The Bite S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ecZyY4SPI97ADf60S4NF44aYO7h.jpg'),
(70204, 4806, 'The Bite S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rmuGCm9rv8lxlU28AhttGSTwjXD.jpg'),
(70205, 4806, 'The Bite S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f5mW5J8Epp7iUu2NcEy99ivaxKu.jpg'),
(70206, 4807, 'Y: O Último Homem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t252DB7o1lRcRqdFawIQgTFKyF1.jpg'),
(70207, 4807, 'Y: O Último Homem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zgN4zSQv1rjsTsKwo6zx8CZVWqO.jpg'),
(70208, 4807, 'Y: O Último Homem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i4EGXDIirRR1XvBsjgsgXHYOnrL.jpg'),
(70209, 4807, 'Y: O Último Homem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLq19mniRo6rTbUZbMhF7ptbj47.jpg'),
(70210, 4807, 'Y: O Último Homem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mfZ0dQ7yPbiWTkXCVwuogGEwZQX.jpg'),
(70211, 4807, 'Y: O Último Homem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OwzSkv8WjW4NMAw1uI7Vtmh1S9.jpg'),
(70212, 4807, 'Y: O Último Homem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/162186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tnVKs702Plx93tufnskxuaJjSOV.jpg'),
(70213, 4807, 'Y: O Último Homem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/162187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkwmv5xFShB5GZuOEeYQOef2L9G.jpg'),
(70214, 4807, 'Y: O Último Homem S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/162188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/spEEdkIzFu6eBFl475lXkRf3hTl.jpg'),
(70215, 4807, 'Y: O Último Homem S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/162189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ckVdbQSyIPPDu2uqdkObOJTAfT4.jpg'),
(70216, 4808, 'Zorro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h0w7gT4isqOb9vGkWN1Q8rXabi6.jpg'),
(70217, 4808, 'Zorro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fI2ukYDaRjJMvVF8xbmw6ARP3Xt.jpg'),
(70218, 4808, 'Zorro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZNl9XEkccGsyUetNdavhRa8Vtr.jpg'),
(70219, 4808, 'Zorro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5KtgI1vPKJ0YX34tZ1rhV6WuudW.jpg'),
(70220, 4808, 'Zorro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mRZQNmEkaE9whxmvZg4H9HNaqZr.jpg'),
(70221, 4808, 'Zorro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6LMAGr6wO9s2111hG4k0INJwnJs.jpg'),
(70222, 4808, 'Zorro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/162108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzAOjccIeuQSwCFD6NoUAxnA9cJ.jpg'),
(70223, 4808, 'Zorro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/162109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e66Yf87NaTOapOc1M0s1tZQkJgl.jpg'),
(70224, 4808, 'Zorro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/162110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Fs3wPw0YSiyQcLlVloYTnmEDTt.jpg'),
(70225, 4808, 'Zorro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/162111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/damVVpXoh3p7jZBHjEjad0fq5wp.jpg'),
(70226, 4808, 'Zorro S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/162112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/98HSl5BqZQUCIQgonjC2iTchJXn.jpg'),
(70227, 4808, 'Zorro S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/162113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jSUg0VXsS2xxouD4zwzlfIFfruz.jpg'),
(70228, 4808, 'Zorro S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/162114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/37zwPoZh6b9pDsIhkR4VKfVqQZl.jpg'),
(70229, 4808, 'Zorro S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/162115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tvjdSiVNMJfOcV28hDIjHQtKK43.jpg'),
(70230, 4808, 'Zorro S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/162116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1dyXtShFWAJMIFJXKKvJOteoXxl.jpg'),
(70231, 4808, 'Zorro S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/162117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2rQjIyVyRloiN52oc0iNhhTawy.jpg'),
(70232, 4808, 'Zorro S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/162118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dX57NOiGE4gcd561PEePipE7VwX.jpg'),
(70233, 4808, 'Zorro S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/162119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8QCAqIpOcc2VGO1F8sL2GTgERKC.jpg'),
(70234, 4808, 'Zorro S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/162120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24i7mDVK43bRyLLS7beA7t5bSuC.jpg'),
(70235, 4808, 'Zorro S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/162121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/egeOa6L1ASQQE7fAx7Mwsb7jHza.jpg'),
(70236, 4808, 'Zorro S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/162122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/acMcdEQ9aLxrFtuqL0RmKO3rwN2.jpg'),
(70237, 4808, 'Zorro S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/162123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pU9GBVOeMcX74Hs7171jbSykV3m.jpg'),
(70238, 4808, 'Zorro S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/162124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zVSW8e6Z0xobTdujksSRgdcq9Hi.jpg'),
(70239, 4808, 'Zorro S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/162125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/opFYzdJ2ijiMmpT9UkqccFVIstd.jpg'),
(70240, 4808, 'Zorro S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/162126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yBPvnCKys302dCsgLJJWoR5n9oM.jpg'),
(70241, 4808, 'Zorro S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/162127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvKQ42CJUQFcY6bUquO55D0Jo3F.jpg'),
(70242, 4808, 'Zorro S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/162128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fw1LZashCg5Fyo00zAAdO17oez9.jpg'),
(70243, 4808, 'Zorro S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/162129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/75WQZAHb8kMDN8GjsQuNnaWhtxJ.jpg'),
(70244, 4808, 'Zorro S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/162130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sIbRItcN87rVrWj0F6c9thrliMh.jpg'),
(70245, 4808, 'Zorro S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/162131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCsUPDOTRHLMFKx4LJweJ7QDqHG.jpg'),
(70246, 4808, 'Zorro S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/162132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6CA8pIKNKkX74oFR2wnL3FAqpec.jpg'),
(70247, 4808, 'Zorro S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/162133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6oo73CB6LU61u32ONB7dGY2mfcM.jpg'),
(70248, 4808, 'Zorro S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/162134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2yKylDzbJv3yn4SyKSTV4yynUMB.jpg'),
(70249, 4808, 'Zorro S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/162135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zRMvAzrcIhlTwGhjzSLI8LDjzr5.jpg'),
(70250, 4808, 'Zorro S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/162136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kNaDid7Se64tKTVdytwNM1e39Ed.jpg'),
(70251, 4808, 'Zorro S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/162137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uitOVdbCGjbMC5BSv7VRlE0eb2b.jpg'),
(70252, 4808, 'Zorro S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/162138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aXnIept8UgKXYS5viuKkUlKjHoc.jpg'),
(70253, 4808, 'Zorro S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/162139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9MTlqThPZtBAHo8NXDwUorlLwcF.jpg'),
(70254, 4808, 'Zorro S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/162140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wxswmdJZAH1uPl94iyQHnc2qjah.jpg'),
(70255, 4809, 'Zorro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4PgXhCwC5VjwGFcN7CzjoUTmigI.jpg'),
(70256, 4809, 'Zorro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/utPi8hcLZXIjR2574L9MuTwg1sF.jpg'),
(70257, 4809, 'Zorro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2OcimISV7K9B6zX1WH7u16Ir9li.jpg'),
(70258, 4809, 'Zorro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/95VBjFtRIr045SexSxUw0oZN55s.jpg'),
(70259, 4809, 'Zorro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDIzLYSJs1nsn9iWp8SLq79uofO.jpg'),
(70260, 4809, 'Zorro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3LOlgTewYum6CVk68WsZjbIbP7h.jpg'),
(70261, 4809, 'Zorro S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/162147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/imxi5tSjmpPsjm58CXfiiTP4Wre.jpg'),
(70262, 4809, 'Zorro S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/162148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gKrX8iqBmzDnmvuDDxmluVxDX1D.jpg'),
(70263, 4809, 'Zorro S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/162149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nCb8vzALW5huSObeUgiiW2bngYV.jpg'),
(70264, 4809, 'Zorro S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/162150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jsTw9YmAzF3Etnymj1XM84FKOng.jpg'),
(70265, 4809, 'Zorro S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/162151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6qOItpGX84HX6cG6HU7HK9pqNZy.jpg'),
(70266, 4809, 'Zorro S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/162152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/69YZ4RB3INvkVTld2Yfn7HlTVUN.jpg'),
(70267, 4809, 'Zorro S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/162153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vDaZfKOR0z2281EvS4U8w4jTjWo.jpg'),
(70268, 4809, 'Zorro S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/162154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ivW5nYyrIHIVxJX5yzhDzC68EtQ.jpg'),
(70269, 4809, 'Zorro S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/162155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aCNh833te1P4O4AspTKIcHkUIIa.jpg'),
(70270, 4809, 'Zorro S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/162156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ly4MWq4k4kJB0hmFh4gkiPYnkks.jpg'),
(70271, 4809, 'Zorro S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/162157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mY60obP1zIZDxmfvz6oIFFkF0cr.jpg'),
(70272, 4809, 'Zorro S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/162158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rExPBjnqboPMsX1HXUoS7iDNfdD.jpg'),
(70273, 4809, 'Zorro S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/162159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/voJbdR5wlQ5zAoHBLsF5A6tYE87.jpg'),
(70274, 4809, 'Zorro S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/162160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOMiBYoNwyVQJPumRlayyWwuYYW.jpg'),
(70275, 4809, 'Zorro S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/162161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/62ikiN2XWXXlH35aNUc7KO7GQPf.jpg'),
(70276, 4809, 'Zorro S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/162162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kuRvEAwkMUctQaJnWqXrx3kEihK.jpg'),
(70277, 4809, 'Zorro S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/162163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ckcVWM06BSPsWQRwqaxs8zjUp57.jpg'),
(70278, 4809, 'Zorro S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/162164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cxWUO3EaYEXLA0CWeecYilsljIf.jpg'),
(70279, 4809, 'Zorro S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/162165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2xbwePsOfzGb5Xvm16tJP6VaZ1c.jpg'),
(70280, 4809, 'Zorro S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/162166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2xbwePsOfzGb5Xvm16tJP6VaZ1c.jpg'),
(70281, 4809, 'Zorro S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/162167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4kOrfLTUw1PnnD0TWO9sBLVjiHJ.jpg'),
(70282, 4809, 'Zorro S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/162168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3mLSUf2uxUKTpWAXZlaKTOG0ohn.jpg'),
(70283, 4809, 'Zorro S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/162169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7RnkVe4UWhr3vPKsnHwqTwz7P9q.jpg'),
(70284, 4809, 'Zorro S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/162170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bp8EmZ3QaEiGBGRMqi2gmfOiGtN.jpg'),
(70285, 4809, 'Zorro S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/162171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xgLRc3V1hCSw7sWtTYNGeL5sc9B.jpg'),
(70286, 4809, 'Zorro S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/162172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kW9BDkVy2FbQDTOlWPR7gbUp9fA.jpg'),
(70287, 4809, 'Zorro S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/162173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v2mjPUuAMsXTwOlZwNTLWiOj2Uc.jpg'),
(70288, 4809, 'Zorro S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/162174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sTe3vhC0e1U47yv3QvoODQjYFpb.jpg'),
(70289, 4809, 'Zorro S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/162175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mjSeuhJVqLuARzPAKdtxzBZQPBx.jpg'),
(70290, 4809, 'Zorro S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/162176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o8CPMNXQRvWKyW2PK5WLpZYtEIt.jpg'),
(70291, 4809, 'Zorro S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/162177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jReC0qQWAhzuXCKH53BZIwh1QgX.jpg'),
(70292, 4809, 'Zorro S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/162178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDuSsAidj4LD1fVJTTTf87dzcLf.jpg'),
(70293, 4809, 'Zorro S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/162179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qjBsw5O6U7KRfxWLNk7nlpkZ8B1.jpg'),
(70294, 4810, 'Clube do Terror S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mi7pJEBb6pcRoYLhy2IhgzsOEPA.jpg'),
(70295, 4810, 'Clube do Terror S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8QKVianuLmlrUIWakwCeAEXBRQo.jpg'),
(70296, 4810, 'Clube do Terror S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mwD2cWoAfEaK5uDqCOL8DTVnKG6.jpg'),
(70297, 4811, 'Clube do Terror S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/162064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/swABrmUqEtxXdWI7mQ8K0GxbtWM.jpg'),
(70298, 4811, 'Clube do Terror S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/162065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nrj0afYhDhbPlH4p0Nbx1mRDVje.jpg'),
(70299, 4811, 'Clube do Terror S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/162066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Xm4BVhhVpDZG7uCRo9B64WjeRW.jpg'),
(70300, 4811, 'Clube do Terror S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/162067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qi6oSu40bWAYLgkB5zQU8Fa2IHe.jpg'),
(70301, 4811, 'Clube do Terror S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/162068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7EMh5O7KpkaJqaCL3LU5ZMisKYx.jpg'),
(70302, 4811, 'Clube do Terror S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/162069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m6PYGni1nMKd4vK1vghqEsvk1yd.jpg'),
(70303, 4812, 'Apaixonados na Cidade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b4Vlz6DY4yqOfSUxyWDPEq2mIdV.jpg'),
(70304, 4812, 'Apaixonados na Cidade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6eJyQSm1WR5jqVjojTdtOnlzife.jpg'),
(70305, 4812, 'Apaixonados na Cidade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCpgGa14kPYDVYeunVqADa7pzSM.jpg'),
(70306, 4812, 'Apaixonados na Cidade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n6Dbd8dBc1hEzDUKX32tCHBCogs.jpg'),
(70307, 4812, 'Apaixonados na Cidade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n8nGiE6cqzsmPEY6lxsfJyzApwz.jpg'),
(70308, 4812, 'Apaixonados na Cidade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5DAsDtHwxjMlrbgedu8FjQdsjAL.jpg'),
(70309, 4812, 'Apaixonados na Cidade S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5A8zvFidTCoTlVTSL2cD6tT4jiD.jpg'),
(70310, 4812, 'Apaixonados na Cidade S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/OU0cRwxdwLtwgBKbsNFJGsNcDC.jpg'),
(70311, 4812, 'Apaixonados na Cidade S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/syRJ52ADsYUiRha7O4NiduTU0wW.jpg'),
(70312, 4812, 'Apaixonados na Cidade S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vyUhf3ZfMgZtYBInVcnWlku8Kiu.jpg'),
(70313, 4812, 'Apaixonados na Cidade S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qRXZM284bAQE68dZS9fEDeMR9iY.jpg'),
(70314, 4812, 'Apaixonados na Cidade S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uDhWW3EpQMnnEcUfN9NCgzKlWAh.jpg'),
(70315, 4812, 'Apaixonados na Cidade S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7BhOONgCsHFEgYu6dn7Q7QI6B4Z.jpg'),
(70316, 4812, 'Apaixonados na Cidade S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oAAEEnukkHSDXylZXNkPsu9gdOx.jpg'),
(70317, 4812, 'Apaixonados na Cidade S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4cN5ER3gH9J6wiScW0qr5wW8aAH.jpg'),
(70318, 4812, 'Apaixonados na Cidade S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nBnqhTL5P1w68Zc2lgOeOoT2UEK.jpg'),
(70319, 4812, 'Apaixonados na Cidade S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/161986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/plHJXw9rzTZPPf2gnIoABQremRF.jpg'),
(70320, 4813, 'Arcane S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7dMkFJvJECDYoL0TRzGQCfF3xD.jpg'),
(70321, 4813, 'Arcane S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/49HmMAu69lbBFhApVE7JaULEbwE.jpg'),
(70322, 4813, 'Arcane S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rWgfZJ9F0bUxvSW6Ak2KfboXUih.jpg'),
(70323, 4813, 'Arcane S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7CYgTZUqI80HeJgN686sYW3f9y2.jpg'),
(70324, 4813, 'Arcane S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/72Ti7nTKEAPgx4VSggb1ksl31rm.jpg'),
(70325, 4813, 'Arcane S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9imUyzKnw5oPE75HTLoXXODOR9O.jpg'),
(70326, 4813, 'Arcane S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3HVZjh2IL3f9UPLp9AmjGd06aUW.jpg'),
(70327, 4813, 'Arcane S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4PhdO5SvOBvrsj6IUx52ii1mtNy.jpg'),
(70328, 4813, 'Arcane S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dbnGqpGWUjLcTVQxr5k1V3no8BB.jpg'),
(70329, 4814, 'Arcane S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/503788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqldf2t8ztc9aiwn3k6mlX3tvRT.jpg'),
(70330, 4814, 'Arcane S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/503789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqldf2t8ztc9aiwn3k6mlX3tvRT.jpg'),
(70331, 4814, 'Arcane S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/503790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqldf2t8ztc9aiwn3k6mlX3tvRT.jpg'),
(70332, 4814, 'Arcane S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/503791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqldf2t8ztc9aiwn3k6mlX3tvRT.jpg'),
(70333, 4814, 'Arcane S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/503792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqldf2t8ztc9aiwn3k6mlX3tvRT.jpg'),
(70334, 4814, 'Arcane S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/503793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqldf2t8ztc9aiwn3k6mlX3tvRT.jpg'),
(70335, 4814, 'Arcane S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/512576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqldf2t8ztc9aiwn3k6mlX3tvRT.jpg'),
(70336, 4814, 'Arcane S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/512577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqldf2t8ztc9aiwn3k6mlX3tvRT.jpg'),
(70337, 4814, 'Arcane S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/512578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqldf2t8ztc9aiwn3k6mlX3tvRT.jpg'),
(70338, 4815, 'Assassinato do Primeiro-Ministro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1EOXAKJGuRxrTqT45JNtvhUvPpU.jpg'),
(70339, 4815, 'Assassinato do Primeiro-Ministro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mrfLFE7Z2P40TYJxjRbjrSuaGC9.jpg'),
(70340, 4815, 'Assassinato do Primeiro-Ministro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tffYBZbYCwF0wPy9yMPwF1YE0xv.jpg'),
(70341, 4815, 'Assassinato do Primeiro-Ministro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yE16QY7ZNVK12nTthu8ZpG5FmeI.jpg'),
(70342, 4815, 'Assassinato do Primeiro-Ministro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uJZjlHqAwulWgifkn7oOUm306Ah.jpg'),
(70343, 4816, 'Hip Hop Uncovered S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nfzGM9G4cMhByE3LCLEYsAH9duO.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(70344, 4816, 'Hip Hop Uncovered S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nfzGM9G4cMhByE3LCLEYsAH9duO.jpg'),
(70345, 4816, 'Hip Hop Uncovered S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nfzGM9G4cMhByE3LCLEYsAH9duO.jpg'),
(70346, 4816, 'Hip Hop Uncovered S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nfzGM9G4cMhByE3LCLEYsAH9duO.jpg'),
(70347, 4816, 'Hip Hop Uncovered S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nfzGM9G4cMhByE3LCLEYsAH9duO.jpg'),
(70348, 4816, 'Hip Hop Uncovered S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nfzGM9G4cMhByE3LCLEYsAH9duO.jpg'),
(70349, 4817, 'Marília Mendonça: Todos os Cantos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y17rbAxVKalWMrvP1McuA4rcQv3.jpg'),
(70350, 4817, 'Marília Mendonça: Todos os Cantos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jyo4pKovRx2hMEdrMQ9U17jHKUP.jpg'),
(70351, 4817, 'Marília Mendonça: Todos os Cantos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vvNM81IqTzEYZbVa5WTZNSYLX4D.jpg'),
(70352, 4817, 'Marília Mendonça: Todos os Cantos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1gHOFnqFdcfbhfBC77nqYKKXwho.jpg'),
(70353, 4818, 'Jack! – Um programa sobre gentileza S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6s67WytkpH23JE81xAtP7IjZBVm.jpg'),
(70354, 4818, 'Jack! – Um programa sobre gentileza S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dDbgUXGpDSetKtQKd1QJg78GvPw.jpg'),
(70355, 4818, 'Jack! – Um programa sobre gentileza S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v7qkgl0W1VKPHHDImSmo5qRCsM9.jpg'),
(70356, 4818, 'Jack! – Um programa sobre gentileza S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/asCTytEntzBjghAZNxfXA2dThiu.jpg'),
(70357, 4818, 'Jack! – Um programa sobre gentileza S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rAaaFvVA0vLlM1rmk4B9xziyehw.jpg'),
(70358, 4818, 'Jack! – Um programa sobre gentileza S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sbOYDVnzAPDM1OkDmhBnvmjUusD.jpg'),
(70359, 4818, 'Jack! – Um programa sobre gentileza S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hWr3HIaReWeb54U64wjRb6YtlkA.jpg'),
(70360, 4819, 'Jack! – Um programa sobre gentileza S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196324.mp4', 'http://timg.bdta.pro/images/c292689c828a7b8ccba82679c8665d6d.jpg'),
(70361, 4819, 'Jack! – Um programa sobre gentileza S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196325.mp4', 'http://timg.bdta.pro/images/52604fbdc1ecf927bf0fb30e98d05b27.jpg'),
(70362, 4819, 'Jack! – Um programa sobre gentileza S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196326.mp4', 'http://timg.bdta.pro/images/2c539c91bbbe6b4ac0f27783e15659f3.jpg'),
(70363, 4819, 'Jack! – Um programa sobre gentileza S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196327.mp4', 'http://timg.bdta.pro/images/3ac5da1c595096bc31eef46fffe08aa4.jpg'),
(70364, 4819, 'Jack! – Um programa sobre gentileza S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196328.mp4', 'http://timg.bdta.pro/images/12701ec55d21be32850aa9c559e535b6.jpg'),
(70365, 4819, 'Jack! – Um programa sobre gentileza S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196329.mp4', 'http://timg.bdta.pro/images/49f6925e129719ba67d557e207e0627b.jpg'),
(70366, 4819, 'Jack! – Um programa sobre gentileza S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196330.mp4', 'http://timg.bdta.pro/images/f9a4b615ebe2a08b4719e9f3be301c69.jpg'),
(70367, 4819, 'Jack! – Um programa sobre gentileza S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196331.mp4', 'http://timg.bdta.pro/images/5ae50d725e27f3f8b0ee21deecf3dd46.jpg'),
(70368, 4819, 'Jack! – Um programa sobre gentileza S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196332.mp4', 'http://timg.bdta.pro/images/13dc97fb897f236c0fb5d661a4c7c8f0.jpg'),
(70369, 4820, 'Olá? Sou Eu! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnRQxhCnKm0qMWtRxcY2SqdflQm.jpg'),
(70370, 4820, 'Olá? Sou Eu! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pCIArWWCRgyElwENmec0U0cZiMM.jpg'),
(70371, 4820, 'Olá? Sou Eu! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sr2w5LDmkhZeZVY3YoxqwmCLXZ9.jpg'),
(70372, 4820, 'Olá? Sou Eu! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9XFAMXJ30xLiFrrlaNESuxjkouU.jpg'),
(70373, 4820, 'Olá? Sou Eu! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fxQMKGoEJh95AC4D1NEUWneVawW.jpg'),
(70374, 4820, 'Olá? Sou Eu! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/161944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tHlRbnp0xKsSohA3WKOdrdBzP2O.jpg'),
(70375, 4820, 'Olá? Sou Eu! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/161945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yC4CpQmhTZjrzoYFq3DS8Vv65o5.jpg'),
(70376, 4820, 'Olá? Sou Eu! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/161946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ZJHjBiQ9j9hkNMxYQX7zmlwzRu.jpg'),
(70377, 4820, 'Olá? Sou Eu! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/161947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7VgRUIe652t7BJy8RTcsIXwbXhs.jpg'),
(70378, 4820, 'Olá? Sou Eu! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/161948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1zFMPUCafIeiZ2zt1NYs4CC9Y6v.jpg'),
(70379, 4820, 'Olá? Sou Eu! S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/161949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/OQfovNSE9VaNVOxt6TEgpjN55f.jpg'),
(70380, 4820, 'Olá? Sou Eu! S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/161950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6d551Gn1ZHh7FGkm7RxR6Z0JLDs.jpg'),
(70381, 4820, 'Olá? Sou Eu! S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/161951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nVIrPJH55UBoadTT3CURiOVaYMv.jpg'),
(70382, 4820, 'Olá? Sou Eu! S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/161952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qoKOmuZ33JfX0I9und6rUYdBt5U.jpg'),
(70383, 4820, 'Olá? Sou Eu! S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/161953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AaKBETYzbzt1pnTtnNygYGmRXqU.jpg'),
(70384, 4820, 'Olá? Sou Eu! S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/161954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s0SvlETNIhTGRBa3H1yw2Sq1Nav.jpg'),
(70385, 4821, 'Onde está Marta del Castillo? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaoy8Bd5MxSzOQIpESTDgziChvw.jpg'),
(70386, 4821, 'Onde está Marta del Castillo? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaoy8Bd5MxSzOQIpESTDgziChvw.jpg'),
(70387, 4821, 'Onde está Marta del Castillo? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaoy8Bd5MxSzOQIpESTDgziChvw.jpg'),
(70388, 4822, 'The Club S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lxMLVwIJuVgftstqmrSGM7tUCY8.jpg'),
(70389, 4822, 'The Club S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Ycy16E69FP4eTulqQT83bmbZPg.jpg'),
(70390, 4822, 'The Club S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aHN9uYyCqarSBNfAk6nv4NbkeVa.jpg'),
(70391, 4822, 'The Club S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ir73BXdXEXyI9HeFlJ1reYTgksU.jpg'),
(70392, 4822, 'The Club S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2BmNIOIHjZFPbro8zzFJwEnSHLX.jpg'),
(70393, 4822, 'The Club S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fldl5yMfkGpA8tu3tE7n1tGzlpE.jpg'),
(70394, 4822, 'The Club S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jHgMj6mtMHEBrFhmZaQCGFGYnFx.jpg'),
(70395, 4822, 'The Club S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jHgMj6mtMHEBrFhmZaQCGFGYnFx.jpg'),
(70396, 4822, 'The Club S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jHgMj6mtMHEBrFhmZaQCGFGYnFx.jpg'),
(70397, 4822, 'The Club S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jHgMj6mtMHEBrFhmZaQCGFGYnFx.jpg'),
(70398, 4823, 'The D\'Amelio Show S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vsO7qm41WEBB24uRlclAg057rMZ.jpg'),
(70399, 4823, 'The D\'Amelio Show S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mAoklUcyJzgRaVzu6gMgisvc5JM.jpg'),
(70400, 4823, 'The D\'Amelio Show S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lqn0OgpuKWlOC6u6XWn3qz103aU.jpg'),
(70401, 4823, 'The D\'Amelio Show S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uWmTd0FfzmV8cSX7dtWPcDS6yjd.jpg'),
(70402, 4823, 'The D\'Amelio Show S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aasyv8HvVvCjGg6vWeQnanrliXe.jpg'),
(70403, 4823, 'The D\'Amelio Show S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uSHHTKWfshW1zM9bcjaiXejKCOJ.jpg'),
(70404, 4823, 'The D\'Amelio Show S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBvp0EsOPIEex1P22gC67ADkEZQ.jpg'),
(70405, 4823, 'The D\'Amelio Show S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZgwKC56kMLfdRBw0h2YSbJI2qS.jpg'),
(70406, 4824, 'The D\'Amelio Show S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qEU6tjupjXcOVl099qq0kFjvjxK.jpg'),
(70407, 4824, 'The D\'Amelio Show S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3YBAumLUqg2TksimDdoBQzjiaMz.jpg'),
(70408, 4824, 'The D\'Amelio Show S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qJakofVOWNAe04ZbvpMXAA9ewFd.jpg'),
(70409, 4824, 'The D\'Amelio Show S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AdIQQW6LR3CttsffGIpQHQhnhia.jpg'),
(70410, 4824, 'The D\'Amelio Show S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vKAaT6ON5ZF0L8b1RffzcSgjG7n.jpg'),
(70411, 4824, 'The D\'Amelio Show S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yeD2OQmoQF2MheS9Dd0GTyLe1tP.jpg'),
(70412, 4824, 'The D\'Amelio Show S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z0xkfDma5z0rwiBO3fNVZ0eEDVg.jpg'),
(70413, 4824, 'The D\'Amelio Show S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rKJfrUXOVYwprh2pLmQiW2rbOc3.jpg'),
(70414, 4824, 'The D\'Amelio Show S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oQjAnFiS8HfLTTNpTQFZSWAVo3n.jpg'),
(70415, 4824, 'The D\'Amelio Show S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vZW7gXM3jwTI7LG8BRxuLmh1bKZ.jpg'),
(70416, 4825, 'The D\'Amelio Show S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z0iCS5Znx7TeRwlYSd4c01Z0lFx.jpg'),
(70417, 4825, 'The D\'Amelio Show S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z0iCS5Znx7TeRwlYSd4c01Z0lFx.jpg'),
(70418, 4825, 'The D\'Amelio Show S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z0iCS5Znx7TeRwlYSd4c01Z0lFx.jpg'),
(70419, 4825, 'The D\'Amelio Show S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z0iCS5Znx7TeRwlYSd4c01Z0lFx.jpg'),
(70420, 4825, 'The D\'Amelio Show S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z0iCS5Znx7TeRwlYSd4c01Z0lFx.jpg'),
(70421, 4825, 'The D\'Amelio Show S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z0iCS5Znx7TeRwlYSd4c01Z0lFx.jpg'),
(70422, 4825, 'The D\'Amelio Show S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z0iCS5Znx7TeRwlYSd4c01Z0lFx.jpg'),
(70423, 4825, 'The D\'Amelio Show S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z0iCS5Znx7TeRwlYSd4c01Z0lFx.jpg'),
(70424, 4825, 'The D\'Amelio Show S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z0iCS5Znx7TeRwlYSd4c01Z0lFx.jpg'),
(70425, 4825, 'The D\'Amelio Show S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z0iCS5Znx7TeRwlYSd4c01Z0lFx.jpg'),
(70426, 4826, 'Tokyo Revengers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FcmZTXklg6ONMC11H0sqiMBpZ7.jpg'),
(70427, 4826, 'Tokyo Revengers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0ZhZ7fc7kWafyugqHbX7CoWhfO.jpg'),
(70428, 4826, 'Tokyo Revengers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3egxb6LOeuuxOmtFJijFr9Va5h.jpg'),
(70429, 4826, 'Tokyo Revengers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bJAhezqKrwaL14vnxZxISHR5ptk.jpg'),
(70430, 4826, 'Tokyo Revengers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mR9h9yI9jr5n10QRpGw4deQStnD.jpg'),
(70431, 4826, 'Tokyo Revengers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6vC4aDuRfpHiyoNdqhW4KCWRYpz.jpg'),
(70432, 4826, 'Tokyo Revengers S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w0Ivwpsw4kc0kIhy9D23DTVqUSK.jpg'),
(70433, 4826, 'Tokyo Revengers S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qNkYATNFMbApgvATdk2fU4w3zYa.jpg'),
(70434, 4826, 'Tokyo Revengers S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4WYP6vds19yH7CqGvsLUhy51QfJ.jpg'),
(70435, 4826, 'Tokyo Revengers S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n6vwasg7CIjbAvtLIBwaMdSi7Dc.jpg'),
(70436, 4826, 'Tokyo Revengers S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1X0VRPm7hCzFxqD2r9X0owXNmtu.jpg'),
(70437, 4826, 'Tokyo Revengers S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5JjriIqwqK5i3BhGlyFDSOWA0EE.jpg'),
(70438, 4826, 'Tokyo Revengers S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7IfbXvxQ8NGmNdhJXquYtCqnje.jpg'),
(70439, 4826, 'Tokyo Revengers S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/235887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vsELfbgRw3Ez7MvdjIEFAdvpJgb.jpg'),
(70440, 4826, 'Tokyo Revengers S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/235888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhjIqpf7K75fAGIpH9PJVI8YKyP.jpg'),
(70441, 4826, 'Tokyo Revengers S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/235889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pQFZAaNPfOuEqMFdwzCJTFSDZ0l.jpg'),
(70442, 4826, 'Tokyo Revengers S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/235890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7xJjcQDAXp02UYtbqPaoDAWTxPJ.jpg'),
(70443, 4826, 'Tokyo Revengers S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/235891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wVdKa97ErBzEa2FbBuFpF6i2EUz.jpg'),
(70444, 4826, 'Tokyo Revengers S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/235892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zvzHveT5QouqOUCCRmw6FcmgIzV.jpg'),
(70445, 4826, 'Tokyo Revengers S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/235893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1BwUPV4RHuxUVeQC1ZzOLuYMs5C.jpg'),
(70446, 4826, 'Tokyo Revengers S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/235894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AnrF7wDI5CvLXxQuFEH8CUfDCo0.jpg'),
(70447, 4826, 'Tokyo Revengers S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/235895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qK25ayIJZKY0HTmBXGbHnbdJcCZ.jpg'),
(70448, 4826, 'Tokyo Revengers S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/235896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/41Ocdf3HTe0iPAoR320PvKcW0EY.jpg'),
(70449, 4826, 'Tokyo Revengers S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/235897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bQH23udylJmaQByLhUo7RMejQzX.jpg'),
(70450, 4827, 'Tokyo Revengers S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kzDHRAkFjeed0lJpjE1eKJDcowS.jpg'),
(70451, 4827, 'Tokyo Revengers S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kzDHRAkFjeed0lJpjE1eKJDcowS.jpg'),
(70452, 4827, 'Tokyo Revengers S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kzDHRAkFjeed0lJpjE1eKJDcowS.jpg'),
(70453, 4827, 'Tokyo Revengers S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kzDHRAkFjeed0lJpjE1eKJDcowS.jpg'),
(70454, 4827, 'Tokyo Revengers S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kzDHRAkFjeed0lJpjE1eKJDcowS.jpg'),
(70455, 4827, 'Tokyo Revengers S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kzDHRAkFjeed0lJpjE1eKJDcowS.jpg'),
(70456, 4827, 'Tokyo Revengers S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kzDHRAkFjeed0lJpjE1eKJDcowS.jpg'),
(70457, 4827, 'Tokyo Revengers S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kzDHRAkFjeed0lJpjE1eKJDcowS.jpg'),
(70458, 4827, 'Tokyo Revengers S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kzDHRAkFjeed0lJpjE1eKJDcowS.jpg'),
(70459, 4827, 'Tokyo Revengers S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kzDHRAkFjeed0lJpjE1eKJDcowS.jpg'),
(70460, 4827, 'Tokyo Revengers S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kzDHRAkFjeed0lJpjE1eKJDcowS.jpg'),
(70461, 4827, 'Tokyo Revengers S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kzDHRAkFjeed0lJpjE1eKJDcowS.jpg'),
(70462, 4827, 'Tokyo Revengers S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kzDHRAkFjeed0lJpjE1eKJDcowS.jpg'),
(70463, 4828, 'Uma Imensidão de Erros: O Caso de Jeffrey MacDonald S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/161931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gagZNqYrKpeqdINxRO8vHXpkvWm.jpg'),
(70464, 4828, 'Uma Imensidão de Erros: O Caso de Jeffrey MacDonald S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/161932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eZcWLfTZtY3frCYIQ8H1lEUuMVa.jpg'),
(70465, 4828, 'Uma Imensidão de Erros: O Caso de Jeffrey MacDonald S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/161933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rfQlhTaBxy8tU9IUYqzOrI1yBUX.jpg'),
(70466, 4828, 'Uma Imensidão de Erros: O Caso de Jeffrey MacDonald S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/161934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/79ogmWTl1hmIuMxq2cbaggpcbLZ.jpg'),
(70467, 4828, 'Uma Imensidão de Erros: O Caso de Jeffrey MacDonald S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/161935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o100rwWXIIjgC0Bh9T939f3suoa.jpg'),
(70468, 4829, 'A Beleza Secreta dos Animais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Kz1QACNHCpLqSStJDtbV1F5DhQ.jpg'),
(70469, 4829, 'A Beleza Secreta dos Animais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dj0coMs0ih6NQHZgrrKHdXPUS0f.jpg'),
(70470, 4829, 'A Beleza Secreta dos Animais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hH9B9klxInG0z4vI6Dv9KxGjC7A.jpg'),
(70471, 4829, 'A Beleza Secreta dos Animais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/trpmse4CG2PSNo4s7Xc5NIAPfIM.jpg'),
(70472, 4830, 'A Beleza Secreta dos Animais S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177428.mp4', 'http://timg.bdta.pro/images/96c47b62c0be874f52c8fcd10e4368d3.jpg'),
(70473, 4830, 'A Beleza Secreta dos Animais S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177429.mp4', 'http://timg.bdta.pro/images/d6d66fccf9eb49327438c871932fec54.jpg'),
(70474, 4830, 'A Beleza Secreta dos Animais S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177430.mp4', 'http://timg.bdta.pro/images/7911590e8961683d8560aab35af10821.jpg'),
(70475, 4830, 'A Beleza Secreta dos Animais S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177431.mp4', 'http://timg.bdta.pro/images/b6b171adbcedf407e99e0a6efe411814.jpg'),
(70476, 4831, 'Chapolin Colorado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70477, 4831, 'Chapolin Colorado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70478, 4831, 'Chapolin Colorado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wGeYjArrpW3FIabCq8GgGxZOybe.jpg'),
(70479, 4831, 'Chapolin Colorado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70480, 4831, 'Chapolin Colorado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70481, 4831, 'Chapolin Colorado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70482, 4831, 'Chapolin Colorado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70483, 4831, 'Chapolin Colorado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Y7THIWMorsj3MXOI0bFHVlwPxz.jpg'),
(70484, 4831, 'Chapolin Colorado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70485, 4831, 'Chapolin Colorado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70486, 4831, 'Chapolin Colorado S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70487, 4831, 'Chapolin Colorado S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70488, 4831, 'Chapolin Colorado S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70489, 4831, 'Chapolin Colorado S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70490, 4831, 'Chapolin Colorado S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70491, 4831, 'Chapolin Colorado S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70492, 4831, 'Chapolin Colorado S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70493, 4831, 'Chapolin Colorado S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70494, 4831, 'Chapolin Colorado S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/166935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70495, 4831, 'Chapolin Colorado S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/166936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70496, 4831, 'Chapolin Colorado S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/166937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70497, 4831, 'Chapolin Colorado S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/166938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70498, 4831, 'Chapolin Colorado S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/166939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70499, 4831, 'Chapolin Colorado S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/166940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70500, 4831, 'Chapolin Colorado S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/166941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70501, 4831, 'Chapolin Colorado S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/166942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70502, 4831, 'Chapolin Colorado S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/166943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70503, 4831, 'Chapolin Colorado S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/166944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70504, 4831, 'Chapolin Colorado S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/166945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70505, 4831, 'Chapolin Colorado S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/166946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70506, 4831, 'Chapolin Colorado S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/166947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70507, 4831, 'Chapolin Colorado S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/166948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70508, 4831, 'Chapolin Colorado S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/166949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70509, 4831, 'Chapolin Colorado S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/166950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70510, 4831, 'Chapolin Colorado S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/166951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70511, 4831, 'Chapolin Colorado S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/166952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70512, 4832, 'Chapolin Colorado S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70513, 4832, 'Chapolin Colorado S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70514, 4832, 'Chapolin Colorado S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70515, 4832, 'Chapolin Colorado S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70516, 4832, 'Chapolin Colorado S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70517, 4832, 'Chapolin Colorado S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70518, 4832, 'Chapolin Colorado S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70519, 4832, 'Chapolin Colorado S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70520, 4832, 'Chapolin Colorado S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70521, 4832, 'Chapolin Colorado S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70522, 4832, 'Chapolin Colorado S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70523, 4832, 'Chapolin Colorado S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70524, 4832, 'Chapolin Colorado S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70525, 4832, 'Chapolin Colorado S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70526, 4832, 'Chapolin Colorado S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70527, 4832, 'Chapolin Colorado S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70528, 4832, 'Chapolin Colorado S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70529, 4832, 'Chapolin Colorado S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70530, 4832, 'Chapolin Colorado S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/166971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70531, 4832, 'Chapolin Colorado S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/166972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70532, 4832, 'Chapolin Colorado S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/166973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70533, 4832, 'Chapolin Colorado S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/166974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70534, 4832, 'Chapolin Colorado S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/166975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70535, 4832, 'Chapolin Colorado S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/166976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70536, 4832, 'Chapolin Colorado S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/166977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70537, 4832, 'Chapolin Colorado S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/166978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70538, 4832, 'Chapolin Colorado S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/166979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70539, 4832, 'Chapolin Colorado S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/166980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70540, 4832, 'Chapolin Colorado S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/166981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70541, 4832, 'Chapolin Colorado S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/166982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70542, 4832, 'Chapolin Colorado S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/166983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70543, 4832, 'Chapolin Colorado S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/166984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70544, 4832, 'Chapolin Colorado S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/166985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70545, 4832, 'Chapolin Colorado S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/166986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70546, 4832, 'Chapolin Colorado S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/166987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70547, 4833, 'Chapolin Colorado S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70548, 4833, 'Chapolin Colorado S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70549, 4833, 'Chapolin Colorado S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70550, 4833, 'Chapolin Colorado S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70551, 4833, 'Chapolin Colorado S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70552, 4833, 'Chapolin Colorado S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70553, 4833, 'Chapolin Colorado S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70554, 4833, 'Chapolin Colorado S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70555, 4833, 'Chapolin Colorado S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70556, 4833, 'Chapolin Colorado S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70557, 4833, 'Chapolin Colorado S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70558, 4833, 'Chapolin Colorado S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70559, 4833, 'Chapolin Colorado S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70560, 4833, 'Chapolin Colorado S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70561, 4833, 'Chapolin Colorado S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70562, 4833, 'Chapolin Colorado S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70563, 4833, 'Chapolin Colorado S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70564, 4833, 'Chapolin Colorado S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70565, 4833, 'Chapolin Colorado S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70566, 4833, 'Chapolin Colorado S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70567, 4833, 'Chapolin Colorado S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/167008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70568, 4833, 'Chapolin Colorado S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/167009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70569, 4833, 'Chapolin Colorado S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/167010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70570, 4833, 'Chapolin Colorado S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/167011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70571, 4833, 'Chapolin Colorado S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/167012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70572, 4833, 'Chapolin Colorado S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/167013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70573, 4833, 'Chapolin Colorado S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/167014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70574, 4833, 'Chapolin Colorado S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/167015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70575, 4833, 'Chapolin Colorado S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/167016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70576, 4833, 'Chapolin Colorado S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/167017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70577, 4833, 'Chapolin Colorado S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/167018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70578, 4834, 'Chapolin Colorado S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70579, 4834, 'Chapolin Colorado S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70580, 4834, 'Chapolin Colorado S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70581, 4834, 'Chapolin Colorado S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70582, 4834, 'Chapolin Colorado S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70583, 4834, 'Chapolin Colorado S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70584, 4834, 'Chapolin Colorado S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70585, 4834, 'Chapolin Colorado S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70586, 4834, 'Chapolin Colorado S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70587, 4834, 'Chapolin Colorado S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70588, 4834, 'Chapolin Colorado S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70589, 4834, 'Chapolin Colorado S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70590, 4834, 'Chapolin Colorado S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70591, 4834, 'Chapolin Colorado S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70592, 4834, 'Chapolin Colorado S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70593, 4834, 'Chapolin Colorado S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70594, 4834, 'Chapolin Colorado S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70595, 4834, 'Chapolin Colorado S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70596, 4834, 'Chapolin Colorado S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70597, 4834, 'Chapolin Colorado S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70598, 4834, 'Chapolin Colorado S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/167039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70599, 4834, 'Chapolin Colorado S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/167040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70600, 4834, 'Chapolin Colorado S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/167041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70601, 4834, 'Chapolin Colorado S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/167042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70602, 4834, 'Chapolin Colorado S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/167043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70603, 4834, 'Chapolin Colorado S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/167044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70604, 4834, 'Chapolin Colorado S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/167045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(70605, 4834, 'Chapolin Colorado S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/167046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70606, 4834, 'Chapolin Colorado S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/167047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70607, 4834, 'Chapolin Colorado S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/167048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70608, 4834, 'Chapolin Colorado S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/167049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70609, 4834, 'Chapolin Colorado S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/167050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70610, 4834, 'Chapolin Colorado S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/167051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70611, 4834, 'Chapolin Colorado S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/167052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70612, 4834, 'Chapolin Colorado S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/167053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70613, 4834, 'Chapolin Colorado S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/167054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70614, 4834, 'Chapolin Colorado S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/167055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70615, 4834, 'Chapolin Colorado S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/167056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70616, 4834, 'Chapolin Colorado S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/167057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70617, 4835, 'Chapolin Colorado S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70618, 4835, 'Chapolin Colorado S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70619, 4835, 'Chapolin Colorado S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70620, 4835, 'Chapolin Colorado S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70621, 4835, 'Chapolin Colorado S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70622, 4835, 'Chapolin Colorado S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70623, 4835, 'Chapolin Colorado S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70624, 4835, 'Chapolin Colorado S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70625, 4835, 'Chapolin Colorado S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70626, 4835, 'Chapolin Colorado S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70627, 4835, 'Chapolin Colorado S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70628, 4835, 'Chapolin Colorado S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70629, 4835, 'Chapolin Colorado S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70630, 4835, 'Chapolin Colorado S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70631, 4835, 'Chapolin Colorado S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70632, 4835, 'Chapolin Colorado S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70633, 4835, 'Chapolin Colorado S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70634, 4835, 'Chapolin Colorado S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70635, 4835, 'Chapolin Colorado S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70636, 4835, 'Chapolin Colorado S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70637, 4835, 'Chapolin Colorado S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/167078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70638, 4835, 'Chapolin Colorado S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/167079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70639, 4835, 'Chapolin Colorado S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/167080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70640, 4835, 'Chapolin Colorado S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/167081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70641, 4835, 'Chapolin Colorado S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/167082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70642, 4835, 'Chapolin Colorado S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/167083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70643, 4835, 'Chapolin Colorado S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/167084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70644, 4835, 'Chapolin Colorado S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/167085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70645, 4835, 'Chapolin Colorado S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/167086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70646, 4835, 'Chapolin Colorado S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/167087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70647, 4835, 'Chapolin Colorado S05 E31', 'http://sinalprivado.info:80/series/1533784/1533784/167088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70648, 4835, 'Chapolin Colorado S05 E32', 'http://sinalprivado.info:80/series/1533784/1533784/167089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70649, 4835, 'Chapolin Colorado S05 E33', 'http://sinalprivado.info:80/series/1533784/1533784/167090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70650, 4835, 'Chapolin Colorado S05 E34', 'http://sinalprivado.info:80/series/1533784/1533784/167091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70651, 4835, 'Chapolin Colorado S05 E35', 'http://sinalprivado.info:80/series/1533784/1533784/167092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70652, 4835, 'Chapolin Colorado S05 E36', 'http://sinalprivado.info:80/series/1533784/1533784/167093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70653, 4835, 'Chapolin Colorado S05 E37', 'http://sinalprivado.info:80/series/1533784/1533784/167094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70654, 4835, 'Chapolin Colorado S05 E38', 'http://sinalprivado.info:80/series/1533784/1533784/167095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70655, 4835, 'Chapolin Colorado S05 E39', 'http://sinalprivado.info:80/series/1533784/1533784/167096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70656, 4835, 'Chapolin Colorado S05 E40', 'http://sinalprivado.info:80/series/1533784/1533784/167097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70657, 4835, 'Chapolin Colorado S05 E41', 'http://sinalprivado.info:80/series/1533784/1533784/167098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70658, 4835, 'Chapolin Colorado S05 E42', 'http://sinalprivado.info:80/series/1533784/1533784/167099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70659, 4835, 'Chapolin Colorado S05 E43', 'http://sinalprivado.info:80/series/1533784/1533784/167100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70660, 4836, 'Chapolin Colorado S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70661, 4836, 'Chapolin Colorado S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70662, 4836, 'Chapolin Colorado S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70663, 4836, 'Chapolin Colorado S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70664, 4836, 'Chapolin Colorado S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70665, 4836, 'Chapolin Colorado S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70666, 4836, 'Chapolin Colorado S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70667, 4836, 'Chapolin Colorado S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70668, 4836, 'Chapolin Colorado S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70669, 4836, 'Chapolin Colorado S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70670, 4836, 'Chapolin Colorado S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70671, 4836, 'Chapolin Colorado S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70672, 4836, 'Chapolin Colorado S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70673, 4836, 'Chapolin Colorado S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70674, 4836, 'Chapolin Colorado S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70675, 4836, 'Chapolin Colorado S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70676, 4836, 'Chapolin Colorado S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70677, 4836, 'Chapolin Colorado S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70678, 4836, 'Chapolin Colorado S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70679, 4836, 'Chapolin Colorado S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70680, 4836, 'Chapolin Colorado S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/167121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70681, 4836, 'Chapolin Colorado S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/167122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70682, 4836, 'Chapolin Colorado S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/167123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70683, 4836, 'Chapolin Colorado S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/167124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70684, 4836, 'Chapolin Colorado S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/167125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70685, 4836, 'Chapolin Colorado S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/167126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70686, 4836, 'Chapolin Colorado S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/167127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70687, 4836, 'Chapolin Colorado S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/167128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70688, 4836, 'Chapolin Colorado S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/167129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70689, 4836, 'Chapolin Colorado S06 E30', 'http://sinalprivado.info:80/series/1533784/1533784/167130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70690, 4836, 'Chapolin Colorado S06 E31', 'http://sinalprivado.info:80/series/1533784/1533784/167131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70691, 4836, 'Chapolin Colorado S06 E32', 'http://sinalprivado.info:80/series/1533784/1533784/167132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70692, 4836, 'Chapolin Colorado S06 E33', 'http://sinalprivado.info:80/series/1533784/1533784/167133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70693, 4836, 'Chapolin Colorado S06 E34', 'http://sinalprivado.info:80/series/1533784/1533784/167134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70694, 4836, 'Chapolin Colorado S06 E35', 'http://sinalprivado.info:80/series/1533784/1533784/167135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70695, 4836, 'Chapolin Colorado S06 E36', 'http://sinalprivado.info:80/series/1533784/1533784/167136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70696, 4836, 'Chapolin Colorado S06 E37', 'http://sinalprivado.info:80/series/1533784/1533784/167137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70697, 4836, 'Chapolin Colorado S06 E38', 'http://sinalprivado.info:80/series/1533784/1533784/167138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70698, 4836, 'Chapolin Colorado S06 E39', 'http://sinalprivado.info:80/series/1533784/1533784/167139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70699, 4836, 'Chapolin Colorado S06 E40', 'http://sinalprivado.info:80/series/1533784/1533784/167140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70700, 4836, 'Chapolin Colorado S06 E41', 'http://sinalprivado.info:80/series/1533784/1533784/167141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70701, 4837, 'Chapolin Colorado S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70702, 4837, 'Chapolin Colorado S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70703, 4837, 'Chapolin Colorado S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70704, 4837, 'Chapolin Colorado S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70705, 4837, 'Chapolin Colorado S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70706, 4837, 'Chapolin Colorado S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70707, 4837, 'Chapolin Colorado S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70708, 4837, 'Chapolin Colorado S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70709, 4837, 'Chapolin Colorado S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70710, 4837, 'Chapolin Colorado S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70711, 4837, 'Chapolin Colorado S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70712, 4837, 'Chapolin Colorado S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70713, 4837, 'Chapolin Colorado S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70714, 4837, 'Chapolin Colorado S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70715, 4837, 'Chapolin Colorado S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70716, 4837, 'Chapolin Colorado S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70717, 4837, 'Chapolin Colorado S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70718, 4837, 'Chapolin Colorado S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70719, 4837, 'Chapolin Colorado S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70720, 4837, 'Chapolin Colorado S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70721, 4837, 'Chapolin Colorado S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/167162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70722, 4837, 'Chapolin Colorado S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/167163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70723, 4837, 'Chapolin Colorado S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/167164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70724, 4837, 'Chapolin Colorado S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/167165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70725, 4837, 'Chapolin Colorado S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/167166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA23gBvmdBRRm245LPI3XmuHh51.jpg'),
(70726, 4838, 'Vendemos e Trocamos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eC6Bn83MLIOAamISilkCWZ7KQaG.jpg'),
(70727, 4838, 'Vendemos e Trocamos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gWQCZ456XU6OAsXt2ZKm8uX1G9j.jpg'),
(70728, 4838, 'Vendemos e Trocamos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2RaT78klyHCOeETkCSeQ0FBoVCc.jpg'),
(70729, 4838, 'Vendemos e Trocamos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4TJ8iI6jVHN146dzKtCdYq7w4ii.jpg'),
(70730, 4838, 'Vendemos e Trocamos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dzAEsIspbDS6kh8ogFCmAljy9VK.jpg'),
(70731, 4838, 'Vendemos e Trocamos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aSId9r5NmHWs5wyr5M0WtVsBznO.jpg'),
(70732, 4839, 'Vendemos e Trocamos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/flacWSBN4sGWzILbtmoDCgbZwrm.jpg'),
(70733, 4839, 'Vendemos e Trocamos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/flacWSBN4sGWzILbtmoDCgbZwrm.jpg'),
(70734, 4839, 'Vendemos e Trocamos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/flacWSBN4sGWzILbtmoDCgbZwrm.jpg'),
(70735, 4839, 'Vendemos e Trocamos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/flacWSBN4sGWzILbtmoDCgbZwrm.jpg'),
(70736, 4839, 'Vendemos e Trocamos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/flacWSBN4sGWzILbtmoDCgbZwrm.jpg'),
(70737, 4839, 'Vendemos e Trocamos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/flacWSBN4sGWzILbtmoDCgbZwrm.jpg'),
(70738, 4840, 'Dexter: Sangue Novo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/igyYWp2f69LIMMLFZzuMvoSdA8n.jpg'),
(70739, 4840, 'Dexter: Sangue Novo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8JeRign9jzxne1UhnyozvxkPZSB.jpg'),
(70740, 4840, 'Dexter: Sangue Novo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3W6oNm9o4lk2csH4cEKA6MDESjh.jpg'),
(70741, 4840, 'Dexter: Sangue Novo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a3bU98DH7BMkz4IBUn0tLPzxA0E.jpg'),
(70742, 4840, 'Dexter: Sangue Novo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iVEa7gHM4eHd9KOQ5FvvuyX1NqV.jpg'),
(70743, 4840, 'Dexter: Sangue Novo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MQoJGTLPxmguUpx1ES0mN3pE5.jpg'),
(70744, 4840, 'Dexter: Sangue Novo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ol5Sm95aBoPDXprTThiz8IkWHdd.jpg'),
(70745, 4840, 'Dexter: Sangue Novo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7D33cg0gxAXAaWuVNCS9IXszVog.jpg'),
(70746, 4840, 'Dexter: Sangue Novo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3CqKW5jbrXUxX7VvPvVhIwBYUN8.jpg'),
(70747, 4840, 'Dexter: Sangue Novo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/edrSXO5bUwrltScuDKjNI8vVelq.jpg'),
(70748, 4841, 'Dr. Brain S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4iRtHoFXclcvhqgJiOW6ngjH0La.jpg'),
(70749, 4841, 'Dr. Brain S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPQabFfdAhRJsebXonkJ3fbwopR.jpg'),
(70750, 4841, 'Dr. Brain S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170360.mp4', 'http://image.tmdb.org/t/p/w1280/vZUacF7ytoH56NqgSlppVh7oL8z.jpg'),
(70751, 4841, 'Dr. Brain S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170361.mp4', 'http://image.tmdb.org/t/p/w1280/lXu8L5QysSJ17pbrizOXCI4jJMk.jpg'),
(70752, 4841, 'Dr. Brain S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170362.mp4', 'http://image.tmdb.org/t/p/w1280/mAf7ivbpNreUwUfvkZFRAAfMVoe.jpg'),
(70753, 4841, 'Dr. Brain S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170363.mp4', 'http://image.tmdb.org/t/p/w1280/wr91J90oHBBUnaaM7FVwjcxlxh7.jpg'),
(70754, 4842, 'É Ouro! O Brilho do Brasil em Tóquio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i5k4Z7rueQTw3lf9rNQ0g4kpMq6.jpg'),
(70755, 4842, 'É Ouro! O Brilho do Brasil em Tóquio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5tdP36dl0qf1LeB1ceKFfdiirqV.jpg'),
(70756, 4842, 'É Ouro! O Brilho do Brasil em Tóquio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8nZ12FBm81vK87loFqOGoGsgeB.jpg'),
(70757, 4842, 'É Ouro! O Brilho do Brasil em Tóquio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8nZ12FBm81vK87loFqOGoGsgeB.jpg'),
(70758, 4842, 'É Ouro! O Brilho do Brasil em Tóquio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8nZ12FBm81vK87loFqOGoGsgeB.jpg'),
(70759, 4842, 'É Ouro! O Brilho do Brasil em Tóquio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8nZ12FBm81vK87loFqOGoGsgeB.jpg'),
(70760, 4842, 'É Ouro! O Brilho do Brasil em Tóquio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8nZ12FBm81vK87loFqOGoGsgeB.jpg'),
(70761, 4842, 'É Ouro! O Brilho do Brasil em Tóquio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8nZ12FBm81vK87loFqOGoGsgeB.jpg'),
(70762, 4843, 'Game Shakers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70763, 4843, 'Game Shakers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70764, 4843, 'Game Shakers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4c9vskNfKFUI1xemVIj02DmIg2.jpg'),
(70765, 4843, 'Game Shakers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70766, 4843, 'Game Shakers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70767, 4843, 'Game Shakers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70768, 4843, 'Game Shakers S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70769, 4843, 'Game Shakers S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s1thMdJJ1fVYVRfZUYhw8kLZhF.jpg'),
(70770, 4843, 'Game Shakers S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70771, 4843, 'Game Shakers S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70772, 4843, 'Game Shakers S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70773, 4843, 'Game Shakers S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70774, 4843, 'Game Shakers S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70775, 4843, 'Game Shakers S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70776, 4843, 'Game Shakers S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70777, 4843, 'Game Shakers S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70778, 4843, 'Game Shakers S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70779, 4843, 'Game Shakers S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70780, 4843, 'Game Shakers S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/166864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70781, 4843, 'Game Shakers S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/166865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70782, 4843, 'Game Shakers S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/166866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70783, 4843, 'Game Shakers S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/166867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70784, 4843, 'Game Shakers S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/166868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70785, 4843, 'Game Shakers S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/166869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70786, 4843, 'Game Shakers S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/166870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70787, 4844, 'Game Shakers S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hoAbvv4Fc3JmtdtDG00XdWeMSxa.jpg'),
(70788, 4844, 'Game Shakers S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/axKukrJloVZSjsPH5GHhXCh6Nbc.jpg'),
(70789, 4844, 'Game Shakers S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70790, 4844, 'Game Shakers S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70791, 4844, 'Game Shakers S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70792, 4844, 'Game Shakers S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70793, 4844, 'Game Shakers S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/stFOOMgr2mkdWwGGdSRqNrxj6eS.jpg'),
(70794, 4844, 'Game Shakers S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70795, 4844, 'Game Shakers S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70796, 4844, 'Game Shakers S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70797, 4844, 'Game Shakers S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70798, 4844, 'Game Shakers S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70799, 4844, 'Game Shakers S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70800, 4844, 'Game Shakers S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70801, 4844, 'Game Shakers S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70802, 4844, 'Game Shakers S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8jn8U9mnIkyzYqB7ewxDj1RhV1.jpg'),
(70803, 4844, 'Game Shakers S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tIhHloZ3a7oYgFZGO4oQoSgwe41.jpg'),
(70804, 4844, 'Game Shakers S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70805, 4844, 'Game Shakers S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/166889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70806, 4844, 'Game Shakers S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/166890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70807, 4845, 'Game Shakers S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gNi1l125rJIqxmIu6hjViQv9GTb.jpg'),
(70808, 4845, 'Game Shakers S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70809, 4845, 'Game Shakers S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgHPZW47Q3BN2woHjKrKmIgBOZJ.jpg'),
(70810, 4845, 'Game Shakers S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70811, 4845, 'Game Shakers S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70812, 4845, 'Game Shakers S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70813, 4845, 'Game Shakers S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70814, 4845, 'Game Shakers S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70815, 4845, 'Game Shakers S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70816, 4845, 'Game Shakers S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70817, 4845, 'Game Shakers S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70818, 4845, 'Game Shakers S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70819, 4845, 'Game Shakers S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70820, 4845, 'Game Shakers S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70821, 4845, 'Game Shakers S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70822, 4845, 'Game Shakers S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70823, 4845, 'Game Shakers S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70824, 4845, 'Game Shakers S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bd3AIxI9397xdr2Xl8Q2rDMObCk.jpg'),
(70825, 4846, 'Gentefied S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A8FJVyQvJgWZYl2QXUe36X3Nmsk.jpg'),
(70826, 4846, 'Gentefied S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3vBHEVOBdKPbmHKJVssLLpHnM6g.jpg'),
(70827, 4846, 'Gentefied S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9mQYyrw2zLn9hYrIl5jCguUqavJ.jpg'),
(70828, 4846, 'Gentefied S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pIFRZkOWRemTBxx2zxLhQDTZq4e.jpg'),
(70829, 4846, 'Gentefied S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7mBV9slkV5ME8kZWM4jmBZ8POK.jpg'),
(70830, 4846, 'Gentefied S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ljnENVZCdt8i8Ik4bB3Cjdw6NXS.jpg'),
(70831, 4846, 'Gentefied S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zArRMOZ2cNNCxCtRQGAd5POR8Vm.jpg'),
(70832, 4846, 'Gentefied S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uMbPdMSAtefyadVUQkl1Zz42FcG.jpg'),
(70833, 4846, 'Gentefied S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7iE2wFgnevgnR2ntmAlW0jQsLoi.jpg'),
(70834, 4846, 'Gentefied S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fJT9LvLUf6xV2FwGqvjQ0bUAxC0.jpg'),
(70835, 4847, 'Gentefied S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yd36XbilyP06O03jc2F3DUJoXpK.jpg'),
(70836, 4847, 'Gentefied S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xohrzuKTLpTZ6rxqDPljlsblOI8.jpg'),
(70837, 4847, 'Gentefied S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cQ6uXRw8zrJaujBCqIlxHq4aN3n.jpg'),
(70838, 4847, 'Gentefied S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1r6BEreIxkTVXuQMdGQggTbf6oW.jpg'),
(70839, 4847, 'Gentefied S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mhdLRxWZehFJneRcjYN4fP2PRIC.jpg'),
(70840, 4847, 'Gentefied S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nBSibnVBaNHWZa6Clhkt14IO6ZS.jpg'),
(70841, 4847, 'Gentefied S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4AWV2m9o6U73Cz86wSAekcLLThD.jpg'),
(70842, 4847, 'Gentefied S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e7NomwMVBzLQJqstMzXi2HIFRjX.jpg'),
(70843, 4848, 'Swagger S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ej5XfWGs1T1I88DBHhlvZAZQVT.jpg'),
(70844, 4848, 'Swagger S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dEkr2VBux5ctYnN3Yzh1fP0NQ7b.jpg'),
(70845, 4848, 'Swagger S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jhGw7ZBV19yAQHSHRFTL8568NGv.jpg'),
(70846, 4848, 'Swagger S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mb5p2hRP8jf1hz7edvA6rksnnJx.jpg'),
(70847, 4848, 'Swagger S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zwjB3cXHmHv8ykSSX1YHqhHBNZ8.jpg'),
(70848, 4848, 'Swagger S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oogHinSAcXIWtJuf0EvFa3pnSVP.jpg'),
(70849, 4848, 'Swagger S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230113.mp4', 'http://image.tmdb.org/t/p/w1280/nADSrDYnJGtCrooT3vU9ic46RjJ.jpg'),
(70850, 4848, 'Swagger S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230114.mp4', 'http://image.tmdb.org/t/p/w1280/g3cp1vIFqA7vdE5tZf6ETD3krlR.jpg'),
(70851, 4848, 'Swagger S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230115.mp4', 'http://image.tmdb.org/t/p/w1280/7ttPaThPqamGXDpfntkTHcN8dEm.jpg'),
(70852, 4848, 'Swagger S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230116.mp4', 'http://image.tmdb.org/t/p/w1280/5uZlRG3jMvYoLom7V11KEbcK9A0.jpg'),
(70853, 4849, 'Swagger S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8zt4CUAZYMgFaYuOjrLN5ADCo9a.jpg'),
(70854, 4849, 'Swagger S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gOtPY3JrWqocnGNw3Q0qmSLJQzm.jpg'),
(70855, 4849, 'Swagger S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hpgVKXntGdSm9WKX9TfdDIzhdpQ.jpg'),
(70856, 4849, 'Swagger S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230120.mp4', 'http://image.tmdb.org/t/p/w1280/ohmKhva1hyYtDKqNKizU7QnUeuY.jpg'),
(70857, 4849, 'Swagger S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230121.mp4', 'http://image.tmdb.org/t/p/w1280/nPX0n9NFaOWDwFx4MQFpLGiHQqq.jpg'),
(70858, 4849, 'Swagger S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230122.mp4', 'http://image.tmdb.org/t/p/w1280/4YMNdmoVmh1EtuLdbHkLupd03Eb.jpg'),
(70859, 4849, 'Swagger S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230123.mp4', 'http://image.tmdb.org/t/p/w1280/cAUCx8C7dFMc61CJc1T9tLvRQJM.jpg'),
(70860, 4849, 'Swagger S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230124.mp4', 'http://image.tmdb.org/t/p/w1280/isW3NDRw4x8KjBdwwnM0yPYyJMT.jpg'),
(70861, 4850, 'The Equalizer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mOGhnsvsf79fEaLMPrugd7RvI6b.jpg'),
(70862, 4850, 'The Equalizer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzYp667WKUm8HY24mnCZPQQgPud.jpg'),
(70863, 4850, 'The Equalizer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AebXe0j8gwScFBmTpIsRHdwFF6a.jpg'),
(70864, 4850, 'The Equalizer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3XgGfMhVcNYH5Gk4XMBFTWab5XE.jpg'),
(70865, 4850, 'The Equalizer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aqgBRIug3S7hhpFcsaoR6n9FTJ4.jpg'),
(70866, 4850, 'The Equalizer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tsfxooKeA4JHkJ72rFUy0Ev6KD5.jpg'),
(70867, 4850, 'The Equalizer S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bh8Ya5k2ZfdHltOg1cWfzVldZ39.jpg'),
(70868, 4850, 'The Equalizer S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ksHpQRzkTBC9QeDlW9uvhcl8skX.jpg'),
(70869, 4850, 'The Equalizer S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cwuYbKIGYGSme0xIMbowWq8HFqj.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(70870, 4850, 'The Equalizer S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jhzOzUawppPJJ1uUd2szHnKrckc.jpg'),
(70871, 4851, 'The Equalizer S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229209.mp4', 'http://timg.bdta.pro/images/ed0135efe5556b9b26f66ff88f04b351.jpg'),
(70872, 4851, 'The Equalizer S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229210.mp4', 'http://timg.bdta.pro/images/1539c4ff6617de08976fac12dffd2bcc.jpg'),
(70873, 4851, 'The Equalizer S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229211.mp4', 'http://timg.bdta.pro/images/302ff035d7fcf5e9dbfd575d34139763.jpg'),
(70874, 4851, 'The Equalizer S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229212.mp4', 'http://timg.bdta.pro/images/9808436664794940a229624096722841.jpg'),
(70875, 4851, 'The Equalizer S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229213.mp4', 'http://timg.bdta.pro/images/2b7cdbd796dd9f6748f10af9bbf8b6a4.jpg'),
(70876, 4851, 'The Equalizer S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229214.mp4', 'http://timg.bdta.pro/images/2ee5f693438b5c0ad4994f0ee9a96f97.jpg'),
(70877, 4851, 'The Equalizer S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229215.mp4', 'http://timg.bdta.pro/images/aeda7b6d7ac36642d48eb4d7258be196.jpg'),
(70878, 4851, 'The Equalizer S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229216.mp4', 'http://timg.bdta.pro/images/c937809ff3ebfb958c44862c8dcf7868.jpg'),
(70879, 4851, 'The Equalizer S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229217.mp4', 'http://timg.bdta.pro/images/9009f998077d0fe5debb9fd71dbf63d2.jpg'),
(70880, 4851, 'The Equalizer S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229218.mp4', 'http://timg.bdta.pro/images/687a720157489659595f74238881e51a.jpg'),
(70881, 4851, 'The Equalizer S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/229219.mp4', 'http://timg.bdta.pro/images/c6e0176d18f5472dbcaa9eda2aff8122.jpg'),
(70882, 4851, 'The Equalizer S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/229220.mp4', 'http://timg.bdta.pro/images/081a48abece1a0bd12efb35086d42af7.jpg'),
(70883, 4851, 'The Equalizer S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/229221.mp4', 'http://timg.bdta.pro/images/4f99867f4528efd82f40ea80ebf8c7cd.jpg'),
(70884, 4851, 'The Equalizer S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/229222.mp4', 'http://timg.bdta.pro/images/85d5bd41b0c964212f1d0ebb4b66368e.jpg'),
(70885, 4851, 'The Equalizer S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/229223.mp4', 'http://timg.bdta.pro/images/347d07480ff939b8b3e07793b0e80c79.jpg'),
(70886, 4851, 'The Equalizer S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/229224.mp4', 'http://timg.bdta.pro/images/9fe975c11f7b5b7c186f6c6e1a2c1f65.jpg'),
(70887, 4851, 'The Equalizer S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/229225.mp4', 'http://timg.bdta.pro/images/631641a9b3a3bdaac9c2259107c667c5.jpg'),
(70888, 4851, 'The Equalizer S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/229226.mp4', 'http://timg.bdta.pro/images/2fb93b01820925f14c0939ffd478a159.jpg'),
(70889, 4852, 'The Equalizer S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/opH4ffEvLikEvEAh1qRFNotalvv.jpg'),
(70890, 4852, 'The Equalizer S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iKmOawRE13uCKTuFjgioTq7F0XS.jpg'),
(70891, 4852, 'The Equalizer S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qtsUZEEq2AaeMY9tM7B7i3DIgOM.jpg'),
(70892, 4852, 'The Equalizer S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eEtyOUWgs8wdxihka7RtAAQas37.jpg'),
(70893, 4852, 'The Equalizer S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uuSxBUXSIWyYIaYpriyNjJKVYP0.jpg'),
(70894, 4852, 'The Equalizer S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tGwZ6s4FbXiWkNRkoTkZfoV80Sv.jpg'),
(70895, 4852, 'The Equalizer S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8WdzlK8BeXzYmHTSJbjB0T6Ofwi.jpg'),
(70896, 4852, 'The Equalizer S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bGLGmkK5A0WUyKQsrOXxPv8hTIX.jpg'),
(70897, 4852, 'The Equalizer S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l3m3W51LW043TWo7ivPgfbOJbcb.jpg'),
(70898, 4852, 'The Equalizer S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4IEu9jjpI2Xz0TdX3f9cynUwYoB.jpg'),
(70899, 4852, 'The Equalizer S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/229237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oQ36llFyqoonz1eFi9NblraeI0H.jpg'),
(70900, 4852, 'The Equalizer S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/229238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cjAeed0imy3XmgUQ0NGvuY6CfrU.jpg'),
(70901, 4852, 'The Equalizer S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/229239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Zy2yN46LLNPQKqhsLdc0QPbPcn.jpg'),
(70902, 4852, 'The Equalizer S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/229240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/58JMSw8jbr3jqCT7RmyIiSw8qQg.jpg'),
(70903, 4852, 'The Equalizer S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/229241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/33dOEEWZK7VlpbbSqlPybcKnKX0.jpg'),
(70904, 4852, 'The Equalizer S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/229242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nwe8VRSqar0YvGZrMEDd5GHTXDb.jpg'),
(70905, 4852, 'The Equalizer S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/229243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4aKRCghF7966ghXwnaEyt3JJB2g.jpg'),
(70906, 4852, 'The Equalizer S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/229244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qbEgCdMGnw9kTvYwkmbjylAEeAM.jpg'),
(70907, 4853, 'The Equalizer S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/277536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n6pk5dhUoTB6gX54LaRKn6UQEVR.jpg'),
(70908, 4853, 'The Equalizer S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/288502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n6pk5dhUoTB6gX54LaRKn6UQEVR.jpg'),
(70909, 4853, 'The Equalizer S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/296694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n6pk5dhUoTB6gX54LaRKn6UQEVR.jpg'),
(70910, 4853, 'The Equalizer S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/305820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n6pk5dhUoTB6gX54LaRKn6UQEVR.jpg'),
(70911, 4853, 'The Equalizer S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/319305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n6pk5dhUoTB6gX54LaRKn6UQEVR.jpg'),
(70912, 4853, 'The Equalizer S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/703936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n6pk5dhUoTB6gX54LaRKn6UQEVR.jpg'),
(70913, 4853, 'The Equalizer S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/703937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n6pk5dhUoTB6gX54LaRKn6UQEVR.jpg'),
(70914, 4853, 'The Equalizer S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/703938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n6pk5dhUoTB6gX54LaRKn6UQEVR.jpg'),
(70915, 4853, 'The Equalizer S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/703939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n6pk5dhUoTB6gX54LaRKn6UQEVR.jpg'),
(70916, 4853, 'The Equalizer S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/703940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n6pk5dhUoTB6gX54LaRKn6UQEVR.jpg'),
(70917, 4854, 'Tudo Bem Não Ser Normal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mHHbmyrRbooFNSItNmhqVhOzvF7.jpg'),
(70918, 4854, 'Tudo Bem Não Ser Normal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6vDDppDq9STqqDRxaO4JKgSQLem.jpg'),
(70919, 4854, 'Tudo Bem Não Ser Normal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dxRYsYEcr3TUvVlt0fsOJy1Z9Sx.jpg'),
(70920, 4854, 'Tudo Bem Não Ser Normal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fa91J0GwHnpugld2euhLls4Al35.jpg'),
(70921, 4854, 'Tudo Bem Não Ser Normal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9IpJ7khguUfZRT64mCF2LkUhlYj.jpg'),
(70922, 4854, 'Tudo Bem Não Ser Normal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nX05NUUv0kp2VmO1dCUKh9PH8WH.jpg'),
(70923, 4854, 'Tudo Bem Não Ser Normal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oPqhuaBNOKBs7ncc04wEGvlYwUJ.jpg'),
(70924, 4854, 'Tudo Bem Não Ser Normal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mYuIXMqLwy6Gat1Jw18J34nqWXC.jpg'),
(70925, 4854, 'Tudo Bem Não Ser Normal S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7q9Y0cOPeDdN7BKdeSBvferE1OT.jpg'),
(70926, 4854, 'Tudo Bem Não Ser Normal S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/viVLl8Ldk9vl8jFGGnzN3XYIBXj.jpg'),
(70927, 4854, 'Tudo Bem Não Ser Normal S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kX96UutmuRI575t5AEJlBWkLQou.jpg'),
(70928, 4854, 'Tudo Bem Não Ser Normal S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8n1usOJ3PCO3IvKmAqZGdYoSxYi.jpg'),
(70929, 4854, 'Tudo Bem Não Ser Normal S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/T6CgYHeFa8tduThvnmvEt9JrVp.jpg'),
(70930, 4854, 'Tudo Bem Não Ser Normal S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXNM6tVxzpr3a0z6P1PjGUBtNmS.jpg'),
(70931, 4854, 'Tudo Bem Não Ser Normal S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/16ZpxNwsir3IDBdWpCEcqFxeCVt.jpg'),
(70932, 4854, 'Tudo Bem Não Ser Normal S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3u9LkeG5XW2kJUl8NLxQmdji9xU.jpg'),
(70933, 4855, 'Um Planeta Perfeito S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6CamZ5AUTOVKl3Ez0U68mWxyN48.jpg'),
(70934, 4855, 'Um Planeta Perfeito S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kYY9vP7Kp7XNZonzKJbvWxvAqyw.jpg'),
(70935, 4855, 'Um Planeta Perfeito S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8VntFUlyjbBf1Q0k5GZEoqXLcYZ.jpg'),
(70936, 4855, 'Um Planeta Perfeito S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/19XObQpj50yWHM0LJ541vWG6iWR.jpg'),
(70937, 4855, 'Um Planeta Perfeito S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kRkRQMkb6K8sNqN7batxt3UoAPD.jpg'),
(70938, 4856, 'Yu-Gi-Oh! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a7HrwCsZosbzHOC8F34lg1RJf05.jpg'),
(70939, 4856, 'Yu-Gi-Oh! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7m9cnAnOY4XH9J01zAuvRUoPBl9.jpg'),
(70940, 4856, 'Yu-Gi-Oh! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/UubsfHqrSEQlMM2u8q7kUfp1CI.jpg'),
(70941, 4856, 'Yu-Gi-Oh! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqecd6H4KLjTYSlUNm8dYWApwVt.jpg'),
(70942, 4856, 'Yu-Gi-Oh! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2FTdkdm9Dlte3WJWYDsQub2mtGc.jpg'),
(70943, 4856, 'Yu-Gi-Oh! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iCCkYyEoaVHYr1ZeRRcG7cxEP5K.jpg'),
(70944, 4856, 'Yu-Gi-Oh! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A0aTWkC1h5BbqFcUPSVFlmBVrnS.jpg'),
(70945, 4856, 'Yu-Gi-Oh! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5o03K7NE4G2GUxIk9Jmj72ypCLb.jpg'),
(70946, 4856, 'Yu-Gi-Oh! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPUwI57ufGh7By49wx4eEWLulTG.jpg'),
(70947, 4856, 'Yu-Gi-Oh! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zsYl08HAAcM8V9IIQ734vHRBavZ.jpg'),
(70948, 4856, 'Yu-Gi-Oh! S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mDM3101AOvA2Ev1X8HGUaiOzO3i.jpg'),
(70949, 4856, 'Yu-Gi-Oh! S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kb9q11SG77E3K7UJNNwu7Lvpot6.jpg'),
(70950, 4856, 'Yu-Gi-Oh! S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qxUwqliEhJ9lLd3BIHXUWRnZ6vB.jpg'),
(70951, 4856, 'Yu-Gi-Oh! S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w9zWeSd5E9gtzSLH2hcJyCyYNxY.jpg'),
(70952, 4856, 'Yu-Gi-Oh! S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qlVHLRUd1QNiqj969Rwht1tUEbh.jpg'),
(70953, 4856, 'Yu-Gi-Oh! S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kgUUQgJ6avbNe5q7MizL7PRUeS3.jpg'),
(70954, 4856, 'Yu-Gi-Oh! S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBF7WYzDD3J153Z9hNDfOCcQKzT.jpg'),
(70955, 4856, 'Yu-Gi-Oh! S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jlzF4966UIBCfJ4rwEU2JgBs9j8.jpg'),
(70956, 4856, 'Yu-Gi-Oh! S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/166589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4W74gxVS8MuF6Y710ZyWfqjwwlU.jpg'),
(70957, 4856, 'Yu-Gi-Oh! S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/166590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a1OJoIz2DVdwKagp0zBevBJ2zWH.jpg'),
(70958, 4856, 'Yu-Gi-Oh! S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/166591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cjiwVdgkGXk0JxeUqLgLeqeqK3v.jpg'),
(70959, 4856, 'Yu-Gi-Oh! S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/166592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n2LoU4Pobz5eqKGBZU1PVBe9yD2.jpg'),
(70960, 4856, 'Yu-Gi-Oh! S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/166593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nTrdrfhNtwmA6V66WPWFIySue09.jpg'),
(70961, 4856, 'Yu-Gi-Oh! S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/166594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rLrHOBDbynVixyCoeCWbXOQs9mZ.jpg'),
(70962, 4856, 'Yu-Gi-Oh! S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/166595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lythv9eDdqJpXsJUzCfguAc2O8e.jpg'),
(70963, 4856, 'Yu-Gi-Oh! S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/166596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gGg9vaDWBz9aIXOnRrOXtSqBsr3.jpg'),
(70964, 4856, 'Yu-Gi-Oh! S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/166597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oe50xbukPYRCBZzFDgfgJFSAVd9.jpg'),
(70965, 4856, 'Yu-Gi-Oh! S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/166598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ynYpdD4cXuPloEwaUQF4yaX71kJ.jpg'),
(70966, 4856, 'Yu-Gi-Oh! S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/166599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3kxwewZKcPcfgWkHLtcRo8lOzEe.jpg'),
(70967, 4856, 'Yu-Gi-Oh! S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/166600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zenORP3rH5kFMUIFNi5Z4oHzu97.jpg'),
(70968, 4856, 'Yu-Gi-Oh! S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/166601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fjHYyqdlqsXMXk6fHkMTa0LbYgW.jpg'),
(70969, 4856, 'Yu-Gi-Oh! S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/166602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6tIN97PxZysvHYLBFYu5f0lSbyD.jpg'),
(70970, 4856, 'Yu-Gi-Oh! S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/166603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wt06DqwF0QHLYfVtopC5bwkcHt7.jpg'),
(70971, 4856, 'Yu-Gi-Oh! S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/166604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/343TIemPDrgDXs5UGHA6TWxhJoI.jpg'),
(70972, 4856, 'Yu-Gi-Oh! S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/166605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lnQFpo2tw4Yk9Ip0ckQBmFqHg7Z.jpg'),
(70973, 4856, 'Yu-Gi-Oh! S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/166606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1oXEVsu7RtnrjAnzohHBniU9ac.jpg'),
(70974, 4856, 'Yu-Gi-Oh! S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/166607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pDlXsEss3rNUHvAXAycMvx06K9f.jpg'),
(70975, 4856, 'Yu-Gi-Oh! S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/166608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t0WrXWF9LnJOqAi3c1Il87IfKC9.jpg'),
(70976, 4856, 'Yu-Gi-Oh! S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/166609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a7itsv6z9vZc2orDxD3HuKdz4n3.jpg'),
(70977, 4856, 'Yu-Gi-Oh! S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/166610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kv0mjcPDalf3HXvjIJydSN2t10B.jpg'),
(70978, 4856, 'Yu-Gi-Oh! S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/166611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dACL52o8jvrUghxiMdMliIXes27.jpg'),
(70979, 4856, 'Yu-Gi-Oh! S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/166612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tkYjSxFUB1QMd2tqTskdapOKnGT.jpg'),
(70980, 4856, 'Yu-Gi-Oh! S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/166613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lGngbpMd0qN0evPEY5P7QTkAH1V.jpg'),
(70981, 4856, 'Yu-Gi-Oh! S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/166614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lxUipf6bXIv30yBQwBl6jxjHKrD.jpg'),
(70982, 4856, 'Yu-Gi-Oh! S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/166615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dT4HpEvhnIzus4F9fS4F3pVzVLd.jpg'),
(70983, 4856, 'Yu-Gi-Oh! S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/166616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/djqhdsOyfNjpcC09utN9euUArHX.jpg'),
(70984, 4856, 'Yu-Gi-Oh! S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/166617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z8Ek90LtZDdkb9MJYRYYz4Voz5i.jpg'),
(70985, 4856, 'Yu-Gi-Oh! S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/166618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/exF1XrzQkHCdCTwyv0mUzvnJPRD.jpg'),
(70986, 4856, 'Yu-Gi-Oh! S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/166619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rN1qms7KHbaKILW9areaumzoyUD.jpg'),
(70987, 4857, 'Yu-Gi-Oh! S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(70988, 4857, 'Yu-Gi-Oh! S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(70989, 4857, 'Yu-Gi-Oh! S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(70990, 4857, 'Yu-Gi-Oh! S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(70991, 4857, 'Yu-Gi-Oh! S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(70992, 4857, 'Yu-Gi-Oh! S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(70993, 4857, 'Yu-Gi-Oh! S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(70994, 4857, 'Yu-Gi-Oh! S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(70995, 4857, 'Yu-Gi-Oh! S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(70996, 4857, 'Yu-Gi-Oh! S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(70997, 4857, 'Yu-Gi-Oh! S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(70998, 4857, 'Yu-Gi-Oh! S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(70999, 4857, 'Yu-Gi-Oh! S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71000, 4857, 'Yu-Gi-Oh! S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71001, 4857, 'Yu-Gi-Oh! S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71002, 4857, 'Yu-Gi-Oh! S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71003, 4857, 'Yu-Gi-Oh! S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71004, 4857, 'Yu-Gi-Oh! S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71005, 4857, 'Yu-Gi-Oh! S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/166638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71006, 4857, 'Yu-Gi-Oh! S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/166639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71007, 4857, 'Yu-Gi-Oh! S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/166640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71008, 4857, 'Yu-Gi-Oh! S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/166641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71009, 4857, 'Yu-Gi-Oh! S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/166642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71010, 4857, 'Yu-Gi-Oh! S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/166643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71011, 4857, 'Yu-Gi-Oh! S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/166644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71012, 4857, 'Yu-Gi-Oh! S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/166645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71013, 4857, 'Yu-Gi-Oh! S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/166646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71014, 4857, 'Yu-Gi-Oh! S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/166647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71015, 4857, 'Yu-Gi-Oh! S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/166648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71016, 4857, 'Yu-Gi-Oh! S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/166649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71017, 4857, 'Yu-Gi-Oh! S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/166650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71018, 4857, 'Yu-Gi-Oh! S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/166651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71019, 4857, 'Yu-Gi-Oh! S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/166652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71020, 4857, 'Yu-Gi-Oh! S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/166653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71021, 4857, 'Yu-Gi-Oh! S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/166654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71022, 4857, 'Yu-Gi-Oh! S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/166655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71023, 4857, 'Yu-Gi-Oh! S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/166656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71024, 4857, 'Yu-Gi-Oh! S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/166657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71025, 4857, 'Yu-Gi-Oh! S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/166658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71026, 4857, 'Yu-Gi-Oh! S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/166659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71027, 4857, 'Yu-Gi-Oh! S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/166660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71028, 4857, 'Yu-Gi-Oh! S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/166661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71029, 4857, 'Yu-Gi-Oh! S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/166662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71030, 4857, 'Yu-Gi-Oh! S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/166663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71031, 4857, 'Yu-Gi-Oh! S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/166664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71032, 4857, 'Yu-Gi-Oh! S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/166665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71033, 4857, 'Yu-Gi-Oh! S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/166666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71034, 4857, 'Yu-Gi-Oh! S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/166667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71035, 4858, 'Yu-Gi-Oh! S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71036, 4858, 'Yu-Gi-Oh! S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71037, 4858, 'Yu-Gi-Oh! S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71038, 4858, 'Yu-Gi-Oh! S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71039, 4858, 'Yu-Gi-Oh! S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71040, 4858, 'Yu-Gi-Oh! S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71041, 4858, 'Yu-Gi-Oh! S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71042, 4858, 'Yu-Gi-Oh! S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71043, 4858, 'Yu-Gi-Oh! S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71044, 4858, 'Yu-Gi-Oh! S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71045, 4858, 'Yu-Gi-Oh! S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71046, 4858, 'Yu-Gi-Oh! S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71047, 4858, 'Yu-Gi-Oh! S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71048, 4858, 'Yu-Gi-Oh! S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71049, 4858, 'Yu-Gi-Oh! S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71050, 4858, 'Yu-Gi-Oh! S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71051, 4858, 'Yu-Gi-Oh! S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71052, 4858, 'Yu-Gi-Oh! S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71053, 4858, 'Yu-Gi-Oh! S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/166686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71054, 4858, 'Yu-Gi-Oh! S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/166687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71055, 4858, 'Yu-Gi-Oh! S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/166688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71056, 4858, 'Yu-Gi-Oh! S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/166689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71057, 4858, 'Yu-Gi-Oh! S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/166690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71058, 4858, 'Yu-Gi-Oh! S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/166691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71059, 4858, 'Yu-Gi-Oh! S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/166692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71060, 4858, 'Yu-Gi-Oh! S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/166693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71061, 4858, 'Yu-Gi-Oh! S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/166694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71062, 4858, 'Yu-Gi-Oh! S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/166695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71063, 4858, 'Yu-Gi-Oh! S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/166696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71064, 4858, 'Yu-Gi-Oh! S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/166697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71065, 4858, 'Yu-Gi-Oh! S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/166698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71066, 4858, 'Yu-Gi-Oh! S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/166699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71067, 4858, 'Yu-Gi-Oh! S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/166700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71068, 4858, 'Yu-Gi-Oh! S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/166701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71069, 4858, 'Yu-Gi-Oh! S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/166702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71070, 4858, 'Yu-Gi-Oh! S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/166703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71071, 4858, 'Yu-Gi-Oh! S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/166704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71072, 4858, 'Yu-Gi-Oh! S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/166705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71073, 4858, 'Yu-Gi-Oh! S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/166706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71074, 4858, 'Yu-Gi-Oh! S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/166707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71075, 4858, 'Yu-Gi-Oh! S03 E41', 'http://sinalprivado.info:80/series/1533784/1533784/166708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71076, 4858, 'Yu-Gi-Oh! S03 E42', 'http://sinalprivado.info:80/series/1533784/1533784/166709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71077, 4858, 'Yu-Gi-Oh! S03 E43', 'http://sinalprivado.info:80/series/1533784/1533784/166710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71078, 4858, 'Yu-Gi-Oh! S03 E44', 'http://sinalprivado.info:80/series/1533784/1533784/166711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71079, 4858, 'Yu-Gi-Oh! S03 E45', 'http://sinalprivado.info:80/series/1533784/1533784/166712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71080, 4858, 'Yu-Gi-Oh! S03 E46', 'http://sinalprivado.info:80/series/1533784/1533784/166713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71081, 4858, 'Yu-Gi-Oh! S03 E47', 'http://sinalprivado.info:80/series/1533784/1533784/166714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71082, 4859, 'Yu-Gi-Oh! S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71083, 4859, 'Yu-Gi-Oh! S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71084, 4859, 'Yu-Gi-Oh! S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71085, 4859, 'Yu-Gi-Oh! S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71086, 4859, 'Yu-Gi-Oh! S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71087, 4859, 'Yu-Gi-Oh! S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71088, 4859, 'Yu-Gi-Oh! S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71089, 4859, 'Yu-Gi-Oh! S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71090, 4859, 'Yu-Gi-Oh! S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71091, 4859, 'Yu-Gi-Oh! S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71092, 4859, 'Yu-Gi-Oh! S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71093, 4859, 'Yu-Gi-Oh! S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71094, 4859, 'Yu-Gi-Oh! S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71095, 4859, 'Yu-Gi-Oh! S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71096, 4859, 'Yu-Gi-Oh! S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71097, 4859, 'Yu-Gi-Oh! S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71098, 4859, 'Yu-Gi-Oh! S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71099, 4859, 'Yu-Gi-Oh! S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71100, 4859, 'Yu-Gi-Oh! S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/166733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71101, 4859, 'Yu-Gi-Oh! S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/166734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71102, 4859, 'Yu-Gi-Oh! S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/166735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71103, 4859, 'Yu-Gi-Oh! S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/166736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71104, 4859, 'Yu-Gi-Oh! S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/166737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71105, 4859, 'Yu-Gi-Oh! S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/166738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71106, 4859, 'Yu-Gi-Oh! S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/166739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71107, 4859, 'Yu-Gi-Oh! S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/166740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71108, 4859, 'Yu-Gi-Oh! S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/166741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71109, 4859, 'Yu-Gi-Oh! S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/166742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71110, 4859, 'Yu-Gi-Oh! S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/166743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71111, 4859, 'Yu-Gi-Oh! S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/166744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71112, 4859, 'Yu-Gi-Oh! S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/166745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71113, 4859, 'Yu-Gi-Oh! S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/166746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71114, 4859, 'Yu-Gi-Oh! S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/166747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71115, 4859, 'Yu-Gi-Oh! S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/166748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71116, 4859, 'Yu-Gi-Oh! S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/166749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71117, 4859, 'Yu-Gi-Oh! S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/166750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71118, 4859, 'Yu-Gi-Oh! S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/166751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71119, 4859, 'Yu-Gi-Oh! S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/166752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71120, 4859, 'Yu-Gi-Oh! S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/166753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71121, 4859, 'Yu-Gi-Oh! S04 E40', 'http://sinalprivado.info:80/series/1533784/1533784/166754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71122, 4860, 'Yu-Gi-Oh! S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71123, 4860, 'Yu-Gi-Oh! S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71124, 4860, 'Yu-Gi-Oh! S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71125, 4860, 'Yu-Gi-Oh! S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71126, 4860, 'Yu-Gi-Oh! S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71127, 4860, 'Yu-Gi-Oh! S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71128, 4860, 'Yu-Gi-Oh! S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71129, 4860, 'Yu-Gi-Oh! S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71130, 4860, 'Yu-Gi-Oh! S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71131, 4860, 'Yu-Gi-Oh! S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71132, 4860, 'Yu-Gi-Oh! S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71133, 4860, 'Yu-Gi-Oh! S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71134, 4860, 'Yu-Gi-Oh! S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71135, 4860, 'Yu-Gi-Oh! S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71136, 4860, 'Yu-Gi-Oh! S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71137, 4860, 'Yu-Gi-Oh! S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71138, 4860, 'Yu-Gi-Oh! S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71139, 4860, 'Yu-Gi-Oh! S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71140, 4860, 'Yu-Gi-Oh! S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/166773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71141, 4860, 'Yu-Gi-Oh! S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/166774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(71142, 4860, 'Yu-Gi-Oh! S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/166775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71143, 4860, 'Yu-Gi-Oh! S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/166776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71144, 4860, 'Yu-Gi-Oh! S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/166777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71145, 4860, 'Yu-Gi-Oh! S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/166778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71146, 4860, 'Yu-Gi-Oh! S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/166779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71147, 4860, 'Yu-Gi-Oh! S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/166780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71148, 4860, 'Yu-Gi-Oh! S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/166781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71149, 4860, 'Yu-Gi-Oh! S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/166782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71150, 4860, 'Yu-Gi-Oh! S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/166783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71151, 4860, 'Yu-Gi-Oh! S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/166784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71152, 4860, 'Yu-Gi-Oh! S05 E31', 'http://sinalprivado.info:80/series/1533784/1533784/166785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71153, 4860, 'Yu-Gi-Oh! S05 E32', 'http://sinalprivado.info:80/series/1533784/1533784/166786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71154, 4860, 'Yu-Gi-Oh! S05 E33', 'http://sinalprivado.info:80/series/1533784/1533784/166787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71155, 4860, 'Yu-Gi-Oh! S05 E34', 'http://sinalprivado.info:80/series/1533784/1533784/166788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71156, 4860, 'Yu-Gi-Oh! S05 E35', 'http://sinalprivado.info:80/series/1533784/1533784/166789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71157, 4860, 'Yu-Gi-Oh! S05 E36', 'http://sinalprivado.info:80/series/1533784/1533784/166790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71158, 4860, 'Yu-Gi-Oh! S05 E37', 'http://sinalprivado.info:80/series/1533784/1533784/166791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71159, 4860, 'Yu-Gi-Oh! S05 E38', 'http://sinalprivado.info:80/series/1533784/1533784/166792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71160, 4860, 'Yu-Gi-Oh! S05 E39', 'http://sinalprivado.info:80/series/1533784/1533784/166793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71161, 4860, 'Yu-Gi-Oh! S05 E40', 'http://sinalprivado.info:80/series/1533784/1533784/166794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71162, 4860, 'Yu-Gi-Oh! S05 E41', 'http://sinalprivado.info:80/series/1533784/1533784/166795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71163, 4860, 'Yu-Gi-Oh! S05 E42', 'http://sinalprivado.info:80/series/1533784/1533784/166796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71164, 4860, 'Yu-Gi-Oh! S05 E43', 'http://sinalprivado.info:80/series/1533784/1533784/166797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71165, 4860, 'Yu-Gi-Oh! S05 E44', 'http://sinalprivado.info:80/series/1533784/1533784/166798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71166, 4860, 'Yu-Gi-Oh! S05 E45', 'http://sinalprivado.info:80/series/1533784/1533784/166799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71167, 4860, 'Yu-Gi-Oh! S05 E46', 'http://sinalprivado.info:80/series/1533784/1533784/166800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71168, 4860, 'Yu-Gi-Oh! S05 E47', 'http://sinalprivado.info:80/series/1533784/1533784/166801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71169, 4860, 'Yu-Gi-Oh! S05 E48', 'http://sinalprivado.info:80/series/1533784/1533784/166802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71170, 4860, 'Yu-Gi-Oh! S05 E49', 'http://sinalprivado.info:80/series/1533784/1533784/166803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71171, 4860, 'Yu-Gi-Oh! S05 E50', 'http://sinalprivado.info:80/series/1533784/1533784/166804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71172, 4860, 'Yu-Gi-Oh! S05 E51', 'http://sinalprivado.info:80/series/1533784/1533784/166805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71173, 4860, 'Yu-Gi-Oh! S05 E52', 'http://sinalprivado.info:80/series/1533784/1533784/166806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDI0u6jomTQ0ZrVlrKyRJCgR3YW.jpg'),
(71174, 4861, 'A Diarista S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nD1HbJg68RaeFLZ9bAvkhPhBRyo.jpg'),
(71175, 4861, 'A Diarista S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eYgYzZYSkrwkibMeiwbQ8GHlVcj.jpg'),
(71176, 4861, 'A Diarista S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7LPuvrYSiDtvgYJSws6AopsV2Ks.jpg'),
(71177, 4861, 'A Diarista S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tdSd0tx6JnSUj1XX8WBXSOfxXpo.jpg'),
(71178, 4861, 'A Diarista S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71179, 4861, 'A Diarista S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7T21xprHxMNrxAWW1Dqhk58Ioof.jpg'),
(71180, 4861, 'A Diarista S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y60izXZlENDX3dKLrcNNNlHyHrR.jpg'),
(71181, 4861, 'A Diarista S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pwJGsRl6zAJfMemx123BRztFmzm.jpg'),
(71182, 4861, 'A Diarista S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkKrBLOpDScmdcPzynhfkv9GZFu.jpg'),
(71183, 4861, 'A Diarista S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zjAmhEt6bQstvw2j8A5he90HsIg.jpg'),
(71184, 4861, 'A Diarista S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71185, 4861, 'A Diarista S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71186, 4861, 'A Diarista S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/164380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71187, 4861, 'A Diarista S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/164381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71188, 4861, 'A Diarista S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/164382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71189, 4861, 'A Diarista S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/164383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71190, 4861, 'A Diarista S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/164384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71191, 4861, 'A Diarista S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/164385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71192, 4861, 'A Diarista S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/164386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71193, 4861, 'A Diarista S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/164387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71194, 4861, 'A Diarista S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/164388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71195, 4861, 'A Diarista S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/164389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71196, 4861, 'A Diarista S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/164390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71197, 4861, 'A Diarista S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/164391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71198, 4861, 'A Diarista S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/164392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71199, 4861, 'A Diarista S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/164393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71200, 4861, 'A Diarista S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/164394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71201, 4861, 'A Diarista S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/164395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71202, 4861, 'A Diarista S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/164396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71203, 4861, 'A Diarista S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/164397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71204, 4861, 'A Diarista S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/164398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71205, 4861, 'A Diarista S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/164399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71206, 4861, 'A Diarista S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/164400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71207, 4861, 'A Diarista S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/164401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71208, 4861, 'A Diarista S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/164402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71209, 4861, 'A Diarista S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/164403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71210, 4861, 'A Diarista S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/164404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71211, 4862, 'A Diarista S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71212, 4862, 'A Diarista S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71213, 4862, 'A Diarista S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71214, 4862, 'A Diarista S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71215, 4862, 'A Diarista S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71216, 4862, 'A Diarista S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71217, 4862, 'A Diarista S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71218, 4862, 'A Diarista S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71219, 4862, 'A Diarista S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71220, 4862, 'A Diarista S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71221, 4862, 'A Diarista S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71222, 4862, 'A Diarista S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71223, 4862, 'A Diarista S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/164417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71224, 4862, 'A Diarista S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/164418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71225, 4862, 'A Diarista S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/164419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71226, 4862, 'A Diarista S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/164420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71227, 4862, 'A Diarista S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/164421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71228, 4862, 'A Diarista S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/164422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71229, 4862, 'A Diarista S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/164423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71230, 4862, 'A Diarista S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/164424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71231, 4862, 'A Diarista S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/164425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71232, 4862, 'A Diarista S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/164426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71233, 4862, 'A Diarista S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/164427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71234, 4862, 'A Diarista S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/164428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71235, 4862, 'A Diarista S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/164429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71236, 4862, 'A Diarista S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/164430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71237, 4862, 'A Diarista S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/164431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71238, 4862, 'A Diarista S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/164432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71239, 4862, 'A Diarista S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/164433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71240, 4862, 'A Diarista S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/164434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71241, 4862, 'A Diarista S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/164435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71242, 4862, 'A Diarista S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/164436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71243, 4862, 'A Diarista S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/164437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71244, 4862, 'A Diarista S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/164438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71245, 4862, 'A Diarista S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/164439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71246, 4862, 'A Diarista S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/164440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71247, 4863, 'A Diarista S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3eBd9x04H9VdOhp4OufQo4CCNUX.jpg'),
(71248, 4863, 'A Diarista S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qrWwppJ3wchTkfmvkN1Wldbt35O.jpg'),
(71249, 4863, 'A Diarista S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k2we48wari6Zs4awalPPzlW4WwX.jpg'),
(71250, 4863, 'A Diarista S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tOf32RXlTlOnmXmzgZe8x25bcJu.jpg'),
(71251, 4863, 'A Diarista S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9njDjrjgDQm5dXmgwPQ4CKkpIDW.jpg'),
(71252, 4863, 'A Diarista S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/CvA6vUgOnrcJ2ZNcAq7dnnGivw.jpg'),
(71253, 4863, 'A Diarista S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/44QW4bwTRaBYhAi2EQCGcTqFftJ.jpg'),
(71254, 4863, 'A Diarista S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wUMvJqT9Mk0i4gzCHZJ1IzdR6Ax.jpg'),
(71255, 4863, 'A Diarista S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k6LgfyMUwr01fAXhtPpp0QJ4l71.jpg'),
(71256, 4863, 'A Diarista S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wgXrpILcxvclc5uaWdt9fmUUEdO.jpg'),
(71257, 4863, 'A Diarista S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/arizobGXyCduXjDSaC1pLksDm8X.jpg'),
(71258, 4863, 'A Diarista S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OLprfUGMVbnCqn5PnG5GvVJTqt.jpg'),
(71259, 4863, 'A Diarista S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/164453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7GmtE4wQluhZOmQ5TBidpNKepMy.jpg'),
(71260, 4863, 'A Diarista S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/164454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sW5eSfxutG8GHXv6SnK6aOXYd55.jpg'),
(71261, 4863, 'A Diarista S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/164455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Uj0gZN1qIwjPAOs0XNjccN3xpb.jpg'),
(71262, 4863, 'A Diarista S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/164456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qTIYXjp2M6VntqDMDiunvtgvvGg.jpg'),
(71263, 4863, 'A Diarista S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/164457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7yMQO3VJ0UbssbeE1jtXz8n7L2l.jpg'),
(71264, 4863, 'A Diarista S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/164458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xrsqRXCBXDparleRl3x9za6Vt8K.jpg'),
(71265, 4863, 'A Diarista S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/164459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/25ImmZoqF9JccURIybn5c8sbNPL.jpg'),
(71266, 4863, 'A Diarista S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/164460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7tfOTBYuD7bpa1HCQnBO5Aho4SI.jpg'),
(71267, 4863, 'A Diarista S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/164461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hu9loNdyY36UfEt6vbrZ5ZpEAin.jpg'),
(71268, 4863, 'A Diarista S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/164462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhdF9Lw5XT4Cob9vQkJtYJgCaCf.jpg'),
(71269, 4863, 'A Diarista S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/164463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2Y0HpE7NSvMuGBC8WX9Svli1MW.jpg'),
(71270, 4863, 'A Diarista S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/164464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4m6HbWcEuuqztmJawMqp85uMMQA.jpg'),
(71271, 4863, 'A Diarista S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/164465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/avWIOomPQ8tuUugMyeV9La1Ivga.jpg'),
(71272, 4863, 'A Diarista S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/164466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iZzTgT1oeGoeugJmEqa1zko4ZEh.jpg'),
(71273, 4863, 'A Diarista S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/164467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tOjENkKTePrVVcsuO60K2QHkzkp.jpg'),
(71274, 4863, 'A Diarista S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/164468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q5MDxFmFHNWwb7bUR2QhG8CRBav.jpg'),
(71275, 4863, 'A Diarista S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/164469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ckGJ3gbZZLUyJMuFFomusANztUK.jpg'),
(71276, 4863, 'A Diarista S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/164470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vG0HBkTVdoEY6Gb9M2CAEO0BZYh.jpg'),
(71277, 4863, 'A Diarista S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/164471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfC5c3vYEr0gNXz1eKjBN1vedGl.jpg'),
(71278, 4864, 'A Diarista S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jaI4AxAj4BnKDQZIXPbA9BImZGF.jpg'),
(71279, 4864, 'A Diarista S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4bEWiDEJTgt51RpU9MYMqyehkVc.jpg'),
(71280, 4864, 'A Diarista S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCOBQN8CIwhku1ZNDb5OLMholqF.jpg'),
(71281, 4864, 'A Diarista S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nkZ2cJfvMKLBu3RNCgzInjLnY2n.jpg'),
(71282, 4864, 'A Diarista S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9MKvSu8iHEhYXilEJSTiyKZCtkX.jpg'),
(71283, 4864, 'A Diarista S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6sLdfLRMoG6HgRYlJaSKnJgTvRW.jpg'),
(71284, 4864, 'A Diarista S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqFXY3FTGqoWGm2TwBGkAYPS8Av.jpg'),
(71285, 4864, 'A Diarista S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/scVqzs6p5CqfbPMJp3S4RQGj0po.jpg'),
(71286, 4864, 'A Diarista S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ulYW78VBaSroZzmVIZEjCY6GKeH.jpg'),
(71287, 4864, 'A Diarista S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wqr8KAFL8CW6IRTTgAtwKFtI5pW.jpg'),
(71288, 4864, 'A Diarista S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6h8dwzgAMLfwi0ZtHPkJ5yALCY3.jpg'),
(71289, 4864, 'A Diarista S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mLTtioyapmxwXSga9PNQdTg3x6R.jpg'),
(71290, 4864, 'A Diarista S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/164484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cBgv0tmlYKiyhwfbx15OsFe8dMZ.jpg'),
(71291, 4864, 'A Diarista S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/164485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dlKbGGTbSygo6IhmwTsB4RDIXXi.jpg'),
(71292, 4864, 'A Diarista S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/164486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oZBczD3fofoUlQZILHPz5FJ366L.jpg'),
(71293, 4865, 'A Grande Corrida: Volta ao Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dUVQYxxofUoYrXXRWhjhSe3aYEX.jpg'),
(71294, 4865, 'A Grande Corrida: Volta ao Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kF40BdSV2tDgwWRz2GqVOPpuS2F.jpg'),
(71295, 4865, 'A Grande Corrida: Volta ao Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iXQAttJH5VPOLxNGfvhQ2h1pH4W.jpg'),
(71296, 4865, 'A Grande Corrida: Volta ao Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1JT6LkBRPPsDzrGEKHqAZ2mN2RA.jpg'),
(71297, 4865, 'A Grande Corrida: Volta ao Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mxQuKilJ9MeP6vZlhDhUUYyvI1F.jpg'),
(71298, 4865, 'A Grande Corrida: Volta ao Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d6c1fn38pYen2z6Xco0IztxNggH.jpg'),
(71299, 4866, 'A Linha Invisível S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vfEF6iHm6uewd2JPsIsgPcJSevW.jpg'),
(71300, 4866, 'A Linha Invisível S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rhDYRdkSpFOe1qMUlyUPupATFd.jpg'),
(71301, 4866, 'A Linha Invisível S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eVuUNwcBovsmpp7KltH9sVKfUKv.jpg'),
(71302, 4866, 'A Linha Invisível S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170565.mp4', 'http://image.tmdb.org/t/p/w1280/ygXoAW0wPJ4Xr8nxSmyuV58YiRj.jpg'),
(71303, 4866, 'A Linha Invisível S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170566.mp4', 'http://image.tmdb.org/t/p/w1280/hBiCDI368F79lRN4glkvvaQ2zCg.jpg'),
(71304, 4866, 'A Linha Invisível S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170567.mp4', 'http://image.tmdb.org/t/p/w1280/twVuIHFi0TlcacNwkBYr7nHBokc.jpg'),
(71305, 4867, 'Arranjo de Natal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBrNYtZF9DITVzajwYrPOP16hpG.jpg'),
(71306, 4867, 'Arranjo de Natal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iDxYTllBG2ANjFmVlqOG2Lnt4Ge.jpg'),
(71307, 4867, 'Arranjo de Natal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cRrNpBXagJsnHYm4Ym4hYpk4rZT.jpg'),
(71308, 4868, 'Chesapeake Shores S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bJv0IWFad1VGm1Yp7ctGP4XIORm.jpg'),
(71309, 4868, 'Chesapeake Shores S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gKEgR8vtixlmnh2e8YnaZ0CJcnD.jpg'),
(71310, 4868, 'Chesapeake Shores S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oJ2cZlwWHEpk7G2dUBmb2nzJuam.jpg'),
(71311, 4868, 'Chesapeake Shores S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jlwvSHujZHnkJ1pzCa7INBQzP3O.jpg'),
(71312, 4868, 'Chesapeake Shores S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/LrXxsWXbosRguHJnC8LSzd7dAL.jpg'),
(71313, 4868, 'Chesapeake Shores S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4zX0d6hz8cG2uHnOiVA19SXIRsr.jpg'),
(71314, 4868, 'Chesapeake Shores S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bQEsnqYV86cc6vTrr4oOKnz39cO.jpg'),
(71315, 4868, 'Chesapeake Shores S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7GU9l4B6QXm7QbqVmgF4wB02ZXl.jpg'),
(71316, 4868, 'Chesapeake Shores S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/YufCBveQLrOiCDK7uJSQivTmH4.jpg'),
(71317, 4868, 'Chesapeake Shores S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dvZ6JDw8onWJJyV2Cq2YGbeZFPM.jpg'),
(71318, 4869, 'Chesapeake Shores S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fw9Clp4ruQxo0cYhZM5vVrJciEx.jpg'),
(71319, 4869, 'Chesapeake Shores S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qtvCK58Rk7GgbJ0zoLO52FIbUG5.jpg'),
(71320, 4869, 'Chesapeake Shores S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/CdC7VljcCpXeYGFcPbDlNQYoTc.jpg'),
(71321, 4869, 'Chesapeake Shores S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gWeZwkqJ10b15J2tNJUDVcFEheU.jpg'),
(71322, 4869, 'Chesapeake Shores S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d52XhsHnVAar2Joo90V4PrJu5UD.jpg'),
(71323, 4869, 'Chesapeake Shores S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sVrBD7XmLk8qBgYWYIYONxdGJ9y.jpg'),
(71324, 4869, 'Chesapeake Shores S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xvHDuD5yaMvE4D5qkh4wW0t2umC.jpg'),
(71325, 4869, 'Chesapeake Shores S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xMxTyMwssr2qN8sgvG1PokEQiKH.jpg'),
(71326, 4869, 'Chesapeake Shores S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e2UMFUIN1U60AbSYDuVYqQxXY8J.jpg'),
(71327, 4869, 'Chesapeake Shores S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mjTVDSGqktwdDNutEL0pbujINAo.jpg'),
(71328, 4870, 'Chesapeake Shores S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aM2FZpNa3cIVNArv9bE4V1DrsO9.jpg'),
(71329, 4870, 'Chesapeake Shores S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/79QkDweVZFboaoQHPXSB6EwvOC3.jpg'),
(71330, 4870, 'Chesapeake Shores S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xh0yWW2t7pb3FFCobOFUUgXkbld.jpg'),
(71331, 4870, 'Chesapeake Shores S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zcyNO6DQ4cmMfv2VeEeyx1VH7TD.jpg'),
(71332, 4870, 'Chesapeake Shores S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vmRqatVIJhHsHzms6NExpKMtYfX.jpg'),
(71333, 4870, 'Chesapeake Shores S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8xOAc8CjoydmQszmQlDInMuOp1f.jpg'),
(71334, 4870, 'Chesapeake Shores S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9iR0TUoDgIGh62D124oVZfLztbM.jpg'),
(71335, 4870, 'Chesapeake Shores S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfNfy5LjSX2RmwrZHyfWl7Z3jPf.jpg'),
(71336, 4870, 'Chesapeake Shores S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dcv8JdFe3HydhX09YBH68aRHlDt.jpg'),
(71337, 4870, 'Chesapeake Shores S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5cUE01iV4SWKWJiIvniU53LeOeL.jpg'),
(71338, 4871, 'Chesapeake Shores S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mFCAlYBSwLgh7k7wuMVbL3aEPFp.jpg'),
(71339, 4871, 'Chesapeake Shores S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ZWjlfM7aaD1FXKGrzUhB9Wt0d8.jpg'),
(71340, 4871, 'Chesapeake Shores S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jxyifQeKZZNrkozZOumxc1d51Qw.jpg'),
(71341, 4871, 'Chesapeake Shores S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yuhpJcIXz51LpV1bsg1ddIp7maD.jpg'),
(71342, 4871, 'Chesapeake Shores S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3B9WNa57Xp9LAiwGNtjJSETFR6T.jpg'),
(71343, 4871, 'Chesapeake Shores S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AaaNi5vOxHevPe4zNswAvBo0PdQ.jpg'),
(71344, 4872, 'Chesapeake Shores S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUuNs59BtjdiABqzG7XT5MIHiTA.jpg'),
(71345, 4872, 'Chesapeake Shores S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kOCBdD5yVsuFyvf19mzXA2tTcYz.jpg'),
(71346, 4872, 'Chesapeake Shores S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5iebqu8I57A96qfnAjl1mxxLDhA.jpg'),
(71347, 4872, 'Chesapeake Shores S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iR0CuxqrpJ5Oa4LtiWCePlV7YET.jpg'),
(71348, 4872, 'Chesapeake Shores S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nBsXJlJeQdtaeUjvdhusxdLex5G.jpg'),
(71349, 4872, 'Chesapeake Shores S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2u7nge6elw7Wn5DAKlhYtWVmF8g.jpg'),
(71350, 4872, 'Chesapeake Shores S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aNO8vChzaHX76rNWPbaz5q7gEzW.jpg'),
(71351, 4872, 'Chesapeake Shores S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wWF7SkG6GAf4qk9VcqMDMlrPSm8.jpg'),
(71352, 4872, 'Chesapeake Shores S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ylN7CVlGijYzM8aOALMSnfY3OH.jpg'),
(71353, 4872, 'Chesapeake Shores S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zDA9HH804ZEakWSm2JgpexdQjMF.jpg'),
(71354, 4873, 'Chesapeake Shores S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195783.mp4', 'http://timg.bdta.pro/images/a3a30529dbe244ddf18e392782f891ef.jpg'),
(71355, 4873, 'Chesapeake Shores S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195784.mp4', 'http://timg.bdta.pro/images/60089301ff294e35e07bbd4badb5f13e.jpg'),
(71356, 4873, 'Chesapeake Shores S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195785.mp4', 'http://timg.bdta.pro/images/3d003de2fd4da5be741e89dd758a2277.jpg'),
(71357, 4873, 'Chesapeake Shores S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195786.mp4', 'http://timg.bdta.pro/images/606af414a535115ed4d92cc9f215a395.jpg'),
(71358, 4873, 'Chesapeake Shores S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195787.mp4', 'http://timg.bdta.pro/images/107fce2d6f03afb8bbd2edb9d7c3cff2.jpg'),
(71359, 4873, 'Chesapeake Shores S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195788.mp4', 'http://timg.bdta.pro/images/cd5ed7b59eb0d15aa667ce062389e20b.jpg'),
(71360, 4873, 'Chesapeake Shores S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195789.mp4', 'http://timg.bdta.pro/images/a78be5c1d6edfdede54aa65c29bd4cb1.jpg'),
(71361, 4873, 'Chesapeake Shores S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195790.mp4', 'http://timg.bdta.pro/images/90d67e3d74c60f57b2b103b4fb03fcf5.jpg'),
(71362, 4873, 'Chesapeake Shores S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dvZ6JDw8onWJJyV2Cq2YGbeZFPM.jpg'),
(71363, 4873, 'Chesapeake Shores S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195792.mp4', 'http://timg.bdta.pro/images/a58dab6d5818c0dbf7194950c6729aa9.jpg'),
(71364, 4874, 'Cowboy Bebop S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eWlqUH2JJ9mKmLF4uRX4QDp4klh.jpg'),
(71365, 4874, 'Cowboy Bebop S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u4kv86ktto5tkiA5o4zubV5jROX.jpg'),
(71366, 4874, 'Cowboy Bebop S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97x7RgRtyC2TPr8ngIGL5Pj7SMA.jpg'),
(71367, 4874, 'Cowboy Bebop S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/49K0ljHV0tXCiMih7cyf7u5huPF.jpg'),
(71368, 4874, 'Cowboy Bebop S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4J29udWoHMKg9EqlUVCrvv3OL2J.jpg'),
(71369, 4874, 'Cowboy Bebop S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aPxX0yCS40b0Rh67QBa1q1hQpkd.jpg'),
(71370, 4874, 'Cowboy Bebop S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgvz51A4QzHomoJuDqtapjrx4xn.jpg'),
(71371, 4874, 'Cowboy Bebop S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/88O5Tg6nwrlhQbkWKpVAvOy6xCC.jpg'),
(71372, 4875, 'Entre Laços S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ruf6aDDuZ4nbg32gOZF43Om6tj5.jpg'),
(71373, 4875, 'Entre Laços S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fs0xR9Ml6GlZDWAYYB9JU7m4uje.jpg'),
(71374, 4875, 'Entre Laços S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/viyz9OIjNuVYUAtx0nX9CAeKX8W.jpg'),
(71375, 4875, 'Entre Laços S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/enhV61VQjS7HOSh4MAPSpS7wHWR.jpg'),
(71376, 4875, 'Entre Laços S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6rZkQqzib4LJIh7VweHESw3KXyn.jpg'),
(71377, 4875, 'Entre Laços S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7hjKQvlCD9NGoNiIb2taFNCT9QE.jpg'),
(71378, 4875, 'Entre Laços S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63tYgiX5R2eVAmJBTQL4F217XCs.jpg'),
(71379, 4875, 'Entre Laços S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCBEdnWzPWFyTYQjVL3WqAlK1pn.jpg'),
(71380, 4875, 'Entre Laços S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sMxyA64DrMJcfU0IiG3cP61YDN7.jpg'),
(71381, 4875, 'Entre Laços S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4rszE5YXU2MsVFTar6d2LI69X1A.jpg'),
(71382, 4876, 'Entrelinhas Pontilhadas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lFyhFLQiekxP13Ed3uZA08qPOXU.jpg'),
(71383, 4876, 'Entrelinhas Pontilhadas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ppqhG5RCAVYyqU9oFWqzd1j9tqE.jpg'),
(71384, 4876, 'Entrelinhas Pontilhadas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ag71X8jaGLj2D6LOnasEIntAU3g.jpg'),
(71385, 4876, 'Entrelinhas Pontilhadas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mwLL5WN6hGNdFkle6J7uBiPhh0u.jpg'),
(71386, 4876, 'Entrelinhas Pontilhadas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zXNqCRNGRO28VHxj9bSjr7Qg0EY.jpg'),
(71387, 4876, 'Entrelinhas Pontilhadas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tL650OFzISVrERyYIYsftR7yZbM.jpg'),
(71388, 4877, 'Farejando Novos Mundos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9LauQBP7Mr1rygGSJ7mr7QJt7eq.jpg'),
(71389, 4877, 'Farejando Novos Mundos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vjylqp5Le8ZalQ9kAS4f58FgmWF.jpg'),
(71390, 4877, 'Farejando Novos Mundos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vjylqp5Le8ZalQ9kAS4f58FgmWF.jpg'),
(71391, 4877, 'Farejando Novos Mundos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vjylqp5Le8ZalQ9kAS4f58FgmWF.jpg'),
(71392, 4877, 'Farejando Novos Mundos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vjylqp5Le8ZalQ9kAS4f58FgmWF.jpg'),
(71393, 4877, 'Farejando Novos Mundos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vjylqp5Le8ZalQ9kAS4f58FgmWF.jpg'),
(71394, 4877, 'Farejando Novos Mundos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vjylqp5Le8ZalQ9kAS4f58FgmWF.jpg'),
(71395, 4877, 'Farejando Novos Mundos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vjylqp5Le8ZalQ9kAS4f58FgmWF.jpg'),
(71396, 4877, 'Farejando Novos Mundos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vjylqp5Le8ZalQ9kAS4f58FgmWF.jpg'),
(71397, 4877, 'Farejando Novos Mundos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vjylqp5Le8ZalQ9kAS4f58FgmWF.jpg'),
(71398, 4878, 'Feyenoord: Por Dentro do Time S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/setBWiseYF7bbnnnoH3zBIQx32n.jpg'),
(71399, 4878, 'Feyenoord: Por Dentro do Time S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AgQjXiSdBQcgC0XprfYT3rolEUi.jpg'),
(71400, 4878, 'Feyenoord: Por Dentro do Time S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zuGjkAB9d5jCwQlQvqgTLzxwCYS.jpg'),
(71401, 4878, 'Feyenoord: Por Dentro do Time S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gxudkM8vVuCLamHzgEzAYYIJTH9.jpg'),
(71402, 4878, 'Feyenoord: Por Dentro do Time S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wDLMyo0trAZ5RmdsjgV7KhQ95wC.jpg'),
(71403, 4878, 'Feyenoord: Por Dentro do Time S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cOrSzaCsT3Ahozqv3wIpmaV0hvB.jpg'),
(71404, 4878, 'Feyenoord: Por Dentro do Time S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sLiq6L8TJ7m9sVRUotbC4sB9Wft.jpg'),
(71405, 4878, 'Feyenoord: Por Dentro do Time S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5bIhPE1LXffYq9vLdGchEh9eqs5.jpg'),
(71406, 4878, 'Feyenoord: Por Dentro do Time S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bpitUq0qmoieVTdDSbln4ja8ook.jpg'),
(71407, 4879, 'Kevin Pode Esperar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mNfZBAChkjnW6RSRO4AGlw3684J.jpg'),
(71408, 4879, 'Kevin Pode Esperar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pD9o1aVDtln866wJlfYV1qlTNhL.jpg'),
(71409, 4879, 'Kevin Pode Esperar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Av1KdEvGRN7ffyO26C9wh3rDuh.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(71410, 4879, 'Kevin Pode Esperar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2rcTz7WXrlrovyV2RO8MGOmDfPa.jpg'),
(71411, 4879, 'Kevin Pode Esperar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uAC36Cet50azCS2VkjO5jsmsj5.jpg'),
(71412, 4879, 'Kevin Pode Esperar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8OlCRz3a2tBBWfaO9gEEWiTbrcY.jpg'),
(71413, 4879, 'Kevin Pode Esperar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2PiXWNKvY5ZrJIAbDKC8JijVPVa.jpg'),
(71414, 4879, 'Kevin Pode Esperar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kLIVIT0dszPgiWddVVyx1rN5rGG.jpg'),
(71415, 4879, 'Kevin Pode Esperar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Xh3qSe7PpXxEi5xkD96Td2XVc0.jpg'),
(71416, 4879, 'Kevin Pode Esperar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hnlQ5doNGBUFtZjuooyM0J80KDP.jpg'),
(71417, 4879, 'Kevin Pode Esperar S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v09IzN61eYhvU88FoN3xFTnVyCc.jpg'),
(71418, 4879, 'Kevin Pode Esperar S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3NysMyc8t9SAnV76kQsFX0rFexb.jpg'),
(71419, 4879, 'Kevin Pode Esperar S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kkeFdauGqn1QMCZFmv2d8XNaHra.jpg'),
(71420, 4879, 'Kevin Pode Esperar S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b81LaXmuJ7xT2xr1iIx2iFXcKQ1.jpg'),
(71421, 4879, 'Kevin Pode Esperar S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7MDYJSsVp9rFlp3fF6cwORWaGUE.jpg'),
(71422, 4879, 'Kevin Pode Esperar S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zyFHH7acuyU2WuHO8OS4Z73Hlxx.jpg'),
(71423, 4879, 'Kevin Pode Esperar S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1DzPcjzmApSvR1uPF5FZLuqt56H.jpg'),
(71424, 4879, 'Kevin Pode Esperar S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xFAYKi6KRbeoRJCqX7or3AF282E.jpg'),
(71425, 4879, 'Kevin Pode Esperar S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/166489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gdt20FNT3EvFOGU64JBbfknurWa.jpg'),
(71426, 4879, 'Kevin Pode Esperar S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/166490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fec3dMqdXiFMB2ZLMh6nfpRePzy.jpg'),
(71427, 4879, 'Kevin Pode Esperar S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/166491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gMQkUJXsxLLaQu7Lot1qRJhotfG.jpg'),
(71428, 4879, 'Kevin Pode Esperar S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/166492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tPYX3UJna92fyci6nkCfcUMtBQP.jpg'),
(71429, 4879, 'Kevin Pode Esperar S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/166493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/se5gpcXHcs8CCml44UPpmj6Gj4c.jpg'),
(71430, 4879, 'Kevin Pode Esperar S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/166494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eNh1blWqbJB1KPBrrZ6RZXvBDGv.jpg'),
(71431, 4880, 'Kevin Pode Esperar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ivps5A35fZveneBQ1ZPahDweAza.jpg'),
(71432, 4880, 'Kevin Pode Esperar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bq90kWSE0LZdocCzXi8h93ob390.jpg'),
(71433, 4880, 'Kevin Pode Esperar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/powydQziDJSQnSWFhTVJomdetLq.jpg'),
(71434, 4880, 'Kevin Pode Esperar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2zwB3yl5afbrw7CgHdZ3xVmbNJd.jpg'),
(71435, 4880, 'Kevin Pode Esperar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5b4l0ryDe0l4XcxMWiNzsZHrcAA.jpg'),
(71436, 4880, 'Kevin Pode Esperar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n8bIgheY3fTv34bkMBDyG6GVXrZ.jpg'),
(71437, 4880, 'Kevin Pode Esperar S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/X735sJOpr86W0LhxOx9m2pgWKf.jpg'),
(71438, 4880, 'Kevin Pode Esperar S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/naFHVVCfix1iRG5MXBe9sVAkya3.jpg'),
(71439, 4880, 'Kevin Pode Esperar S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shWyYWa6U0W7b4cbDQlLspCF72e.jpg'),
(71440, 4880, 'Kevin Pode Esperar S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tM1M2UEoqEuuyLMeJTKxUMLW7aE.jpg'),
(71441, 4880, 'Kevin Pode Esperar S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hWuSiUmoPhdhorgKVgOeGsI1feH.jpg'),
(71442, 4880, 'Kevin Pode Esperar S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1CVirFSBTxOhuP8lDXgqZvAcsjK.jpg'),
(71443, 4880, 'Kevin Pode Esperar S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uDP9bdvmzFgGqOdWWKTHckZECeS.jpg'),
(71444, 4880, 'Kevin Pode Esperar S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/scNELpbnWohdmGuiYxODTPghXgR.jpg'),
(71445, 4880, 'Kevin Pode Esperar S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ZjQzfUDsPUJX0LTcvaR3hprrSd.jpg'),
(71446, 4880, 'Kevin Pode Esperar S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zibdu2mkK5opr7LyLUrL5YdAjk4.jpg'),
(71447, 4880, 'Kevin Pode Esperar S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/epF4nheyCQyowCuQcfZ54eNQkr6.jpg'),
(71448, 4880, 'Kevin Pode Esperar S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/juq7S6zuooO0yHTv50vhqJ5Dm2Z.jpg'),
(71449, 4880, 'Kevin Pode Esperar S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/166513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybo7pHrOLWOzK3UdfrblIQCKShE.jpg'),
(71450, 4880, 'Kevin Pode Esperar S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/166514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eZCiq5DjPHucLW9cJiXTby7LPFO.jpg'),
(71451, 4880, 'Kevin Pode Esperar S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/166515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yiPQ3tSx5ALa7Y6NJWWfP4WQ75i.jpg'),
(71452, 4880, 'Kevin Pode Esperar S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/166516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a8PfFMoPflZEfnjxdnfIER3Pqxc.jpg'),
(71453, 4880, 'Kevin Pode Esperar S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/166517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4JJGi3h3Sv2Rp2BdmPSnz0uRQlr.jpg'),
(71454, 4880, 'Kevin Pode Esperar S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/166518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p74MHg8E20BL0oO941ZjBNzq4kr.jpg'),
(71455, 4881, 'o Assassino do Zodíaco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uBfm0zJWAZBLWiAesZaJX34ZAkg.jpg'),
(71456, 4881, 'o Assassino do Zodíaco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bdbem8k8yGkzzcp7q2u2oqDuTvi.jpg'),
(71457, 4881, 'o Assassino do Zodíaco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iw0YZebBa4rKNooE59IOxTWRFtQ.jpg'),
(71458, 4881, 'o Assassino do Zodíaco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMRhGPze1CaakQ5OI7cHlCD7X5b.jpg'),
(71459, 4882, 'Music Box S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/49p1mYv73Gn3WE6ch1gMR7SzWVG.jpg'),
(71460, 4883, 'O psiquiatra ao lado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tulBo2D7cCV4HceDuGn1brOarWL.jpg'),
(71461, 4883, 'O psiquiatra ao lado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Q0oToX1IcwMsqsyPlGWdWOrb0R.jpg'),
(71462, 4883, 'O psiquiatra ao lado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5yp4PdGtr3xm6ARYjWKfwHucl0s.jpg'),
(71463, 4883, 'O psiquiatra ao lado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171598.mp4', 'http://image.tmdb.org/t/p/w1280/jzdDCjN2ljL1yzlxHeVJUsEeLXj.jpg'),
(71464, 4883, 'O psiquiatra ao lado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171599.mp4', 'http://image.tmdb.org/t/p/w1280/q38b1UkqkcIjqSATBrxBO8ROfQP.jpg'),
(71465, 4883, 'O psiquiatra ao lado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171600.mp4', 'http://image.tmdb.org/t/p/w1280/ipkkn2DzDMLCSoKJRCJPSglYVoH.jpg'),
(71466, 4883, 'O psiquiatra ao lado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171601.mp4', 'http://image.tmdb.org/t/p/w1280/kkqZUletfShLvOGxErbmYFzkmKC.jpg'),
(71467, 4883, 'O psiquiatra ao lado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171602.mp4', 'http://image.tmdb.org/t/p/w1280/zSmp9QbrormU4NM7K1q6gCY11po.jpg'),
(71468, 4884, 'Onision - Abuso na Internet S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n7yFNwp75GkJC2Agr8EcIuLe49e.jpg'),
(71469, 4884, 'Onision - Abuso na Internet S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AhmAHqz9KiOPzn7URGvUdzqAJ9T.jpg'),
(71470, 4884, 'Onision - Abuso na Internet S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUYrfOMO10ckWkBNGprhb0rkcHB.jpg'),
(71471, 4884, 'Onision - Abuso na Internet S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cu8oZBQVmxIH8GXBtAXfvn56pSH.jpg'),
(71472, 4885, 'Operação Fronteira: América do Sul S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xFUFhZIOzM4cszc1ExCostCbAGX.jpg'),
(71473, 4885, 'Operação Fronteira: América do Sul S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xFUFhZIOzM4cszc1ExCostCbAGX.jpg'),
(71474, 4885, 'Operação Fronteira: América do Sul S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xFUFhZIOzM4cszc1ExCostCbAGX.jpg'),
(71475, 4885, 'Operação Fronteira: América do Sul S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xFUFhZIOzM4cszc1ExCostCbAGX.jpg'),
(71476, 4885, 'Operação Fronteira: América do Sul S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xFUFhZIOzM4cszc1ExCostCbAGX.jpg'),
(71477, 4885, 'Operação Fronteira: América do Sul S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xFUFhZIOzM4cszc1ExCostCbAGX.jpg'),
(71478, 4885, 'Operação Fronteira: América do Sul S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xFUFhZIOzM4cszc1ExCostCbAGX.jpg'),
(71479, 4885, 'Operação Fronteira: América do Sul S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xFUFhZIOzM4cszc1ExCostCbAGX.jpg'),
(71480, 4885, 'Operação Fronteira: América do Sul S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xFUFhZIOzM4cszc1ExCostCbAGX.jpg'),
(71481, 4885, 'Operação Fronteira: América do Sul S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xFUFhZIOzM4cszc1ExCostCbAGX.jpg'),
(71482, 4885, 'Operação Fronteira: América do Sul S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/166452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xFUFhZIOzM4cszc1ExCostCbAGX.jpg'),
(71483, 4885, 'Operação Fronteira: América do Sul S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/166453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xFUFhZIOzM4cszc1ExCostCbAGX.jpg'),
(71484, 4885, 'Operação Fronteira: América do Sul S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/166454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xFUFhZIOzM4cszc1ExCostCbAGX.jpg'),
(71485, 4885, 'Operação Fronteira: América do Sul S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/166455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xFUFhZIOzM4cszc1ExCostCbAGX.jpg'),
(71486, 4885, 'Operação Fronteira: América do Sul S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/166456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xFUFhZIOzM4cszc1ExCostCbAGX.jpg'),
(71487, 4885, 'Operação Fronteira: América do Sul S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/166457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xFUFhZIOzM4cszc1ExCostCbAGX.jpg'),
(71488, 4885, 'Operação Fronteira: América do Sul S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/166458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xFUFhZIOzM4cszc1ExCostCbAGX.jpg'),
(71489, 4885, 'Operação Fronteira: América do Sul S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/166459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xFUFhZIOzM4cszc1ExCostCbAGX.jpg'),
(71490, 4885, 'Operação Fronteira: América do Sul S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/166460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xFUFhZIOzM4cszc1ExCostCbAGX.jpg'),
(71491, 4885, 'Operação Fronteira: América do Sul S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/166461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xFUFhZIOzM4cszc1ExCostCbAGX.jpg'),
(71492, 4886, 'Parot S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/25tLLdhgl9DLy244XurXWKhgEej.jpg'),
(71493, 4886, 'Parot S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dnpFxIJHO9pvpYvLtzBLJKr7E1o.jpg'),
(71494, 4886, 'Parot S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/osFfYuMiGo1AU1F5s7MRmGd7iyy.jpg'),
(71495, 4886, 'Parot S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqwZNcj5nPKotgiwSnB1VJeGbkx.jpg'),
(71496, 4886, 'Parot S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aYmIyb0o5PnhOelyoAmO0ojhij0.jpg'),
(71497, 4886, 'Parot S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9w9T1CXYZXd9frqsY8tvHAaZ4h9.jpg'),
(71498, 4886, 'Parot S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lkbux3jGXVRBwj5aDvnH6oNK9LW.jpg'),
(71499, 4886, 'Parot S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5c3M04TxpweIt4712Fis5QNOOFs.jpg'),
(71500, 4886, 'Parot S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bNcEsGCGWAMZdfgL8aWhiCppob9.jpg'),
(71501, 4886, 'Parot S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5RDND6Fsq7d7p7HCEqDUbK0unOM.jpg'),
(71502, 4887, 'Profecia do Inferno S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c28wngerlJ7MM0ocYjX1dzwueH0.jpg'),
(71503, 4887, 'Profecia do Inferno S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iYGMucvbhqz88F1FC3ttBHiq0mB.jpg'),
(71504, 4887, 'Profecia do Inferno S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/os9bLyU35xZlOQkcA6Ee2T2Rein.jpg'),
(71505, 4887, 'Profecia do Inferno S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zRge9nmPBBhkfsVwmJpNhLEBU1f.jpg'),
(71506, 4887, 'Profecia do Inferno S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6G6tvlxcctuVVk6YXUmEcvmioBh.jpg'),
(71507, 4887, 'Profecia do Inferno S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oGdlZt118qzw1Iar5YH3Ddy4jCX.jpg'),
(71508, 4888, 'Profecia do Inferno S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/719519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xScitPU6asSBhTPcLdf6iVgrcvH.jpg'),
(71509, 4888, 'Profecia do Inferno S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/719520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nKmglTaG0DqtUk0T9D5EmRdWhwm.jpg'),
(71510, 4888, 'Profecia do Inferno S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/719521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jCx4IqZjwWeN8YWf9nGNvoeNGo9.jpg'),
(71511, 4888, 'Profecia do Inferno S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/719522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zICJMPYcb8pOt4NBYRCfdV8wcdg.jpg'),
(71512, 4888, 'Profecia do Inferno S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/719523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cLBDwn2pugMBq4l6pPxmOmqW7QY.jpg'),
(71513, 4888, 'Profecia do Inferno S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/719524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3SsnFjznTz35uuuBf3ISnWHocXy.jpg'),
(71514, 4889, 'Red Light S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s37AUCEmfqI3BoDansgKbMaqsV1.jpg'),
(71515, 4889, 'Red Light S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0V9VsvHFU9Ie43o92g7yjMjunB.jpg'),
(71516, 4889, 'Red Light S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sVO4VVZFbi7jRIYhpJHj1ABReSi.jpg'),
(71517, 4889, 'Red Light S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vgpBtASS7a213Wbo3lnuv1Bw9ZT.jpg'),
(71518, 4889, 'Red Light S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x3BmbgQAdzDul9klWmomLwto5Z7.jpg'),
(71519, 4889, 'Red Light S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/plwWNwbPRMfradM03WNlrGhrIhz.jpg'),
(71520, 4889, 'Red Light S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfsud98tdcX9cAcDD1qn0wFW4Mw.jpg'),
(71521, 4889, 'Red Light S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1LsHwkHUDY5nXffEQDwMvCxOfNn.jpg'),
(71522, 4889, 'Red Light S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uazTsz5YSt8NnKREwsS93JwplT9.jpg'),
(71523, 4889, 'Red Light S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkoA8sgdMySVnbkSvBWQpdejAMF.jpg'),
(71524, 4890, 'Spy City S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2uyG6UUkOzmo7R0y6vFz8XTNxa3.jpg'),
(71525, 4890, 'Spy City S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tk6zon4cmb3W6UKuYRjlqqtxQQV.jpg'),
(71526, 4890, 'Spy City S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hrx3pBuUw1yC4a2Zv4C29bB3IYZ.jpg'),
(71527, 4890, 'Spy City S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2UH6PdNfPm5RRJ8WZIIFt0O1Ild.jpg'),
(71528, 4890, 'Spy City S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kNNW2iWPo8jewXppXZjseUny57J.jpg'),
(71529, 4890, 'Spy City S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jVRJe0o3OgZJEUB0pFGKhhT2gVD.jpg'),
(71530, 4891, 'Vivendo com o Inimigo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3z2854maJWAE0obYaJkJlBS8m0l.jpg'),
(71531, 4891, 'Vivendo com o Inimigo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kcIo9ozbpbBTA2UeNmtMMhajepS.jpg'),
(71532, 4891, 'Vivendo com o Inimigo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5NPzoFUzE2iQvbWhIR11Ah8Qooz.jpg'),
(71533, 4891, 'Vivendo com o Inimigo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7uE2yNAGLwFLoZTeZOeoZ0sFGn.jpg'),
(71534, 4891, 'Vivendo com o Inimigo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zM6jIT19bqkFL45FH1Yle46h5CQ.jpg'),
(71535, 4891, 'Vivendo com o Inimigo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uAMjILmX9MXSgAU7KrHGHECMlxl.jpg'),
(71536, 4892, 'Vivendo com o Inimigo S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/279330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(71537, 4892, 'Vivendo com o Inimigo S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/285636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(71538, 4892, 'Vivendo com o Inimigo S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/295105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(71539, 4892, 'Vivendo com o Inimigo S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/299673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(71540, 4892, 'Vivendo com o Inimigo S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/303728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(71541, 4893, 'Yabba-Dabba Dinossauros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71542, 4893, 'Yabba-Dabba Dinossauros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71543, 4893, 'Yabba-Dabba Dinossauros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71544, 4893, 'Yabba-Dabba Dinossauros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71545, 4893, 'Yabba-Dabba Dinossauros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71546, 4893, 'Yabba-Dabba Dinossauros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71547, 4893, 'Yabba-Dabba Dinossauros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71548, 4893, 'Yabba-Dabba Dinossauros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71549, 4893, 'Yabba-Dabba Dinossauros S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71550, 4893, 'Yabba-Dabba Dinossauros S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71551, 4893, 'Yabba-Dabba Dinossauros S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71552, 4893, 'Yabba-Dabba Dinossauros S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71553, 4893, 'Yabba-Dabba Dinossauros S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71554, 4894, 'Yabba-Dabba Dinossauros S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71555, 4894, 'Yabba-Dabba Dinossauros S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71556, 4894, 'Yabba-Dabba Dinossauros S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71557, 4894, 'Yabba-Dabba Dinossauros S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71558, 4894, 'Yabba-Dabba Dinossauros S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71559, 4894, 'Yabba-Dabba Dinossauros S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71560, 4894, 'Yabba-Dabba Dinossauros S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71561, 4894, 'Yabba-Dabba Dinossauros S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71562, 4894, 'Yabba-Dabba Dinossauros S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71563, 4894, 'Yabba-Dabba Dinossauros S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71564, 4894, 'Yabba-Dabba Dinossauros S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71565, 4894, 'Yabba-Dabba Dinossauros S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71566, 4894, 'Yabba-Dabba Dinossauros S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywpDEYIo4KhhtGLfpCQLVmKrwwg.jpg'),
(71567, 4895, 'A Roda do Tempo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ucVwvH0NqJC5LdN1C8d4qfaLgDt.jpg'),
(71568, 4895, 'A Roda do Tempo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gC4bsEZdMyQRqEQyJqGQ28cR0Ct.jpg'),
(71569, 4895, 'A Roda do Tempo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fEJrLcvcH5Dikcfv3hrzA2uvw8q.jpg'),
(71570, 4895, 'A Roda do Tempo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237514.mp4', 'http://image.tmdb.org/t/p/w1280/yRFsTWVi5oaDzEfY1RxMaqZheAi.jpg'),
(71571, 4895, 'A Roda do Tempo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237515.mp4', 'http://image.tmdb.org/t/p/w1280/mG0msmGey6EJ2KPdKV0EROzZPxo.jpg'),
(71572, 4895, 'A Roda do Tempo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237516.mp4', 'http://image.tmdb.org/t/p/w1280/7hsl7FPEqI8OBDtAr6N3oH6Iodh.jpg'),
(71573, 4895, 'A Roda do Tempo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237517.mp4', 'http://image.tmdb.org/t/p/w1280/dJXKOytnEGNjT13Et0YWTN2R1xH.jpg'),
(71574, 4895, 'A Roda do Tempo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237518.mp4', 'http://image.tmdb.org/t/p/w1280/zV4PtAr2cMYhUcypPsIQzFeiWjg.jpg'),
(71575, 4896, 'A Roda do Tempo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2f42fl7AhRSQ4GFtFK5Rj4YVFAg.jpg'),
(71576, 4896, 'A Roda do Tempo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/npwYpbErBmBmH3yBT6bDpujHNoh.jpg'),
(71577, 4896, 'A Roda do Tempo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x3fIXKakskWcmWCYNTDLMHbkuYq.jpg'),
(71578, 4896, 'A Roda do Tempo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237522.mp4', 'http://image.tmdb.org/t/p/w1280/2znTxo0rWH9dlfdSHsOZIoDNrjV.jpg'),
(71579, 4896, 'A Roda do Tempo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LKxmsgkBSbwGJkNOnYgD9gzS87.jpg'),
(71580, 4896, 'A Roda do Tempo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LKxmsgkBSbwGJkNOnYgD9gzS87.jpg'),
(71581, 4896, 'A Roda do Tempo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LKxmsgkBSbwGJkNOnYgD9gzS87.jpg'),
(71582, 4896, 'A Roda do Tempo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LKxmsgkBSbwGJkNOnYgD9gzS87.jpg'),
(71583, 4897, 'A Roda do Tempo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/725363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LKxmsgkBSbwGJkNOnYgD9gzS87.jpg'),
(71584, 4897, 'A Roda do Tempo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/725364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LKxmsgkBSbwGJkNOnYgD9gzS87.jpg'),
(71585, 4897, 'A Roda do Tempo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/725365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LKxmsgkBSbwGJkNOnYgD9gzS87.jpg'),
(71586, 4897, 'A Roda do Tempo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/731701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LKxmsgkBSbwGJkNOnYgD9gzS87.jpg'),
(71587, 4897, 'A Roda do Tempo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/743099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LKxmsgkBSbwGJkNOnYgD9gzS87.jpg'),
(71588, 4897, 'A Roda do Tempo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/756051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LKxmsgkBSbwGJkNOnYgD9gzS87.jpg'),
(71589, 4897, 'A Roda do Tempo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/768795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LKxmsgkBSbwGJkNOnYgD9gzS87.jpg'),
(71590, 4897, 'A Roda do Tempo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/771431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LKxmsgkBSbwGJkNOnYgD9gzS87.jpg'),
(71591, 4898, 'Justiça Jovem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lMIIv0YPrbCgkQmAUqZNm0HbZw3.jpg'),
(71592, 4898, 'Justiça Jovem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l0it1ftVsJHP4N34A865Z0E95fS.jpg'),
(71593, 4898, 'Justiça Jovem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g33Nuxw0lRjmZHDk1wUgf2lZbcg.jpg'),
(71594, 4898, 'Justiça Jovem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9J040mDC2Lrajpq2MpQyygib3mi.jpg'),
(71595, 4898, 'Justiça Jovem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p139g0jE50eVNTUHhUT5vfTRbzc.jpg'),
(71596, 4898, 'Justiça Jovem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ah47UB5pd1hrXZ60Ss1sOCbeJhV.jpg'),
(71597, 4898, 'Justiça Jovem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vvnsHCID7u6XoVUmcs7y7VBhG0f.jpg'),
(71598, 4898, 'Justiça Jovem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iezyUQB2Jj8dmh9UHtpGhgYS4KZ.jpg'),
(71599, 4898, 'Justiça Jovem S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6aJv1mMzbS6X8SQVSt87V1sHBfJ.jpg'),
(71600, 4898, 'Justiça Jovem S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/swRYWxAQ28AmEfRknVYkBdH6Pxh.jpg'),
(71601, 4898, 'Justiça Jovem S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8souJBKq7vuvDTzF8vGvFIwGmR.jpg'),
(71602, 4898, 'Justiça Jovem S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aT50LbOaDxvIAyYRrSCYxNPjGRO.jpg'),
(71603, 4898, 'Justiça Jovem S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aiNljjTojvkVHPxzRmckVghPtYV.jpg'),
(71604, 4898, 'Justiça Jovem S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d6pEyx19LYlFzbEKMW4CUbTZg4o.jpg'),
(71605, 4898, 'Justiça Jovem S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jF81w2GmsVSZVmdsCdOoiJ9W1SZ.jpg'),
(71606, 4898, 'Justiça Jovem S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zaIqwCqpieWkJ50umvjmdzPQtoK.jpg'),
(71607, 4898, 'Justiça Jovem S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDkfB7efCtKR7UyVXWT7s0D5mgN.jpg'),
(71608, 4898, 'Justiça Jovem S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/234154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5KxiryvthzdcOXGBzlTJBQlKR.jpg'),
(71609, 4898, 'Justiça Jovem S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/234155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d6D0LkYV4gelIlD8Vf5HLrI4xGu.jpg'),
(71610, 4898, 'Justiça Jovem S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/234156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A0xbCwhTVgqsWCW4YYV5uCUds8s.jpg'),
(71611, 4898, 'Justiça Jovem S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/234157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mU0RA7SydfrWHpEQCSDWhkRPoo.jpg'),
(71612, 4898, 'Justiça Jovem S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/234158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dF6XNOLwJboSD7eOuCVjUGrvL8A.jpg'),
(71613, 4898, 'Justiça Jovem S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/234159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uvYlNmY2HW1ZoXxJeMTvJe3PsTP.jpg'),
(71614, 4898, 'Justiça Jovem S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/234160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g3L7f8vZAkl22zsHLocmoQ0ySWP.jpg'),
(71615, 4898, 'Justiça Jovem S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/234161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/68XYsY3R9TmX5akxq1IllBVgf66.jpg'),
(71616, 4898, 'Justiça Jovem S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/234162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7BGv3xyxxk53F4sH2PVmOuyLjdf.jpg'),
(71617, 4899, 'Justiça Jovem S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vQ6phdn6Z7H8aKJiEHQVlOgJjxM.jpg'),
(71618, 4899, 'Justiça Jovem S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hk3HtXE0DlC2Q0ncT4FJzkkjXUq.jpg'),
(71619, 4899, 'Justiça Jovem S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q3HDieQUrsu3YqDVSB7WKgxQjxj.jpg'),
(71620, 4899, 'Justiça Jovem S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/acXCzmE26QmdmgOmtFKu1zvzIPL.jpg'),
(71621, 4899, 'Justiça Jovem S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lRn5twnNu8dxrqAHwDClNlUZAVm.jpg'),
(71622, 4899, 'Justiça Jovem S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqFHrcXDdMKMrRda6wkoF9KEe39.jpg'),
(71623, 4899, 'Justiça Jovem S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nXIktKdAoA94mRBFakTUQL6LSpb.jpg'),
(71624, 4899, 'Justiça Jovem S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oy5GMVnQRGde00rJ4nIZJZD23jP.jpg'),
(71625, 4899, 'Justiça Jovem S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w1QHyQqqKXLnYECbQaQbPXp6jgJ.jpg'),
(71626, 4899, 'Justiça Jovem S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybjSbpjTDXGQWWgBvOhpvItOWxG.jpg'),
(71627, 4899, 'Justiça Jovem S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bmhfECV6k9dhzxsPuA1rQgrs231.jpg'),
(71628, 4899, 'Justiça Jovem S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6d9w02OgkY0xC87ZtyVVvxkCRAB.jpg'),
(71629, 4899, 'Justiça Jovem S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1AN1zXMCmu51UTKE9CYNM31vIHK.jpg'),
(71630, 4899, 'Justiça Jovem S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aflspgrCmmLJfxOElyxAp89zjy9.jpg'),
(71631, 4899, 'Justiça Jovem S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yOlwVx9DrPxuqA9pSjm3uOx91WK.jpg'),
(71632, 4899, 'Justiça Jovem S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lAUAqJrQ4SshjEeRMZrsN9c1Izq.jpg'),
(71633, 4899, 'Justiça Jovem S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLEiBHzhasXFwe7dW9BDiMqyND1.jpg'),
(71634, 4899, 'Justiça Jovem S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/234180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5L8QqSXUFqRN8Jta9Wk98CuEIRE.jpg'),
(71635, 4899, 'Justiça Jovem S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/234181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rPWoIH8n3XTTktQe5HxNNLXeTDt.jpg'),
(71636, 4899, 'Justiça Jovem S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/234182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/myQxeSgcma4rrfxK4WVg95VCZuI.jpg'),
(71637, 4900, 'Justiça Jovem S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gorAhQMHKcJnJMfttl58cbsRjDx.jpg'),
(71638, 4900, 'Justiça Jovem S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/71uL7zfxfwnFOf158Yhl71QGgNC.jpg'),
(71639, 4900, 'Justiça Jovem S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUGNzQcrLZb4wjF45ZLtroVc9Qw.jpg'),
(71640, 4900, 'Justiça Jovem S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gDpwUkQzMlwvkxgn0q808744VtM.jpg'),
(71641, 4900, 'Justiça Jovem S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zXaQbCgPCCnl3HdrwDKYadyuQjm.jpg'),
(71642, 4900, 'Justiça Jovem S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lbHeY8BQa1SxBtKNtruFDwLQyiz.jpg'),
(71643, 4900, 'Justiça Jovem S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aqlwe7dxBef29JRj8dUpKcj0yI5.jpg'),
(71644, 4900, 'Justiça Jovem S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1yDPjSG0m45XdGgWOIQEYal43fQ.jpg'),
(71645, 4900, 'Justiça Jovem S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8SY4NBY2bZGMjL7hukVEcyOaoKW.jpg'),
(71646, 4900, 'Justiça Jovem S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhYqjMKoCpB19BH1uc9MVwQP50C.jpg'),
(71647, 4900, 'Justiça Jovem S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wgdyzYNtkUool0KRjtl6evheG5H.jpg'),
(71648, 4900, 'Justiça Jovem S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4lTP0g3VFzKf5N2n4C6C3keSnEy.jpg'),
(71649, 4900, 'Justiça Jovem S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xzHBApi46MtFJv7QTWAl2z8zZcP.jpg'),
(71650, 4900, 'Justiça Jovem S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97e0y5aoRSW7zXePSFJPgZ0AtMe.jpg'),
(71651, 4900, 'Justiça Jovem S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zHgKgwPOjyW5ooHDQJ2qtaDwphc.jpg'),
(71652, 4900, 'Justiça Jovem S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ycSMjJbkvpZ6nYsYG3JebktbxEi.jpg'),
(71653, 4900, 'Justiça Jovem S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vKsye9kI3f9ulrmBtAkFW7wjbTQ.jpg'),
(71654, 4900, 'Justiça Jovem S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/234200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqQwrbHCho3BBJIHqFYI7oWaJi6.jpg'),
(71655, 4900, 'Justiça Jovem S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/234201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4I1IbvjF4xPsvAfGh0tv7lCpTFc.jpg'),
(71656, 4900, 'Justiça Jovem S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/234202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVCPvVI81gwXi4oMZ3VneUx7vYW.jpg'),
(71657, 4900, 'Justiça Jovem S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/234203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ppA6C3j2jRugoEijIcgx6Eie3Sq.jpg'),
(71658, 4900, 'Justiça Jovem S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/234204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/42ozg5I1jLOYYF6Kc2ynLB3pc61.jpg'),
(71659, 4900, 'Justiça Jovem S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/234205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/37R088cd063vp02WX2n3HEhRANr.jpg'),
(71660, 4900, 'Justiça Jovem S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/234206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mNgrJn0duWaUdQff7nXtXjfING9.jpg'),
(71661, 4900, 'Justiça Jovem S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/234207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o54vbtWsc6Mi2QHDtWoePob9whH.jpg'),
(71662, 4900, 'Justiça Jovem S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/234208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9DCwaniE7PVyYRsJcOEFcSNhknY.jpg'),
(71663, 4901, 'Justiça Jovem S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqmpINsUhWpy7CLNtl2G7viROrt.jpg'),
(71664, 4901, 'Justiça Jovem S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jO5McGq9llDifFyKd5ZxQFZoxAQ.jpg'),
(71665, 4901, 'Justiça Jovem S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dpnzB2wFHm4QAPa6rBKXlvHgs0F.jpg'),
(71666, 4901, 'Justiça Jovem S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uOutHpzWmtlrUCfCY2uddbr7K99.jpg'),
(71667, 4901, 'Justiça Jovem S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zcdPQFUvveJZ1Nc37mpFUXW1eET.jpg'),
(71668, 4901, 'Justiça Jovem S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gdnUuKXw41gj1f8OrMJYcrc95dt.jpg'),
(71669, 4901, 'Justiça Jovem S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ykiP02cUOVsukaM2bKWTB5MaeTY.jpg'),
(71670, 4901, 'Justiça Jovem S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lbW4NcyFnQQfmdEcgAdK8lTn49d.jpg'),
(71671, 4901, 'Justiça Jovem S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ceRVgFCdvvbZQscWhPbqdomiNF.jpg'),
(71672, 4901, 'Justiça Jovem S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/axc9UNARVMFZxePq3UGmo8O8fuC.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(71673, 4901, 'Justiça Jovem S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l4vcAh0epJfDCtnm2pNh0b2Rw7a.jpg'),
(71674, 4901, 'Justiça Jovem S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ylrj7qGTQnrnteO498hclKM2GXq.jpg'),
(71675, 4901, 'Justiça Jovem S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5xr9St1GHJK23x5IOHtyeqUVs3E.jpg'),
(71676, 4901, 'Justiça Jovem S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7SivECbuqVS5su3LuvKDy8zC9FJ.jpg'),
(71677, 4901, 'Justiça Jovem S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yuBsvKNN2cAFwxgYoBP0u9GkGkJ.jpg'),
(71678, 4901, 'Justiça Jovem S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhlMFI4OucgtlApwlBqPUf18WOm.jpg'),
(71679, 4901, 'Justiça Jovem S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mf2uQquKQcAeWYHyMIrWkf3cybH.jpg'),
(71680, 4901, 'Justiça Jovem S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/234226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vRDVcwybVmpPrr7n6obzpLsPhG1.jpg'),
(71681, 4901, 'Justiça Jovem S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/234227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tWWLu1sWfzDfMrIQdrxUYG6RbC8.jpg'),
(71682, 4901, 'Justiça Jovem S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/234228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8nphlQaEHVutAQw2wkwt6D9tWDy.jpg'),
(71683, 4901, 'Justiça Jovem S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/234229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/agvyPDzhQFWTod0NMB5vuLcyeXJ.jpg'),
(71684, 4901, 'Justiça Jovem S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/234230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvIDudZUcghR2qlhZas6c6IQLGx.jpg'),
(71685, 4901, 'Justiça Jovem S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/234231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMSq4ZgQcJGnlP2R8ejqlYoAw4I.jpg'),
(71686, 4901, 'Justiça Jovem S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/234232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ThPLpfemxBiew1tGCoktCyw2JB.jpg'),
(71687, 4901, 'Justiça Jovem S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/234233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bGxARSZUuDbgkX03TzrXSXcHgNJ.jpg'),
(71688, 4901, 'Justiça Jovem S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/234234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aIrFAxd14cA3vf0ieShje23KedZ.jpg'),
(71689, 4902, 'Sobreviventes do Gelo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/glhC4mXwaVWU1ts3FMcec2fcV5b.jpg'),
(71690, 4902, 'Sobreviventes do Gelo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/glhC4mXwaVWU1ts3FMcec2fcV5b.jpg'),
(71691, 4902, 'Sobreviventes do Gelo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/glhC4mXwaVWU1ts3FMcec2fcV5b.jpg'),
(71692, 4902, 'Sobreviventes do Gelo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/glhC4mXwaVWU1ts3FMcec2fcV5b.jpg'),
(71693, 4902, 'Sobreviventes do Gelo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/glhC4mXwaVWU1ts3FMcec2fcV5b.jpg'),
(71694, 4902, 'Sobreviventes do Gelo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/glhC4mXwaVWU1ts3FMcec2fcV5b.jpg'),
(71695, 4902, 'Sobreviventes do Gelo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/glhC4mXwaVWU1ts3FMcec2fcV5b.jpg'),
(71696, 4902, 'Sobreviventes do Gelo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/glhC4mXwaVWU1ts3FMcec2fcV5b.jpg'),
(71697, 4902, 'Sobreviventes do Gelo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/glhC4mXwaVWU1ts3FMcec2fcV5b.jpg'),
(71698, 4902, 'Sobreviventes do Gelo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/166394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/glhC4mXwaVWU1ts3FMcec2fcV5b.jpg'),
(71699, 4903, 'Sobreviventes do Gelo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/166395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/glhC4mXwaVWU1ts3FMcec2fcV5b.jpg'),
(71700, 4903, 'Sobreviventes do Gelo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/166396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/glhC4mXwaVWU1ts3FMcec2fcV5b.jpg'),
(71701, 4903, 'Sobreviventes do Gelo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/166397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/glhC4mXwaVWU1ts3FMcec2fcV5b.jpg'),
(71702, 4903, 'Sobreviventes do Gelo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/166398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/glhC4mXwaVWU1ts3FMcec2fcV5b.jpg'),
(71703, 4903, 'Sobreviventes do Gelo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/166399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/glhC4mXwaVWU1ts3FMcec2fcV5b.jpg'),
(71704, 4903, 'Sobreviventes do Gelo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/166400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/glhC4mXwaVWU1ts3FMcec2fcV5b.jpg'),
(71705, 4903, 'Sobreviventes do Gelo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/166401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/glhC4mXwaVWU1ts3FMcec2fcV5b.jpg'),
(71706, 4903, 'Sobreviventes do Gelo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/166402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/glhC4mXwaVWU1ts3FMcec2fcV5b.jpg'),
(71707, 4903, 'Sobreviventes do Gelo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/166403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/glhC4mXwaVWU1ts3FMcec2fcV5b.jpg'),
(71708, 4904, 'Presença de Anita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/165683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9pZVwE2UrjO5vZT0bJ2Vv5ufLJA.jpg'),
(71709, 4904, 'Presença de Anita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/165684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9pZVwE2UrjO5vZT0bJ2Vv5ufLJA.jpg'),
(71710, 4904, 'Presença de Anita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/165685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9pZVwE2UrjO5vZT0bJ2Vv5ufLJA.jpg'),
(71711, 4904, 'Presença de Anita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/165686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9pZVwE2UrjO5vZT0bJ2Vv5ufLJA.jpg'),
(71712, 4904, 'Presença de Anita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/165687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9pZVwE2UrjO5vZT0bJ2Vv5ufLJA.jpg'),
(71713, 4904, 'Presença de Anita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/165688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9pZVwE2UrjO5vZT0bJ2Vv5ufLJA.jpg'),
(71714, 4904, 'Presença de Anita S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/165689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9pZVwE2UrjO5vZT0bJ2Vv5ufLJA.jpg'),
(71715, 4904, 'Presença de Anita S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/165690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9pZVwE2UrjO5vZT0bJ2Vv5ufLJA.jpg'),
(71716, 4904, 'Presença de Anita S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/165691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9pZVwE2UrjO5vZT0bJ2Vv5ufLJA.jpg'),
(71717, 4904, 'Presença de Anita S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/165692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9pZVwE2UrjO5vZT0bJ2Vv5ufLJA.jpg'),
(71718, 4904, 'Presença de Anita S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/165693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9pZVwE2UrjO5vZT0bJ2Vv5ufLJA.jpg'),
(71719, 4904, 'Presença de Anita S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/165694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9pZVwE2UrjO5vZT0bJ2Vv5ufLJA.jpg'),
(71720, 4904, 'Presença de Anita S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/165695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9pZVwE2UrjO5vZT0bJ2Vv5ufLJA.jpg'),
(71721, 4904, 'Presença de Anita S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/165696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9pZVwE2UrjO5vZT0bJ2Vv5ufLJA.jpg'),
(71722, 4904, 'Presença de Anita S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/165697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9pZVwE2UrjO5vZT0bJ2Vv5ufLJA.jpg'),
(71723, 4904, 'Presença de Anita S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/165698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9pZVwE2UrjO5vZT0bJ2Vv5ufLJA.jpg'),
(71724, 4905, 'Gavião Arqueiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AwCNTaG7VPVwaBRSZkvQUMEfyuZ.jpg'),
(71725, 4905, 'Gavião Arqueiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v6DjX5jATXUpkILMFMEOR61PWr5.jpg'),
(71726, 4905, 'Gavião Arqueiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169695.mp4', 'http://image.tmdb.org/t/p/w1280/4JIxm0YFv0d8nMEwmMBrOOs2H0k.jpg'),
(71727, 4905, 'Gavião Arqueiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169696.mp4', 'http://image.tmdb.org/t/p/w1280/3K3CPASP9NhbxPwkSvCskRpmzTL.jpg'),
(71728, 4905, 'Gavião Arqueiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oaDRxEaBGVFqYyc4ycbyLRstZ1F.jpg'),
(71729, 4905, 'Gavião Arqueiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nXuI42V8HgmyMlewU2tiOEEjKsC.jpg'),
(71730, 4906, '90 Dias na Cozinha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/165062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rYHzBgkUJtFXubAzAuClXf1kh5V.jpg'),
(71731, 4906, '90 Dias na Cozinha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/165063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j6GMDkoJH9SVQ1rpUApE7vKkC7Y.jpg'),
(71732, 4906, '90 Dias na Cozinha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/165064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3lzM8MQxmHaghNKu8eNNwbnSCEx.jpg'),
(71733, 4906, '90 Dias na Cozinha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/165065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1GVrbUGGHYI3TZIoHlsAKge8ROL.jpg'),
(71734, 4906, '90 Dias na Cozinha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/165066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tyh3N9nlEimu4VWt36EFSDnMHma.jpg'),
(71735, 4906, '90 Dias na Cozinha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/165067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ZFgvARM9R5qQQWTwruObDn8yes.jpg'),
(71736, 4907, 'A Casa Harper S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/165052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/635FkTdbenofLo5ZkHMfi5l7dAj.jpg'),
(71737, 4907, 'A Casa Harper S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/165053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ae8vEgpeeDB8954mI4bxXAv5j2.jpg'),
(71738, 4907, 'A Casa Harper S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/165054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Ki5BjgHMuMWmqIJeb34pAb64BF.jpg'),
(71739, 4907, 'A Casa Harper S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/165055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1tWTDcGPcKQUWkuaCgGtGMgBO9f.jpg'),
(71740, 4907, 'A Casa Harper S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/165056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aanuwr8qmlMw0Af5rzkdm2Tcxse.jpg'),
(71741, 4907, 'A Casa Harper S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/165057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iYIBsDloNkVkzTfBHC3HGGC6LG6.jpg'),
(71742, 4907, 'A Casa Harper S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/165058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1u67PuKWqZvbmAKbFsIjDcNipfk.jpg'),
(71743, 4907, 'A Casa Harper S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/165059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o5TW13x4trZSCTcV7sj33geOEri.jpg'),
(71744, 4907, 'A Casa Harper S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/165060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ikEXn3Q7iq3pb2rCHjQL47MO8GV.jpg'),
(71745, 4907, 'A Casa Harper S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/165061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7wrzLgPDuFcqsyJryOsgDAziUj.jpg'),
(71746, 4908, 'A pequena espiã S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qDXe9qmLV7llpkEvjsGRol2BXGG.jpg'),
(71747, 4908, 'A pequena espiã S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aYmf5LTWkJiiLRAnc5aGsAgZYFD.jpg'),
(71748, 4908, 'A pequena espiã S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Ht94hKhEZDodeKw9mGoznde4qD.jpg'),
(71749, 4908, 'A pequena espiã S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/75sz2aMW74siZ3Z6AVu5YLw2aGQ.jpg'),
(71750, 4908, 'A pequena espiã S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1fP9jC1SVqJZMqwUijfUj1L0h0t.jpg'),
(71751, 4908, 'A pequena espiã S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180259.mp4', 'http://timg.bdta.pro/images/432211460f16b5dfe37a953f910cda75.jpg'),
(71752, 4908, 'A pequena espiã S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180260.mp4', 'http://timg.bdta.pro/images/1c90efe24122f80f5bc051da1401e06f.jpg'),
(71753, 4908, 'A pequena espiã S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180261.mp4', 'http://timg.bdta.pro/images/bba13a00ccb561f0aa844bfe8d94c58a.jpg'),
(71754, 4908, 'A pequena espiã S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180262.mp4', 'http://timg.bdta.pro/images/bf4a1bc17465668baf424b5734a1627a.jpg'),
(71755, 4908, 'A pequena espiã S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180263.mp4', 'http://timg.bdta.pro/images/b1190bbf245c4f706be4b2b50fe8f3b3.jpg'),
(71756, 4909, 'Amor: Verdade ou Consequência S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/165045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mgCOh13TGmOSAEz9ikUjUzJAwLt.jpg'),
(71757, 4909, 'Amor: Verdade ou Consequência S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/165046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vAGC6uJbYwYLwu0Uhcvyyo7zJB.jpg'),
(71758, 4909, 'Amor: Verdade ou Consequência S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/165047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x8YZAX0jP7T6F1CKZzwaggQ4oAU.jpg'),
(71759, 4909, 'Amor: Verdade ou Consequência S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/165048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sWXPR3wT3A0eT3Kw8Ndk7bjAXp8.jpg'),
(71760, 4909, 'Amor: Verdade ou Consequência S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/165049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pMoaTWlojq1YxtMHMRpeqcKsljI.jpg'),
(71761, 4909, 'Amor: Verdade ou Consequência S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/165050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t2GkJrUw7UrMe8y5q4Ex6s9illB.jpg'),
(71762, 4909, 'Amor: Verdade ou Consequência S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/165051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpTIvWteYhgDlw1k8wos8QoQTcq.jpg'),
(71763, 4910, 'Ana Bolena: A Rainha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/165042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8fxAddYetISabpb6ZINd2ha5nBj.jpg'),
(71764, 4910, 'Ana Bolena: A Rainha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/165043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z7JptrVrrA75oD7eKXN3lNVZ0EV.jpg'),
(71765, 4910, 'Ana Bolena: A Rainha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/165044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lSS7BHyp4PnN7kdBK8C6y8JnFhB.jpg'),
(71766, 4911, 'De Casa Nova: Cidade Renovada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/165036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sEMRPHQ0FVE2MWmqihT503mn0DL.jpg'),
(71767, 4911, 'De Casa Nova: Cidade Renovada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/165037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJIcxD7FgVgR7gbyH46XSG3Lyx7.jpg'),
(71768, 4911, 'De Casa Nova: Cidade Renovada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/165038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xDIBbKSqXyZx9NockmTbinBpvtL.jpg'),
(71769, 4911, 'De Casa Nova: Cidade Renovada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/165039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6JAouPhhOtQiR7PSjSKph3TgLfl.jpg'),
(71770, 4911, 'De Casa Nova: Cidade Renovada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/165040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hyTXyI2gyVjvd5wVbaiFbbFXdkr.jpg'),
(71771, 4911, 'De Casa Nova: Cidade Renovada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/165041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/NJJg8p8pkTmZuW3Wzsk8SGegyA.jpg'),
(71772, 4912, 'Dúvida Razoável: Uma História de Dois Sequestros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/165032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5EJxd7kc4kND9RCWTYNKUOvwL0H.jpg'),
(71773, 4912, 'Dúvida Razoável: Uma História de Dois Sequestros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/165033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5EJxd7kc4kND9RCWTYNKUOvwL0H.jpg'),
(71774, 4912, 'Dúvida Razoável: Uma História de Dois Sequestros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/165034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5EJxd7kc4kND9RCWTYNKUOvwL0H.jpg'),
(71775, 4912, 'Dúvida Razoável: Uma História de Dois Sequestros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/165035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5EJxd7kc4kND9RCWTYNKUOvwL0H.jpg'),
(71776, 4913, 'Ferinha e a Fábrica de Tudo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/165022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nw4aeldO2bL7qEiAMH2b0OgWfhG.jpg'),
(71777, 4913, 'Ferinha e a Fábrica de Tudo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/165023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pAP9a9TlY5oEZ5SeikIDdN1W7wf.jpg'),
(71778, 4913, 'Ferinha e a Fábrica de Tudo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/165024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pAP9a9TlY5oEZ5SeikIDdN1W7wf.jpg'),
(71779, 4913, 'Ferinha e a Fábrica de Tudo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/165025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pAP9a9TlY5oEZ5SeikIDdN1W7wf.jpg'),
(71780, 4913, 'Ferinha e a Fábrica de Tudo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/165026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pAP9a9TlY5oEZ5SeikIDdN1W7wf.jpg'),
(71781, 4913, 'Ferinha e a Fábrica de Tudo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/165027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pAP9a9TlY5oEZ5SeikIDdN1W7wf.jpg'),
(71782, 4913, 'Ferinha e a Fábrica de Tudo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/165028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pAP9a9TlY5oEZ5SeikIDdN1W7wf.jpg'),
(71783, 4913, 'Ferinha e a Fábrica de Tudo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/165029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pAP9a9TlY5oEZ5SeikIDdN1W7wf.jpg'),
(71784, 4913, 'Ferinha e a Fábrica de Tudo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/165030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pAP9a9TlY5oEZ5SeikIDdN1W7wf.jpg'),
(71785, 4913, 'Ferinha e a Fábrica de Tudo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/165031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pAP9a9TlY5oEZ5SeikIDdN1W7wf.jpg'),
(71786, 4914, 'Into the Dark S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71787, 4914, 'Into the Dark S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71788, 4914, 'Into the Dark S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/165000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71789, 4914, 'Into the Dark S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/165001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71790, 4914, 'Into the Dark S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/165002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71791, 4914, 'Into the Dark S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/165003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71792, 4914, 'Into the Dark S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/165004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71793, 4914, 'Into the Dark S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/165005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71794, 4914, 'Into the Dark S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/165006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71795, 4914, 'Into the Dark S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/165007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71796, 4914, 'Into the Dark S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/165008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71797, 4914, 'Into the Dark S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/165009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71798, 4915, 'Into the Dark S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/165010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71799, 4915, 'Into the Dark S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/165011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71800, 4915, 'Into the Dark S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/165012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71801, 4915, 'Into the Dark S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/165013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71802, 4915, 'Into the Dark S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/165014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71803, 4915, 'Into the Dark S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/165015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71804, 4915, 'Into the Dark S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/165016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71805, 4915, 'Into the Dark S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/165017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71806, 4915, 'Into the Dark S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/165018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71807, 4915, 'Into the Dark S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/165019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71808, 4915, 'Into the Dark S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/165020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71809, 4915, 'Into the Dark S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/165021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agbqVmagonLY2PM5T59yukqnIPF.jpg'),
(71810, 4916, 'Largados e Pelados Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1KwUDqG6WHydwuBubzhgZch4HQ.jpg'),
(71811, 4916, 'Largados e Pelados Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pw3sW2HSKLnJhlUFDbkGzOv3G9t.jpg'),
(71812, 4916, 'Largados e Pelados Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cES5DU67ZEZRBUXNihB9vkgGjhQ.jpg'),
(71813, 4916, 'Largados e Pelados Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8D9Ts3p9oo66rrPXVi4RFXO0v18.jpg'),
(71814, 4916, 'Largados e Pelados Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8D9Ts3p9oo66rrPXVi4RFXO0v18.jpg'),
(71815, 4916, 'Largados e Pelados Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8D9Ts3p9oo66rrPXVi4RFXO0v18.jpg'),
(71816, 4916, 'Largados e Pelados Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203141.mp4', 'http://image.tmdb.org/t/p/w1280/dGTJAkunXiJ5ERsCbTIU9Edsr9D.jpg'),
(71817, 4917, 'Largados e Pelados Brasil S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lb4TyrONBZgs0ri3rLAQ85wr7T4.jpg'),
(71818, 4917, 'Largados e Pelados Brasil S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qytaGBTAms9hfmCyFz3C8FLwlQO.jpg'),
(71819, 4917, 'Largados e Pelados Brasil S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6rKfj8TruFmgI5xKgTvL3M1szQx.jpg'),
(71820, 4917, 'Largados e Pelados Brasil S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f8dkrwBzTYVyNWm2rRzF0LrWpT8.jpg'),
(71821, 4917, 'Largados e Pelados Brasil S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dqNlC8WgrE16R4ZoxhjNy9I5VDs.jpg'),
(71822, 4917, 'Largados e Pelados Brasil S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/exevXU5uTqu9Bighd1RoTzR9cBJ.jpg'),
(71823, 4917, 'Largados e Pelados Brasil S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ewmleQVBpjjbNUeOzorpNDxhwt2.jpg'),
(71824, 4918, 'Largados e Pelados Brasil S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/292162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8D9Ts3p9oo66rrPXVi4RFXO0v18.jpg'),
(71825, 4918, 'Largados e Pelados Brasil S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/292163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8D9Ts3p9oo66rrPXVi4RFXO0v18.jpg'),
(71826, 4918, 'Largados e Pelados Brasil S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/292164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8D9Ts3p9oo66rrPXVi4RFXO0v18.jpg'),
(71827, 4918, 'Largados e Pelados Brasil S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/292165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8D9Ts3p9oo66rrPXVi4RFXO0v18.jpg'),
(71828, 4918, 'Largados e Pelados Brasil S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/296758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8D9Ts3p9oo66rrPXVi4RFXO0v18.jpg'),
(71829, 4918, 'Largados e Pelados Brasil S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/299891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8D9Ts3p9oo66rrPXVi4RFXO0v18.jpg'),
(71830, 4918, 'Largados e Pelados Brasil S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/304371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8D9Ts3p9oo66rrPXVi4RFXO0v18.jpg'),
(71831, 4919, 'Navillera S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q8PCl0lJfcjek22KPKvPrqgmr30.jpg'),
(71832, 4919, 'Navillera S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sezImWPLbz9rrUaMGGI1qgmHvpT.jpg'),
(71833, 4919, 'Navillera S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vMBLvtkgJTaoXD3VmzsGPFmJ3BY.jpg'),
(71834, 4919, 'Navillera S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/reWDLlVCjXGbakGOcVkDLP64Vli.jpg'),
(71835, 4919, 'Navillera S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8lnUdKU1xgMEHoF5S0ro8fy5JIW.jpg'),
(71836, 4919, 'Navillera S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/csTEzc3cp5O7jw0uoEfJgWRPOo9.jpg'),
(71837, 4919, 'Navillera S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCWgpLufKnkcEHMLtf4qwcZHejy.jpg'),
(71838, 4919, 'Navillera S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ii7Iq264tra2Lbu8sCIqi9o7M3p.jpg'),
(71839, 4919, 'Navillera S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gEAFAWpMH8crAYtElRhK95384Lj.jpg'),
(71840, 4919, 'Navillera S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oBumiqqlPqCx36UKy8tEIK4BVtu.jpg'),
(71841, 4919, 'Navillera S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v0vXeIyaz1DTTkIzqqiuz8JjoVd.jpg'),
(71842, 4919, 'Navillera S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lAhfUInuDwyCbO1M5qIHy0y5OZC.jpg'),
(71843, 4920, 'Nos Os Filhos da Estacao Zoo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u0Z2hQywbZX2zU7zPpmtb9YBgYw.jpg'),
(71844, 4920, 'Nos Os Filhos da Estacao Zoo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cJBACakUYH2GzfkMFcwA5Ql2LSZ.jpg'),
(71845, 4920, 'Nos Os Filhos da Estacao Zoo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nSOkGKEiLdOdac3oNNYxv6On6u2.jpg'),
(71846, 4920, 'Nos Os Filhos da Estacao Zoo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ogeLmhDf16bJv8ngTqu4ypHAXhi.jpg'),
(71847, 4920, 'Nos Os Filhos da Estacao Zoo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zjvWP4djo4QHgl5B574Uj8QKtyq.jpg'),
(71848, 4920, 'Nos Os Filhos da Estacao Zoo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c9e69apVndZo1i2yx1sOQNqDMAR.jpg'),
(71849, 4920, 'Nos Os Filhos da Estacao Zoo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u1DiXrDaeatFfOQS7FYP2Ock07r.jpg'),
(71850, 4920, 'Nos Os Filhos da Estacao Zoo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5flxxbn38SktNjRP6Sd4YoajGrY.jpg'),
(71851, 4921, 'Reservation Dogs S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6zTTC1lHHOGorVcTDzWi0UsGwwo.jpg'),
(71852, 4921, 'Reservation Dogs S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A8kae2xsXlLUYW181ukmAXfWAlK.jpg'),
(71853, 4921, 'Reservation Dogs S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ig0zfsWBK09LEdmc4FrKh1avzpw.jpg'),
(71854, 4921, 'Reservation Dogs S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/72dsnJDYsBPhrT3SpSKdstIgCku.jpg'),
(71855, 4921, 'Reservation Dogs S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x2RIvsU2oKN9NCuKEIj3GjPvacc.jpg'),
(71856, 4921, 'Reservation Dogs S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/76tKWLjOKWo556mVndVbCwDM2bg.jpg'),
(71857, 4921, 'Reservation Dogs S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1aGJBq5A4qGq2BXJtS6zdEknvLZ.jpg'),
(71858, 4921, 'Reservation Dogs S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8qcWhiKVToAb2IWgNm1R1g9F364.jpg'),
(71859, 4922, 'Reservation Dogs S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/unHL6054a1lztZDFRjhYzKTLwFr.jpg'),
(71860, 4922, 'Reservation Dogs S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Out15lbVMyvkWzEPqo0ivwQtVz.jpg'),
(71861, 4922, 'Reservation Dogs S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6RxD9U4V5JjeXtmTeUu3WQF74O3.jpg'),
(71862, 4922, 'Reservation Dogs S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3VEK6cmT0zOENTXeEnCZkz0ZzP.jpg'),
(71863, 4922, 'Reservation Dogs S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nhSJOuF7EOAJUQxPvFKBtFlFiNI.jpg'),
(71864, 4922, 'Reservation Dogs S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2AQw5ab4EbEggpyJtl6xRCcsISs.jpg'),
(71865, 4922, 'Reservation Dogs S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/njFjGrT47Cl5AFF9qyAqAb0FwRw.jpg'),
(71866, 4922, 'Reservation Dogs S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qKrmlKmN8qxEUhmBgs0zGxGhzyM.jpg'),
(71867, 4922, 'Reservation Dogs S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhjq0goLyqvQVhqXfx3gLlPwofa.jpg'),
(71868, 4922, 'Reservation Dogs S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fj78g8amS9KIreQ8ALjbYn4JMdd.jpg'),
(71869, 4923, 'Tá Puxado! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9jKtt6tBtN1hcVyY9skGpf3T0sk.jpg'),
(71870, 4923, 'Tá Puxado! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/GR3xNOZ8u3C9gCU8UMbDYTO8M0.jpg'),
(71871, 4923, 'Tá Puxado! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hOolV60o1wD6y6HYPAY74dMzvff.jpg'),
(71872, 4923, 'Tá Puxado! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/njQXyYCtNFrvW8Z8uvcNAjVGNAl.jpg'),
(71873, 4923, 'Tá Puxado! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5GvBrfbSGxDJsoRCG6DXZAIENDN.jpg'),
(71874, 4923, 'Tá Puxado! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pBSWEcSjFqO07mK3v5wk65QypLs.jpg'),
(71875, 4923, 'Tá Puxado! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/66kxw0zzi8nhvWMqcho2R7l7b8Z.jpg'),
(71876, 4923, 'Tá Puxado! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kniEqyUOa2xJ7KXhopwsz9Pbi0G.jpg'),
(71877, 4923, 'Tá Puxado! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m13IB3R5Yp9VNU4iqiJpyyw8Epi.jpg'),
(71878, 4923, 'Tá Puxado! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dSfvxtnXUQaMGRiGA1NgwfNG3hJ.jpg'),
(71879, 4923, 'Tá Puxado! S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xujOoBdleU01MtCLiWVWesrVHOi.jpg'),
(71880, 4923, 'Tá Puxado! S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tE06GpFhtsfzqeQfvgQw0xS9aqE.jpg'),
(71881, 4923, 'Tá Puxado! S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/164964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hChXWcqLhbtaEiv6q0TyxNRYMNV.jpg'),
(71882, 4923, 'Tá Puxado! S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/164965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzNLTGhwfb3Nax431ZZyKOUqdOo.jpg'),
(71883, 4923, 'Tá Puxado! S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/164966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4jBtUpCSKGTkXxgVymVM5hc7Vt.jpg'),
(71884, 4923, 'Tá Puxado! S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/164967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ytfFyAEHmh9MWfdCXsyWQrRaZvR.jpg'),
(71885, 4923, 'Tá Puxado! S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/164968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sseMAAh8W00t1pOrAl3hLgZ1oT6.jpg'),
(71886, 4923, 'Tá Puxado! S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/164969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3pDnE8q6jZWPYsjImEubOZTFf1o.jpg'),
(71887, 4923, 'Tá Puxado! S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/164970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6WtwE2ZIvf9mVFrCfZf2ODYoLXE.jpg'),
(71888, 4923, 'Tá Puxado! S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/164971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j7BRw9wA6sScNVaFUDeBuwt9Fps.jpg'),
(71889, 4923, 'Tá Puxado! S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/164972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rjPdlPH4te5vFG7U8JxsjMlrRL.jpg'),
(71890, 4923, 'Tá Puxado! S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/164973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9R22YwjoiEmjWf5V0oEsGgx8VnD.jpg'),
(71891, 4923, 'Tá Puxado! S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/164974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4Uurpdbp9UAOZQ94qiKaJa1a06.jpg'),
(71892, 4923, 'Tá Puxado! S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/164975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wIVH81NYLWQCysoZVqBl1nFzJ0w.jpg'),
(71893, 4923, 'Tá Puxado! S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/164976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oZjJUHTaxcBjZCZK7lmUNhWNjfH.jpg'),
(71894, 4923, 'Tá Puxado! S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/164977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l3sV7rsZhHvmEc1D2fRIPCaHUBf.jpg'),
(71895, 4924, 'Tipo Isso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8vZDn9D1T5rS6LM433TbvdTnFi0.jpg'),
(71896, 4924, 'Tipo Isso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zxdR8OVk1a0mknX1UJFiNRLsqWF.jpg'),
(71897, 4924, 'Tipo Isso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1AWSZJ7e0j4SbHNU9YybYSAoLqn.jpg'),
(71898, 4924, 'Tipo Isso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sYWuq7c9Ql9ySbDsBaqNyFhS9bx.jpg'),
(71899, 4924, 'Tipo Isso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aX7W0gA10yBYqYMIzEDzLzxGiLf.jpg'),
(71900, 4924, 'Tipo Isso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hAR7EARsaqR4DgwGh4DqJYtVEMK.jpg'),
(71901, 4924, 'Tipo Isso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ong0ZfopazsFpLx39nEjuxpoHxl.jpg'),
(71902, 4924, 'Tipo Isso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l3otwqspG8fB6onnIYpaKHTuOxq.jpg'),
(71903, 4925, 'Tipo Isso S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vph2C5UhE2OdDlg1OrGnu21wnnI.jpg'),
(71904, 4925, 'Tipo Isso S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vph2C5UhE2OdDlg1OrGnu21wnnI.jpg'),
(71905, 4925, 'Tipo Isso S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vph2C5UhE2OdDlg1OrGnu21wnnI.jpg'),
(71906, 4925, 'Tipo Isso S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vph2C5UhE2OdDlg1OrGnu21wnnI.jpg'),
(71907, 4925, 'Tipo Isso S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vph2C5UhE2OdDlg1OrGnu21wnnI.jpg'),
(71908, 4925, 'Tipo Isso S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vph2C5UhE2OdDlg1OrGnu21wnnI.jpg'),
(71909, 4925, 'Tipo Isso S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vph2C5UhE2OdDlg1OrGnu21wnnI.jpg'),
(71910, 4925, 'Tipo Isso S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vph2C5UhE2OdDlg1OrGnu21wnnI.jpg'),
(71911, 4926, 'Tipo Isso S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vph2C5UhE2OdDlg1OrGnu21wnnI.jpg'),
(71912, 4926, 'Tipo Isso S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vph2C5UhE2OdDlg1OrGnu21wnnI.jpg'),
(71913, 4926, 'Tipo Isso S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/270751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vph2C5UhE2OdDlg1OrGnu21wnnI.jpg'),
(71914, 4926, 'Tipo Isso S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/270752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vph2C5UhE2OdDlg1OrGnu21wnnI.jpg'),
(71915, 4926, 'Tipo Isso S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/270753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vph2C5UhE2OdDlg1OrGnu21wnnI.jpg'),
(71916, 4926, 'Tipo Isso S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/270754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vph2C5UhE2OdDlg1OrGnu21wnnI.jpg'),
(71917, 4926, 'Tipo Isso S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/270755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vph2C5UhE2OdDlg1OrGnu21wnnI.jpg'),
(71918, 4926, 'Tipo Isso S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/270756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vph2C5UhE2OdDlg1OrGnu21wnnI.jpg'),
(71919, 4927, 'Vidrados no Natal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xSard8xs0gFgQnQBTqsADc9vR3w.jpg'),
(71920, 4927, 'Vidrados no Natal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xSard8xs0gFgQnQBTqsADc9vR3w.jpg'),
(71921, 4927, 'Vidrados no Natal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xSard8xs0gFgQnQBTqsADc9vR3w.jpg'),
(71922, 4927, 'Vidrados no Natal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xSard8xs0gFgQnQBTqsADc9vR3w.jpg'),
(71923, 4928, 'A Mais Pura Verdade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBGAqV9yQ2d7myFRuwztaHkzSRm.jpg'),
(71924, 4928, 'A Mais Pura Verdade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8y6SHiMEfCJlHxRzngzK9Qa8WNn.jpg'),
(71925, 4928, 'A Mais Pura Verdade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nf1refZU9an17w3thSlYzi7CPoZ.jpg'),
(71926, 4928, 'A Mais Pura Verdade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/37MeOtcSC7iyobfAOTvUAWevMYl.jpg'),
(71927, 4928, 'A Mais Pura Verdade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kjCnzEHmYG8VCg2Svaa4vGisegP.jpg'),
(71928, 4928, 'A Mais Pura Verdade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fgiipXFMtebtFRkBBXjq0qeLALZ.jpg'),
(71929, 4928, 'A Mais Pura Verdade S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3mVdG7AIlxpVFgU4xqHiFZmOzmb.jpg'),
(71930, 4929, 'Acesso Total: Botafogo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9R120FjqxqSX65gLUTA6mLKuQK.jpg'),
(71931, 4929, 'Acesso Total: Botafogo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aD8xaii9dWjtM2YEtBTXDlUU9y9.jpg'),
(71932, 4929, 'Acesso Total: Botafogo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5sJAj7eEOSTwe2IpyhlOTgz5w6m.jpg'),
(71933, 4929, 'Acesso Total: Botafogo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/epcLp6mu7FoAQ3JTDG8RfkiMu1C.jpg'),
(71934, 4929, 'Acesso Total: Botafogo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9R120FjqxqSX65gLUTA6mLKuQK.jpg'),
(71935, 4929, 'Acesso Total: Botafogo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9R120FjqxqSX65gLUTA6mLKuQK.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(71936, 4929, 'Acesso Total: Botafogo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9R120FjqxqSX65gLUTA6mLKuQK.jpg'),
(71937, 4929, 'Acesso Total: Botafogo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9R120FjqxqSX65gLUTA6mLKuQK.jpg'),
(71938, 4930, 'Alasca: Reabilitação Selvagem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wH8q5G6NM5ZSoeqxBT8u9DH1eTg.jpg'),
(71939, 4930, 'Alasca: Reabilitação Selvagem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wH8q5G6NM5ZSoeqxBT8u9DH1eTg.jpg'),
(71940, 4930, 'Alasca: Reabilitação Selvagem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wH8q5G6NM5ZSoeqxBT8u9DH1eTg.jpg'),
(71941, 4930, 'Alasca: Reabilitação Selvagem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wH8q5G6NM5ZSoeqxBT8u9DH1eTg.jpg'),
(71942, 4930, 'Alasca: Reabilitação Selvagem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wH8q5G6NM5ZSoeqxBT8u9DH1eTg.jpg'),
(71943, 4930, 'Alasca: Reabilitação Selvagem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wH8q5G6NM5ZSoeqxBT8u9DH1eTg.jpg'),
(71944, 4931, 'Edens Zero S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2IoGPJ4xBOEs94mcMND37y9f1dk.jpg'),
(71945, 4931, 'Edens Zero S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t4sHDCQnWTdgzOhZQY76r5HZE5i.jpg'),
(71946, 4931, 'Edens Zero S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vz766s2yRxcHV6lClsC2pTsED79.jpg'),
(71947, 4931, 'Edens Zero S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rlt1SOz4PPztFY59uUqEsEc6xMg.jpg'),
(71948, 4931, 'Edens Zero S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/65bP4LJGzxUECNLqg7bhQgAiZDh.jpg'),
(71949, 4931, 'Edens Zero S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pYkV7NnTRoBuNGNGsmwZa2T029L.jpg'),
(71950, 4931, 'Edens Zero S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eC4x46hgTsOSXUqrPZs2peO7Gww.jpg'),
(71951, 4931, 'Edens Zero S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7kEhyFgdD98VS6YxopEVeZSIGSi.jpg'),
(71952, 4931, 'Edens Zero S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w6mUJ7XNPZ4v80HQA3blX1syxBu.jpg'),
(71953, 4931, 'Edens Zero S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uN8Z5of02zJFaDQPxxuPoTfmfmN.jpg'),
(71954, 4931, 'Edens Zero S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ubqeKJZdrntqgrgzcgBcOlLZXyj.jpg'),
(71955, 4931, 'Edens Zero S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJafjQmws074rXLAxbha6DDH5DH.jpg'),
(71956, 4931, 'Edens Zero S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/164872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gKXJQCGTtPJMseE8lexc4azaAFu.jpg'),
(71957, 4931, 'Edens Zero S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/164873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h8T7AdfFSyQoqQHodJrxSPWJrDT.jpg'),
(71958, 4931, 'Edens Zero S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/164874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hjPT1nwBXt62GwWhO0xJ2z5PD4a.jpg'),
(71959, 4931, 'Edens Zero S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/164875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lkelvoxCFLrfbpo12TlWJ0Eixmb.jpg'),
(71960, 4931, 'Edens Zero S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/164876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jlJzEdG7wWtiT6Eoqk2ApfjqHBF.jpg'),
(71961, 4931, 'Edens Zero S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/164877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nZvobblvi6GROQLL8Dn89psrN4e.jpg'),
(71962, 4931, 'Edens Zero S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/164878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nVFHVMkiKltWUUEWGJvB3uE3ddP.jpg'),
(71963, 4931, 'Edens Zero S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/164879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jaUsXdTPv99lhOaGDbvTPgA7ya5.jpg'),
(71964, 4931, 'Edens Zero S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/164880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xAMyjNbtEDWOA3R7XQXz8aoX7V8.jpg'),
(71965, 4931, 'Edens Zero S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/164881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ji5fF2bNc7ISiWV54dbl9Z9jH6E.jpg'),
(71966, 4931, 'Edens Zero S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/164882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ceQ5Ed2Oej2hlXO4T276fqGCbe4.jpg'),
(71967, 4931, 'Edens Zero S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/164883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e4n2MRwrB6DrbkIXs7RMxclHUMF.jpg'),
(71968, 4931, 'Edens Zero S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/164884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iBMMoXepXQp3HFz2N01GlUhs1iN.jpg'),
(71969, 4932, 'Comando Estelar Flashman S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8fQx1JqJFwvBfiak0x2PhFgW9Su.jpg'),
(71970, 4932, 'Comando Estelar Flashman S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mQKCGUWQFwSyfO4Ld8gfLFOyhM1.jpg'),
(71971, 4932, 'Comando Estelar Flashman S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQermkNor9mwvQ3fu1ClMC0H2qT.jpg'),
(71972, 4932, 'Comando Estelar Flashman S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71973, 4932, 'Comando Estelar Flashman S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71974, 4932, 'Comando Estelar Flashman S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71975, 4932, 'Comando Estelar Flashman S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71976, 4932, 'Comando Estelar Flashman S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71977, 4932, 'Comando Estelar Flashman S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71978, 4932, 'Comando Estelar Flashman S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71979, 4932, 'Comando Estelar Flashman S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71980, 4932, 'Comando Estelar Flashman S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71981, 4932, 'Comando Estelar Flashman S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/164897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71982, 4932, 'Comando Estelar Flashman S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/164898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71983, 4932, 'Comando Estelar Flashman S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/164899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71984, 4932, 'Comando Estelar Flashman S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/164900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71985, 4932, 'Comando Estelar Flashman S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/164901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71986, 4932, 'Comando Estelar Flashman S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/164902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71987, 4932, 'Comando Estelar Flashman S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/164903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71988, 4932, 'Comando Estelar Flashman S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/164904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71989, 4932, 'Comando Estelar Flashman S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/164905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71990, 4932, 'Comando Estelar Flashman S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/164906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71991, 4932, 'Comando Estelar Flashman S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/164907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71992, 4932, 'Comando Estelar Flashman S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/164908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71993, 4932, 'Comando Estelar Flashman S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/164909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71994, 4932, 'Comando Estelar Flashman S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/164910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71995, 4932, 'Comando Estelar Flashman S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/164911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71996, 4932, 'Comando Estelar Flashman S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/164912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71997, 4932, 'Comando Estelar Flashman S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/164913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71998, 4932, 'Comando Estelar Flashman S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/164914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(71999, 4932, 'Comando Estelar Flashman S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/164915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(72000, 4932, 'Comando Estelar Flashman S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/164916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(72001, 4932, 'Comando Estelar Flashman S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/164917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(72002, 4932, 'Comando Estelar Flashman S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/164918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(72003, 4932, 'Comando Estelar Flashman S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/164919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(72004, 4932, 'Comando Estelar Flashman S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/164920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(72005, 4932, 'Comando Estelar Flashman S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/164921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(72006, 4932, 'Comando Estelar Flashman S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/164922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(72007, 4932, 'Comando Estelar Flashman S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/164923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(72008, 4932, 'Comando Estelar Flashman S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/164924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(72009, 4932, 'Comando Estelar Flashman S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/164925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(72010, 4932, 'Comando Estelar Flashman S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/164926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(72011, 4932, 'Comando Estelar Flashman S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/164927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(72012, 4932, 'Comando Estelar Flashman S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/164928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(72013, 4932, 'Comando Estelar Flashman S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/164929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(72014, 4932, 'Comando Estelar Flashman S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/164930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(72015, 4932, 'Comando Estelar Flashman S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/164931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(72016, 4932, 'Comando Estelar Flashman S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/164932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(72017, 4932, 'Comando Estelar Flashman S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/164933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(72018, 4932, 'Comando Estelar Flashman S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/164934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jlvGYATgv5bVbP2tybmqIdd7rS.jpg'),
(72019, 4933, 'Jiban - O Policial de Aço S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bWnORgRZtIiPb6Tu2cKWj4DPtwr.jpg'),
(72020, 4933, 'Jiban - O Policial de Aço S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBGpomFVarm1bmYXyY2TYMrqyMk.jpg'),
(72021, 4933, 'Jiban - O Policial de Aço S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqCYVTGqkmwcEBudKGdBHSgKIul.jpg'),
(72022, 4933, 'Jiban - O Policial de Aço S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wEf508IvvtQ9ZCKae9wvfWLYjBQ.jpg'),
(72023, 4933, 'Jiban - O Policial de Aço S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5CG97p5ZGeub6CyKSvC7WmGVf2T.jpg'),
(72024, 4933, 'Jiban - O Policial de Aço S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqhCEzVvWBAMme266t82yuDPjGU.jpg'),
(72025, 4933, 'Jiban - O Policial de Aço S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6R0WlkLEkYCLBuoKkrzWZuol0gn.jpg'),
(72026, 4933, 'Jiban - O Policial de Aço S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i1HRJ4XJo22RDsslHjZAFNDSpP7.jpg'),
(72027, 4933, 'Jiban - O Policial de Aço S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gR1gnflr3tDQsMPy0iPed5ikMZd.jpg'),
(72028, 4933, 'Jiban - O Policial de Aço S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJFEUVFF4kTEiOhSTjHD2DGvQYA.jpg'),
(72029, 4933, 'Jiban - O Policial de Aço S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sgb2wSkfTCEA2VHmZwgok7YQWS7.jpg'),
(72030, 4933, 'Jiban - O Policial de Aço S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kUnopzIjswq5wz88FpimEk8Xz7G.jpg'),
(72031, 4933, 'Jiban - O Policial de Aço S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/164820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8GvXSSBdfWLgS9Opt2GkMYPyQL6.jpg'),
(72032, 4933, 'Jiban - O Policial de Aço S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/164821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cc5qeFlR6DtAMTttZQgMLkPW78W.jpg'),
(72033, 4933, 'Jiban - O Policial de Aço S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/164822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7l9iU9d4liXKgPvE8ICJKLAXlo5.jpg'),
(72034, 4933, 'Jiban - O Policial de Aço S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/164823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjuT3QBpEFlgyQRSPBtbOCsdDnz.jpg'),
(72035, 4933, 'Jiban - O Policial de Aço S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/164824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gzGtDqGSiqdXHEUxAF100JuA01X.jpg'),
(72036, 4933, 'Jiban - O Policial de Aço S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/164825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lMW9zZbRLwRn7Qq84PS7wFb5zwP.jpg'),
(72037, 4933, 'Jiban - O Policial de Aço S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/164826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7AIrdtAdG9ditXTjiy5lF4S1W5N.jpg'),
(72038, 4933, 'Jiban - O Policial de Aço S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/164827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yRL9LeDEegcIj3ZfZUVID3JhZwi.jpg'),
(72039, 4933, 'Jiban - O Policial de Aço S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/164828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfEOx3fcr728fXiQH4KEjiIBvK0.jpg'),
(72040, 4933, 'Jiban - O Policial de Aço S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/164829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9CSC8Y8lUdfMHna6F5nKcOEwOYb.jpg'),
(72041, 4933, 'Jiban - O Policial de Aço S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/164830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4mxOyYTS4cGrCZQUmVFaJvKXRb5.jpg'),
(72042, 4933, 'Jiban - O Policial de Aço S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/164831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n7FECthUmY1pv7rDfRKWdT2DoHv.jpg'),
(72043, 4933, 'Jiban - O Policial de Aço S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/164832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/47R6XabCZIQZVm2XIzDLyEXpbrn.jpg'),
(72044, 4933, 'Jiban - O Policial de Aço S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/164833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fc5OCPXR67dHvAK2lAZkh1Ym7TY.jpg'),
(72045, 4933, 'Jiban - O Policial de Aço S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/164834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lC6gSHFYKKOVoEMLQ5SoCyXiGvq.jpg'),
(72046, 4933, 'Jiban - O Policial de Aço S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/164835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dF5fu65IzThVUfwIbWmyeqe3uF3.jpg'),
(72047, 4933, 'Jiban - O Policial de Aço S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/164836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y3DhQpn4GauaPgXpo2lVgkPrjP.jpg'),
(72048, 4933, 'Jiban - O Policial de Aço S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/164837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2nAUJGxHgUrxVsIKRx09UCcWGi.jpg'),
(72049, 4933, 'Jiban - O Policial de Aço S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/164838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4llCwk8cT5lcQAgnqCrm6FXuPgD.jpg'),
(72050, 4933, 'Jiban - O Policial de Aço S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/164839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/szFnqY8tFcebfigvG0Nh3haMhE.jpg'),
(72051, 4933, 'Jiban - O Policial de Aço S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/164840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/giMrllwmUzpDWDsM5EKJZKqnsCT.jpg'),
(72052, 4933, 'Jiban - O Policial de Aço S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/164841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3FvcrwOdb2M0EDRPeIDY3y7tFta.jpg'),
(72053, 4933, 'Jiban - O Policial de Aço S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/164842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n2EaO5LtldDFMhZTTWM1GaIT76J.jpg'),
(72054, 4933, 'Jiban - O Policial de Aço S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/164843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5X1qM8nhKEcpLrpqMTrxiWvmTGy.jpg'),
(72055, 4933, 'Jiban - O Policial de Aço S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/164844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvqkktPkpkRCjHQ5BVeCK2Ef5RG.jpg'),
(72056, 4933, 'Jiban - O Policial de Aço S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/164845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pO0vQT3OOYlO427qI4sVDOqc9pZ.jpg'),
(72057, 4933, 'Jiban - O Policial de Aço S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/164846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/knZjOB9TmXUynu6aUca3RA8C6p6.jpg'),
(72058, 4933, 'Jiban - O Policial de Aço S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/164847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t6jdiknNv6hskGVwaXuz2voenM4.jpg'),
(72059, 4933, 'Jiban - O Policial de Aço S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/164848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1yjvpO9khQyxCJMQfE4TQiJ9bCM.jpg'),
(72060, 4933, 'Jiban - O Policial de Aço S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/164849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ikQEitJuVdHYGd3pyUG535wSNpn.jpg'),
(72061, 4933, 'Jiban - O Policial de Aço S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/164850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oiQDTCdq759uKHi0sDlqGdZya7s.jpg'),
(72062, 4933, 'Jiban - O Policial de Aço S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/164851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ix8QvuheYMEYFCpuMK3qUtKvl5E.jpg'),
(72063, 4933, 'Jiban - O Policial de Aço S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/164852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKgWp0xv7FywezqgIbGZ5W7ItV3.jpg'),
(72064, 4933, 'Jiban - O Policial de Aço S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/164853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qFkhNw4EiK12uS1rrDjkpbvtBpt.jpg'),
(72065, 4933, 'Jiban - O Policial de Aço S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/164854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gunkXoazL2tPhH9qRGCxr7yvBmg.jpg'),
(72066, 4933, 'Jiban - O Policial de Aço S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/164855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLDj6ADEQ70sJNNH0blWCSpRCDp.jpg'),
(72067, 4933, 'Jiban - O Policial de Aço S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/164856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uAQcAN6zBrFfYPE5pe2DYEh8bUw.jpg'),
(72068, 4933, 'Jiban - O Policial de Aço S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/164857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/emblobFfbByiGpnAK2l4KD2BJhG.jpg'),
(72069, 4933, 'Jiban - O Policial de Aço S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/164858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sSD7tU1k3QnkHQH2yIzB3fVqOWb.jpg'),
(72070, 4933, 'Jiban - O Policial de Aço S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/164859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yL3HbKUlaI84OvdMeZHS7CAsj5h.jpg'),
(72071, 4934, 'Law & Order: Crime Organizado (2021) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDVqhraEF3PInGokpn4WApkqyko.jpg'),
(72072, 4934, 'Law & Order: Crime Organizado (2021) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AevkLn3cDytNA5NoA2GLIHJPYwK.jpg'),
(72073, 4934, 'Law & Order: Crime Organizado (2021) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6CI8kmqTopou6hnRokeXh8GZ15o.jpg'),
(72074, 4934, 'Law & Order: Crime Organizado (2021) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2V3gSicFibeOELK3wW42ftHZAS.jpg'),
(72075, 4934, 'Law & Order: Crime Organizado (2021) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hwx3UXPbYz7OXXsmy4MsuM4R3Ap.jpg'),
(72076, 4934, 'Law & Order: Crime Organizado (2021) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rgINc6nrCR0ZTnuqwI97K7pRPAr.jpg'),
(72077, 4934, 'Law & Order: Crime Organizado (2021) S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fwVAgLOzbxZHbwgFO09aCf3Zeb9.jpg'),
(72078, 4934, 'Law & Order: Crime Organizado (2021) S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nv7IQzXdb3GVdch69HlfFr15N3q.jpg'),
(72079, 4935, 'Law & Order: Crime Organizado (2021) S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194646.mp4', 'http://timg.bdta.pro/images/ca4811a484f3ec92a6fac39ca582a083.jpg'),
(72080, 4935, 'Law & Order: Crime Organizado (2021) S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194647.mp4', 'http://timg.bdta.pro/images/341dff818b05b728f332ac4ee718e1b2.jpg'),
(72081, 4935, 'Law & Order: Crime Organizado (2021) S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194648.mp4', 'http://timg.bdta.pro/images/e217a81c385cadd8d02b8998169b6bab.jpg'),
(72082, 4935, 'Law & Order: Crime Organizado (2021) S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194649.mp4', 'http://timg.bdta.pro/images/cf9b4e743c8329054289d5e2ee5dab52.jpg'),
(72083, 4935, 'Law & Order: Crime Organizado (2021) S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194650.mp4', 'http://timg.bdta.pro/images/af61790a35949facf743517d812fc3bc.jpg'),
(72084, 4935, 'Law & Order: Crime Organizado (2021) S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194651.mp4', 'http://timg.bdta.pro/images/956f226070205e797f0b6bf7bbf56ee2.jpg'),
(72085, 4935, 'Law & Order: Crime Organizado (2021) S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194652.mp4', 'http://timg.bdta.pro/images/1566e5fc95ffbc6c0ded4c2da1d6dc76.jpg'),
(72086, 4935, 'Law & Order: Crime Organizado (2021) S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194653.mp4', 'http://timg.bdta.pro/images/2cae90aada87fd7bc69f1afc387ce112.jpg'),
(72087, 4935, 'Law & Order: Crime Organizado (2021) S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194654.mp4', 'http://timg.bdta.pro/images/53c268141cf74a458c2a3a00d34b23b9.jpg'),
(72088, 4935, 'Law & Order: Crime Organizado (2021) S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194655.mp4', 'http://timg.bdta.pro/images/947904e82c32402259fbc16dae336671.jpg'),
(72089, 4935, 'Law & Order: Crime Organizado (2021) S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194656.mp4', 'http://timg.bdta.pro/images/ed6b5ef31688f3a0f52615b1216a721a.jpg'),
(72090, 4935, 'Law & Order: Crime Organizado (2021) S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194657.mp4', 'http://timg.bdta.pro/images/0e0748e97b0119f992737ee81d96a348.jpg'),
(72091, 4935, 'Law & Order: Crime Organizado (2021) S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/194658.mp4', 'http://timg.bdta.pro/images/32ec2f148c575ed3f2bf426c17a75a0a.jpg'),
(72092, 4935, 'Law & Order: Crime Organizado (2021) S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/194659.mp4', 'http://timg.bdta.pro/images/6b3a8cd8e2c2e3f9fd5185443eb20a89.jpg'),
(72093, 4935, 'Law & Order: Crime Organizado (2021) S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/194660.mp4', 'http://timg.bdta.pro/images/3c4db71eaaf371fcc6564e53ba756d2e.jpg'),
(72094, 4935, 'Law & Order: Crime Organizado (2021) S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/194661.mp4', 'http://timg.bdta.pro/images/3a28d697fce54bf435cf07d6695000f4.jpg'),
(72095, 4935, 'Law & Order: Crime Organizado (2021) S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/194662.mp4', 'http://timg.bdta.pro/images/bc779d676cbba721efe6d4d631272bac.jpg'),
(72096, 4935, 'Law & Order: Crime Organizado (2021) S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/194663.mp4', 'http://timg.bdta.pro/images/922ed5358a14bd5cb16f0c32c4e53e09.jpg'),
(72097, 4935, 'Law & Order: Crime Organizado (2021) S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/194664.mp4', 'http://timg.bdta.pro/images/4c2c9d45ae1ca231211639b6adf68e7b.jpg'),
(72098, 4935, 'Law & Order: Crime Organizado (2021) S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/194665.mp4', 'http://timg.bdta.pro/images/c3251bb5340d7e7a184d7beb9b942ade.jpg'),
(72099, 4935, 'Law & Order: Crime Organizado (2021) S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/194666.mp4', 'http://timg.bdta.pro/images/c386d267d6791840415e44735b7da9a8.jpg'),
(72100, 4935, 'Law & Order: Crime Organizado (2021) S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/194667.mp4', 'http://timg.bdta.pro/images/a7d8516eea17d5e0949a0f801f341110.jpg'),
(72101, 4936, 'O Plano é Esse S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uPzbv159xTp7u9cvFdCI0Pl5CY.jpg'),
(72102, 4936, 'O Plano é Esse S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uPzbv159xTp7u9cvFdCI0Pl5CY.jpg'),
(72103, 4936, 'O Plano é Esse S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uPzbv159xTp7u9cvFdCI0Pl5CY.jpg'),
(72104, 4936, 'O Plano é Esse S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uPzbv159xTp7u9cvFdCI0Pl5CY.jpg'),
(72105, 4936, 'O Plano é Esse S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uPzbv159xTp7u9cvFdCI0Pl5CY.jpg'),
(72106, 4936, 'O Plano é Esse S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uPzbv159xTp7u9cvFdCI0Pl5CY.jpg'),
(72107, 4937, 'Platinum End S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/84rk6ZUXiQgozG5hSazNrr1eKap.jpg'),
(72108, 4937, 'Platinum End S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dNc0ywS0oPNOzMcgSaTjyBLQkMe.jpg'),
(72109, 4937, 'Platinum End S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198069.mp4', 'http://image.tmdb.org/t/p/w1280/euSmNCElVqwejRVZv0XGJqSVyMv.jpg'),
(72110, 4937, 'Platinum End S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198070.mp4', 'http://timg.bdta.pro/images/640b4c5c34004ecdf19d769c7300f455.jpg'),
(72111, 4937, 'Platinum End S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198071.mp4', 'http://timg.bdta.pro/images/fccd9e6aa5fd28ffc01fb59d5efdfc04.jpg'),
(72112, 4937, 'Platinum End S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198072.mp4', 'http://timg.bdta.pro/images/87daf031acb9ceb2fdf0d3d22f55a94a.jpg'),
(72113, 4937, 'Platinum End S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198073.mp4', 'http://timg.bdta.pro/images/bea065b568601ea169a8bbdc0068e3c2.jpg'),
(72114, 4937, 'Platinum End S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198074.mp4', 'http://timg.bdta.pro/images/771a771e708c51773adf316ee2d8cadf.jpg'),
(72115, 4937, 'Platinum End S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198075.mp4', 'http://timg.bdta.pro/images/5f776078d2f95b0339c9e0f109ea4b90.jpg'),
(72116, 4937, 'Platinum End S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198076.mp4', 'http://timg.bdta.pro/images/c8103f7643092333e3d2fabbe2d45dfe.jpg'),
(72117, 4937, 'Platinum End S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/198077.mp4', 'http://timg.bdta.pro/images/ee60c657c17786b085392b2bc05d6e36.jpg'),
(72118, 4937, 'Platinum End S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/198078.mp4', 'http://timg.bdta.pro/images/fb67007660c988c84ac09c1d01ec05df.jpg'),
(72119, 4937, 'Platinum End S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/198079.mp4', 'http://timg.bdta.pro/images/35a4b631b92b31243d7e14abef81a83a.jpg'),
(72120, 4937, 'Platinum End S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/198080.mp4', 'http://timg.bdta.pro/images/9dba9423329237c339da47b4ebae7c42.jpg'),
(72121, 4937, 'Platinum End S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/198081.mp4', 'http://timg.bdta.pro/images/6f2599a3252364793929bbafcbcadc05.jpg'),
(72122, 4937, 'Platinum End S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/198082.mp4', 'http://timg.bdta.pro/images/b5c608a239c492da0724c7f27f62835a.jpg'),
(72123, 4937, 'Platinum End S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/198083.mp4', 'http://timg.bdta.pro/images/8b618e419a03012d9f2ff0e5b8bdc3e1.jpg'),
(72124, 4937, 'Platinum End S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/198084.mp4', 'http://timg.bdta.pro/images/310a425e6c3d6558734ce63c0cb78401.jpg'),
(72125, 4937, 'Platinum End S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/198085.mp4', 'http://timg.bdta.pro/images/e07d45f3318178586749f001a4797657.jpg'),
(72126, 4937, 'Platinum End S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/198086.mp4', 'http://timg.bdta.pro/images/2d63ebb1dca7569e07d8003032ede1ca.jpg'),
(72127, 4937, 'Platinum End S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/198087.mp4', 'http://timg.bdta.pro/images/c7a25dec02a51334df68aa916b1e770f.jpg'),
(72128, 4937, 'Platinum End S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/198088.mp4', 'http://timg.bdta.pro/images/12a8a67f9bfaa72c433162b369cd0e25.jpg'),
(72129, 4937, 'Platinum End S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/198089.mp4', 'http://timg.bdta.pro/images/ceb5bafa6b77c8929c14d156b65777c7.jpg'),
(72130, 4937, 'Platinum End S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/198090.mp4', 'http://timg.bdta.pro/images/3838c56a0ab88f4723f390413b699e30.jpg'),
(72131, 4938, 'Sakugan S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9e63OMcsUOs7chyxj4lpiIweBWZ.jpg'),
(72132, 4939, 'School of Chocolate S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pgPaIeoE5wOI6eflvfGbZqpHduv.jpg'),
(72133, 4939, 'School of Chocolate S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pgPaIeoE5wOI6eflvfGbZqpHduv.jpg'),
(72134, 4939, 'School of Chocolate S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pgPaIeoE5wOI6eflvfGbZqpHduv.jpg'),
(72135, 4939, 'School of Chocolate S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pgPaIeoE5wOI6eflvfGbZqpHduv.jpg'),
(72136, 4939, 'School of Chocolate S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pgPaIeoE5wOI6eflvfGbZqpHduv.jpg'),
(72137, 4939, 'School of Chocolate S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pgPaIeoE5wOI6eflvfGbZqpHduv.jpg'),
(72138, 4939, 'School of Chocolate S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pgPaIeoE5wOI6eflvfGbZqpHduv.jpg'),
(72139, 4939, 'School of Chocolate S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pgPaIeoE5wOI6eflvfGbZqpHduv.jpg'),
(72140, 4940, 'Shameless S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Tc8Frb7FQ7M6PuvTy5y6Ku2okW.jpg'),
(72141, 4940, 'Shameless S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qPHQCMYtZLH1JB9cbqvT9ea4gMr.jpg'),
(72142, 4940, 'Shameless S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7dFOY3RDAlSTeEf24OqWoLg4xyh.jpg'),
(72143, 4940, 'Shameless S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hD52DDGxzlXOlzQQlviJjFFxSgj.jpg'),
(72144, 4940, 'Shameless S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xH5j3tDhYx1GMp6hjRsZZPu6oSF.jpg'),
(72145, 4940, 'Shameless S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6L0XhfM9XBrNux7uHuyESzkHCG.jpg'),
(72146, 4940, 'Shameless S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pAOwT92JXdJdWRsT8uilqZOTtR8.jpg'),
(72147, 4940, 'Shameless S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vKRqYWkYJnfq8zG1isdVacTCLSR.jpg'),
(72148, 4940, 'Shameless S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/js1jVtUs2RQw0qX0ZKPJkNddSsF.jpg'),
(72149, 4940, 'Shameless S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pn4oSP86rVl8x6IzrlZi5PyeQ0C.jpg'),
(72150, 4940, 'Shameless S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aMtDmWFwvS8smsg7b0pGR7FOYMb.jpg'),
(72151, 4940, 'Shameless S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p5IKpyElBPOmHo9oJMDTKZ3SNAB.jpg'),
(72152, 4941, 'Shameless S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ItVQgm7OuHLehY77Nuj6uJrd4V.jpg'),
(72153, 4941, 'Shameless S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8chEVE1Rr3yIoKp4Z7Av3S4prcS.jpg'),
(72154, 4941, 'Shameless S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eS3I3d0Flo0OtLRwaN0X4cDt0Dz.jpg'),
(72155, 4941, 'Shameless S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v7EaG4qelxKqCBwNhUvA0t4zNdN.jpg'),
(72156, 4941, 'Shameless S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e5QTopt7sZWywDJoiWjBgRoaqB4.jpg'),
(72157, 4941, 'Shameless S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odUaAQWwnCVAs2dObXx2v66GnuP.jpg'),
(72158, 4941, 'Shameless S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gmNMCrhmu6t8Zlm8ijjdWis14gD.jpg'),
(72159, 4941, 'Shameless S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4pXJjekpa3ccPT3HNbMm952pLqo.jpg'),
(72160, 4941, 'Shameless S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/solvTKhy5AltH7t12Y0ZtNBj4sI.jpg'),
(72161, 4941, 'Shameless S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fjHxfIa9oyJrgQQ0OwTGFn5ktzC.jpg'),
(72162, 4941, 'Shameless S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h6dfGV5IpiPsSQ4Rt7ficjp4Yhg.jpg'),
(72163, 4941, 'Shameless S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4XT34OtzFw9URnr2JquIxrPO12W.jpg'),
(72164, 4942, 'Shameless S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13msytnxJ7mVH11fDG3IIVtrUUR.jpg'),
(72165, 4942, 'Shameless S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lO4AxV2hSmP4UmVRatUMHoAqOFj.jpg'),
(72166, 4942, 'Shameless S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t8RL7UNO3DQHmKj6I1v6epfYT0J.jpg'),
(72167, 4942, 'Shameless S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3dJfiSPAQ3ZiWQmT3h8rLIbKlzI.jpg'),
(72168, 4942, 'Shameless S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3a7gM2RFlCmY4nAOtK13y8VF2sp.jpg'),
(72169, 4942, 'Shameless S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8jY8spUGjU1uQvsWftQb0bbqbEn.jpg'),
(72170, 4942, 'Shameless S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jxkVJHvlBf12BtfpqDJqp0TwYvP.jpg'),
(72171, 4942, 'Shameless S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mdQ15OwooFxrRo6QltcMQ0PE718.jpg'),
(72172, 4942, 'Shameless S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/TL9jutgbEyC2viHDkjMqigT8w9.jpg'),
(72173, 4942, 'Shameless S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/urJKfuxxw1l0eN4ae2wqLC20Uu6.jpg'),
(72174, 4942, 'Shameless S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nZIeauWGypB4zsSRBMXF2luCFMs.jpg'),
(72175, 4942, 'Shameless S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w0wK6ky15IN8VhUnOPCiqijTo7r.jpg'),
(72176, 4943, 'Shameless S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kgdpSUYPL1o19r2y3Bq0fbsEfmD.jpg'),
(72177, 4943, 'Shameless S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kZsqL8N1PfXQdMVLgCuZ14881rZ.jpg'),
(72178, 4943, 'Shameless S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z9HtBuiyE6LdkEbrIJlVfa9RyRz.jpg'),
(72179, 4943, 'Shameless S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w6MulNroi3MtdeiB45TjuHLfnmD.jpg'),
(72180, 4943, 'Shameless S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0SwEVAKLyb6HKchzVRoaCzt5aH.jpg'),
(72181, 4943, 'Shameless S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AffEBlPuLbPFZHkcHMv6n5Ovcnc.jpg'),
(72182, 4943, 'Shameless S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3bxqT0V9A9RQQe6Ku4fLmQYONVo.jpg'),
(72183, 4943, 'Shameless S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/upMr3i8T4g3JnJPVybVB2vG5khv.jpg'),
(72184, 4943, 'Shameless S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2RXMGlksrTzyMjX614Nz39gSve0.jpg'),
(72185, 4943, 'Shameless S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A4iv6wenBNSJGgCVwvGGSA1nv5w.jpg'),
(72186, 4943, 'Shameless S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5g36I0XQY3VAJjMOPAHbL3Dn0q9.jpg'),
(72187, 4943, 'Shameless S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ziEHl0LL7mnAsRFOhSbyNwJFodd.jpg'),
(72188, 4944, 'Shameless S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6uY06mCfQqQSZG9bZqarne8oiD7.jpg'),
(72189, 4944, 'Shameless S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fA0S64RuLClYPd76h254DUsRtnt.jpg'),
(72190, 4944, 'Shameless S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/skab8kUHsw5SDAF9fNEtFvN4eXp.jpg'),
(72191, 4944, 'Shameless S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5qJoiceVtEmsHTNH1jm4h7X7Hs2.jpg'),
(72192, 4944, 'Shameless S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ofsUde9VbQCJED7PRZ976UftDZs.jpg'),
(72193, 4944, 'Shameless S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7TvBNt57KW1uRHd08SeQBEowy0A.jpg'),
(72194, 4944, 'Shameless S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFtu6111ZwEx9MQP3VDHSjnlGs8.jpg'),
(72195, 4944, 'Shameless S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iLd8IZDYAgCBzjppIbfxVWE07He.jpg'),
(72196, 4944, 'Shameless S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6UXc1PZ22Ja8pffXRA81yjq92HO.jpg'),
(72197, 4944, 'Shameless S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oWqloJFHUQ9Mm7z0uo7XMuAWEfD.jpg'),
(72198, 4944, 'Shameless S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zjiqebJC0DspA39WHECWyZHuRGg.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(72199, 4944, 'Shameless S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/23c0rN3hsRmjgxogFjP2IcQkiFi.jpg'),
(72200, 4945, 'Shameless S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1aPVtgckjoC1NO83bCiDSYnh7iO.jpg'),
(72201, 4945, 'Shameless S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bJHtkc5z6SbpcYxH4CKr8eHbInK.jpg'),
(72202, 4945, 'Shameless S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/upbdXfvDISczDNeN2OMQB91zJaW.jpg'),
(72203, 4945, 'Shameless S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mdAiPada2gHV6IdUDWXVucQ022D.jpg'),
(72204, 4945, 'Shameless S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cBCIzkfvNiRixyPPCHWTt8OtJ3c.jpg'),
(72205, 4945, 'Shameless S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lqyf3Qds2KvPTOtwlMs6NVn0Fjg.jpg'),
(72206, 4945, 'Shameless S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aFFJ6n1MiABAKaPjkw1Zg7gZ7Ab.jpg'),
(72207, 4945, 'Shameless S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Ed9PBac4zbhQJq1y4sQZmiLg6q.jpg'),
(72208, 4945, 'Shameless S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jujxXGuS15f8PvjH1Klbo8iczKs.jpg'),
(72209, 4945, 'Shameless S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rf7bztr7ozagFDpqctwAW0tFaVh.jpg'),
(72210, 4945, 'Shameless S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4LonXDzBASKjXw5Kes2QV5G2UP8.jpg'),
(72211, 4945, 'Shameless S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x2BRGDXpLnckl0PlNkDtvEnBaMU.jpg'),
(72212, 4946, 'Shameless S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1RjfbrsJPp8pFEMZoR8LOp2g4ez.jpg'),
(72213, 4946, 'Shameless S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mDOM44lFoa80ZjqvwvGQNJE3uQA.jpg'),
(72214, 4946, 'Shameless S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5awa29I3fv0YEKfGuqYFWk4ymBn.jpg'),
(72215, 4946, 'Shameless S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pNnqjDSwpa4SQoJaNrA0RxdCDOY.jpg'),
(72216, 4946, 'Shameless S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mLF6V1SVdfcISLvqqKBaGmGlGL4.jpg'),
(72217, 4946, 'Shameless S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s6qaHuBuHHGy5kNAHOXounKJ2Lu.jpg'),
(72218, 4946, 'Shameless S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ghkRyhOIal9dH9ELbGfn4deC5Iz.jpg'),
(72219, 4946, 'Shameless S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kJkVZAM5LPXfYUZylyKc7KYgVIG.jpg'),
(72220, 4946, 'Shameless S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9OleLwXoYcdg7qUMhrq2846SNvy.jpg'),
(72221, 4946, 'Shameless S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3svhJGDXQlr7YufF6HPKWIFoYWc.jpg'),
(72222, 4946, 'Shameless S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fqwIfpYgzLhtUD2kJ9Oi0q8lnzR.jpg'),
(72223, 4946, 'Shameless S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/utRbGtSmmsF49U80wQvsdt1LLKa.jpg'),
(72224, 4947, 'Shameless S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7HGoqjNuUbjpLyhM2xJSt4JPTa3.jpg'),
(72225, 4947, 'Shameless S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aHZvRADDD10dc7DPF2QLjmAx0SK.jpg'),
(72226, 4947, 'Shameless S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9R4rXTD3ZOvIq4D6qsg8HFvPPYe.jpg'),
(72227, 4947, 'Shameless S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lTGqnWnuEHfziFMbim43M5qX1nz.jpg'),
(72228, 4947, 'Shameless S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1BRhJYxxLQGIpNdW4BYBFAzeKec.jpg'),
(72229, 4947, 'Shameless S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9mntMvrZmRUHzghiNEmx4fLVLNC.jpg'),
(72230, 4947, 'Shameless S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fMOQTEiSXuAmq7b2ehExwv5N7fM.jpg'),
(72231, 4947, 'Shameless S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6t55FkYbeiUB1hu6tvSV5YpAwAq.jpg'),
(72232, 4947, 'Shameless S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c7zXFIITEY1XWG62Fyqp99Zecxp.jpg'),
(72233, 4947, 'Shameless S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jo66AE5czB1Xe2zSngdY0VNLd9P.jpg'),
(72234, 4947, 'Shameless S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2XJBXH7UvyppBzwH1O7iLZYT3Lp.jpg'),
(72235, 4947, 'Shameless S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6vpLYKMumafDbRLIPe66trffWRi.jpg'),
(72236, 4948, 'Shameless S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nmNklhNeVN5VsLiWlU0ojpzpReY.jpg'),
(72237, 4948, 'Shameless S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vvVMCYuQgMBZzbo1smEUKPebbXb.jpg'),
(72238, 4948, 'Shameless S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hbkjOOF3tCjzpEJkQv2QGZmT6aR.jpg'),
(72239, 4948, 'Shameless S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3kEYDnWF2cvLGwzwJObK6ioPxoF.jpg'),
(72240, 4948, 'Shameless S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7FehmekHQ9bMdylwkWpjUz5i28e.jpg'),
(72241, 4948, 'Shameless S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ezD5eIwCyLy5vSrscsAOYt30cbp.jpg'),
(72242, 4948, 'Shameless S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dQ9i7gW43GvOw0xiKNIfGgOZICv.jpg'),
(72243, 4948, 'Shameless S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n7yjk9Z6PibgGZvaJsjHtzEEzLS.jpg'),
(72244, 4948, 'Shameless S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9NDmPewdSsxgkxLYvwL6KMZmDJ6.jpg'),
(72245, 4948, 'Shameless S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5NlB6TFCaH3CgxxDNThARIJHWNl.jpg'),
(72246, 4948, 'Shameless S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k38ivcJDVazLKWrHxy2SRzp8MPY.jpg'),
(72247, 4948, 'Shameless S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3zgfIfx5EOHNgGh14jCGGbGo0gF.jpg'),
(72248, 4949, 'Shameless S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQ8jvT4wKqR91j9pAu6MPAXDTdK.jpg'),
(72249, 4949, 'Shameless S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vM4AvDHpJ1q26DYOcXzmirSR6Te.jpg'),
(72250, 4949, 'Shameless S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3wHg2sZ4m67T2mjJQzRRBzncSvB.jpg'),
(72251, 4949, 'Shameless S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f7ckvPxCZglSNMCGKSY0lXJ53Uf.jpg'),
(72252, 4949, 'Shameless S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q6kpw6nauYZdtYx5RY6ko7euYd6.jpg'),
(72253, 4949, 'Shameless S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mFHoR88ymYpTSgH4KCROBOJOEhN.jpg'),
(72254, 4949, 'Shameless S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fb4Y75scYCKM5DtsYq6lMyUx1Bx.jpg'),
(72255, 4949, 'Shameless S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aESuxsoSiNLEhlnOc0PqIC1UxYJ.jpg'),
(72256, 4949, 'Shameless S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7P5EOoo3hQI8srKskhiPe75ixjV.jpg'),
(72257, 4949, 'Shameless S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8zVszM02ljBoWaHi8pn12PwhrQp.jpg'),
(72258, 4949, 'Shameless S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7xxZ8jAiP0JIGwPTfnMCiQDzbWo.jpg'),
(72259, 4949, 'Shameless S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zc8Y53h0L4uv4aG9jcXobcjfKJz.jpg'),
(72260, 4950, 'Shameless S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cwhAOKuyo2gAoTGEShMpwT5sMFr.jpg'),
(72261, 4950, 'Shameless S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gRWL8khdyoonhyQ2tHRiaZgPJoy.jpg'),
(72262, 4950, 'Shameless S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n4fDedxEpHAjy3bELKvEYiLJRcP.jpg'),
(72263, 4950, 'Shameless S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/G9Mox2AzfJqGtwkTcBlOUtg8cG.jpg'),
(72264, 4950, 'Shameless S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCb9Hxoyu9zj6NCb3mv4NLHAJNH.jpg'),
(72265, 4950, 'Shameless S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qEMEEh02CmpRHMH3fr275BzMbjP.jpg'),
(72266, 4950, 'Shameless S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r78n7yGL4gtUXQCrxBit3cXXgmN.jpg'),
(72267, 4950, 'Shameless S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yOyiDxrsXeUN9nm3a65dv00g5Fx.jpg'),
(72268, 4950, 'Shameless S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7fmKgn8ThYacpHaTnFmLjsc3xRB.jpg'),
(72269, 4950, 'Shameless S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cliNZdn3CePQ6WciHQ1sMIe5222.jpg'),
(72270, 4950, 'Shameless S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7YgDtheF1j8PR57476D4wH0TdW2.jpg'),
(72271, 4950, 'Shameless S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tGp0pGTCLcQI6IJPVWSf4AFvpId.jpg'),
(72272, 4951, 'Super Crooks S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ns7YHX9ah8CEov0v6foKF737RYF.jpg'),
(72273, 4951, 'Super Crooks S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uJxlr7ZVG73BPmD7R5NTL34VOsQ.jpg'),
(72274, 4951, 'Super Crooks S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vM67rcLz1j9xwgP172F4pjTeElj.jpg'),
(72275, 4951, 'Super Crooks S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f6OWkK8rS7f61FE6FUbhtT4YMq.jpg'),
(72276, 4951, 'Super Crooks S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wTDpTkshKtZSsX6RPaCLzv9pWrj.jpg'),
(72277, 4951, 'Super Crooks S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6TgQTmDiipK13O7YRinXURLQflI.jpg'),
(72278, 4951, 'Super Crooks S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v6fKcaVwrpYdcBmUz1DeZSeJBhx.jpg'),
(72279, 4951, 'Super Crooks S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gHVRBDEjBLIM6HI6ndLvejKBPGN.jpg'),
(72280, 4951, 'Super Crooks S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sASF4K9P7YvzRdJxDuQ2cHWR1Yd.jpg'),
(72281, 4951, 'Super Crooks S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sm5gZcSMhyLYzQhqvne5apn4uBl.jpg'),
(72282, 4951, 'Super Crooks S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AfIeN8BtXpC90NnuabqV4XG3jXP.jpg'),
(72283, 4951, 'Super Crooks S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMs4FlnV0YV7EFUBNu21xsWjBZO.jpg'),
(72284, 4951, 'Super Crooks S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/164660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t4ZqkOrYuKDWHtLRccwKFqsd0JZ.jpg'),
(72285, 4952, 'The Beatles: Get Back [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9b4B2ph6dLNhO4hwz9XnhaSSc1D.jpg'),
(72286, 4952, 'The Beatles: Get Back [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5uovxcgoy2O8h7W32G4RczNa2i.jpg'),
(72287, 4952, 'The Beatles: Get Back [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3yrV1J3j4fndIsYz3tMt2yIaSgi.jpg'),
(72288, 4953, 'Wilfred S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mwtwgFhM5spIXZHYo96Py2R3dU3.jpg'),
(72289, 4953, 'Wilfred S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v2J8qFo42x3Cgau5dlG9AlUyvH8.jpg'),
(72290, 4953, 'Wilfred S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6xYUSKMNfOd6t8UqMcPRXYVp4ir.jpg'),
(72291, 4953, 'Wilfred S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fFRb4jlxHS6a4rfWZliQ3negJZz.jpg'),
(72292, 4953, 'Wilfred S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sBfRo4cLZxptjdynChzJ3vnl4AJ.jpg'),
(72293, 4953, 'Wilfred S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2GpRUgWcX4ez9o128aaY6eYh8vm.jpg'),
(72294, 4953, 'Wilfred S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6AlLUq1ZSPvd9tOPSLuFrGk5mcC.jpg'),
(72295, 4953, 'Wilfred S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zL7GrxIqY5eOUcikyGdX3BKKSfP.jpg'),
(72296, 4953, 'Wilfred S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bKwpMadqw6Rhgeiaq2BJWawXD65.jpg'),
(72297, 4953, 'Wilfred S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vtaxIBPnMOboJLqCrsdSSg4vPp6.jpg'),
(72298, 4953, 'Wilfred S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rKCCnN4QZZbGuPVirEG4zNnJMy8.jpg'),
(72299, 4953, 'Wilfred S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ye2IGYWJQhrQGXC8ox6mbWfmQqk.jpg'),
(72300, 4953, 'Wilfred S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/164611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5jFPNvZsBQcTdRLoFjWSAC4KWi.jpg'),
(72301, 4954, 'Wilfred S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u4t2b0oWKPESvmU3jU4LERCrzcu.jpg'),
(72302, 4954, 'Wilfred S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uYdvnvmlGF4ndWYqjCLCikEbU9.jpg'),
(72303, 4954, 'Wilfred S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hd7AEXAmfjn6l7Z3y5xfH8gCq0J.jpg'),
(72304, 4954, 'Wilfred S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gI7mXmIqweffPw8l25KbbaggMdu.jpg'),
(72305, 4954, 'Wilfred S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lfaqDqbvXUPnn4mYWWweRq0NGn1.jpg'),
(72306, 4954, 'Wilfred S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFzo3PKcNVk5Q6x0LQ7fqFwbGvL.jpg'),
(72307, 4954, 'Wilfred S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4RXYtO1Pxp0IQs8WGXQkUxBt7zL.jpg'),
(72308, 4954, 'Wilfred S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/essVdFoniB0HaQjzWnRaw7H8pBb.jpg'),
(72309, 4954, 'Wilfred S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AhCbiF5tGk7GOu3zTcG9sbvZJZl.jpg'),
(72310, 4954, 'Wilfred S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3GXEvH5hdF4vn6ERcvrYHLRkj4Z.jpg'),
(72311, 4954, 'Wilfred S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vsq2azYAGSk4oClvGaeKTHVtHyt.jpg'),
(72312, 4954, 'Wilfred S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fRLRfCMIyERW4i3Pzpe7YwOAtIp.jpg'),
(72313, 4954, 'Wilfred S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/164624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gmY3q8Kua91eIKSS5Cu9PmfHJvm.jpg'),
(72314, 4955, 'Wilfred S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dKFqQVwHjzOVIggKdBhWc6ArWe2.jpg'),
(72315, 4955, 'Wilfred S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5XIJiEwOyX5ciSWB5mogDwDMJhE.jpg'),
(72316, 4955, 'Wilfred S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cqYBXzawHa6oCPmw9WYcRIa5itS.jpg'),
(72317, 4955, 'Wilfred S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o3UbfYjyDzWmeaMOKgPgBnJnQQV.jpg'),
(72318, 4955, 'Wilfred S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3zFPsakIOpHk1qWuftyC9cGr7A.jpg'),
(72319, 4955, 'Wilfred S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yknz0EW7IdN5yXzzaCDkub9NWgT.jpg'),
(72320, 4955, 'Wilfred S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fCaHRWwgrbcWSia8HltClb8NgXT.jpg'),
(72321, 4955, 'Wilfred S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ogvSmzqKMqkr3th0nEL3CWu2Ezm.jpg'),
(72322, 4955, 'Wilfred S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cMhCD7D821kzFHyYypmRF0u4wxA.jpg'),
(72323, 4955, 'Wilfred S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hZRTclxuWkDqBfgLXiplF11YMiy.jpg'),
(72324, 4955, 'Wilfred S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udTzjBeijeFE3Z027Zx3CGR9s3D.jpg'),
(72325, 4955, 'Wilfred S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vYBm92TiF2fiw4VQowV2wGCYYq5.jpg'),
(72326, 4955, 'Wilfred S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/164637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ar06EIZd0y3wFUuq4GK4knXid55.jpg'),
(72327, 4956, 'Wilfred S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uYdvnvmlGF4ndWYqjCLCikEbU9.jpg'),
(72328, 4956, 'Wilfred S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uYdvnvmlGF4ndWYqjCLCikEbU9.jpg'),
(72329, 4956, 'Wilfred S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uYdvnvmlGF4ndWYqjCLCikEbU9.jpg'),
(72330, 4956, 'Wilfred S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uYdvnvmlGF4ndWYqjCLCikEbU9.jpg'),
(72331, 4956, 'Wilfred S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uYdvnvmlGF4ndWYqjCLCikEbU9.jpg'),
(72332, 4956, 'Wilfred S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uYdvnvmlGF4ndWYqjCLCikEbU9.jpg'),
(72333, 4956, 'Wilfred S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uYdvnvmlGF4ndWYqjCLCikEbU9.jpg'),
(72334, 4956, 'Wilfred S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uYdvnvmlGF4ndWYqjCLCikEbU9.jpg'),
(72335, 4956, 'Wilfred S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uYdvnvmlGF4ndWYqjCLCikEbU9.jpg'),
(72336, 4956, 'Wilfred S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uYdvnvmlGF4ndWYqjCLCikEbU9.jpg'),
(72337, 4957, 'Yu Yu Hakusho S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/164487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7szIsVQu2M9AKEzY6U2cpLMzRih.jpg'),
(72338, 4957, 'Yu Yu Hakusho S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/164488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ot6PPEP9Gldm5QGb41cXI0jiOtU.jpg'),
(72339, 4957, 'Yu Yu Hakusho S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/164489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fLpNxzEDN37opkNk2Xs3uptfyLx.jpg'),
(72340, 4957, 'Yu Yu Hakusho S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/164490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/emxDCxQOI9WxTqOEICFK2Y6VPE0.jpg'),
(72341, 4957, 'Yu Yu Hakusho S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/164491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v7BE06Y7HOWHkH4FdslJ7xG29Bb.jpg'),
(72342, 4957, 'Yu Yu Hakusho S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/164492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x0fcp7OJnwIxZID5wmteV0kUMCl.jpg'),
(72343, 4957, 'Yu Yu Hakusho S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/164493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A0XXBkd4QnJHxuYoZiT9PBHPSVJ.jpg'),
(72344, 4957, 'Yu Yu Hakusho S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/164494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nPq9bXKKJprTFzkgfqRSKEXU25C.jpg'),
(72345, 4957, 'Yu Yu Hakusho S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/164495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5fNDkZ1xzh4BgC2aSXswx4D6ish.jpg'),
(72346, 4957, 'Yu Yu Hakusho S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/164496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ry9N0eKwOSC17wwmbOZMYsJhBjA.jpg'),
(72347, 4957, 'Yu Yu Hakusho S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/164497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmxHTaGATPTZibpnTnRSCg7LJAl.jpg'),
(72348, 4957, 'Yu Yu Hakusho S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/164498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gnZ3t2nOinFQ2io35Q4PzTVr9Dt.jpg'),
(72349, 4957, 'Yu Yu Hakusho S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/164499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iNGTzI3mMf36Qfm9Ga4LC3erx3J.jpg'),
(72350, 4957, 'Yu Yu Hakusho S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/164500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uwLX37JzFTFASM6oG9hcxl3pR6Q.jpg'),
(72351, 4957, 'Yu Yu Hakusho S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/164501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wIGzR96pkmUaW7XKxmu8KJDYtLD.jpg'),
(72352, 4957, 'Yu Yu Hakusho S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/164502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Rq4BJNLN0XErwioGv2zrFFmF7i.jpg'),
(72353, 4957, 'Yu Yu Hakusho S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/164503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ekvLL4SdSppF1E5yH1tIZ1Pc6ce.jpg'),
(72354, 4957, 'Yu Yu Hakusho S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/164504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ttOpd9FeSDrdXi0VjPdOhYbexsW.jpg'),
(72355, 4957, 'Yu Yu Hakusho S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/164505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iKAAlT8d1mRizNgPjtJgZqPlQns.jpg'),
(72356, 4957, 'Yu Yu Hakusho S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/164506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lUY2YBJOH4O3WGZuXA3RhddpcFI.jpg'),
(72357, 4957, 'Yu Yu Hakusho S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/164507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v4oSiBVE7so2VselS1eZqCPhxiz.jpg'),
(72358, 4957, 'Yu Yu Hakusho S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/164508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oI8bc3TD3rA3LHgOhjWjb6p1Uqy.jpg'),
(72359, 4957, 'Yu Yu Hakusho S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/164509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5qRGXkvKKSNwrksh556obAA42Gg.jpg'),
(72360, 4957, 'Yu Yu Hakusho S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/164510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rPQnIfmMOz7h4AGjGtr2IIGdx8T.jpg'),
(72361, 4957, 'Yu Yu Hakusho S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/164511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5FzrcE9z9el2xCfMn7qOXRN5PCo.jpg'),
(72362, 4957, 'Yu Yu Hakusho S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/164512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72363, 4957, 'Yu Yu Hakusho S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/164513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72364, 4957, 'Yu Yu Hakusho S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/164514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72365, 4957, 'Yu Yu Hakusho S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/164515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72366, 4957, 'Yu Yu Hakusho S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/164516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72367, 4957, 'Yu Yu Hakusho S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/164517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72368, 4957, 'Yu Yu Hakusho S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/164518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72369, 4957, 'Yu Yu Hakusho S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/164519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72370, 4957, 'Yu Yu Hakusho S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/164520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72371, 4957, 'Yu Yu Hakusho S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/164521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72372, 4957, 'Yu Yu Hakusho S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/164522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72373, 4957, 'Yu Yu Hakusho S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/164523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72374, 4957, 'Yu Yu Hakusho S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/164524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72375, 4957, 'Yu Yu Hakusho S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/164525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72376, 4957, 'Yu Yu Hakusho S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/164526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72377, 4957, 'Yu Yu Hakusho S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/164527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72378, 4957, 'Yu Yu Hakusho S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/164528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72379, 4957, 'Yu Yu Hakusho S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/164529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72380, 4957, 'Yu Yu Hakusho S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/164530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72381, 4957, 'Yu Yu Hakusho S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/164531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72382, 4957, 'Yu Yu Hakusho S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/164532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72383, 4957, 'Yu Yu Hakusho S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/164533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72384, 4957, 'Yu Yu Hakusho S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/164534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72385, 4957, 'Yu Yu Hakusho S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/164535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72386, 4957, 'Yu Yu Hakusho S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/164536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72387, 4957, 'Yu Yu Hakusho S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/164537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72388, 4957, 'Yu Yu Hakusho S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/164538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72389, 4957, 'Yu Yu Hakusho S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/164539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72390, 4957, 'Yu Yu Hakusho S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/164540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72391, 4957, 'Yu Yu Hakusho S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/164541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72392, 4957, 'Yu Yu Hakusho S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/164542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72393, 4957, 'Yu Yu Hakusho S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/164543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72394, 4957, 'Yu Yu Hakusho S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/164544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72395, 4957, 'Yu Yu Hakusho S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/164545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72396, 4957, 'Yu Yu Hakusho S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/164546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72397, 4957, 'Yu Yu Hakusho S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/164547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72398, 4957, 'Yu Yu Hakusho S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/164548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72399, 4957, 'Yu Yu Hakusho S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/164549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72400, 4957, 'Yu Yu Hakusho S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/164550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72401, 4957, 'Yu Yu Hakusho S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/164551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72402, 4957, 'Yu Yu Hakusho S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/164552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72403, 4957, 'Yu Yu Hakusho S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/164553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72404, 4957, 'Yu Yu Hakusho S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/164554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72405, 4957, 'Yu Yu Hakusho S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/164555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72406, 4957, 'Yu Yu Hakusho S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/164556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72407, 4957, 'Yu Yu Hakusho S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/164557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72408, 4957, 'Yu Yu Hakusho S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/164558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72409, 4957, 'Yu Yu Hakusho S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/164559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72410, 4957, 'Yu Yu Hakusho S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/164560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72411, 4957, 'Yu Yu Hakusho S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/164561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72412, 4957, 'Yu Yu Hakusho S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/164562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72413, 4957, 'Yu Yu Hakusho S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/164563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72414, 4957, 'Yu Yu Hakusho S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/164564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72415, 4957, 'Yu Yu Hakusho S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/164565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72416, 4957, 'Yu Yu Hakusho S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/164566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72417, 4957, 'Yu Yu Hakusho S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/164567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72418, 4957, 'Yu Yu Hakusho S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/164568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72419, 4957, 'Yu Yu Hakusho S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/164569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72420, 4957, 'Yu Yu Hakusho S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/164570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72421, 4957, 'Yu Yu Hakusho S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/164571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72422, 4957, 'Yu Yu Hakusho S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/164572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72423, 4957, 'Yu Yu Hakusho S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/164573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72424, 4957, 'Yu Yu Hakusho S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/164574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72425, 4957, 'Yu Yu Hakusho S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/164575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72426, 4957, 'Yu Yu Hakusho S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/164576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72427, 4957, 'Yu Yu Hakusho S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/164577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72428, 4957, 'Yu Yu Hakusho S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/164578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72429, 4957, 'Yu Yu Hakusho S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/164579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72430, 4957, 'Yu Yu Hakusho S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/164580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72431, 4957, 'Yu Yu Hakusho S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/164581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72432, 4957, 'Yu Yu Hakusho S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/164582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72433, 4957, 'Yu Yu Hakusho S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/164583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72434, 4957, 'Yu Yu Hakusho S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/164584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72435, 4957, 'Yu Yu Hakusho S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/164585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72436, 4957, 'Yu Yu Hakusho S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/164586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72437, 4957, 'Yu Yu Hakusho S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/164587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72438, 4957, 'Yu Yu Hakusho S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/164589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72439, 4957, 'Yu Yu Hakusho S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/164590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72440, 4957, 'Yu Yu Hakusho S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/164591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72441, 4957, 'Yu Yu Hakusho S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/164592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72442, 4957, 'Yu Yu Hakusho S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/164593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72443, 4957, 'Yu Yu Hakusho S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/164594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72444, 4957, 'Yu Yu Hakusho S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/164595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72445, 4957, 'Yu Yu Hakusho S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/164596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72446, 4957, 'Yu Yu Hakusho S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/164597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72447, 4957, 'Yu Yu Hakusho S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/164598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j6dzDPkrAsfJ6GUyyMPz38ZkpbF.jpg'),
(72448, 4958, 'A Comida de Amanha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163646.mp4', 'https://i.bj-share.info/6606689324cb842045391bef4f6fcae6.jpg'),
(72449, 4958, 'A Comida de Amanha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163647.mp4', 'https://i.bj-share.info/6606689324cb842045391bef4f6fcae6.jpg'),
(72450, 4958, 'A Comida de Amanha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163648.mp4', 'https://i.bj-share.info/6606689324cb842045391bef4f6fcae6.jpg'),
(72451, 4959, 'Apaixonados Por Comida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163640.mp4', 'https://i.bj-share.info/9eb83c1410ad9248f3c98089db5e54bf.jpg'),
(72452, 4959, 'Apaixonados Por Comida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163641.mp4', 'https://i.bj-share.info/9eb83c1410ad9248f3c98089db5e54bf.jpg'),
(72453, 4959, 'Apaixonados Por Comida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163642.mp4', 'https://i.bj-share.info/9eb83c1410ad9248f3c98089db5e54bf.jpg'),
(72454, 4959, 'Apaixonados Por Comida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163643.mp4', 'https://i.bj-share.info/9eb83c1410ad9248f3c98089db5e54bf.jpg'),
(72455, 4959, 'Apaixonados Por Comida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163644.mp4', 'https://i.bj-share.info/9eb83c1410ad9248f3c98089db5e54bf.jpg'),
(72456, 4959, 'Apaixonados Por Comida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163645.mp4', 'https://i.bj-share.info/9eb83c1410ad9248f3c98089db5e54bf.jpg'),
(72457, 4960, 'Beyblade Burst S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bTgxQMmfKl1Vvk0MJKGfhSQIIZP.jpg'),
(72458, 4960, 'Beyblade Burst S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72459, 4960, 'Beyblade Burst S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72460, 4960, 'Beyblade Burst S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72461, 4960, 'Beyblade Burst S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72462, 4960, 'Beyblade Burst S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72463, 4960, 'Beyblade Burst S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72464, 4960, 'Beyblade Burst S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72465, 4960, 'Beyblade Burst S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72466, 4960, 'Beyblade Burst S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72467, 4960, 'Beyblade Burst S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72468, 4960, 'Beyblade Burst S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72469, 4960, 'Beyblade Burst S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72470, 4960, 'Beyblade Burst S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(72471, 4960, 'Beyblade Burst S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72472, 4960, 'Beyblade Burst S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72473, 4960, 'Beyblade Burst S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72474, 4960, 'Beyblade Burst S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72475, 4960, 'Beyblade Burst S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72476, 4960, 'Beyblade Burst S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72477, 4960, 'Beyblade Burst S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/163609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72478, 4960, 'Beyblade Burst S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/163610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72479, 4960, 'Beyblade Burst S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/163611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72480, 4960, 'Beyblade Burst S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/163612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72481, 4960, 'Beyblade Burst S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/163613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72482, 4960, 'Beyblade Burst S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/163614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72483, 4960, 'Beyblade Burst S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/163615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72484, 4960, 'Beyblade Burst S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/163616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72485, 4960, 'Beyblade Burst S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/163617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72486, 4960, 'Beyblade Burst S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/163618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72487, 4960, 'Beyblade Burst S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/163619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72488, 4960, 'Beyblade Burst S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/163620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72489, 4960, 'Beyblade Burst S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/163621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72490, 4960, 'Beyblade Burst S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/163622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72491, 4960, 'Beyblade Burst S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/163623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72492, 4960, 'Beyblade Burst S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/163624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72493, 4960, 'Beyblade Burst S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/163625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72494, 4960, 'Beyblade Burst S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/163626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72495, 4960, 'Beyblade Burst S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/163627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72496, 4960, 'Beyblade Burst S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/163628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72497, 4960, 'Beyblade Burst S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/163629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72498, 4960, 'Beyblade Burst S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/163630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72499, 4960, 'Beyblade Burst S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/163631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72500, 4960, 'Beyblade Burst S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/163632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72501, 4960, 'Beyblade Burst S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/163633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72502, 4960, 'Beyblade Burst S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/163634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72503, 4960, 'Beyblade Burst S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/163635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72504, 4960, 'Beyblade Burst S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/163636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72505, 4960, 'Beyblade Burst S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/163637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72506, 4960, 'Beyblade Burst S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/163638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72507, 4960, 'Beyblade Burst S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/163639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fG7BHxDlntPyB57UuNo9sXmAmLV.jpg'),
(72508, 4961, 'Cartel Crew S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jgO3JIlOZ8fR3qiDN32ryuvZnzV.jpg'),
(72509, 4961, 'Cartel Crew S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jgO3JIlOZ8fR3qiDN32ryuvZnzV.jpg'),
(72510, 4961, 'Cartel Crew S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jgO3JIlOZ8fR3qiDN32ryuvZnzV.jpg'),
(72511, 4961, 'Cartel Crew S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jgO3JIlOZ8fR3qiDN32ryuvZnzV.jpg'),
(72512, 4961, 'Cartel Crew S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jgO3JIlOZ8fR3qiDN32ryuvZnzV.jpg'),
(72513, 4961, 'Cartel Crew S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jgO3JIlOZ8fR3qiDN32ryuvZnzV.jpg'),
(72514, 4961, 'Cartel Crew S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jgO3JIlOZ8fR3qiDN32ryuvZnzV.jpg'),
(72515, 4961, 'Cartel Crew S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jgO3JIlOZ8fR3qiDN32ryuvZnzV.jpg'),
(72516, 4961, 'Cartel Crew S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jgO3JIlOZ8fR3qiDN32ryuvZnzV.jpg'),
(72517, 4961, 'Cartel Crew S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jgO3JIlOZ8fR3qiDN32ryuvZnzV.jpg'),
(72518, 4962, 'Casos Bizarros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163570.mp4', 'https://i.bj-share.info/ab8bf6f71e02678a00c0db0e34521b93.jpg'),
(72519, 4962, 'Casos Bizarros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163571.mp4', 'https://i.bj-share.info/ab8bf6f71e02678a00c0db0e34521b93.jpg'),
(72520, 4962, 'Casos Bizarros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163572.mp4', 'https://i.bj-share.info/ab8bf6f71e02678a00c0db0e34521b93.jpg'),
(72521, 4962, 'Casos Bizarros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163573.mp4', 'https://i.bj-share.info/ab8bf6f71e02678a00c0db0e34521b93.jpg'),
(72522, 4962, 'Casos Bizarros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163574.mp4', 'https://i.bj-share.info/ab8bf6f71e02678a00c0db0e34521b93.jpg'),
(72523, 4962, 'Casos Bizarros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163575.mp4', 'https://i.bj-share.info/ab8bf6f71e02678a00c0db0e34521b93.jpg'),
(72524, 4962, 'Casos Bizarros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163576.mp4', 'https://i.bj-share.info/ab8bf6f71e02678a00c0db0e34521b93.jpg'),
(72525, 4962, 'Casos Bizarros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163577.mp4', 'https://i.bj-share.info/ab8bf6f71e02678a00c0db0e34521b93.jpg'),
(72526, 4962, 'Casos Bizarros S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163578.mp4', 'https://i.bj-share.info/ab8bf6f71e02678a00c0db0e34521b93.jpg'),
(72527, 4963, 'RÉ & MI S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8Nl91s8W0mbbUI5W8Qm7sbFbnX.jpg'),
(72528, 4963, 'RÉ & MI S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ymRH0V20RFH1mJW26rMZanZ8W9R.jpg'),
(72529, 4963, 'RÉ & MI S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6zAXKtmyoRl0mDE3cc7EduUAwI0.jpg'),
(72530, 4963, 'RÉ & MI S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kac3j6WKgaqniLU4cOKyGB35zST.jpg'),
(72531, 4963, 'RÉ & MI S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nLPQz3U6G1mY7s51gdZMeiUmWir.jpg'),
(72532, 4963, 'RÉ & MI S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Rn9cM0iOnWPxb5UxOmGQfYZM3P.jpg'),
(72533, 4963, 'RÉ & MI S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jYCbHUMifYMVxXPV2MokgycPLsw.jpg'),
(72534, 4963, 'RÉ & MI S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jYCbHUMifYMVxXPV2MokgycPLsw.jpg'),
(72535, 4964, 'Doenças Misteriosas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e33AEPyNNYvvOzVnvqd8Octxbg9.jpg'),
(72536, 4964, 'Doenças Misteriosas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e33AEPyNNYvvOzVnvqd8Octxbg9.jpg'),
(72537, 4964, 'Doenças Misteriosas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e33AEPyNNYvvOzVnvqd8Octxbg9.jpg'),
(72538, 4964, 'Doenças Misteriosas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e33AEPyNNYvvOzVnvqd8Octxbg9.jpg'),
(72539, 4964, 'Doenças Misteriosas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e33AEPyNNYvvOzVnvqd8Octxbg9.jpg'),
(72540, 4964, 'Doenças Misteriosas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e33AEPyNNYvvOzVnvqd8Octxbg9.jpg'),
(72541, 4964, 'Doenças Misteriosas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e33AEPyNNYvvOzVnvqd8Octxbg9.jpg'),
(72542, 4964, 'Doenças Misteriosas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e33AEPyNNYvvOzVnvqd8Octxbg9.jpg'),
(72543, 4965, 'Elfos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Y4VGSyLJi4pmO8jqucLMsPdPcG.jpg'),
(72544, 4965, 'Elfos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rs3gvS7hBi6gRmLiVJhQHHd6gwT.jpg'),
(72545, 4965, 'Elfos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/blsfzSdP8kLPWAwi780WSqncOaf.jpg'),
(72546, 4965, 'Elfos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nvb7FU2yK6V8erg3pTSMBChZhsT.jpg'),
(72547, 4965, 'Elfos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cEJeYn4E2MssiTGv5jPTXACAw1D.jpg'),
(72548, 4965, 'Elfos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5WyD4PkmBdRy6Hqir6HxgunA6Wk.jpg'),
(72549, 4966, 'Erros Médicos: Vidas Alteradas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jj4KinVqaFySXPboIBWoFfWltYb.jpg'),
(72550, 4966, 'Erros Médicos: Vidas Alteradas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jj4KinVqaFySXPboIBWoFfWltYb.jpg'),
(72551, 4966, 'Erros Médicos: Vidas Alteradas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jj4KinVqaFySXPboIBWoFfWltYb.jpg'),
(72552, 4966, 'Erros Médicos: Vidas Alteradas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jj4KinVqaFySXPboIBWoFfWltYb.jpg'),
(72553, 4966, 'Erros Médicos: Vidas Alteradas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jj4KinVqaFySXPboIBWoFfWltYb.jpg'),
(72554, 4966, 'Erros Médicos: Vidas Alteradas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jj4KinVqaFySXPboIBWoFfWltYb.jpg'),
(72555, 4966, 'Erros Médicos: Vidas Alteradas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jj4KinVqaFySXPboIBWoFfWltYb.jpg'),
(72556, 4966, 'Erros Médicos: Vidas Alteradas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jj4KinVqaFySXPboIBWoFfWltYb.jpg'),
(72557, 4966, 'Erros Médicos: Vidas Alteradas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jj4KinVqaFySXPboIBWoFfWltYb.jpg'),
(72558, 4966, 'Erros Médicos: Vidas Alteradas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jj4KinVqaFySXPboIBWoFfWltYb.jpg'),
(72559, 4967, 'Lady Night S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wMPcaPlHdUelE6klHzfaedo6mY8.jpg'),
(72560, 4967, 'Lady Night S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v5caAfJQVqofzmvVVXpCOqRdx1u.jpg'),
(72561, 4967, 'Lady Night S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2b86gOWCfeHNgQhFAYIO1Kbbqgq.jpg'),
(72562, 4967, 'Lady Night S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rL9WCxgZA2vOO1RrUbvFU5hT4J3.jpg'),
(72563, 4967, 'Lady Night S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6yi6IvgPjhEXbbMHYDCw8h0V1FD.jpg'),
(72564, 4967, 'Lady Night S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nwyvA2Dn7bfWCOOmdSd0b9a4h5H.jpg'),
(72565, 4967, 'Lady Night S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uldWU4ptEcdToCXcHWVN8fNqlyT.jpg'),
(72566, 4967, 'Lady Night S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eBdLUpB6jBxqIiGG4HWjcsNXI97.jpg'),
(72567, 4967, 'Lady Night S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9RLJWGtCGyecZUjPGXczjl8b1pO.jpg'),
(72568, 4967, 'Lady Night S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uiPc3cym2pmvnkWHbj7NrHgYfAo.jpg'),
(72569, 4967, 'Lady Night S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6XK3LJYDpyb8DQYKOiNdGqjAazv.jpg'),
(72570, 4967, 'Lady Night S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1LjuZTBkPfja9uW0DicMt1knJem.jpg'),
(72571, 4967, 'Lady Night S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ag4J3guJWpThTapEhpWFnZDgNbw.jpg'),
(72572, 4967, 'Lady Night S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/207745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x3JTHmJMSNPnLDIrVXyAhXc4ejI.jpg'),
(72573, 4967, 'Lady Night S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/207746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8UEsOPxchXNMp9tCJ1YKlaLi3vd.jpg'),
(72574, 4967, 'Lady Night S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/207747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nbm57TRfEIHFFb62aSu1EDhPKmX.jpg'),
(72575, 4967, 'Lady Night S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/207748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0kmw4ZnwpI8T0Gcvutp9r2yk0A.jpg'),
(72576, 4967, 'Lady Night S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/207749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yOnJQHhvYakw6bQ37pYGpLjJi5s.jpg'),
(72577, 4967, 'Lady Night S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/207750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4K0Y33bwnysIuG80q6ezIkb3HTD.jpg'),
(72578, 4967, 'Lady Night S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/207751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cPsF2gJjymYb8wCeY1PLPILX58.jpg'),
(72579, 4967, 'Lady Night S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/207752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7jjl6RaVtbaB4WwLEFEbkDtVmEu.jpg'),
(72580, 4967, 'Lady Night S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/207753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lXOzcjZ3GjsELTuX0jW7LTQziA.jpg'),
(72581, 4967, 'Lady Night S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/207754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iPmMfycqaGjBVjOBjlZBKrTkGEp.jpg'),
(72582, 4967, 'Lady Night S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/207755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3CsLwIlpSmC1XNlUnU6FGFtSimg.jpg'),
(72583, 4967, 'Lady Night S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/207756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6mRIJ6QTGMXWxt5qclFGN96OLgo.jpg'),
(72584, 4968, 'Lady Night S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDwS69MVM2qb2Tj7BSF5ROVffnT.jpg'),
(72585, 4968, 'Lady Night S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rOcnsVblrIdP8OHHBVvJbggEfCy.jpg'),
(72586, 4968, 'Lady Night S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5kST87gIk57q3nLfUD1Rdbep4TO.jpg'),
(72587, 4968, 'Lady Night S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8pHnzoCBeqS4ysvL4ZxdDeS9FIC.jpg'),
(72588, 4968, 'Lady Night S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cN1lV9HFBX1VITpQWaG8b0Rn2cO.jpg'),
(72589, 4968, 'Lady Night S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Auf3PGWWkn56O5uwcphSSyA2vpo.jpg'),
(72590, 4968, 'Lady Night S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tc1QNuHqLEWpkNaBrRNPBvBbadm.jpg'),
(72591, 4968, 'Lady Night S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sDzfyfph84fL8eEpVN1R34FNCfo.jpg'),
(72592, 4968, 'Lady Night S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/prYCwGYxz3ovhkZvcebLj2jwpAB.jpg'),
(72593, 4968, 'Lady Night S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1k3T8j692SGBOEAJfPUGY3J7p0M.jpg'),
(72594, 4968, 'Lady Night S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ga4yWsHYdR4b4HD4MQhPASPEB9N.jpg'),
(72595, 4968, 'Lady Night S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r49oUbmpvBQ75grr3TcVe7VD7oK.jpg'),
(72596, 4968, 'Lady Night S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Fa88Jab0cbJrC7T3ndXqg1X5Zu.jpg'),
(72597, 4968, 'Lady Night S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/207770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hBoWHvmvxsKNzuQe5Dtk4Lrk1aL.jpg'),
(72598, 4968, 'Lady Night S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/207771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ZI9SymXDAOFTakJTKzIGKDTRF9.jpg'),
(72599, 4968, 'Lady Night S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/207772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ACSkF8WEFhlTO9Ucaz9OtEJXZa.jpg'),
(72600, 4968, 'Lady Night S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/207773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nesWDmGBp35DfouXUVKvlykShgF.jpg'),
(72601, 4968, 'Lady Night S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/207774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7zO9KttPWmv2fTagcnfR77Vikyk.jpg'),
(72602, 4968, 'Lady Night S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/207775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1BcSbb1Ws4LPZBKrqQwqGURN9KO.jpg'),
(72603, 4968, 'Lady Night S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/207776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fpZSUcj0rqttMq7v9kHbcQHReVN.jpg'),
(72604, 4969, 'Lady Night S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pQahnuM2dsKq16NEj9e9Ybv1Ym9.jpg'),
(72605, 4969, 'Lady Night S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQXVrTdtbCS66P3QovlRkzheCIb.jpg'),
(72606, 4969, 'Lady Night S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jEdbRTCLjePOlpVynKnBxPcSB9C.jpg'),
(72607, 4969, 'Lady Night S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bX6yi4oX4G1WxW9xd3BVScQ8qA6.jpg'),
(72608, 4969, 'Lady Night S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4FpgutjtlEUYoVXCrOEZjs0Lwnf.jpg'),
(72609, 4969, 'Lady Night S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/akT8HZFUlwf3ZtQDwiz79WPKMbe.jpg'),
(72610, 4969, 'Lady Night S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yjQIsFweBLLErHeskHsUjYHy4Eb.jpg'),
(72611, 4969, 'Lady Night S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gK9FbwaY4IrlVdPwNARlHlX5Tbm.jpg'),
(72612, 4969, 'Lady Night S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9W1ICM4Hj1Ijp2AbPq2Mq8sU5mV.jpg'),
(72613, 4969, 'Lady Night S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mHgB0ijkLFqJLsx5CBVXILAQSnA.jpg'),
(72614, 4969, 'Lady Night S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qhVV4tUmsxeG3759hM5jmVcB8OQ.jpg'),
(72615, 4969, 'Lady Night S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tzorSvVKhJqj4Qm3GbGhw15o7wL.jpg'),
(72616, 4969, 'Lady Night S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o8mWVvv91clDFUoEJgho9pJCepA.jpg'),
(72617, 4969, 'Lady Night S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/207790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQtiNrZO5mukyYxxPcAj2eu6Qia.jpg'),
(72618, 4969, 'Lady Night S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/207791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c512zCMChzz48BPgqrXetMs1W97.jpg'),
(72619, 4969, 'Lady Night S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/207792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZSKmfuppTiKiAEyx1uJa0QntwN.jpg'),
(72620, 4969, 'Lady Night S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/207793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uWuQy9NYMNq09GJFU2JHqTSzLX8.jpg'),
(72621, 4969, 'Lady Night S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/207794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sstJXgDIeBX8UGoEZyMSCN6Pt8e.jpg'),
(72622, 4969, 'Lady Night S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/207795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y4F5no1W3xs659G9mHRsI8o2KEE.jpg'),
(72623, 4969, 'Lady Night S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/207796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cAlE5zlsaoDxUhK9uN11H4KkAve.jpg'),
(72624, 4969, 'Lady Night S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/207797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pQ0vPNdYEoWgshl8JPF4AbQx1xn.jpg'),
(72625, 4969, 'Lady Night S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/207798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z3NDulIdaUAujSquGsAksD1ifTw.jpg'),
(72626, 4969, 'Lady Night S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/207799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uQkyHaF6JTEVgTdpTGQ0VCk1wle.jpg'),
(72627, 4969, 'Lady Night S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/207800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vk7irlTmZwflDl6aIHEnoXMm2qv.jpg'),
(72628, 4969, 'Lady Night S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/207801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2BEi2MfpFKxFnvZDfs9YrmOfne3.jpg'),
(72629, 4970, 'Lady Night S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nUbykyyiyt9p1i4xyNkpuAgEdd1.jpg'),
(72630, 4970, 'Lady Night S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/goZebvdKW99MaUZzw4PMf2yrRp7.jpg'),
(72631, 4970, 'Lady Night S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zX7aMtNaSXI4dgAZlXCxVH6oLNX.jpg'),
(72632, 4970, 'Lady Night S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZWQbaIkSDvSNk9zMFzPgDcybFi.jpg'),
(72633, 4970, 'Lady Night S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iFOZ3VorkKHJH8kjND0RzzYJJZ2.jpg'),
(72634, 4970, 'Lady Night S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1aKDPmgdlZ8sct7dNuHHNpiRIkm.jpg'),
(72635, 4970, 'Lady Night S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfh8fkRsxl8U4C6DJHJIH8efH4g.jpg'),
(72636, 4970, 'Lady Night S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ivctUcTL0uWxRFtAcIC5QxN9MfW.jpg'),
(72637, 4970, 'Lady Night S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kTjW5LfLqenEXVdqvtxwNh9VwhB.jpg'),
(72638, 4970, 'Lady Night S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bzceNrOFGXshsTXtZ5XowHamy99.jpg'),
(72639, 4970, 'Lady Night S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9L8tnrUhHJj1gM2f4y5nNoqUFH.jpg'),
(72640, 4970, 'Lady Night S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72641, 4970, 'Lady Night S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72642, 4971, 'Lady Night S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jyVKl7d4HO1NCgmdgkFP1RrpbWT.jpg'),
(72643, 4971, 'Lady Night S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkYk1118QLbX57JGcOZspK3CgoF.jpg'),
(72644, 4971, 'Lady Night S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4TaGi4OftSRmplu8VG2fUbNgDPt.jpg'),
(72645, 4971, 'Lady Night S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jyC9U9PjJyGl5GQIdxFZZR2eOhy.jpg'),
(72646, 4971, 'Lady Night S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWy8HpkZLNIYvEuKFcUfLhwZNHJ.jpg'),
(72647, 4971, 'Lady Night S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7hB1fpDY8MDJ27gGAOQuEe0BOdY.jpg'),
(72648, 4971, 'Lady Night S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ap5nQGhDyIi4yb4Z6ENOgeTmWO1.jpg'),
(72649, 4971, 'Lady Night S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nP7l2r3NitWzZQiVftZyRjPLTg9.jpg'),
(72650, 4971, 'Lady Night S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2g2YFGwA0AvhFA3eqjP7YsvK7xW.jpg'),
(72651, 4971, 'Lady Night S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sSJnETl0aAelDuVbKNkzI6BFyw2.jpg'),
(72652, 4971, 'Lady Night S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/slpREqRKhfYLbcbDJvXqFEMX1wp.jpg'),
(72653, 4971, 'Lady Night S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/awQ4ky9cHo2wGdkhz4x2DAEjOp5.jpg'),
(72654, 4971, 'Lady Night S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/18jhdjk368uvyQgEiLf46nJubtP.jpg'),
(72655, 4971, 'Lady Night S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/207828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fJBNToF2kamSq7NWGpaimB91Im0.jpg'),
(72656, 4972, 'Lady Night S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iiZcbKoeEsZsAXDdV44DSj25ZkP.jpg'),
(72657, 4972, 'Lady Night S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72658, 4972, 'Lady Night S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72659, 4972, 'Lady Night S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72660, 4972, 'Lady Night S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72661, 4972, 'Lady Night S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72662, 4972, 'Lady Night S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72663, 4972, 'Lady Night S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72664, 4972, 'Lady Night S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72665, 4972, 'Lady Night S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72666, 4972, 'Lady Night S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72667, 4972, 'Lady Night S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72668, 4972, 'Lady Night S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72669, 4972, 'Lady Night S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/207842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72670, 4972, 'Lady Night S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/207843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72671, 4973, 'Lady Night S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bH5XHaWw1qhl52gQmHmcjG5FzK8.jpg'),
(72672, 4973, 'Lady Night S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6YqLmHJNNEplC9DJYepw9J9UrC1.jpg'),
(72673, 4973, 'Lady Night S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ngyh4HARG2NWrrLSdaX5AOOD6ia.jpg'),
(72674, 4973, 'Lady Night S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hWfrKe3KsTTOMIJ1wQW88rhuMEv.jpg'),
(72675, 4973, 'Lady Night S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d5ZoLgkdOKOLz2KIGZInNbcFUbb.jpg'),
(72676, 4973, 'Lady Night S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x8O8x9fh0udCnl3x86hbVjFgAaN.jpg'),
(72677, 4973, 'Lady Night S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFGFfejuLpRL3hTQx6LLrPBoLuP.jpg'),
(72678, 4973, 'Lady Night S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5QNkQMAl9qdFbJ7r2CPdXCcAkk2.jpg'),
(72679, 4973, 'Lady Night S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kOsVp5duXP0atdmm0N5oDsGt89z.jpg'),
(72680, 4973, 'Lady Night S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r0PRN7RMPuJTIMOLkucgx143aAH.jpg'),
(72681, 4973, 'Lady Night S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72682, 4973, 'Lady Night S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72683, 4973, 'Lady Night S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72684, 4973, 'Lady Night S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/207857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72685, 4973, 'Lady Night S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/207858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72686, 4974, 'Lady Night S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/489149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72687, 4974, 'Lady Night S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/489150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72688, 4974, 'Lady Night S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/489151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72689, 4974, 'Lady Night S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/489152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72690, 4974, 'Lady Night S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/489153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72691, 4974, 'Lady Night S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/491217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72692, 4974, 'Lady Night S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/491218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72693, 4974, 'Lady Night S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/491219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72694, 4974, 'Lady Night S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/491220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72695, 4974, 'Lady Night S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/491221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72696, 4974, 'Lady Night S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/495874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72697, 4974, 'Lady Night S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/492705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72698, 4974, 'Lady Night S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/492706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72699, 4974, 'Lady Night S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/492707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72700, 4974, 'Lady Night S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/495878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72701, 4974, 'Lady Night S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/495879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72702, 4974, 'Lady Night S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/499136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72703, 4974, 'Lady Night S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/499137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72704, 4974, 'Lady Night S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/499138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72705, 4974, 'Lady Night S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/505968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72706, 4974, 'Lady Night S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/505969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72707, 4974, 'Lady Night S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/505970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72708, 4974, 'Lady Night S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/505971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72709, 4974, 'Lady Night S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/505972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72710, 4974, 'Lady Night S08 E25', 'http://sinalprivado.info:80/series/1533784/1533784/507911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72711, 4974, 'Lady Night S08 E26', 'http://sinalprivado.info:80/series/1533784/1533784/511864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72712, 4974, 'Lady Night S08 E27', 'http://sinalprivado.info:80/series/1533784/1533784/511865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72713, 4974, 'Lady Night S08 E28', 'http://sinalprivado.info:80/series/1533784/1533784/511866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72714, 4974, 'Lady Night S08 E29', 'http://sinalprivado.info:80/series/1533784/1533784/511867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72715, 4974, 'Lady Night S08 E30', 'http://sinalprivado.info:80/series/1533784/1533784/511868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72716, 4975, 'Lady Night S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/881214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72717, 4975, 'Lady Night S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/881215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72718, 4975, 'Lady Night S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/881216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72719, 4975, 'Lady Night S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/881325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72720, 4975, 'Lady Night S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/881326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72721, 4975, 'Lady Night S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/881327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72722, 4975, 'Lady Night S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/881328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72723, 4975, 'Lady Night S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/881329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72724, 4975, 'Lady Night S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/881330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72725, 4975, 'Lady Night S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/881331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72726, 4975, 'Lady Night S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/882346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72727, 4975, 'Lady Night S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/882347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72728, 4975, 'Lady Night S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/882873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72729, 4975, 'Lady Night S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/882874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72730, 4975, 'Lady Night S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/882875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72731, 4975, 'Lady Night S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/883798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72732, 4975, 'Lady Night S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/883799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvVWisfCGTnmqXGdTkCKdvBbypt.jpg'),
(72733, 4976, 'Momonstros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72734, 4976, 'Momonstros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72735, 4976, 'Momonstros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72736, 4976, 'Momonstros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72737, 4976, 'Momonstros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72738, 4976, 'Momonstros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72739, 4976, 'Momonstros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72740, 4976, 'Momonstros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72741, 4976, 'Momonstros S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(72742, 4976, 'Momonstros S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72743, 4976, 'Momonstros S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/163496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72744, 4976, 'Momonstros S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/163497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72745, 4976, 'Momonstros S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/163498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72746, 4976, 'Momonstros S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/163499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72747, 4976, 'Momonstros S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/163500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72748, 4976, 'Momonstros S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/163501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72749, 4976, 'Momonstros S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/163502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72750, 4976, 'Momonstros S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/163503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72751, 4976, 'Momonstros S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/163504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72752, 4976, 'Momonstros S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/163505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72753, 4976, 'Momonstros S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/163506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72754, 4976, 'Momonstros S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/163507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72755, 4976, 'Momonstros S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/163508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72756, 4976, 'Momonstros S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/163509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72757, 4976, 'Momonstros S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/163510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72758, 4976, 'Momonstros S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/163511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72759, 4976, 'Momonstros S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/163512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72760, 4976, 'Momonstros S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/163513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72761, 4976, 'Momonstros S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/163514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72762, 4976, 'Momonstros S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/163515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72763, 4976, 'Momonstros S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/163516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72764, 4976, 'Momonstros S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/163517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72765, 4976, 'Momonstros S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/163518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72766, 4976, 'Momonstros S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/163519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72767, 4976, 'Momonstros S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/163520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72768, 4976, 'Momonstros S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/163521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72769, 4976, 'Momonstros S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/163522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72770, 4976, 'Momonstros S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/163523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72771, 4976, 'Momonstros S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/163524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72772, 4976, 'Momonstros S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/163525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72773, 4976, 'Momonstros S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/163526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72774, 4976, 'Momonstros S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/163527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72775, 4976, 'Momonstros S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/163528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72776, 4976, 'Momonstros S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/163529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72777, 4976, 'Momonstros S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/163530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72778, 4976, 'Momonstros S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/163531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72779, 4976, 'Momonstros S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/163532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72780, 4976, 'Momonstros S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/163533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72781, 4976, 'Momonstros S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/163534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72782, 4976, 'Momonstros S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/163535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72783, 4976, 'Momonstros S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/163536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72784, 4976, 'Momonstros S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/163537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xXAY62hNFtckgN78yQ11rkP6aw.jpg'),
(72785, 4977, 'Muquiranas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tDkbC5fQz37VCRrQSwshmnDndus.jpg'),
(72786, 4977, 'Muquiranas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kjKJzCfrrDDlxZN6wiBs8oknzZ1.jpg'),
(72787, 4977, 'Muquiranas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2O6EKoWIzzeKl6vCO5jCHyx9RBV.jpg'),
(72788, 4977, 'Muquiranas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gxNE7xvAmb3atMvYStWyokjoxCL.jpg'),
(72789, 4977, 'Muquiranas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/brQoGpiOWr7aBjPJLhBKovGSOVR.jpg'),
(72790, 4977, 'Muquiranas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fcgy3h7GnIbjPgGa9IPmdOToK6t.jpg'),
(72791, 4978, 'Muquiranas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iMHX8rX6I12WEqik2D85phhyhmT.jpg'),
(72792, 4978, 'Muquiranas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ashUQb4DT4VOefFH7n6ueN0ufbK.jpg'),
(72793, 4978, 'Muquiranas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rQ9kP2eSYvSVtyA68wx5hsX3A6m.jpg'),
(72794, 4978, 'Muquiranas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ccJaGevbwd5O5kuhvTb7ysGi1xx.jpg'),
(72795, 4978, 'Muquiranas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNqCUyeAdjwQZ5Hnb97tYNB6nge.jpg'),
(72796, 4978, 'Muquiranas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/duL3FBjUdZHx0PWGBs3iCCBPI0V.jpg'),
(72797, 4978, 'Muquiranas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4lADtHdMFGSZ51BzqahEeB1dQMC.jpg'),
(72798, 4978, 'Muquiranas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mgEykHF2K09TiHHESfAZcr5WSkw.jpg'),
(72799, 4979, 'Muquiranas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lVQjhNvGoPfRveGrED9e1So3Lw1.jpg'),
(72800, 4979, 'Muquiranas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bAvB83x4zca5SvBK0HgeJrJBFu4.jpg'),
(72801, 4979, 'Muquiranas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nQ05bducbSrDX0ePhGnRDdF2GjM.jpg'),
(72802, 4979, 'Muquiranas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/enyJMr8f5fk96xsTeOwLyDJuSdU.jpg'),
(72803, 4979, 'Muquiranas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/163480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kJBtRDQ8kOSqAcF1AwrNvbEIQl2.jpg'),
(72804, 4979, 'Muquiranas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/163481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7pGdNRRJbQjGAx1ho4Wja7kBUKd.jpg'),
(72805, 4979, 'Muquiranas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/163482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Y0IG4XNMwbMeflaqUgzWuwNJXU.jpg'),
(72806, 4979, 'Muquiranas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/163483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jITS0Cr76RV892OfjNLZHdn1yJm.jpg'),
(72807, 4979, 'Muquiranas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/163484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mxYZH9pxE79rgOrWJNYE7DYPUse.jpg'),
(72808, 4979, 'Muquiranas S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/163485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zKT60JWHZnnOc6MBxSKTjUtBujz.jpg'),
(72809, 4980, 'O Desaparecimento de Birgit Meier S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/163458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rkDWNUUoKYEGHVBTjLpIH7DqD5h.jpg'),
(72810, 4980, 'O Desaparecimento de Birgit Meier S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/163459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rkDWNUUoKYEGHVBTjLpIH7DqD5h.jpg'),
(72811, 4980, 'O Desaparecimento de Birgit Meier S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/163460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rkDWNUUoKYEGHVBTjLpIH7DqD5h.jpg'),
(72812, 4980, 'O Desaparecimento de Birgit Meier S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/163461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rkDWNUUoKYEGHVBTjLpIH7DqD5h.jpg'),
(72813, 4981, 'O Melhor de Mexicanicos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170743.mp4', 'https://i.bj-share.info/467726a612c73639bf6f63fe31896542.jpg'),
(72814, 4981, 'O Melhor de Mexicanicos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170744.mp4', 'https://i.bj-share.info/467726a612c73639bf6f63fe31896542.jpg'),
(72815, 4981, 'O Melhor de Mexicanicos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170745.mp4', 'https://i.bj-share.info/467726a612c73639bf6f63fe31896542.jpg'),
(72816, 4981, 'O Melhor de Mexicanicos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170746.mp4', 'https://i.bj-share.info/467726a612c73639bf6f63fe31896542.jpg'),
(72817, 4981, 'O Melhor de Mexicanicos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170747.mp4', 'https://i.bj-share.info/467726a612c73639bf6f63fe31896542.jpg'),
(72818, 4981, 'O Melhor de Mexicanicos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170748.mp4', 'https://i.bj-share.info/467726a612c73639bf6f63fe31896542.jpg'),
(72819, 4981, 'O Melhor de Mexicanicos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170749.mp4', 'https://i.bj-share.info/467726a612c73639bf6f63fe31896542.jpg'),
(72820, 4981, 'O Melhor de Mexicanicos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170750.mp4', 'https://i.bj-share.info/467726a612c73639bf6f63fe31896542.jpg'),
(72821, 4981, 'O Melhor de Mexicanicos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170751.mp4', 'https://i.bj-share.info/467726a612c73639bf6f63fe31896542.jpg'),
(72822, 4981, 'O Melhor de Mexicanicos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170752.mp4', 'https://i.bj-share.info/467726a612c73639bf6f63fe31896542.jpg'),
(72823, 4982, 'Os Sustos Ocultos de Frankelda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uLuwatOiPqFB8u9oWtDhMl5NqyA.jpg'),
(72824, 4982, 'Os Sustos Ocultos de Frankelda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7tT0YUvsldSkZfBPOelbo7hWq2w.jpg'),
(72825, 4982, 'Os Sustos Ocultos de Frankelda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3PeAwJYFBfKvVWRfpnz3OroB4PJ.jpg'),
(72826, 4982, 'Os Sustos Ocultos de Frankelda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tAOUekZ8bvcD3IFDZbUx4nLdVKo.jpg'),
(72827, 4982, 'Os Sustos Ocultos de Frankelda S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sQJtt3DgGxJ2LSKLshhSDt5Mk9u.jpg'),
(72828, 4983, 'Tudo ou Nada: Juventus [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/623WQnO0JDULYt64tg5Px1omoEW.jpg'),
(72829, 4983, 'Tudo ou Nada: Juventus [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/623WQnO0JDULYt64tg5Px1omoEW.jpg'),
(72830, 4983, 'Tudo ou Nada: Juventus [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/623WQnO0JDULYt64tg5Px1omoEW.jpg'),
(72831, 4983, 'Tudo ou Nada: Juventus [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/623WQnO0JDULYt64tg5Px1omoEW.jpg'),
(72832, 4983, 'Tudo ou Nada: Juventus [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/623WQnO0JDULYt64tg5Px1omoEW.jpg'),
(72833, 4983, 'Tudo ou Nada: Juventus [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/623WQnO0JDULYt64tg5Px1omoEW.jpg'),
(72834, 4983, 'Tudo ou Nada: Juventus [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/623WQnO0JDULYt64tg5Px1omoEW.jpg'),
(72835, 4983, 'Tudo ou Nada: Juventus [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/623WQnO0JDULYt64tg5Px1omoEW.jpg'),
(72836, 4984, 'Acapulco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5IP9orFtKw4GOyob9J14OvC0kNv.jpg'),
(72837, 4984, 'Acapulco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ktYD4UhshuxwN4FBg1JmeHQBxMT.jpg'),
(72838, 4984, 'Acapulco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8w4KKZ7rrU6ThQ563yMRvX7Wou.jpg'),
(72839, 4984, 'Acapulco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uErGLZl3DdyHlqzoinptWDLj4FS.jpg'),
(72840, 4984, 'Acapulco S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xwMhnZb8EX4no2zr3U9COi0NTIQ.jpg'),
(72841, 4984, 'Acapulco S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/21C0xP5r7FR8j2BI1sy5wkDHOQL.jpg'),
(72842, 4984, 'Acapulco S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/38hQG5Pq190VQr3t6I3YvzeMxLa.jpg'),
(72843, 4984, 'Acapulco S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/R7eauOJcXENJPp4KwFBHGUd67N.jpg'),
(72844, 4984, 'Acapulco S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d6mUGQQusp0e7Ad5nJ32u7JKAF3.jpg'),
(72845, 4984, 'Acapulco S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/555ImD1GK0J3pKrMcxJ3OpEDldt.jpg'),
(72846, 4985, 'Acapulco S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m8nLDlR00uQ41ejuHmhWo2I2tSz.jpg'),
(72847, 4985, 'Acapulco S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6DOM4Rb96NdiAsNkB4LjobWF77a.jpg'),
(72848, 4985, 'Acapulco S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x8TPiLXdq5mg45ZtWAApHU0uwhM.jpg'),
(72849, 4985, 'Acapulco S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wiNckcVGBQgaCTiejfy3GzhqhdU.jpg'),
(72850, 4985, 'Acapulco S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203454.mp4', 'http://image.tmdb.org/t/p/w1280/gS6vPhQuJHMaPIgfmD11wUDzIJJ.jpg'),
(72851, 4985, 'Acapulco S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2cTziJSk6Ie2viwVAiwvscce57k.jpg'),
(72852, 4985, 'Acapulco S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzcCbWRcDDjgob1F8h4ogkcZzzv.jpg'),
(72853, 4985, 'Acapulco S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203457.mp4', 'http://image.tmdb.org/t/p/w1280/9npf9mQo3jDgzaAG3XrHz8l7YQO.jpg'),
(72854, 4985, 'Acapulco S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203458.mp4', 'http://image.tmdb.org/t/p/w1280/gy8D1XLDEExyFv1EhTJt9emeszm.jpg'),
(72855, 4985, 'Acapulco S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203459.mp4', 'http://image.tmdb.org/t/p/w1280/sgRpP3gifwq2vFjj12cZfqcCcTO.jpg'),
(72856, 4986, 'Acapulco S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/360445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9biFnd1kx1uhc7CDTGISHN9PSno.jpg'),
(72857, 4986, 'Acapulco S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/360446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9biFnd1kx1uhc7CDTGISHN9PSno.jpg'),
(72858, 4986, 'Acapulco S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/360447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9biFnd1kx1uhc7CDTGISHN9PSno.jpg'),
(72859, 4986, 'Acapulco S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/360448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9biFnd1kx1uhc7CDTGISHN9PSno.jpg'),
(72860, 4986, 'Acapulco S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/360449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9biFnd1kx1uhc7CDTGISHN9PSno.jpg'),
(72861, 4986, 'Acapulco S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/369756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9biFnd1kx1uhc7CDTGISHN9PSno.jpg'),
(72862, 4986, 'Acapulco S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/375484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9biFnd1kx1uhc7CDTGISHN9PSno.jpg'),
(72863, 4986, 'Acapulco S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/383426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9biFnd1kx1uhc7CDTGISHN9PSno.jpg'),
(72864, 4986, 'Acapulco S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/385169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9biFnd1kx1uhc7CDTGISHN9PSno.jpg'),
(72865, 4986, 'Acapulco S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/398114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9biFnd1kx1uhc7CDTGISHN9PSno.jpg'),
(72866, 4987, 'Acapulco S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/874785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9biFnd1kx1uhc7CDTGISHN9PSno.jpg'),
(72867, 4987, 'Acapulco S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/874786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9biFnd1kx1uhc7CDTGISHN9PSno.jpg'),
(72868, 4987, 'Acapulco S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/878895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9biFnd1kx1uhc7CDTGISHN9PSno.jpg'),
(72869, 4987, 'Acapulco S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/880000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9biFnd1kx1uhc7CDTGISHN9PSno.jpg'),
(72870, 4987, 'Acapulco S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/880417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9biFnd1kx1uhc7CDTGISHN9PSno.jpg'),
(72871, 4987, 'Acapulco S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/881267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9biFnd1kx1uhc7CDTGISHN9PSno.jpg'),
(72872, 4987, 'Acapulco S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/881362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9biFnd1kx1uhc7CDTGISHN9PSno.jpg'),
(72873, 4987, 'Acapulco S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/882370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9biFnd1kx1uhc7CDTGISHN9PSno.jpg'),
(72874, 4987, 'Acapulco S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/883841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9biFnd1kx1uhc7CDTGISHN9PSno.jpg'),
(72875, 4987, 'Acapulco S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/885343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9biFnd1kx1uhc7CDTGISHN9PSno.jpg'),
(72876, 4988, 'All The Way Up: Caminho para A Fama S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5h30CXkAxodoNa1j0ZpZLphiRcD.jpg'),
(72877, 4988, 'All The Way Up: Caminho para A Fama S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/drYXaeyBLIqQBlcCyiKhNZiqsn8.jpg'),
(72878, 4988, 'All The Way Up: Caminho para A Fama S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/msri2oDQo0yRuFe4CZE9Uk2mTJY.jpg'),
(72879, 4988, 'All The Way Up: Caminho para A Fama S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9vexKryxud9alRlQCIZWTwoT1Zf.jpg'),
(72880, 4988, 'All The Way Up: Caminho para A Fama S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvPqgj6Jij2iwqiLeGCSQmzHdUf.jpg'),
(72881, 4988, 'All The Way Up: Caminho para A Fama S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ieCqR8AtT08BJHDgghV6Ywq0LnU.jpg'),
(72882, 4988, 'All The Way Up: Caminho para A Fama S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1u6TwOj4Uj8NB6IGqy7KkCIY3yZ.jpg'),
(72883, 4988, 'All The Way Up: Caminho para A Fama S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9XnjgVfQPICDrn5ihKgKTOZa7rq.jpg'),
(72884, 4988, 'All The Way Up: Caminho para A Fama S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/waxaScd3paW2Ih3AMqZz85o15xZ.jpg'),
(72885, 4988, 'All The Way Up: Caminho para A Fama S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qtF1f5EKSmLYus4EPwd75V6VC5B.jpg'),
(72886, 4989, 'Blade Runner: Black Lotus [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sdIXx7UbzSZg9JbS7slKE1zivh2.jpg'),
(72887, 4989, 'Blade Runner: Black Lotus [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Al58Ns28IQ8hjuIFA7xdCl8lCfp.jpg'),
(72888, 4989, 'Blade Runner: Black Lotus [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aDuMqY3aSpUxKKetiJQ1I9BUlHR.jpg'),
(72889, 4989, 'Blade Runner: Black Lotus [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yc851h9y28vjKVEIC792KHW9Lu1.jpg'),
(72890, 4989, 'Blade Runner: Black Lotus [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173003.mp4', 'http://image.tmdb.org/t/p/w1280/lqfZQF6a2p6fQSd75NntzyYv57y.jpg'),
(72891, 4989, 'Blade Runner: Black Lotus [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173004.mp4', 'http://image.tmdb.org/t/p/w1280/1kB7krEH2cRwoYT7k4g2ScjuPP9.jpg'),
(72892, 4989, 'Blade Runner: Black Lotus [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vte61QgYvAFIG52IhGIBAJo6jKc.jpg'),
(72893, 4989, 'Blade Runner: Black Lotus [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3zhGsgKxrUkT2GLHohO7Sx2pfof.jpg'),
(72894, 4989, 'Blade Runner: Black Lotus [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173007.mp4', 'http://image.tmdb.org/t/p/w1280/fke1VzwpVMrlGJAdhnZ8DWslN86.jpg'),
(72895, 4989, 'Blade Runner: Black Lotus [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173008.mp4', 'http://timg.bdta.pro/images/f4cdaeba99200432f0dab64e02aeb191.jpg'),
(72896, 4989, 'Blade Runner: Black Lotus [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173009.mp4', 'http://timg.bdta.pro/images/21a22477a864310ee4b723b688dc7e71.jpg'),
(72897, 4989, 'Blade Runner: Black Lotus [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173010.mp4', 'http://timg.bdta.pro/images/99b3cc348a77d0bc914e1ddcf480d3e2.jpg'),
(72898, 4989, 'Blade Runner: Black Lotus [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173011.mp4', 'http://timg.bdta.pro/images/f157ed0ad1d0477cda66a326719b2c50.jpg'),
(72899, 4990, 'Coyotes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dDYWngxR0Hf6DeZyg6gS3OkkKfp.jpg'),
(72900, 4990, 'Coyotes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1AqajwcCAuTVcAEjpHjC7osMfYr.jpg'),
(72901, 4990, 'Coyotes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wjGYEUYV0GYxWYeKQCIa2eQxR6y.jpg'),
(72902, 4990, 'Coyotes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ku0GnnSyioLx0Wob2RSSlvzzSYC.jpg'),
(72903, 4990, 'Coyotes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A6iYr8UFIFcGs0meLcYKGK2H1wK.jpg'),
(72904, 4990, 'Coyotes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mcaLoYnRbkq5LFesXvElnybiRGF.jpg'),
(72905, 4991, 'Harlem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/O1RcTvakJTeAcGVGcB3MLUTSQQ.jpg'),
(72906, 4991, 'Harlem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hdMvuVgmZPlSdXOx7OyjVRLR0kO.jpg'),
(72907, 4991, 'Harlem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l6xfps47p0TFWgm6AJxGWUn9EpE.jpg'),
(72908, 4991, 'Harlem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/50Scb8sKRgin8I5bv579yGiftQ0.jpg'),
(72909, 4991, 'Harlem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lQd260Ji0B4niwbVH5mDxkngh5X.jpg'),
(72910, 4991, 'Harlem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hZuYqyi6vpx3yh0Een4NU4fXkD4.jpg'),
(72911, 4991, 'Harlem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8RxBr5VJyATnZCDX2MGIFC3m2qm.jpg'),
(72912, 4991, 'Harlem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r6OYtPh5hovhDn7FWNU7b3VQlI7.jpg'),
(72913, 4991, 'Harlem S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cjI3zbY2LITE2yJ8RdTNAtcNJC1.jpg'),
(72914, 4991, 'Harlem S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zHd1Ufa7YXCMEopSKPbjrpnNDzi.jpg'),
(72915, 4992, 'Harlem S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5lQaVbR9p1fMpSYY0jzUuIOGsC.jpg'),
(72916, 4992, 'Harlem S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/spZI1s0DjZzTTGXnsuo2gjF34Wp.jpg'),
(72917, 4992, 'Harlem S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206598.mp4', 'http://image.tmdb.org/t/p/w1280/wpLWCIgm2UGnGMF4g2Zl452sRuB.jpg'),
(72918, 4992, 'Harlem S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206599.mp4', 'http://image.tmdb.org/t/p/w1280/dJZKJSXN5tCC4gCFsfVUtHjBzp0.jpg'),
(72919, 4992, 'Harlem S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iYRwHtOyA5RScuyqDn2aRunhJxY.jpg'),
(72920, 4992, 'Harlem S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bZtaf166fNqVPgcte9tzkj9TOyR.jpg'),
(72921, 4992, 'Harlem S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QGieLgD396XGXxqcXo6BcMoHL3.jpg'),
(72922, 4992, 'Harlem S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/92woSDYH0oy8zM5qP7ScVOvkfU.jpg'),
(72923, 4993, 'Insânia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rDHbRgx3XQ2givkxKfI60PPbXHV.jpg'),
(72924, 4993, 'Insânia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/phj67JKNX7BBUVoy14uDAaKcOiJ.jpg'),
(72925, 4993, 'Insânia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vkMDC6Wtom4VLD139IPsvOxCr9.jpg'),
(72926, 4993, 'Insânia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ssufOHw7GbVlN24Y0tH9IlUWLOP.jpg'),
(72927, 4993, 'Insânia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pvkHslDovYxosqyT2q27lyhZYfQ.jpg'),
(72928, 4993, 'Insânia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hFthprVRgq4uTIYZM4mOOYiQgEg.jpg'),
(72929, 4993, 'Insânia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1raxEokV0OBDnkElGHKYEl93KuT.jpg'),
(72930, 4993, 'Insânia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1UY6NVo8pLpHEbYke9JdYPitzq9.jpg'),
(72931, 4994, 'Lockdown Americano & Desbancando Borat S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cGXDTKOcKq6WgN4Ajbgb5AyQbME.jpg'),
(72932, 4994, 'Lockdown Americano & Desbancando Borat S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hPrr6OWqQFEvhT68aJhfrtq4nzg.jpg'),
(72933, 4994, 'Lockdown Americano & Desbancando Borat S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5A8SY9H5gNKVBVDLsLKG5pn8FF8.jpg'),
(72934, 4994, 'Lockdown Americano & Desbancando Borat S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3pXOPQXa4dALra3MZ19swNmmwjN.jpg'),
(72935, 4994, 'Lockdown Americano & Desbancando Borat S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wCp0qGj2d3eiai9bNg5SzTxRPyl.jpg'),
(72936, 4994, 'Lockdown Americano & Desbancando Borat S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wgGJ7QgwjBuE44xq19IQlnmoaEI.jpg'),
(72937, 4994, 'Lockdown Americano & Desbancando Borat S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3lc0ELyIiSERxtzqc5maebc3m3A.jpg'),
(72938, 4995, 'O Melhor Do Chespirito S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170599.mp4', 'https://i.imgur.com/IAmzJfX.jpg'),
(72939, 4995, 'O Melhor Do Chespirito S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170600.mp4', 'https://i.imgur.com/IAmzJfX.jpg'),
(72940, 4995, 'O Melhor Do Chespirito S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170601.mp4', 'https://i.imgur.com/IAmzJfX.jpg'),
(72941, 4995, 'O Melhor Do Chespirito S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170602.mp4', 'https://i.imgur.com/IAmzJfX.jpg'),
(72942, 4995, 'O Melhor Do Chespirito S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170603.mp4', 'https://i.imgur.com/IAmzJfX.jpg'),
(72943, 4995, 'O Melhor Do Chespirito S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170604.mp4', 'https://i.imgur.com/IAmzJfX.jpg'),
(72944, 4995, 'O Melhor Do Chespirito S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170605.mp4', 'https://i.imgur.com/IAmzJfX.jpg'),
(72945, 4995, 'O Melhor Do Chespirito S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170606.mp4', 'https://i.imgur.com/IAmzJfX.jpg'),
(72946, 4996, 'Quilos Mortais: Como Eles Estão Agora? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72947, 4996, 'Quilos Mortais: Como Eles Estão Agora? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72948, 4996, 'Quilos Mortais: Como Eles Estão Agora? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72949, 4996, 'Quilos Mortais: Como Eles Estão Agora? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72950, 4997, 'Quilos Mortais: Como Eles Estão Agora? S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72951, 4997, 'Quilos Mortais: Como Eles Estão Agora? S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72952, 4997, 'Quilos Mortais: Como Eles Estão Agora? S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72953, 4997, 'Quilos Mortais: Como Eles Estão Agora? S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72954, 4997, 'Quilos Mortais: Como Eles Estão Agora? S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72955, 4997, 'Quilos Mortais: Como Eles Estão Agora? S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72956, 4997, 'Quilos Mortais: Como Eles Estão Agora? S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72957, 4997, 'Quilos Mortais: Como Eles Estão Agora? S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72958, 4998, 'Quilos Mortais: Como Eles Estão Agora? S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72959, 4998, 'Quilos Mortais: Como Eles Estão Agora? S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72960, 4998, 'Quilos Mortais: Como Eles Estão Agora? S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72961, 4998, 'Quilos Mortais: Como Eles Estão Agora? S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72962, 4998, 'Quilos Mortais: Como Eles Estão Agora? S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72963, 4998, 'Quilos Mortais: Como Eles Estão Agora? S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72964, 4998, 'Quilos Mortais: Como Eles Estão Agora? S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72965, 4998, 'Quilos Mortais: Como Eles Estão Agora? S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72966, 4998, 'Quilos Mortais: Como Eles Estão Agora? S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72967, 4998, 'Quilos Mortais: Como Eles Estão Agora? S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72968, 4998, 'Quilos Mortais: Como Eles Estão Agora? S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/169891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72969, 4999, 'Quilos Mortais: Como Eles Estão Agora? S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72970, 4999, 'Quilos Mortais: Como Eles Estão Agora? S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72971, 4999, 'Quilos Mortais: Como Eles Estão Agora? S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72972, 4999, 'Quilos Mortais: Como Eles Estão Agora? S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72973, 4999, 'Quilos Mortais: Como Eles Estão Agora? S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72974, 4999, 'Quilos Mortais: Como Eles Estão Agora? S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72975, 4999, 'Quilos Mortais: Como Eles Estão Agora? S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72976, 4999, 'Quilos Mortais: Como Eles Estão Agora? S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72977, 4999, 'Quilos Mortais: Como Eles Estão Agora? S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72978, 4999, 'Quilos Mortais: Como Eles Estão Agora? S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72979, 4999, 'Quilos Mortais: Como Eles Estão Agora? S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/169902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72980, 4999, 'Quilos Mortais: Como Eles Estão Agora? S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/169903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72981, 5000, 'Quilos Mortais: Como Eles Estão Agora? S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72982, 5000, 'Quilos Mortais: Como Eles Estão Agora? S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72983, 5000, 'Quilos Mortais: Como Eles Estão Agora? S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72984, 5000, 'Quilos Mortais: Como Eles Estão Agora? S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72985, 5000, 'Quilos Mortais: Como Eles Estão Agora? S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72986, 5000, 'Quilos Mortais: Como Eles Estão Agora? S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72987, 5000, 'Quilos Mortais: Como Eles Estão Agora? S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72988, 5000, 'Quilos Mortais: Como Eles Estão Agora? S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72989, 5000, 'Quilos Mortais: Como Eles Estão Agora? S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72990, 5000, 'Quilos Mortais: Como Eles Estão Agora? S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72991, 5000, 'Quilos Mortais: Como Eles Estão Agora? S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/169914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72992, 5000, 'Quilos Mortais: Como Eles Estão Agora? S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/169915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y2x0WkCYiGJzPBD6RHni7ethYQD.jpg'),
(72993, 5001, 'Saindo do Armario com Colton Underwood S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gnbMMccZKioIVZPEnuhglnNKc6w.jpg'),
(72994, 5001, 'Saindo do Armario com Colton Underwood S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gnbMMccZKioIVZPEnuhglnNKc6w.jpg'),
(72995, 5001, 'Saindo do Armario com Colton Underwood S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gnbMMccZKioIVZPEnuhglnNKc6w.jpg'),
(72996, 5001, 'Saindo do Armario com Colton Underwood S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gnbMMccZKioIVZPEnuhglnNKc6w.jpg'),
(72997, 5001, 'Saindo do Armario com Colton Underwood S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gnbMMccZKioIVZPEnuhglnNKc6w.jpg'),
(72998, 5001, 'Saindo do Armario com Colton Underwood S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gnbMMccZKioIVZPEnuhglnNKc6w.jpg'),
(72999, 5002, 'Dexter: Sangue Novo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/igyYWp2f69LIMMLFZzuMvoSdA8n.jpg'),
(73000, 5002, 'Dexter: Sangue Novo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8JeRign9jzxne1UhnyozvxkPZSB.jpg'),
(73001, 5002, 'Dexter: Sangue Novo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3W6oNm9o4lk2csH4cEKA6MDESjh.jpg'),
(73002, 5002, 'Dexter: Sangue Novo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a3bU98DH7BMkz4IBUn0tLPzxA0E.jpg'),
(73003, 5002, 'Dexter: Sangue Novo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iVEa7gHM4eHd9KOQ5FvvuyX1NqV.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(73004, 5002, 'Dexter: Sangue Novo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MQoJGTLPxmguUpx1ES0mN3pE5.jpg'),
(73005, 5002, 'Dexter: Sangue Novo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ol5Sm95aBoPDXprTThiz8IkWHdd.jpg'),
(73006, 5002, 'Dexter: Sangue Novo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7D33cg0gxAXAaWuVNCS9IXszVog.jpg'),
(73007, 5002, 'Dexter: Sangue Novo [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3CqKW5jbrXUxX7VvPvVhIwBYUN8.jpg'),
(73008, 5002, 'Dexter: Sangue Novo [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/edrSXO5bUwrltScuDKjNI8vVelq.jpg'),
(73009, 5003, 'A Lenda de Lady Ferrari S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170530.mp4', 'https://i.bj-share.info/9be6436a30553bd546d4ef0fd3fab931.jpg'),
(73010, 5003, 'A Lenda de Lady Ferrari S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170531.mp4', 'https://i.bj-share.info/9be6436a30553bd546d4ef0fd3fab931.jpg'),
(73011, 5003, 'A Lenda de Lady Ferrari S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170532.mp4', 'https://i.bj-share.info/9be6436a30553bd546d4ef0fd3fab931.jpg'),
(73012, 5003, 'A Lenda de Lady Ferrari S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170533.mp4', 'https://i.bj-share.info/9be6436a30553bd546d4ef0fd3fab931.jpg'),
(73013, 5003, 'A Lenda de Lady Ferrari S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170534.mp4', 'https://i.bj-share.info/9be6436a30553bd546d4ef0fd3fab931.jpg'),
(73014, 5003, 'A Lenda de Lady Ferrari S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170535.mp4', 'https://i.bj-share.info/9be6436a30553bd546d4ef0fd3fab931.jpg'),
(73015, 5003, 'A Lenda de Lady Ferrari S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170536.mp4', 'https://i.bj-share.info/9be6436a30553bd546d4ef0fd3fab931.jpg'),
(73016, 5003, 'A Lenda de Lady Ferrari S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170537.mp4', 'https://i.bj-share.info/9be6436a30553bd546d4ef0fd3fab931.jpg'),
(73017, 5003, 'A Lenda de Lady Ferrari S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170538.mp4', 'https://i.bj-share.info/9be6436a30553bd546d4ef0fd3fab931.jpg'),
(73018, 5003, 'A Lenda de Lady Ferrari S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170539.mp4', 'https://i.bj-share.info/9be6436a30553bd546d4ef0fd3fab931.jpg'),
(73019, 5003, 'A Lenda de Lady Ferrari S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170540.mp4', 'https://i.bj-share.info/9be6436a30553bd546d4ef0fd3fab931.jpg'),
(73020, 5003, 'A Lenda de Lady Ferrari S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170541.mp4', 'https://i.bj-share.info/9be6436a30553bd546d4ef0fd3fab931.jpg'),
(73021, 5004, 'A Lenda de Sleepy Hollow S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xbjO4nZZ3XSvK01ZtiHjkCnAYeZ.jpg'),
(73022, 5004, 'A Lenda de Sleepy Hollow S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zUUplxAcO5NReHfZifTDz3nQPUM.jpg'),
(73023, 5004, 'A Lenda de Sleepy Hollow S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9hbR91QFgXvQlGHU8UZzWkAqMjR.jpg'),
(73024, 5004, 'A Lenda de Sleepy Hollow S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/desZO3s0jYNPJorGjnC5Ys7LdiU.jpg'),
(73025, 5004, 'A Lenda de Sleepy Hollow S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ElhWbQUPMn7AJzryXRYW76TCcH.jpg'),
(73026, 5004, 'A Lenda de Sleepy Hollow S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9AFYcRs94uVnTGfkvDZXDEnxpqa.jpg'),
(73027, 5004, 'A Lenda de Sleepy Hollow S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dCK17BkOjDXsGRcDlNwfWcUy6aB.jpg'),
(73028, 5004, 'A Lenda de Sleepy Hollow S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uxVbnjqcugdggcbKInf4KuLpjqk.jpg'),
(73029, 5004, 'A Lenda de Sleepy Hollow S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xAkahiptoDSLbYZw4U4s1zNLmHc.jpg'),
(73030, 5004, 'A Lenda de Sleepy Hollow S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ayOpoNR7J9iHY1TFWoU2FeKbIt9.jpg'),
(73031, 5004, 'A Lenda de Sleepy Hollow S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n8opNuKOXXXVnxrIZzlDObzieeC.jpg'),
(73032, 5004, 'A Lenda de Sleepy Hollow S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uG2YDUpCbIfgo0gAdQyse0kLr7.jpg'),
(73033, 5005, 'A Lenda de Sleepy Hollow S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lAQKCOOwg9xMoYQTvS5rDuZ12ZS.jpg'),
(73034, 5005, 'A Lenda de Sleepy Hollow S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4NI7lSLvUi6UiekctPDIArYsXxY.jpg'),
(73035, 5005, 'A Lenda de Sleepy Hollow S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lRySByFFuiKzvFceLw10ROX2cZ0.jpg'),
(73036, 5005, 'A Lenda de Sleepy Hollow S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1DuWHYOEvngJjKDveIAHkUa5a9w.jpg'),
(73037, 5005, 'A Lenda de Sleepy Hollow S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/niVYBgumGmBiouaBFj7sWfmu7vp.jpg'),
(73038, 5005, 'A Lenda de Sleepy Hollow S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kAqFE9XBKuuhtV2EVA5u6VrSDU.jpg'),
(73039, 5005, 'A Lenda de Sleepy Hollow S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kniDqREJqJSzP2Xo0nhMa7ZBTbg.jpg'),
(73040, 5005, 'A Lenda de Sleepy Hollow S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yfNCuwlnzBnWZ2VjPgsxA1dgrmJ.jpg'),
(73041, 5005, 'A Lenda de Sleepy Hollow S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e3agT16ef5to3oXwFWpbQLBU31F.jpg'),
(73042, 5005, 'A Lenda de Sleepy Hollow S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e5shtp4MiUbtBRyXtmY1RI1tyt4.jpg'),
(73043, 5005, 'A Lenda de Sleepy Hollow S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rFrgKcaqNvGAVtAMX929ILHVesQ.jpg'),
(73044, 5005, 'A Lenda de Sleepy Hollow S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fFvZ8lpiTJMtodJ22Tm7cx1hsyV.jpg'),
(73045, 5005, 'A Lenda de Sleepy Hollow S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/170493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xeEci1yDs66il1ICLBjpSaruQ0g.jpg'),
(73046, 5005, 'A Lenda de Sleepy Hollow S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/170494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmJgU4J34MUyJ8UB9AcTthfX3Wn.jpg'),
(73047, 5005, 'A Lenda de Sleepy Hollow S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/170495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8jQd3wmI3mqyybKPjftZ5s6Awqg.jpg'),
(73048, 5005, 'A Lenda de Sleepy Hollow S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/170496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gRKdku7YUws48vfG9xQXzF3x66f.jpg'),
(73049, 5005, 'A Lenda de Sleepy Hollow S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/170497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qj2vvGjDElo8ohYOeF7ogRPSxWw.jpg'),
(73050, 5005, 'A Lenda de Sleepy Hollow S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/170498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6wteSXlfjDOkWvIEJAAEi7ZWhW4.jpg'),
(73051, 5006, 'A Lenda de Sleepy Hollow S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6eC69nUtm1cwwbxx6LweMmuclvP.jpg'),
(73052, 5006, 'A Lenda de Sleepy Hollow S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/boDjKfwnjhFUgGCkjmBfLXujv7W.jpg'),
(73053, 5006, 'A Lenda de Sleepy Hollow S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zOyjTFJFS86oZeHn8jH1wR7LCRC.jpg'),
(73054, 5006, 'A Lenda de Sleepy Hollow S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ywAF5CDjfVJXAr5hYtseXwiy7g7.jpg'),
(73055, 5006, 'A Lenda de Sleepy Hollow S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7qxXvfYG7gnzBBk0RqORdj2rtYS.jpg'),
(73056, 5006, 'A Lenda de Sleepy Hollow S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/45bTvmjY8XPoHNKcPZgCxYsJCMF.jpg'),
(73057, 5006, 'A Lenda de Sleepy Hollow S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5t1bzyALGI1PBHBo7ZAZwyt8Jwt.jpg'),
(73058, 5006, 'A Lenda de Sleepy Hollow S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vh2n2CuEhr1hZYrUALIj8hTCPvs.jpg'),
(73059, 5006, 'A Lenda de Sleepy Hollow S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/agpMhDnPVcjonAXofraFdAEO5gI.jpg'),
(73060, 5006, 'A Lenda de Sleepy Hollow S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5NwBSskYTxhphrgvSBHUzTmCUJH.jpg'),
(73061, 5006, 'A Lenda de Sleepy Hollow S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ppFll87900fjPQhslKCaU0n2BqD.jpg'),
(73062, 5006, 'A Lenda de Sleepy Hollow S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zPh7JS9itmdYA14UCjOpklqD0vL.jpg'),
(73063, 5006, 'A Lenda de Sleepy Hollow S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/170511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1mXIADSRHz75NpNUWb1BuGft4tk.jpg'),
(73064, 5006, 'A Lenda de Sleepy Hollow S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/170512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w5KjRNHztKsqQafb9UmiX2n0Uam.jpg'),
(73065, 5006, 'A Lenda de Sleepy Hollow S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/170513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u60X7q8AuqTd49diur7tpenr2t3.jpg'),
(73066, 5006, 'A Lenda de Sleepy Hollow S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/170514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j5IIeyfIiasy15nHfDlZIoJUeef.jpg'),
(73067, 5006, 'A Lenda de Sleepy Hollow S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/170515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dl8KVllbLII7aE8CvB04zm2QQqR.jpg'),
(73068, 5006, 'A Lenda de Sleepy Hollow S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/170516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4cl4X1bTtjkvgUGKVXw6bmlAmVy.jpg'),
(73069, 5007, 'A Lenda de Sleepy Hollow S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sCVU5gza0nBatV6moupknDb75gV.jpg'),
(73070, 5007, 'A Lenda de Sleepy Hollow S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1AGM9xxp3cTvbkH4ulgly0MyAtL.jpg'),
(73071, 5007, 'A Lenda de Sleepy Hollow S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kIVRWwb0M27snpOlSPZQZQWtby3.jpg'),
(73072, 5007, 'A Lenda de Sleepy Hollow S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gGgGlg7mf3vYZwxaVxmJkAdaStn.jpg'),
(73073, 5007, 'A Lenda de Sleepy Hollow S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/54pHOiaokLyjSHpZPEFNWR2IPAV.jpg'),
(73074, 5007, 'A Lenda de Sleepy Hollow S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qdUIbFzu66GzdvpHIqHDTYWT8Gr.jpg'),
(73075, 5007, 'A Lenda de Sleepy Hollow S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wUq4pbiAL5qeBkDhWmxpt58Y0Ll.jpg'),
(73076, 5007, 'A Lenda de Sleepy Hollow S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p9TDNz8DLa20LDoH4FGWn2U6XRH.jpg'),
(73077, 5007, 'A Lenda de Sleepy Hollow S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSaIkNqikX57dEiGyMyslCjHii4.jpg'),
(73078, 5007, 'A Lenda de Sleepy Hollow S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7RwXCN7a5ll6j8OypuCBacX2sD4.jpg'),
(73079, 5007, 'A Lenda de Sleepy Hollow S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wQ9gkv7xwh7vpaaLriIHWEaGSf8.jpg'),
(73080, 5007, 'A Lenda de Sleepy Hollow S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/SQZ7Quzvh5SUPO0L85zxAXCOVR.jpg'),
(73081, 5007, 'A Lenda de Sleepy Hollow S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/170529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8vaQeDWmDk2ffGRCYmemfo8w3js.jpg'),
(73082, 5008, 'A Vida Sexual das Universitárias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p8l6LZp5DdrWUGcUEt1PCfiZDHT.jpg'),
(73083, 5008, 'A Vida Sexual das Universitárias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mI2loK02FylHsihb7OaIPN3PHxv.jpg'),
(73084, 5008, 'A Vida Sexual das Universitárias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQhcHitYTJANhosqkouwSD1E04B.jpg'),
(73085, 5008, 'A Vida Sexual das Universitárias S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n8ieXmCaQgW71kZx7aAa1qL3ZlD.jpg'),
(73086, 5008, 'A Vida Sexual das Universitárias S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aDgJ2gRGf7GbHG1JBBxtJpPeCCg.jpg'),
(73087, 5008, 'A Vida Sexual das Universitárias S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mkOrK2EZW54jP0rzhwfqq0mRHAY.jpg'),
(73088, 5008, 'A Vida Sexual das Universitárias S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AsXXzXmDgjy7b4a5bqNzNBZyon0.jpg'),
(73089, 5008, 'A Vida Sexual das Universitárias S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r4TcjXM3Fmi4wPj2T1D1hhSQbLj.jpg'),
(73090, 5008, 'A Vida Sexual das Universitárias S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2ZdlXbf28JSPWNxazHuoHU5lGB.jpg'),
(73091, 5008, 'A Vida Sexual das Universitárias S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4m21t8UljHhBXfXBRletvqdaWPb.jpg'),
(73092, 5009, 'A Vida Sexual das Universitárias S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zboNvbaweAOWA9dg74qM3tqV4jH.jpg'),
(73093, 5009, 'A Vida Sexual das Universitárias S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gnwjK5aGAS7hf67vVE9ZqmRFKR3.jpg'),
(73094, 5009, 'A Vida Sexual das Universitárias S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3IJfr7S6zq81zlt3W1q4vauoFAl.jpg'),
(73095, 5009, 'A Vida Sexual das Universitárias S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bUKwtYNiUe2yNkcolTXojhxRYlc.jpg'),
(73096, 5009, 'A Vida Sexual das Universitárias S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/edOwy7KaFGUP6aAZKVtFbbB9Ycd.jpg'),
(73097, 5009, 'A Vida Sexual das Universitárias S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kyF90o9rB140MQLoSYUdedYnCRd.jpg'),
(73098, 5009, 'A Vida Sexual das Universitárias S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1tUS6x3CalaamO4QUSqwkrIkfL.jpg'),
(73099, 5009, 'A Vida Sexual das Universitárias S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y9NdaM7zHnNFfFrSsQL3TtXkebi.jpg'),
(73100, 5009, 'A Vida Sexual das Universitárias S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eHHKNh7Ar49TnBt4PvU3dPLTtC1.jpg'),
(73101, 5009, 'A Vida Sexual das Universitárias S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fBouhCVT9q83Zb5uWKgGioT5Kja.jpg'),
(73102, 5010, 'A Vida Sexual das Universitárias S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/512618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehZETR3w8YTD0o7eWOXi41SS2Ll.jpg'),
(73103, 5010, 'A Vida Sexual das Universitárias S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/514765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehZETR3w8YTD0o7eWOXi41SS2Ll.jpg'),
(73104, 5010, 'A Vida Sexual das Universitárias S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehZETR3w8YTD0o7eWOXi41SS2Ll.jpg'),
(73105, 5010, 'A Vida Sexual das Universitárias S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehZETR3w8YTD0o7eWOXi41SS2Ll.jpg'),
(73106, 5010, 'A Vida Sexual das Universitárias S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/639751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehZETR3w8YTD0o7eWOXi41SS2Ll.jpg'),
(73107, 5010, 'A Vida Sexual das Universitárias S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/659885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehZETR3w8YTD0o7eWOXi41SS2Ll.jpg'),
(73108, 5010, 'A Vida Sexual das Universitárias S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/659886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehZETR3w8YTD0o7eWOXi41SS2Ll.jpg'),
(73109, 5010, 'A Vida Sexual das Universitárias S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/663177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehZETR3w8YTD0o7eWOXi41SS2Ll.jpg'),
(73110, 5010, 'A Vida Sexual das Universitárias S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/666370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehZETR3w8YTD0o7eWOXi41SS2Ll.jpg'),
(73111, 5010, 'A Vida Sexual das Universitárias S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/677825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehZETR3w8YTD0o7eWOXi41SS2Ll.jpg'),
(73112, 5011, 'Águas do Norte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8K6sbIUHmizEhel42jlE5ZNJzY2.jpg'),
(73113, 5011, 'Águas do Norte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/12ve3G6uhVSsMVM83gGLmDgYEk0.jpg'),
(73114, 5011, 'Águas do Norte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uJvlOicEjGFlBX2PDV3CfjhVYBU.jpg'),
(73115, 5011, 'Águas do Norte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yEh5CMyqNzFIiBByu5P23kmVRlY.jpg'),
(73116, 5011, 'Águas do Norte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yBDspe0CxvEd2j8Qy3kayDzbo6v.jpg'),
(73117, 5011, 'Águas do Norte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lLxkJ3nn5UEGF3urCYndD1DmlIq.jpg'),
(73118, 5012, 'Any Malu Show S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170437.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73119, 5012, 'Any Malu Show S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170438.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73120, 5012, 'Any Malu Show S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170439.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73121, 5012, 'Any Malu Show S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170440.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73122, 5012, 'Any Malu Show S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170441.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73123, 5012, 'Any Malu Show S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170442.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73124, 5012, 'Any Malu Show S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170443.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73125, 5012, 'Any Malu Show S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170444.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73126, 5012, 'Any Malu Show S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170445.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73127, 5012, 'Any Malu Show S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170446.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73128, 5012, 'Any Malu Show S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170447.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73129, 5012, 'Any Malu Show S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170448.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73130, 5012, 'Any Malu Show S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/170449.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73131, 5013, 'Any Malu Show S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170450.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73132, 5013, 'Any Malu Show S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170451.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73133, 5013, 'Any Malu Show S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170452.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73134, 5013, 'Any Malu Show S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170453.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73135, 5013, 'Any Malu Show S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170454.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73136, 5013, 'Any Malu Show S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170455.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73137, 5013, 'Any Malu Show S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170456.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73138, 5013, 'Any Malu Show S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170457.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73139, 5013, 'Any Malu Show S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170458.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73140, 5013, 'Any Malu Show S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170459.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73141, 5013, 'Any Malu Show S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170460.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73142, 5013, 'Any Malu Show S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170461.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73143, 5013, 'Any Malu Show S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/170462.mp4', 'https://i.bj-share.info/3b27328fba93d6e6d8a6ecb989388faf.jpg'),
(73144, 5014, 'Balthazar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yJ2bKmQq4IOKOu5HTXreUrjZSz3.jpg'),
(73145, 5014, 'Balthazar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13GaSYiSR6KxnCByBNRS8H6wtSZ.jpg'),
(73146, 5014, 'Balthazar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sSc8qMo5Sq5yRouHrieH9ixqt93.jpg'),
(73147, 5014, 'Balthazar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kUz4bLi8AHjLuhiyNKuwaoYfDKs.jpg'),
(73148, 5014, 'Balthazar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCaz7CM6QyCbwHZF3AF4ylyv1bN.jpg'),
(73149, 5014, 'Balthazar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/khnvW3gP99LKXIIwO2UqxsX23x2.jpg'),
(73150, 5015, 'Balthazar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182644.mp4', 'http://timg.bdta.pro/images/c37e58cd841b489d16968bb34ff32a91.jpg'),
(73151, 5015, 'Balthazar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182645.mp4', 'http://timg.bdta.pro/images/c9a5fd59462f12ee4728d0dc85611674.jpg'),
(73152, 5015, 'Balthazar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182646.mp4', 'http://timg.bdta.pro/images/2f33033c78c12b02279a6709f0031afc.jpg'),
(73153, 5015, 'Balthazar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182647.mp4', 'http://timg.bdta.pro/images/d2a0703fa97c579af5adfe2de003e057.jpg'),
(73154, 5015, 'Balthazar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182648.mp4', 'http://timg.bdta.pro/images/3f0d1c1a3e97c01efc35d440cec7b806.jpg'),
(73155, 5015, 'Balthazar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182649.mp4', 'http://timg.bdta.pro/images/2fa460ef286bf97e880f97b4422d2497.jpg'),
(73156, 5015, 'Balthazar S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182650.mp4', 'http://timg.bdta.pro/images/e12b96da78d536b56d66c71fd7bb28fe.jpg'),
(73157, 5015, 'Balthazar S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182651.mp4', 'http://timg.bdta.pro/images/a1d87ddadd9b5f0ceef999898678db2c.jpg'),
(73158, 5015, 'Balthazar S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/182652.mp4', 'http://timg.bdta.pro/images/34e51c3ad94499f3faf5b26993a7acbd.jpg'),
(73159, 5015, 'Balthazar S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/182653.mp4', 'http://timg.bdta.pro/images/2b14e91895d826b9b2fe5a306061614b.jpg'),
(73160, 5016, 'Balthazar S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182654.mp4', 'http://timg.bdta.pro/images/c8fe0098e40f84db40411daa0ddd00e0.jpg'),
(73161, 5016, 'Balthazar S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182655.mp4', 'http://timg.bdta.pro/images/e3e24bfef959c24b651bde3ef8c2f06f.jpg'),
(73162, 5016, 'Balthazar S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182656.mp4', 'http://timg.bdta.pro/images/19da5b3c35d3db3659bd563df70602bc.jpg'),
(73163, 5016, 'Balthazar S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182657.mp4', 'http://timg.bdta.pro/images/e5b55eda1b737d2683f7f782eea3fb40.jpg'),
(73164, 5016, 'Balthazar S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182658.mp4', 'http://timg.bdta.pro/images/3961b5bc8f0963751aed694979432ebe.jpg'),
(73165, 5016, 'Balthazar S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182659.mp4', 'http://timg.bdta.pro/images/07c23d26a340a2fbf3a53b6bb6fbaa00.jpg'),
(73166, 5016, 'Balthazar S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182660.mp4', 'http://timg.bdta.pro/images/50f8fc66baf5104738e10296613ccb00.jpg'),
(73167, 5016, 'Balthazar S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182661.mp4', 'http://timg.bdta.pro/images/1a96c649904b4be1a93e53b37bf750ec.jpg'),
(73168, 5017, 'Balthazar S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182662.mp4', 'http://timg.bdta.pro/images/28ab5c1c22d3bf9a9d823c2eafdec296.jpg'),
(73169, 5017, 'Balthazar S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182663.mp4', 'http://timg.bdta.pro/images/a5d200bd3996be463ab2dcbb7aa13ad9.jpg'),
(73170, 5017, 'Balthazar S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182664.mp4', 'http://timg.bdta.pro/images/d6bb9bb3f754024288626885c5d9a039.jpg'),
(73171, 5017, 'Balthazar S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182665.mp4', 'http://timg.bdta.pro/images/06d476f002397f2a64b8aef111d41fd7.jpg'),
(73172, 5017, 'Balthazar S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182666.mp4', 'http://timg.bdta.pro/images/867554e674504f4819576879d1803b9a.jpg'),
(73173, 5017, 'Balthazar S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182667.mp4', 'http://timg.bdta.pro/images/c7a4e8b67c307193633e86166de8f196.jpg'),
(73174, 5017, 'Balthazar S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182668.mp4', 'http://timg.bdta.pro/images/6b3fda8d1be293f6f965f3a749600f99.jpg'),
(73175, 5017, 'Balthazar S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182669.mp4', 'http://timg.bdta.pro/images/96cc38c8afb4b6a45ad7f7420541d56f.jpg'),
(73176, 5018, 'Bem-vindos à Terra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k6MMAIhhkDE5BAt4WZp4H7aQJb4.jpg'),
(73177, 5018, 'Bem-vindos à Terra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ay7BASMAUIHupDLONifNjq10nZw.jpg'),
(73178, 5018, 'Bem-vindos à Terra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s3zyHFpUXgv7mPplG8WccNT5yRG.jpg'),
(73179, 5018, 'Bem-vindos à Terra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qwzp5D5i3sodgXWQAKCxG4L7CfB.jpg'),
(73180, 5018, 'Bem-vindos à Terra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sy7gUJjM2pvs9PGNHkHayrozWJd.jpg'),
(73181, 5018, 'Bem-vindos à Terra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ovgPlpZwVSTUAJAvUGAPZbDLoJU.jpg'),
(73182, 5019, 'Cozinhando o Impossível S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lGNEldnuNcFrGmhzAv9QAbIUiRw.jpg'),
(73183, 5019, 'Cozinhando o Impossível S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7CeS1YmDaRxCODahfT7IeKfdwbu.jpg'),
(73184, 5019, 'Cozinhando o Impossível S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xCOEA45sJryUFnJh6tuz2G9U8es.jpg'),
(73185, 5019, 'Cozinhando o Impossível S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZFY6VZImahQmkX7Q2Dkd2EAum3.jpg'),
(73186, 5019, 'Cozinhando o Impossível S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dmp8bT7xDGxVtqNQxxXEU7zFrN7.jpg'),
(73187, 5019, 'Cozinhando o Impossível S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7379Efj80MECg1NVpWCycz6rSwm.jpg'),
(73188, 5019, 'Cozinhando o Impossível S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cHYjrDbBUdauwzYTB23J9bHA9tT.jpg'),
(73189, 5019, 'Cozinhando o Impossível S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rB2xJ8VpsasYfWNnjKGQwlreX6k.jpg'),
(73190, 5020, 'Gil na Califórnia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWUo21drlb6Jwb7Ika0KFsQYp1V.jpg'),
(73191, 5020, 'Gil na Califórnia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWUo21drlb6Jwb7Ika0KFsQYp1V.jpg'),
(73192, 5020, 'Gil na Califórnia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWUo21drlb6Jwb7Ika0KFsQYp1V.jpg'),
(73193, 5020, 'Gil na Califórnia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWUo21drlb6Jwb7Ika0KFsQYp1V.jpg'),
(73194, 5020, 'Gil na Califórnia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWUo21drlb6Jwb7Ika0KFsQYp1V.jpg'),
(73195, 5021, 'Harry Potter: O Campeonato das Casas de Hogwarts S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168856.mp4', 'http://image.tmdb.org/t/p/w1280/5drpoVxqBSBGQlCgdBcoS4dAASd.jpg'),
(73196, 5021, 'Harry Potter: O Campeonato das Casas de Hogwarts S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZjyjF1cArywOiW29bqeamyVD98.jpg'),
(73197, 5021, 'Harry Potter: O Campeonato das Casas de Hogwarts S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hZYDMzndu7tNgF3DHTGPyGFGn89.jpg'),
(73198, 5021, 'Harry Potter: O Campeonato das Casas de Hogwarts S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168859.mp4', 'http://image.tmdb.org/t/p/w1280/19uOGHh6G9YqPG8xgRSMSf2uG21.jpg'),
(73199, 5022, 'Ice S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5QU6cMGlwc0kE3Aol7ef6vMyC81.jpg'),
(73200, 5022, 'Ice S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p28jjMgYoZALzbRS8TLRAvykjSw.jpg'),
(73201, 5022, 'Ice S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cPJ8alHVSGQAJXXZP7iNPE6I2Xe.jpg'),
(73202, 5022, 'Ice S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hK78dzAmykoF9r0YXYxGDBcauQW.jpg'),
(73203, 5022, 'Ice S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xBWGtUuakun828LpHu52Ep90tV5.jpg'),
(73204, 5022, 'Ice S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oIeiyUNgsykzHEwfV8nkCgNwBQ7.jpg'),
(73205, 5022, 'Ice S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9LqBEyuBOgv76iHFY0vwMACnP7k.jpg'),
(73206, 5022, 'Ice S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kGaNk0hvCc50ZJpRTb6QUNalvn4.jpg'),
(73207, 5022, 'Ice S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jWNyGLJzkoIRmA7sLAmlOUeiMSo.jpg'),
(73208, 5022, 'Ice S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aLlxyuYuFB6CupfyeFn78kM4w29.jpg'),
(73209, 5023, 'Ice S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hFUq0Ssrv7xlWFjq0XXH4FUa7ZM.jpg'),
(73210, 5023, 'Ice S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9hXh0mPpZc6jofRn0JNvpccPxLQ.jpg'),
(73211, 5023, 'Ice S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yGJtvGJdtQHewoxmBWnwLuVn9OT.jpg'),
(73212, 5023, 'Ice S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6H1gzL4rAocrYkY8StzMXO2Wy5b.jpg'),
(73213, 5023, 'Ice S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ehBPzHiKSDssjMClNJKaBgZSDoz.jpg'),
(73214, 5023, 'Ice S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bq2ZA7hSt6FANLCfjSxKcV4CPlw.jpg'),
(73215, 5023, 'Ice S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cjCBdtTmGdFmAqwLN3eDDBv1krk.jpg'),
(73216, 5023, 'Ice S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nqesxcHQY728bSVeO2HRvCTTyyy.jpg'),
(73217, 5023, 'Ice S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6wBKsA2PJLBPevL89P5MNSKIuGH.jpg'),
(73218, 5023, 'Ice S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n4tGo2JFkJk0viZWFcyZRjet5gP.jpg'),
(73219, 5024, 'Kamikaze: Em Queda Livre S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vQMW6rzeuHPBj0dTMgGehSxxJ7r.jpg'),
(73220, 5024, 'Kamikaze: Em Queda Livre S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v0Ckn9bASC2awMLoLaPWiGEFTl9.jpg'),
(73221, 5024, 'Kamikaze: Em Queda Livre S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zaQex3up0fDL1jl7fB2ja2jbUCf.jpg'),
(73222, 5024, 'Kamikaze: Em Queda Livre S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nkzTu2EegmZou5Fm71lc5L4pXQq.jpg'),
(73223, 5024, 'Kamikaze: Em Queda Livre S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fXqzQWfWItu3rbUU0jtPZLDJQIs.jpg'),
(73224, 5024, 'Kamikaze: Em Queda Livre S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cMMcOLu5ZVllDNYEOQBbZYpubpP.jpg'),
(73225, 5024, 'Kamikaze: Em Queda Livre S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2trU7wfgyCUDBYC35avuASjap8.jpg'),
(73226, 5024, 'Kamikaze: Em Queda Livre S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a3RuJtcOiDvLLBp9KYH97ikjQez.jpg'),
(73227, 5025, 'LOL Se Rir Ja Era S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6vhMrdBc4FYJuBCxvjGYSXUMM3j.jpg'),
(73228, 5025, 'LOL Se Rir Ja Era S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3aHrnqyN5aNUWE6YeZ0gAOee49m.jpg'),
(73229, 5025, 'LOL Se Rir Ja Era S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3T5DjPQA47kUpAsjQc3Aua5irAt.jpg'),
(73230, 5025, 'LOL Se Rir Ja Era S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag2xnUhbrRkStDshgrfifmAXgLK.jpg'),
(73231, 5025, 'LOL Se Rir Ja Era S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag2xnUhbrRkStDshgrfifmAXgLK.jpg'),
(73232, 5025, 'LOL Se Rir Ja Era S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag2xnUhbrRkStDshgrfifmAXgLK.jpg'),
(73233, 5026, 'LOL Se Rir Ja Era S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag2xnUhbrRkStDshgrfifmAXgLK.jpg'),
(73234, 5026, 'LOL Se Rir Ja Era S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag2xnUhbrRkStDshgrfifmAXgLK.jpg'),
(73235, 5026, 'LOL Se Rir Ja Era S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag2xnUhbrRkStDshgrfifmAXgLK.jpg'),
(73236, 5026, 'LOL Se Rir Ja Era S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag2xnUhbrRkStDshgrfifmAXgLK.jpg'),
(73237, 5026, 'LOL Se Rir Ja Era S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag2xnUhbrRkStDshgrfifmAXgLK.jpg'),
(73238, 5026, 'LOL Se Rir Ja Era S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag2xnUhbrRkStDshgrfifmAXgLK.jpg'),
(73239, 5027, 'LOL Se Rir Ja Era S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag2xnUhbrRkStDshgrfifmAXgLK.jpg'),
(73240, 5027, 'LOL Se Rir Ja Era S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag2xnUhbrRkStDshgrfifmAXgLK.jpg'),
(73241, 5027, 'LOL Se Rir Ja Era S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag2xnUhbrRkStDshgrfifmAXgLK.jpg'),
(73242, 5027, 'LOL Se Rir Ja Era S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag2xnUhbrRkStDshgrfifmAXgLK.jpg'),
(73243, 5027, 'LOL Se Rir Ja Era S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag2xnUhbrRkStDshgrfifmAXgLK.jpg'),
(73244, 5027, 'LOL Se Rir Ja Era S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag2xnUhbrRkStDshgrfifmAXgLK.jpg'),
(73245, 5028, 'LOL Se Rir Ja Era S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/784880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kEbwSW9cDbIG020dEtDJTT82ioR.jpg'),
(73246, 5028, 'LOL Se Rir Ja Era S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/784881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6PIPADtF2f2pGMCPqLe5mrpQMHI.jpg'),
(73247, 5028, 'LOL Se Rir Ja Era S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/784882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8c8fbwPBRUXIn85Oy9hFGirWjZs.jpg'),
(73248, 5028, 'LOL Se Rir Ja Era S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/778011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag2xnUhbrRkStDshgrfifmAXgLK.jpg'),
(73249, 5028, 'LOL Se Rir Ja Era S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/778012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag2xnUhbrRkStDshgrfifmAXgLK.jpg'),
(73250, 5028, 'LOL Se Rir Ja Era S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/778013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag2xnUhbrRkStDshgrfifmAXgLK.jpg'),
(73251, 5029, 'Largados e Pelados: Sozinhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170370.mp4', 'https://i.bj-share.info/13ce6d475742c8e11b9cdbedb7630add.jpg'),
(73252, 5029, 'Largados e Pelados: Sozinhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170371.mp4', 'https://i.bj-share.info/13ce6d475742c8e11b9cdbedb7630add.jpg'),
(73253, 5029, 'Largados e Pelados: Sozinhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170372.mp4', 'https://i.bj-share.info/13ce6d475742c8e11b9cdbedb7630add.jpg'),
(73254, 5029, 'Largados e Pelados: Sozinhos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170373.mp4', 'https://i.bj-share.info/13ce6d475742c8e11b9cdbedb7630add.jpg'),
(73255, 5029, 'Largados e Pelados: Sozinhos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170374.mp4', 'https://i.bj-share.info/13ce6d475742c8e11b9cdbedb7630add.jpg'),
(73256, 5029, 'Largados e Pelados: Sozinhos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170375.mp4', 'https://i.bj-share.info/13ce6d475742c8e11b9cdbedb7630add.jpg'),
(73257, 5029, 'Largados e Pelados: Sozinhos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170376.mp4', 'https://i.bj-share.info/13ce6d475742c8e11b9cdbedb7630add.jpg'),
(73258, 5029, 'Largados e Pelados: Sozinhos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170377.mp4', 'https://i.bj-share.info/13ce6d475742c8e11b9cdbedb7630add.jpg'),
(73259, 5030, 'Meikyuu Black Company S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170378.mp4', 'http://image.tmdb.org/t/p/w1280/pXbIYCzP4ZpB1Ur1yJOBQTviuDe.jpg'),
(73260, 5030, 'Meikyuu Black Company S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qWs0WyBGyM49gmXaI8IRMCKGV9y.jpg'),
(73261, 5030, 'Meikyuu Black Company S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ceSmI4F82bYWpAqj9FsT6KbCxMQ.jpg'),
(73262, 5030, 'Meikyuu Black Company S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eX2QSv8Zhy5tnWKjg4qjWV3Uyf0.jpg'),
(73263, 5030, 'Meikyuu Black Company S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nBAEDWSMFkdHL7LtG6pCsJPBuzP.jpg'),
(73264, 5030, 'Meikyuu Black Company S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8hhlzVXo5Nxk7xtQqlNFovHeVnP.jpg'),
(73265, 5030, 'Meikyuu Black Company S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/12BCkPU3TKILDW1wwCbD4W85DjY.jpg'),
(73266, 5030, 'Meikyuu Black Company S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/N5GjJMcNiDPYsfEctahzau1nCb.jpg'),
(73267, 5030, 'Meikyuu Black Company S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iTicGMQZoKeRcxOHoCeCjoy82hn.jpg'),
(73268, 5030, 'Meikyuu Black Company S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wy8Wt62ftHdvRBzZ7Ts8uLTXfHM.jpg'),
(73269, 5030, 'Meikyuu Black Company S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aINU6MR3TiNCkjhue8jhiyRhSJc.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(73270, 5030, 'Meikyuu Black Company S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ulI51ATnlIep1xfSlWnqAyWEeV.jpg'),
(73271, 5031, 'Pesca Mortal: Aventura no Sangue S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFaF3iIJwjvXroID142nLBH9PKM.jpg'),
(73272, 5031, 'Pesca Mortal: Aventura no Sangue S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7hjMDEk6RYILR9pTVIAKluEGLjX.jpg'),
(73273, 5031, 'Pesca Mortal: Aventura no Sangue S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f6qz5O7SfFw4WkNlPf3iYX5AyIH.jpg'),
(73274, 5031, 'Pesca Mortal: Aventura no Sangue S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5d4GsHBTuUIOIp3rQ16CeoNuxVk.jpg'),
(73275, 5031, 'Pesca Mortal: Aventura no Sangue S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6sOgm5Do8kOmMeSgSFLkIdSvK8A.jpg'),
(73276, 5031, 'Pesca Mortal: Aventura no Sangue S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOBoI3L7KMuOuSk8rv3iPsAfgAk.jpg'),
(73277, 5032, 'Pesca Mortal: Aventura no Sangue S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7HGwicpqZrGr8Xxu4t8hcAthJXL.jpg'),
(73278, 5032, 'Pesca Mortal: Aventura no Sangue S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xjygiz8I0iRSZrO0HHEpWebN38N.jpg'),
(73279, 5032, 'Pesca Mortal: Aventura no Sangue S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q9SNPFRb7JZZe3uYRHMFZP2G4zM.jpg'),
(73280, 5032, 'Pesca Mortal: Aventura no Sangue S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYrlCxDukWtvFx3iudCtRZQfTl1.jpg'),
(73281, 5032, 'Pesca Mortal: Aventura no Sangue S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xx3kXdX8gFVoAzNTZXa6sVGHt0N.jpg'),
(73282, 5032, 'Pesca Mortal: Aventura no Sangue S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3Ybcw88FLs2QvRVcuA0Z1MvoQW.jpg'),
(73283, 5032, 'Pesca Mortal: Aventura no Sangue S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gaKFErSwdN7Ced1YWmsHufTfJKh.jpg'),
(73284, 5032, 'Pesca Mortal: Aventura no Sangue S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pXV2iCaHbP9Pw9MbBycNpozILdT.jpg'),
(73285, 5032, 'Pesca Mortal: Aventura no Sangue S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mhQdFNXvUkFjlUCi6roXAPRCqxL.jpg'),
(73286, 5032, 'Pesca Mortal: Aventura no Sangue S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wIQWLNzJ2JTrxzpHa2Jr4mjApr8.jpg'),
(73287, 5033, 'Pesca Mortal: Aventura no Sangue S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sW4dC8uxndd3jQ9cqBMzIYFcIIY.jpg'),
(73288, 5033, 'Pesca Mortal: Aventura no Sangue S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nkmFvWMdQa5rxy9BER2AmkTY8b4.jpg'),
(73289, 5033, 'Pesca Mortal: Aventura no Sangue S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w97FI2vqC8cq7XMCnrSflsbKqFS.jpg'),
(73290, 5033, 'Pesca Mortal: Aventura no Sangue S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5xk6KsU4nIEDmdOkcNiYxhjiQG5.jpg'),
(73291, 5033, 'Pesca Mortal: Aventura no Sangue S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9N02OnAuTGhL1FH6W520KvxXDwP.jpg'),
(73292, 5033, 'Pesca Mortal: Aventura no Sangue S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mOiABGJlZeg9h2i0HPtGeOpFJxE.jpg'),
(73293, 5033, 'Pesca Mortal: Aventura no Sangue S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ve0D9VzQgYMCTvXlfPE32CYvPoQ.jpg'),
(73294, 5033, 'Pesca Mortal: Aventura no Sangue S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nwn8eU9xHI3Pf5Cy5PDFy1qyARW.jpg'),
(73295, 5033, 'Pesca Mortal: Aventura no Sangue S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dzPV5znBKU7DLVVKhQpk0DBorPd.jpg'),
(73296, 5033, 'Pesca Mortal: Aventura no Sangue S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AhX5sxGxpO3im8SFlUuoro7LSk0.jpg'),
(73297, 5033, 'Pesca Mortal: Aventura no Sangue S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5d4GsHBTuUIOIp3rQ16CeoNuxVk.jpg'),
(73298, 5033, 'Pesca Mortal: Aventura no Sangue S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5d4GsHBTuUIOIp3rQ16CeoNuxVk.jpg'),
(73299, 5034, 'Refletidas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pe37hKLTu3dK8unziyB6A7yFYFr.jpg'),
(73300, 5034, 'Refletidas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4tjG3ADEbiWT9JP5ThvUSyftlrH.jpg'),
(73301, 5034, 'Refletidas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bG6ULNNBF7fJotwKW9L5IBLp9S7.jpg'),
(73302, 5034, 'Refletidas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hv3BrmRLqNjpL2HWa1xmKPjWXvp.jpg'),
(73303, 5034, 'Refletidas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4sf35CkxdITZdt0xdbf2u8i3Nry.jpg'),
(73304, 5034, 'Refletidas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ivshLCIHFco5cfa0wMpkQSUYoYO.jpg'),
(73305, 5034, 'Refletidas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pLYia5TxUmW2HGL3fdxyKFN6fTv.jpg'),
(73306, 5034, 'Refletidas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOTFzf2ZLZCYsv77UpsQO5AfB4f.jpg'),
(73307, 5034, 'Refletidas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qNx83hrioPEbt8aDW1714wxnina.jpg'),
(73308, 5034, 'Refletidas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v1flnvAK3uCaZHUyPrvxxfEn7qj.jpg'),
(73309, 5034, 'Refletidas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/174687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oaWSEPyOI6bZgWdV1RE2HKxYhSy.jpg'),
(73310, 5034, 'Refletidas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/174688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pdF5cFb7IVyFhEuPBd9GmQb6sCb.jpg'),
(73311, 5034, 'Refletidas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/174689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/66QGoAgVg1USrsAELCy2txEEKj.jpg'),
(73312, 5034, 'Refletidas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/174690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pnn93KJXDPuuTcCWnVTznmNOiRP.jpg'),
(73313, 5034, 'Refletidas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/174691.mp4', 'http://timg.bdta.pro/images/0cf30dfe5076bc523d71df2b9ac91a0e.jpg'),
(73314, 5034, 'Refletidas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/174692.mp4', 'http://timg.bdta.pro/images/d5918fa9fae2a8e4e109605d0488b339.jpg'),
(73315, 5035, 'Rio Shore S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7TK7VoNV0xOk8FUcYD8kThBFMTy.jpg'),
(73316, 5035, 'Rio Shore S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7TK7VoNV0xOk8FUcYD8kThBFMTy.jpg'),
(73317, 5035, 'Rio Shore S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7TK7VoNV0xOk8FUcYD8kThBFMTy.jpg'),
(73318, 5035, 'Rio Shore S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7TK7VoNV0xOk8FUcYD8kThBFMTy.jpg'),
(73319, 5035, 'Rio Shore S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7TK7VoNV0xOk8FUcYD8kThBFMTy.jpg'),
(73320, 5035, 'Rio Shore S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7TK7VoNV0xOk8FUcYD8kThBFMTy.jpg'),
(73321, 5035, 'Rio Shore S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7TK7VoNV0xOk8FUcYD8kThBFMTy.jpg'),
(73322, 5035, 'Rio Shore S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7TK7VoNV0xOk8FUcYD8kThBFMTy.jpg'),
(73323, 5035, 'Rio Shore S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7TK7VoNV0xOk8FUcYD8kThBFMTy.jpg'),
(73324, 5035, 'Rio Shore S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7TK7VoNV0xOk8FUcYD8kThBFMTy.jpg'),
(73325, 5035, 'Rio Shore S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7TK7VoNV0xOk8FUcYD8kThBFMTy.jpg'),
(73326, 5035, 'Rio Shore S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7TK7VoNV0xOk8FUcYD8kThBFMTy.jpg'),
(73327, 5036, 'Rio Shore S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233284.mp4', 'http://timg.bdta.pro/images/ce816cecd1659a2b4ae49c6270775c07.jpg'),
(73328, 5036, 'Rio Shore S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233285.mp4', 'http://timg.bdta.pro/images/8b6f4b8b75175e1d39746f609f7fdc9d.jpg'),
(73329, 5036, 'Rio Shore S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233286.mp4', 'http://timg.bdta.pro/images/afdb7b1c66b8cd55d327adeb98e475c1.jpg'),
(73330, 5036, 'Rio Shore S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/577958.mp4', 'http://gstaticontent.com/images/67ea4280a7f96ee204b61490632cdc8d.jpg'),
(73331, 5036, 'Rio Shore S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233289.mp4', 'http://timg.bdta.pro/images/9fd38120f74e24ff8ce03cf8d87ff2e1.jpg'),
(73332, 5036, 'Rio Shore S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233290.mp4', 'http://timg.bdta.pro/images/8bd710d055d28081d2bf8700de930c37.jpg'),
(73333, 5036, 'Rio Shore S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233291.mp4', 'http://timg.bdta.pro/images/25834650799e8fb1db5ecc909ac7a716.jpg'),
(73334, 5036, 'Rio Shore S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233292.mp4', 'http://timg.bdta.pro/images/5008c1f1e26aae4cd777345005d9a353.jpg'),
(73335, 5036, 'Rio Shore S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233293.mp4', 'http://timg.bdta.pro/images/3c70c4dbf57e4aa20e3513ca0b2f3295.jpg'),
(73336, 5036, 'Rio Shore S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233294.mp4', 'http://timg.bdta.pro/images/55b0942858a8303c0228cf72761f5a41.jpg'),
(73337, 5036, 'Rio Shore S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233295.mp4', 'http://timg.bdta.pro/images/b163bd4fabe7b19325ba7d000971343f.jpg'),
(73338, 5036, 'Rio Shore S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233296.mp4', 'http://timg.bdta.pro/images/d40fa79c98fcd22b9ead2b03c4e4d182.jpg'),
(73339, 5037, 'Rio Shore S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233297.mp4', 'http://image.tmdb.org/t/p/w1280/9U6sHlg5zFBZTk1kQaO9RLOciJ.jpg'),
(73340, 5037, 'Rio Shore S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233298.mp4', 'http://image.tmdb.org/t/p/w1280/oKzocDSqVG1TEe7QCuPTQdf4la8.jpg'),
(73341, 5037, 'Rio Shore S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7TK7VoNV0xOk8FUcYD8kThBFMTy.jpg'),
(73342, 5037, 'Rio Shore S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233300.mp4', 'http://image.tmdb.org/t/p/w1280/ApOUeFPR0PvtNkKaLO7IGK91aQD.jpg'),
(73343, 5037, 'Rio Shore S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233301.mp4', 'http://image.tmdb.org/t/p/w1280/9buqZObwlxXvOJj5K1TFGXy4BRG.jpg'),
(73344, 5037, 'Rio Shore S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233302.mp4', 'http://image.tmdb.org/t/p/w1280/3ps4xfcflmoOceKHqeo3T24w9M9.jpg'),
(73345, 5037, 'Rio Shore S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7TK7VoNV0xOk8FUcYD8kThBFMTy.jpg'),
(73346, 5037, 'Rio Shore S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233304.mp4', 'http://image.tmdb.org/t/p/w1280/hGXFe1OpVZwusbjtsS9Yl1Npued.jpg'),
(73347, 5037, 'Rio Shore S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7TK7VoNV0xOk8FUcYD8kThBFMTy.jpg'),
(73348, 5037, 'Rio Shore S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7TK7VoNV0xOk8FUcYD8kThBFMTy.jpg'),
(73349, 5037, 'Rio Shore S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7TK7VoNV0xOk8FUcYD8kThBFMTy.jpg'),
(73350, 5037, 'Rio Shore S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7TK7VoNV0xOk8FUcYD8kThBFMTy.jpg'),
(73351, 5038, 'Supernormal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9jUVVSgVJlm5UTvZU2WzrS6l8DS.jpg'),
(73352, 5038, 'Supernormal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n9mFhX32LbyyiUVorndDjd7dLxK.jpg'),
(73353, 5038, 'Supernormal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nKGCUYk9DVrGMqysaxpVEj4spDb.jpg'),
(73354, 5038, 'Supernormal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/19KdHOKX1VwguqbRnNuhcv47yUg.jpg'),
(73355, 5038, 'Supernormal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nLXoS5V6r524yFlRpquB2dF9zGF.jpg'),
(73356, 5038, 'Supernormal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ccIzDsbymxYdOI81EAbQCAQzH6O.jpg'),
(73357, 5039, 'Vida de Madeireiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nOrGMFnZ5vfGoGzXmiQRVQP4602.jpg'),
(73358, 5039, 'Vida de Madeireiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cSffNhO03WV8MVcyCfDPv4mNcH0.jpg'),
(73359, 5039, 'Vida de Madeireiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lJtbEWYbp3hU8OYcuUpb1b4Q7Yp.jpg'),
(73360, 5039, 'Vida de Madeireiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gSXPjHKIJEPQk2SHgvHXkdXVC0x.jpg'),
(73361, 5039, 'Vida de Madeireiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dMfqPWYwjxWdKpWrxkVN09Rz274.jpg'),
(73362, 5039, 'Vida de Madeireiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6A7XKMNExuh66oSKPpN19rWDSgi.jpg'),
(73363, 5039, 'Vida de Madeireiro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iinwylvUPyWzw978HvaPvp83M1N.jpg'),
(73364, 5039, 'Vida de Madeireiro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hBixbe97Y02wh5j1wCo0hUNf8Cw.jpg'),
(73365, 5039, 'Vida de Madeireiro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jdVmBEJuilDXeACCYkH7bGusS1Z.jpg'),
(73366, 5039, 'Vida de Madeireiro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q4eQjdmwtIXBrGY0WA0DBdsXH0H.jpg'),
(73367, 5040, 'Vida de Madeireiro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/53fQBZPnslE7pWG7Obv5nB1FtnS.jpg'),
(73368, 5040, 'Vida de Madeireiro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mePtg8QVS95B4omCgLBjK3qPvxa.jpg'),
(73369, 5040, 'Vida de Madeireiro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vxumFxW43KrtdBC13nxNIe76nOB.jpg'),
(73370, 5040, 'Vida de Madeireiro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mkU3cfr7nZNZ21PHZUA4zf1zYKu.jpg'),
(73371, 5040, 'Vida de Madeireiro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q5ZTErQnbp9diobtCGEKO0TmsjG.jpg'),
(73372, 5040, 'Vida de Madeireiro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ay3qaFi774ajQxTktotJsXOmgrQ.jpg'),
(73373, 5040, 'Vida de Madeireiro S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nrBFfLqA9lrohlcKu3GG1wIR2Ih.jpg'),
(73374, 5040, 'Vida de Madeireiro S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aY4UtG2SWgYQS8olOFGzH5DcnRp.jpg'),
(73375, 5041, 'Largados e Pelados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e87kOWVI7XvkOYHIA3HzqomOvbc.jpg'),
(73376, 5041, 'Largados e Pelados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPMjSnuOA5z9wEgFZsujZQlr7f4.jpg'),
(73377, 5041, 'Largados e Pelados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lqa7WzThaBdKbkuGrRGmfFsFK5U.jpg'),
(73378, 5041, 'Largados e Pelados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Ymm57jOMa522An8xzN2EoIPn1Q.jpg'),
(73379, 5041, 'Largados e Pelados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dxw4ZPSWrgx7zrZtfyuDY18USFs.jpg'),
(73380, 5041, 'Largados e Pelados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73381, 5041, 'Largados e Pelados S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73382, 5041, 'Largados e Pelados S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Z1hTbLWFkLIQnuJe6ZSNjl2nV1.jpg'),
(73383, 5042, 'Largados e Pelados S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73384, 5042, 'Largados e Pelados S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73385, 5042, 'Largados e Pelados S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73386, 5042, 'Largados e Pelados S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73387, 5042, 'Largados e Pelados S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73388, 5042, 'Largados e Pelados S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73389, 5043, 'Largados e Pelados S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73390, 5043, 'Largados e Pelados S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73391, 5043, 'Largados e Pelados S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73392, 5043, 'Largados e Pelados S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73393, 5043, 'Largados e Pelados S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73394, 5043, 'Largados e Pelados S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73395, 5043, 'Largados e Pelados S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73396, 5043, 'Largados e Pelados S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73397, 5043, 'Largados e Pelados S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73398, 5043, 'Largados e Pelados S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73399, 5044, 'Largados e Pelados S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73400, 5044, 'Largados e Pelados S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73401, 5044, 'Largados e Pelados S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73402, 5044, 'Largados e Pelados S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73403, 5044, 'Largados e Pelados S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gVzxxsMTpI7qfxjMNzNAzJ3FxPL.jpg'),
(73404, 5044, 'Largados e Pelados S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2oQSsFqvVQwT0Cf1or8wPrNnVQg.jpg'),
(73405, 5044, 'Largados e Pelados S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4DC7EQah9EGMTQp3IvGspK3wdZl.jpg'),
(73406, 5044, 'Largados e Pelados S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b2ivUi3VvqlSRr4WywQpY7bsBi0.jpg'),
(73407, 5044, 'Largados e Pelados S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qQtfsst4xBAtzozwrKqetSzW9w6.jpg'),
(73408, 5044, 'Largados e Pelados S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73409, 5044, 'Largados e Pelados S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AbnrvHf7Ba8dgyprYcdKZsWdCcR.jpg'),
(73410, 5045, 'Largados e Pelados S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73411, 5045, 'Largados e Pelados S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73412, 5045, 'Largados e Pelados S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73413, 5045, 'Largados e Pelados S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73414, 5045, 'Largados e Pelados S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73415, 5045, 'Largados e Pelados S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73416, 5045, 'Largados e Pelados S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73417, 5045, 'Largados e Pelados S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73418, 5045, 'Largados e Pelados S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73419, 5046, 'Largados e Pelados S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73420, 5046, 'Largados e Pelados S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73421, 5046, 'Largados e Pelados S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73422, 5046, 'Largados e Pelados S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73423, 5046, 'Largados e Pelados S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73424, 5046, 'Largados e Pelados S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73425, 5046, 'Largados e Pelados S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73426, 5046, 'Largados e Pelados S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73427, 5046, 'Largados e Pelados S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73428, 5046, 'Largados e Pelados S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73429, 5046, 'Largados e Pelados S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73430, 5046, 'Largados e Pelados S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73431, 5047, 'Largados e Pelados S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73432, 5047, 'Largados e Pelados S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73433, 5047, 'Largados e Pelados S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73434, 5047, 'Largados e Pelados S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73435, 5047, 'Largados e Pelados S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73436, 5047, 'Largados e Pelados S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73437, 5047, 'Largados e Pelados S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73438, 5047, 'Largados e Pelados S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73439, 5047, 'Largados e Pelados S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73440, 5047, 'Largados e Pelados S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73441, 5047, 'Largados e Pelados S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73442, 5048, 'Largados e Pelados S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73443, 5048, 'Largados e Pelados S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73444, 5048, 'Largados e Pelados S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73445, 5048, 'Largados e Pelados S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73446, 5048, 'Largados e Pelados S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73447, 5048, 'Largados e Pelados S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73448, 5049, 'Largados e Pelados S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/naAcXIPOYgidgoup7uKI61Sw5oB.jpg'),
(73449, 5049, 'Largados e Pelados S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9VMq8pIuDeFe8mTHYwdARpHszRd.jpg'),
(73450, 5049, 'Largados e Pelados S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8aOwNhYjoAOwDISNHPUQ53IQvcw.jpg'),
(73451, 5049, 'Largados e Pelados S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oT95ISPAuKtRS7q68jiQ6uGGNM4.jpg'),
(73452, 5049, 'Largados e Pelados S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fS2xWyc7dtGWVc3fD0cM1oHnaAH.jpg'),
(73453, 5049, 'Largados e Pelados S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8WaVApbVAAXTqxz3UFp1borzuO5.jpg'),
(73454, 5049, 'Largados e Pelados S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2boSATNSuCcsrTmfofNLaidduWx.jpg'),
(73455, 5049, 'Largados e Pelados S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73456, 5049, 'Largados e Pelados S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73457, 5049, 'Largados e Pelados S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73458, 5049, 'Largados e Pelados S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73459, 5049, 'Largados e Pelados S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73460, 5049, 'Largados e Pelados S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73461, 5049, 'Largados e Pelados S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/244583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73462, 5049, 'Largados e Pelados S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/244584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73463, 5050, 'Largados e Pelados S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73464, 5050, 'Largados e Pelados S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73465, 5050, 'Largados e Pelados S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73466, 5050, 'Largados e Pelados S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73467, 5050, 'Largados e Pelados S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73468, 5050, 'Largados e Pelados S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73469, 5050, 'Largados e Pelados S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73470, 5050, 'Largados e Pelados S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73471, 5050, 'Largados e Pelados S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73472, 5050, 'Largados e Pelados S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73473, 5050, 'Largados e Pelados S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73474, 5050, 'Largados e Pelados S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73475, 5050, 'Largados e Pelados S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73476, 5050, 'Largados e Pelados S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/244598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73477, 5050, 'Largados e Pelados S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/244599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73478, 5050, 'Largados e Pelados S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/244600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73479, 5050, 'Largados e Pelados S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/244601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73480, 5050, 'Largados e Pelados S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/244602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73481, 5050, 'Largados e Pelados S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/244603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73482, 5050, 'Largados e Pelados S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/626641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73483, 5051, 'Largados e Pelados S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73484, 5051, 'Largados e Pelados S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73485, 5051, 'Largados e Pelados S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73486, 5051, 'Largados e Pelados S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73487, 5051, 'Largados e Pelados S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73488, 5051, 'Largados e Pelados S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73489, 5051, 'Largados e Pelados S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73490, 5051, 'Largados e Pelados S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73491, 5051, 'Largados e Pelados S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73492, 5051, 'Largados e Pelados S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73493, 5051, 'Largados e Pelados S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73494, 5051, 'Largados e Pelados S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73495, 5051, 'Largados e Pelados S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73496, 5051, 'Largados e Pelados S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/244618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73497, 5051, 'Largados e Pelados S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/244619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73498, 5051, 'Largados e Pelados S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/244620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73499, 5051, 'Largados e Pelados S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/244621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73500, 5051, 'Largados e Pelados S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/244622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73501, 5051, 'Largados e Pelados S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/244623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73502, 5051, 'Largados e Pelados S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/244624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73503, 5051, 'Largados e Pelados S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/244625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73504, 5051, 'Largados e Pelados S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/244626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73505, 5051, 'Largados e Pelados S11 E23', 'http://sinalprivado.info:80/series/1533784/1533784/244627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73506, 5051, 'Largados e Pelados S11 E24', 'http://sinalprivado.info:80/series/1533784/1533784/244628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73507, 5051, 'Largados e Pelados S11 E25', 'http://sinalprivado.info:80/series/1533784/1533784/244629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73508, 5052, 'Largados e Pelados S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73509, 5052, 'Largados e Pelados S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73510, 5052, 'Largados e Pelados S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73511, 5052, 'Largados e Pelados S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73512, 5052, 'Largados e Pelados S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73513, 5052, 'Largados e Pelados S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73514, 5052, 'Largados e Pelados S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73515, 5052, 'Largados e Pelados S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73516, 5052, 'Largados e Pelados S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73517, 5052, 'Largados e Pelados S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73518, 5052, 'Largados e Pelados S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73519, 5053, 'Largados e Pelados S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73520, 5053, 'Largados e Pelados S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73521, 5053, 'Largados e Pelados S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73522, 5053, 'Largados e Pelados S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73523, 5053, 'Largados e Pelados S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73524, 5053, 'Largados e Pelados S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73525, 5054, 'Largados e Pelados S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73526, 5054, 'Largados e Pelados S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73527, 5054, 'Largados e Pelados S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73528, 5054, 'Largados e Pelados S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73529, 5054, 'Largados e Pelados S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73530, 5054, 'Largados e Pelados S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73531, 5054, 'Largados e Pelados S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73532, 5054, 'Largados e Pelados S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(73533, 5054, 'Largados e Pelados S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73534, 5054, 'Largados e Pelados S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73535, 5054, 'Largados e Pelados S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73536, 5054, 'Largados e Pelados S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73537, 5054, 'Largados e Pelados S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73538, 5055, 'Largados e Pelados S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73539, 5055, 'Largados e Pelados S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73540, 5055, 'Largados e Pelados S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73541, 5055, 'Largados e Pelados S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/421552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sHdDkl8MbXnEJDUwF0ccPvJYqps.jpg'),
(73542, 5055, 'Largados e Pelados S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/421553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oFTKnBlN4EKLXET4NKwpZ0wKdT7.jpg'),
(73543, 5055, 'Largados e Pelados S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/626702.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p6S6WE0NEG7wrJgYA59P7ijQ5Ss.jpg'),
(73544, 5055, 'Largados e Pelados S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/270514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/in1ic1kK3tcaceGw9FSWJPMDmLX.jpg'),
(73545, 5055, 'Largados e Pelados S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/626704.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/13fjxgiJpQ3m7EICm2c9HWw8aml.jpg'),
(73546, 5055, 'Largados e Pelados S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/626705.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xnPjuRZklE1OWAipeGSlQuJg2lC.jpg'),
(73547, 5056, 'Largados e Pelados S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73548, 5057, 'Largados e Pelados S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/421559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73549, 5057, 'Largados e Pelados S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/427583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73550, 5057, 'Largados e Pelados S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/432273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73551, 5057, 'Largados e Pelados S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/434694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73552, 5057, 'Largados e Pelados S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/436525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73553, 5057, 'Largados e Pelados S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/447796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73554, 5057, 'Largados e Pelados S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/483155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73555, 5057, 'Largados e Pelados S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/483156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73556, 5057, 'Largados e Pelados S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/488927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73557, 5057, 'Largados e Pelados S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/503257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73558, 5057, 'Largados e Pelados S17 E11', 'http://sinalprivado.info:80/series/1533784/1533784/503258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73559, 5057, 'Largados e Pelados S17 E12', 'http://sinalprivado.info:80/series/1533784/1533784/503259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73560, 5058, 'Largados e Pelados S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/833255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73561, 5058, 'Largados e Pelados S18 E02', 'http://sinalprivado.info:80/series/1533784/1533784/841975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73562, 5058, 'Largados e Pelados S18 E03', 'http://sinalprivado.info:80/series/1533784/1533784/848758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73563, 5058, 'Largados e Pelados S18 E04', 'http://sinalprivado.info:80/series/1533784/1533784/859680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73564, 5058, 'Largados e Pelados S18 E05', 'http://sinalprivado.info:80/series/1533784/1533784/862079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73565, 5058, 'Largados e Pelados S18 E06', 'http://sinalprivado.info:80/series/1533784/1533784/868235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6LSTSQ46Rxu0wmsNyqy0ge4qOaN.jpg'),
(73566, 5059, 'Os Fosters: Família Adotiva [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iM1xdmuxhadO9z7qXhDyWRxcjbi.jpg'),
(73567, 5059, 'Os Fosters: Família Adotiva [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Qg5LhKwwilQRyGftbrk0vgD0mv.jpg'),
(73568, 5059, 'Os Fosters: Família Adotiva [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nlF15Dbt0VD7jPmM48C28v4krQD.jpg'),
(73569, 5059, 'Os Fosters: Família Adotiva [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/75yW7WCWhsfQzMuG57pRLf72LFG.jpg'),
(73570, 5059, 'Os Fosters: Família Adotiva [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cvEw5MHCY4eZwzmxXxlgrfLPeEv.jpg'),
(73571, 5059, 'Os Fosters: Família Adotiva [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqACLIYlQ6bTdz1Aq5K9A2r0Z9j.jpg'),
(73572, 5059, 'Os Fosters: Família Adotiva [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hInA8XrR2DEyoSXUGAPptqqQlFb.jpg'),
(73573, 5059, 'Os Fosters: Família Adotiva [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8AVokyMatmAtXFTvwVYB7fGjUHC.jpg'),
(73574, 5059, 'Os Fosters: Família Adotiva [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lYK5crXk88JKKvB6F0pwVgzi4xs.jpg'),
(73575, 5059, 'Os Fosters: Família Adotiva [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3xr5Upa3VhtpWcX6n1zFzDyzh9O.jpg'),
(73576, 5059, 'Os Fosters: Família Adotiva [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nmTmnP5BoxTHbBwNxkgC3e1AUfj.jpg'),
(73577, 5059, 'Os Fosters: Família Adotiva [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jq1va8w61udouxw7mQrKESsHFMW.jpg'),
(73578, 5059, 'Os Fosters: Família Adotiva [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/170266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xaBEZ6jepKfHRX8Eh2b6AEI3EgK.jpg'),
(73579, 5059, 'Os Fosters: Família Adotiva [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/170267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qTsqVAEELoQcy3zK1e20a1RyN6g.jpg'),
(73580, 5059, 'Os Fosters: Família Adotiva [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/170268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cVGrAUWdAjDppA25nbojCJ8Nv8D.jpg'),
(73581, 5059, 'Os Fosters: Família Adotiva [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/170269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yN10jwHelVGfWHbF9qQxRbuFUDQ.jpg'),
(73582, 5059, 'Os Fosters: Família Adotiva [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/170270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mcTh4ElO3z9uzHqDO98qrDY6s6b.jpg'),
(73583, 5059, 'Os Fosters: Família Adotiva [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/170271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1bq9ESc38RmZHbwGcZXLy0uebNK.jpg'),
(73584, 5059, 'Os Fosters: Família Adotiva [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/170272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7T4ZHfKHbXR16wMfFq0wpdQifCO.jpg'),
(73585, 5059, 'Os Fosters: Família Adotiva [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/170273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/elsKY81fsdeuAASNiH7ZBhMwu3m.jpg'),
(73586, 5059, 'Os Fosters: Família Adotiva [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/170274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jnbhv2gJVbEjB1OOR1rSjmUP1br.jpg'),
(73587, 5060, 'Os Fosters: Família Adotiva [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/miEHtwYyVYARtxn0NkPrMr3aw0n.jpg'),
(73588, 5060, 'Os Fosters: Família Adotiva [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eXO8IqiSu4GakC3SAFhyKycYk70.jpg'),
(73589, 5060, 'Os Fosters: Família Adotiva [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfQEP37qB08CRYMP0KMpM6Mm5AK.jpg'),
(73590, 5060, 'Os Fosters: Família Adotiva [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5QatRNDUR9qBdEU4MrB8egwYPIK.jpg'),
(73591, 5060, 'Os Fosters: Família Adotiva [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDo52jClbfBByJbmb3c6Y5cjqIE.jpg'),
(73592, 5060, 'Os Fosters: Família Adotiva [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gRLzv3rMNtP42ljC5LpWOTcAGZ0.jpg'),
(73593, 5060, 'Os Fosters: Família Adotiva [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eh8NTCIBdRVGCSMUBkc08FbIKe5.jpg'),
(73594, 5060, 'Os Fosters: Família Adotiva [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eVwJidQQxm2Pd2BB45lKguMTUhe.jpg'),
(73595, 5060, 'Os Fosters: Família Adotiva [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mj8dCEYZE7QnbQsKqi5LNoBMovW.jpg'),
(73596, 5060, 'Os Fosters: Família Adotiva [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/esnavZYynVhPMqLgyyGXEGZsALM.jpg'),
(73597, 5060, 'Os Fosters: Família Adotiva [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wwk1t0QXKHIePsbyUQqCZIcJiek.jpg'),
(73598, 5060, 'Os Fosters: Família Adotiva [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aL0G0projoEdIwKCkoWSzdh10B0.jpg'),
(73599, 5060, 'Os Fosters: Família Adotiva [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/170287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AnPVzrZmgaKXd91tFMuOCm36efS.jpg'),
(73600, 5060, 'Os Fosters: Família Adotiva [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/170288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wafrJ0BHFCeiKQZ5hJfre4pnyWW.jpg'),
(73601, 5060, 'Os Fosters: Família Adotiva [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/170289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a5yImuQPT4LOdNM1JMQrmbPyOev.jpg'),
(73602, 5060, 'Os Fosters: Família Adotiva [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/170290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Q7PgxZUqLfzGq0NgC2b37jkfGt.jpg'),
(73603, 5060, 'Os Fosters: Família Adotiva [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/170291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p621KQSIl9KOLsg3FxjnfbFf3wE.jpg'),
(73604, 5060, 'Os Fosters: Família Adotiva [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/170292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOffe9kCss3gNlNKPcqqQkq4IZi.jpg'),
(73605, 5060, 'Os Fosters: Família Adotiva [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/170293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lLz1LOQj4elaxILP120nZVNBc6M.jpg'),
(73606, 5060, 'Os Fosters: Família Adotiva [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/170294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eZkeuwZzxHh9HovP2pspvORt42l.jpg'),
(73607, 5060, 'Os Fosters: Família Adotiva [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/170295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eh95g9XB18T69Q7kYV8HggsXZIE.jpg'),
(73608, 5061, 'Os Fosters: Família Adotiva [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1OQJVHEVPBGY4F0L7B6ErBwu4.jpg'),
(73609, 5061, 'Os Fosters: Família Adotiva [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qRNXlv0e4jTwlzj17OYGffHrQ4X.jpg'),
(73610, 5061, 'Os Fosters: Família Adotiva [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3eRHu4TYs2wllxw8cVcCu9MYZat.jpg'),
(73611, 5061, 'Os Fosters: Família Adotiva [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1omuC3PzsfEt51d1vHDGtTiWOgH.jpg'),
(73612, 5061, 'Os Fosters: Família Adotiva [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1GS9VbSKhQenGUZ5WBYzlkcVF0m.jpg'),
(73613, 5061, 'Os Fosters: Família Adotiva [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5eS9wzZKWoKUOiTsjD6SkapGZKW.jpg'),
(73614, 5061, 'Os Fosters: Família Adotiva [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zmHJA38YjCdOJK5yVYZJfinAH1S.jpg'),
(73615, 5061, 'Os Fosters: Família Adotiva [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zkW0e63pYR2DcjNfZl8kZUdTX4G.jpg'),
(73616, 5061, 'Os Fosters: Família Adotiva [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/viUzm5j79J1oE2pwBadj1PnufF0.jpg'),
(73617, 5061, 'Os Fosters: Família Adotiva [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z0pfvVyG9j4iTqpUOP9wDYWmubF.jpg'),
(73618, 5061, 'Os Fosters: Família Adotiva [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uTDlzWUya6AneU00xZQYLxrtRl1.jpg'),
(73619, 5061, 'Os Fosters: Família Adotiva [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t6Oz4clv5l4o3wYwqp8cit1aue7.jpg'),
(73620, 5061, 'Os Fosters: Família Adotiva [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/170308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uEV8IL4dGQaE4Z0e1Xl7N6QAQ1s.jpg'),
(73621, 5061, 'Os Fosters: Família Adotiva [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/170309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2E3qQCSCH0IDSvVoU0ZF70SbtaY.jpg'),
(73622, 5061, 'Os Fosters: Família Adotiva [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/170310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6UQECiUbVXknqO3g6EZ5LR8fBjD.jpg'),
(73623, 5061, 'Os Fosters: Família Adotiva [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/170311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nGcKCJNNAhudByVYpCcv208CW9H.jpg'),
(73624, 5061, 'Os Fosters: Família Adotiva [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/170312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3e46zoMNOPWs119zU1QrYqqNk.jpg'),
(73625, 5061, 'Os Fosters: Família Adotiva [L] S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/170313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qgLt4wCkxg8VuJXszyl9cmiP0Fq.jpg'),
(73626, 5061, 'Os Fosters: Família Adotiva [L] S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/170314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x6g0mq0Ru6WfuKwhtNZd5YnMECL.jpg'),
(73627, 5061, 'Os Fosters: Família Adotiva [L] S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/170315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mLI9FqPPjOkyIZ6DkR9kRwBiUr8.jpg'),
(73628, 5062, 'Os Fosters: Família Adotiva [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xpFfQDDFfmLZuKEDaTxqddJd293.jpg'),
(73629, 5062, 'Os Fosters: Família Adotiva [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lYvJkAPnWHeQ7yB0JtNApGCAcBf.jpg'),
(73630, 5062, 'Os Fosters: Família Adotiva [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/35NSmiWE2sPl2TMFYdzRrdbRF1m.jpg'),
(73631, 5062, 'Os Fosters: Família Adotiva [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dN391FeElRO9u64lh5mhk2NhkbM.jpg'),
(73632, 5062, 'Os Fosters: Família Adotiva [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mmoYEADHZ5RUEPsOB673H0Bw3Zz.jpg'),
(73633, 5062, 'Os Fosters: Família Adotiva [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dx2ScL1ANBdsqutTmSW3rFsooE.jpg'),
(73634, 5062, 'Os Fosters: Família Adotiva [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1zMeFeQzJXVEiqsTarRlO4jf6iz.jpg'),
(73635, 5062, 'Os Fosters: Família Adotiva [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AeOTDqdFabDcnmmICq0nOOJzjNh.jpg'),
(73636, 5062, 'Os Fosters: Família Adotiva [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/28634pgCMtVpFClXOtqFAGVjkTA.jpg'),
(73637, 5062, 'Os Fosters: Família Adotiva [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hflPmXs22D6kNx4NcFVLUGK3gYo.jpg'),
(73638, 5062, 'Os Fosters: Família Adotiva [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s4VoadoEA7OkEu7rIOZ1AfG2USB.jpg'),
(73639, 5062, 'Os Fosters: Família Adotiva [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mIDasui8y5wV6EpdWaExvzWtSiN.jpg'),
(73640, 5062, 'Os Fosters: Família Adotiva [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/170328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2sq2X2uDvUktlskh0bQbof6vBUx.jpg'),
(73641, 5062, 'Os Fosters: Família Adotiva [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/170329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1JYYkqFCrBGE33vaAyepiIVtf6e.jpg'),
(73642, 5062, 'Os Fosters: Família Adotiva [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/170330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3w9ZoLLJ8toDo5995JYjIbpm1f0.jpg'),
(73643, 5062, 'Os Fosters: Família Adotiva [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/170331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vqfhv9EvyjmmuFp616Kn7NTa0ym.jpg'),
(73644, 5062, 'Os Fosters: Família Adotiva [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/170332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wLC35RDOVx09oOAJAGWx1dLULc8.jpg'),
(73645, 5062, 'Os Fosters: Família Adotiva [L] S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/170333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tee8nUlJvb7L0CN7UIhMTS37GU4.jpg'),
(73646, 5062, 'Os Fosters: Família Adotiva [L] S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/170334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vDGIvYMBtZiC095h4adqbPgrpgW.jpg'),
(73647, 5062, 'Os Fosters: Família Adotiva [L] S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/170335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nH5inON4s2T6W3SxfdQJieBfBEN.jpg'),
(73648, 5063, 'Os Fosters: Família Adotiva [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qTyR3wJ6uwI508WY1U5izk80DgX.jpg'),
(73649, 5063, 'Os Fosters: Família Adotiva [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QRHxVF8iB9hbOWbkjdaPAzMB08.jpg'),
(73650, 5063, 'Os Fosters: Família Adotiva [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/coiEcqK7wJDT1GKyiQbMBVyzMvM.jpg'),
(73651, 5063, 'Os Fosters: Família Adotiva [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/smpMKGUswo5eaYq1o5PwW47a9d5.jpg'),
(73652, 5063, 'Os Fosters: Família Adotiva [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dpWCoBoQ0kk3uI2XzvoxgpNnouU.jpg'),
(73653, 5063, 'Os Fosters: Família Adotiva [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kIilN6i1CDmhzPyEhMbOQFEFKdF.jpg'),
(73654, 5063, 'Os Fosters: Família Adotiva [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mqOWPgmxpIKxvtXXecdUjt5CGdg.jpg'),
(73655, 5063, 'Os Fosters: Família Adotiva [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Qbm50BJ481kK01TWnnAPpHEwkM.jpg'),
(73656, 5063, 'Os Fosters: Família Adotiva [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iQtGHQVsogoBxwh3q4FI4P6ibDM.jpg'),
(73657, 5063, 'Os Fosters: Família Adotiva [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fSJ8SxWwubndKNq9qwRybz0wWPn.jpg'),
(73658, 5063, 'Os Fosters: Família Adotiva [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5XOxEtMdR7dYrX79111pEp79Na1.jpg'),
(73659, 5063, 'Os Fosters: Família Adotiva [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3TGHhYkTwvDzg4XBl4n700pl8oR.jpg'),
(73660, 5063, 'Os Fosters: Família Adotiva [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/170348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qEMtbJtrXECIukLy9v5A5GqG4JO.jpg'),
(73661, 5063, 'Os Fosters: Família Adotiva [L] S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/170349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cPud4glxLLFwB2ivwJqlXBWHR9X.jpg'),
(73662, 5063, 'Os Fosters: Família Adotiva [L] S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/170350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1fQ3VfPfXQ0m0ZkLREelxYn6b9U.jpg'),
(73663, 5063, 'Os Fosters: Família Adotiva [L] S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/170351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zi5Er2aMIDABL6a5vFXPrnYE9N.jpg'),
(73664, 5063, 'Os Fosters: Família Adotiva [L] S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/170352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ugY3AmDhLMYHl4HwCZ362fRNwpX.jpg'),
(73665, 5063, 'Os Fosters: Família Adotiva [L] S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/170353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ra5Ueeq5p4wKs1I2DWvSVaQ8xDg.jpg'),
(73666, 5063, 'Os Fosters: Família Adotiva [L] S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/170354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/quYXrmDZ5TseGzJjwwhWQ9feJkr.jpg'),
(73667, 5063, 'Os Fosters: Família Adotiva [L] S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/170355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uzhhcwTtacpS0VvGWtiyMx3u1pW.jpg'),
(73668, 5063, 'Os Fosters: Família Adotiva [L] S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/170356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ru2wbZ8WYaY6PmxJZ2ylAJ7LZDm.jpg'),
(73669, 5063, 'Os Fosters: Família Adotiva [L] S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/170357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7wqKWLKaxcUTnptHs9DkccO48jg.jpg'),
(73670, 5064, 'Senhor dos Céus S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ieGeFeQaUHzwwBipJiVX0oPU2Lb.jpg'),
(73671, 5064, 'Senhor dos Céus S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nFTkQPJrbpQThlBrJNq6msq6edX.jpg'),
(73672, 5064, 'Senhor dos Céus S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xDsfRboxBawscQk62IexZWoIcJI.jpg'),
(73673, 5064, 'Senhor dos Céus S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oLrQKmfQvqxq1IyNDZbpJUkWeEO.jpg'),
(73674, 5064, 'Senhor dos Céus S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a3My8sqvtxj2loUhhhgBUc6VzGU.jpg'),
(73675, 5064, 'Senhor dos Céus S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j7k4EuAPgUZTGavOGx7ovBGVl8Q.jpg'),
(73676, 5064, 'Senhor dos Céus S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkzHx0Z6eNJtrer59CbN44Ch5tQ.jpg'),
(73677, 5064, 'Senhor dos Céus S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4vOPqimpZDcotR84Iv85mft8gMR.jpg'),
(73678, 5064, 'Senhor dos Céus S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3DTYDBBlPfnwqudkRH6L5rA84q.jpg'),
(73679, 5064, 'Senhor dos Céus S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63mzfTorGIU5avbPSWnCgByzqT6.jpg'),
(73680, 5064, 'Senhor dos Céus S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/169926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2mcCaGX73aBlX7KCyQz5mHgjzhF.jpg'),
(73681, 5064, 'Senhor dos Céus S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/169927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lmKkTGCHMSgLRwt5gGdMg56i1Ld.jpg'),
(73682, 5064, 'Senhor dos Céus S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/169928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aqzP6BGmRJcmJM5XnrsWfVeT4uR.jpg'),
(73683, 5064, 'Senhor dos Céus S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/169929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8n0CrJM2x48oht4kn0bGpg9WKB1.jpg'),
(73684, 5064, 'Senhor dos Céus S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/169930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lANVyF4cIjGNYTApeUCOqgboBmw.jpg'),
(73685, 5064, 'Senhor dos Céus S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/169931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glr3rtRqfPqYS8GgcT9R87fgSCo.jpg'),
(73686, 5064, 'Senhor dos Céus S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/169932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2acIVd5gHYPfKXf99xdIDqvf0Z.jpg'),
(73687, 5064, 'Senhor dos Céus S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/169933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h6sMAQDWAmUEK9VqlsWDpifg0qT.jpg'),
(73688, 5064, 'Senhor dos Céus S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/169934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iQAj6a1zK6Qe0EnubpKmN6VkYOl.jpg'),
(73689, 5064, 'Senhor dos Céus S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/169935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y4qwuzGhDTjUUSfDUqTZxbizhdM.jpg'),
(73690, 5064, 'Senhor dos Céus S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/169936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/StSWUb6aZiJJCBGWxIYlZinyVb.jpg'),
(73691, 5064, 'Senhor dos Céus S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/169937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/agLQwFi4Oa85naGXBcfo5SsjBtQ.jpg'),
(73692, 5064, 'Senhor dos Céus S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/169938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6b4xJEG0Rq1jMyJFiDwRB8qCUzd.jpg'),
(73693, 5064, 'Senhor dos Céus S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/169939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sgmCIdL2TTW4XJ4bmrFJWbMZPN3.jpg'),
(73694, 5064, 'Senhor dos Céus S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/169940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73695, 5064, 'Senhor dos Céus S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/169941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73696, 5064, 'Senhor dos Céus S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/169942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73697, 5064, 'Senhor dos Céus S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/169943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73698, 5064, 'Senhor dos Céus S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/169944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73699, 5064, 'Senhor dos Céus S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/169945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73700, 5064, 'Senhor dos Céus S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/169946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73701, 5064, 'Senhor dos Céus S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/169947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73702, 5064, 'Senhor dos Céus S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/169948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73703, 5064, 'Senhor dos Céus S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/169949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73704, 5064, 'Senhor dos Céus S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/169950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73705, 5064, 'Senhor dos Céus S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/169951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73706, 5064, 'Senhor dos Céus S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/169952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73707, 5064, 'Senhor dos Céus S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/169953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73708, 5064, 'Senhor dos Céus S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/169954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73709, 5064, 'Senhor dos Céus S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/169955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73710, 5064, 'Senhor dos Céus S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/169956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73711, 5064, 'Senhor dos Céus S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/169957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73712, 5064, 'Senhor dos Céus S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/169958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73713, 5064, 'Senhor dos Céus S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/169959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73714, 5064, 'Senhor dos Céus S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/169960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73715, 5064, 'Senhor dos Céus S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/169961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73716, 5064, 'Senhor dos Céus S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/169962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73717, 5064, 'Senhor dos Céus S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/169963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73718, 5064, 'Senhor dos Céus S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/169964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73719, 5064, 'Senhor dos Céus S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/169965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73720, 5064, 'Senhor dos Céus S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/169966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73721, 5064, 'Senhor dos Céus S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/169967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73722, 5064, 'Senhor dos Céus S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/169968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73723, 5064, 'Senhor dos Céus S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/169969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73724, 5064, 'Senhor dos Céus S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/169970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73725, 5064, 'Senhor dos Céus S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/169971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73726, 5064, 'Senhor dos Céus S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/169972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73727, 5064, 'Senhor dos Céus S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/169973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73728, 5064, 'Senhor dos Céus S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/169974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73729, 5064, 'Senhor dos Céus S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/169975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73730, 5064, 'Senhor dos Céus S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/169976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73731, 5064, 'Senhor dos Céus S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/169977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73732, 5064, 'Senhor dos Céus S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/169978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73733, 5064, 'Senhor dos Céus S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/169979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73734, 5064, 'Senhor dos Céus S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/169980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73735, 5064, 'Senhor dos Céus S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/169981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73736, 5064, 'Senhor dos Céus S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/169982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73737, 5064, 'Senhor dos Céus S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/169983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73738, 5064, 'Senhor dos Céus S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/169984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73739, 5064, 'Senhor dos Céus S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/169985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73740, 5064, 'Senhor dos Céus S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/169986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73741, 5064, 'Senhor dos Céus S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/169987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73742, 5064, 'Senhor dos Céus S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/169988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73743, 5064, 'Senhor dos Céus S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/169989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73744, 5065, 'Senhor dos Céus S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dIUuXvT6DYhBXy5nMV5hSi9ZRUn.jpg'),
(73745, 5065, 'Senhor dos Céus S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dIUuXvT6DYhBXy5nMV5hSi9ZRUn.jpg'),
(73746, 5065, 'Senhor dos Céus S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dIUuXvT6DYhBXy5nMV5hSi9ZRUn.jpg'),
(73747, 5065, 'Senhor dos Céus S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dIUuXvT6DYhBXy5nMV5hSi9ZRUn.jpg'),
(73748, 5065, 'Senhor dos Céus S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dIUuXvT6DYhBXy5nMV5hSi9ZRUn.jpg'),
(73749, 5065, 'Senhor dos Céus S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73750, 5065, 'Senhor dos Céus S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73751, 5065, 'Senhor dos Céus S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73752, 5065, 'Senhor dos Céus S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73753, 5065, 'Senhor dos Céus S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73754, 5065, 'Senhor dos Céus S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73755, 5065, 'Senhor dos Céus S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73756, 5065, 'Senhor dos Céus S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/170002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73757, 5065, 'Senhor dos Céus S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/170003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73758, 5065, 'Senhor dos Céus S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/170004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73759, 5065, 'Senhor dos Céus S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/170005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73760, 5065, 'Senhor dos Céus S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/170006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73761, 5065, 'Senhor dos Céus S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/170007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73762, 5065, 'Senhor dos Céus S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/170008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73763, 5065, 'Senhor dos Céus S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/170009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73764, 5065, 'Senhor dos Céus S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/170010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73765, 5065, 'Senhor dos Céus S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/170011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73766, 5065, 'Senhor dos Céus S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/170012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73767, 5065, 'Senhor dos Céus S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/170013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73768, 5065, 'Senhor dos Céus S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/170014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73769, 5065, 'Senhor dos Céus S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/170015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73770, 5065, 'Senhor dos Céus S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/170016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73771, 5065, 'Senhor dos Céus S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/170017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73772, 5065, 'Senhor dos Céus S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/170018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73773, 5065, 'Senhor dos Céus S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/170019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73774, 5065, 'Senhor dos Céus S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/170020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73775, 5065, 'Senhor dos Céus S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/170021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73776, 5065, 'Senhor dos Céus S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/170022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73777, 5065, 'Senhor dos Céus S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/170023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73778, 5065, 'Senhor dos Céus S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/170024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73779, 5065, 'Senhor dos Céus S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/170025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73780, 5065, 'Senhor dos Céus S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/170026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73781, 5065, 'Senhor dos Céus S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/170027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73782, 5065, 'Senhor dos Céus S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/170028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73783, 5065, 'Senhor dos Céus S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/170029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73784, 5065, 'Senhor dos Céus S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/170030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73785, 5065, 'Senhor dos Céus S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/170031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73786, 5065, 'Senhor dos Céus S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/170032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73787, 5065, 'Senhor dos Céus S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/170033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73788, 5065, 'Senhor dos Céus S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/170034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(73789, 5065, 'Senhor dos Céus S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/170035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73790, 5065, 'Senhor dos Céus S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/170036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73791, 5065, 'Senhor dos Céus S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/170037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73792, 5065, 'Senhor dos Céus S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/170038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73793, 5065, 'Senhor dos Céus S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/170039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73794, 5065, 'Senhor dos Céus S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/170040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73795, 5065, 'Senhor dos Céus S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/170041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73796, 5065, 'Senhor dos Céus S02 E53', 'http://sinalprivado.info:80/series/1533784/1533784/170042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73797, 5065, 'Senhor dos Céus S02 E54', 'http://sinalprivado.info:80/series/1533784/1533784/170043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73798, 5065, 'Senhor dos Céus S02 E55', 'http://sinalprivado.info:80/series/1533784/1533784/170044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73799, 5065, 'Senhor dos Céus S02 E56', 'http://sinalprivado.info:80/series/1533784/1533784/170045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73800, 5065, 'Senhor dos Céus S02 E57', 'http://sinalprivado.info:80/series/1533784/1533784/170046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73801, 5065, 'Senhor dos Céus S02 E58', 'http://sinalprivado.info:80/series/1533784/1533784/170047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73802, 5065, 'Senhor dos Céus S02 E59', 'http://sinalprivado.info:80/series/1533784/1533784/170048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73803, 5065, 'Senhor dos Céus S02 E60', 'http://sinalprivado.info:80/series/1533784/1533784/170049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73804, 5065, 'Senhor dos Céus S02 E61', 'http://sinalprivado.info:80/series/1533784/1533784/170050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73805, 5065, 'Senhor dos Céus S02 E62', 'http://sinalprivado.info:80/series/1533784/1533784/170051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73806, 5065, 'Senhor dos Céus S02 E63', 'http://sinalprivado.info:80/series/1533784/1533784/170052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73807, 5065, 'Senhor dos Céus S02 E64', 'http://sinalprivado.info:80/series/1533784/1533784/170053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73808, 5065, 'Senhor dos Céus S02 E65', 'http://sinalprivado.info:80/series/1533784/1533784/170054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73809, 5065, 'Senhor dos Céus S02 E66', 'http://sinalprivado.info:80/series/1533784/1533784/170055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73810, 5065, 'Senhor dos Céus S02 E67', 'http://sinalprivado.info:80/series/1533784/1533784/170056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73811, 5065, 'Senhor dos Céus S02 E68', 'http://sinalprivado.info:80/series/1533784/1533784/170057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73812, 5065, 'Senhor dos Céus S02 E69', 'http://sinalprivado.info:80/series/1533784/1533784/170058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73813, 5065, 'Senhor dos Céus S02 E70', 'http://sinalprivado.info:80/series/1533784/1533784/170059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73814, 5065, 'Senhor dos Céus S02 E71', 'http://sinalprivado.info:80/series/1533784/1533784/170060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73815, 5065, 'Senhor dos Céus S02 E72', 'http://sinalprivado.info:80/series/1533784/1533784/170061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73816, 5065, 'Senhor dos Céus S02 E73', 'http://sinalprivado.info:80/series/1533784/1533784/170062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73817, 5065, 'Senhor dos Céus S02 E74', 'http://sinalprivado.info:80/series/1533784/1533784/170063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73818, 5065, 'Senhor dos Céus S02 E75', 'http://sinalprivado.info:80/series/1533784/1533784/170064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73819, 5065, 'Senhor dos Céus S02 E76', 'http://sinalprivado.info:80/series/1533784/1533784/170065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73820, 5065, 'Senhor dos Céus S02 E77', 'http://sinalprivado.info:80/series/1533784/1533784/170066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73821, 5065, 'Senhor dos Céus S02 E78', 'http://sinalprivado.info:80/series/1533784/1533784/170067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73822, 5065, 'Senhor dos Céus S02 E79', 'http://sinalprivado.info:80/series/1533784/1533784/170068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73823, 5065, 'Senhor dos Céus S02 E80', 'http://sinalprivado.info:80/series/1533784/1533784/170069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(73824, 5066, 'Senhor dos Céus S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4UXAdRn4FqBHLlFf5m0Gts767l.jpg'),
(73825, 5066, 'Senhor dos Céus S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4UXAdRn4FqBHLlFf5m0Gts767l.jpg'),
(73826, 5066, 'Senhor dos Céus S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4UXAdRn4FqBHLlFf5m0Gts767l.jpg'),
(73827, 5066, 'Senhor dos Céus S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4UXAdRn4FqBHLlFf5m0Gts767l.jpg'),
(73828, 5066, 'Senhor dos Céus S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4UXAdRn4FqBHLlFf5m0Gts767l.jpg'),
(73829, 5066, 'Senhor dos Céus S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4UXAdRn4FqBHLlFf5m0Gts767l.jpg'),
(73830, 5066, 'Senhor dos Céus S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bPOxQecMPRGvfFUCNkTzfEClKEb.jpg'),
(73831, 5066, 'Senhor dos Céus S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cTebIKiKMZTMz9NVmUyYIzUOCtJ.jpg'),
(73832, 5066, 'Senhor dos Céus S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lNbVbkNDuMktwBr7IzDfmRlm5Dn.jpg'),
(73833, 5066, 'Senhor dos Céus S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zV4HFXxrRrFsflPEXVWXSihakG.jpg'),
(73834, 5066, 'Senhor dos Céus S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7YmBwqreUqAj9jHqi7iKqRxkCSu.jpg'),
(73835, 5066, 'Senhor dos Céus S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pxfURkWIvuBLtQuUprIAnmZ3FMy.jpg'),
(73836, 5066, 'Senhor dos Céus S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/170082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/15Bwdun2oGmS25gv8XwZzvZxtfd.jpg'),
(73837, 5066, 'Senhor dos Céus S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/170083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/agKwP5itW0rLLwIdoPsqpXJBGYX.jpg'),
(73838, 5066, 'Senhor dos Céus S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/170084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9NUkwn5gRXFwFcPD7ozJO678GWB.jpg'),
(73839, 5066, 'Senhor dos Céus S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/170085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nlnIVO6QsXQSLzpOFaWxFo5dbFP.jpg'),
(73840, 5066, 'Senhor dos Céus S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/170086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1choqEWBBdi06N9nRATiTATGb14.jpg'),
(73841, 5066, 'Senhor dos Céus S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/170087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMkHfEV2S1yb5yp4shKcbD3XMI6.jpg'),
(73842, 5066, 'Senhor dos Céus S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/170088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dobim8QGHyArXO4nWyYGqY1uElk.jpg'),
(73843, 5066, 'Senhor dos Céus S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/170089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/38qddGApx6NJaG4wNa8ObZOA1vE.jpg'),
(73844, 5066, 'Senhor dos Céus S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/170090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A7x5ZDqBEaLUE9bmI3fUdqQn8wY.jpg'),
(73845, 5066, 'Senhor dos Céus S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/170091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vD492eSlEPlQcjlHcppk0WMHz59.jpg'),
(73846, 5066, 'Senhor dos Céus S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/170092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7h7U0JokJlUtbPbtNMzo2h1AHdk.jpg'),
(73847, 5066, 'Senhor dos Céus S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/170093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o51L7dSiJg7ePCMutbaR1L7cSei.jpg'),
(73848, 5066, 'Senhor dos Céus S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/170094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bszglf4RrOUp7Gdt5AUaOVF7heG.jpg'),
(73849, 5066, 'Senhor dos Céus S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/170095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iMNjsQgTwcn4zbbJPg8w035lFP5.jpg'),
(73850, 5066, 'Senhor dos Céus S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/170096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kMn1sY6Pyqw8y8UhORzLrjCBJxj.jpg'),
(73851, 5066, 'Senhor dos Céus S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/170097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qeVervXaHFGSppnTIIZ2XplkLS7.jpg'),
(73852, 5066, 'Senhor dos Céus S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/170098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4z28aOwX8Hyi32pzvBfYCAHKVZo.jpg'),
(73853, 5066, 'Senhor dos Céus S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/170099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mhAJ4Ni7YwBJpvmPnw1ztOlvMS2.jpg'),
(73854, 5066, 'Senhor dos Céus S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/170100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdFlSstvJEiSPi414OF35yDjGJ5.jpg'),
(73855, 5066, 'Senhor dos Céus S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/170101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eXh9oHUVxeN3FY1kNsJcrYIRWjw.jpg'),
(73856, 5066, 'Senhor dos Céus S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/170102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8j1xoVzEAbpjigQLx79L0Fw0FYP.jpg'),
(73857, 5066, 'Senhor dos Céus S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/170103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AvtNpxQGn4QGq7w5cl9SJBO9sBN.jpg'),
(73858, 5066, 'Senhor dos Céus S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/170104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4s6vOhjAZklLYZaXdrOefN8d6HE.jpg'),
(73859, 5066, 'Senhor dos Céus S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/170105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iICgcG4GDOYkj05yyzMt6gegtUO.jpg'),
(73860, 5066, 'Senhor dos Céus S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/170106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6sqXFiPYOEs4L08xFpVOFBgKxxf.jpg'),
(73861, 5066, 'Senhor dos Céus S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/170107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0noAI7b8w6E2RCRdoZIyNdJ1hz.jpg'),
(73862, 5066, 'Senhor dos Céus S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/170108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWZGOn3BuYBemLOHPiNBIGhgwEe.jpg'),
(73863, 5066, 'Senhor dos Céus S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/170109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSDtPz09h5IEiHhu3pPMXsU0ITw.jpg'),
(73864, 5066, 'Senhor dos Céus S03 E41', 'http://sinalprivado.info:80/series/1533784/1533784/170110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qFAO0ZkhQJc7AzcMlTXZTS5XTZj.jpg'),
(73865, 5066, 'Senhor dos Céus S03 E42', 'http://sinalprivado.info:80/series/1533784/1533784/170111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZgOwJlKdBm2qzAtmsraWag1JqN.jpg'),
(73866, 5066, 'Senhor dos Céus S03 E43', 'http://sinalprivado.info:80/series/1533784/1533784/170112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f3fGcA8abBGiwytvIwk5HUHah2Y.jpg'),
(73867, 5066, 'Senhor dos Céus S03 E44', 'http://sinalprivado.info:80/series/1533784/1533784/170113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n1rCqzPiNqxafV7ksGl7AOfV02i.jpg'),
(73868, 5066, 'Senhor dos Céus S03 E45', 'http://sinalprivado.info:80/series/1533784/1533784/170114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ntGu1RyLLTUFBJQ1k5yv44ZZwT0.jpg'),
(73869, 5066, 'Senhor dos Céus S03 E46', 'http://sinalprivado.info:80/series/1533784/1533784/170115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/acHwNkE4jNPf1nFhafkm1hiTWI2.jpg'),
(73870, 5066, 'Senhor dos Céus S03 E47', 'http://sinalprivado.info:80/series/1533784/1533784/170116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t1AoZKEHsV62W9Ww8ljy9sMkapq.jpg'),
(73871, 5066, 'Senhor dos Céus S03 E48', 'http://sinalprivado.info:80/series/1533784/1533784/170117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1yDydXm4auyjjwvEZjJv3cLnnEU.jpg'),
(73872, 5066, 'Senhor dos Céus S03 E49', 'http://sinalprivado.info:80/series/1533784/1533784/170118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5eDi8LsljssFDAbWRZFOZb1pMQN.jpg'),
(73873, 5066, 'Senhor dos Céus S03 E50', 'http://sinalprivado.info:80/series/1533784/1533784/170119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qCoeZp0BcznBWMM0qa3s1lQprnz.jpg'),
(73874, 5066, 'Senhor dos Céus S03 E51', 'http://sinalprivado.info:80/series/1533784/1533784/170120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j4jN6qPcvvlZpIgYC6834cTqfzS.jpg'),
(73875, 5066, 'Senhor dos Céus S03 E52', 'http://sinalprivado.info:80/series/1533784/1533784/170121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t1DB3SLh26P11uqj58gyuvszrvq.jpg'),
(73876, 5066, 'Senhor dos Céus S03 E53', 'http://sinalprivado.info:80/series/1533784/1533784/170122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shvQ5gnAlJoYZcdDzEi0FSAxO9I.jpg'),
(73877, 5066, 'Senhor dos Céus S03 E54', 'http://sinalprivado.info:80/series/1533784/1533784/170123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v1nAMsP9xy3pKOxW8jp85x2G0MZ.jpg'),
(73878, 5066, 'Senhor dos Céus S03 E55', 'http://sinalprivado.info:80/series/1533784/1533784/170124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nPdq1wjrmiioEnPWaClZOVhRco0.jpg'),
(73879, 5066, 'Senhor dos Céus S03 E56', 'http://sinalprivado.info:80/series/1533784/1533784/170125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fk5sREqdW9LoXzLfMsaXctZ0dAY.jpg'),
(73880, 5066, 'Senhor dos Céus S03 E57', 'http://sinalprivado.info:80/series/1533784/1533784/170126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pITid3uzQv1nN9taKNt7YbNPmoC.jpg'),
(73881, 5066, 'Senhor dos Céus S03 E58', 'http://sinalprivado.info:80/series/1533784/1533784/170127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ylvrSZjW0C8wlBkzKlEl6eDGRp.jpg'),
(73882, 5066, 'Senhor dos Céus S03 E59', 'http://sinalprivado.info:80/series/1533784/1533784/170128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mHAXxpPfHLpwSDH1K1cgyRECVXY.jpg'),
(73883, 5066, 'Senhor dos Céus S03 E60', 'http://sinalprivado.info:80/series/1533784/1533784/170129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1dBIAgVTFsR8BvghK5WOOX8I5UE.jpg'),
(73884, 5066, 'Senhor dos Céus S03 E61', 'http://sinalprivado.info:80/series/1533784/1533784/170130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z99slaD5NeuKdk71axV3lC9MN6R.jpg'),
(73885, 5066, 'Senhor dos Céus S03 E62', 'http://sinalprivado.info:80/series/1533784/1533784/170131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y9nSLWX6Sfg22lOIxTM0ePgiPUn.jpg'),
(73886, 5066, 'Senhor dos Céus S03 E63', 'http://sinalprivado.info:80/series/1533784/1533784/170132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6PSaq439YMbVy34uvmN22hWutst.jpg'),
(73887, 5066, 'Senhor dos Céus S03 E64', 'http://sinalprivado.info:80/series/1533784/1533784/170133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iablbAOtwCWmDpvXhzVnW6xGZyS.jpg'),
(73888, 5066, 'Senhor dos Céus S03 E65', 'http://sinalprivado.info:80/series/1533784/1533784/170134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2b57IvMJJw8tEmAXRptGkwXS7ZG.jpg'),
(73889, 5066, 'Senhor dos Céus S03 E66', 'http://sinalprivado.info:80/series/1533784/1533784/170135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a4Qi7WcOIoQuGiAVccLVBXDTOuN.jpg'),
(73890, 5066, 'Senhor dos Céus S03 E67', 'http://sinalprivado.info:80/series/1533784/1533784/170136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/coukXxPz6LD9KHK3c0YY6zYyiiI.jpg'),
(73891, 5066, 'Senhor dos Céus S03 E68', 'http://sinalprivado.info:80/series/1533784/1533784/170137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ukn8l4lGKdC7rjaA0WLhl3lFDz3.jpg'),
(73892, 5066, 'Senhor dos Céus S03 E69', 'http://sinalprivado.info:80/series/1533784/1533784/170138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Vq7HZjCG08Gu900etW2ZwjtadI.jpg'),
(73893, 5066, 'Senhor dos Céus S03 E70', 'http://sinalprivado.info:80/series/1533784/1533784/170139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9GiL2EppUvz5gdMd58RO0S8Njmw.jpg'),
(73894, 5066, 'Senhor dos Céus S03 E71', 'http://sinalprivado.info:80/series/1533784/1533784/170140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nhLRAfSnBsa57k4PEsXWKfA90U4.jpg'),
(73895, 5066, 'Senhor dos Céus S03 E72', 'http://sinalprivado.info:80/series/1533784/1533784/170141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mXnxTamguMZMBBUI1kWM9UBoao0.jpg'),
(73896, 5066, 'Senhor dos Céus S03 E73', 'http://sinalprivado.info:80/series/1533784/1533784/170142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fuUw45bSQscWeB2JMFm7JeLkRXB.jpg'),
(73897, 5066, 'Senhor dos Céus S03 E74', 'http://sinalprivado.info:80/series/1533784/1533784/170143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qAjNjOIsqvoSiahqAik9ObHXoe.jpg'),
(73898, 5066, 'Senhor dos Céus S03 E75', 'http://sinalprivado.info:80/series/1533784/1533784/170144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kLxvV36KauWoAXCxlWg2nEhn1aY.jpg'),
(73899, 5066, 'Senhor dos Céus S03 E76', 'http://sinalprivado.info:80/series/1533784/1533784/170145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/paJ4LWgjlzzVOxbF2o8w0YO8RJA.jpg'),
(73900, 5066, 'Senhor dos Céus S03 E77', 'http://sinalprivado.info:80/series/1533784/1533784/170146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eepC3FETactq14FOMhZJUT2k9Un.jpg'),
(73901, 5066, 'Senhor dos Céus S03 E78', 'http://sinalprivado.info:80/series/1533784/1533784/170147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nu2nMPKfTrX3IN7qHq980xIZhjw.jpg'),
(73902, 5066, 'Senhor dos Céus S03 E79', 'http://sinalprivado.info:80/series/1533784/1533784/170148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wjS3r6DAeZZh9hlk5fG8BQ0qJht.jpg'),
(73903, 5066, 'Senhor dos Céus S03 E80', 'http://sinalprivado.info:80/series/1533784/1533784/170149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3wV7uq3ygreoYtemWAGaND7nBN7.jpg'),
(73904, 5066, 'Senhor dos Céus S03 E81', 'http://sinalprivado.info:80/series/1533784/1533784/170150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xUYnKqDKpWHJ3hBd50FNlnkmKUR.jpg'),
(73905, 5066, 'Senhor dos Céus S03 E82', 'http://sinalprivado.info:80/series/1533784/1533784/170151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wJNAQCk1ComFhuLnDfrZ9rKxV49.jpg'),
(73906, 5066, 'Senhor dos Céus S03 E83', 'http://sinalprivado.info:80/series/1533784/1533784/170152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ny84ph0i2rqJXqytsL5zr09XCy.jpg'),
(73907, 5066, 'Senhor dos Céus S03 E84', 'http://sinalprivado.info:80/series/1533784/1533784/170153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1RWxCvrxBRUgkaq7oiNl0470Gss.jpg'),
(73908, 5066, 'Senhor dos Céus S03 E85', 'http://sinalprivado.info:80/series/1533784/1533784/170154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fcvcxUFR3cvemun1DeqDJRxLM4e.jpg'),
(73909, 5066, 'Senhor dos Céus S03 E86', 'http://sinalprivado.info:80/series/1533784/1533784/170155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1UNEXolAOhpZrkXWoAqlQrF3Jep.jpg'),
(73910, 5066, 'Senhor dos Céus S03 E87', 'http://sinalprivado.info:80/series/1533784/1533784/170156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g8U2udiskLw4WuumefCptjYl4s9.jpg'),
(73911, 5066, 'Senhor dos Céus S03 E88', 'http://sinalprivado.info:80/series/1533784/1533784/170157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jagl3blQIX3t9IfEdfBeNHc7VTc.jpg'),
(73912, 5066, 'Senhor dos Céus S03 E89', 'http://sinalprivado.info:80/series/1533784/1533784/170158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vTOxzt6kUG0jd14PNvTFDEGaG9U.jpg'),
(73913, 5066, 'Senhor dos Céus S03 E90', 'http://sinalprivado.info:80/series/1533784/1533784/170159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/385RQYvGKMRzh7FhAdhjeZfQKx6.jpg'),
(73914, 5066, 'Senhor dos Céus S03 E91', 'http://sinalprivado.info:80/series/1533784/1533784/170160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7mV9n9vcbUC5nOMcFZ8Ab9txSQf.jpg'),
(73915, 5066, 'Senhor dos Céus S03 E92', 'http://sinalprivado.info:80/series/1533784/1533784/170161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cJaRHYIbX4aW5trxWVjsvmThI6j.jpg'),
(73916, 5066, 'Senhor dos Céus S03 E93', 'http://sinalprivado.info:80/series/1533784/1533784/170162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6gCFzzYJciLeWKxjiSeh3iT4bCx.jpg'),
(73917, 5066, 'Senhor dos Céus S03 E94', 'http://sinalprivado.info:80/series/1533784/1533784/170163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p7LSa2S4ZORaQyXp9LUSIix5oxa.jpg'),
(73918, 5066, 'Senhor dos Céus S03 E95', 'http://sinalprivado.info:80/series/1533784/1533784/170164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5RRpCO9WGNCSj3nHe8J570CIYyo.jpg'),
(73919, 5066, 'Senhor dos Céus S03 E96', 'http://sinalprivado.info:80/series/1533784/1533784/170165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oEQvJoFHdru6St5fk15Od9JiR15.jpg'),
(73920, 5066, 'Senhor dos Céus S03 E97', 'http://sinalprivado.info:80/series/1533784/1533784/170166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hiuoilzhEojJffXBnwE5MKCIm0G.jpg'),
(73921, 5066, 'Senhor dos Céus S03 E98', 'http://sinalprivado.info:80/series/1533784/1533784/170167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8mPUcNOHHTJJLhTaUa49RAKdLRO.jpg'),
(73922, 5066, 'Senhor dos Céus S03 E99', 'http://sinalprivado.info:80/series/1533784/1533784/170168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gOcqZNf1s2NbSThy9jYSptzKNHS.jpg'),
(73923, 5066, 'Senhor dos Céus S03 E100', 'http://sinalprivado.info:80/series/1533784/1533784/170169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yCwFxfCsZYRK69lsGgJpNpl2hOH.jpg'),
(73924, 5066, 'Senhor dos Céus S03 E101', 'http://sinalprivado.info:80/series/1533784/1533784/170170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1H3erWjKDDSNJ2wlsHtd0y3vF1S.jpg'),
(73925, 5066, 'Senhor dos Céus S03 E102', 'http://sinalprivado.info:80/series/1533784/1533784/170171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qan5SRvlbmxS8pb2H6pv08zzB6i.jpg'),
(73926, 5066, 'Senhor dos Céus S03 E103', 'http://sinalprivado.info:80/series/1533784/1533784/170172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iy8DTtIP224n2ZgakO6pKicXDqI.jpg'),
(73927, 5066, 'Senhor dos Céus S03 E104', 'http://sinalprivado.info:80/series/1533784/1533784/170173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ngj2ZX3SsyFVLjV9bhJRchwuaDj.jpg'),
(73928, 5067, 'Senhor dos Céus S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3IITeRe5Oiqz2jl0BdJIab5Xo4R.jpg'),
(73929, 5067, 'Senhor dos Céus S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3IITeRe5Oiqz2jl0BdJIab5Xo4R.jpg'),
(73930, 5067, 'Senhor dos Céus S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3IITeRe5Oiqz2jl0BdJIab5Xo4R.jpg'),
(73931, 5067, 'Senhor dos Céus S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3IITeRe5Oiqz2jl0BdJIab5Xo4R.jpg'),
(73932, 5067, 'Senhor dos Céus S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3IITeRe5Oiqz2jl0BdJIab5Xo4R.jpg'),
(73933, 5067, 'Senhor dos Céus S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3IITeRe5Oiqz2jl0BdJIab5Xo4R.jpg'),
(73934, 5067, 'Senhor dos Céus S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eGOIm4AdFbcWCP8dqc6c7mYMaYy.jpg'),
(73935, 5067, 'Senhor dos Céus S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9X3847IHvZQbT1ttDGqK7T8Z5RN.jpg'),
(73936, 5067, 'Senhor dos Céus S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qPMUyNsNNbZaEyy8TrnLMzEO9Nn.jpg'),
(73937, 5067, 'Senhor dos Céus S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hgE4eP2fymNebIIFQ7Wf1gymxz9.jpg'),
(73938, 5067, 'Senhor dos Céus S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/awNmxQb7KXhE4a2hDNsceYSfYgv.jpg'),
(73939, 5067, 'Senhor dos Céus S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9SN7mNBweeahoBF0HSYr5QbwidM.jpg'),
(73940, 5067, 'Senhor dos Céus S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/170186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8Neja4SdknTCd5yy1CfOs0m7pn.jpg'),
(73941, 5067, 'Senhor dos Céus S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/170187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kXcBiHGTWkwwM8R8t20CEw2qMNZ.jpg'),
(73942, 5067, 'Senhor dos Céus S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/170188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dhdwZXFqZ7bCZXSt0YnKUBPaHZj.jpg'),
(73943, 5067, 'Senhor dos Céus S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/170189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/arEtOpioKZqbKNsFCo5m22IsJdd.jpg'),
(73944, 5067, 'Senhor dos Céus S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/170190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/upelSj3Nuve5NIU0ihMbDk7jnpp.jpg'),
(73945, 5067, 'Senhor dos Céus S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/170191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ozFysI9S4GTqffwKSfNYzZDlXdc.jpg'),
(73946, 5067, 'Senhor dos Céus S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/170192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lMQsyFxvBi4ApmGOGBmLYgPGzRB.jpg'),
(73947, 5067, 'Senhor dos Céus S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/170193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rcAqo31jnqb6634RBkJU3bfuxVq.jpg'),
(73948, 5067, 'Senhor dos Céus S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/170194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/PcajFs8PjqgeA3qzqjAa8zKFMR.jpg'),
(73949, 5067, 'Senhor dos Céus S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/170195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uaPeIPnDZXMljsVUzPjCfbj3HiQ.jpg'),
(73950, 5067, 'Senhor dos Céus S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/170196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vgP9VuWKRinpGsm3bGHyUJbvKnb.jpg'),
(73951, 5067, 'Senhor dos Céus S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/170197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gMxaz1eufm8jX0KsnIliYwA5Bl8.jpg'),
(73952, 5067, 'Senhor dos Céus S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/170198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pbsel3V4oAY9Iyx12b8s316nXWV.jpg'),
(73953, 5067, 'Senhor dos Céus S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/170199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k7V8b5ClgVNWcVE6wE0M7MPcVQJ.jpg'),
(73954, 5067, 'Senhor dos Céus S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/170200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w0lZXAClAbvbbwR8KB9my5jSAyH.jpg'),
(73955, 5067, 'Senhor dos Céus S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/170201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t697J7lEDHxXtfPU68dsle7FTjK.jpg'),
(73956, 5067, 'Senhor dos Céus S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/170202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eg8QTfsfN2Vmk35JrlAYPFraweo.jpg'),
(73957, 5067, 'Senhor dos Céus S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/170203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pZitpM7lLBlgWynmKg5crccR05B.jpg'),
(73958, 5067, 'Senhor dos Céus S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/170204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vcqKZVAYFJkVPkDVlG6mDoEN0zP.jpg'),
(73959, 5067, 'Senhor dos Céus S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/170205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMeBccJZN4ABLbZuFGlPotZ0Gtb.jpg'),
(73960, 5067, 'Senhor dos Céus S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/170206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hLzIedr3BLStXKmQbg8uRzVQtE4.jpg'),
(73961, 5067, 'Senhor dos Céus S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/170207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHjsOwk9FKS0u2Aao2ZVoF8BJdB.jpg'),
(73962, 5067, 'Senhor dos Céus S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/170208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zCN8GJY8sOlfY4V2pByPUdVroa3.jpg'),
(73963, 5067, 'Senhor dos Céus S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/170209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zKymu20wDM9qJ0HLYeP0wrDQVgU.jpg'),
(73964, 5067, 'Senhor dos Céus S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/170210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eO0B6cKwIOL6aCBxgHaUM6BDq3r.jpg'),
(73965, 5067, 'Senhor dos Céus S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/170211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ejthllllZfwjXHlKUmqMvvNXf1O.jpg'),
(73966, 5067, 'Senhor dos Céus S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/170212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/znEtMvOEBw8CtthhOrRQr91ll4l.jpg'),
(73967, 5067, 'Senhor dos Céus S04 E40', 'http://sinalprivado.info:80/series/1533784/1533784/170213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qKUxHklbVCOc2V0WFS1vrZCcHr5.jpg'),
(73968, 5067, 'Senhor dos Céus S04 E41', 'http://sinalprivado.info:80/series/1533784/1533784/170214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/reGQsJ8eXcA8I3OhqFWJtYOp9q3.jpg'),
(73969, 5067, 'Senhor dos Céus S04 E42', 'http://sinalprivado.info:80/series/1533784/1533784/170215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eXIhkew67CSnMpgTyiJ4UjvsaCw.jpg'),
(73970, 5067, 'Senhor dos Céus S04 E43', 'http://sinalprivado.info:80/series/1533784/1533784/170216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uWKptsZhOhytLpxlJgYW2VjVJYd.jpg'),
(73971, 5067, 'Senhor dos Céus S04 E44', 'http://sinalprivado.info:80/series/1533784/1533784/170217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1kGC4Voc4dS4L8K5wvaCy1dkw1E.jpg'),
(73972, 5067, 'Senhor dos Céus S04 E45', 'http://sinalprivado.info:80/series/1533784/1533784/170218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hAmCCOp1XSrZsnKUan7sCsLo7Cr.jpg'),
(73973, 5067, 'Senhor dos Céus S04 E46', 'http://sinalprivado.info:80/series/1533784/1533784/170219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tM5EufTaVVPXNkiTOFdvAXTVL0u.jpg'),
(73974, 5067, 'Senhor dos Céus S04 E47', 'http://sinalprivado.info:80/series/1533784/1533784/170220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ak9SjQfAiMib4aa7S7Uz0vRbJ5P.jpg'),
(73975, 5067, 'Senhor dos Céus S04 E48', 'http://sinalprivado.info:80/series/1533784/1533784/170221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7YSwqnz688S3iL1svP81UG5IgCj.jpg'),
(73976, 5067, 'Senhor dos Céus S04 E49', 'http://sinalprivado.info:80/series/1533784/1533784/170222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uTBx15yVnXs9dXnJ1QIGX7hNeSI.jpg'),
(73977, 5067, 'Senhor dos Céus S04 E50', 'http://sinalprivado.info:80/series/1533784/1533784/170223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8VV3n9lInAZLer9198aDzxLYQ13.jpg'),
(73978, 5067, 'Senhor dos Céus S04 E51', 'http://sinalprivado.info:80/series/1533784/1533784/170224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/afe2gVe1FRKZZsVUHSI1u9q0GxN.jpg'),
(73979, 5067, 'Senhor dos Céus S04 E52', 'http://sinalprivado.info:80/series/1533784/1533784/170225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xqIjSpDXYz0wEdGGD9qlbAAftk9.jpg'),
(73980, 5067, 'Senhor dos Céus S04 E53', 'http://sinalprivado.info:80/series/1533784/1533784/170226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ceyXXa5QB5829soTTIiuRTHgCtU.jpg'),
(73981, 5067, 'Senhor dos Céus S04 E54', 'http://sinalprivado.info:80/series/1533784/1533784/170227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zgccBWqT708nL2HOHEv5R7kwLb3.jpg'),
(73982, 5067, 'Senhor dos Céus S04 E55', 'http://sinalprivado.info:80/series/1533784/1533784/170228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cAbEYdOkwdURdImHeCkb9XzSt7S.jpg'),
(73983, 5067, 'Senhor dos Céus S04 E56', 'http://sinalprivado.info:80/series/1533784/1533784/170229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cFDKenWTGXb4wKjTqjQRw24Bgnm.jpg'),
(73984, 5067, 'Senhor dos Céus S04 E57', 'http://sinalprivado.info:80/series/1533784/1533784/170230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rBRUaSJPrpReciHyMjWf0wurpO8.jpg'),
(73985, 5067, 'Senhor dos Céus S04 E58', 'http://sinalprivado.info:80/series/1533784/1533784/170231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b4xcwxe18VUXtP1Rk21MhEDAb1r.jpg'),
(73986, 5067, 'Senhor dos Céus S04 E59', 'http://sinalprivado.info:80/series/1533784/1533784/170232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3NrhOrvnMHiZD0qteOuXRbqThZF.jpg'),
(73987, 5067, 'Senhor dos Céus S04 E60', 'http://sinalprivado.info:80/series/1533784/1533784/170233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2E1v9HFGnTSVqSICkOPthdfXfKv.jpg'),
(73988, 5067, 'Senhor dos Céus S04 E61', 'http://sinalprivado.info:80/series/1533784/1533784/170234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/498IIw86jXqOyiwPtD5WOSNClIX.jpg'),
(73989, 5067, 'Senhor dos Céus S04 E62', 'http://sinalprivado.info:80/series/1533784/1533784/170235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/acKTswYxGhIoNGYWw56tdFD6zaZ.jpg'),
(73990, 5067, 'Senhor dos Céus S04 E63', 'http://sinalprivado.info:80/series/1533784/1533784/170236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gtyC5wJpqXi5vVlLr7CNvY8LuUg.jpg'),
(73991, 5067, 'Senhor dos Céus S04 E64', 'http://sinalprivado.info:80/series/1533784/1533784/170237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ZVnXGz26zjCrZs5aRmHLqdNHI8.jpg'),
(73992, 5067, 'Senhor dos Céus S04 E65', 'http://sinalprivado.info:80/series/1533784/1533784/170238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hFNhf9i5BxxSyVN7CMwmG5YUC41.jpg'),
(73993, 5067, 'Senhor dos Céus S04 E66', 'http://sinalprivado.info:80/series/1533784/1533784/170239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t1AAci6DJDK9TkyibzuWHafdESR.jpg'),
(73994, 5067, 'Senhor dos Céus S04 E67', 'http://sinalprivado.info:80/series/1533784/1533784/170240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gIdivU5AqqUpHCU6b0Iv48bbNwO.jpg'),
(73995, 5067, 'Senhor dos Céus S04 E68', 'http://sinalprivado.info:80/series/1533784/1533784/170241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3VhCYwl8fb1DQvizLS7N0CelWdW.jpg'),
(73996, 5067, 'Senhor dos Céus S04 E69', 'http://sinalprivado.info:80/series/1533784/1533784/170242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iiZHpmJ9p1526unB1xmrlz1ZqO9.jpg'),
(73997, 5067, 'Senhor dos Céus S04 E70', 'http://sinalprivado.info:80/series/1533784/1533784/170243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vi2BU2sK8BlJkTeKlyArocMYjaG.jpg'),
(73998, 5067, 'Senhor dos Céus S04 E71', 'http://sinalprivado.info:80/series/1533784/1533784/170244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qNqBVNt0rFjhVUhfJPV3vt8CUBr.jpg'),
(73999, 5067, 'Senhor dos Céus S04 E72', 'http://sinalprivado.info:80/series/1533784/1533784/170245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8sXvQkMaP4Ww2VnsH53dedGCF7P.jpg'),
(74000, 5067, 'Senhor dos Céus S04 E73', 'http://sinalprivado.info:80/series/1533784/1533784/170246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5rDe4Rrt5ujuOYEGHIdgQ27qkWh.jpg'),
(74001, 5067, 'Senhor dos Céus S04 E74', 'http://sinalprivado.info:80/series/1533784/1533784/170247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2wF7sFspy5iWGF5NBlDYV0Yhm3q.jpg'),
(74002, 5067, 'Senhor dos Céus S04 E75', 'http://sinalprivado.info:80/series/1533784/1533784/170248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eBigJNtEXVsz56BY9ODDmiaTsox.jpg'),
(74003, 5067, 'Senhor dos Céus S04 E76', 'http://sinalprivado.info:80/series/1533784/1533784/170249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fwKTvl1ysFdob3xHnGUn8mrxCls.jpg'),
(74004, 5067, 'Senhor dos Céus S04 E77', 'http://sinalprivado.info:80/series/1533784/1533784/170250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6qG0wAjQGjQJxPTFBHiFOKqqdLu.jpg'),
(74005, 5067, 'Senhor dos Céus S04 E78', 'http://sinalprivado.info:80/series/1533784/1533784/170251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Meb86ONHaol220435zeVgIsgIZ.jpg'),
(74006, 5067, 'Senhor dos Céus S04 E79', 'http://sinalprivado.info:80/series/1533784/1533784/170252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2MFfe03J9UUs72iomZcMrsXhK1M.jpg'),
(74007, 5067, 'Senhor dos Céus S04 E80', 'http://sinalprivado.info:80/series/1533784/1533784/170253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cz84Y53ZIzvZwteFQeHtYruBZyW.jpg'),
(74008, 5068, 'Senhor dos Céus S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/357686.mp4', 'https://image.tmdb.org/t/p/w300/d2DJD5SZuLWMmld2fojMrNE2HIg.jpg'),
(74009, 5068, 'Senhor dos Céus S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/357687.mp4', 'https://image.tmdb.org/t/p/w300/iZ4Z81w88uVWDqA0UdMmcDYKhS1.jpg'),
(74010, 5068, 'Senhor dos Céus S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/357688.mp4', 'https://image.tmdb.org/t/p/w300/iZ4Z81w88uVWDqA0UdMmcDYKhS1.jpg'),
(74011, 5068, 'Senhor dos Céus S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/357689.mp4', 'https://image.tmdb.org/t/p/w300/iZ4Z81w88uVWDqA0UdMmcDYKhS1.jpg'),
(74012, 5068, 'Senhor dos Céus S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/357690.mp4', 'https://image.tmdb.org/t/p/w300/iZ4Z81w88uVWDqA0UdMmcDYKhS1.jpg'),
(74013, 5068, 'Senhor dos Céus S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/357691.mp4', 'https://image.tmdb.org/t/p/w300/iZ4Z81w88uVWDqA0UdMmcDYKhS1.jpg'),
(74014, 5068, 'Senhor dos Céus S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/357692.mp4', 'https://image.tmdb.org/t/p/w300/w3T00qc0Sii8qO192IKTxG9M7eb.jpg'),
(74015, 5068, 'Senhor dos Céus S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/357693.mp4', 'https://image.tmdb.org/t/p/w300/zty0Rpp07ditakh7wFqtFN6ocI4.jpg'),
(74016, 5068, 'Senhor dos Céus S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/357694.mp4', 'https://image.tmdb.org/t/p/w300/1sSM7qqbVmoM3lFu3jwuqWuZkZM.jpg'),
(74017, 5068, 'Senhor dos Céus S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/357695.mp4', 'https://image.tmdb.org/t/p/w300/vUzJuAhh5B8xvy9WzZHfB5bc8VL.jpg'),
(74018, 5068, 'Senhor dos Céus S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/357696.mp4', 'https://image.tmdb.org/t/p/w300/20Gy3wnsUwG7lqYkJ5cWnLhkvjw.jpg'),
(74019, 5068, 'Senhor dos Céus S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/357697.mp4', 'https://image.tmdb.org/t/p/w300/oR1f3UkDNVTE1olxiSBYJKG3WSu.jpg'),
(74020, 5068, 'Senhor dos Céus S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/357698.mp4', 'https://image.tmdb.org/t/p/w300/18BVvTbhK7ASRbpP938z8wm6r4l.jpg'),
(74021, 5068, 'Senhor dos Céus S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/357699.mp4', 'https://image.tmdb.org/t/p/w300/gKGKei0M8BRFwcbTmmhy6R95T9y.jpg'),
(74022, 5068, 'Senhor dos Céus S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/357700.mp4', 'https://image.tmdb.org/t/p/w300/6Cz9RICd0y1XJtvdgeNuJLTpW4T.jpg'),
(74023, 5068, 'Senhor dos Céus S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/357701.mp4', 'https://image.tmdb.org/t/p/w300/xPM65FQA7jPCpoKE35KyRBpBSJ5.jpg'),
(74024, 5068, 'Senhor dos Céus S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/357702.mp4', 'https://image.tmdb.org/t/p/w300/9i2dJQHyNYEDKzQwodgVqLFcRn3.jpg'),
(74025, 5068, 'Senhor dos Céus S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/357703.mp4', 'https://image.tmdb.org/t/p/w300/rcxIInzKriJdhwJESOal5jCihpe.jpg'),
(74026, 5068, 'Senhor dos Céus S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/357704.mp4', 'https://image.tmdb.org/t/p/w300/quKX1GQb9vwAQZf7Q9yGpOGlGd6.jpg'),
(74027, 5068, 'Senhor dos Céus S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/357705.mp4', 'https://image.tmdb.org/t/p/w300/tbMKSGXWeYheI9lYwkvR0iIdFtJ.jpg'),
(74028, 5068, 'Senhor dos Céus S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/357706.mp4', 'https://image.tmdb.org/t/p/w300/mYsJ9hnhgIQuRf6YO9EzcMBbXIR.jpg'),
(74029, 5068, 'Senhor dos Céus S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/357707.mp4', 'https://image.tmdb.org/t/p/w300/v6ZH0frON4hvtlEUX5WyfL6zAqL.jpg'),
(74030, 5068, 'Senhor dos Céus S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/357708.mp4', 'https://image.tmdb.org/t/p/w300/rYGmRshkBZITu8STQmR46uCbrFT.jpg'),
(74031, 5068, 'Senhor dos Céus S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/357709.mp4', 'https://image.tmdb.org/t/p/w300/dSlI1oZ5ZdDtJ0EEd3eMOEHcyXr.jpg'),
(74032, 5068, 'Senhor dos Céus S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/357710.mp4', 'https://image.tmdb.org/t/p/w300/8yjbngqVNz9X40SI7cRq3ZIhs2r.jpg'),
(74033, 5068, 'Senhor dos Céus S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/357711.mp4', 'https://image.tmdb.org/t/p/w300/urpgQGAzPFRIAmTplH3lpE9VeUw.jpg'),
(74034, 5068, 'Senhor dos Céus S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/357712.mp4', 'https://image.tmdb.org/t/p/w300/bEap0TVYaSdeYsa6U31kI2Nhtjm.jpg'),
(74035, 5068, 'Senhor dos Céus S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/357713.mp4', 'https://image.tmdb.org/t/p/w300/v3foShtW6PBcKwJqFqZDE4SFVKu.jpg'),
(74036, 5068, 'Senhor dos Céus S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/357714.mp4', 'https://image.tmdb.org/t/p/w300/rMgn88PHAr1ds8QWdFNQi40ImGL.jpg'),
(74037, 5068, 'Senhor dos Céus S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/357715.mp4', 'https://image.tmdb.org/t/p/w300/tbNb8LRaGV2p3hFjSxQTFI6WpvR.jpg'),
(74038, 5068, 'Senhor dos Céus S05 E31', 'http://sinalprivado.info:80/series/1533784/1533784/357716.mp4', 'https://image.tmdb.org/t/p/w300/wET1mNDCGRU0tzaLCLgKT0v7F9E.jpg'),
(74039, 5068, 'Senhor dos Céus S05 E32', 'http://sinalprivado.info:80/series/1533784/1533784/357717.mp4', 'https://image.tmdb.org/t/p/w300/hLpHEq1SIr8zDUMjGIRAEdQIVeR.jpg'),
(74040, 5068, 'Senhor dos Céus S05 E33', 'http://sinalprivado.info:80/series/1533784/1533784/357718.mp4', 'https://image.tmdb.org/t/p/w300/1aWMhYlfrTgeDzMXuBSv49dNpUP.jpg'),
(74041, 5068, 'Senhor dos Céus S05 E34', 'http://sinalprivado.info:80/series/1533784/1533784/357719.mp4', 'https://image.tmdb.org/t/p/w300/fYmaMrcwl2TWknzRxEq8ZpiILgu.jpg'),
(74042, 5068, 'Senhor dos Céus S05 E35', 'http://sinalprivado.info:80/series/1533784/1533784/357720.mp4', 'https://image.tmdb.org/t/p/w300/zG0ChrC37wQaQuMwjHrfOJd5H9v.jpg'),
(74043, 5068, 'Senhor dos Céus S05 E36', 'http://sinalprivado.info:80/series/1533784/1533784/357721.mp4', 'https://image.tmdb.org/t/p/w300/cRJXPqrzX2h4KgULtkPhJJVE01k.jpg'),
(74044, 5068, 'Senhor dos Céus S05 E37', 'http://sinalprivado.info:80/series/1533784/1533784/357722.mp4', 'https://image.tmdb.org/t/p/w300/iAmEpwiiBbN2zeBCDVor6Y6yi6m.jpg'),
(74045, 5068, 'Senhor dos Céus S05 E38', 'http://sinalprivado.info:80/series/1533784/1533784/357723.mp4', 'https://image.tmdb.org/t/p/w300/X5XQHoyozjXuPkV3x8RpPuWVbx.jpg'),
(74046, 5068, 'Senhor dos Céus S05 E39', 'http://sinalprivado.info:80/series/1533784/1533784/357724.mp4', 'https://image.tmdb.org/t/p/w300/f0yxh80oLYed4zpq6dDVZTEn2Qk.jpg'),
(74047, 5068, 'Senhor dos Céus S05 E40', 'http://sinalprivado.info:80/series/1533784/1533784/357725.mp4', 'https://image.tmdb.org/t/p/w300/vfgYAXGU0lU4GF6T5lShGxxdDyu.jpg'),
(74048, 5068, 'Senhor dos Céus S05 E41', 'http://sinalprivado.info:80/series/1533784/1533784/357726.mp4', 'https://image.tmdb.org/t/p/w300/oTRD8DE5IdXvWJLGlArzfKXt7EK.jpg'),
(74049, 5068, 'Senhor dos Céus S05 E42', 'http://sinalprivado.info:80/series/1533784/1533784/357727.mp4', 'https://image.tmdb.org/t/p/w300/epXf8NwGKkQKhHpa6liU2iLrJxv.jpg'),
(74050, 5068, 'Senhor dos Céus S05 E43', 'http://sinalprivado.info:80/series/1533784/1533784/357728.mp4', 'https://image.tmdb.org/t/p/w300/nRdRAKDwtoadj7ut4NUW20BqFlk.jpg'),
(74051, 5068, 'Senhor dos Céus S05 E44', 'http://sinalprivado.info:80/series/1533784/1533784/357729.mp4', 'https://image.tmdb.org/t/p/w300/fq1peMePSHEqnW7kwiZHKf0NIwP.jpg'),
(74052, 5068, 'Senhor dos Céus S05 E45', 'http://sinalprivado.info:80/series/1533784/1533784/357730.mp4', 'https://image.tmdb.org/t/p/w300/xQ8j7PqloGI15nnprBlWCzzoZsL.jpg'),
(74053, 5068, 'Senhor dos Céus S05 E46', 'http://sinalprivado.info:80/series/1533784/1533784/357731.mp4', 'https://image.tmdb.org/t/p/w300/sFl4GLMnGD3946UgemlLX7o20rm.jpg'),
(74054, 5068, 'Senhor dos Céus S05 E47', 'http://sinalprivado.info:80/series/1533784/1533784/357732.mp4', 'https://image.tmdb.org/t/p/w300/aMDRGPObO5AWUWgS2lIBzwtmGJA.jpg'),
(74055, 5068, 'Senhor dos Céus S05 E48', 'http://sinalprivado.info:80/series/1533784/1533784/357733.mp4', 'https://image.tmdb.org/t/p/w300/hDEhV9YzBWgKKPylItYTJoSCZS5.jpg'),
(74056, 5068, 'Senhor dos Céus S05 E49', 'http://sinalprivado.info:80/series/1533784/1533784/357734.mp4', 'https://image.tmdb.org/t/p/w300/cRO4INPbHE5F9uVa5YOojlQ9wM.jpg'),
(74057, 5068, 'Senhor dos Céus S05 E50', 'http://sinalprivado.info:80/series/1533784/1533784/357735.mp4', 'https://image.tmdb.org/t/p/w300/lrrDTNKDXylKS28pC3JSBJS3TUY.jpg'),
(74058, 5068, 'Senhor dos Céus S05 E51', 'http://sinalprivado.info:80/series/1533784/1533784/357736.mp4', 'https://image.tmdb.org/t/p/w300/ArLTzUb4M64N2MuuZpxJSPjYNXN.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(74059, 5068, 'Senhor dos Céus S05 E52', 'http://sinalprivado.info:80/series/1533784/1533784/357737.mp4', 'https://image.tmdb.org/t/p/w300/afha1jzbOluDPnjfC7WuXLw7jNe.jpg'),
(74060, 5068, 'Senhor dos Céus S05 E53', 'http://sinalprivado.info:80/series/1533784/1533784/357738.mp4', 'https://image.tmdb.org/t/p/w300/m047tKvBeTZKSsslDrVHF2yLjne.jpg'),
(74061, 5068, 'Senhor dos Céus S05 E54', 'http://sinalprivado.info:80/series/1533784/1533784/357739.mp4', 'https://image.tmdb.org/t/p/w300/6LgNXybl25GouFiwkyPocPni0VB.jpg'),
(74062, 5068, 'Senhor dos Céus S05 E55', 'http://sinalprivado.info:80/series/1533784/1533784/357740.mp4', 'https://image.tmdb.org/t/p/w300/fi8cMXXIP5sVeQRTMjZP64al8mK.jpg'),
(74063, 5068, 'Senhor dos Céus S05 E56', 'http://sinalprivado.info:80/series/1533784/1533784/357741.mp4', 'https://image.tmdb.org/t/p/w300/95oc0Wic6XCo7xAE63wCM8xcm7U.jpg'),
(74064, 5068, 'Senhor dos Céus S05 E57', 'http://sinalprivado.info:80/series/1533784/1533784/357742.mp4', 'https://image.tmdb.org/t/p/w300/7sCooNcFFT9O5euCMJggjjIcwCT.jpg'),
(74065, 5068, 'Senhor dos Céus S05 E58', 'http://sinalprivado.info:80/series/1533784/1533784/357743.mp4', 'https://image.tmdb.org/t/p/w300/6MzSykFmX2NUieIVQaujUDQgEPg.jpg'),
(74066, 5068, 'Senhor dos Céus S05 E59', 'http://sinalprivado.info:80/series/1533784/1533784/357744.mp4', 'https://image.tmdb.org/t/p/w300/4XvjcRW9zg0wLgIr6JtCJqfQCZI.jpg'),
(74067, 5068, 'Senhor dos Céus S05 E60', 'http://sinalprivado.info:80/series/1533784/1533784/357745.mp4', 'https://image.tmdb.org/t/p/w300/qDTU4p0Km4kS25nMVYzjFssYXZR.jpg'),
(74068, 5068, 'Senhor dos Céus S05 E61', 'http://sinalprivado.info:80/series/1533784/1533784/357746.mp4', 'https://image.tmdb.org/t/p/w300/4qVL30RRppOE8cCElVO0q4o0eXM.jpg'),
(74069, 5068, 'Senhor dos Céus S05 E62', 'http://sinalprivado.info:80/series/1533784/1533784/357747.mp4', 'https://image.tmdb.org/t/p/w300/yFSRn4HPdHBRlYIbY6ttXCRnFA4.jpg'),
(74070, 5068, 'Senhor dos Céus S05 E63', 'http://sinalprivado.info:80/series/1533784/1533784/357748.mp4', 'https://image.tmdb.org/t/p/w300/aIneb4zdMD0bytusDcWmT6jIBCD.jpg'),
(74071, 5068, 'Senhor dos Céus S05 E64', 'http://sinalprivado.info:80/series/1533784/1533784/357749.mp4', 'https://image.tmdb.org/t/p/w300/aVH8JeFrg9PrRCzwoIdvhWi6mAw.jpg'),
(74072, 5068, 'Senhor dos Céus S05 E65', 'http://sinalprivado.info:80/series/1533784/1533784/357750.mp4', 'https://image.tmdb.org/t/p/w300/mQgwtC5OzTbhAR1RdDWWAJIOyzx.jpg'),
(74073, 5068, 'Senhor dos Céus S05 E66', 'http://sinalprivado.info:80/series/1533784/1533784/357751.mp4', 'https://image.tmdb.org/t/p/w300/sLV9ikiudWy6OEFlPyHdCgfqY5b.jpg'),
(74074, 5068, 'Senhor dos Céus S05 E67', 'http://sinalprivado.info:80/series/1533784/1533784/357752.mp4', 'https://image.tmdb.org/t/p/w300/5YRxFNmoGBdPfjKiR0s62EIyniy.jpg'),
(74075, 5068, 'Senhor dos Céus S05 E68', 'http://sinalprivado.info:80/series/1533784/1533784/357753.mp4', 'https://image.tmdb.org/t/p/w300/daHlDdI1bYc2UpGtee3iNOhyxRa.jpg'),
(74076, 5068, 'Senhor dos Céus S05 E69', 'http://sinalprivado.info:80/series/1533784/1533784/357754.mp4', 'https://image.tmdb.org/t/p/w300/eZRAREZUTW0yN3HuX3EpHHXTaoS.jpg'),
(74077, 5068, 'Senhor dos Céus S05 E70', 'http://sinalprivado.info:80/series/1533784/1533784/357755.mp4', 'https://image.tmdb.org/t/p/w300/9iQj4CQs7scyHOUzCUZ6YsbOVmK.jpg'),
(74078, 5068, 'Senhor dos Céus S05 E71', 'http://sinalprivado.info:80/series/1533784/1533784/357756.mp4', 'https://image.tmdb.org/t/p/w300/2905hvyA4P35qhH0otb9dtvGaTt.jpg'),
(74079, 5068, 'Senhor dos Céus S05 E72', 'http://sinalprivado.info:80/series/1533784/1533784/357757.mp4', 'https://image.tmdb.org/t/p/w300/cFW1P2jO3MD78bMG0GpNArZLB3W.jpg'),
(74080, 5068, 'Senhor dos Céus S05 E73', 'http://sinalprivado.info:80/series/1533784/1533784/357758.mp4', 'https://image.tmdb.org/t/p/w300/bQGUHqapNCzW3y2Ug8aZkxJmoZH.jpg'),
(74081, 5068, 'Senhor dos Céus S05 E74', 'http://sinalprivado.info:80/series/1533784/1533784/357759.mp4', 'https://image.tmdb.org/t/p/w300/kZS643FyhZfoskbbmqpth9uqSaG.jpg'),
(74082, 5068, 'Senhor dos Céus S05 E75', 'http://sinalprivado.info:80/series/1533784/1533784/357760.mp4', 'https://image.tmdb.org/t/p/w300/rjiAirTnGJxZwx0rkJ468g8Ll1G.jpg'),
(74083, 5068, 'Senhor dos Céus S05 E76', 'http://sinalprivado.info:80/series/1533784/1533784/357761.mp4', 'https://image.tmdb.org/t/p/w300/7KrhUc5tegYXuEbe4IXsV6K73Ws.jpg'),
(74084, 5068, 'Senhor dos Céus S05 E77', 'http://sinalprivado.info:80/series/1533784/1533784/357762.mp4', 'https://image.tmdb.org/t/p/w300/tz1BHIUyhqxi6LKf8jXDa00GUGk.jpg'),
(74085, 5068, 'Senhor dos Céus S05 E78', 'http://sinalprivado.info:80/series/1533784/1533784/357763.mp4', 'https://image.tmdb.org/t/p/w300/xY50yzB2oS39kr4RfJGGkYaC9mG.jpg'),
(74086, 5068, 'Senhor dos Céus S05 E79', 'http://sinalprivado.info:80/series/1533784/1533784/357764.mp4', 'https://image.tmdb.org/t/p/w300/oAC3DsXl8RqHk6v0M96eDGQCo9B.jpg'),
(74087, 5068, 'Senhor dos Céus S05 E80', 'http://sinalprivado.info:80/series/1533784/1533784/357765.mp4', 'https://image.tmdb.org/t/p/w300/iisD11Tbni9RlzCA6ZFSDe4Hbba.jpg'),
(74088, 5068, 'Senhor dos Céus S05 E81', 'http://sinalprivado.info:80/series/1533784/1533784/357766.mp4', 'https://image.tmdb.org/t/p/w300/4IDRCjdhM7j3qQ4VawylJV9fosT.jpg'),
(74089, 5068, 'Senhor dos Céus S05 E82', 'http://sinalprivado.info:80/series/1533784/1533784/357767.mp4', 'https://image.tmdb.org/t/p/w300/72gpnZz0rYs4BPxevuKMkrng6mP.jpg'),
(74090, 5068, 'Senhor dos Céus S05 E83', 'http://sinalprivado.info:80/series/1533784/1533784/357768.mp4', 'https://image.tmdb.org/t/p/w300/jcXfzsITbnh0Tq1BAVuICCCR5ag.jpg'),
(74091, 5068, 'Senhor dos Céus S05 E84', 'http://sinalprivado.info:80/series/1533784/1533784/357769.mp4', 'https://image.tmdb.org/t/p/w300/modKb05k8OHeIlg33ClO82l9EC8.jpg'),
(74092, 5068, 'Senhor dos Céus S05 E85', 'http://sinalprivado.info:80/series/1533784/1533784/357770.mp4', 'https://image.tmdb.org/t/p/w300/8Icb1yVe1gpZW7slIEWsV4gdbYk.jpg'),
(74093, 5068, 'Senhor dos Céus S05 E86', 'http://sinalprivado.info:80/series/1533784/1533784/357771.mp4', 'https://image.tmdb.org/t/p/w300/oBM1Ss5TxRULjHDJsLWbDpCLzlQ.jpg'),
(74094, 5068, 'Senhor dos Céus S05 E87', 'http://sinalprivado.info:80/series/1533784/1533784/357772.mp4', 'https://image.tmdb.org/t/p/w300/lYTJMah0W0jIJ5owXP7TXh8ckft.jpg'),
(74095, 5068, 'Senhor dos Céus S05 E88', 'http://sinalprivado.info:80/series/1533784/1533784/357773.mp4', 'https://image.tmdb.org/t/p/w300/9p981G1RNruVHqyNNMysJKismL4.jpg'),
(74096, 5068, 'Senhor dos Céus S05 E89', 'http://sinalprivado.info:80/series/1533784/1533784/357774.mp4', 'https://image.tmdb.org/t/p/w300/sKxim6i8ADsgVlN5Y1UQcn8hVbS.jpg'),
(74097, 5068, 'Senhor dos Céus S05 E90', 'http://sinalprivado.info:80/series/1533784/1533784/357775.mp4', 'https://image.tmdb.org/t/p/w300/bTIyOWxQ0JiDRIIp4a5IFYxBPrO.jpg'),
(74098, 5068, 'Senhor dos Céus S05 E91', 'http://sinalprivado.info:80/series/1533784/1533784/357776.mp4', 'https://image.tmdb.org/t/p/w300/aAKVmFNuV5PaR1nelW5G35RxtSm.jpg'),
(74099, 5068, 'Senhor dos Céus S05 E92', 'http://sinalprivado.info:80/series/1533784/1533784/357777.mp4', 'https://image.tmdb.org/t/p/w300/n4WKspbltQj7kUGXcCTEmQxkoCS.jpg'),
(74100, 5068, 'Senhor dos Céus S05 E93', 'http://sinalprivado.info:80/series/1533784/1533784/357778.mp4', 'https://image.tmdb.org/t/p/w300/xV92ynl8sSgYMzAR0gKLaOfhVPA.jpg'),
(74101, 5068, 'Senhor dos Céus S05 E94', 'http://sinalprivado.info:80/series/1533784/1533784/357779.mp4', 'https://image.tmdb.org/t/p/w300/u3lc4nOEVGLLUAxzbAQ8moMlgyo.jpg'),
(74102, 5069, 'Senhor dos Céus S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/357780.mp4', 'https://image.tmdb.org/t/p/w300/qWVpkl9Bs2vFFg0bNm9nWzuPIG8.jpg'),
(74103, 5069, 'Senhor dos Céus S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/357781.mp4', 'https://image.tmdb.org/t/p/w300/2Sh3w8mzF3AeWP6oXNwCRHqtXMW.jpg'),
(74104, 5069, 'Senhor dos Céus S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/357782.mp4', 'https://image.tmdb.org/t/p/w300/oCiNLDZvBFPa1Oc3sg0Abj8zyqS.jpg'),
(74105, 5069, 'Senhor dos Céus S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/357783.mp4', 'https://image.tmdb.org/t/p/w300/is3A31TXEN6CWzzm3crUFLvQECt.jpg'),
(74106, 5069, 'Senhor dos Céus S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/357784.mp4', 'https://image.tmdb.org/t/p/w300/xhbuvngwuJ7EAiD5APNTvMdFzrH.jpg'),
(74107, 5069, 'Senhor dos Céus S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/357785.mp4', 'https://image.tmdb.org/t/p/w300/hBZFrqEdNdzAezJMoUlEx8tYJy1.jpg'),
(74108, 5069, 'Senhor dos Céus S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/357786.mp4', 'https://image.tmdb.org/t/p/w300/dXYYPCe8Eso1VpiZg0diZCyvka6.jpg'),
(74109, 5069, 'Senhor dos Céus S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/357787.mp4', 'https://image.tmdb.org/t/p/w300/xxKDgk57iiTBWC0Rppgc92HNyb2.jpg'),
(74110, 5069, 'Senhor dos Céus S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/357788.mp4', 'https://image.tmdb.org/t/p/w300/ut9T2GCJLyDRZNjfoR182to5ctl.jpg'),
(74111, 5069, 'Senhor dos Céus S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/357789.mp4', 'https://image.tmdb.org/t/p/w300/wafaNd8k4ae6wESOXy6s3P2eVUl.jpg'),
(74112, 5069, 'Senhor dos Céus S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/357790.mp4', 'https://image.tmdb.org/t/p/w300/5M3tL65SgpW3eS69gb17vnSXnVz.jpg'),
(74113, 5069, 'Senhor dos Céus S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/357791.mp4', 'https://image.tmdb.org/t/p/w300/85zZgInCGkkmEE4UI9NDZ6SU1Li.jpg'),
(74114, 5069, 'Senhor dos Céus S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/357792.mp4', 'https://image.tmdb.org/t/p/w300/tcdDrLjMRgWDSSmUA6VWrCnoxlt.jpg'),
(74115, 5069, 'Senhor dos Céus S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/357793.mp4', 'https://image.tmdb.org/t/p/w300/ymM93a9yjgvWpGpIhkxqwLbtdhg.jpg'),
(74116, 5069, 'Senhor dos Céus S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/357794.mp4', 'https://image.tmdb.org/t/p/w300/wJkk3t09j812ARmdrFytnno26Pk.jpg'),
(74117, 5069, 'Senhor dos Céus S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/357795.mp4', 'https://image.tmdb.org/t/p/w300/oUiqejjbF00je03f2NX7PDaBiO9.jpg'),
(74118, 5069, 'Senhor dos Céus S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/357796.mp4', 'https://image.tmdb.org/t/p/w300/9bPb1J14R6yDcdh9SIYXHvFWsbz.jpg'),
(74119, 5069, 'Senhor dos Céus S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/357797.mp4', 'https://image.tmdb.org/t/p/w300/8eMGp195vRI7DMeyLMKNqH9mrc0.jpg'),
(74120, 5069, 'Senhor dos Céus S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/357798.mp4', 'https://image.tmdb.org/t/p/w300/kRWIi5I0gO8uA7c6oyqjra16a26.jpg'),
(74121, 5069, 'Senhor dos Céus S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/357799.mp4', 'https://image.tmdb.org/t/p/w300/71mfZdSHBix4hV4Oykj8d35r3wv.jpg'),
(74122, 5069, 'Senhor dos Céus S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/357800.mp4', 'https://image.tmdb.org/t/p/w300/rsCNhd5y5N9rilqRJTKCUhjmtSO.jpg'),
(74123, 5069, 'Senhor dos Céus S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/357801.mp4', 'https://image.tmdb.org/t/p/w300/g79Ug1JzoAtOu67BOzaDoOBzc79.jpg'),
(74124, 5069, 'Senhor dos Céus S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/357802.mp4', 'https://image.tmdb.org/t/p/w300/t6pwJ1J5e3MESaJxn4PuGqQFYR3.jpg'),
(74125, 5069, 'Senhor dos Céus S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/357803.mp4', 'https://image.tmdb.org/t/p/w300/gtYQgI6d0Wzvbx1GcMEroRgF2uD.jpg'),
(74126, 5069, 'Senhor dos Céus S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/357804.mp4', 'https://image.tmdb.org/t/p/w300/a4E3idnBOdrMJV0LW061HOEe8fT.jpg'),
(74127, 5069, 'Senhor dos Céus S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/357805.mp4', 'https://image.tmdb.org/t/p/w300/prX9jDDJ9UlDBnjWcpCZcRw2n9T.jpg'),
(74128, 5069, 'Senhor dos Céus S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/357806.mp4', 'https://image.tmdb.org/t/p/w300/yARFn56xtuMCL7Ts6bHOdvsotn5.jpg'),
(74129, 5069, 'Senhor dos Céus S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/357807.mp4', 'https://image.tmdb.org/t/p/w300/tvnrOdeWcy6DiTPrAnqseFXt1fw.jpg'),
(74130, 5069, 'Senhor dos Céus S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/357808.mp4', 'https://image.tmdb.org/t/p/w300/268YfqRKXog3mn23pY9sISb4ZEl.jpg'),
(74131, 5069, 'Senhor dos Céus S06 E30', 'http://sinalprivado.info:80/series/1533784/1533784/357809.mp4', 'https://image.tmdb.org/t/p/w300/xAxwILa9vKHeRhshezqW8GH4Ahl.jpg'),
(74132, 5069, 'Senhor dos Céus S06 E31', 'http://sinalprivado.info:80/series/1533784/1533784/357810.mp4', 'https://image.tmdb.org/t/p/w300/fwaEhbNqHjJIvLyCXixc21YAHPx.jpg'),
(74133, 5069, 'Senhor dos Céus S06 E32', 'http://sinalprivado.info:80/series/1533784/1533784/357811.mp4', 'https://image.tmdb.org/t/p/w300/sC0OaHGAcdU1Snuv2fnmrY5qfTd.jpg'),
(74134, 5069, 'Senhor dos Céus S06 E33', 'http://sinalprivado.info:80/series/1533784/1533784/357812.mp4', 'https://image.tmdb.org/t/p/w300/jz0NiyMr90BjlOnbKTZWNuGLXse.jpg'),
(74135, 5069, 'Senhor dos Céus S06 E34', 'http://sinalprivado.info:80/series/1533784/1533784/357813.mp4', 'https://image.tmdb.org/t/p/w300/pWZ1LK7Ualt2Tv19EaH8ExX92GF.jpg'),
(74136, 5069, 'Senhor dos Céus S06 E35', 'http://sinalprivado.info:80/series/1533784/1533784/357814.mp4', 'https://image.tmdb.org/t/p/w300/kiPoAuxQdF1KaTdK68xVq8Pc9vP.jpg'),
(74137, 5069, 'Senhor dos Céus S06 E36', 'http://sinalprivado.info:80/series/1533784/1533784/357815.mp4', 'https://image.tmdb.org/t/p/w300/cDaKLhJLraecasMTqXnI3tiltjW.jpg'),
(74138, 5069, 'Senhor dos Céus S06 E37', 'http://sinalprivado.info:80/series/1533784/1533784/357816.mp4', 'https://image.tmdb.org/t/p/w300/amSZXlbNkAUtM0fkqJS0QmQMOe.jpg'),
(74139, 5069, 'Senhor dos Céus S06 E38', 'http://sinalprivado.info:80/series/1533784/1533784/357817.mp4', 'https://image.tmdb.org/t/p/w300/hRxILbZIlqt8ssKWWL5IkpUACnD.jpg'),
(74140, 5069, 'Senhor dos Céus S06 E39', 'http://sinalprivado.info:80/series/1533784/1533784/357818.mp4', 'https://image.tmdb.org/t/p/w300/feWM8aNrpbbGmWirO8SBbZI25lF.jpg'),
(74141, 5069, 'Senhor dos Céus S06 E40', 'http://sinalprivado.info:80/series/1533784/1533784/357819.mp4', 'https://image.tmdb.org/t/p/w300/jOCN4JcYvaQLG1fZWrdjbHpfIci.jpg'),
(74142, 5069, 'Senhor dos Céus S06 E41', 'http://sinalprivado.info:80/series/1533784/1533784/357820.mp4', 'https://image.tmdb.org/t/p/w300/9ISRlSaXkh4pQKMVcr6IvEZg0bt.jpg'),
(74143, 5069, 'Senhor dos Céus S06 E42', 'http://sinalprivado.info:80/series/1533784/1533784/357821.mp4', 'https://image.tmdb.org/t/p/w300/datADGOpKlPZA8d2NTHTGPVfGMI.jpg'),
(74144, 5069, 'Senhor dos Céus S06 E43', 'http://sinalprivado.info:80/series/1533784/1533784/357822.mp4', 'https://image.tmdb.org/t/p/w300/xrQilGOlSvn5jfEgaPtcV1VC33b.jpg'),
(74145, 5069, 'Senhor dos Céus S06 E44', 'http://sinalprivado.info:80/series/1533784/1533784/357823.mp4', 'https://image.tmdb.org/t/p/w300/oS0XNYBH9hROFm8Dd0dpdaKO8wF.jpg'),
(74146, 5069, 'Senhor dos Céus S06 E45', 'http://sinalprivado.info:80/series/1533784/1533784/357824.mp4', 'https://image.tmdb.org/t/p/w300/fGxin8PkOITgVPmZIq1hQA4o2c1.jpg'),
(74147, 5069, 'Senhor dos Céus S06 E46', 'http://sinalprivado.info:80/series/1533784/1533784/357825.mp4', 'https://image.tmdb.org/t/p/w300/f2NJMli6qHArzaE5Md6vL7MAfT.jpg'),
(74148, 5069, 'Senhor dos Céus S06 E47', 'http://sinalprivado.info:80/series/1533784/1533784/357826.mp4', 'https://image.tmdb.org/t/p/w300/aDl3aDihfIAWpcuSQ2wnt2QUSIk.jpg'),
(74149, 5069, 'Senhor dos Céus S06 E48', 'http://sinalprivado.info:80/series/1533784/1533784/357827.mp4', 'https://image.tmdb.org/t/p/w300/zLjyWDSqTaJPJqlXld3LfxFJdps.jpg'),
(74150, 5069, 'Senhor dos Céus S06 E49', 'http://sinalprivado.info:80/series/1533784/1533784/357828.mp4', 'https://image.tmdb.org/t/p/w300/h6uJfzdr0KQ9b3q9zDsGY1OJWy2.jpg'),
(74151, 5069, 'Senhor dos Céus S06 E50', 'http://sinalprivado.info:80/series/1533784/1533784/357829.mp4', 'https://image.tmdb.org/t/p/w300/jR74sZxHspZWqFqDqWqMSc0h8cF.jpg'),
(74152, 5069, 'Senhor dos Céus S06 E51', 'http://sinalprivado.info:80/series/1533784/1533784/357830.mp4', 'https://image.tmdb.org/t/p/w300/eklMp9jGXM6mElNoQNX3z0gLZZX.jpg'),
(74153, 5069, 'Senhor dos Céus S06 E52', 'http://sinalprivado.info:80/series/1533784/1533784/357831.mp4', 'https://image.tmdb.org/t/p/w300/eklMp9jGXM6mElNoQNX3z0gLZZX.jpg'),
(74154, 5069, 'Senhor dos Céus S06 E53', 'http://sinalprivado.info:80/series/1533784/1533784/357832.mp4', 'https://image.tmdb.org/t/p/w300/yTqGluGSqcZXZqnm31GdZM3FYFq.jpg'),
(74155, 5069, 'Senhor dos Céus S06 E54', 'http://sinalprivado.info:80/series/1533784/1533784/357833.mp4', 'https://image.tmdb.org/t/p/w300/zyLZj0OUpEBQxsovmjf1Sb0t4pZ.jpg'),
(74156, 5069, 'Senhor dos Céus S06 E55', 'http://sinalprivado.info:80/series/1533784/1533784/357834.mp4', 'https://image.tmdb.org/t/p/w300/8mPQjLCkBcrIacrFXBK61sREzxy.jpg'),
(74157, 5069, 'Senhor dos Céus S06 E56', 'http://sinalprivado.info:80/series/1533784/1533784/357835.mp4', 'https://image.tmdb.org/t/p/w300/aBgxEodu2PyJCslQT3qZq2zcNb6.jpg'),
(74158, 5069, 'Senhor dos Céus S06 E57', 'http://sinalprivado.info:80/series/1533784/1533784/357836.mp4', 'https://image.tmdb.org/t/p/w300/xAuHXeZmMZG2h0XXdBMCdrT2qOo.jpg'),
(74159, 5069, 'Senhor dos Céus S06 E58', 'http://sinalprivado.info:80/series/1533784/1533784/357837.mp4', 'https://image.tmdb.org/t/p/w300/38VwVflRnZrewljLCM5hCx10IjE.jpg'),
(74160, 5069, 'Senhor dos Céus S06 E59', 'http://sinalprivado.info:80/series/1533784/1533784/357838.mp4', 'https://image.tmdb.org/t/p/w300/duLTIhFWRNlJk6Sth93hsaoihvY.jpg'),
(74161, 5069, 'Senhor dos Céus S06 E60', 'http://sinalprivado.info:80/series/1533784/1533784/357839.mp4', 'https://image.tmdb.org/t/p/w300/kFWoBLcm8AtjFqztawNbwJdyU80.jpg'),
(74162, 5069, 'Senhor dos Céus S06 E61', 'http://sinalprivado.info:80/series/1533784/1533784/357840.mp4', 'https://image.tmdb.org/t/p/w300/9gBgtP0FWXygnKmi2XVZxuPE5RG.jpg'),
(74163, 5069, 'Senhor dos Céus S06 E62', 'http://sinalprivado.info:80/series/1533784/1533784/357841.mp4', 'https://image.tmdb.org/t/p/w300/4Nd37Y4ansY0IbSET7H5T61LTP9.jpg'),
(74164, 5069, 'Senhor dos Céus S06 E63', 'http://sinalprivado.info:80/series/1533784/1533784/357842.mp4', 'https://image.tmdb.org/t/p/w300/60kqGnnjpeEaXC9cRq7qPSPtaMP.jpg'),
(74165, 5069, 'Senhor dos Céus S06 E64', 'http://sinalprivado.info:80/series/1533784/1533784/357843.mp4', 'https://image.tmdb.org/t/p/w300/19bZFBHA9CcjSZoCDkpBWD9CKZ6.jpg'),
(74166, 5069, 'Senhor dos Céus S06 E65', 'http://sinalprivado.info:80/series/1533784/1533784/357844.mp4', 'https://image.tmdb.org/t/p/w300/l7XtU2HIOW2v25e4fPQrVTgf3G.jpg'),
(74167, 5069, 'Senhor dos Céus S06 E66', 'http://sinalprivado.info:80/series/1533784/1533784/357845.mp4', 'https://image.tmdb.org/t/p/w300/g9EjWeC1jQB7Q3jLrZkLDkeXadU.jpg'),
(74168, 5069, 'Senhor dos Céus S06 E67', 'http://sinalprivado.info:80/series/1533784/1533784/357846.mp4', 'https://image.tmdb.org/t/p/w300/mjQbbNtPJVAEuo8DnKnMdd8qDKn.jpg'),
(74169, 5069, 'Senhor dos Céus S06 E68', 'http://sinalprivado.info:80/series/1533784/1533784/357847.mp4', 'https://image.tmdb.org/t/p/w300/pqRbRsJMJwLsJt2eZr240hFtvj2.jpg'),
(74170, 5069, 'Senhor dos Céus S06 E69', 'http://sinalprivado.info:80/series/1533784/1533784/357848.mp4', 'https://image.tmdb.org/t/p/w300/uZPwpCdmFUo7MEKGIputH8cC6w0.jpg'),
(74171, 5069, 'Senhor dos Céus S06 E70', 'http://sinalprivado.info:80/series/1533784/1533784/357849.mp4', 'https://image.tmdb.org/t/p/w300/ypeHIErB8ufFXdWjBE9KybRqRoT.jpg'),
(74172, 5069, 'Senhor dos Céus S06 E71', 'http://sinalprivado.info:80/series/1533784/1533784/357850.mp4', 'https://image.tmdb.org/t/p/w300/oe9UU429bGDUgZok0L2drWDYhQl.jpg'),
(74173, 5069, 'Senhor dos Céus S06 E72', 'http://sinalprivado.info:80/series/1533784/1533784/357851.mp4', 'https://image.tmdb.org/t/p/w300/pwcmW0h9PuuON7gEHhRcefgHzLE.jpg'),
(74174, 5069, 'Senhor dos Céus S06 E73', 'http://sinalprivado.info:80/series/1533784/1533784/357852.mp4', 'https://image.tmdb.org/t/p/w300/jgZyOHuRsPXARXSWwwP5A9lVHMw.jpg'),
(74175, 5069, 'Senhor dos Céus S06 E74', 'http://sinalprivado.info:80/series/1533784/1533784/357853.mp4', 'https://image.tmdb.org/t/p/w300/okVuNxlmPOjPGwP4gM4uhHXwQ8M.jpg'),
(74176, 5069, 'Senhor dos Céus S06 E75', 'http://sinalprivado.info:80/series/1533784/1533784/357854.mp4', 'https://image.tmdb.org/t/p/w300/59QZ1TYFkvlP2QHimppaPPL28YK.jpg'),
(74177, 5069, 'Senhor dos Céus S06 E76', 'http://sinalprivado.info:80/series/1533784/1533784/357855.mp4', 'https://image.tmdb.org/t/p/w300/8GLl5cjTmc52En3Awn5adMvdZcT.jpg'),
(74178, 5069, 'Senhor dos Céus S06 E77', 'http://sinalprivado.info:80/series/1533784/1533784/357856.mp4', 'https://image.tmdb.org/t/p/w300/oSBU9fpujGoDlVJ7FikdWKABXj7.jpg'),
(74179, 5069, 'Senhor dos Céus S06 E78', 'http://sinalprivado.info:80/series/1533784/1533784/357857.mp4', 'https://image.tmdb.org/t/p/w300/d6P3KQSPi72oVX95hQJElGD0jyn.jpg'),
(74180, 5069, 'Senhor dos Céus S06 E79', 'http://sinalprivado.info:80/series/1533784/1533784/357858.mp4', 'https://image.tmdb.org/t/p/w300/3hVX4fq0pfzukcykGk96rjMJ6oO.jpg'),
(74181, 5069, 'Senhor dos Céus S06 E80', 'http://sinalprivado.info:80/series/1533784/1533784/357859.mp4', 'https://image.tmdb.org/t/p/w300/8rRdcfAiA5DBf2J8JcRQ8yB0Pf3.jpg'),
(74182, 5069, 'Senhor dos Céus S06 E81', 'http://sinalprivado.info:80/series/1533784/1533784/357860.mp4', 'https://image.tmdb.org/t/p/w300/q7CwXJwSF7g05GXz4Kqs3BG9xOL.jpg'),
(74183, 5069, 'Senhor dos Céus S06 E82', 'http://sinalprivado.info:80/series/1533784/1533784/357861.mp4', 'https://image.tmdb.org/t/p/w300/l7jSTCJBMXvQnXekKbcT15iEiDS.jpg'),
(74184, 5069, 'Senhor dos Céus S06 E83', 'http://sinalprivado.info:80/series/1533784/1533784/357862.mp4', 'https://image.tmdb.org/t/p/w300/hph4AkkMZOuXpkH3eOi7Drv1t4V.jpg'),
(74185, 5069, 'Senhor dos Céus S06 E84', 'http://sinalprivado.info:80/series/1533784/1533784/357863.mp4', 'https://image.tmdb.org/t/p/w300/pwLxNkFn3f43TCs9rV2GoIiK0CR.jpg'),
(74186, 5069, 'Senhor dos Céus S06 E85', 'http://sinalprivado.info:80/series/1533784/1533784/357864.mp4', 'https://image.tmdb.org/t/p/w300/anWMfEdU6dP5v7b8rg4dc23RyAK.jpg'),
(74187, 5069, 'Senhor dos Céus S06 E86', 'http://sinalprivado.info:80/series/1533784/1533784/357865.mp4', 'https://image.tmdb.org/t/p/w300/d6etrSGa6zVZLEle8iljD8C7xDG.jpg'),
(74188, 5069, 'Senhor dos Céus S06 E87', 'http://sinalprivado.info:80/series/1533784/1533784/357866.mp4', 'https://image.tmdb.org/t/p/w300/wvdT2OKzfKUYkl55CuqfBqz7AkH.jpg'),
(74189, 5069, 'Senhor dos Céus S06 E88', 'http://sinalprivado.info:80/series/1533784/1533784/357867.mp4', 'https://image.tmdb.org/t/p/w300/hkewJK7MpqrkHb6JBIPmjMixBSX.jpg'),
(74190, 5069, 'Senhor dos Céus S06 E89', 'http://sinalprivado.info:80/series/1533784/1533784/357868.mp4', 'https://image.tmdb.org/t/p/w300/4Du5TnMFvu8ru4ui8m1bSGkbhmz.jpg'),
(74191, 5069, 'Senhor dos Céus S06 E90', 'http://sinalprivado.info:80/series/1533784/1533784/357869.mp4', 'https://image.tmdb.org/t/p/w300/4RHbkAR86EowCUAhI3zjh2d5WMH.jpg'),
(74192, 5069, 'Senhor dos Céus S06 E91', 'http://sinalprivado.info:80/series/1533784/1533784/357870.mp4', 'https://image.tmdb.org/t/p/w300/8s71bOq5wBWdnTpoSq4r3sdJoGK.jpg'),
(74193, 5069, 'Senhor dos Céus S06 E92', 'http://sinalprivado.info:80/series/1533784/1533784/357871.mp4', 'https://image.tmdb.org/t/p/w300/68bO88dK3TUFI3wlUJ1X5t26QcP.jpg'),
(74194, 5069, 'Senhor dos Céus S06 E93', 'http://sinalprivado.info:80/series/1533784/1533784/357872.mp4', 'https://image.tmdb.org/t/p/w300/jC5ywlNhJtabkbYF6J4jKaSDPpF.jpg'),
(74195, 5069, 'Senhor dos Céus S06 E94', 'http://sinalprivado.info:80/series/1533784/1533784/357873.mp4', 'https://image.tmdb.org/t/p/w300/nddHBvp76lwaOCR7ymDPtQWzGn2.jpg'),
(74196, 5069, 'Senhor dos Céus S06 E95', 'http://sinalprivado.info:80/series/1533784/1533784/357874.mp4', 'https://image.tmdb.org/t/p/w300/4xVAaGBZUOOJkeLGQ8BMrekrqUR.jpg'),
(74197, 5069, 'Senhor dos Céus S06 E96', 'http://sinalprivado.info:80/series/1533784/1533784/357875.mp4', 'https://image.tmdb.org/t/p/w300/V10KiDtCF2VPVWuv6oi7IN3YUY.jpg'),
(74198, 5069, 'Senhor dos Céus S06 E97', 'http://sinalprivado.info:80/series/1533784/1533784/357876.mp4', 'https://image.tmdb.org/t/p/w300/lwm1hhA7BRQGL6HvkfLNexI0TGp.jpg'),
(74199, 5069, 'Senhor dos Céus S06 E98', 'http://sinalprivado.info:80/series/1533784/1533784/357877.mp4', 'https://image.tmdb.org/t/p/w300/qxKe7dxVZcchvU9CUQ0jyPCiaw.jpg'),
(74200, 5069, 'Senhor dos Céus S06 E99', 'http://sinalprivado.info:80/series/1533784/1533784/357878.mp4', 'https://image.tmdb.org/t/p/w300/mLk2pWXsoVXiDX1kihR5FMdLRQd.jpg'),
(74201, 5070, 'Senhor dos Céus S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/357879.mp4', 'https://image.tmdb.org/t/p/w300/zW5scXQSA4sgPmjkDkz1K5IdM2P.jpg'),
(74202, 5070, 'Senhor dos Céus S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/357880.mp4', 'https://image.tmdb.org/t/p/w300/zW5scXQSA4sgPmjkDkz1K5IdM2P.jpg'),
(74203, 5070, 'Senhor dos Céus S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/357881.mp4', 'https://image.tmdb.org/t/p/w300/zW5scXQSA4sgPmjkDkz1K5IdM2P.jpg'),
(74204, 5070, 'Senhor dos Céus S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/357882.mp4', 'https://image.tmdb.org/t/p/w300/zW5scXQSA4sgPmjkDkz1K5IdM2P.jpg'),
(74205, 5070, 'Senhor dos Céus S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/357883.mp4', 'https://image.tmdb.org/t/p/w300/zW5scXQSA4sgPmjkDkz1K5IdM2P.jpg'),
(74206, 5070, 'Senhor dos Céus S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/357884.mp4', 'https://image.tmdb.org/t/p/w300/zW5scXQSA4sgPmjkDkz1K5IdM2P.jpg'),
(74207, 5070, 'Senhor dos Céus S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/357885.mp4', 'https://image.tmdb.org/t/p/w300/7hiz3fmLydK60xY3iJr3ML8qInm.jpg'),
(74208, 5070, 'Senhor dos Céus S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/357886.mp4', 'https://image.tmdb.org/t/p/w300/6esMZUEjV1NtbIUBm0819cKe3fj.jpg'),
(74209, 5070, 'Senhor dos Céus S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/357887.mp4', 'https://image.tmdb.org/t/p/w300/2Hw3kqh557wQtewgERcLukeypz3.jpg'),
(74210, 5070, 'Senhor dos Céus S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/357888.mp4', 'https://image.tmdb.org/t/p/w300/36eRVKd5vdDDBVMNdw4NnRWQPpG.jpg'),
(74211, 5070, 'Senhor dos Céus S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/357889.mp4', 'https://image.tmdb.org/t/p/w300/mADjj2lrl5EGrYqewyUjQ3XboSx.jpg'),
(74212, 5070, 'Senhor dos Céus S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/357890.mp4', 'https://image.tmdb.org/t/p/w300/wtjWH4l2eG9znqYT4kyGYNZyxky.jpg'),
(74213, 5070, 'Senhor dos Céus S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/357891.mp4', 'https://image.tmdb.org/t/p/w300/kpmtQiFk3faFl2ndbujzzbWiWkP.jpg'),
(74214, 5070, 'Senhor dos Céus S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/357892.mp4', 'https://image.tmdb.org/t/p/w300/8sTw1bfFkKRBgHNTqzwmcvAAHvb.jpg'),
(74215, 5070, 'Senhor dos Céus S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/357893.mp4', 'https://image.tmdb.org/t/p/w300/8xRdNnXETDhbtJChUsfC71lpqQO.jpg'),
(74216, 5070, 'Senhor dos Céus S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/357894.mp4', 'https://image.tmdb.org/t/p/w300/oVXKxEjUinDTFVQ7bBMgoanU6US.jpg'),
(74217, 5070, 'Senhor dos Céus S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/357895.mp4', 'https://image.tmdb.org/t/p/w300/5Bki5T6BMUeHbXEueKV41M33sjk.jpg'),
(74218, 5070, 'Senhor dos Céus S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/357896.mp4', 'https://image.tmdb.org/t/p/w300/afQMk6nTwtR9ZQlyGGYpNeSzkmW.jpg'),
(74219, 5070, 'Senhor dos Céus S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/357897.mp4', 'https://image.tmdb.org/t/p/w300/2MQZxgo6ihlHZJ5aWFLaBCiErxM.jpg'),
(74220, 5070, 'Senhor dos Céus S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/357898.mp4', 'https://image.tmdb.org/t/p/w300/bKB3sQa5PTVYrrRcnjvgSicUCTw.jpg'),
(74221, 5070, 'Senhor dos Céus S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/357899.mp4', 'https://image.tmdb.org/t/p/w300/5u6maKrgKxbxFYLyYXsUaS3qPM.jpg'),
(74222, 5070, 'Senhor dos Céus S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/357900.mp4', 'https://image.tmdb.org/t/p/w300/8wlJ3FKESTgOANZ0j8oh05adgKT.jpg'),
(74223, 5070, 'Senhor dos Céus S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/357901.mp4', 'https://image.tmdb.org/t/p/w300/zdHNuS0gVQ8Wkj85AZzIL4lw3bg.jpg'),
(74224, 5070, 'Senhor dos Céus S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/357902.mp4', 'https://image.tmdb.org/t/p/w300/1wQ4d0iWza4SMhwro5ZlHL5ioRG.jpg'),
(74225, 5070, 'Senhor dos Céus S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/357903.mp4', 'https://image.tmdb.org/t/p/w300/j1Wv2fYVzfkxUwGMvRpBvMQTmnK.jpg'),
(74226, 5070, 'Senhor dos Céus S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/357904.mp4', 'https://image.tmdb.org/t/p/w300/7wwZBFjndk3AaV32rqlzFsJhG0y.jpg'),
(74227, 5070, 'Senhor dos Céus S07 E27', 'http://sinalprivado.info:80/series/1533784/1533784/357905.mp4', 'https://image.tmdb.org/t/p/w300/8S4wjtwlVfK3qKWH0goviBpyvl7.jpg'),
(74228, 5070, 'Senhor dos Céus S07 E28', 'http://sinalprivado.info:80/series/1533784/1533784/357906.mp4', 'https://image.tmdb.org/t/p/w300/iK1HTbWJ6xvjKv0fVD86eH2nEQj.jpg'),
(74229, 5070, 'Senhor dos Céus S07 E29', 'http://sinalprivado.info:80/series/1533784/1533784/357907.mp4', 'https://image.tmdb.org/t/p/w300/ayA0qLJloWu6vvScLpc53HGIHUS.jpg'),
(74230, 5070, 'Senhor dos Céus S07 E30', 'http://sinalprivado.info:80/series/1533784/1533784/357908.mp4', 'https://image.tmdb.org/t/p/w300/8C4ca1guA7c2EwsOgvD2UaOiH5p.jpg'),
(74231, 5070, 'Senhor dos Céus S07 E31', 'http://sinalprivado.info:80/series/1533784/1533784/357909.mp4', 'https://image.tmdb.org/t/p/w300/vBJnVFdDTNFjdRy1RABEhp9wtDq.jpg'),
(74232, 5070, 'Senhor dos Céus S07 E32', 'http://sinalprivado.info:80/series/1533784/1533784/357910.mp4', 'https://image.tmdb.org/t/p/w300/dG5YMX5aofyLMoRgVGITXekMVdJ.jpg'),
(74233, 5070, 'Senhor dos Céus S07 E33', 'http://sinalprivado.info:80/series/1533784/1533784/357911.mp4', 'https://image.tmdb.org/t/p/w300/7rfo9c3gMOuiaM2MQZzsw5zxny9.jpg'),
(74234, 5070, 'Senhor dos Céus S07 E34', 'http://sinalprivado.info:80/series/1533784/1533784/357912.mp4', 'https://image.tmdb.org/t/p/w300/sk3bojSWLsbf5pwMEl3NiHQHPN1.jpg'),
(74235, 5070, 'Senhor dos Céus S07 E35', 'http://sinalprivado.info:80/series/1533784/1533784/357913.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74236, 5070, 'Senhor dos Céus S07 E36', 'http://sinalprivado.info:80/series/1533784/1533784/357914.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74237, 5070, 'Senhor dos Céus S07 E37', 'http://sinalprivado.info:80/series/1533784/1533784/357915.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74238, 5070, 'Senhor dos Céus S07 E38', 'http://sinalprivado.info:80/series/1533784/1533784/357916.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74239, 5070, 'Senhor dos Céus S07 E39', 'http://sinalprivado.info:80/series/1533784/1533784/357917.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74240, 5070, 'Senhor dos Céus S07 E40', 'http://sinalprivado.info:80/series/1533784/1533784/357918.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74241, 5070, 'Senhor dos Céus S07 E41', 'http://sinalprivado.info:80/series/1533784/1533784/357919.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74242, 5070, 'Senhor dos Céus S07 E42', 'http://sinalprivado.info:80/series/1533784/1533784/357920.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74243, 5070, 'Senhor dos Céus S07 E43', 'http://sinalprivado.info:80/series/1533784/1533784/357921.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74244, 5070, 'Senhor dos Céus S07 E44', 'http://sinalprivado.info:80/series/1533784/1533784/357922.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74245, 5070, 'Senhor dos Céus S07 E45', 'http://sinalprivado.info:80/series/1533784/1533784/357923.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74246, 5070, 'Senhor dos Céus S07 E46', 'http://sinalprivado.info:80/series/1533784/1533784/357924.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74247, 5070, 'Senhor dos Céus S07 E47', 'http://sinalprivado.info:80/series/1533784/1533784/357925.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74248, 5070, 'Senhor dos Céus S07 E48', 'http://sinalprivado.info:80/series/1533784/1533784/357926.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74249, 5070, 'Senhor dos Céus S07 E49', 'http://sinalprivado.info:80/series/1533784/1533784/357927.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74250, 5070, 'Senhor dos Céus S07 E50', 'http://sinalprivado.info:80/series/1533784/1533784/357928.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74251, 5070, 'Senhor dos Céus S07 E51', 'http://sinalprivado.info:80/series/1533784/1533784/357929.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74252, 5070, 'Senhor dos Céus S07 E52', 'http://sinalprivado.info:80/series/1533784/1533784/357930.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74253, 5070, 'Senhor dos Céus S07 E53', 'http://sinalprivado.info:80/series/1533784/1533784/357931.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74254, 5070, 'Senhor dos Céus S07 E54', 'http://sinalprivado.info:80/series/1533784/1533784/357932.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74255, 5070, 'Senhor dos Céus S07 E55', 'http://sinalprivado.info:80/series/1533784/1533784/357933.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74256, 5070, 'Senhor dos Céus S07 E56', 'http://sinalprivado.info:80/series/1533784/1533784/357934.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74257, 5070, 'Senhor dos Céus S07 E57', 'http://sinalprivado.info:80/series/1533784/1533784/357935.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74258, 5070, 'Senhor dos Céus S07 E58', 'http://sinalprivado.info:80/series/1533784/1533784/357936.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74259, 5070, 'Senhor dos Céus S07 E59', 'http://sinalprivado.info:80/series/1533784/1533784/357937.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74260, 5070, 'Senhor dos Céus S07 E60', 'http://sinalprivado.info:80/series/1533784/1533784/357938.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74261, 5070, 'Senhor dos Céus S07 E61', 'http://sinalprivado.info:80/series/1533784/1533784/357939.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74262, 5070, 'Senhor dos Céus S07 E62', 'http://sinalprivado.info:80/series/1533784/1533784/357940.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74263, 5070, 'Senhor dos Céus S07 E63', 'http://sinalprivado.info:80/series/1533784/1533784/357941.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74264, 5070, 'Senhor dos Céus S07 E64', 'http://sinalprivado.info:80/series/1533784/1533784/357942.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74265, 5070, 'Senhor dos Céus S07 E65', 'http://sinalprivado.info:80/series/1533784/1533784/357943.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74266, 5070, 'Senhor dos Céus S07 E66', 'http://sinalprivado.info:80/series/1533784/1533784/357944.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74267, 5070, 'Senhor dos Céus S07 E67', 'http://sinalprivado.info:80/series/1533784/1533784/357945.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74268, 5070, 'Senhor dos Céus S07 E68', 'http://sinalprivado.info:80/series/1533784/1533784/357946.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74269, 5070, 'Senhor dos Céus S07 E69', 'http://sinalprivado.info:80/series/1533784/1533784/357947.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74270, 5070, 'Senhor dos Céus S07 E70', 'http://sinalprivado.info:80/series/1533784/1533784/357948.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74271, 5070, 'Senhor dos Céus S07 E71', 'http://sinalprivado.info:80/series/1533784/1533784/357949.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74272, 5070, 'Senhor dos Céus S07 E72', 'http://sinalprivado.info:80/series/1533784/1533784/357950.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74273, 5070, 'Senhor dos Céus S07 E73', 'http://sinalprivado.info:80/series/1533784/1533784/357951.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74274, 5070, 'Senhor dos Céus S07 E74', 'http://sinalprivado.info:80/series/1533784/1533784/357952.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74275, 5070, 'Senhor dos Céus S07 E75', 'http://sinalprivado.info:80/series/1533784/1533784/357953.mp4', 'https://image.tmdb.org/t/p/w300/x3e8gfWPm79FllQ9jEP1TqslqMU.jpg'),
(74276, 5070, 'Senhor dos Céus S07 E76', 'http://sinalprivado.info:80/series/1533784/1533784/357954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ag7VUdnrRz5Qpq3Yn3E5OCvFnu0.jpg'),
(74277, 5071, 'Arlequina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8DMfVxiyVOIPsB5YLqWyZMaT5p.jpg'),
(74278, 5071, 'Arlequina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fbQu2Z9tLTYDIN14NwSbcG1gBdw.jpg'),
(74279, 5071, 'Arlequina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ccS92LvZovvVCRJgNKIaw4GnqMQ.jpg'),
(74280, 5071, 'Arlequina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pnod1diLLRYlIAi3vqiauU91YvD.jpg'),
(74281, 5071, 'Arlequina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k2FuGFmTjkttoQVafXAuFteVgkU.jpg'),
(74282, 5071, 'Arlequina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jUoXH5Jqm45hP07SVuGkiPiR43u.jpg'),
(74283, 5071, 'Arlequina S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJCJUuvfJoFdlU4irZqxJM7zN4S.jpg'),
(74284, 5071, 'Arlequina S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8pp0i88OgrgcKScZ981niYwRB8.jpg'),
(74285, 5071, 'Arlequina S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8RqEhuhPQBxGB9PgJ1ygD0gt2c.jpg'),
(74286, 5071, 'Arlequina S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xVGhRWBqqA47eRHcCy4rw4jNpOT.jpg'),
(74287, 5071, 'Arlequina S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rRcaL58yiuVzRWYu1rTNOa6ux7Z.jpg'),
(74288, 5071, 'Arlequina S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/diLwX1RYjisUA6NjL4XL3DidGGB.jpg'),
(74289, 5071, 'Arlequina S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/232032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/84kLcZ2e3pjjeX5SWcQtruIyYNK.jpg'),
(74290, 5072, 'Arlequina S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zDU0f5wB2yXtgP39FuEbbEongGR.jpg'),
(74291, 5072, 'Arlequina S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3TkkcyqZeIH5N5wJZ377BOXmIqF.jpg'),
(74292, 5072, 'Arlequina S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11zkBxYBO6pxL6cHkVfIYrtdgjV.jpg'),
(74293, 5072, 'Arlequina S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4mAA8mcOtcmm7JGrfRIg2iGhJpp.jpg'),
(74294, 5072, 'Arlequina S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aA3OcRJWXZaorNOl69nunhuxVD3.jpg'),
(74295, 5072, 'Arlequina S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jpULlKZxRFBPTAALnfztUH5nFP5.jpg'),
(74296, 5072, 'Arlequina S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6jyBpgFShlsu3lPfmoagwGGHoVi.jpg'),
(74297, 5072, 'Arlequina S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pV7e0JbcJb5sVb5q16IgBzBZ0YR.jpg'),
(74298, 5072, 'Arlequina S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qKGR65tXsrAOdqLumyXf5BB9JlL.jpg'),
(74299, 5072, 'Arlequina S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uRtki2qIyHEt0iYciaE78E44ncI.jpg'),
(74300, 5072, 'Arlequina S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6w6hJD391szNzpuXurPgqOoNkX7.jpg'),
(74301, 5072, 'Arlequina S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d6pO7gqrWbUdZevNdJXiLMtiDmZ.jpg'),
(74302, 5072, 'Arlequina S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/232045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8HzE91LtQyL85iKpQOtb5Uc7R5O.jpg'),
(74303, 5073, 'Arlequina S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tpmECRzhXPf6jNPp3GrX9vD7Vpz.jpg'),
(74304, 5073, 'Arlequina S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sPEltOadXGMgeMvlCanKNa7Fw46.jpg'),
(74305, 5073, 'Arlequina S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzQ8lyeNetbwirQTqdIEqiR69aA.jpg'),
(74306, 5073, 'Arlequina S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tFF4CEKZHEfesARNJ94tXrlylwQ.jpg'),
(74307, 5073, 'Arlequina S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a7HPhlzQL6mv5CgSDwChLTx0xLw.jpg'),
(74308, 5073, 'Arlequina S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rmzf0NIxnnC3tJO7kzCVh9v5FXl.jpg'),
(74309, 5073, 'Arlequina S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/atE5RdfRq2QAWP5Xa5zQtUEQL0R.jpg'),
(74310, 5073, 'Arlequina S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f8owjce2zqE9v849bE4S88g8gsH.jpg'),
(74311, 5073, 'Arlequina S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kR6LOTUWx60ORZQuRuMCYgi2tLx.jpg'),
(74312, 5073, 'Arlequina S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lv4otwXHZljAOGKRlMmsanzKngs.jpg'),
(74313, 5073, 'Arlequina S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tXOfLcGBbIBBCWn7NQXmm89JNXa.jpg'),
(74314, 5074, 'Arlequina S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/isvqACkGEzQUOAT2ZtNDt5HtuEZ.jpg'),
(74315, 5074, 'Arlequina S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cnhaiPtFoSgEl72I2va9drKproO.jpg'),
(74316, 5074, 'Arlequina S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ALMPyxyRxr6RR5oiOU21qc7EXt.jpg'),
(74317, 5074, 'Arlequina S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232060.mp4', 'http://image.tmdb.org/t/p/w1280/bhE9nZLprMw5qebJaaSaySPg6qd.jpg'),
(74318, 5074, 'Arlequina S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232061.mp4', 'http://image.tmdb.org/t/p/w1280/nWPMQriu0ndTPzzbCADGZvVVkIA.jpg'),
(74319, 5074, 'Arlequina S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232062.mp4', 'http://image.tmdb.org/t/p/w1280/4y4a2CtVTZ8e6KZ9rHpChcBgLB4.jpg'),
(74320, 5074, 'Arlequina S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232063.mp4', 'http://image.tmdb.org/t/p/w1280/yaRA5E903KlI3SjhJwGYCi0w2fo.jpg'),
(74321, 5074, 'Arlequina S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232064.mp4', 'http://image.tmdb.org/t/p/w1280/qgFJPiQ2fo4safwg7sZfrb3uWlK.jpg'),
(74322, 5074, 'Arlequina S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232065.mp4', 'http://image.tmdb.org/t/p/w1280/d7MtoIkR1AcEzQZkrqldKJrvspE.jpg'),
(74323, 5075, 'Arlequina S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/665926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bl4hQISOR5QNu4cITDuN1E4zLAJ.jpg'),
(74324, 5075, 'Arlequina S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/677795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bl4hQISOR5QNu4cITDuN1E4zLAJ.jpg'),
(74325, 5075, 'Arlequina S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/681032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bl4hQISOR5QNu4cITDuN1E4zLAJ.jpg'),
(74326, 5075, 'Arlequina S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/687868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bl4hQISOR5QNu4cITDuN1E4zLAJ.jpg'),
(74327, 5075, 'Arlequina S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/696327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bl4hQISOR5QNu4cITDuN1E4zLAJ.jpg'),
(74328, 5075, 'Arlequina S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/703202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bl4hQISOR5QNu4cITDuN1E4zLAJ.jpg'),
(74329, 5075, 'Arlequina S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/708049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bl4hQISOR5QNu4cITDuN1E4zLAJ.jpg'),
(74330, 5075, 'Arlequina S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/719190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bl4hQISOR5QNu4cITDuN1E4zLAJ.jpg'),
(74331, 5075, 'Arlequina S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/725346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bl4hQISOR5QNu4cITDuN1E4zLAJ.jpg'),
(74332, 5075, 'Arlequina S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/731670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bl4hQISOR5QNu4cITDuN1E4zLAJ.jpg'),
(74333, 5076, 'A Negociadora S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8YGDknHj1Z0fFq5ct2aR6ASYum9.jpg'),
(74334, 5076, 'A Negociadora S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rn2AUFf2I0AjkklsJNfa0TOThGW.jpg'),
(74335, 5076, 'A Negociadora S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lBCddl2VvN7Z8Y1QoA5jRgCnauh.jpg'),
(74336, 5076, 'A Negociadora S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfInOgufRHu5YsKtebgO3alym1b.jpg'),
(74337, 5076, 'A Negociadora S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uq8ftrILD6XqcRNudrQrg1eahS7.jpg'),
(74338, 5076, 'A Negociadora S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uWliV0fWN9DX0n1jevSzf8QqSfk.jpg'),
(74339, 5076, 'A Negociadora S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p8xfi1YokOkDv0kz27n6hNV1lxr.jpg'),
(74340, 5076, 'A Negociadora S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ihRDLTmLHE263Sq1ED4XKxEF3w.jpg'),
(74341, 5076, 'A Negociadora S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uyf7hOwQ6BqwX0nPtT5RL4UMnjI.jpg'),
(74342, 5076, 'A Negociadora S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ae7aRdnH9SpbYkWKadmh6l9LMa.jpg'),
(74343, 5076, 'A Negociadora S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/169393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wSBbcqESD33p6T7W3YkrN2wqvJt.jpg'),
(74344, 5076, 'A Negociadora S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/169394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cqxWZSYxuJqe9rYwjzhJm1Au3tV.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(74345, 5077, 'Batalha das Comidinhas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27DXPlKE4bcsalvgzPg8FvkNogE.jpg'),
(74346, 5077, 'Batalha das Comidinhas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27DXPlKE4bcsalvgzPg8FvkNogE.jpg'),
(74347, 5077, 'Batalha das Comidinhas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27DXPlKE4bcsalvgzPg8FvkNogE.jpg'),
(74348, 5077, 'Batalha das Comidinhas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27DXPlKE4bcsalvgzPg8FvkNogE.jpg'),
(74349, 5077, 'Batalha das Comidinhas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27DXPlKE4bcsalvgzPg8FvkNogE.jpg'),
(74350, 5077, 'Batalha das Comidinhas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27DXPlKE4bcsalvgzPg8FvkNogE.jpg'),
(74351, 5078, 'Búnker S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uISmYkqDEuIpGkcabttJuF2plaO.jpg'),
(74352, 5078, 'Búnker S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hAOv4Yn5l5gQQwZ7RIXTsP9kKn7.jpg'),
(74353, 5078, 'Búnker S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/veeTDLZ8ZIkwiigwfngwtvmFRJz.jpg'),
(74354, 5078, 'Búnker S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6utljg4tIhIezYoIxcFD5umJ0Ai.jpg'),
(74355, 5078, 'Búnker S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEIkyQTIAS8y1iL8O5SnaCDTS6.jpg'),
(74356, 5078, 'Búnker S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fHzW07X5YzPRhiLAlkZ5gkAeA26.jpg'),
(74357, 5078, 'Búnker S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8wop8MHh6Z7mD90EREd33XramAL.jpg'),
(74358, 5078, 'Búnker S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hCrLf2ElgYgDqLyU9cV0ktZ7F0j.jpg'),
(74359, 5079, 'Como Acabar Com o Natal: O Casamento S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/556483.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kfQBBBUgLqj5iPphvy5HtCZ76VJ.jpg'),
(74360, 5079, 'Como Acabar Com o Natal: O Casamento S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/556485.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3L3ZCQLGdVL34NlmaMv8olda9s8.jpg'),
(74361, 5079, 'Como Acabar Com o Natal: O Casamento S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/556487.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4amLw6N0wPt2AoZkwLIOnULAcjt.jpg'),
(74362, 5079, 'Como Acabar Com o Natal: O Casamento S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uwzQsjOO7tcw6zfDtkzlH5UyXV.jpg'),
(74363, 5080, 'Dopesick S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3NZlgalDbq1vjPa8pC5mj4UQRr3.jpg'),
(74364, 5080, 'Dopesick S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mX2rXthM4L38RSkVRDoWPu2ZePT.jpg'),
(74365, 5080, 'Dopesick S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2jNlGPhxkYL1C4vgohWhoXzGfiJ.jpg'),
(74366, 5080, 'Dopesick S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5GHqObCDh2sAetwxRjQoC4o2yd8.jpg'),
(74367, 5080, 'Dopesick S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dnfpZudATzp3ZeP6GF4iUfr71Jd.jpg'),
(74368, 5080, 'Dopesick S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfW6ksCiOjEjzHV2jhybR4bhJLz.jpg'),
(74369, 5080, 'Dopesick S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gauWgbzQWjV57vyIs6DNdWCsFKC.jpg'),
(74370, 5080, 'Dopesick S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gl5LteQDwv4kT2aGO2kmIQDVf8H.jpg'),
(74371, 5081, 'Exterminadores do Além S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CPEbp4Yrk8XXGd6FmRFKDWSnLy.jpg'),
(74372, 5081, 'Exterminadores do Além S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CPEbp4Yrk8XXGd6FmRFKDWSnLy.jpg'),
(74373, 5081, 'Exterminadores do Além S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CPEbp4Yrk8XXGd6FmRFKDWSnLy.jpg'),
(74374, 5081, 'Exterminadores do Além S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CPEbp4Yrk8XXGd6FmRFKDWSnLy.jpg'),
(74375, 5081, 'Exterminadores do Além S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CPEbp4Yrk8XXGd6FmRFKDWSnLy.jpg'),
(74376, 5081, 'Exterminadores do Além S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CPEbp4Yrk8XXGd6FmRFKDWSnLy.jpg'),
(74377, 5081, 'Exterminadores do Além S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CPEbp4Yrk8XXGd6FmRFKDWSnLy.jpg'),
(74378, 5081, 'Exterminadores do Além S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CPEbp4Yrk8XXGd6FmRFKDWSnLy.jpg'),
(74379, 5081, 'Exterminadores do Além S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CPEbp4Yrk8XXGd6FmRFKDWSnLy.jpg'),
(74380, 5081, 'Exterminadores do Além S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CPEbp4Yrk8XXGd6FmRFKDWSnLy.jpg'),
(74381, 5082, 'Largados e Pelados: A Tribo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3codUxJO7JSvB1cHYlRPPmILSv5.jpg'),
(74382, 5082, 'Largados e Pelados: A Tribo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3codUxJO7JSvB1cHYlRPPmILSv5.jpg'),
(74383, 5082, 'Largados e Pelados: A Tribo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3codUxJO7JSvB1cHYlRPPmILSv5.jpg'),
(74384, 5082, 'Largados e Pelados: A Tribo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3codUxJO7JSvB1cHYlRPPmILSv5.jpg'),
(74385, 5082, 'Largados e Pelados: A Tribo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3codUxJO7JSvB1cHYlRPPmILSv5.jpg'),
(74386, 5082, 'Largados e Pelados: A Tribo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3codUxJO7JSvB1cHYlRPPmILSv5.jpg'),
(74387, 5082, 'Largados e Pelados: A Tribo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3codUxJO7JSvB1cHYlRPPmILSv5.jpg'),
(74388, 5082, 'Largados e Pelados: A Tribo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPROVBi59tgdfpfsvzCMYj6GppO.jpg'),
(74389, 5082, 'Largados e Pelados: A Tribo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3codUxJO7JSvB1cHYlRPPmILSv5.jpg'),
(74390, 5083, 'Largados e Pelados: A Tribo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3codUxJO7JSvB1cHYlRPPmILSv5.jpg'),
(74391, 5083, 'Largados e Pelados: A Tribo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3codUxJO7JSvB1cHYlRPPmILSv5.jpg'),
(74392, 5083, 'Largados e Pelados: A Tribo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3codUxJO7JSvB1cHYlRPPmILSv5.jpg'),
(74393, 5083, 'Largados e Pelados: A Tribo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3codUxJO7JSvB1cHYlRPPmILSv5.jpg'),
(74394, 5083, 'Largados e Pelados: A Tribo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3codUxJO7JSvB1cHYlRPPmILSv5.jpg'),
(74395, 5083, 'Largados e Pelados: A Tribo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3codUxJO7JSvB1cHYlRPPmILSv5.jpg'),
(74396, 5083, 'Largados e Pelados: A Tribo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3codUxJO7JSvB1cHYlRPPmILSv5.jpg'),
(74397, 5083, 'Largados e Pelados: A Tribo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3codUxJO7JSvB1cHYlRPPmILSv5.jpg'),
(74398, 5083, 'Largados e Pelados: A Tribo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wEotfAH7S2BWHUkNaG17Pot1y83.jpg'),
(74399, 5084, 'Largados e Pelados: A Tribo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oM1viDggOXQgL63ibdpDt7FeTN2.jpg'),
(74400, 5084, 'Largados e Pelados: A Tribo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OTAhUSrPiZJuTyNNb4gpq4SLGp.jpg'),
(74401, 5084, 'Largados e Pelados: A Tribo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OTAhUSrPiZJuTyNNb4gpq4SLGp.jpg'),
(74402, 5084, 'Largados e Pelados: A Tribo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OTAhUSrPiZJuTyNNb4gpq4SLGp.jpg'),
(74403, 5084, 'Largados e Pelados: A Tribo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OTAhUSrPiZJuTyNNb4gpq4SLGp.jpg'),
(74404, 5084, 'Largados e Pelados: A Tribo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OTAhUSrPiZJuTyNNb4gpq4SLGp.jpg'),
(74405, 5084, 'Largados e Pelados: A Tribo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OTAhUSrPiZJuTyNNb4gpq4SLGp.jpg'),
(74406, 5084, 'Largados e Pelados: A Tribo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OTAhUSrPiZJuTyNNb4gpq4SLGp.jpg'),
(74407, 5084, 'Largados e Pelados: A Tribo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74408, 5084, 'Largados e Pelados: A Tribo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OTAhUSrPiZJuTyNNb4gpq4SLGp.jpg'),
(74409, 5085, 'Largados e Pelados: A Tribo S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74410, 5085, 'Largados e Pelados: A Tribo S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74411, 5085, 'Largados e Pelados: A Tribo S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74412, 5085, 'Largados e Pelados: A Tribo S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74413, 5085, 'Largados e Pelados: A Tribo S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74414, 5085, 'Largados e Pelados: A Tribo S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74415, 5085, 'Largados e Pelados: A Tribo S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74416, 5085, 'Largados e Pelados: A Tribo S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74417, 5085, 'Largados e Pelados: A Tribo S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74418, 5085, 'Largados e Pelados: A Tribo S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74419, 5085, 'Largados e Pelados: A Tribo S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74420, 5086, 'Largados e Pelados: A Tribo S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3codUxJO7JSvB1cHYlRPPmILSv5.jpg'),
(74421, 5086, 'Largados e Pelados: A Tribo S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74422, 5086, 'Largados e Pelados: A Tribo S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74423, 5086, 'Largados e Pelados: A Tribo S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74424, 5086, 'Largados e Pelados: A Tribo S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74425, 5086, 'Largados e Pelados: A Tribo S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74426, 5086, 'Largados e Pelados: A Tribo S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74427, 5086, 'Largados e Pelados: A Tribo S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74428, 5086, 'Largados e Pelados: A Tribo S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74429, 5086, 'Largados e Pelados: A Tribo S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74430, 5086, 'Largados e Pelados: A Tribo S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74431, 5087, 'Largados e Pelados: A Tribo S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74432, 5087, 'Largados e Pelados: A Tribo S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74433, 5087, 'Largados e Pelados: A Tribo S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74434, 5087, 'Largados e Pelados: A Tribo S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74435, 5087, 'Largados e Pelados: A Tribo S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74436, 5087, 'Largados e Pelados: A Tribo S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74437, 5087, 'Largados e Pelados: A Tribo S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74438, 5087, 'Largados e Pelados: A Tribo S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74439, 5087, 'Largados e Pelados: A Tribo S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74440, 5087, 'Largados e Pelados: A Tribo S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74441, 5087, 'Largados e Pelados: A Tribo S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74442, 5088, 'Largados e Pelados: A Tribo S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74443, 5088, 'Largados e Pelados: A Tribo S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74444, 5088, 'Largados e Pelados: A Tribo S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74445, 5088, 'Largados e Pelados: A Tribo S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74446, 5088, 'Largados e Pelados: A Tribo S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74447, 5088, 'Largados e Pelados: A Tribo S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74448, 5088, 'Largados e Pelados: A Tribo S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74449, 5088, 'Largados e Pelados: A Tribo S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74450, 5088, 'Largados e Pelados: A Tribo S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74451, 5088, 'Largados e Pelados: A Tribo S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74452, 5089, 'Largados e Pelados: A Tribo S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74453, 5089, 'Largados e Pelados: A Tribo S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74454, 5089, 'Largados e Pelados: A Tribo S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74455, 5089, 'Largados e Pelados: A Tribo S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74456, 5089, 'Largados e Pelados: A Tribo S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74457, 5089, 'Largados e Pelados: A Tribo S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74458, 5089, 'Largados e Pelados: A Tribo S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74459, 5089, 'Largados e Pelados: A Tribo S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74460, 5089, 'Largados e Pelados: A Tribo S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74461, 5089, 'Largados e Pelados: A Tribo S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74462, 5090, 'Largados e Pelados: A Tribo S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/292247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74463, 5090, 'Largados e Pelados: A Tribo S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/292248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74464, 5090, 'Largados e Pelados: A Tribo S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/292249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74465, 5090, 'Largados e Pelados: A Tribo S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/292250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74466, 5090, 'Largados e Pelados: A Tribo S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/292251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74467, 5090, 'Largados e Pelados: A Tribo S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/292252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74468, 5091, 'Largados e Pelados: A Tribo S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/460949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74469, 5091, 'Largados e Pelados: A Tribo S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/460950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74470, 5091, 'Largados e Pelados: A Tribo S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/474207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74471, 5091, 'Largados e Pelados: A Tribo S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/474208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74472, 5091, 'Largados e Pelados: A Tribo S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/474209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74473, 5091, 'Largados e Pelados: A Tribo S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/477988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74474, 5091, 'Largados e Pelados: A Tribo S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/489021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74475, 5091, 'Largados e Pelados: A Tribo S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/493646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlJg6QLXqK1RrucEe72u9mHbuj2.jpg'),
(74476, 5092, 'Medicina do Amanhã S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uyIVyNvbDcP41EAyfFAae1Ch5Ns.jpg'),
(74477, 5092, 'Medicina do Amanhã S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kEd7rpL4D8BQplfjPFA3SAEC6ya.jpg'),
(74478, 5092, 'Medicina do Amanhã S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lLRWRhDiASEpn9SLgpnMMlAcl2w.jpg'),
(74479, 5093, 'Motherland: Fort Salem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iDyJFG8pxNM3hbIyIFuCLQy5WaN.jpg'),
(74480, 5093, 'Motherland: Fort Salem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zjX6jAYkM77ILq71er7g9dNct9V.jpg'),
(74481, 5093, 'Motherland: Fort Salem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qivlUdP3k6RFfQHg18SMpmRH7gn.jpg'),
(74482, 5093, 'Motherland: Fort Salem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nRpW07XPE9hqoNyPSVy9FmjahLY.jpg'),
(74483, 5093, 'Motherland: Fort Salem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/abxtxcm2UlvjCXK5LX85CvR2gXJ.jpg'),
(74484, 5093, 'Motherland: Fort Salem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6fMOCnuESZ3OidFwUnnA1wlM11P.jpg'),
(74485, 5093, 'Motherland: Fort Salem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4eru52I2BEjBiUoGwYpOQaELBIa.jpg'),
(74486, 5093, 'Motherland: Fort Salem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k6GPBGR6WhPY7ChQkTlB6ywKkKd.jpg'),
(74487, 5093, 'Motherland: Fort Salem S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shUnFh9BiUbKlsfEco6BZJis4p0.jpg'),
(74488, 5093, 'Motherland: Fort Salem S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/unBop6Cg7FQsPVZoCQTNpbgrqDE.jpg'),
(74489, 5094, 'Motherland: Fort Salem S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wdswFcIZCeDmxHhRoyb4mKol2m6.jpg'),
(74490, 5094, 'Motherland: Fort Salem S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gG4CKBA6RGLKB5olEnGKgylXJiA.jpg'),
(74491, 5094, 'Motherland: Fort Salem S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xl1KcYfVVfNcfrr3RbOYJFP99Id.jpg'),
(74492, 5094, 'Motherland: Fort Salem S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8N4rY4tCigzEkjtmJukhLJNs55d.jpg'),
(74493, 5094, 'Motherland: Fort Salem S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pLdvFsXKOJw1HeiXbCFCuvPmdwQ.jpg'),
(74494, 5094, 'Motherland: Fort Salem S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2XQYfaR1a5oC4c9NcvDGhvauX0h.jpg'),
(74495, 5094, 'Motherland: Fort Salem S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y7va5lYczcJc7EHLmyNpNfo5ulx.jpg'),
(74496, 5094, 'Motherland: Fort Salem S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iAuOClmwwdZRQyV9Fu0EUBq66TT.jpg'),
(74497, 5094, 'Motherland: Fort Salem S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ydWe5sqCeS77eBOYpFXxSCBL0DB.jpg'),
(74498, 5094, 'Motherland: Fort Salem S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k14BA9qGIUPhAbifeQZZMyQfQtb.jpg'),
(74499, 5095, 'Motherland: Fort Salem S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x4JQjM9k260tJphWdmahGzIAtnx.jpg'),
(74500, 5095, 'Motherland: Fort Salem S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vTynS8aDHUVVCoZt8GAwU8nf7F5.jpg'),
(74501, 5095, 'Motherland: Fort Salem S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uvoDyHD7m9PKWDlhQQG3PHNonbR.jpg'),
(74502, 5095, 'Motherland: Fort Salem S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n8BR8bXvXio5sKuwIORlmBXo0k2.jpg'),
(74503, 5095, 'Motherland: Fort Salem S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v6mWug8xFC9y5wBtW5VCBDX69Qu.jpg'),
(74504, 5095, 'Motherland: Fort Salem S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8TSYZNuBiRyoqTTaPv7BolFM039.jpg'),
(74505, 5095, 'Motherland: Fort Salem S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Hv1RKXBxliYrjAbNtZmHbcptO5.jpg'),
(74506, 5095, 'Motherland: Fort Salem S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8HukI7ucoOvqo9IlimzityT12BY.jpg'),
(74507, 5095, 'Motherland: Fort Salem S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y8vAXW3hRbTYFaMdQJO0InQocpI.jpg'),
(74508, 5095, 'Motherland: Fort Salem S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8JRdlO0g7uVfLHIbP9NJUgzRHK0.jpg'),
(74509, 5096, 'O Mar da Tranquilidade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AdG8blABuieEGZdjRYGOP7Dbhbq.jpg'),
(74510, 5096, 'O Mar da Tranquilidade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5wYeFz4bWpSgLlWszBMeFBwneSE.jpg'),
(74511, 5096, 'O Mar da Tranquilidade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dGUWIXwzmgFb3q9WuJYCUJBP5vj.jpg'),
(74512, 5096, 'O Mar da Tranquilidade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5CaOEDfpPe7j7q6ZcwnLPRXssT3.jpg'),
(74513, 5096, 'O Mar da Tranquilidade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A6aGL8UUg4F6nM0wwLQ4VHP2aRK.jpg'),
(74514, 5096, 'O Mar da Tranquilidade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p4cgfTIQkFiD0MM7fV9t2jjEFkY.jpg'),
(74515, 5096, 'O Mar da Tranquilidade S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rs8upkqqBy0UG73t8Jc0nUy1tUZ.jpg'),
(74516, 5096, 'O Mar da Tranquilidade S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2NEd4739dHM0RxbVn59Ck5yEOx.jpg'),
(74517, 5097, 'O Show do Sábado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ijvrap65jjZvxNeJ4Qi2C4eOxBL.jpg'),
(74518, 5097, 'O Show do Sábado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1CMBocvufRpzWuHF4MM3yKFIG9b.jpg'),
(74519, 5097, 'O Show do Sábado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7sakq7vqWlkJCHkyvR1CRSUEbaI.jpg'),
(74520, 5097, 'O Show do Sábado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AiQtzGrq5xlG1gjKo4TJ5lT0tmc.jpg'),
(74521, 5097, 'O Show do Sábado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wbgTmSTfOWWangxEqqfsIdvqa2g.jpg'),
(74522, 5097, 'O Show do Sábado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x0YPorCTwmA1AsJsrHlADSBpOEy.jpg'),
(74523, 5097, 'O Show do Sábado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kJFxxnCreBZ1Kjoffa6ZLxiRN4k.jpg'),
(74524, 5097, 'O Show do Sábado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6h4WkatAse0JnCG04yWxPZ1SeuG.jpg'),
(74525, 5098, 'Os Mãos de Vaca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jKAtgTtXKEHYpvfitgxZoNr7kEh.jpg'),
(74526, 5098, 'Os Mãos de Vaca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7CbP7jVFUYyB4MJWUiSqrDL3Hbp.jpg'),
(74527, 5098, 'Os Mãos de Vaca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mJbPIJ3uD782ZuNZfNPuk7eh4SP.jpg'),
(74528, 5098, 'Os Mãos de Vaca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3aeXLGXIAOpFjx0u5ocjKx2v3iX.jpg'),
(74529, 5098, 'Os Mãos de Vaca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hswdFMFKJv21i2BNbRX4OA9zfOF.jpg'),
(74530, 5098, 'Os Mãos de Vaca S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f1tfEBziex3ORMKQDTCEp7aEbz4.jpg'),
(74531, 5099, 'Óvnis: Investigação Secreta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nvg32rnkTLvc6sU2CPv9FlhoCaj.jpg'),
(74532, 5099, 'Óvnis: Investigação Secreta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nvg32rnkTLvc6sU2CPv9FlhoCaj.jpg'),
(74533, 5099, 'Óvnis: Investigação Secreta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nvg32rnkTLvc6sU2CPv9FlhoCaj.jpg'),
(74534, 5099, 'Óvnis: Investigação Secreta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nvg32rnkTLvc6sU2CPv9FlhoCaj.jpg'),
(74535, 5099, 'Óvnis: Investigação Secreta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nvg32rnkTLvc6sU2CPv9FlhoCaj.jpg'),
(74536, 5099, 'Óvnis: Investigação Secreta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nvg32rnkTLvc6sU2CPv9FlhoCaj.jpg'),
(74537, 5100, 'Óvnis: Investigação Secreta S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nvg32rnkTLvc6sU2CPv9FlhoCaj.jpg'),
(74538, 5100, 'Óvnis: Investigação Secreta S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nvg32rnkTLvc6sU2CPv9FlhoCaj.jpg'),
(74539, 5100, 'Óvnis: Investigação Secreta S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nvg32rnkTLvc6sU2CPv9FlhoCaj.jpg'),
(74540, 5100, 'Óvnis: Investigação Secreta S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nvg32rnkTLvc6sU2CPv9FlhoCaj.jpg'),
(74541, 5100, 'Óvnis: Investigação Secreta S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nvg32rnkTLvc6sU2CPv9FlhoCaj.jpg'),
(74542, 5100, 'Óvnis: Investigação Secreta S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nvg32rnkTLvc6sU2CPv9FlhoCaj.jpg'),
(74543, 5100, 'Óvnis: Investigação Secreta S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nvg32rnkTLvc6sU2CPv9FlhoCaj.jpg'),
(74544, 5100, 'Óvnis: Investigação Secreta S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nvg32rnkTLvc6sU2CPv9FlhoCaj.jpg'),
(74545, 5101, 'Poesia que Transforma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mhvTwejzt3WOMxrP2T4ebvMDMMY.jpg'),
(74546, 5101, 'Poesia que Transforma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eZNW42YoS9byZ75cmZGifoDSeR2.jpg'),
(74547, 5101, 'Poesia que Transforma S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tQRTZTz21cE58sR8T1KWV11RJKe.jpg'),
(74548, 5101, 'Poesia que Transforma S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jszNDJwJfUzgv9Zj69doFknVIQv.jpg'),
(74549, 5101, 'Poesia que Transforma S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yMNvMhfz4jkljtw45gGIZZQ9CR9.jpg'),
(74550, 5102, 'Segunda Guerra em Cores: Caminho para a Vitória S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MDHTmGVNmIspi4Xs6b7YO5wTev.jpg'),
(74551, 5102, 'Segunda Guerra em Cores: Caminho para a Vitória S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MDHTmGVNmIspi4Xs6b7YO5wTev.jpg'),
(74552, 5102, 'Segunda Guerra em Cores: Caminho para a Vitória S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MDHTmGVNmIspi4Xs6b7YO5wTev.jpg'),
(74553, 5102, 'Segunda Guerra em Cores: Caminho para a Vitória S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MDHTmGVNmIspi4Xs6b7YO5wTev.jpg'),
(74554, 5102, 'Segunda Guerra em Cores: Caminho para a Vitória S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MDHTmGVNmIspi4Xs6b7YO5wTev.jpg'),
(74555, 5102, 'Segunda Guerra em Cores: Caminho para a Vitória S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MDHTmGVNmIspi4Xs6b7YO5wTev.jpg'),
(74556, 5102, 'Segunda Guerra em Cores: Caminho para a Vitória S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MDHTmGVNmIspi4Xs6b7YO5wTev.jpg'),
(74557, 5102, 'Segunda Guerra em Cores: Caminho para a Vitória S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MDHTmGVNmIspi4Xs6b7YO5wTev.jpg'),
(74558, 5102, 'Segunda Guerra em Cores: Caminho para a Vitória S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MDHTmGVNmIspi4Xs6b7YO5wTev.jpg'),
(74559, 5102, 'Segunda Guerra em Cores: Caminho para a Vitória S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MDHTmGVNmIspi4Xs6b7YO5wTev.jpg'),
(74560, 5103, 'Selling Tampa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mhGFKTVl9AgsjebD4HySkNleB5O.jpg'),
(74561, 5103, 'Selling Tampa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mhGFKTVl9AgsjebD4HySkNleB5O.jpg'),
(74562, 5103, 'Selling Tampa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mhGFKTVl9AgsjebD4HySkNleB5O.jpg'),
(74563, 5103, 'Selling Tampa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mhGFKTVl9AgsjebD4HySkNleB5O.jpg'),
(74564, 5103, 'Selling Tampa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mhGFKTVl9AgsjebD4HySkNleB5O.jpg'),
(74565, 5103, 'Selling Tampa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mhGFKTVl9AgsjebD4HySkNleB5O.jpg'),
(74566, 5103, 'Selling Tampa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mhGFKTVl9AgsjebD4HySkNleB5O.jpg'),
(74567, 5103, 'Selling Tampa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mhGFKTVl9AgsjebD4HySkNleB5O.jpg'),
(74568, 5104, 'Sex Appeal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKrHOPuXZjAzdqt5zTPBFgHluJ7.jpg'),
(74569, 5104, 'Sex Appeal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKrHOPuXZjAzdqt5zTPBFgHluJ7.jpg'),
(74570, 5104, 'Sex Appeal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKrHOPuXZjAzdqt5zTPBFgHluJ7.jpg'),
(74571, 5104, 'Sex Appeal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKrHOPuXZjAzdqt5zTPBFgHluJ7.jpg'),
(74572, 5104, 'Sex Appeal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKrHOPuXZjAzdqt5zTPBFgHluJ7.jpg'),
(74573, 5104, 'Sex Appeal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKrHOPuXZjAzdqt5zTPBFgHluJ7.jpg'),
(74574, 5104, 'Sex Appeal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKrHOPuXZjAzdqt5zTPBFgHluJ7.jpg'),
(74575, 5104, 'Sex Appeal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKrHOPuXZjAzdqt5zTPBFgHluJ7.jpg'),
(74576, 5104, 'Sex Appeal S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKrHOPuXZjAzdqt5zTPBFgHluJ7.jpg'),
(74577, 5104, 'Sex Appeal S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKrHOPuXZjAzdqt5zTPBFgHluJ7.jpg'),
(74578, 5104, 'Sex Appeal S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/169273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKrHOPuXZjAzdqt5zTPBFgHluJ7.jpg'),
(74579, 5104, 'Sex Appeal S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/169274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKrHOPuXZjAzdqt5zTPBFgHluJ7.jpg'),
(74580, 5104, 'Sex Appeal S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/169275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKrHOPuXZjAzdqt5zTPBFgHluJ7.jpg'),
(74581, 5104, 'Sex Appeal S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/169276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKrHOPuXZjAzdqt5zTPBFgHluJ7.jpg'),
(74582, 5104, 'Sex Appeal S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/169277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKrHOPuXZjAzdqt5zTPBFgHluJ7.jpg'),
(74583, 5104, 'Sex Appeal S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/169278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKrHOPuXZjAzdqt5zTPBFgHluJ7.jpg'),
(74584, 5104, 'Sex Appeal S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/169279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKrHOPuXZjAzdqt5zTPBFgHluJ7.jpg'),
(74585, 5104, 'Sex Appeal S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/169280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKrHOPuXZjAzdqt5zTPBFgHluJ7.jpg'),
(74586, 5104, 'Sex Appeal S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/169281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKrHOPuXZjAzdqt5zTPBFgHluJ7.jpg'),
(74587, 5105, 'The Cut Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8InF4F3NJ4kzObvJpsdZJqTHyop.jpg'),
(74588, 5105, 'The Cut Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dmRIOEFuI22yzpmo6aOpx2gdr16.jpg'),
(74589, 5105, 'The Cut Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ox8ucqdbrXfekT6G9bDrG4ueegM.jpg'),
(74590, 5105, 'The Cut Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jxmqOLNQVwDbYwExvBIre1AMrOd.jpg'),
(74591, 5105, 'The Cut Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jxmqOLNQVwDbYwExvBIre1AMrOd.jpg'),
(74592, 5105, 'The Cut Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jxmqOLNQVwDbYwExvBIre1AMrOd.jpg'),
(74593, 5105, 'The Cut Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jxmqOLNQVwDbYwExvBIre1AMrOd.jpg'),
(74594, 5105, 'The Cut Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jxmqOLNQVwDbYwExvBIre1AMrOd.jpg'),
(74595, 5106, 'Tom e Jerry em Nova Iorque S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5nvIUVjFpRAiMziG5zP2KR1uLHV.jpg'),
(74596, 5106, 'Tom e Jerry em Nova Iorque S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5nvIUVjFpRAiMziG5zP2KR1uLHV.jpg'),
(74597, 5106, 'Tom e Jerry em Nova Iorque S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5nvIUVjFpRAiMziG5zP2KR1uLHV.jpg'),
(74598, 5106, 'Tom e Jerry em Nova Iorque S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5nvIUVjFpRAiMziG5zP2KR1uLHV.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(74599, 5106, 'Tom e Jerry em Nova Iorque S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5nvIUVjFpRAiMziG5zP2KR1uLHV.jpg'),
(74600, 5106, 'Tom e Jerry em Nova Iorque S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5nvIUVjFpRAiMziG5zP2KR1uLHV.jpg'),
(74601, 5106, 'Tom e Jerry em Nova Iorque S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5nvIUVjFpRAiMziG5zP2KR1uLHV.jpg'),
(74602, 5107, 'Tom e Jerry em Nova Iorque S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5nvIUVjFpRAiMziG5zP2KR1uLHV.jpg'),
(74603, 5107, 'Tom e Jerry em Nova Iorque S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5nvIUVjFpRAiMziG5zP2KR1uLHV.jpg'),
(74604, 5107, 'Tom e Jerry em Nova Iorque S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5nvIUVjFpRAiMziG5zP2KR1uLHV.jpg'),
(74605, 5107, 'Tom e Jerry em Nova Iorque S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5nvIUVjFpRAiMziG5zP2KR1uLHV.jpg'),
(74606, 5107, 'Tom e Jerry em Nova Iorque S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5nvIUVjFpRAiMziG5zP2KR1uLHV.jpg'),
(74607, 5107, 'Tom e Jerry em Nova Iorque S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5nvIUVjFpRAiMziG5zP2KR1uLHV.jpg'),
(74608, 5108, 'Top Chef Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74609, 5108, 'Top Chef Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74610, 5108, 'Top Chef Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74611, 5108, 'Top Chef Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74612, 5108, 'Top Chef Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74613, 5108, 'Top Chef Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74614, 5108, 'Top Chef Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74615, 5108, 'Top Chef Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74616, 5108, 'Top Chef Brasil S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74617, 5108, 'Top Chef Brasil S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74618, 5108, 'Top Chef Brasil S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74619, 5108, 'Top Chef Brasil S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74620, 5108, 'Top Chef Brasil S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74621, 5109, 'Top Chef Brasil S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tN2dv9ni2mOH2K7bMq5JIbNnxnC.jpg'),
(74622, 5109, 'Top Chef Brasil S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ncuerNHqUdEdEiUBKAEO4gCJIrM.jpg'),
(74623, 5109, 'Top Chef Brasil S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uRlMpRNcvLbksLxU4BA5qPpPmHw.jpg'),
(74624, 5109, 'Top Chef Brasil S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7yHehG3L0o5LhpmFHzQ6j0XSZqy.jpg'),
(74625, 5109, 'Top Chef Brasil S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yZfoU2HIwajRTrU9sqKQlOhcF2v.jpg'),
(74626, 5109, 'Top Chef Brasil S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iIMtOt8fKEaOSwSzwvmJJ0JaFAd.jpg'),
(74627, 5109, 'Top Chef Brasil S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2bGZJk8gtzRzljWQp6C2SYJ4MDT.jpg'),
(74628, 5109, 'Top Chef Brasil S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74629, 5109, 'Top Chef Brasil S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pQ8Q0nal4ZJ8vTcuLogTfd3bbAt.jpg'),
(74630, 5109, 'Top Chef Brasil S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dvJPL65OIrhPG8zdzAx6mnm4SxI.jpg'),
(74631, 5109, 'Top Chef Brasil S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lfsNU2697C0pipd7rk5amR0YLDa.jpg'),
(74632, 5109, 'Top Chef Brasil S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1TTpoYVvGJPc60GyzAfFAiEBVvt.jpg'),
(74633, 5110, 'Top Chef Brasil S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74634, 5110, 'Top Chef Brasil S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74635, 5110, 'Top Chef Brasil S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hyX6JB87RCqGgEY1tnOJdP9G2gx.jpg'),
(74636, 5110, 'Top Chef Brasil S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vgUmt96ckxFqAhW2JJVcPK3sUMw.jpg'),
(74637, 5110, 'Top Chef Brasil S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fqMI7CGTIWyh9zSWzYeL3BdpLda.jpg'),
(74638, 5110, 'Top Chef Brasil S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tO6dJJlvkLErSKQcoFsom0iBlmS.jpg'),
(74639, 5110, 'Top Chef Brasil S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sBeRisdnBgOzXtKzi1P5i8JfM42.jpg'),
(74640, 5110, 'Top Chef Brasil S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iuuuW8Z4jVRbi7RV8dn7bid84BM.jpg'),
(74641, 5110, 'Top Chef Brasil S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74642, 5110, 'Top Chef Brasil S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74643, 5110, 'Top Chef Brasil S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74644, 5110, 'Top Chef Brasil S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74645, 5111, 'Top Chef Brasil S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74646, 5111, 'Top Chef Brasil S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74647, 5111, 'Top Chef Brasil S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74648, 5111, 'Top Chef Brasil S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74649, 5111, 'Top Chef Brasil S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74650, 5111, 'Top Chef Brasil S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74651, 5111, 'Top Chef Brasil S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74652, 5111, 'Top Chef Brasil S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74653, 5111, 'Top Chef Brasil S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74654, 5111, 'Top Chef Brasil S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74655, 5111, 'Top Chef Brasil S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74656, 5111, 'Top Chef Brasil S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74657, 5111, 'Top Chef Brasil S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74658, 5111, 'Top Chef Brasil S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74659, 5111, 'Top Chef Brasil S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74660, 5111, 'Top Chef Brasil S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQIaICWRNBfzOLru0cGZJMiI1Yk.jpg'),
(74661, 5112, 'Auto Posto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l2Qme2knBsWsWPlqTFyFt73918o.jpg'),
(74662, 5112, 'Auto Posto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hnaYyST1lj64vM8Q0uMeauYhXJx.jpg'),
(74663, 5112, 'Auto Posto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vc5AJRPvvJ4PUrVfLNYB0vJaYnL.jpg'),
(74664, 5112, 'Auto Posto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1DmedcX5OSJXd9w5iNp4x9LtsPl.jpg'),
(74665, 5112, 'Auto Posto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tZgUktBuWp0ICT7IonflXwEjqGs.jpg'),
(74666, 5112, 'Auto Posto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pL2P2ZTjr8gU2WgD96ThJihi9br.jpg'),
(74667, 5112, 'Auto Posto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pL2P2ZTjr8gU2WgD96ThJihi9br.jpg'),
(74668, 5112, 'Auto Posto S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pL2P2ZTjr8gU2WgD96ThJihi9br.jpg'),
(74669, 5112, 'Auto Posto S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pL2P2ZTjr8gU2WgD96ThJihi9br.jpg'),
(74670, 5112, 'Auto Posto S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pL2P2ZTjr8gU2WgD96ThJihi9br.jpg'),
(74671, 5113, 'Auto Posto S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pL2P2ZTjr8gU2WgD96ThJihi9br.jpg'),
(74672, 5113, 'Auto Posto S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pL2P2ZTjr8gU2WgD96ThJihi9br.jpg'),
(74673, 5113, 'Auto Posto S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pL2P2ZTjr8gU2WgD96ThJihi9br.jpg'),
(74674, 5113, 'Auto Posto S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pL2P2ZTjr8gU2WgD96ThJihi9br.jpg'),
(74675, 5113, 'Auto Posto S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pL2P2ZTjr8gU2WgD96ThJihi9br.jpg'),
(74676, 5113, 'Auto Posto S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pL2P2ZTjr8gU2WgD96ThJihi9br.jpg'),
(74677, 5113, 'Auto Posto S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pL2P2ZTjr8gU2WgD96ThJihi9br.jpg'),
(74678, 5113, 'Auto Posto S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pL2P2ZTjr8gU2WgD96ThJihi9br.jpg'),
(74679, 5113, 'Auto Posto S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pL2P2ZTjr8gU2WgD96ThJihi9br.jpg'),
(74680, 5113, 'Auto Posto S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pL2P2ZTjr8gU2WgD96ThJihi9br.jpg'),
(74681, 5114, 'Califórnia em Chamas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tj6ik4Q6T5rIsBlW5RQNPAWnqHh.jpg'),
(74682, 5114, 'Califórnia em Chamas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lUz3WZzwgGFugBEfBLB35CgJiUq.jpg'),
(74683, 5114, 'Califórnia em Chamas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c6vdfl9NfTsMEaXYsNvgqVc9V4z.jpg'),
(74684, 5114, 'Califórnia em Chamas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qOYwnygHctyzbol8zy9TOl7YW88.jpg'),
(74685, 5114, 'Califórnia em Chamas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lmkEXmSyLYTugVqlsCq2mdWc4vw.jpg'),
(74686, 5114, 'Califórnia em Chamas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1UbDLdie9X56xdCOCPT6WRp8IPh.jpg'),
(74687, 5115, 'Desvendando o Passado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mngkcCnB2sl0QKIwz29akMx8GL1.jpg'),
(74688, 5115, 'Desvendando o Passado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zQqNZtGrUPgoDK9CFynItT6QcVx.jpg'),
(74689, 5115, 'Desvendando o Passado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odbg51ng5bSrxwM6Mc5cgcsOViY.jpg'),
(74690, 5115, 'Desvendando o Passado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uXs3pfagtKVjNlgK2MYChM5oqWC.jpg'),
(74691, 5115, 'Desvendando o Passado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yUPsluRzAYxFfTEcGOVZ4lPqohb.jpg'),
(74692, 5115, 'Desvendando o Passado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yx1D1MRRFI5e6roo3WR3nwflQkz.jpg'),
(74693, 5115, 'Desvendando o Passado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w2xfwRomkdyqHxI1183SU39G8qB.jpg'),
(74694, 5115, 'Desvendando o Passado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1tz1j0Dv6Y5zrpA0nSCQqY0GpCU.jpg'),
(74695, 5116, 'Duna [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4L6aN91BpQr8J4LxLQrliV9QDXI.jpg'),
(74696, 5116, 'Duna [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9yLws0GZ6EyrYfiaf7advst1aXi.jpg'),
(74697, 5116, 'Duna [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gVLYnMFLDQTfzuy0pXHUVcTJTqC.jpg'),
(74698, 5117, 'Fé na Vida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m7FBwRxiT1DSeROmW5mSDQAHuth.jpg'),
(74699, 5117, 'Fé na Vida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m7FBwRxiT1DSeROmW5mSDQAHuth.jpg'),
(74700, 5117, 'Fé na Vida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m7FBwRxiT1DSeROmW5mSDQAHuth.jpg'),
(74701, 5118, 'Fique Comigo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hTfPZPAawxizNt6gDeJbT0O5uEP.jpg'),
(74702, 5118, 'Fique Comigo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yxHczqcL2RsV9hR0zcxlgrpJ02P.jpg'),
(74703, 5118, 'Fique Comigo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cneKLWwpeoybjjy3AMLQsnGMswV.jpg'),
(74704, 5118, 'Fique Comigo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cZagb1Z3EOQxVFoig2iKfbm1cPz.jpg'),
(74705, 5118, 'Fique Comigo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2qraOWpIgjPSsqPGECtfQgaROlf.jpg'),
(74706, 5118, 'Fique Comigo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QbqtpXgix9FLpEAUSrJQ7aQ7yP.jpg'),
(74707, 5118, 'Fique Comigo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c9mArjdPwd53jHU4Hr5d6oSqzef.jpg'),
(74708, 5118, 'Fique Comigo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fE5AmT12RkATsLCgBfgRd4IjCvc.jpg'),
(74709, 5119, 'Gente Ansiosa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6TGwAlX1OoQoPPJ2mUZccqR3uV0.jpg'),
(74710, 5119, 'Gente Ansiosa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5mhvVE1xur6h3Snk8gmCPYD758X.jpg'),
(74711, 5119, 'Gente Ansiosa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2MyJI8myaV0rV8F7PIfxdawJvV1.jpg'),
(74712, 5119, 'Gente Ansiosa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sMWjKURmAwwvpsHF9uf9poyr70s.jpg'),
(74713, 5119, 'Gente Ansiosa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3tL6vjZopUBa6WxY7aP2914YBPB.jpg'),
(74714, 5119, 'Gente Ansiosa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mOrUE3D7aDlfkx1o71gNkI6qdEi.jpg'),
(74715, 5120, 'Jornada Astral S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AfB6fhTxNXDg4XyInqritcrgowK.jpg'),
(74716, 5120, 'Jornada Astral S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lWhR7dgmqcgCkGqYyms0bylX1p4.jpg'),
(74717, 5120, 'Jornada Astral S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7mmUXn7AQS26MCW28qOSPjCIpK.jpg'),
(74718, 5120, 'Jornada Astral S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h92FQRq8BAyUskLcYvMm1GN7Akq.jpg'),
(74719, 5120, 'Jornada Astral S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tWPMbomvFgu9k9rMnexmwugibVD.jpg'),
(74720, 5120, 'Jornada Astral S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x9C4hActGn9A0FuSFRddSHUi8B7.jpg'),
(74721, 5120, 'Jornada Astral S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/60a2dGDvfJutix2JvLs6xTkV088.jpg'),
(74722, 5120, 'Jornada Astral S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3f7P71Erf1ncWwqbV3GfuMSdgg2.jpg'),
(74723, 5120, 'Jornada Astral S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5272wr3FwCXHTBNqod9H25r0FoT.jpg'),
(74724, 5120, 'Jornada Astral S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQSQTdCEXrbfg8IUro4PtTWiKAS.jpg'),
(74725, 5120, 'Jornada Astral S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/169103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hmAU79zj0tkd5m6r7GHwwg6R2Y.jpg'),
(74726, 5120, 'Jornada Astral S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/169104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rwJOPHRjW76wGCItedjpN2Zfr4.jpg'),
(74727, 5121, 'Kitz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r88sF4INWSiadthqydFXo9Yo92V.jpg'),
(74728, 5121, 'Kitz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6n6WgLV0yOCQpbkZkC10pIO1ht5.jpg'),
(74729, 5121, 'Kitz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mCFbpwxosItGqovvEV1VP9hTsGY.jpg'),
(74730, 5121, 'Kitz S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cnEgqlSqmggZB38y60wkqLPCNaC.jpg'),
(74731, 5121, 'Kitz S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBCuW3qP1EJM79x72xfn0PeUdeF.jpg'),
(74732, 5121, 'Kitz S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mSRO2gxLZfmHWV7xDdt6aZZP2KT.jpg'),
(74733, 5122, 'Moonshine S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wjrl77SwAozWa9v8XZvJayqNj0r.jpg'),
(74734, 5122, 'Moonshine S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hGT4lNmmBnIxzuKQ1n0NERYU6UV.jpg'),
(74735, 5122, 'Moonshine S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rFHraEeSFRizQa1oH4NvunUgXTT.jpg'),
(74736, 5122, 'Moonshine S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r660BLuFwrntiVu7sLQXp8DUndW.jpg'),
(74737, 5122, 'Moonshine S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ySsoCnRmJBg9GwbnAvbXHYAsQKU.jpg'),
(74738, 5122, 'Moonshine S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ebdjJ3hT78pFzFcL7yslbtdaUPB.jpg'),
(74739, 5122, 'Moonshine S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dqOh7wS2ulGYO5KUVZfuqIDErot.jpg'),
(74740, 5122, 'Moonshine S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iGA7VHK8GcANWFhuxmWQO0qGlUO.jpg'),
(74741, 5123, 'Moonshine S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5P9PC64xLf0azPs5AFifvI8kDAt.jpg'),
(74742, 5123, 'Moonshine S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5P9PC64xLf0azPs5AFifvI8kDAt.jpg'),
(74743, 5123, 'Moonshine S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5P9PC64xLf0azPs5AFifvI8kDAt.jpg'),
(74744, 5123, 'Moonshine S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5P9PC64xLf0azPs5AFifvI8kDAt.jpg'),
(74745, 5123, 'Moonshine S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5P9PC64xLf0azPs5AFifvI8kDAt.jpg'),
(74746, 5123, 'Moonshine S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5P9PC64xLf0azPs5AFifvI8kDAt.jpg'),
(74747, 5123, 'Moonshine S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5P9PC64xLf0azPs5AFifvI8kDAt.jpg'),
(74748, 5123, 'Moonshine S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5P9PC64xLf0azPs5AFifvI8kDAt.jpg'),
(74749, 5124, 'Motos Sagradas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eB4VfpYBrzxFp6b2aPRrX8Eg0h8.jpg'),
(74750, 5124, 'Motos Sagradas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fbLIS8MvDwKEm309YZFgxWzsULe.jpg'),
(74751, 5124, 'Motos Sagradas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/605Tl64QO4XJfdlyDBu1ylFXz4X.jpg'),
(74752, 5124, 'Motos Sagradas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qG8Cawqd7PkgSw7dGyFWUvwFKwe.jpg'),
(74753, 5124, 'Motos Sagradas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oPkh0p1rPVugcBqPJ6NKfxFWpBU.jpg'),
(74754, 5124, 'Motos Sagradas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ahjqhPzzm0TkBw1YRztrfJx5H8D.jpg'),
(74755, 5125, 'Dicky e Dawn S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yXSec3aV5qb7Z76tR8zjI99Kcej.jpg'),
(74756, 5125, 'Dicky e Dawn S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4Zf4lQ3VowK5GYX9VrA1ngnSfw.jpg'),
(74757, 5125, 'Dicky e Dawn S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ls1FGt0crUzUhnFwmsVFmuBzICe.jpg'),
(74758, 5125, 'Dicky e Dawn S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74759, 5125, 'Dicky e Dawn S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74760, 5125, 'Dicky e Dawn S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74761, 5125, 'Dicky e Dawn S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74762, 5125, 'Dicky e Dawn S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74763, 5125, 'Dicky e Dawn S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74764, 5125, 'Dicky e Dawn S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74765, 5125, 'Dicky e Dawn S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/169009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74766, 5125, 'Dicky e Dawn S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/169010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74767, 5125, 'Dicky e Dawn S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/169011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74768, 5125, 'Dicky e Dawn S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/169012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74769, 5125, 'Dicky e Dawn S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/169013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q6SOgqjYmLhWGTgYQ35RL1nynX0.jpg'),
(74770, 5125, 'Dicky e Dawn S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/169014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74771, 5125, 'Dicky e Dawn S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/169015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74772, 5125, 'Dicky e Dawn S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/169016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74773, 5125, 'Dicky e Dawn S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/169017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74774, 5125, 'Dicky e Dawn S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/169018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74775, 5126, 'Dicky e Dawn S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74776, 5126, 'Dicky e Dawn S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74777, 5126, 'Dicky e Dawn S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74778, 5126, 'Dicky e Dawn S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74779, 5126, 'Dicky e Dawn S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qEeZaQ07W6mHtQWXyFTSyJOzoUa.jpg'),
(74780, 5126, 'Dicky e Dawn S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z6pBTBWFc3c84gDzpfh04atBP7q.jpg'),
(74781, 5126, 'Dicky e Dawn S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tVEJOsmGOevjOmVNoihGHyYoANA.jpg'),
(74782, 5126, 'Dicky e Dawn S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yOGGDe1p6roy19o99sqUIsSAtwF.jpg'),
(74783, 5126, 'Dicky e Dawn S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74784, 5126, 'Dicky e Dawn S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74785, 5126, 'Dicky e Dawn S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/169029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74786, 5126, 'Dicky e Dawn S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/169030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74787, 5126, 'Dicky e Dawn S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/169031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74788, 5126, 'Dicky e Dawn S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/169032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74789, 5126, 'Dicky e Dawn S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/169033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74790, 5126, 'Dicky e Dawn S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/169034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74791, 5126, 'Dicky e Dawn S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/169035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74792, 5126, 'Dicky e Dawn S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/169036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74793, 5126, 'Dicky e Dawn S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/169037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74794, 5126, 'Dicky e Dawn S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/169038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eVK7zXWGOMALO2gzjCvsnYdObll.jpg'),
(74795, 5126, 'Dicky e Dawn S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/169039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74796, 5126, 'Dicky e Dawn S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/169040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74797, 5126, 'Dicky e Dawn S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/169041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74798, 5126, 'Dicky e Dawn S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/169042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yRlZ3YsxcEkbwqWIo5cqR2GqF6I.jpg'),
(74799, 5126, 'Dicky e Dawn S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/169043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74800, 5127, 'Dicky e Dawn S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yZmaBJ3QqeISpugWkBfOxBirhFm.jpg'),
(74801, 5127, 'Dicky e Dawn S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74802, 5127, 'Dicky e Dawn S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74803, 5127, 'Dicky e Dawn S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74804, 5127, 'Dicky e Dawn S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74805, 5127, 'Dicky e Dawn S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74806, 5127, 'Dicky e Dawn S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74807, 5127, 'Dicky e Dawn S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74808, 5127, 'Dicky e Dawn S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74809, 5127, 'Dicky e Dawn S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74810, 5127, 'Dicky e Dawn S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/169054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74811, 5127, 'Dicky e Dawn S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/169055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74812, 5127, 'Dicky e Dawn S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/169056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74813, 5127, 'Dicky e Dawn S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/169057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74814, 5127, 'Dicky e Dawn S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/169058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/thhNkSoXWmZvwbAZStHIa9CFgGu.jpg'),
(74815, 5127, 'Dicky e Dawn S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/169059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74816, 5127, 'Dicky e Dawn S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/169060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74817, 5127, 'Dicky e Dawn S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/169061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74818, 5127, 'Dicky e Dawn S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/169062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74819, 5127, 'Dicky e Dawn S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/169063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74820, 5127, 'Dicky e Dawn S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/169064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74821, 5127, 'Dicky e Dawn S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/169065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74822, 5127, 'Dicky e Dawn S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/169066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74823, 5127, 'Dicky e Dawn S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/169067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74824, 5128, 'Dicky e Dawn S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/169068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74825, 5128, 'Dicky e Dawn S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/169069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74826, 5128, 'Dicky e Dawn S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/169070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74827, 5128, 'Dicky e Dawn S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/169071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74828, 5128, 'Dicky e Dawn S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/169072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74829, 5128, 'Dicky e Dawn S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/169073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74830, 5128, 'Dicky e Dawn S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/169074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74831, 5128, 'Dicky e Dawn S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/169075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74832, 5128, 'Dicky e Dawn S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/169076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74833, 5128, 'Dicky e Dawn S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/169077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74834, 5128, 'Dicky e Dawn S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/169078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74835, 5128, 'Dicky e Dawn S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/169079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74836, 5128, 'Dicky e Dawn S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/169080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIp7OThxhHgPya3p0SW8QNEPCzv.jpg'),
(74837, 5129, 'O Livro de Boba Fett S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/taTPQoXNrt8nmQf9blQUULDUZhl.jpg'),
(74838, 5129, 'O Livro de Boba Fett S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172455.mp4', 'http://image.tmdb.org/t/p/w1280/dX4VVci4gy0H7bX1lq3N6Gsu4av.jpg'),
(74839, 5129, 'O Livro de Boba Fett S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172456.mp4', 'http://image.tmdb.org/t/p/w1280/3B984p4X91TQk2scTohjvex174P.jpg'),
(74840, 5129, 'O Livro de Boba Fett S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172457.mp4', 'http://timg.bdta.pro/images/dbd0acd3066e714e8e2c961fe062332d.jpg'),
(74841, 5129, 'O Livro de Boba Fett S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172458.mp4', 'http://timg.bdta.pro/images/87c210a8b67d267127a342ed31ae3641.jpg'),
(74842, 5129, 'O Livro de Boba Fett S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172459.mp4', 'http://timg.bdta.pro/images/7aa4e0281758bde7ab7306079acfea8f.jpg'),
(74843, 5129, 'O Livro de Boba Fett S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172460.mp4', 'http://timg.bdta.pro/images/c1628bb156da7d21d9cfd63c4d895b2f.jpg'),
(74844, 5130, 'O Rei de Porcelana S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xziun40gRYQ7VFsiTSWirPERLsV.jpg'),
(74845, 5130, 'O Rei de Porcelana S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8TKToNczPEp8YbuwMVCXYCXah9c.jpg'),
(74846, 5130, 'O Rei de Porcelana S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2RKyqk3REOz7By1ea8dlDjcZ48m.jpg'),
(74847, 5130, 'O Rei de Porcelana S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4jse0jyJnUWLTaz5KMynRhiWw3z.jpg'),
(74848, 5130, 'O Rei de Porcelana S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2jfBvlN9Bpxeou2yMVQj2RBxqZ0.jpg'),
(74849, 5130, 'O Rei de Porcelana S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqQcLEf45TrqD0ZEzwxI60sPzIQ.jpg'),
(74850, 5130, 'O Rei de Porcelana S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ac7nzaOVDl65xjgW4aTqY9eUWli.jpg'),
(74851, 5130, 'O Rei de Porcelana S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wQv66MvR9JRF7Nuq0ckGiiIfxN3.jpg'),
(74852, 5130, 'O Rei de Porcelana S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/168987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aVkUVk5Hd2yEnPdCR1RDkLr57x4.jpg'),
(74853, 5130, 'O Rei de Porcelana S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/168988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wO6PL9pn1FXIWneudzdGLl9sf9t.jpg'),
(74854, 5130, 'O Rei de Porcelana S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/168989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x96N2nthAn9Cx1mPDsTGC1kyznl.jpg'),
(74855, 5130, 'O Rei de Porcelana S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/168990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tqPqph4l8dask8Y01sKbsZuthue.jpg'),
(74856, 5130, 'O Rei de Porcelana S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/168991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5aNdZ4JZT58AUWKr9fhQ0qyw1OS.jpg'),
(74857, 5130, 'O Rei de Porcelana S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/168992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oq0rn44HhDfGmKtCAAtSBeocrPH.jpg'),
(74858, 5130, 'O Rei de Porcelana S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/168993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7QEGw8LYHxeqcEkDx32x306JSP.jpg'),
(74859, 5130, 'O Rei de Porcelana S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/168994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8HRAblJSfzuql0RPhuI2jizNcJV.jpg'),
(74860, 5130, 'O Rei de Porcelana S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/168995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hDKiy0DJZuTN8ZNisg5PQhO0zqC.jpg'),
(74861, 5130, 'O Rei de Porcelana S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/168996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xMXpbMgOPtm902huXaWUhXTjmRY.jpg'),
(74862, 5130, 'O Rei de Porcelana S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/168997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wS40huGdUrQjfNR5dFX8fXKmJ2b.jpg'),
(74863, 5130, 'O Rei de Porcelana S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/168998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dj3qaOFwuqriClUbvwGbJilg6fc.jpg'),
(74864, 5131, 'Passaporte para Liberdade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/IQlcC3Fz9QlbLQJWecsQhMdmsQ.jpg'),
(74865, 5131, 'Passaporte para Liberdade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlko98oAN0vWeJWmm1kePPj0Foa.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(74866, 5131, 'Passaporte para Liberdade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlko98oAN0vWeJWmm1kePPj0Foa.jpg'),
(74867, 5131, 'Passaporte para Liberdade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlko98oAN0vWeJWmm1kePPj0Foa.jpg'),
(74868, 5131, 'Passaporte para Liberdade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlko98oAN0vWeJWmm1kePPj0Foa.jpg'),
(74869, 5131, 'Passaporte para Liberdade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlko98oAN0vWeJWmm1kePPj0Foa.jpg'),
(74870, 5131, 'Passaporte para Liberdade S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlko98oAN0vWeJWmm1kePPj0Foa.jpg'),
(74871, 5131, 'Passaporte para Liberdade S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlko98oAN0vWeJWmm1kePPj0Foa.jpg'),
(74872, 5132, 'Retrospectiva 2021: Edição Globoplay S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/utfvHUoyudhB3QavKvcIvtsA2Y8.jpg'),
(74873, 5132, 'Retrospectiva 2021: Edição Globoplay S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/utfvHUoyudhB3QavKvcIvtsA2Y8.jpg'),
(74874, 5132, 'Retrospectiva 2021: Edição Globoplay S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/utfvHUoyudhB3QavKvcIvtsA2Y8.jpg'),
(74875, 5133, 'Rolling Kitchen Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0GS6p7gzRiYMjgEHNkeXTTLLV.jpg'),
(74876, 5133, 'Rolling Kitchen Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0GS6p7gzRiYMjgEHNkeXTTLLV.jpg'),
(74877, 5133, 'Rolling Kitchen Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0GS6p7gzRiYMjgEHNkeXTTLLV.jpg'),
(74878, 5133, 'Rolling Kitchen Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0GS6p7gzRiYMjgEHNkeXTTLLV.jpg'),
(74879, 5133, 'Rolling Kitchen Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0GS6p7gzRiYMjgEHNkeXTTLLV.jpg'),
(74880, 5133, 'Rolling Kitchen Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0GS6p7gzRiYMjgEHNkeXTTLLV.jpg'),
(74881, 5133, 'Rolling Kitchen Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0GS6p7gzRiYMjgEHNkeXTTLLV.jpg'),
(74882, 5133, 'Rolling Kitchen Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0GS6p7gzRiYMjgEHNkeXTTLLV.jpg'),
(74883, 5133, 'Rolling Kitchen Brasil S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0GS6p7gzRiYMjgEHNkeXTTLLV.jpg'),
(74884, 5133, 'Rolling Kitchen Brasil S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0GS6p7gzRiYMjgEHNkeXTTLLV.jpg'),
(74885, 5134, 'Rolling Kitchen Brasil S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0GS6p7gzRiYMjgEHNkeXTTLLV.jpg'),
(74886, 5134, 'Rolling Kitchen Brasil S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0GS6p7gzRiYMjgEHNkeXTTLLV.jpg'),
(74887, 5134, 'Rolling Kitchen Brasil S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0GS6p7gzRiYMjgEHNkeXTTLLV.jpg'),
(74888, 5134, 'Rolling Kitchen Brasil S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0GS6p7gzRiYMjgEHNkeXTTLLV.jpg'),
(74889, 5134, 'Rolling Kitchen Brasil S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0GS6p7gzRiYMjgEHNkeXTTLLV.jpg'),
(74890, 5134, 'Rolling Kitchen Brasil S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0GS6p7gzRiYMjgEHNkeXTTLLV.jpg'),
(74891, 5134, 'Rolling Kitchen Brasil S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0GS6p7gzRiYMjgEHNkeXTTLLV.jpg'),
(74892, 5134, 'Rolling Kitchen Brasil S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0GS6p7gzRiYMjgEHNkeXTTLLV.jpg'),
(74893, 5134, 'Rolling Kitchen Brasil S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0GS6p7gzRiYMjgEHNkeXTTLLV.jpg'),
(74894, 5134, 'Rolling Kitchen Brasil S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/st0GS6p7gzRiYMjgEHNkeXTTLLV.jpg'),
(74895, 5135, 'Romulus S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udFS6QiYZkIFfFJfHq1hE18ag6z.jpg'),
(74896, 5135, 'Romulus S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4mDLAfNti8bkzOq9TXIJJ3UYJJp.jpg'),
(74897, 5135, 'Romulus S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AE2Hlop7LNkklSsjeTCdK3IfZo.jpg'),
(74898, 5135, 'Romulus S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPrIdNDrdM7EDaQgQbYJYtapDJU.jpg'),
(74899, 5135, 'Romulus S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o9P0qujdXNUurhMsZXgliPGAyAw.jpg'),
(74900, 5135, 'Romulus S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bcBKHDrPDRKKGmM3Z4pTRh2j7Kb.jpg'),
(74901, 5135, 'Romulus S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lS10heAWuz50eDEDCxoAWvEiv7J.jpg'),
(74902, 5135, 'Romulus S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kx0CT5DDFgSJP6JLVcaBX1ZN3Jx.jpg'),
(74903, 5135, 'Romulus S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/168966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qW1tVe9GskcHvQl1GSWQS4mOCtU.jpg'),
(74904, 5135, 'Romulus S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/168967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6XQHrxL49jW16YVqWBQFkMERyA3.jpg'),
(74905, 5136, 'Rugrats S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/82AvIt8Q1AeM04tMuhkPvuiUsD3.jpg'),
(74906, 5136, 'Rugrats S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8oRG4jfiySrAelX7Ii4AZKSufmJ.jpg'),
(74907, 5136, 'Rugrats S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2RLU2CfL1YlFFQRPSlqKocgvpnT.jpg'),
(74908, 5136, 'Rugrats S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/snOOM9JAkvygIH1LRdxN7k6cF3q.jpg'),
(74909, 5136, 'Rugrats S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lG7ri78TjfniI3XcuCa0qMeRHAI.jpg'),
(74910, 5136, 'Rugrats S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t4OkDZfaoU4CWf83nhsYDrI2UHb.jpg'),
(74911, 5136, 'Rugrats S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6CTdP8ol6j4An0fm67GNNAnI5dZ.jpg'),
(74912, 5136, 'Rugrats S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/71YluwVrruex4ZVT5zurrtUztv1.jpg'),
(74913, 5136, 'Rugrats S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e705NpOlpaSGBvMYPJwrix6HPme.jpg'),
(74914, 5136, 'Rugrats S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hxwXHUMUVGGo0niVjhh38yDsBHQ.jpg'),
(74915, 5136, 'Rugrats S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ryxn261LF4AENoV6eosP96SHjIv.jpg'),
(74916, 5136, 'Rugrats S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xpr2bNE7bxgFymGADuy54z7fkyM.jpg'),
(74917, 5136, 'Rugrats S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ol6nu4cd2ioWEJt0Op4aPxYDGoL.jpg'),
(74918, 5136, 'Rugrats S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/211825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lTIBEU53bzMDohohilVOOdjW8gO.jpg'),
(74919, 5137, 'Rugrats S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bk5bqkQVYC32lozZO6Z0ZLw32jv.jpg'),
(74920, 5137, 'Rugrats S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bk5bqkQVYC32lozZO6Z0ZLw32jv.jpg'),
(74921, 5137, 'Rugrats S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bk5bqkQVYC32lozZO6Z0ZLw32jv.jpg'),
(74922, 5137, 'Rugrats S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bk5bqkQVYC32lozZO6Z0ZLw32jv.jpg'),
(74923, 5137, 'Rugrats S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bk5bqkQVYC32lozZO6Z0ZLw32jv.jpg'),
(74924, 5137, 'Rugrats S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bk5bqkQVYC32lozZO6Z0ZLw32jv.jpg'),
(74925, 5137, 'Rugrats S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bk5bqkQVYC32lozZO6Z0ZLw32jv.jpg'),
(74926, 5138, 'Shadows House S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFvdmFxkz69SFwEGetIpDkSGhq9.jpg'),
(74927, 5138, 'Shadows House S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wQ1xcM9c0XdTRyvJim92zQjTbT2.jpg'),
(74928, 5138, 'Shadows House S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5VfApkcgAoQFkRtRVLVEyQCK2zF.jpg'),
(74929, 5138, 'Shadows House S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AjhFAMEs2ZIUdchP2YkYl0mDh0L.jpg'),
(74930, 5138, 'Shadows House S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqPAzNgkMwz1Nsx4lYbDTDFVSa3.jpg'),
(74931, 5138, 'Shadows House S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ofdWYf1KHTxQ36eyLoIm1ot3G2b.jpg'),
(74932, 5138, 'Shadows House S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/196FiBChGl8n9zyboMFqE8kYaQV.jpg'),
(74933, 5138, 'Shadows House S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kab6hm8QSIfqMHKp8zD0T1J9xsH.jpg'),
(74934, 5138, 'Shadows House S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4dPYzSpJmfJXWNNNqGi6KM6tXj7.jpg'),
(74935, 5138, 'Shadows House S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8gn5Z2PCWehBtTi9JnvLt390IZV.jpg'),
(74936, 5138, 'Shadows House S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xwLtzPIDjROyPBe7GrVQd7qXVjS.jpg'),
(74937, 5138, 'Shadows House S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/drM9kdQtKDIuGI01SbWG2tX3N4z.jpg'),
(74938, 5138, 'Shadows House S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qLkiEy6mqmyi1n4DyByOIwNIfye.jpg'),
(74939, 5139, 'Shadows House S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200155.mp4', 'http://timg.bdta.pro/images/f1df94565d503eb1ca5950e7a7108c7d.jpg'),
(74940, 5139, 'Shadows House S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200156.mp4', 'http://timg.bdta.pro/images/1719468a8bb3380d89e2d693777798bd.jpg'),
(74941, 5139, 'Shadows House S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200157.mp4', 'http://timg.bdta.pro/images/08395d7819db31aca2b52cca3beb8149.jpg'),
(74942, 5139, 'Shadows House S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200158.mp4', 'http://timg.bdta.pro/images/5dd7aa783809b20502cc42face554ecb.jpg'),
(74943, 5139, 'Shadows House S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200159.mp4', 'http://timg.bdta.pro/images/bad93953cc4d5720b5898042fbe39440.jpg'),
(74944, 5139, 'Shadows House S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200160.mp4', 'http://timg.bdta.pro/images/6484b82924eab01b74549a0b82f79442.jpg'),
(74945, 5139, 'Shadows House S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200161.mp4', 'http://timg.bdta.pro/images/b3f6fbfea99b8542e8a528277a435191.jpg'),
(74946, 5139, 'Shadows House S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200162.mp4', 'http://timg.bdta.pro/images/970a56521621c153f740c313d6713726.jpg'),
(74947, 5139, 'Shadows House S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200163.mp4', 'http://timg.bdta.pro/images/35a793206f908209387e1cf396726fa8.jpg'),
(74948, 5139, 'Shadows House S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200164.mp4', 'http://timg.bdta.pro/images/122e841b50391a44ee35e4661360e6cd.jpg'),
(74949, 5139, 'Shadows House S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200165.mp4', 'http://timg.bdta.pro/images/aa693c09598e5195c3dcbd1459b05314.jpg'),
(74950, 5139, 'Shadows House S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200166.mp4', 'http://timg.bdta.pro/images/90c6eab7ac54b6289fa85c62b0bb11c0.jpg'),
(74951, 5140, 'com Papa Francisco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fBsXeZqyrOIaz96r4TrO1B15AW8.jpg'),
(74952, 5140, 'com Papa Francisco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ZrAs7wBXUhFpwZaVbT4lBQW8BC.jpg'),
(74953, 5140, 'com Papa Francisco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g5INSXZAKu6KaV0u613afczHUKj.jpg'),
(74954, 5140, 'com Papa Francisco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yBBbxz3J8hLiWWHDntf07Ws7Q0W.jpg'),
(74955, 5141, 'The Archie Show S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ija9ATl6OuIggbXCo6cooIRr5BW.jpg'),
(74956, 5141, 'The Archie Show S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzRUnbtEULQOi1BGknsBDWoNcIx.jpg'),
(74957, 5141, 'The Archie Show S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sLRWH776J7sZtuUJIqiSgHF3KEv.jpg'),
(74958, 5141, 'The Archie Show S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9bm17GDRVaQL8Va9RXESYXtyrKL.jpg'),
(74959, 5141, 'The Archie Show S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cuktmF2gGP4nDXwG0eX3bE1UMDj.jpg'),
(74960, 5141, 'The Archie Show S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nWe6OSd0ItGJbUkNybfjCPQCPdL.jpg'),
(74961, 5141, 'The Archie Show S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cHqH0liCXI88u5AEbo7EentwQKZ.jpg'),
(74962, 5141, 'The Archie Show S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uERGk9TVu8Z54feqaniOtOt91jF.jpg'),
(74963, 5141, 'The Archie Show S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/168928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o4T7uPz4JbV77o8E4LaCZKAwgnM.jpg'),
(74964, 5141, 'The Archie Show S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/168929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4QwCn2InoV6k6YbaATn2W3Gz5E9.jpg'),
(74965, 5141, 'The Archie Show S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/168930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lB18US03OGzZ89GXq661o3On8BH.jpg'),
(74966, 5141, 'The Archie Show S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/168931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8TPPT43QIImjlgJWfah4fGG4gy.jpg'),
(74967, 5141, 'The Archie Show S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/168932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eNNvoCy7ZElwIGYbqpFh46CQj9Z.jpg'),
(74968, 5141, 'The Archie Show S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/168933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1wTcY4qifAizQy1X4Eg9owZ4bwI.jpg'),
(74969, 5141, 'The Archie Show S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/168934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b00H1yPNwbVpW5CswXgcZD2ozin.jpg'),
(74970, 5141, 'The Archie Show S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/168935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mKfK2jQH0axpSaovx7Hs9UsZUuY.jpg'),
(74971, 5141, 'The Archie Show S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/168936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGgOQvHItAnCXffOfya8d3FTpqJ.jpg'),
(74972, 5141, 'The Archie Show S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/168937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2lLhwR7nMpIEzBt8IJGE97eAGFD.jpg'),
(74973, 5141, 'The Archie Show S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/168938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2lLhwR7nMpIEzBt8IJGE97eAGFD.jpg'),
(74974, 5141, 'The Archie Show S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/168939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2lLhwR7nMpIEzBt8IJGE97eAGFD.jpg'),
(74975, 5141, 'The Archie Show S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/168940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2lLhwR7nMpIEzBt8IJGE97eAGFD.jpg'),
(74976, 5141, 'The Archie Show S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/168941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2lLhwR7nMpIEzBt8IJGE97eAGFD.jpg'),
(74977, 5141, 'The Archie Show S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/168942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2lLhwR7nMpIEzBt8IJGE97eAGFD.jpg'),
(74978, 5141, 'The Archie Show S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/168943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2lLhwR7nMpIEzBt8IJGE97eAGFD.jpg'),
(74979, 5141, 'The Archie Show S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/168944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2lLhwR7nMpIEzBt8IJGE97eAGFD.jpg'),
(74980, 5141, 'The Archie Show S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/168945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2lLhwR7nMpIEzBt8IJGE97eAGFD.jpg'),
(74981, 5141, 'The Archie Show S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/168946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2lLhwR7nMpIEzBt8IJGE97eAGFD.jpg'),
(74982, 5141, 'The Archie Show S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/168947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2lLhwR7nMpIEzBt8IJGE97eAGFD.jpg'),
(74983, 5141, 'The Archie Show S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/168948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2lLhwR7nMpIEzBt8IJGE97eAGFD.jpg'),
(74984, 5141, 'The Archie Show S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/168949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2lLhwR7nMpIEzBt8IJGE97eAGFD.jpg'),
(74985, 5141, 'The Archie Show S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/168950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2lLhwR7nMpIEzBt8IJGE97eAGFD.jpg'),
(74986, 5141, 'The Archie Show S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/168951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2lLhwR7nMpIEzBt8IJGE97eAGFD.jpg'),
(74987, 5141, 'The Archie Show S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/168952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2lLhwR7nMpIEzBt8IJGE97eAGFD.jpg'),
(74988, 5141, 'The Archie Show S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/168953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2lLhwR7nMpIEzBt8IJGE97eAGFD.jpg'),
(74989, 5142, 'The Choe Show S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9iwLI4pZ0441kFEhi2rZ713mmjc.jpg'),
(74990, 5142, 'The Choe Show S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Wbsks03NKl2UfjXrBqGAFLvbtd.jpg'),
(74991, 5142, 'The Choe Show S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYqdw01J4rnLk22M67oqu9zxF9o.jpg'),
(74992, 5142, 'The Choe Show S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3brH7KrAgCWgEPJKfvIn5MC7sjt.jpg'),
(74993, 5143, 'Vida dos Suricatos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bzZcgBjvi5up1Xu7u1b05XkCKMp.jpg'),
(74994, 5143, 'Vida dos Suricatos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qDH4bHl5zEeR4kKGDWyizWQPrlI.jpg'),
(74995, 5143, 'Vida dos Suricatos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4nQZVhKwehRFUHnLTpyBixTh92k.jpg'),
(74996, 5143, 'Vida dos Suricatos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2RqbDhdU3i9Hpf0qpCWF8QI0s1h.jpg'),
(74997, 5143, 'Vida dos Suricatos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5BrFNtaUSlcXrhc0vVGiKfze1mW.jpg'),
(74998, 5143, 'Vida dos Suricatos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tGqkYC1IizyQMWYUn2cM5gRIsjK.jpg'),
(74999, 5144, 'Vinte e Poucos Anos: Em Austin S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4QdMD2jNeDEwe5438Kt9ltYnAI3.jpg'),
(75000, 5144, 'Vinte e Poucos Anos: Em Austin S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4QdMD2jNeDEwe5438Kt9ltYnAI3.jpg'),
(75001, 5144, 'Vinte e Poucos Anos: Em Austin S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4QdMD2jNeDEwe5438Kt9ltYnAI3.jpg'),
(75002, 5144, 'Vinte e Poucos Anos: Em Austin S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4QdMD2jNeDEwe5438Kt9ltYnAI3.jpg'),
(75003, 5144, 'Vinte e Poucos Anos: Em Austin S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4QdMD2jNeDEwe5438Kt9ltYnAI3.jpg'),
(75004, 5144, 'Vinte e Poucos Anos: Em Austin S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4QdMD2jNeDEwe5438Kt9ltYnAI3.jpg'),
(75005, 5144, 'Vinte e Poucos Anos: Em Austin S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4QdMD2jNeDEwe5438Kt9ltYnAI3.jpg'),
(75006, 5144, 'Vinte e Poucos Anos: Em Austin S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4QdMD2jNeDEwe5438Kt9ltYnAI3.jpg'),
(75007, 5144, 'Vinte e Poucos Anos: Em Austin S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/168906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4QdMD2jNeDEwe5438Kt9ltYnAI3.jpg'),
(75008, 5144, 'Vinte e Poucos Anos: Em Austin S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/168907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4QdMD2jNeDEwe5438Kt9ltYnAI3.jpg'),
(75009, 5144, 'Vinte e Poucos Anos: Em Austin S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/168908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4QdMD2jNeDEwe5438Kt9ltYnAI3.jpg'),
(75010, 5144, 'Vinte e Poucos Anos: Em Austin S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/168909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4QdMD2jNeDEwe5438Kt9ltYnAI3.jpg'),
(75011, 5145, 'Wakefield S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6bkarFLWZdzkgEASLV0aw1DwqFF.jpg'),
(75012, 5145, 'Wakefield S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/46yAY9QDcQ1Ora7BTLNt0A6WeSz.jpg'),
(75013, 5145, 'Wakefield S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rhUhpXdvhqg38F0fusf01F57odk.jpg'),
(75014, 5145, 'Wakefield S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kwXLZKdcjc9TgzqW7kJXoukpzJw.jpg'),
(75015, 5145, 'Wakefield S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dFTXUqUS2HIHi4YGM4Kk8VzbL4h.jpg'),
(75016, 5145, 'Wakefield S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0kStQQ79PNnGRU4nAU4DRqCF6C.jpg'),
(75017, 5145, 'Wakefield S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wwWM5xtvkUWLVXGkJRwJcmTqa8W.jpg'),
(75018, 5145, 'Wakefield S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xqmAOWlJk2ebABWzhyr3glK8qaS.jpg'),
(75019, 5146, 'COBRA S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rgpyQPt5P8wH3DjotUa667E7BW3.jpg'),
(75020, 5146, 'COBRA S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/orzub0dAGWOXvY47jqX0HIa5gct.jpg'),
(75021, 5146, 'COBRA S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tkxK3SKtPpn7oMBZ4bNqDk0bsou.jpg'),
(75022, 5146, 'COBRA S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cdt4yQC6LdZH3Fh7BvpRXeAJ6zP.jpg'),
(75023, 5146, 'COBRA S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l69uEKH6kn2cfAZFm3s8UE4wEEH.jpg'),
(75024, 5146, 'COBRA S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t9H8cUxl8ld91N7t1HqiG3ksbaS.jpg'),
(75025, 5147, 'COBRA S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu44VNAq6yhQi0PamsSXXYS1sLr.jpg'),
(75026, 5147, 'COBRA S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu44VNAq6yhQi0PamsSXXYS1sLr.jpg'),
(75027, 5147, 'COBRA S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu44VNAq6yhQi0PamsSXXYS1sLr.jpg'),
(75028, 5147, 'COBRA S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu44VNAq6yhQi0PamsSXXYS1sLr.jpg'),
(75029, 5147, 'COBRA S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu44VNAq6yhQi0PamsSXXYS1sLr.jpg'),
(75030, 5147, 'COBRA S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu44VNAq6yhQi0PamsSXXYS1sLr.jpg'),
(75031, 5148, 'Girls5eva S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/XaSYVEGwm974zpYljBEjG4OqL.jpg'),
(75032, 5148, 'Girls5eva S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/giRUC9EMo0U3NnODxAp7sKbe8I4.jpg'),
(75033, 5148, 'Girls5eva S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hrvXVbERorKY6MhQslmPTUrzPo2.jpg'),
(75034, 5148, 'Girls5eva S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sqY4ijzv6G5HtBAh9gCtiIEfWPH.jpg'),
(75035, 5148, 'Girls5eva S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kJpPCa3cwhN9hn2G8iqY7YCYlU2.jpg'),
(75036, 5148, 'Girls5eva S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOQ4zjYvI2lACflJkHd1V4oaj9T.jpg'),
(75037, 5148, 'Girls5eva S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b1pm4Km0QfnqgeWSAzyjnNa8x9r.jpg'),
(75038, 5148, 'Girls5eva S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ziM7w8fBJoZGR0mc95JsO1FGbX6.jpg'),
(75039, 5149, 'Girls5eva S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/303495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVFu4hVzFfnW1C16tmBS4v4g8fc.jpg'),
(75040, 5149, 'Girls5eva S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/303496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVFu4hVzFfnW1C16tmBS4v4g8fc.jpg'),
(75041, 5149, 'Girls5eva S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/303497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVFu4hVzFfnW1C16tmBS4v4g8fc.jpg'),
(75042, 5149, 'Girls5eva S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/303498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVFu4hVzFfnW1C16tmBS4v4g8fc.jpg'),
(75043, 5149, 'Girls5eva S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/303499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVFu4hVzFfnW1C16tmBS4v4g8fc.jpg'),
(75044, 5149, 'Girls5eva S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/303500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVFu4hVzFfnW1C16tmBS4v4g8fc.jpg'),
(75045, 5149, 'Girls5eva S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/303501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVFu4hVzFfnW1C16tmBS4v4g8fc.jpg'),
(75046, 5149, 'Girls5eva S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/303502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVFu4hVzFfnW1C16tmBS4v4g8fc.jpg'),
(75047, 5150, 'Girls5eva S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/303503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVFu4hVzFfnW1C16tmBS4v4g8fc.jpg'),
(75048, 5150, 'Girls5eva S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/303504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVFu4hVzFfnW1C16tmBS4v4g8fc.jpg'),
(75049, 5150, 'Girls5eva S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/303505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVFu4hVzFfnW1C16tmBS4v4g8fc.jpg'),
(75050, 5150, 'Girls5eva S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/303506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVFu4hVzFfnW1C16tmBS4v4g8fc.jpg'),
(75051, 5150, 'Girls5eva S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/303507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVFu4hVzFfnW1C16tmBS4v4g8fc.jpg'),
(75052, 5150, 'Girls5eva S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/303508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVFu4hVzFfnW1C16tmBS4v4g8fc.jpg'),
(75053, 5151, 'Keeping Up With the Kardashians [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zCRRZFziQR3Hzz2diB7Ghx0XzwQ.jpg'),
(75054, 5151, 'Keeping Up With the Kardashians [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a0KqPjJUfxvnwzVvqAwLkCRZNEh.jpg'),
(75055, 5151, 'Keeping Up With the Kardashians [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gFmM24l1aSbXetBqgMulgj5FhKR.jpg'),
(75056, 5151, 'Keeping Up With the Kardashians [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4HxCaIhZC4PR8dqSb7NG8uJZc4O.jpg'),
(75057, 5151, 'Keeping Up With the Kardashians [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9gQj6BAzdzph2AfTD8RGkq3M4y.jpg'),
(75058, 5151, 'Keeping Up With the Kardashians [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2C5JucbSL4uOEjx3PrB82rxtWVX.jpg'),
(75059, 5151, 'Keeping Up With the Kardashians [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yVxb9NbLHRzU26JYRZA2QHJqLtJ.jpg'),
(75060, 5151, 'Keeping Up With the Kardashians [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6lUUHgcAYlfRwsbUCOLgcxoy8N7.jpg'),
(75061, 5152, 'Montanha da Morte: O Incidente na Passagem Dyatlov S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8tOXF0Pw3KrYMWf0kmIvGgeervY.jpg'),
(75062, 5152, 'Montanha da Morte: O Incidente na Passagem Dyatlov S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iH1kP48N9WPZMP8OIxu0D6XOlsN.jpg'),
(75063, 5152, 'Montanha da Morte: O Incidente na Passagem Dyatlov S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Moev2jRIPAP9w3zgEGYmr8Uu23.jpg'),
(75064, 5152, 'Montanha da Morte: O Incidente na Passagem Dyatlov S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rWVhPnkIZMz6GQjkIiK45Y0ERit.jpg'),
(75065, 5152, 'Montanha da Morte: O Incidente na Passagem Dyatlov S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kLMkaYrl4QU0NrSryhOpEQb0jvk.jpg'),
(75066, 5152, 'Montanha da Morte: O Incidente na Passagem Dyatlov S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mAcfdisfoAzsYjvfkMOXskjREgJ.jpg'),
(75067, 5152, 'Montanha da Morte: O Incidente na Passagem Dyatlov S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nlTHn9hvj7tRnjlQOpANZGhlihI.jpg'),
(75068, 5152, 'Montanha da Morte: O Incidente na Passagem Dyatlov S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cTyuOzJ1V770KoJa56ft0DBz0s8.jpg'),
(75069, 5153, 'Nostradamus: Fim dos Dias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xGzc0ThqzCsmJMjFuHmm0v35V6v.jpg'),
(75070, 5153, 'Nostradamus: Fim dos Dias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xGzc0ThqzCsmJMjFuHmm0v35V6v.jpg'),
(75071, 5153, 'Nostradamus: Fim dos Dias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xGzc0ThqzCsmJMjFuHmm0v35V6v.jpg'),
(75072, 5153, 'Nostradamus: Fim dos Dias S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xGzc0ThqzCsmJMjFuHmm0v35V6v.jpg'),
(75073, 5153, 'Nostradamus: Fim dos Dias S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xGzc0ThqzCsmJMjFuHmm0v35V6v.jpg'),
(75074, 5153, 'Nostradamus: Fim dos Dias S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xGzc0ThqzCsmJMjFuHmm0v35V6v.jpg'),
(75075, 5153, 'Nostradamus: Fim dos Dias S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xGzc0ThqzCsmJMjFuHmm0v35V6v.jpg'),
(75076, 5153, 'Nostradamus: Fim dos Dias S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xGzc0ThqzCsmJMjFuHmm0v35V6v.jpg'),
(75077, 5154, 'Nua e Crua S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6xGNgNHCG4wrqbNkhedu0MGyGXJ.jpg'),
(75078, 5154, 'Nua e Crua S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uuWZhgF7V8KWzfFqgPyjpSazPWv.jpg'),
(75079, 5154, 'Nua e Crua S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gWuJKFfUAStp7ry5zrCu6E3bT3o.jpg'),
(75080, 5154, 'Nua e Crua S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bpL1zpHrVqmNIHEmC6yUi7cN0C.jpg'),
(75081, 5154, 'Nua e Crua S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e7AXqrHXQezsPOs5YyM1suFLyAZ.jpg'),
(75082, 5154, 'Nua e Crua S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v7XbBz3AtbfD6ytJ37OzoyRYQA2.jpg'),
(75083, 5154, 'Nua e Crua S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yl7BdxpVZ2r65KHPFNrwjFtGXjk.jpg'),
(75084, 5154, 'Nua e Crua S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vxFu2EsM0O9HNn67iMJ50zn1o9X.jpg'),
(75085, 5155, 'O Despertar das Tartarugas Ninja S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cHEhvL3a2jkWehXFdpwCGiNs2V.jpg'),
(75086, 5155, 'O Despertar das Tartarugas Ninja S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9CgoMDJiPxC0rrkFEAdTqW2sI0N.jpg'),
(75087, 5155, 'O Despertar das Tartarugas Ninja S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rWaGdTqYneLce3eLSGoos6Syc5F.jpg'),
(75088, 5155, 'O Despertar das Tartarugas Ninja S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5R3BlVCvWss8cjbO9nPrnGmgSP4.jpg'),
(75089, 5155, 'O Despertar das Tartarugas Ninja S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aG774pg46I93FNCkPofzAPJPx5h.jpg'),
(75090, 5155, 'O Despertar das Tartarugas Ninja S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e4dPgdmpOIMcNxfv0Hvt7reCbjs.jpg'),
(75091, 5155, 'O Despertar das Tartarugas Ninja S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKqyuCYLyVxb99hMRmQFstGP5B3.jpg'),
(75092, 5155, 'O Despertar das Tartarugas Ninja S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tKUUEQgNftzkdVs6V8zhVSobO9h.jpg'),
(75093, 5155, 'O Despertar das Tartarugas Ninja S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/168214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDrkto3iI7BFKm9NPdM0s1qKS4x.jpg'),
(75094, 5155, 'O Despertar das Tartarugas Ninja S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/168215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jMv3ZPWEy4HBjynT0RqMt0A6ibf.jpg'),
(75095, 5155, 'O Despertar das Tartarugas Ninja S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/168216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/caXYs8fY1Iw6QQ2CZtLXY5STHXl.jpg'),
(75096, 5155, 'O Despertar das Tartarugas Ninja S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/168217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qNkOvqH1L6Jfogs5lnoXwFZr6vP.jpg'),
(75097, 5155, 'O Despertar das Tartarugas Ninja S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/168218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6JQ8onztqkgVVBpH81w6Y6qodmP.jpg'),
(75098, 5155, 'O Despertar das Tartarugas Ninja S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/168219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fR0hK7WA9MEVu74fLoaVMF6dsHw.jpg'),
(75099, 5155, 'O Despertar das Tartarugas Ninja S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/168220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4LZxcn6nWG1yWBKG0RD98HY13b4.jpg'),
(75100, 5155, 'O Despertar das Tartarugas Ninja S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/168221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4LZxcn6nWG1yWBKG0RD98HY13b4.jpg'),
(75101, 5155, 'O Despertar das Tartarugas Ninja S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/168222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4LZxcn6nWG1yWBKG0RD98HY13b4.jpg'),
(75102, 5155, 'O Despertar das Tartarugas Ninja S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/168223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4LZxcn6nWG1yWBKG0RD98HY13b4.jpg'),
(75103, 5155, 'O Despertar das Tartarugas Ninja S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/168224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4LZxcn6nWG1yWBKG0RD98HY13b4.jpg'),
(75104, 5155, 'O Despertar das Tartarugas Ninja S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/168225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4LZxcn6nWG1yWBKG0RD98HY13b4.jpg'),
(75105, 5155, 'O Despertar das Tartarugas Ninja S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/168226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4LZxcn6nWG1yWBKG0RD98HY13b4.jpg'),
(75106, 5155, 'O Despertar das Tartarugas Ninja S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/168227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4LZxcn6nWG1yWBKG0RD98HY13b4.jpg'),
(75107, 5155, 'O Despertar das Tartarugas Ninja S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/168228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4LZxcn6nWG1yWBKG0RD98HY13b4.jpg'),
(75108, 5155, 'O Despertar das Tartarugas Ninja S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/168229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4LZxcn6nWG1yWBKG0RD98HY13b4.jpg'),
(75109, 5155, 'O Despertar das Tartarugas Ninja S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/168230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4LZxcn6nWG1yWBKG0RD98HY13b4.jpg'),
(75110, 5155, 'O Despertar das Tartarugas Ninja S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/168231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4LZxcn6nWG1yWBKG0RD98HY13b4.jpg'),
(75111, 5156, 'O Marinheiro Popeye S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3gupsOp6O0tsSPwMkWxGDWz943l.jpg'),
(75112, 5156, 'O Marinheiro Popeye S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v7iNo7PoZdGxhud0IVtr6w19Cti.jpg'),
(75113, 5156, 'O Marinheiro Popeye S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ys8sDPlyUijBYjjUOrvcdMF0dPx.jpg'),
(75114, 5156, 'O Marinheiro Popeye S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75115, 5156, 'O Marinheiro Popeye S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75116, 5156, 'O Marinheiro Popeye S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gUDHKNVykr91jXwPfBUedP8SuSw.jpg'),
(75117, 5156, 'O Marinheiro Popeye S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75118, 5156, 'O Marinheiro Popeye S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jLFekah5zYT596WLMb1mCB99Pbp.jpg'),
(75119, 5156, 'O Marinheiro Popeye S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75120, 5156, 'O Marinheiro Popeye S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uml0srbrY7oU24IGmQcFmtHEXcu.jpg'),
(75121, 5156, 'O Marinheiro Popeye S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75122, 5156, 'O Marinheiro Popeye S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xtNp9NG2hr0ySqAZbVmKyBaW4UH.jpg'),
(75123, 5156, 'O Marinheiro Popeye S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75124, 5156, 'O Marinheiro Popeye S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75125, 5156, 'O Marinheiro Popeye S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75126, 5156, 'O Marinheiro Popeye S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2aULWu1pZ54owGtTS5N2xADKTqZ.jpg'),
(75127, 5156, 'O Marinheiro Popeye S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tSH0lQY7cs08C8NoaVGMjlBknom.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(75128, 5156, 'O Marinheiro Popeye S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75129, 5156, 'O Marinheiro Popeye S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/loUTA58iFNRovhLXWjoEPFHzqZZ.jpg'),
(75130, 5156, 'O Marinheiro Popeye S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4kQsssFmpoHAKEkirMOQupuxxqI.jpg'),
(75131, 5156, 'O Marinheiro Popeye S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/167786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75132, 5156, 'O Marinheiro Popeye S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/167787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6wUrHP8S5WG7LEW7Lzty0hgOqGa.jpg'),
(75133, 5156, 'O Marinheiro Popeye S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/167788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75134, 5156, 'O Marinheiro Popeye S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/167789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75135, 5156, 'O Marinheiro Popeye S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/167790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nZ6M201O0D9alApxQyJDcyMkZaS.jpg'),
(75136, 5156, 'O Marinheiro Popeye S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/167791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75137, 5156, 'O Marinheiro Popeye S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/167792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75138, 5156, 'O Marinheiro Popeye S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/167793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75139, 5156, 'O Marinheiro Popeye S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/167794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75140, 5156, 'O Marinheiro Popeye S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/167795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75141, 5156, 'O Marinheiro Popeye S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/167796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75142, 5156, 'O Marinheiro Popeye S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/167797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75143, 5156, 'O Marinheiro Popeye S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/167798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75144, 5156, 'O Marinheiro Popeye S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/167799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bha3tc20mmAoPW6jhzqBs8OLyCL.jpg'),
(75145, 5156, 'O Marinheiro Popeye S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/167800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y7fNPna73tbjgFM7LMgmyQvwnQC.jpg'),
(75146, 5156, 'O Marinheiro Popeye S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/167801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75147, 5156, 'O Marinheiro Popeye S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/167802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75148, 5156, 'O Marinheiro Popeye S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/167803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75149, 5156, 'O Marinheiro Popeye S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/167804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75150, 5156, 'O Marinheiro Popeye S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/167805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75151, 5156, 'O Marinheiro Popeye S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/167806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75152, 5156, 'O Marinheiro Popeye S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/167807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75153, 5156, 'O Marinheiro Popeye S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/167808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75154, 5156, 'O Marinheiro Popeye S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/167809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75155, 5156, 'O Marinheiro Popeye S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/167810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1zhlzEN0ymtJZ4YJNiq2Li2r3Hq.jpg'),
(75156, 5156, 'O Marinheiro Popeye S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/167811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75157, 5156, 'O Marinheiro Popeye S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/167812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75158, 5156, 'O Marinheiro Popeye S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/167813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75159, 5156, 'O Marinheiro Popeye S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/167814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75160, 5156, 'O Marinheiro Popeye S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/167815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75161, 5156, 'O Marinheiro Popeye S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/167816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bq4WcRV4Ebh479t1zjR6CBt2JeF.jpg'),
(75162, 5156, 'O Marinheiro Popeye S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/167817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lcj1iMTTqU17EzaCTOMqwNPqMXT.jpg'),
(75163, 5156, 'O Marinheiro Popeye S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/167818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75164, 5156, 'O Marinheiro Popeye S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/167819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75165, 5156, 'O Marinheiro Popeye S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/167820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75166, 5156, 'O Marinheiro Popeye S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/167821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75167, 5156, 'O Marinheiro Popeye S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/167822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75168, 5156, 'O Marinheiro Popeye S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/167823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75169, 5156, 'O Marinheiro Popeye S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/167824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75170, 5156, 'O Marinheiro Popeye S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/167825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dUMoPZUSbLxZLw1nQHV1wHB2WNv.jpg'),
(75171, 5156, 'O Marinheiro Popeye S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/167826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75172, 5156, 'O Marinheiro Popeye S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/167827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75173, 5156, 'O Marinheiro Popeye S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/167828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75174, 5156, 'O Marinheiro Popeye S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/167829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75175, 5156, 'O Marinheiro Popeye S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/167830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75176, 5156, 'O Marinheiro Popeye S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/167831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75177, 5156, 'O Marinheiro Popeye S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/167832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75178, 5156, 'O Marinheiro Popeye S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/167833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75179, 5156, 'O Marinheiro Popeye S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/167834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75180, 5156, 'O Marinheiro Popeye S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/167835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75181, 5156, 'O Marinheiro Popeye S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/167836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75182, 5156, 'O Marinheiro Popeye S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/167837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75183, 5156, 'O Marinheiro Popeye S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/167838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qNCCv8hnVGPIJIqxu4CEZFBpEKU.jpg'),
(75184, 5156, 'O Marinheiro Popeye S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/167839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0Wx1VuauTmo58Q7sjlZZ7cxWIK.jpg'),
(75185, 5156, 'O Marinheiro Popeye S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/167840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75186, 5156, 'O Marinheiro Popeye S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/167841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75187, 5156, 'O Marinheiro Popeye S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/167842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75188, 5156, 'O Marinheiro Popeye S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/167843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AaIiVAOVXUHVfEpl0NHyARvySNo.jpg'),
(75189, 5156, 'O Marinheiro Popeye S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/167844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75190, 5156, 'O Marinheiro Popeye S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/167845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75191, 5156, 'O Marinheiro Popeye S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/167846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75192, 5156, 'O Marinheiro Popeye S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/167847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cStBjtUg52oz6GQKhUkhWeOGxme.jpg'),
(75193, 5156, 'O Marinheiro Popeye S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/167848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75194, 5156, 'O Marinheiro Popeye S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/167849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75195, 5156, 'O Marinheiro Popeye S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/167850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bwJPtgAAkZfJbx8JOI6Q73hjQUt.jpg'),
(75196, 5156, 'O Marinheiro Popeye S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/167851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75197, 5156, 'O Marinheiro Popeye S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/167852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75198, 5156, 'O Marinheiro Popeye S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/167853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8p3EGvZVFHcKHOVpAhPnim7EuHU.jpg'),
(75199, 5156, 'O Marinheiro Popeye S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/167854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75200, 5156, 'O Marinheiro Popeye S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/167855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75201, 5156, 'O Marinheiro Popeye S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/167856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75202, 5156, 'O Marinheiro Popeye S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/167857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wkpQaW2v8cLOb9CtqVTJwy9XsKh.jpg'),
(75203, 5156, 'O Marinheiro Popeye S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/167858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75204, 5156, 'O Marinheiro Popeye S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/167859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75205, 5156, 'O Marinheiro Popeye S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/167860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75206, 5156, 'O Marinheiro Popeye S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/167861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75207, 5156, 'O Marinheiro Popeye S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/167862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75208, 5156, 'O Marinheiro Popeye S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/167863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hL6fapcWOsKqW4ZIJtlkNhKhXTV.jpg'),
(75209, 5156, 'O Marinheiro Popeye S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/167864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75210, 5156, 'O Marinheiro Popeye S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/167865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75211, 5156, 'O Marinheiro Popeye S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/167866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75212, 5156, 'O Marinheiro Popeye S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/167867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3vWpTkHAPxfkUNdAxVNUpc7PVsm.jpg'),
(75213, 5156, 'O Marinheiro Popeye S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/167868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75214, 5156, 'O Marinheiro Popeye S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/167869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75215, 5156, 'O Marinheiro Popeye S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/167870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ihncH7FC5mtEYrsCHk9gBgosDmh.jpg'),
(75216, 5156, 'O Marinheiro Popeye S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/167871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j1DTlKFhtdr3X2rOt0T2AwK2f75.jpg'),
(75217, 5156, 'O Marinheiro Popeye S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/167872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75218, 5157, 'O Marinheiro Popeye S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wDeTpoamFZ9sHRwqClywb4OCkzN.jpg'),
(75219, 5157, 'O Marinheiro Popeye S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75220, 5157, 'O Marinheiro Popeye S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qrYpKHJBlzplXmClBNUIxpAOBP5.jpg'),
(75221, 5157, 'O Marinheiro Popeye S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udUJxpJSaRCvezki5h1HWqlQK5s.jpg'),
(75222, 5157, 'O Marinheiro Popeye S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jnJYPOiYaXtUpEuUNvqy3hwQBr8.jpg'),
(75223, 5157, 'O Marinheiro Popeye S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75224, 5157, 'O Marinheiro Popeye S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75225, 5157, 'O Marinheiro Popeye S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75226, 5157, 'O Marinheiro Popeye S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hXnHwvJ277gcW68RBJknUBhKRl6.jpg'),
(75227, 5157, 'O Marinheiro Popeye S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mi0qShZDLHY1vn4idbvevUURqTE.jpg'),
(75228, 5157, 'O Marinheiro Popeye S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75229, 5157, 'O Marinheiro Popeye S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y2a8MVeksa201lxRHFVN1At6K4d.jpg'),
(75230, 5157, 'O Marinheiro Popeye S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r9dLwD1jvEmTVOown9WxWlk0qrL.jpg'),
(75231, 5157, 'O Marinheiro Popeye S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75232, 5157, 'O Marinheiro Popeye S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fyEfhrtvdd2cTjggGrCvDpRVohC.jpg'),
(75233, 5157, 'O Marinheiro Popeye S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75234, 5157, 'O Marinheiro Popeye S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gzQRu4LyuFaY09giF0HJRW5WNqr.jpg'),
(75235, 5157, 'O Marinheiro Popeye S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eoyvhb0cH3wigNuWsaPW6La2B1L.jpg'),
(75236, 5157, 'O Marinheiro Popeye S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6RPsWvXZttxHcpixCAtbvfY9JKL.jpg'),
(75237, 5157, 'O Marinheiro Popeye S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75238, 5157, 'O Marinheiro Popeye S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/167893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mEhiw2WUKBrvv48hWp9ZLVTDAcm.jpg'),
(75239, 5157, 'O Marinheiro Popeye S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/167894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBd39vpjjIC21flUB39vHLQhrWU.jpg'),
(75240, 5157, 'O Marinheiro Popeye S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/167895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75241, 5157, 'O Marinheiro Popeye S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/167896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75242, 5157, 'O Marinheiro Popeye S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/167897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75243, 5157, 'O Marinheiro Popeye S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/167898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75244, 5157, 'O Marinheiro Popeye S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/167899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75245, 5157, 'O Marinheiro Popeye S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/167900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kEQlg1LYd6BSRJoUEMK9k8v2kJV.jpg'),
(75246, 5157, 'O Marinheiro Popeye S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/167901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9E03X4m0aua4C3YbCRJ7Ku4CMrL.jpg'),
(75247, 5157, 'O Marinheiro Popeye S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/167902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6rBJ4ncHbhNzfengVQMC7aVODm1.jpg'),
(75248, 5157, 'O Marinheiro Popeye S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/167903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rcA2gybj8r2QJHgmbWIdVFDCLFS.jpg'),
(75249, 5157, 'O Marinheiro Popeye S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/167904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75250, 5157, 'O Marinheiro Popeye S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/167905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75251, 5157, 'O Marinheiro Popeye S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/167906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75252, 5157, 'O Marinheiro Popeye S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/167907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75253, 5157, 'O Marinheiro Popeye S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/167908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sGdAsqC5gi9vLRlegbulaab2qmn.jpg'),
(75254, 5157, 'O Marinheiro Popeye S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/167909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nmquumqVPT689rA3MM5EMIL9wdP.jpg'),
(75255, 5157, 'O Marinheiro Popeye S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/167910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75256, 5157, 'O Marinheiro Popeye S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/167911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kdUm4CBx3b7vjQqlTkNAlyGcgHs.jpg'),
(75257, 5157, 'O Marinheiro Popeye S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/167912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75258, 5157, 'O Marinheiro Popeye S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/167913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75259, 5157, 'O Marinheiro Popeye S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/167914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75260, 5157, 'O Marinheiro Popeye S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/167915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75261, 5157, 'O Marinheiro Popeye S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/167916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75262, 5157, 'O Marinheiro Popeye S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/167917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75263, 5157, 'O Marinheiro Popeye S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/167918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4vMFJRGDjKQKzhMGQh39ZZCIIDM.jpg'),
(75264, 5157, 'O Marinheiro Popeye S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/167919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75265, 5157, 'O Marinheiro Popeye S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/167920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75266, 5157, 'O Marinheiro Popeye S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/167921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75267, 5157, 'O Marinheiro Popeye S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/167922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75268, 5157, 'O Marinheiro Popeye S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/167923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75269, 5157, 'O Marinheiro Popeye S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/167924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75270, 5157, 'O Marinheiro Popeye S02 E53', 'http://sinalprivado.info:80/series/1533784/1533784/167925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75271, 5157, 'O Marinheiro Popeye S02 E54', 'http://sinalprivado.info:80/series/1533784/1533784/167926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75272, 5157, 'O Marinheiro Popeye S02 E55', 'http://sinalprivado.info:80/series/1533784/1533784/167927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75273, 5157, 'O Marinheiro Popeye S02 E56', 'http://sinalprivado.info:80/series/1533784/1533784/167928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75274, 5157, 'O Marinheiro Popeye S02 E57', 'http://sinalprivado.info:80/series/1533784/1533784/167929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75275, 5157, 'O Marinheiro Popeye S02 E58', 'http://sinalprivado.info:80/series/1533784/1533784/167930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75276, 5157, 'O Marinheiro Popeye S02 E59', 'http://sinalprivado.info:80/series/1533784/1533784/167931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75277, 5157, 'O Marinheiro Popeye S02 E60', 'http://sinalprivado.info:80/series/1533784/1533784/167932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75278, 5157, 'O Marinheiro Popeye S02 E61', 'http://sinalprivado.info:80/series/1533784/1533784/167933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75279, 5157, 'O Marinheiro Popeye S02 E62', 'http://sinalprivado.info:80/series/1533784/1533784/167934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75280, 5157, 'O Marinheiro Popeye S02 E63', 'http://sinalprivado.info:80/series/1533784/1533784/167935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75281, 5157, 'O Marinheiro Popeye S02 E64', 'http://sinalprivado.info:80/series/1533784/1533784/167936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75282, 5157, 'O Marinheiro Popeye S02 E65', 'http://sinalprivado.info:80/series/1533784/1533784/167937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75283, 5157, 'O Marinheiro Popeye S02 E66', 'http://sinalprivado.info:80/series/1533784/1533784/167938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75284, 5157, 'O Marinheiro Popeye S02 E67', 'http://sinalprivado.info:80/series/1533784/1533784/167939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75285, 5157, 'O Marinheiro Popeye S02 E68', 'http://sinalprivado.info:80/series/1533784/1533784/167940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75286, 5157, 'O Marinheiro Popeye S02 E69', 'http://sinalprivado.info:80/series/1533784/1533784/167941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75287, 5157, 'O Marinheiro Popeye S02 E70', 'http://sinalprivado.info:80/series/1533784/1533784/167942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75288, 5157, 'O Marinheiro Popeye S02 E71', 'http://sinalprivado.info:80/series/1533784/1533784/167943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75289, 5157, 'O Marinheiro Popeye S02 E72', 'http://sinalprivado.info:80/series/1533784/1533784/167944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75290, 5157, 'O Marinheiro Popeye S02 E73', 'http://sinalprivado.info:80/series/1533784/1533784/167945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75291, 5157, 'O Marinheiro Popeye S02 E74', 'http://sinalprivado.info:80/series/1533784/1533784/167946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75292, 5157, 'O Marinheiro Popeye S02 E75', 'http://sinalprivado.info:80/series/1533784/1533784/167947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75293, 5157, 'O Marinheiro Popeye S02 E76', 'http://sinalprivado.info:80/series/1533784/1533784/167948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75294, 5157, 'O Marinheiro Popeye S02 E77', 'http://sinalprivado.info:80/series/1533784/1533784/167949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75295, 5157, 'O Marinheiro Popeye S02 E78', 'http://sinalprivado.info:80/series/1533784/1533784/167950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75296, 5157, 'O Marinheiro Popeye S02 E79', 'http://sinalprivado.info:80/series/1533784/1533784/167951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75297, 5157, 'O Marinheiro Popeye S02 E80', 'http://sinalprivado.info:80/series/1533784/1533784/167952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75298, 5157, 'O Marinheiro Popeye S02 E81', 'http://sinalprivado.info:80/series/1533784/1533784/167953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75299, 5157, 'O Marinheiro Popeye S02 E82', 'http://sinalprivado.info:80/series/1533784/1533784/167954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75300, 5157, 'O Marinheiro Popeye S02 E83', 'http://sinalprivado.info:80/series/1533784/1533784/167955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75301, 5157, 'O Marinheiro Popeye S02 E84', 'http://sinalprivado.info:80/series/1533784/1533784/167956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75302, 5157, 'O Marinheiro Popeye S02 E85', 'http://sinalprivado.info:80/series/1533784/1533784/167957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75303, 5157, 'O Marinheiro Popeye S02 E86', 'http://sinalprivado.info:80/series/1533784/1533784/167958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75304, 5157, 'O Marinheiro Popeye S02 E87', 'http://sinalprivado.info:80/series/1533784/1533784/167959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75305, 5157, 'O Marinheiro Popeye S02 E88', 'http://sinalprivado.info:80/series/1533784/1533784/167960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75306, 5157, 'O Marinheiro Popeye S02 E89', 'http://sinalprivado.info:80/series/1533784/1533784/167961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75307, 5157, 'O Marinheiro Popeye S02 E90', 'http://sinalprivado.info:80/series/1533784/1533784/167962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75308, 5157, 'O Marinheiro Popeye S02 E91', 'http://sinalprivado.info:80/series/1533784/1533784/167963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75309, 5157, 'O Marinheiro Popeye S02 E92', 'http://sinalprivado.info:80/series/1533784/1533784/167964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75310, 5157, 'O Marinheiro Popeye S02 E93', 'http://sinalprivado.info:80/series/1533784/1533784/167965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75311, 5157, 'O Marinheiro Popeye S02 E94', 'http://sinalprivado.info:80/series/1533784/1533784/167966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75312, 5157, 'O Marinheiro Popeye S02 E95', 'http://sinalprivado.info:80/series/1533784/1533784/167967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75313, 5157, 'O Marinheiro Popeye S02 E96', 'http://sinalprivado.info:80/series/1533784/1533784/167968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75314, 5157, 'O Marinheiro Popeye S02 E97', 'http://sinalprivado.info:80/series/1533784/1533784/167969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75315, 5157, 'O Marinheiro Popeye S02 E98', 'http://sinalprivado.info:80/series/1533784/1533784/167970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75316, 5157, 'O Marinheiro Popeye S02 E99', 'http://sinalprivado.info:80/series/1533784/1533784/167971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75317, 5157, 'O Marinheiro Popeye S02 E100', 'http://sinalprivado.info:80/series/1533784/1533784/167972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75318, 5157, 'O Marinheiro Popeye S02 E101', 'http://sinalprivado.info:80/series/1533784/1533784/167973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75319, 5157, 'O Marinheiro Popeye S02 E102', 'http://sinalprivado.info:80/series/1533784/1533784/167974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75320, 5157, 'O Marinheiro Popeye S02 E103', 'http://sinalprivado.info:80/series/1533784/1533784/167975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75321, 5157, 'O Marinheiro Popeye S02 E104', 'http://sinalprivado.info:80/series/1533784/1533784/167976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75322, 5157, 'O Marinheiro Popeye S02 E105', 'http://sinalprivado.info:80/series/1533784/1533784/167977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75323, 5157, 'O Marinheiro Popeye S02 E106', 'http://sinalprivado.info:80/series/1533784/1533784/167978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75324, 5157, 'O Marinheiro Popeye S02 E107', 'http://sinalprivado.info:80/series/1533784/1533784/167979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75325, 5157, 'O Marinheiro Popeye S02 E108', 'http://sinalprivado.info:80/series/1533784/1533784/167980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75326, 5157, 'O Marinheiro Popeye S02 E109', 'http://sinalprivado.info:80/series/1533784/1533784/167981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75327, 5157, 'O Marinheiro Popeye S02 E110', 'http://sinalprivado.info:80/series/1533784/1533784/167982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75328, 5157, 'O Marinheiro Popeye S02 E111', 'http://sinalprivado.info:80/series/1533784/1533784/167983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75329, 5157, 'O Marinheiro Popeye S02 E112', 'http://sinalprivado.info:80/series/1533784/1533784/167984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75330, 5157, 'O Marinheiro Popeye S02 E113', 'http://sinalprivado.info:80/series/1533784/1533784/167985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75331, 5157, 'O Marinheiro Popeye S02 E114', 'http://sinalprivado.info:80/series/1533784/1533784/167986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75332, 5158, 'O Marinheiro Popeye S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75333, 5158, 'O Marinheiro Popeye S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75334, 5158, 'O Marinheiro Popeye S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75335, 5158, 'O Marinheiro Popeye S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75336, 5158, 'O Marinheiro Popeye S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75337, 5158, 'O Marinheiro Popeye S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75338, 5158, 'O Marinheiro Popeye S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75339, 5158, 'O Marinheiro Popeye S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75340, 5158, 'O Marinheiro Popeye S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75341, 5158, 'O Marinheiro Popeye S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75342, 5158, 'O Marinheiro Popeye S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75343, 5158, 'O Marinheiro Popeye S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75344, 5158, 'O Marinheiro Popeye S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75345, 5158, 'O Marinheiro Popeye S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/168000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75346, 5158, 'O Marinheiro Popeye S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/168001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75347, 5158, 'O Marinheiro Popeye S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/168002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75348, 5158, 'O Marinheiro Popeye S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/168003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75349, 5158, 'O Marinheiro Popeye S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/168004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75350, 5158, 'O Marinheiro Popeye S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/168005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75351, 5158, 'O Marinheiro Popeye S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/168006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75352, 5158, 'O Marinheiro Popeye S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/168007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75353, 5158, 'O Marinheiro Popeye S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/168008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75354, 5158, 'O Marinheiro Popeye S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/168009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75355, 5158, 'O Marinheiro Popeye S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/168010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75356, 5158, 'O Marinheiro Popeye S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/168011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75357, 5158, 'O Marinheiro Popeye S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/168012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75358, 5158, 'O Marinheiro Popeye S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/168013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75359, 5158, 'O Marinheiro Popeye S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/168014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75360, 5158, 'O Marinheiro Popeye S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/168015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75361, 5158, 'O Marinheiro Popeye S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/168016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75362, 5158, 'O Marinheiro Popeye S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/168017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75363, 5158, 'O Marinheiro Popeye S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/168018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75364, 5158, 'O Marinheiro Popeye S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/168019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75365, 5158, 'O Marinheiro Popeye S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/168020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75366, 5158, 'O Marinheiro Popeye S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/168021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75367, 5158, 'O Marinheiro Popeye S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/168022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75368, 5158, 'O Marinheiro Popeye S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/168023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75369, 5158, 'O Marinheiro Popeye S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/168024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75370, 5158, 'O Marinheiro Popeye S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/168025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75371, 5158, 'O Marinheiro Popeye S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/168026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75372, 5158, 'O Marinheiro Popeye S03 E41', 'http://sinalprivado.info:80/series/1533784/1533784/168027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75373, 5158, 'O Marinheiro Popeye S03 E42', 'http://sinalprivado.info:80/series/1533784/1533784/168028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75374, 5158, 'O Marinheiro Popeye S03 E43', 'http://sinalprivado.info:80/series/1533784/1533784/168029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75375, 5158, 'O Marinheiro Popeye S03 E44', 'http://sinalprivado.info:80/series/1533784/1533784/168030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75376, 5158, 'O Marinheiro Popeye S03 E45', 'http://sinalprivado.info:80/series/1533784/1533784/168031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75377, 5158, 'O Marinheiro Popeye S03 E46', 'http://sinalprivado.info:80/series/1533784/1533784/168032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75378, 5158, 'O Marinheiro Popeye S03 E47', 'http://sinalprivado.info:80/series/1533784/1533784/168033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75379, 5158, 'O Marinheiro Popeye S03 E48', 'http://sinalprivado.info:80/series/1533784/1533784/168034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75380, 5158, 'O Marinheiro Popeye S03 E49', 'http://sinalprivado.info:80/series/1533784/1533784/168035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75381, 5158, 'O Marinheiro Popeye S03 E50', 'http://sinalprivado.info:80/series/1533784/1533784/168036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75382, 5158, 'O Marinheiro Popeye S03 E51', 'http://sinalprivado.info:80/series/1533784/1533784/168037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75383, 5158, 'O Marinheiro Popeye S03 E52', 'http://sinalprivado.info:80/series/1533784/1533784/168038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75384, 5158, 'O Marinheiro Popeye S03 E53', 'http://sinalprivado.info:80/series/1533784/1533784/168039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75385, 5158, 'O Marinheiro Popeye S03 E54', 'http://sinalprivado.info:80/series/1533784/1533784/168040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(75386, 5158, 'O Marinheiro Popeye S03 E55', 'http://sinalprivado.info:80/series/1533784/1533784/168041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75387, 5158, 'O Marinheiro Popeye S03 E56', 'http://sinalprivado.info:80/series/1533784/1533784/168042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75388, 5158, 'O Marinheiro Popeye S03 E57', 'http://sinalprivado.info:80/series/1533784/1533784/168043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75389, 5158, 'O Marinheiro Popeye S03 E58', 'http://sinalprivado.info:80/series/1533784/1533784/168044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75390, 5158, 'O Marinheiro Popeye S03 E59', 'http://sinalprivado.info:80/series/1533784/1533784/168045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75391, 5158, 'O Marinheiro Popeye S03 E60', 'http://sinalprivado.info:80/series/1533784/1533784/168046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75392, 5158, 'O Marinheiro Popeye S03 E61', 'http://sinalprivado.info:80/series/1533784/1533784/168047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75393, 5158, 'O Marinheiro Popeye S03 E62', 'http://sinalprivado.info:80/series/1533784/1533784/168048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75394, 5158, 'O Marinheiro Popeye S03 E63', 'http://sinalprivado.info:80/series/1533784/1533784/168049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75395, 5158, 'O Marinheiro Popeye S03 E64', 'http://sinalprivado.info:80/series/1533784/1533784/168050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75396, 5158, 'O Marinheiro Popeye S03 E65', 'http://sinalprivado.info:80/series/1533784/1533784/168051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75397, 5158, 'O Marinheiro Popeye S03 E66', 'http://sinalprivado.info:80/series/1533784/1533784/168052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75398, 5158, 'O Marinheiro Popeye S03 E67', 'http://sinalprivado.info:80/series/1533784/1533784/168053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75399, 5158, 'O Marinheiro Popeye S03 E68', 'http://sinalprivado.info:80/series/1533784/1533784/168054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75400, 5158, 'O Marinheiro Popeye S03 E69', 'http://sinalprivado.info:80/series/1533784/1533784/168055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75401, 5158, 'O Marinheiro Popeye S03 E70', 'http://sinalprivado.info:80/series/1533784/1533784/168056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75402, 5158, 'O Marinheiro Popeye S03 E71', 'http://sinalprivado.info:80/series/1533784/1533784/168057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75403, 5158, 'O Marinheiro Popeye S03 E72', 'http://sinalprivado.info:80/series/1533784/1533784/168058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75404, 5158, 'O Marinheiro Popeye S03 E73', 'http://sinalprivado.info:80/series/1533784/1533784/168059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75405, 5158, 'O Marinheiro Popeye S03 E74', 'http://sinalprivado.info:80/series/1533784/1533784/168060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75406, 5158, 'O Marinheiro Popeye S03 E75', 'http://sinalprivado.info:80/series/1533784/1533784/168061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75407, 5158, 'O Marinheiro Popeye S03 E76', 'http://sinalprivado.info:80/series/1533784/1533784/168062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75408, 5158, 'O Marinheiro Popeye S03 E77', 'http://sinalprivado.info:80/series/1533784/1533784/168063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75409, 5158, 'O Marinheiro Popeye S03 E78', 'http://sinalprivado.info:80/series/1533784/1533784/168064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75410, 5158, 'O Marinheiro Popeye S03 E79', 'http://sinalprivado.info:80/series/1533784/1533784/168065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75411, 5158, 'O Marinheiro Popeye S03 E80', 'http://sinalprivado.info:80/series/1533784/1533784/168066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75412, 5158, 'O Marinheiro Popeye S03 E81', 'http://sinalprivado.info:80/series/1533784/1533784/168067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75413, 5158, 'O Marinheiro Popeye S03 E82', 'http://sinalprivado.info:80/series/1533784/1533784/168068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75414, 5158, 'O Marinheiro Popeye S03 E83', 'http://sinalprivado.info:80/series/1533784/1533784/168069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75415, 5158, 'O Marinheiro Popeye S03 E84', 'http://sinalprivado.info:80/series/1533784/1533784/168070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75416, 5158, 'O Marinheiro Popeye S03 E85', 'http://sinalprivado.info:80/series/1533784/1533784/168071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75417, 5158, 'O Marinheiro Popeye S03 E86', 'http://sinalprivado.info:80/series/1533784/1533784/168072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75418, 5158, 'O Marinheiro Popeye S03 E87', 'http://sinalprivado.info:80/series/1533784/1533784/168073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75419, 5158, 'O Marinheiro Popeye S03 E88', 'http://sinalprivado.info:80/series/1533784/1533784/168074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75420, 5158, 'O Marinheiro Popeye S03 E89', 'http://sinalprivado.info:80/series/1533784/1533784/168075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75421, 5158, 'O Marinheiro Popeye S03 E90', 'http://sinalprivado.info:80/series/1533784/1533784/168076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75422, 5158, 'O Marinheiro Popeye S03 E91', 'http://sinalprivado.info:80/series/1533784/1533784/168077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75423, 5158, 'O Marinheiro Popeye S03 E92', 'http://sinalprivado.info:80/series/1533784/1533784/168078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75424, 5158, 'O Marinheiro Popeye S03 E93', 'http://sinalprivado.info:80/series/1533784/1533784/168079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75425, 5158, 'O Marinheiro Popeye S03 E94', 'http://sinalprivado.info:80/series/1533784/1533784/168080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75426, 5158, 'O Marinheiro Popeye S03 E95', 'http://sinalprivado.info:80/series/1533784/1533784/168081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75427, 5158, 'O Marinheiro Popeye S03 E96', 'http://sinalprivado.info:80/series/1533784/1533784/168082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75428, 5158, 'O Marinheiro Popeye S03 E97', 'http://sinalprivado.info:80/series/1533784/1533784/168083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75429, 5158, 'O Marinheiro Popeye S03 E98', 'http://sinalprivado.info:80/series/1533784/1533784/168084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75430, 5158, 'O Marinheiro Popeye S03 E99', 'http://sinalprivado.info:80/series/1533784/1533784/168085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75431, 5158, 'O Marinheiro Popeye S03 E100', 'http://sinalprivado.info:80/series/1533784/1533784/168086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75432, 5158, 'O Marinheiro Popeye S03 E101', 'http://sinalprivado.info:80/series/1533784/1533784/168087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75433, 5158, 'O Marinheiro Popeye S03 E102', 'http://sinalprivado.info:80/series/1533784/1533784/168088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75434, 5158, 'O Marinheiro Popeye S03 E103', 'http://sinalprivado.info:80/series/1533784/1533784/168089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75435, 5158, 'O Marinheiro Popeye S03 E104', 'http://sinalprivado.info:80/series/1533784/1533784/168090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75436, 5158, 'O Marinheiro Popeye S03 E105', 'http://sinalprivado.info:80/series/1533784/1533784/168091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75437, 5158, 'O Marinheiro Popeye S03 E106', 'http://sinalprivado.info:80/series/1533784/1533784/168092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75438, 5158, 'O Marinheiro Popeye S03 E107', 'http://sinalprivado.info:80/series/1533784/1533784/168093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75439, 5158, 'O Marinheiro Popeye S03 E108', 'http://sinalprivado.info:80/series/1533784/1533784/168094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75440, 5158, 'O Marinheiro Popeye S03 E109', 'http://sinalprivado.info:80/series/1533784/1533784/168095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75441, 5159, 'O Marinheiro Popeye S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/168096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75442, 5159, 'O Marinheiro Popeye S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/168097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75443, 5159, 'O Marinheiro Popeye S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/168098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75444, 5159, 'O Marinheiro Popeye S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/168099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75445, 5159, 'O Marinheiro Popeye S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/168100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75446, 5159, 'O Marinheiro Popeye S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/168101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75447, 5159, 'O Marinheiro Popeye S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/168102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75448, 5159, 'O Marinheiro Popeye S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/168103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75449, 5159, 'O Marinheiro Popeye S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/168104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75450, 5159, 'O Marinheiro Popeye S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/168105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75451, 5159, 'O Marinheiro Popeye S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/168106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75452, 5159, 'O Marinheiro Popeye S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/168107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75453, 5159, 'O Marinheiro Popeye S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/168108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75454, 5159, 'O Marinheiro Popeye S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/168109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75455, 5159, 'O Marinheiro Popeye S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/168110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75456, 5159, 'O Marinheiro Popeye S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/168111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75457, 5159, 'O Marinheiro Popeye S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/168112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75458, 5159, 'O Marinheiro Popeye S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/168113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75459, 5159, 'O Marinheiro Popeye S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/168114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75460, 5159, 'O Marinheiro Popeye S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/168115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75461, 5159, 'O Marinheiro Popeye S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/168116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75462, 5159, 'O Marinheiro Popeye S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/168117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75463, 5159, 'O Marinheiro Popeye S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/168118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75464, 5159, 'O Marinheiro Popeye S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/168119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75465, 5159, 'O Marinheiro Popeye S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/168120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75466, 5159, 'O Marinheiro Popeye S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/168121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75467, 5159, 'O Marinheiro Popeye S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/168122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75468, 5159, 'O Marinheiro Popeye S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/168123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75469, 5159, 'O Marinheiro Popeye S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/168124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75470, 5159, 'O Marinheiro Popeye S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/168125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75471, 5159, 'O Marinheiro Popeye S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/168126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75472, 5159, 'O Marinheiro Popeye S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/168127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75473, 5159, 'O Marinheiro Popeye S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/168128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75474, 5159, 'O Marinheiro Popeye S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/168129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75475, 5159, 'O Marinheiro Popeye S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/168130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75476, 5159, 'O Marinheiro Popeye S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/168131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75477, 5159, 'O Marinheiro Popeye S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/168132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75478, 5159, 'O Marinheiro Popeye S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/168133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75479, 5159, 'O Marinheiro Popeye S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/168134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75480, 5159, 'O Marinheiro Popeye S04 E40', 'http://sinalprivado.info:80/series/1533784/1533784/168135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75481, 5159, 'O Marinheiro Popeye S04 E41', 'http://sinalprivado.info:80/series/1533784/1533784/168136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75482, 5159, 'O Marinheiro Popeye S04 E42', 'http://sinalprivado.info:80/series/1533784/1533784/168137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75483, 5159, 'O Marinheiro Popeye S04 E43', 'http://sinalprivado.info:80/series/1533784/1533784/168138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75484, 5159, 'O Marinheiro Popeye S04 E44', 'http://sinalprivado.info:80/series/1533784/1533784/168139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75485, 5159, 'O Marinheiro Popeye S04 E45', 'http://sinalprivado.info:80/series/1533784/1533784/168140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75486, 5159, 'O Marinheiro Popeye S04 E46', 'http://sinalprivado.info:80/series/1533784/1533784/168141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75487, 5159, 'O Marinheiro Popeye S04 E47', 'http://sinalprivado.info:80/series/1533784/1533784/168142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75488, 5159, 'O Marinheiro Popeye S04 E48', 'http://sinalprivado.info:80/series/1533784/1533784/168143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75489, 5159, 'O Marinheiro Popeye S04 E49', 'http://sinalprivado.info:80/series/1533784/1533784/168144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75490, 5159, 'O Marinheiro Popeye S04 E50', 'http://sinalprivado.info:80/series/1533784/1533784/168145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75491, 5159, 'O Marinheiro Popeye S04 E51', 'http://sinalprivado.info:80/series/1533784/1533784/168146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75492, 5159, 'O Marinheiro Popeye S04 E52', 'http://sinalprivado.info:80/series/1533784/1533784/168147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75493, 5159, 'O Marinheiro Popeye S04 E53', 'http://sinalprivado.info:80/series/1533784/1533784/168148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75494, 5159, 'O Marinheiro Popeye S04 E54', 'http://sinalprivado.info:80/series/1533784/1533784/168149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75495, 5159, 'O Marinheiro Popeye S04 E55', 'http://sinalprivado.info:80/series/1533784/1533784/168150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75496, 5159, 'O Marinheiro Popeye S04 E56', 'http://sinalprivado.info:80/series/1533784/1533784/168151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75497, 5159, 'O Marinheiro Popeye S04 E57', 'http://sinalprivado.info:80/series/1533784/1533784/168152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75498, 5159, 'O Marinheiro Popeye S04 E58', 'http://sinalprivado.info:80/series/1533784/1533784/168153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75499, 5159, 'O Marinheiro Popeye S04 E59', 'http://sinalprivado.info:80/series/1533784/1533784/168154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75500, 5159, 'O Marinheiro Popeye S04 E60', 'http://sinalprivado.info:80/series/1533784/1533784/168155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75501, 5159, 'O Marinheiro Popeye S04 E61', 'http://sinalprivado.info:80/series/1533784/1533784/168156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75502, 5159, 'O Marinheiro Popeye S04 E62', 'http://sinalprivado.info:80/series/1533784/1533784/168157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75503, 5159, 'O Marinheiro Popeye S04 E63', 'http://sinalprivado.info:80/series/1533784/1533784/168158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75504, 5159, 'O Marinheiro Popeye S04 E64', 'http://sinalprivado.info:80/series/1533784/1533784/168159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75505, 5159, 'O Marinheiro Popeye S04 E65', 'http://sinalprivado.info:80/series/1533784/1533784/168160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75506, 5159, 'O Marinheiro Popeye S04 E66', 'http://sinalprivado.info:80/series/1533784/1533784/168161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75507, 5159, 'O Marinheiro Popeye S04 E67', 'http://sinalprivado.info:80/series/1533784/1533784/168162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75508, 5159, 'O Marinheiro Popeye S04 E68', 'http://sinalprivado.info:80/series/1533784/1533784/168163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75509, 5159, 'O Marinheiro Popeye S04 E69', 'http://sinalprivado.info:80/series/1533784/1533784/168164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75510, 5159, 'O Marinheiro Popeye S04 E70', 'http://sinalprivado.info:80/series/1533784/1533784/168165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75511, 5159, 'O Marinheiro Popeye S04 E71', 'http://sinalprivado.info:80/series/1533784/1533784/168166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75512, 5159, 'O Marinheiro Popeye S04 E72', 'http://sinalprivado.info:80/series/1533784/1533784/168167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75513, 5159, 'O Marinheiro Popeye S04 E73', 'http://sinalprivado.info:80/series/1533784/1533784/168168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75514, 5159, 'O Marinheiro Popeye S04 E74', 'http://sinalprivado.info:80/series/1533784/1533784/168169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75515, 5159, 'O Marinheiro Popeye S04 E75', 'http://sinalprivado.info:80/series/1533784/1533784/168170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75516, 5159, 'O Marinheiro Popeye S04 E76', 'http://sinalprivado.info:80/series/1533784/1533784/168171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75517, 5159, 'O Marinheiro Popeye S04 E77', 'http://sinalprivado.info:80/series/1533784/1533784/168172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75518, 5159, 'O Marinheiro Popeye S04 E78', 'http://sinalprivado.info:80/series/1533784/1533784/168173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75519, 5159, 'O Marinheiro Popeye S04 E79', 'http://sinalprivado.info:80/series/1533784/1533784/168174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75520, 5159, 'O Marinheiro Popeye S04 E80', 'http://sinalprivado.info:80/series/1533784/1533784/168175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75521, 5159, 'O Marinheiro Popeye S04 E81', 'http://sinalprivado.info:80/series/1533784/1533784/168176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75522, 5159, 'O Marinheiro Popeye S04 E82', 'http://sinalprivado.info:80/series/1533784/1533784/168177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75523, 5159, 'O Marinheiro Popeye S04 E83', 'http://sinalprivado.info:80/series/1533784/1533784/168178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75524, 5159, 'O Marinheiro Popeye S04 E84', 'http://sinalprivado.info:80/series/1533784/1533784/168179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75525, 5159, 'O Marinheiro Popeye S04 E85', 'http://sinalprivado.info:80/series/1533784/1533784/168180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75526, 5159, 'O Marinheiro Popeye S04 E86', 'http://sinalprivado.info:80/series/1533784/1533784/168181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75527, 5159, 'O Marinheiro Popeye S04 E87', 'http://sinalprivado.info:80/series/1533784/1533784/168182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75528, 5159, 'O Marinheiro Popeye S04 E88', 'http://sinalprivado.info:80/series/1533784/1533784/168183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75529, 5159, 'O Marinheiro Popeye S04 E89', 'http://sinalprivado.info:80/series/1533784/1533784/168184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75530, 5159, 'O Marinheiro Popeye S04 E90', 'http://sinalprivado.info:80/series/1533784/1533784/168185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75531, 5159, 'O Marinheiro Popeye S04 E91', 'http://sinalprivado.info:80/series/1533784/1533784/168186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75532, 5159, 'O Marinheiro Popeye S04 E92', 'http://sinalprivado.info:80/series/1533784/1533784/168187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75533, 5159, 'O Marinheiro Popeye S04 E93', 'http://sinalprivado.info:80/series/1533784/1533784/168188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75534, 5159, 'O Marinheiro Popeye S04 E94', 'http://sinalprivado.info:80/series/1533784/1533784/168189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75535, 5159, 'O Marinheiro Popeye S04 E95', 'http://sinalprivado.info:80/series/1533784/1533784/168190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75536, 5159, 'O Marinheiro Popeye S04 E96', 'http://sinalprivado.info:80/series/1533784/1533784/168191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75537, 5159, 'O Marinheiro Popeye S04 E97', 'http://sinalprivado.info:80/series/1533784/1533784/168192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75538, 5159, 'O Marinheiro Popeye S04 E98', 'http://sinalprivado.info:80/series/1533784/1533784/168193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75539, 5159, 'O Marinheiro Popeye S04 E99', 'http://sinalprivado.info:80/series/1533784/1533784/168194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75540, 5159, 'O Marinheiro Popeye S04 E100', 'http://sinalprivado.info:80/series/1533784/1533784/168195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75541, 5159, 'O Marinheiro Popeye S04 E101', 'http://sinalprivado.info:80/series/1533784/1533784/168196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75542, 5159, 'O Marinheiro Popeye S04 E102', 'http://sinalprivado.info:80/series/1533784/1533784/168197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75543, 5159, 'O Marinheiro Popeye S04 E103', 'http://sinalprivado.info:80/series/1533784/1533784/168198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75544, 5159, 'O Marinheiro Popeye S04 E104', 'http://sinalprivado.info:80/series/1533784/1533784/168199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75545, 5159, 'O Marinheiro Popeye S04 E105', 'http://sinalprivado.info:80/series/1533784/1533784/168200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75546, 5159, 'O Marinheiro Popeye S04 E106', 'http://sinalprivado.info:80/series/1533784/1533784/168201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75547, 5159, 'O Marinheiro Popeye S04 E107', 'http://sinalprivado.info:80/series/1533784/1533784/168202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75548, 5159, 'O Marinheiro Popeye S04 E108', 'http://sinalprivado.info:80/series/1533784/1533784/168203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75549, 5159, 'O Marinheiro Popeye S04 E109', 'http://sinalprivado.info:80/series/1533784/1533784/168204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75550, 5159, 'O Marinheiro Popeye S04 E110', 'http://sinalprivado.info:80/series/1533784/1533784/168205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQPDl1S1pRg2jzCQWtVUuauZSqa.jpg'),
(75551, 5160, 'O Programa: 90 Dias Longe das Drogas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kFnVJbnPiJCXHLegy6NYsKj6SxP.jpg'),
(75552, 5160, 'O Programa: 90 Dias Longe das Drogas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hCF8GWrG8H0QMuBOsfXJvaogoUD.jpg'),
(75553, 5160, 'O Programa: 90 Dias Longe das Drogas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6YOxoyif6pYPBN15yRg9kaNV74B.jpg'),
(75554, 5160, 'O Programa: 90 Dias Longe das Drogas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o402WUHlSqJU1e85w1bvHzxrG2H.jpg'),
(75555, 5160, 'O Programa: 90 Dias Longe das Drogas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o402WUHlSqJU1e85w1bvHzxrG2H.jpg'),
(75556, 5160, 'O Programa: 90 Dias Longe das Drogas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o402WUHlSqJU1e85w1bvHzxrG2H.jpg'),
(75557, 5161, 'O Submundo das Apostas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167752.mp4', 'https://i.bj-share.info/ff832e473fd38b8c5048aa030fe54835.jpg'),
(75558, 5161, 'O Submundo das Apostas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167753.mp4', 'https://i.bj-share.info/ff832e473fd38b8c5048aa030fe54835.jpg'),
(75559, 5161, 'O Submundo das Apostas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167754.mp4', 'https://i.bj-share.info/ff832e473fd38b8c5048aa030fe54835.jpg'),
(75560, 5161, 'O Submundo das Apostas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167755.mp4', 'https://i.bj-share.info/ff832e473fd38b8c5048aa030fe54835.jpg'),
(75561, 5161, 'O Submundo das Apostas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167756.mp4', 'https://i.bj-share.info/ff832e473fd38b8c5048aa030fe54835.jpg'),
(75562, 5161, 'O Submundo das Apostas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167757.mp4', 'https://i.bj-share.info/ff832e473fd38b8c5048aa030fe54835.jpg'),
(75563, 5161, 'O Submundo das Apostas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167758.mp4', 'https://i.bj-share.info/ff832e473fd38b8c5048aa030fe54835.jpg'),
(75564, 5161, 'O Submundo das Apostas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167759.mp4', 'https://i.bj-share.info/ff832e473fd38b8c5048aa030fe54835.jpg'),
(75565, 5162, 'O.J.: Made in America [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ZWSWp2LY40JPQNTkfse1hlaEL.jpg'),
(75566, 5162, 'O.J.: Made in America [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2vqIFIuTAAQeYri9KS1GfY1H6IX.jpg'),
(75567, 5162, 'O.J.: Made in America [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qO1CkAXduRj2vKUJxrTv00QMIdP.jpg'),
(75568, 5162, 'O.J.: Made in America [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tfsLXX6xkI6FGjos6Iw0BXZK6MP.jpg'),
(75569, 5162, 'O.J.: Made in America [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w9zFSaOSawIK2NrDxZQ44qtmnBi.jpg'),
(75570, 5163, 'Onision: Abuso na Internet S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n7yFNwp75GkJC2Agr8EcIuLe49e.jpg'),
(75571, 5163, 'Onision: Abuso na Internet S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AhmAHqz9KiOPzn7URGvUdzqAJ9T.jpg'),
(75572, 5163, 'Onision: Abuso na Internet S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUYrfOMO10ckWkBNGprhb0rkcHB.jpg'),
(75573, 5163, 'Onision: Abuso na Internet S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cu8oZBQVmxIH8GXBtAXfvn56pSH.jpg'),
(75574, 5164, 'Patrulheiros em Ação S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oUJzSNYFqyIIdB1kHB7L9aSskG6.jpg'),
(75575, 5164, 'Patrulheiros em Ação S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wmhN42J5eb03sSMX7tajmJePrni.jpg'),
(75576, 5164, 'Patrulheiros em Ação S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hUMSk3skmcTA0USJlPg85fmtym0.jpg'),
(75577, 5164, 'Patrulheiros em Ação S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i04336B1uktCcq0UAWQASvfoHEj.jpg'),
(75578, 5164, 'Patrulheiros em Ação S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dQCRbBNcm1e5sQYtwzKO7uVxzIL.jpg'),
(75579, 5164, 'Patrulheiros em Ação S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xdmsbEr31djSnlyP09ZlInUaQqR.jpg'),
(75580, 5164, 'Patrulheiros em Ação S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ou3bALynRqYXLxnMMnmZSZi5xK5.jpg'),
(75581, 5164, 'Patrulheiros em Ação S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hth3AIRGRBGmeJLzjLMGwLsmvB6.jpg'),
(75582, 5164, 'Patrulheiros em Ação S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b4AuSa4H1xYVidbGCgXE2dokDA9.jpg'),
(75583, 5164, 'Patrulheiros em Ação S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2fjN4cbRxQk25RJw73eFelb4W6y.jpg'),
(75584, 5165, 'Raised by Wolves S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pEM2dl0FvKLt3ClQwCYwViYQZzO.jpg'),
(75585, 5165, 'Raised by Wolves S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j9wGe5HIXgXw8Z81WlH9pSOryTf.jpg'),
(75586, 5165, 'Raised by Wolves S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9sV450BnUEZMsMPMY1yCQBv9QT5.jpg'),
(75587, 5165, 'Raised by Wolves S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yf6lZPqTw28ivyqBAbqWzTlWUqA.jpg'),
(75588, 5165, 'Raised by Wolves S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eVNKJhZQ1dFHLG9Ka4j23uda2tI.jpg'),
(75589, 5165, 'Raised by Wolves S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nzZPpSuQ5I5kwZLHRbMorJWsla9.jpg'),
(75590, 5165, 'Raised by Wolves S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5tygscjsHMzizn1niJpLl52ONx6.jpg'),
(75591, 5165, 'Raised by Wolves S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j2Q0vBQDpu3lQFzBjOypHaZFr0M.jpg'),
(75592, 5165, 'Raised by Wolves S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Yd2VeoZGJB9vbXI8x37kX0Pjn3.jpg'),
(75593, 5165, 'Raised by Wolves S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jP6poDtDban7GKgIonbTWqQLcxf.jpg'),
(75594, 5166, 'Raised by Wolves S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177828.mp4', 'http://timg.bdta.pro/images/21d59d3097e8af7b91e1289f0dfe9102.jpg'),
(75595, 5166, 'Raised by Wolves S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177829.mp4', 'http://timg.bdta.pro/images/1a526a4fffd73abebcfbf01a3c2d7bb5.jpg'),
(75596, 5166, 'Raised by Wolves S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177830.mp4', 'http://timg.bdta.pro/images/9758e223b898a9dc16630df8777115e8.jpg'),
(75597, 5166, 'Raised by Wolves S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177831.mp4', 'http://timg.bdta.pro/images/025bfcf3f6d94b691e6984a6a5f47ccf.jpg'),
(75598, 5166, 'Raised by Wolves S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177832.mp4', 'http://timg.bdta.pro/images/e2e45c3a12fd22bc7b1d433d3793cc7a.jpg'),
(75599, 5166, 'Raised by Wolves S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177833.mp4', 'http://timg.bdta.pro/images/134e6b449ae022793da05330d3f75df9.jpg'),
(75600, 5166, 'Raised by Wolves S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177834.mp4', 'http://timg.bdta.pro/images/1ea7844eb7df0ec2b40c0db78f313528.jpg'),
(75601, 5166, 'Raised by Wolves S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177835.mp4', 'http://timg.bdta.pro/images/f01cca312cd71ee6f5d0e0c33de110a8.jpg'),
(75602, 5167, 'Rebelde S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mQ1KUd9yqB00AZC3p4v4mVWBWsq.jpg'),
(75603, 5167, 'Rebelde S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oXY1PzXXkQJmpFYvU8ppiqPh5jE.jpg'),
(75604, 5167, 'Rebelde S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qNp6XHs36g8ue0lVOmSIA5lfLmn.jpg'),
(75605, 5167, 'Rebelde S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8iqRzSQDEmVsUeIhUuAclliGqcv.jpg'),
(75606, 5167, 'Rebelde S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Yb6l4pSrZ8wOO23ZXSoufWuXVQ.jpg'),
(75607, 5167, 'Rebelde S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNovuZIA7QEvOPBQVDXQMek8QNA.jpg'),
(75608, 5167, 'Rebelde S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6VpYq70BTGRJDB7ciVcQLzSXhEu.jpg'),
(75609, 5167, 'Rebelde S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2d82SIXLZlmvwmQSFxO1k3dW1CI.jpg'),
(75610, 5168, 'Rebelde S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190629.mp4', 'http://timg.bdta.pro/images/4d765e41d0eced7ce8af01d242b32ae8.jpg'),
(75611, 5168, 'Rebelde S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190630.mp4', 'http://timg.bdta.pro/images/833bb2b366242d8b7ce6dc783c2659da.jpg'),
(75612, 5168, 'Rebelde S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190631.mp4', 'http://timg.bdta.pro/images/bcc0ec9492caea3c503d741e73b292eb.jpg'),
(75613, 5168, 'Rebelde S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190632.mp4', 'http://timg.bdta.pro/images/089a7985eab33cf2036643c238476410.jpg'),
(75614, 5168, 'Rebelde S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190633.mp4', 'http://timg.bdta.pro/images/d389a04cc6bd496a836c44759a2df989.jpg'),
(75615, 5168, 'Rebelde S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190634.mp4', 'http://timg.bdta.pro/images/8fba15fe6047b546c81fba18b82040bf.jpg'),
(75616, 5168, 'Rebelde S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190635.mp4', 'http://timg.bdta.pro/images/ea57d11a84c76aa19a0a724b3a6ea701.jpg'),
(75617, 5168, 'Rebelde S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190636.mp4', 'http://timg.bdta.pro/images/3dd837d620a1527105442a3742ea4118.jpg'),
(75618, 5169, 'Supermansion S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75619, 5169, 'Supermansion S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75620, 5169, 'Supermansion S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75621, 5169, 'Supermansion S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75622, 5169, 'Supermansion S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75623, 5169, 'Supermansion S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75624, 5169, 'Supermansion S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75625, 5169, 'Supermansion S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75626, 5169, 'Supermansion S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75627, 5169, 'Supermansion S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75628, 5169, 'Supermansion S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75629, 5169, 'Supermansion S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75630, 5169, 'Supermansion S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75631, 5170, 'Supermansion S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75632, 5170, 'Supermansion S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75633, 5170, 'Supermansion S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75634, 5170, 'Supermansion S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75635, 5170, 'Supermansion S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75636, 5170, 'Supermansion S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75637, 5170, 'Supermansion S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75638, 5170, 'Supermansion S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75639, 5170, 'Supermansion S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75640, 5170, 'Supermansion S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75641, 5170, 'Supermansion S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75642, 5170, 'Supermansion S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75643, 5171, 'Supermansion S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75644, 5171, 'Supermansion S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75645, 5171, 'Supermansion S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75646, 5171, 'Supermansion S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75647, 5171, 'Supermansion S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(75648, 5171, 'Supermansion S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75649, 5171, 'Supermansion S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75650, 5171, 'Supermansion S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75651, 5171, 'Supermansion S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75652, 5171, 'Supermansion S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75653, 5171, 'Supermansion S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75654, 5171, 'Supermansion S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75655, 5171, 'Supermansion S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75656, 5171, 'Supermansion S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/173425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75657, 5171, 'Supermansion S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/173426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75658, 5171, 'Supermansion S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/173427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75659, 5171, 'Supermansion S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/173428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75660, 5171, 'Supermansion S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/173429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75661, 5171, 'Supermansion S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/173430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75662, 5171, 'Supermansion S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/173431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75663, 5171, 'Supermansion S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/173432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Mv6oIo8bkWATYpZUzzvxT63Qyl.jpg'),
(75664, 5172, 'The Comey Rule S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rPRYXWO72HYYNEx2QQRNGFMQRlX.jpg'),
(75665, 5172, 'The Comey Rule S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jbxlezxQGGSYqFlqNrAroRwQoV9.jpg'),
(75666, 5172, 'The Comey Rule S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wftjHCpgqziAw42JZWdFWhro3km.jpg'),
(75667, 5172, 'The Comey Rule S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wftjHCpgqziAw42JZWdFWhro3km.jpg'),
(75668, 5173, 'Tigue E Lupa: Os Detetives S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/167709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/whp8ZHeaHJWDlPXWo5AVsuwikmw.jpg'),
(75669, 5173, 'Tigue E Lupa: Os Detetives S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/167710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nnl1XTan3kf0r3NZXXmtwfm2qep.jpg'),
(75670, 5173, 'Tigue E Lupa: Os Detetives S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/167711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kjMybYI63kXR4oYwxSvv3sjiqT4.jpg'),
(75671, 5173, 'Tigue E Lupa: Os Detetives S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/167712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pbDxzZX0jJhRgivKwYCA82Q7Klp.jpg'),
(75672, 5173, 'Tigue E Lupa: Os Detetives S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/167713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pbDxzZX0jJhRgivKwYCA82Q7Klp.jpg'),
(75673, 5173, 'Tigue E Lupa: Os Detetives S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/167714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pbDxzZX0jJhRgivKwYCA82Q7Klp.jpg'),
(75674, 5173, 'Tigue E Lupa: Os Detetives S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/167715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pbDxzZX0jJhRgivKwYCA82Q7Klp.jpg'),
(75675, 5173, 'Tigue E Lupa: Os Detetives S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/167716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pbDxzZX0jJhRgivKwYCA82Q7Klp.jpg'),
(75676, 5173, 'Tigue E Lupa: Os Detetives S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/167717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pbDxzZX0jJhRgivKwYCA82Q7Klp.jpg'),
(75677, 5173, 'Tigue E Lupa: Os Detetives S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/167718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pbDxzZX0jJhRgivKwYCA82Q7Klp.jpg'),
(75678, 5173, 'Tigue E Lupa: Os Detetives S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/167719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pbDxzZX0jJhRgivKwYCA82Q7Klp.jpg'),
(75679, 5173, 'Tigue E Lupa: Os Detetives S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/167720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pbDxzZX0jJhRgivKwYCA82Q7Klp.jpg'),
(75680, 5173, 'Tigue E Lupa: Os Detetives S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/167721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pbDxzZX0jJhRgivKwYCA82Q7Klp.jpg'),
(75681, 5173, 'Tigue E Lupa: Os Detetives S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/167722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pbDxzZX0jJhRgivKwYCA82Q7Klp.jpg'),
(75682, 5173, 'Tigue E Lupa: Os Detetives S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/167723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pbDxzZX0jJhRgivKwYCA82Q7Klp.jpg'),
(75683, 5173, 'Tigue E Lupa: Os Detetives S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/167724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pbDxzZX0jJhRgivKwYCA82Q7Klp.jpg'),
(75684, 5173, 'Tigue E Lupa: Os Detetives S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/167725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pbDxzZX0jJhRgivKwYCA82Q7Klp.jpg'),
(75685, 5173, 'Tigue E Lupa: Os Detetives S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/167726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pbDxzZX0jJhRgivKwYCA82Q7Klp.jpg'),
(75686, 5173, 'Tigue E Lupa: Os Detetives S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/167727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pbDxzZX0jJhRgivKwYCA82Q7Klp.jpg'),
(75687, 5173, 'Tigue E Lupa: Os Detetives S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/167728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pbDxzZX0jJhRgivKwYCA82Q7Klp.jpg'),
(75688, 5174, 'True Life Crime - Reino Unido S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2E3HHDBdEQJ94PYfgPjKw1EpqeM.jpg'),
(75689, 5174, 'True Life Crime - Reino Unido S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2E3HHDBdEQJ94PYfgPjKw1EpqeM.jpg'),
(75690, 5174, 'True Life Crime - Reino Unido S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2E3HHDBdEQJ94PYfgPjKw1EpqeM.jpg'),
(75691, 5174, 'True Life Crime - Reino Unido S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2E3HHDBdEQJ94PYfgPjKw1EpqeM.jpg'),
(75692, 5175, 'True Life Crime - Reino Unido S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/521775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2E3HHDBdEQJ94PYfgPjKw1EpqeM.jpg'),
(75693, 5175, 'True Life Crime - Reino Unido S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/521776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2E3HHDBdEQJ94PYfgPjKw1EpqeM.jpg'),
(75694, 5175, 'True Life Crime - Reino Unido S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/521777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2E3HHDBdEQJ94PYfgPjKw1EpqeM.jpg'),
(75695, 5175, 'True Life Crime - Reino Unido S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/521778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2E3HHDBdEQJ94PYfgPjKw1EpqeM.jpg'),
(75696, 5175, 'True Life Crime - Reino Unido S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/521779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2E3HHDBdEQJ94PYfgPjKw1EpqeM.jpg'),
(75697, 5175, 'True Life Crime - Reino Unido S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/521780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2E3HHDBdEQJ94PYfgPjKw1EpqeM.jpg'),
(75698, 5176, '30 Moedas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2XcHx2JiBNDyDiPLSAyxnoxdNJx.jpg'),
(75699, 5176, '30 Moedas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A2Q3cjux6zVIPlpfbzx9feCLMIQ.jpg'),
(75700, 5176, '30 Moedas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dzwMOd3LWQkneTx82n3qnQgo8vY.jpg'),
(75701, 5176, '30 Moedas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uO62DrL07DEhjWJtEGQsXWMH2UD.jpg'),
(75702, 5176, '30 Moedas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/smBtHm1uCnZoweh0NrXKrj38vma.jpg'),
(75703, 5176, '30 Moedas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2CmUfHZ6a0AK0ue8VKFnVCGYYH.jpg'),
(75704, 5176, '30 Moedas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/puCKq5qdS4luiSL1CqCU9EVLXyE.jpg'),
(75705, 5176, '30 Moedas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dyONiZWsW8g5LDot0EXcqRBzD2R.jpg'),
(75706, 5177, '30 Moedas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iIvwxIekGKCLfbzKFK4smgaUhg6.jpg'),
(75707, 5177, '30 Moedas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iIvwxIekGKCLfbzKFK4smgaUhg6.jpg'),
(75708, 5177, '30 Moedas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iIvwxIekGKCLfbzKFK4smgaUhg6.jpg'),
(75709, 5177, '30 Moedas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iIvwxIekGKCLfbzKFK4smgaUhg6.jpg'),
(75710, 5177, '30 Moedas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iIvwxIekGKCLfbzKFK4smgaUhg6.jpg'),
(75711, 5177, '30 Moedas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iIvwxIekGKCLfbzKFK4smgaUhg6.jpg'),
(75712, 5177, '30 Moedas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iIvwxIekGKCLfbzKFK4smgaUhg6.jpg'),
(75713, 5177, '30 Moedas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iIvwxIekGKCLfbzKFK4smgaUhg6.jpg'),
(75714, 5178, 'A Surda Absurda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jrf9iPPMQnlnxSt7iBfyON9U25z.jpg'),
(75715, 5178, 'A Surda Absurda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dCWNqljTFj90kCFwL5AVbVm4JeG.jpg'),
(75716, 5178, 'A Surda Absurda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmODFk76FAPlNwKd74Q2e0wRPFC.jpg'),
(75717, 5179, 'Are You The One? Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75718, 5179, 'Are You The One? Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75719, 5179, 'Are You The One? Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75720, 5179, 'Are You The One? Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75721, 5179, 'Are You The One? Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75722, 5179, 'Are You The One? Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75723, 5179, 'Are You The One? Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75724, 5179, 'Are You The One? Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75725, 5179, 'Are You The One? Brasil S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75726, 5179, 'Are You The One? Brasil S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75727, 5179, 'Are You The One? Brasil S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75728, 5180, 'Are You The One? Brasil S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75729, 5180, 'Are You The One? Brasil S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75730, 5180, 'Are You The One? Brasil S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75731, 5180, 'Are You The One? Brasil S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75732, 5180, 'Are You The One? Brasil S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75733, 5180, 'Are You The One? Brasil S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75734, 5180, 'Are You The One? Brasil S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75735, 5180, 'Are You The One? Brasil S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75736, 5180, 'Are You The One? Brasil S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75737, 5180, 'Are You The One? Brasil S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75738, 5180, 'Are You The One? Brasil S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75739, 5181, 'Are You The One? Brasil S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75740, 5181, 'Are You The One? Brasil S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75741, 5181, 'Are You The One? Brasil S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75742, 5181, 'Are You The One? Brasil S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75743, 5181, 'Are You The One? Brasil S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75744, 5181, 'Are You The One? Brasil S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75745, 5181, 'Are You The One? Brasil S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75746, 5181, 'Are You The One? Brasil S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75747, 5181, 'Are You The One? Brasil S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75748, 5181, 'Are You The One? Brasil S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75749, 5182, 'Are You The One? Brasil S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75750, 5182, 'Are You The One? Brasil S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75751, 5182, 'Are You The One? Brasil S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75752, 5182, 'Are You The One? Brasil S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75753, 5182, 'Are You The One? Brasil S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75754, 5182, 'Are You The One? Brasil S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75755, 5182, 'Are You The One? Brasil S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75756, 5182, 'Are You The One? Brasil S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75757, 5182, 'Are You The One? Brasil S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75758, 5182, 'Are You The One? Brasil S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p9NTJF6IXLvhwcjQhcI1CJVyaIU.jpg'),
(75759, 5183, 'Baptiste S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2BRpotVzycM1EGmmhcCB8t0LLKe.jpg'),
(75760, 5183, 'Baptiste S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iNuPJIc6w478umHPpl0iKWxqdcY.jpg'),
(75761, 5183, 'Baptiste S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ghg4LWxtUEb8g3nD37YCfkMUNG.jpg'),
(75762, 5183, 'Baptiste S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1b6Ex7sKzsne6dCoQhsff9MCHon.jpg'),
(75763, 5183, 'Baptiste S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hCPWuG0SiYl0Z9vH9uUc3e5E4me.jpg'),
(75764, 5183, 'Baptiste S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dNYXdvTlIqTA3Aq2hOp5VRQpdmJ.jpg'),
(75765, 5184, 'Baptiste S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vyRqwCKHNXGZGAt9LNWtHB3rC7n.jpg'),
(75766, 5184, 'Baptiste S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyM5lBX8wKvJJBWmjeRJ1EZnvdu.jpg'),
(75767, 5184, 'Baptiste S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173020.mp4', 'http://timg.bdta.pro/images/02b38a8afe51f8c0e6dfb308d1a1a5d9.jpg'),
(75768, 5184, 'Baptiste S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173021.mp4', 'http://timg.bdta.pro/images/2b9ccdc2167aea30fa4944711d97e30b.jpg'),
(75769, 5184, 'Baptiste S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173022.mp4', 'http://timg.bdta.pro/images/be1330226533cb1280f3db16c801877c.jpg'),
(75770, 5184, 'Baptiste S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173023.mp4', 'http://timg.bdta.pro/images/73b46ea77a619af0723ec80f01adde31.jpg'),
(75771, 5185, 'Mansão Hype S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sIppViBWffdcN2m6ffOsl0NKhHw.jpg'),
(75772, 5185, 'Mansão Hype S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sIppViBWffdcN2m6ffOsl0NKhHw.jpg'),
(75773, 5185, 'Mansão Hype S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sIppViBWffdcN2m6ffOsl0NKhHw.jpg'),
(75774, 5185, 'Mansão Hype S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sIppViBWffdcN2m6ffOsl0NKhHw.jpg'),
(75775, 5185, 'Mansão Hype S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sIppViBWffdcN2m6ffOsl0NKhHw.jpg'),
(75776, 5185, 'Mansão Hype S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sIppViBWffdcN2m6ffOsl0NKhHw.jpg'),
(75777, 5185, 'Mansão Hype S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sIppViBWffdcN2m6ffOsl0NKhHw.jpg'),
(75778, 5185, 'Mansão Hype S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sIppViBWffdcN2m6ffOsl0NKhHw.jpg'),
(75779, 5186, 'Mieruko-chan S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dMWqq3Ytli7b5WsTp7eIpsjCfNx.jpg'),
(75780, 5186, 'Mieruko-chan S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/96a2uHoitJYy9zyQss0dsWICGVL.jpg'),
(75781, 5186, 'Mieruko-chan S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2fcIAlq9RPF7RZfeDvoRsz4q9Fw.jpg'),
(75782, 5186, 'Mieruko-chan S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y1XRIWYxBAt2qUsqx5Vg35rpmXi.jpg'),
(75783, 5186, 'Mieruko-chan S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2hhSfupnlF4o8MGv3xRFVs3FkOZ.jpg'),
(75784, 5186, 'Mieruko-chan S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8nRKNsf7zdryKIwdZvIQeOrccGa.jpg'),
(75785, 5186, 'Mieruko-chan S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xk7uWW6qROPS5p7TLEAoF5GcIYE.jpg'),
(75786, 5186, 'Mieruko-chan S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wWrDfzbhXFDDirXSjGNBOVVNXsn.jpg'),
(75787, 5186, 'Mieruko-chan S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PBlykMMbLRalVloHKwgyX1WXXr.jpg'),
(75788, 5186, 'Mieruko-chan S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/buteg6ifWC0RmBVUKYWqYvjGMgv.jpg'),
(75789, 5186, 'Mieruko-chan S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2dKaTDRtXdl6wWhEwbz6LloyJHz.jpg'),
(75790, 5186, 'Mieruko-chan S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13FIPPbhGEQf6HIAwmMjdNV5ml2.jpg'),
(75791, 5187, 'O Canto Livre de Nara Leão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gejD1D54nUhvevO9kRSPXFuPkuG.jpg'),
(75792, 5187, 'O Canto Livre de Nara Leão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gejD1D54nUhvevO9kRSPXFuPkuG.jpg'),
(75793, 5187, 'O Canto Livre de Nara Leão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gejD1D54nUhvevO9kRSPXFuPkuG.jpg'),
(75794, 5187, 'O Canto Livre de Nara Leão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gejD1D54nUhvevO9kRSPXFuPkuG.jpg'),
(75795, 5187, 'O Canto Livre de Nara Leão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gejD1D54nUhvevO9kRSPXFuPkuG.jpg'),
(75796, 5188, 'Pequena Ellen S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/avs0E7SmdKtmqdg4f5mILMnKIRY.jpg'),
(75797, 5188, 'Pequena Ellen S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/avs0E7SmdKtmqdg4f5mILMnKIRY.jpg'),
(75798, 5188, 'Pequena Ellen S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/avs0E7SmdKtmqdg4f5mILMnKIRY.jpg'),
(75799, 5188, 'Pequena Ellen S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/avs0E7SmdKtmqdg4f5mILMnKIRY.jpg'),
(75800, 5188, 'Pequena Ellen S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/avs0E7SmdKtmqdg4f5mILMnKIRY.jpg'),
(75801, 5188, 'Pequena Ellen S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/avs0E7SmdKtmqdg4f5mILMnKIRY.jpg'),
(75802, 5188, 'Pequena Ellen S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/avs0E7SmdKtmqdg4f5mILMnKIRY.jpg'),
(75803, 5188, 'Pequena Ellen S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/avs0E7SmdKtmqdg4f5mILMnKIRY.jpg'),
(75804, 5188, 'Pequena Ellen S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/avs0E7SmdKtmqdg4f5mILMnKIRY.jpg'),
(75805, 5188, 'Pequena Ellen S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/avs0E7SmdKtmqdg4f5mILMnKIRY.jpg'),
(75806, 5189, 'Rede de Escuridão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/szlrGF1bJabFO91RGrKNwL1bgWz.jpg'),
(75807, 5189, 'Rede de Escuridão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKOxpsI5qxuIiO2M3EMnfu5MW1z.jpg'),
(75808, 5189, 'Rede de Escuridão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/szlrGF1bJabFO91RGrKNwL1bgWz.jpg'),
(75809, 5189, 'Rede de Escuridão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/szlrGF1bJabFO91RGrKNwL1bgWz.jpg'),
(75810, 5189, 'Rede de Escuridão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/szlrGF1bJabFO91RGrKNwL1bgWz.jpg'),
(75811, 5189, 'Rede de Escuridão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/szlrGF1bJabFO91RGrKNwL1bgWz.jpg'),
(75812, 5189, 'Rede de Escuridão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/szlrGF1bJabFO91RGrKNwL1bgWz.jpg'),
(75813, 5190, 'Segredos Sordidos Dean Corll e John Wayne Gacy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xTkvq2OTiwJ0eqznqj6WReJ7Xtg.jpg'),
(75814, 5190, 'Segredos Sordidos Dean Corll e John Wayne Gacy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xTkvq2OTiwJ0eqznqj6WReJ7Xtg.jpg'),
(75815, 5191, 'Testemunha Alienigena S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171613.mp4', 'https://i.bj-share.info/5d0b03a6fd8b1bed80465799a0f25910.jpg'),
(75816, 5191, 'Testemunha Alienigena S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171614.mp4', 'https://i.bj-share.info/5d0b03a6fd8b1bed80465799a0f25910.jpg'),
(75817, 5191, 'Testemunha Alienigena S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171615.mp4', 'https://i.bj-share.info/5d0b03a6fd8b1bed80465799a0f25910.jpg'),
(75818, 5191, 'Testemunha Alienigena S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171616.mp4', 'https://i.bj-share.info/5d0b03a6fd8b1bed80465799a0f25910.jpg'),
(75819, 5191, 'Testemunha Alienigena S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171617.mp4', 'https://i.bj-share.info/5d0b03a6fd8b1bed80465799a0f25910.jpg'),
(75820, 5191, 'Testemunha Alienigena S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171618.mp4', 'https://i.bj-share.info/5d0b03a6fd8b1bed80465799a0f25910.jpg'),
(75821, 5191, 'Testemunha Alienigena S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171619.mp4', 'https://i.bj-share.info/5d0b03a6fd8b1bed80465799a0f25910.jpg'),
(75822, 5191, 'Testemunha Alienigena S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171620.mp4', 'https://i.bj-share.info/5d0b03a6fd8b1bed80465799a0f25910.jpg'),
(75823, 5192, 'Aggretsuko S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3tT2Bx7vDOYFulOd39sTn6DDjxU.jpg'),
(75824, 5192, 'Aggretsuko S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xIgbfyN5GBu0JPMzqDgcV073RvM.jpg'),
(75825, 5192, 'Aggretsuko S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ofBOgu6G7nkBWoqSBL9aZAUWZHL.jpg'),
(75826, 5192, 'Aggretsuko S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eGYqUCPYucckNXDzyUiZ7q0yzkS.jpg'),
(75827, 5192, 'Aggretsuko S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xtNVybO8LpM7EqBDqq2z6q2G6Y5.jpg'),
(75828, 5192, 'Aggretsuko S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tzfRpt4CuiL6bDTrKi9Ab5dm9yw.jpg'),
(75829, 5192, 'Aggretsuko S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Cd5dUAnW8wakwrS4AFvRprVFDl.jpg'),
(75830, 5192, 'Aggretsuko S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d6UyDqo8MF0BXqlJBnRgPDsRWNt.jpg'),
(75831, 5192, 'Aggretsuko S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shUnJOXs6DSVBzJ6P62fIkBOnwy.jpg'),
(75832, 5192, 'Aggretsuko S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AqNjvFZxl2zaNxxDVxzc39MFfPC.jpg'),
(75833, 5193, 'Aqueles Olhos Negros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eNY7Gk1wgwE3qClIPPwoc286mbV.jpg'),
(75834, 5193, 'Aqueles Olhos Negros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xRvnZd3lB2i5Fjf4JftUVJpsFi4.jpg'),
(75835, 5193, 'Aqueles Olhos Negros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yRJoPm2biS0yTzIZIJksxBKF7Cb.jpg'),
(75836, 5193, 'Aqueles Olhos Negros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oToJ2UxFsKA7RY2PfinXSLT5ohT.jpg'),
(75837, 5193, 'Aqueles Olhos Negros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f1D3grC9wVymHIoye039ReeQF68.jpg'),
(75838, 5193, 'Aqueles Olhos Negros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eWxe8uWVDEQJ30pmaLdIoOm5iRn.jpg'),
(75839, 5193, 'Aqueles Olhos Negros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qYoK79Eq8zbvqxftODShQU3ckaE.jpg'),
(75840, 5193, 'Aqueles Olhos Negros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ghpcbaoTGKsmQqn5EpFqlHfuxMe.jpg'),
(75841, 5194, 'Aqueles Olhos Negros S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtS38CTGr0v2N85Wvsc0nIb74YF.jpg'),
(75842, 5194, 'Aqueles Olhos Negros S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtS38CTGr0v2N85Wvsc0nIb74YF.jpg'),
(75843, 5194, 'Aqueles Olhos Negros S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtS38CTGr0v2N85Wvsc0nIb74YF.jpg'),
(75844, 5194, 'Aqueles Olhos Negros S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtS38CTGr0v2N85Wvsc0nIb74YF.jpg'),
(75845, 5194, 'Aqueles Olhos Negros S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtS38CTGr0v2N85Wvsc0nIb74YF.jpg'),
(75846, 5194, 'Aqueles Olhos Negros S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtS38CTGr0v2N85Wvsc0nIb74YF.jpg'),
(75847, 5195, 'Arquivo 81 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9qgwd08WLgv3MpZwLlmOiFy98Ll.jpg'),
(75848, 5195, 'Arquivo 81 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q2tK0BPJdIgZqYTajTX33bv0622.jpg'),
(75849, 5195, 'Arquivo 81 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kIlFeCnS9EIuF5isKc4FUJdtEW.jpg'),
(75850, 5195, 'Arquivo 81 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6lwdC5VKIcz90NwswG3Dy2aEIfp.jpg'),
(75851, 5195, 'Arquivo 81 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ISpg1oZ7GgPgD0RErNXwwX5qS.jpg'),
(75852, 5195, 'Arquivo 81 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2jBdZfzc8eKX7gl4lcfXcYSnnAr.jpg'),
(75853, 5195, 'Arquivo 81 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJI9671HJYwMk8mGdXVvfPttPXC.jpg'),
(75854, 5195, 'Arquivo 81 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lf02lDoLoDqVVGGEbq38aWfxDo1.jpg'),
(75855, 5196, 'Babylon 5 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1kBYVDGlvtEoR6R1mrXUAvZWVo.jpg'),
(75856, 5196, 'Babylon 5 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8oSHcFez5KBgbiPB3izhLH6lnbN.jpg'),
(75857, 5196, 'Babylon 5 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x7SDDsg4BskUtTu3xUBJUXFdpcq.jpg'),
(75858, 5196, 'Babylon 5 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tdmrJWG83FHK9HPYvFZmUBVRmDc.jpg'),
(75859, 5196, 'Babylon 5 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/olSAbE2dGc0fRsUeVxJvH5DmZfv.jpg'),
(75860, 5196, 'Babylon 5 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBP2GoLjZ8lsanOfSZ5UDwajiiS.jpg'),
(75861, 5196, 'Babylon 5 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xkhjwKqKM1SHdXJZguhGOhCFKjF.jpg'),
(75862, 5196, 'Babylon 5 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8dsiHI8RjORmxPJen2VsuJYBIj.jpg'),
(75863, 5196, 'Babylon 5 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iTtNL9nUCkVNkNTqPc8UYlRaorn.jpg'),
(75864, 5196, 'Babylon 5 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d5TaIOVhiYkPkMrHrsOAzMoBnGg.jpg'),
(75865, 5196, 'Babylon 5 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5sDz9tYC8knPfNDa5Fa2k9cQci3.jpg'),
(75866, 5196, 'Babylon 5 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4PYfq3Q4whc6UIUyd0vKdhsG0GW.jpg'),
(75867, 5196, 'Babylon 5 S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gmwi1VxNWJv2HeHS0v0Ag3JImsr.jpg'),
(75868, 5196, 'Babylon 5 S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/173524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/toP67SY7O6uEENXG9TkwTgyjxZ0.jpg'),
(75869, 5196, 'Babylon 5 S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/173525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJAOgaxPQKpyzsrsCGV27FFY5vI.jpg'),
(75870, 5196, 'Babylon 5 S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/173526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8P7atMZhxItYvDJCKWi2V2PghHS.jpg'),
(75871, 5196, 'Babylon 5 S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/173527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/55RMoJF4YjtWG8Q9tWkNyXcv8NX.jpg'),
(75872, 5196, 'Babylon 5 S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/173528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/acRXWdxLNgXk3HXKRW4hz69CgmM.jpg'),
(75873, 5196, 'Babylon 5 S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/173529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cUZMHPeb9tdC3pFHA6pLpp1cecU.jpg'),
(75874, 5196, 'Babylon 5 S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/173530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z4RfVLr6OSCPMw2FmNXwWuxZ7RN.jpg'),
(75875, 5196, 'Babylon 5 S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/173531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/er8rtkgy7aXFztP8hjGIHAuYESi.jpg'),
(75876, 5196, 'Babylon 5 S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/173532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/23AfTBojMC69NmcObQs37WxjBMs.jpg'),
(75877, 5197, 'Babylon 5 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173533.mp4', 'http://timg.bdta.pro/images/2ba1c812cbe340602a5c40c910305e6e.jpg'),
(75878, 5197, 'Babylon 5 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173534.mp4', 'http://timg.bdta.pro/images/5f77f03c718c6b935d6b664f419bb038.jpg'),
(75879, 5197, 'Babylon 5 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173535.mp4', 'http://timg.bdta.pro/images/7efb2ca9331b2b853269778417fe3033.jpg'),
(75880, 5197, 'Babylon 5 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173536.mp4', 'http://timg.bdta.pro/images/097531bc76852d70cb8db0650f6803d2.jpg'),
(75881, 5197, 'Babylon 5 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173537.mp4', 'http://timg.bdta.pro/images/339ed918352929d8b78f9216a15c72f6.jpg'),
(75882, 5197, 'Babylon 5 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173538.mp4', 'http://timg.bdta.pro/images/46674c4b76c3d3a9f0721c964a39e71d.jpg'),
(75883, 5197, 'Babylon 5 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173539.mp4', 'http://timg.bdta.pro/images/5894bc0221a967f3a9540d4f0a1c9198.jpg'),
(75884, 5197, 'Babylon 5 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173540.mp4', 'http://timg.bdta.pro/images/c936dc3ecb6b5c91651bf433e662ee4e.jpg'),
(75885, 5197, 'Babylon 5 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173541.mp4', 'http://timg.bdta.pro/images/f9b9d063e53fcaff6ccd05547dd7afad.jpg'),
(75886, 5197, 'Babylon 5 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173542.mp4', 'http://timg.bdta.pro/images/18eef0d3094ddaba2e2338760f3dc118.jpg'),
(75887, 5197, 'Babylon 5 S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173543.mp4', 'http://timg.bdta.pro/images/e6075558808f02f4e4d7f48778cf8f28.jpg'),
(75888, 5197, 'Babylon 5 S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173544.mp4', 'http://timg.bdta.pro/images/e6fdf2dd774fe151e92ba643f8dea7e0.jpg'),
(75889, 5197, 'Babylon 5 S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173545.mp4', 'http://timg.bdta.pro/images/a641cc25b93371ba69a6185220dea9ed.jpg'),
(75890, 5197, 'Babylon 5 S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/173546.mp4', 'http://timg.bdta.pro/images/498fba945bec8545f6328606f2842020.jpg'),
(75891, 5197, 'Babylon 5 S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/173547.mp4', 'http://timg.bdta.pro/images/803c856471e5455bf7bb3091d71156a3.jpg'),
(75892, 5197, 'Babylon 5 S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/173548.mp4', 'http://timg.bdta.pro/images/9584c22149a38788e8d48c2dc61fb27c.jpg'),
(75893, 5197, 'Babylon 5 S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/173549.mp4', 'http://timg.bdta.pro/images/b8341b44728ac9c5b2ead896315199d3.jpg'),
(75894, 5197, 'Babylon 5 S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/173550.mp4', 'http://timg.bdta.pro/images/dfd66911a79b663abd0d50c110fd33ad.jpg'),
(75895, 5197, 'Babylon 5 S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/173551.mp4', 'http://timg.bdta.pro/images/11d547b10922eee14e47859999cb61b9.jpg'),
(75896, 5197, 'Babylon 5 S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/173552.mp4', 'http://timg.bdta.pro/images/9085783b255d5c7177a8b3aa327fff92.jpg'),
(75897, 5197, 'Babylon 5 S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/173553.mp4', 'http://timg.bdta.pro/images/3d850ac7cc07380593872fb9d6bc38bc.jpg'),
(75898, 5197, 'Babylon 5 S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/173554.mp4', 'http://timg.bdta.pro/images/d75298fe5327013bae6d82112f25bc49.jpg'),
(75899, 5198, 'Babylon 5 S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173555.mp4', 'http://timg.bdta.pro/images/3d53b070922dd5c79139622d8b14b54a.jpg'),
(75900, 5198, 'Babylon 5 S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173556.mp4', 'http://timg.bdta.pro/images/2588c93d371580b7cbe030a6b2b7a877.jpg'),
(75901, 5198, 'Babylon 5 S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173557.mp4', 'http://timg.bdta.pro/images/4c30ed842959918f9231017bb82aec1f.jpg'),
(75902, 5198, 'Babylon 5 S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173558.mp4', 'http://timg.bdta.pro/images/675f6c5894cb58ff7a181fc321262ecd.jpg'),
(75903, 5198, 'Babylon 5 S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173559.mp4', 'http://timg.bdta.pro/images/8e34fcb86a6cabd96ab750d0ea884f8f.jpg'),
(75904, 5198, 'Babylon 5 S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173560.mp4', 'http://timg.bdta.pro/images/8bef5bc90de8b9d5030632b6770b1ab5.jpg'),
(75905, 5198, 'Babylon 5 S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173561.mp4', 'http://timg.bdta.pro/images/55b4b37ca9ee2934c57123a3db88917f.jpg'),
(75906, 5198, 'Babylon 5 S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173562.mp4', 'http://timg.bdta.pro/images/413781bedd9f31eb66d54b2b8f335877.jpg'),
(75907, 5198, 'Babylon 5 S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173563.mp4', 'http://timg.bdta.pro/images/f02d82c9951e6a2d5099122493118f6f.jpg'),
(75908, 5198, 'Babylon 5 S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173564.mp4', 'http://timg.bdta.pro/images/af589fec4634a9b06de8a0c620071ea1.jpg'),
(75909, 5198, 'Babylon 5 S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173565.mp4', 'http://timg.bdta.pro/images/ed16d1ed63ccf7ccd0541f84074cbf0a.jpg'),
(75910, 5198, 'Babylon 5 S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173566.mp4', 'http://timg.bdta.pro/images/9a101ab9d57521ce4b513a39542fbb80.jpg'),
(75911, 5198, 'Babylon 5 S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173567.mp4', 'http://timg.bdta.pro/images/079b034ca5da1056ac8c2966e01e8c5e.jpg'),
(75912, 5198, 'Babylon 5 S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/173568.mp4', 'http://timg.bdta.pro/images/62fb0c2353ffdfba42d2f4d8ea32cab5.jpg'),
(75913, 5198, 'Babylon 5 S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/173569.mp4', 'http://timg.bdta.pro/images/ad25bbcf63d61d4d0c7df8f514fc6d73.jpg'),
(75914, 5198, 'Babylon 5 S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/173570.mp4', 'http://timg.bdta.pro/images/fa7de51e13b37ff19a26222900d3a614.jpg'),
(75915, 5198, 'Babylon 5 S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/173571.mp4', 'http://timg.bdta.pro/images/4abbd2e7e38599eab39bc9ba99538b7e.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(75916, 5198, 'Babylon 5 S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/173572.mp4', 'http://timg.bdta.pro/images/5733c027f14ce6f4edbd0e8a06528ff8.jpg'),
(75917, 5198, 'Babylon 5 S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/173573.mp4', 'http://timg.bdta.pro/images/f7ba3e0036bcdabb2493a579ed5c18e2.jpg'),
(75918, 5198, 'Babylon 5 S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/173574.mp4', 'http://timg.bdta.pro/images/55692abb2eeae95d2c117f014d0193dc.jpg'),
(75919, 5198, 'Babylon 5 S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/173575.mp4', 'http://timg.bdta.pro/images/665dbfa28202e550e09d7c9d654042bc.jpg'),
(75920, 5198, 'Babylon 5 S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/173576.mp4', 'http://timg.bdta.pro/images/5dcad9fba8360573c783525ac89414a4.jpg'),
(75921, 5199, 'Babylon 5 S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173577.mp4', 'http://timg.bdta.pro/images/f3bcac7cb87aa7005b75c556d7276b19.jpg'),
(75922, 5199, 'Babylon 5 S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173578.mp4', 'http://timg.bdta.pro/images/3bafbd8b12b3612dbdbdd69b56fe9735.jpg'),
(75923, 5199, 'Babylon 5 S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173579.mp4', 'http://timg.bdta.pro/images/295f2c2fbd43d066c95a526f5ab4db1c.jpg'),
(75924, 5199, 'Babylon 5 S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173580.mp4', 'http://timg.bdta.pro/images/890320aa137c8c2457f8dcae063a2cd2.jpg'),
(75925, 5199, 'Babylon 5 S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173581.mp4', 'http://timg.bdta.pro/images/7c0447802f646554a51f38c67c2825fc.jpg'),
(75926, 5199, 'Babylon 5 S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173582.mp4', 'http://timg.bdta.pro/images/3521b4d3119c3fad19dd0da8ef6a3ed1.jpg'),
(75927, 5199, 'Babylon 5 S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173583.mp4', 'http://timg.bdta.pro/images/dd4ecb64b529133547be5eaf70d89c7f.jpg'),
(75928, 5199, 'Babylon 5 S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173584.mp4', 'http://timg.bdta.pro/images/92c7823b8569ece3d1edc8b8a42520a6.jpg'),
(75929, 5199, 'Babylon 5 S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173585.mp4', 'http://timg.bdta.pro/images/5f44269b3efce8fb1372b46f7315ed09.jpg'),
(75930, 5199, 'Babylon 5 S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173586.mp4', 'http://timg.bdta.pro/images/f8cf2d71fa39a46464a774c8d6f70a8c.jpg'),
(75931, 5199, 'Babylon 5 S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173587.mp4', 'http://timg.bdta.pro/images/fed2551b10889b5a7a0f95c688735cfd.jpg'),
(75932, 5199, 'Babylon 5 S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173588.mp4', 'http://timg.bdta.pro/images/9e0d73841ab71118cc7f07c742805a51.jpg'),
(75933, 5199, 'Babylon 5 S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173589.mp4', 'http://timg.bdta.pro/images/db68fe6d08fc3dc6c0444363d9e3912f.jpg'),
(75934, 5199, 'Babylon 5 S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/173590.mp4', 'http://timg.bdta.pro/images/464aef84179eeb8ff477997a2ec37cb6.jpg'),
(75935, 5199, 'Babylon 5 S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/173591.mp4', 'http://timg.bdta.pro/images/e9f06fd07be54dd888c19939286a0b44.jpg'),
(75936, 5199, 'Babylon 5 S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/173592.mp4', 'http://timg.bdta.pro/images/ed0968267914421d57ce9312df6d3f2f.jpg'),
(75937, 5199, 'Babylon 5 S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/173593.mp4', 'http://timg.bdta.pro/images/d4bae1644017de0c446dfe17c4edc91e.jpg'),
(75938, 5199, 'Babylon 5 S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/173594.mp4', 'http://timg.bdta.pro/images/02e528ba869adb282c35ea10f2702ae6.jpg'),
(75939, 5199, 'Babylon 5 S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/173595.mp4', 'http://timg.bdta.pro/images/aac9c53e34fd6f7012587dfb2792233a.jpg'),
(75940, 5199, 'Babylon 5 S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/173596.mp4', 'http://timg.bdta.pro/images/b779ec6a85f0f5d9246f2772243b0a90.jpg'),
(75941, 5199, 'Babylon 5 S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/173597.mp4', 'http://timg.bdta.pro/images/45090f890bc68b7dbf66549f6b5f85e4.jpg'),
(75942, 5199, 'Babylon 5 S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/173598.mp4', 'http://timg.bdta.pro/images/0a77f339d3f38a07a8532e6176e9ea3d.jpg'),
(75943, 5200, 'Babylon 5 S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173599.mp4', 'http://timg.bdta.pro/images/36ea83bd901dc4959fe8f111d0083c1a.jpg'),
(75944, 5200, 'Babylon 5 S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173600.mp4', 'http://timg.bdta.pro/images/d5d1eb90f20887107ae5ec3d10eba01e.jpg'),
(75945, 5200, 'Babylon 5 S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173601.mp4', 'http://timg.bdta.pro/images/c938abb1cb310df592516bd686c00f53.jpg'),
(75946, 5200, 'Babylon 5 S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173602.mp4', 'http://timg.bdta.pro/images/be24abaac1531678fe45bfe5b2f13a3c.jpg'),
(75947, 5200, 'Babylon 5 S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173603.mp4', 'http://timg.bdta.pro/images/0f51ffbd82a22b06d23d3a8c402977db.jpg'),
(75948, 5200, 'Babylon 5 S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173604.mp4', 'http://timg.bdta.pro/images/22217fefaea6d12710b6b4b2ea8d0aad.jpg'),
(75949, 5200, 'Babylon 5 S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173605.mp4', 'http://timg.bdta.pro/images/cd9e59d230f9fbbe632a68d2e9ec3a19.jpg'),
(75950, 5200, 'Babylon 5 S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173606.mp4', 'http://timg.bdta.pro/images/887a5bfa1ecd9d401df80ed6acefbb21.jpg'),
(75951, 5200, 'Babylon 5 S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173607.mp4', 'http://timg.bdta.pro/images/3971b07f0f45f6cdbec40b27a5a30429.jpg'),
(75952, 5200, 'Babylon 5 S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173608.mp4', 'http://timg.bdta.pro/images/21521e0c7773d54087e8db211bb64e98.jpg'),
(75953, 5200, 'Babylon 5 S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173609.mp4', 'http://timg.bdta.pro/images/3da6232512513ed012001be324b13908.jpg'),
(75954, 5200, 'Babylon 5 S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173610.mp4', 'http://timg.bdta.pro/images/6c6092823e3f180751d84f1a83b044cb.jpg'),
(75955, 5200, 'Babylon 5 S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173611.mp4', 'http://timg.bdta.pro/images/b94504aade46c30a8b43ac46264ebf94.jpg'),
(75956, 5200, 'Babylon 5 S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/173612.mp4', 'http://timg.bdta.pro/images/2bc0b8246c8cc4be3b237b1165b6335f.jpg'),
(75957, 5200, 'Babylon 5 S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/173613.mp4', 'http://timg.bdta.pro/images/e555d50a5133322df15fd959904ada43.jpg'),
(75958, 5200, 'Babylon 5 S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/173614.mp4', 'http://timg.bdta.pro/images/02a2f519f736576478c72d17b35b78dc.jpg'),
(75959, 5200, 'Babylon 5 S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/173615.mp4', 'http://timg.bdta.pro/images/7b55a539b8017c4cf870d589b3edc89e.jpg'),
(75960, 5200, 'Babylon 5 S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/173616.mp4', 'http://timg.bdta.pro/images/190b85ce452c33844c2e9e8691dbfcfc.jpg'),
(75961, 5200, 'Babylon 5 S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/173617.mp4', 'http://timg.bdta.pro/images/f04fe0d902887fe26e89d38eed05c8e7.jpg'),
(75962, 5200, 'Babylon 5 S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/173618.mp4', 'http://timg.bdta.pro/images/510817368d18f670bb99288f7a0eb648.jpg'),
(75963, 5200, 'Babylon 5 S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/173619.mp4', 'http://timg.bdta.pro/images/42fc6f5ff08c4296d9ded7b4cd5d9274.jpg'),
(75964, 5200, 'Babylon 5 S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/173620.mp4', 'http://timg.bdta.pro/images/24546a81ea852d9fb11b05d2f93fa8cc.jpg'),
(75965, 5201, 'De Férias com o Ex Caribe S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75966, 5201, 'De Férias com o Ex Caribe S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75967, 5201, 'De Férias com o Ex Caribe S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75968, 5201, 'De Férias com o Ex Caribe S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75969, 5201, 'De Férias com o Ex Caribe S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75970, 5201, 'De Férias com o Ex Caribe S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75971, 5201, 'De Férias com o Ex Caribe S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75972, 5201, 'De Férias com o Ex Caribe S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75973, 5201, 'De Férias com o Ex Caribe S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75974, 5201, 'De Férias com o Ex Caribe S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75975, 5201, 'De Férias com o Ex Caribe S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75976, 5201, 'De Férias com o Ex Caribe S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75977, 5202, 'De Férias com o Ex Caribe S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75978, 5202, 'De Férias com o Ex Caribe S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75979, 5202, 'De Férias com o Ex Caribe S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75980, 5202, 'De Férias com o Ex Caribe S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75981, 5202, 'De Férias com o Ex Caribe S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75982, 5202, 'De Férias com o Ex Caribe S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75983, 5202, 'De Férias com o Ex Caribe S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75984, 5202, 'De Férias com o Ex Caribe S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7bkCDdGAG8QlU0LzLWv4kow9J5L.jpg'),
(75985, 5202, 'De Férias com o Ex Caribe S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nqqBKmBn7Bm0NoHCzLRPO6Jrhpp.jpg'),
(75986, 5202, 'De Férias com o Ex Caribe S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5MzIHSV8NtuvVXo3Z4i1UzumgT.jpg'),
(75987, 5202, 'De Férias com o Ex Caribe S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AwiI0F1IqU0IqJv9PXxYnbvgNuS.jpg'),
(75988, 5202, 'De Férias com o Ex Caribe S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qfmJj76vBfF9PENrmEoSZgB5wOH.jpg'),
(75989, 5203, 'De Férias com o Ex Caribe S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75990, 5203, 'De Férias com o Ex Caribe S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75991, 5203, 'De Férias com o Ex Caribe S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75992, 5203, 'De Férias com o Ex Caribe S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75993, 5203, 'De Férias com o Ex Caribe S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75994, 5203, 'De Férias com o Ex Caribe S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75995, 5203, 'De Férias com o Ex Caribe S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75996, 5203, 'De Férias com o Ex Caribe S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75997, 5203, 'De Férias com o Ex Caribe S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75998, 5203, 'De Férias com o Ex Caribe S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(75999, 5203, 'De Férias com o Ex Caribe S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(76000, 5203, 'De Férias com o Ex Caribe S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(76001, 5203, 'De Férias com o Ex Caribe S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(76002, 5204, 'De Férias com o Ex Caribe S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/816148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(76003, 5204, 'De Férias com o Ex Caribe S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/816149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(76004, 5204, 'De Férias com o Ex Caribe S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/822713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(76005, 5204, 'De Férias com o Ex Caribe S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/828279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(76006, 5204, 'De Férias com o Ex Caribe S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/842017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(76007, 5204, 'De Férias com o Ex Caribe S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/847723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(76008, 5204, 'De Férias com o Ex Caribe S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/851490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(76009, 5204, 'De Férias com o Ex Caribe S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/856445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(76010, 5204, 'De Férias com o Ex Caribe S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/865744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(76011, 5204, 'De Férias com o Ex Caribe S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/870867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(76012, 5204, 'De Férias com o Ex Caribe S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/874642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(76013, 5204, 'De Férias com o Ex Caribe S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/879427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(76014, 5204, 'De Férias com o Ex Caribe S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/879892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(76015, 5204, 'De Férias com o Ex Caribe S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/882366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qt2aU4M55WULh4KDb4hxHuokrju.jpg'),
(76016, 5205, 'Descendentes do Sol [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cbPzc5qli0iyOvIBjPgJq3CriDk.jpg'),
(76017, 5205, 'Descendentes do Sol [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zZTsDCuvWBTMk5vWy8xMRjrUWk8.jpg'),
(76018, 5205, 'Descendentes do Sol [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zI0absqhHPgDX6xFVyC1UlJouDE.jpg'),
(76019, 5205, 'Descendentes do Sol [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tCfo6w7A9exHAeukfJ10PbsrQ0O.jpg'),
(76020, 5205, 'Descendentes do Sol [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4YiXDHILdrJZ9C8Wm34GViXFl7F.jpg'),
(76021, 5205, 'Descendentes do Sol [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6EG89BO40yeccgWqAWQ4whoR9qg.jpg'),
(76022, 5205, 'Descendentes do Sol [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a1Q6bV1ArNzFjQpS4TyLpPWKYX8.jpg'),
(76023, 5205, 'Descendentes do Sol [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ajb3TgeSwm9LAKGsLYLkhli10fd.jpg'),
(76024, 5205, 'Descendentes do Sol [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uYodWxXaOLZVSFrI2jSP4GvdhPy.jpg'),
(76025, 5205, 'Descendentes do Sol [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xSYQAuD2pd9IAKDjCUqQKiGfrEI.jpg'),
(76026, 5205, 'Descendentes do Sol [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6eqPKGqnJIEc7HIsYOhRqiUIBBs.jpg'),
(76027, 5205, 'Descendentes do Sol [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ee3hlcRP7taSaEjJp5ooyg6uL74.jpg'),
(76028, 5205, 'Descendentes do Sol [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pakSKZyU4gMKvcxzwcXCrszdnYr.jpg'),
(76029, 5205, 'Descendentes do Sol [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1iizaIR7Vc0g5PWOP0nTfPzQm7K.jpg'),
(76030, 5205, 'Descendentes do Sol [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rEwyssPOg9mCC1n8mOR9dJL3fWA.jpg'),
(76031, 5205, 'Descendentes do Sol [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ogo5XLnVyQACCaGeyo1jrhp9CA6.jpg'),
(76032, 5205, 'Descendentes do Sol [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d0XyclHMeH9sBjay3sXvSKAWeFC.jpg'),
(76033, 5205, 'Descendentes do Sol [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d0XyclHMeH9sBjay3sXvSKAWeFC.jpg'),
(76034, 5205, 'Descendentes do Sol [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/171534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d0XyclHMeH9sBjay3sXvSKAWeFC.jpg'),
(76035, 5206, 'Dupla do Barulho ao Resgate S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5j84NUrVKSQ3a4hRTGBC4NiC3Ii.jpg'),
(76036, 5206, 'Dupla do Barulho ao Resgate S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5j84NUrVKSQ3a4hRTGBC4NiC3Ii.jpg'),
(76037, 5206, 'Dupla do Barulho ao Resgate S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vTVP1l0iQpGt4qCyuxPNBWprzZK.jpg'),
(76038, 5206, 'Dupla do Barulho ao Resgate S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5j84NUrVKSQ3a4hRTGBC4NiC3Ii.jpg'),
(76039, 5206, 'Dupla do Barulho ao Resgate S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5j84NUrVKSQ3a4hRTGBC4NiC3Ii.jpg'),
(76040, 5206, 'Dupla do Barulho ao Resgate S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5j84NUrVKSQ3a4hRTGBC4NiC3Ii.jpg'),
(76041, 5206, 'Dupla do Barulho ao Resgate S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5j84NUrVKSQ3a4hRTGBC4NiC3Ii.jpg'),
(76042, 5206, 'Dupla do Barulho ao Resgate S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5j84NUrVKSQ3a4hRTGBC4NiC3Ii.jpg'),
(76043, 5206, 'Dupla do Barulho ao Resgate S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5j84NUrVKSQ3a4hRTGBC4NiC3Ii.jpg'),
(76044, 5206, 'Dupla do Barulho ao Resgate S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5j84NUrVKSQ3a4hRTGBC4NiC3Ii.jpg'),
(76045, 5206, 'Dupla do Barulho ao Resgate S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5j84NUrVKSQ3a4hRTGBC4NiC3Ii.jpg'),
(76046, 5206, 'Dupla do Barulho ao Resgate S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5j84NUrVKSQ3a4hRTGBC4NiC3Ii.jpg'),
(76047, 5206, 'Dupla do Barulho ao Resgate S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5j84NUrVKSQ3a4hRTGBC4NiC3Ii.jpg'),
(76048, 5206, 'Dupla do Barulho ao Resgate S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5j84NUrVKSQ3a4hRTGBC4NiC3Ii.jpg'),
(76049, 5206, 'Dupla do Barulho ao Resgate S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5j84NUrVKSQ3a4hRTGBC4NiC3Ii.jpg'),
(76050, 5206, 'Dupla do Barulho ao Resgate S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5j84NUrVKSQ3a4hRTGBC4NiC3Ii.jpg'),
(76051, 5206, 'Dupla do Barulho ao Resgate S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5j84NUrVKSQ3a4hRTGBC4NiC3Ii.jpg'),
(76052, 5206, 'Dupla do Barulho ao Resgate S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5j84NUrVKSQ3a4hRTGBC4NiC3Ii.jpg'),
(76053, 5206, 'Dupla do Barulho ao Resgate S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/171514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5j84NUrVKSQ3a4hRTGBC4NiC3Ii.jpg'),
(76054, 5206, 'Dupla do Barulho ao Resgate S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/171515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5j84NUrVKSQ3a4hRTGBC4NiC3Ii.jpg'),
(76055, 5207, 'Estação Onze S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hGTb6PDUlMUZCuB9oVV7MqMddOg.jpg'),
(76056, 5207, 'Estação Onze S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mvksVnZqGqHVZk2MKLDwAtmIz0Y.jpg'),
(76057, 5207, 'Estação Onze S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBPGU2SUGODPmw3Np9dK9VOXBFm.jpg'),
(76058, 5207, 'Estação Onze S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/33HZEuxlC4u7UzlxOxLKKfI7K8u.jpg'),
(76059, 5207, 'Estação Onze S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1CWrxP81thMXkZVP7jcTard7I33.jpg'),
(76060, 5207, 'Estação Onze S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oEJkmyi4V5LgzIrSS6auO3nw42x.jpg'),
(76061, 5207, 'Estação Onze S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5tMy5hvFGcCKbTFFrVh2Me975da.jpg'),
(76062, 5207, 'Estação Onze S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqdCFHQoSOxnNoVz4FZJkrhQJlN.jpg'),
(76063, 5207, 'Estação Onze S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4xbAjYLICEBIW8bvj1JZEv5OgjO.jpg'),
(76064, 5207, 'Estação Onze S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fSRxtMvWEqHoEdob7pT3XjBVaXx.jpg'),
(76065, 5208, 'Estrela fascinante Patrine S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76066, 5208, 'Estrela fascinante Patrine S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76067, 5208, 'Estrela fascinante Patrine S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76068, 5208, 'Estrela fascinante Patrine S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76069, 5208, 'Estrela fascinante Patrine S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76070, 5208, 'Estrela fascinante Patrine S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76071, 5208, 'Estrela fascinante Patrine S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76072, 5208, 'Estrela fascinante Patrine S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76073, 5208, 'Estrela fascinante Patrine S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76074, 5208, 'Estrela fascinante Patrine S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76075, 5208, 'Estrela fascinante Patrine S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76076, 5208, 'Estrela fascinante Patrine S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76077, 5208, 'Estrela fascinante Patrine S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/194483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76078, 5208, 'Estrela fascinante Patrine S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/194484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76079, 5208, 'Estrela fascinante Patrine S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/194485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76080, 5208, 'Estrela fascinante Patrine S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/194486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76081, 5208, 'Estrela fascinante Patrine S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/194487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76082, 5208, 'Estrela fascinante Patrine S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/194488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76083, 5208, 'Estrela fascinante Patrine S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/194489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76084, 5208, 'Estrela fascinante Patrine S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/194490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76085, 5208, 'Estrela fascinante Patrine S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/194491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76086, 5208, 'Estrela fascinante Patrine S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/194492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76087, 5208, 'Estrela fascinante Patrine S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/194493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76088, 5208, 'Estrela fascinante Patrine S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/194494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76089, 5208, 'Estrela fascinante Patrine S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/194495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76090, 5208, 'Estrela fascinante Patrine S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/194496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76091, 5208, 'Estrela fascinante Patrine S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/194497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76092, 5208, 'Estrela fascinante Patrine S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/194498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76093, 5208, 'Estrela fascinante Patrine S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/194499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76094, 5208, 'Estrela fascinante Patrine S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/194500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76095, 5208, 'Estrela fascinante Patrine S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/194501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76096, 5208, 'Estrela fascinante Patrine S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/194502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76097, 5208, 'Estrela fascinante Patrine S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/194503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76098, 5208, 'Estrela fascinante Patrine S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/194504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76099, 5208, 'Estrela fascinante Patrine S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/194505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76100, 5208, 'Estrela fascinante Patrine S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/194506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76101, 5208, 'Estrela fascinante Patrine S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/194507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76102, 5208, 'Estrela fascinante Patrine S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/194508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76103, 5208, 'Estrela fascinante Patrine S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/194509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76104, 5208, 'Estrela fascinante Patrine S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/194510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76105, 5208, 'Estrela fascinante Patrine S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/194511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76106, 5208, 'Estrela fascinante Patrine S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/194512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76107, 5208, 'Estrela fascinante Patrine S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/194513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76108, 5208, 'Estrela fascinante Patrine S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/194514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76109, 5208, 'Estrela fascinante Patrine S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/194515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76110, 5208, 'Estrela fascinante Patrine S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/194516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76111, 5208, 'Estrela fascinante Patrine S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/194517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76112, 5208, 'Estrela fascinante Patrine S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/194518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76113, 5208, 'Estrela fascinante Patrine S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/194519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76114, 5208, 'Estrela fascinante Patrine S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/194520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76115, 5208, 'Estrela fascinante Patrine S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/194521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76116, 5208, 'Estrela fascinante Patrine S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/194522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pxIl32GtXBHxZLwZtqbx2jYcoa.jpg'),
(76117, 5209, 'FBI: International S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDaO3bEcQ3gFg3AIyOZLFuXqhWn.jpg'),
(76118, 5209, 'FBI: International S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224360.mp4', 'http://timg.bdta.pro/images/c528c1b6142276150042bd9862b1c134.jpg'),
(76119, 5209, 'FBI: International S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224361.mp4', 'http://timg.bdta.pro/images/2bc4487b308f3c8fb5d4c8d3e79b106d.jpg'),
(76120, 5209, 'FBI: International S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224362.mp4', 'http://timg.bdta.pro/images/255ecdba6cb6193e4657027962a6f4c7.jpg'),
(76121, 5209, 'FBI: International S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224363.mp4', 'http://timg.bdta.pro/images/f1918f5ce108b8712b7d724ac9f7898e.jpg'),
(76122, 5209, 'FBI: International S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224364.mp4', 'http://timg.bdta.pro/images/5380c2f0c10b319300ab3c2f5c538a8a.jpg'),
(76123, 5209, 'FBI: International S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224365.mp4', 'http://timg.bdta.pro/images/960592ee9d7e1752d6bda27a9a1bdd5e.jpg'),
(76124, 5209, 'FBI: International S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224366.mp4', 'http://timg.bdta.pro/images/43bccec547690b25ecd6a00b0d11de65.jpg'),
(76125, 5209, 'FBI: International S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224367.mp4', 'http://timg.bdta.pro/images/c8538892b8cca3e778e9f3eae8c00e5a.jpg'),
(76126, 5209, 'FBI: International S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224368.mp4', 'http://timg.bdta.pro/images/4f3943bf9f2f982178388cc7448357ce.jpg'),
(76127, 5209, 'FBI: International S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224369.mp4', 'http://timg.bdta.pro/images/35d74998f071d328e89fffbebe88d24e.jpg'),
(76128, 5209, 'FBI: International S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224370.mp4', 'http://timg.bdta.pro/images/e3a88fe0e5d572d96f267e2a0f4b8fde.jpg'),
(76129, 5209, 'FBI: International S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224371.mp4', 'http://timg.bdta.pro/images/4e3255bb36b54d3c9a7668ec26768ae5.jpg'),
(76130, 5209, 'FBI: International S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224372.mp4', 'http://timg.bdta.pro/images/6f840eda349bde4ea1abab18f844ac40.jpg'),
(76131, 5209, 'FBI: International S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76132, 5209, 'FBI: International S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224374.mp4', 'http://timg.bdta.pro/images/88ff604dd0a7ce6feac3cb737e4f540e.jpg'),
(76133, 5209, 'FBI: International S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224375.mp4', 'http://timg.bdta.pro/images/2e71d6876a8ac8d5e744dbf59e0be254.jpg'),
(76134, 5209, 'FBI: International S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224376.mp4', 'http://timg.bdta.pro/images/8cd76d6b51431fe634054474ece45ca8.jpg'),
(76135, 5209, 'FBI: International S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224377.mp4', 'http://timg.bdta.pro/images/c3b2e324f39017dd41aef4aba7a645b7.jpg'),
(76136, 5209, 'FBI: International S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224378.mp4', 'http://timg.bdta.pro/images/6a4d8af1ff353aa394f68ba738184b1c.jpg'),
(76137, 5209, 'FBI: International S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224379.mp4', 'http://timg.bdta.pro/images/12cc7a42b1b6620de25747b481d49e1f.jpg'),
(76138, 5210, 'FBI: International S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224380.mp4', 'http://image.tmdb.org/t/p/w1280/bWKd2urjukUKgWXAba1EiCXtvmi.jpg'),
(76139, 5210, 'FBI: International S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224381.mp4', 'http://image.tmdb.org/t/p/w1280/mH9usEz0L0mHzHGI6F4rQlLxbWm.jpg'),
(76140, 5210, 'FBI: International S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224382.mp4', 'http://image.tmdb.org/t/p/w1280/mjdfxTOVDB4fibax3npWKSkNa6s.jpg'),
(76141, 5210, 'FBI: International S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224383.mp4', 'http://image.tmdb.org/t/p/w1280/z9XmrOSkUHMfRoXqPRDdN5HSPGi.jpg'),
(76142, 5210, 'FBI: International S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224384.mp4', 'http://image.tmdb.org/t/p/w1280/7ig1Ddc9mpLIeld6BBLAPfmIngI.jpg'),
(76143, 5210, 'FBI: International S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224385.mp4', 'http://image.tmdb.org/t/p/w1280/2kG9KvnE9UBod6WQjTnqbPs3nEa.jpg'),
(76144, 5210, 'FBI: International S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224386.mp4', 'http://image.tmdb.org/t/p/w1280/sfcnH6G0MxIhytvhwFLybKEe3bX.jpg'),
(76145, 5210, 'FBI: International S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224387.mp4', 'http://image.tmdb.org/t/p/w1280/zRqoTcGxQAbZiBQnyrpWpfDtAdC.jpg'),
(76146, 5210, 'FBI: International S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224388.mp4', 'http://image.tmdb.org/t/p/w1280/nLTO76yhGLgBM5LuIazA1Z9Xgz0.jpg'),
(76147, 5210, 'FBI: International S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224389.mp4', 'http://image.tmdb.org/t/p/w1280/bi5SKc6xyXpUELEIBu8Ie8KBYvP.jpg'),
(76148, 5210, 'FBI: International S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224390.mp4', 'http://image.tmdb.org/t/p/w1280/wxDSQE9g98tEIJjcKmnggA9zJ1V.jpg'),
(76149, 5210, 'FBI: International S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224391.mp4', 'http://image.tmdb.org/t/p/w1280/jkvjND6cHPysBzgpXP79YMaou8h.jpg'),
(76150, 5210, 'FBI: International S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224392.mp4', 'http://image.tmdb.org/t/p/w1280/51IN4qPO65PKf6eaV2b0bH0iU48.jpg'),
(76151, 5210, 'FBI: International S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224393.mp4', 'http://image.tmdb.org/t/p/w1280/lu9PQa9DxisdlBsYUt9YFQatrig.jpg'),
(76152, 5210, 'FBI: International S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224394.mp4', 'http://image.tmdb.org/t/p/w1280/xv8pC97hfFBwPTglPbl5eaNK1yg.jpg'),
(76153, 5210, 'FBI: International S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224395.mp4', 'http://image.tmdb.org/t/p/w1280/2dGGr3MqMUxi4g47hEkRMDwWDp.jpg'),
(76154, 5210, 'FBI: International S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224396.mp4', 'http://image.tmdb.org/t/p/w1280/hc0AUjJEVyR4cx9f76TLBOa55fN.jpg'),
(76155, 5210, 'FBI: International S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224397.mp4', 'http://image.tmdb.org/t/p/w1280/rIjYOV86els8OcOuTcGq5UQ0uG0.jpg'),
(76156, 5210, 'FBI: International S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224398.mp4', 'http://image.tmdb.org/t/p/w1280/frI1ZAC9uK1Y5Ble9Mrk29WLo60.jpg'),
(76157, 5210, 'FBI: International S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224399.mp4', 'http://image.tmdb.org/t/p/w1280/v0zVTi21G6djPW0dsDDTi3ouMxk.jpg'),
(76158, 5210, 'FBI: International S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224400.mp4', 'http://image.tmdb.org/t/p/w1280/g79KZ0yBJNXxZEzQJkr3ULgAmYI.jpg'),
(76159, 5210, 'FBI: International S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224401.mp4', 'http://image.tmdb.org/t/p/w1280/eDfpeLYIdYf9ay7HeqlmR95x3bf.jpg'),
(76160, 5211, 'FBI: International S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/338889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76161, 5211, 'FBI: International S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/338890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76162, 5211, 'FBI: International S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/345599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76163, 5211, 'FBI: International S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/356655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76164, 5211, 'FBI: International S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/356656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76165, 5211, 'FBI: International S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/363550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76166, 5211, 'FBI: International S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/368977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76167, 5211, 'FBI: International S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/384307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76168, 5211, 'FBI: International S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/384308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76169, 5211, 'FBI: International S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/384309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76170, 5211, 'FBI: International S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/397082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76171, 5211, 'FBI: International S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/403494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76172, 5211, 'FBI: International S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/409235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76173, 5212, 'FBI: International S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/662984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76174, 5212, 'FBI: International S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/665028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76175, 5212, 'FBI: International S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/677718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76176, 5212, 'FBI: International S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/679800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76177, 5212, 'FBI: International S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/687660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76178, 5212, 'FBI: International S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/696188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76179, 5212, 'FBI: International S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/701997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76180, 5212, 'FBI: International S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/714979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(76181, 5212, 'FBI: International S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/718533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76182, 5212, 'FBI: International S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/724922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76183, 5212, 'FBI: International S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/731550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76184, 5212, 'FBI: International S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/742756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76185, 5212, 'FBI: International S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/767559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76186, 5212, 'FBI: International S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/767560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76187, 5212, 'FBI: International S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/794861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76188, 5212, 'FBI: International S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/796057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76189, 5212, 'FBI: International S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/801399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76190, 5212, 'FBI: International S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/810199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76191, 5212, 'FBI: International S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/822604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76192, 5212, 'FBI: International S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/838144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76193, 5212, 'FBI: International S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/847445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76194, 5212, 'FBI: International S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/854914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyVOAhJzPy7jP1yB6ujIhvbX2Ru.jpg'),
(76195, 5213, 'Flatbush Misdemeanors S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/idBSg1S263yGLsGjSMc9n8whZc0.jpg'),
(76196, 5213, 'Flatbush Misdemeanors S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qTW0JB47VnGc4Vvk0TSHPuGygrn.jpg'),
(76197, 5213, 'Flatbush Misdemeanors S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/drSDZmEaxljZSFG40198Aj9PLH9.jpg'),
(76198, 5213, 'Flatbush Misdemeanors S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTo3CB5sTr06QVck3caDei12V2L.jpg'),
(76199, 5213, 'Flatbush Misdemeanors S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0x8lzrM1USXtUXhX74kRYQYHe3.jpg'),
(76200, 5213, 'Flatbush Misdemeanors S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ny2BjaPubWHyxQ6r6RWVC3Zp4WI.jpg'),
(76201, 5213, 'Flatbush Misdemeanors S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1enZ0ct54rrRSJXu21gCH68KqxR.jpg'),
(76202, 5213, 'Flatbush Misdemeanors S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aIiJWI9CulrYYZG0TkPmpqVfvbN.jpg'),
(76203, 5213, 'Flatbush Misdemeanors S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uC0JTafda92bK3UBlIf6bYaSxSq.jpg'),
(76204, 5213, 'Flatbush Misdemeanors S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Y2bC0sL66Atf2iB8OqYPBeziAG.jpg'),
(76205, 5214, 'Flatbush Misdemeanors S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198249.mp4', 'http://timg.bdta.pro/images/e4c9748e25b1d5e7333299dbc51988d4.jpg'),
(76206, 5214, 'Flatbush Misdemeanors S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198250.mp4', 'http://timg.bdta.pro/images/039c6d26e10a9c181d812ff0f3f4f7b8.jpg'),
(76207, 5214, 'Flatbush Misdemeanors S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198251.mp4', 'http://timg.bdta.pro/images/6fff08bb5d72069bd9f02d6278fd9338.jpg'),
(76208, 5214, 'Flatbush Misdemeanors S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198252.mp4', 'http://timg.bdta.pro/images/065d0373ac18674d348cd33510cf59b2.jpg'),
(76209, 5214, 'Flatbush Misdemeanors S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198253.mp4', 'http://timg.bdta.pro/images/388c4c922d234a721396d008ce7e8e9f.jpg'),
(76210, 5214, 'Flatbush Misdemeanors S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198254.mp4', 'http://timg.bdta.pro/images/b18fd2910d14550f5317494637116cdd.jpg'),
(76211, 5214, 'Flatbush Misdemeanors S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198255.mp4', 'http://timg.bdta.pro/images/720f49e264525d04c374071ada0255a1.jpg'),
(76212, 5214, 'Flatbush Misdemeanors S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198256.mp4', 'http://timg.bdta.pro/images/b652613506c7f167b30968a3c4c74c79.jpg'),
(76213, 5214, 'Flatbush Misdemeanors S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198257.mp4', 'http://timg.bdta.pro/images/8c4abec6ff8c55fa744feb31d7b0157f.jpg'),
(76214, 5214, 'Flatbush Misdemeanors S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198258.mp4', 'http://timg.bdta.pro/images/4f3e90ebf43edd8ca834d7ba5fed6cd9.jpg'),
(76215, 5215, 'I\'m Dying Up Here S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/asDev6zqr7kok1ZP4UFshw0tJAY.jpg'),
(76216, 5215, 'I\'m Dying Up Here S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/enVVcgRNFOmQrdTOicpR0SAxEvx.jpg'),
(76217, 5215, 'I\'m Dying Up Here S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7S7IMyrBPQG6WdYUdftrh2qgxZi.jpg'),
(76218, 5215, 'I\'m Dying Up Here S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/twJNLGCJItdBCsIMjGkCpbhGi4J.jpg'),
(76219, 5215, 'I\'m Dying Up Here S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a5ejNyLFOfPS449fWGt7RhMoNq5.jpg'),
(76220, 5215, 'I\'m Dying Up Here S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wHEyaaysncbpf1mqyFXtmJDb5Tb.jpg'),
(76221, 5215, 'I\'m Dying Up Here S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dijA5RZE8ev0WbQZz8LXqhpUmZc.jpg'),
(76222, 5215, 'I\'m Dying Up Here S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oOGOz9SaRti6nvI4v4VIEkBjCEJ.jpg'),
(76223, 5215, 'I\'m Dying Up Here S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oOGOz9SaRti6nvI4v4VIEkBjCEJ.jpg'),
(76224, 5215, 'I\'m Dying Up Here S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oOGOz9SaRti6nvI4v4VIEkBjCEJ.jpg'),
(76225, 5216, 'I\'m Dying Up Here S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o18Z7M0wfbfVHm4Bi7UeNugWdWl.jpg'),
(76226, 5216, 'I\'m Dying Up Here S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sQJrD3P01LN0WbJ8DIcpy1Deqjs.jpg'),
(76227, 5216, 'I\'m Dying Up Here S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ypT0hXmM40DyRZwHEGmQj4ytNH.jpg'),
(76228, 5216, 'I\'m Dying Up Here S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ebb8pwlznWwnXao7yXlQzFpV9YU.jpg'),
(76229, 5216, 'I\'m Dying Up Here S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4G3A33isIJCpczmiZhdZdGIUx4Z.jpg'),
(76230, 5216, 'I\'m Dying Up Here S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkH8rigoWxb0qlj0ZGHgUEC7vJX.jpg'),
(76231, 5216, 'I\'m Dying Up Here S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5S2yPfexEp38gNw779XJ6tVeNUC.jpg'),
(76232, 5216, 'I\'m Dying Up Here S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oOGOz9SaRti6nvI4v4VIEkBjCEJ.jpg'),
(76233, 5216, 'I\'m Dying Up Here S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oOGOz9SaRti6nvI4v4VIEkBjCEJ.jpg'),
(76234, 5216, 'I\'m Dying Up Here S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oOGOz9SaRti6nvI4v4VIEkBjCEJ.jpg'),
(76235, 5217, 'Nosso Eterno Verão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/urH1DCGQYaYJm8LpUOlGzIJSX4K.jpg'),
(76236, 5217, 'Nosso Eterno Verão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNGkxWLR9ufYcVuMbILr9NJdPD5.jpg'),
(76237, 5217, 'Nosso Eterno Verão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vs4CTZ1IV6DokGAoA0EVLlFX60e.jpg'),
(76238, 5217, 'Nosso Eterno Verão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1PVBsg6tk82wdNAoQYS5ktulcbx.jpg'),
(76239, 5217, 'Nosso Eterno Verão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uk5VFY1kdZ8ga7BPzbVKAypsb7f.jpg'),
(76240, 5217, 'Nosso Eterno Verão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6DO4peboEdTNwmYH2xtkdSrXwiG.jpg'),
(76241, 5217, 'Nosso Eterno Verão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172152.mp4', 'http://timg.bdta.pro/images/fdd4b65f44982d515a92ce282b4f4d10.jpg'),
(76242, 5217, 'Nosso Eterno Verão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172153.mp4', 'http://timg.bdta.pro/images/f3e36b8539d81b733432c79e084f5791.jpg'),
(76243, 5217, 'Nosso Eterno Verão S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172154.mp4', 'http://timg.bdta.pro/images/dab26811a1374384e4b34cc4ab84f74b.jpg'),
(76244, 5217, 'Nosso Eterno Verão S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172155.mp4', 'http://timg.bdta.pro/images/63f6051356a497f9b292c613af35c802.jpg'),
(76245, 5217, 'Nosso Eterno Verão S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172156.mp4', 'http://timg.bdta.pro/images/3a6cb39c439ae0f3fb1b7ac39340b8ee.jpg'),
(76246, 5217, 'Nosso Eterno Verão S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172157.mp4', 'http://timg.bdta.pro/images/51982b11544ddbdbd19e566a02577c9d.jpg'),
(76247, 5217, 'Nosso Eterno Verão S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172158.mp4', 'http://timg.bdta.pro/images/a733bfda4b6cc796a10ef3aeabf2860c.jpg'),
(76248, 5217, 'Nosso Eterno Verão S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172159.mp4', 'http://timg.bdta.pro/images/5c281fff5f091142d3dca72ef569decb.jpg'),
(76249, 5217, 'Nosso Eterno Verão S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/172160.mp4', 'http://timg.bdta.pro/images/1e4df4f6e2ec240d0587ee292e70e6c9.jpg'),
(76250, 5217, 'Nosso Eterno Verão S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/172161.mp4', 'http://timg.bdta.pro/images/cdca5a1e0e0be4a91a146bb40aa6609e.jpg'),
(76251, 5218, 'O Jogo das Chaves [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cv98XpDQcMyqNyxD4k3NiJhWRla.jpg'),
(76252, 5218, 'O Jogo das Chaves [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ctSnf7VxjsTo5N1fgMETrWjrzSV.jpg'),
(76253, 5218, 'O Jogo das Chaves [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJ9s9M2l7gib30t4nnW0P7GAD9b.jpg'),
(76254, 5218, 'O Jogo das Chaves [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gR0fxvkwBW1umMpjACDSTTzmOmA.jpg'),
(76255, 5218, 'O Jogo das Chaves [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ap2k7wbdDlQOFzkXlAfTZcFlFYU.jpg'),
(76256, 5218, 'O Jogo das Chaves [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xnV8lTYj1aeAwAxvGjfhzj87J5M.jpg'),
(76257, 5218, 'O Jogo das Chaves [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lQjrz53n0GuiQ7I7HZkkAV2Vgii.jpg'),
(76258, 5218, 'O Jogo das Chaves [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8E9Tww1mKknUo8CORp9f8YscRK.jpg'),
(76259, 5218, 'O Jogo das Chaves [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/946hoJnaNZbCeyicY5DsHCA3yUB.jpg'),
(76260, 5218, 'O Jogo das Chaves [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cA4se2VR5hqFAjaNgdUjpwV1PHF.jpg'),
(76261, 5219, 'O Jogo das Chaves [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uYWnFW9OEY8j56eNfUJG5ySM6ZB.jpg'),
(76262, 5219, 'O Jogo das Chaves [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fRXyPpzhq1Ua3jx0MgXAWnn0aNu.jpg'),
(76263, 5219, 'O Jogo das Chaves [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fLVU6fYiNLwYmDn3r1sGic2pyFD.jpg'),
(76264, 5219, 'O Jogo das Chaves [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oDevT6Y2PrFSdwIbJUqUSWa4NC8.jpg'),
(76265, 5219, 'O Jogo das Chaves [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4cc77OMOyOSk03SmRZMIgkAl3R4.jpg'),
(76266, 5219, 'O Jogo das Chaves [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/smpcAAI8Gkw0yN8T0yOdhlKwy0n.jpg'),
(76267, 5219, 'O Jogo das Chaves [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sB5eIvDS5viFa9BLNtiHUIdqyeh.jpg'),
(76268, 5219, 'O Jogo das Chaves [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kNoF0J5rRKy6V7YUgRa7CJpqjts.jpg'),
(76269, 5220, 'O Jogo das Chaves [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/464074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cMy9qphoOLJjYJJJQBBul0d94q.jpg'),
(76270, 5220, 'O Jogo das Chaves [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/464075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cMy9qphoOLJjYJJJQBBul0d94q.jpg'),
(76271, 5220, 'O Jogo das Chaves [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/464076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cMy9qphoOLJjYJJJQBBul0d94q.jpg'),
(76272, 5220, 'O Jogo das Chaves [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/464077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cMy9qphoOLJjYJJJQBBul0d94q.jpg'),
(76273, 5220, 'O Jogo das Chaves [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/464078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cMy9qphoOLJjYJJJQBBul0d94q.jpg'),
(76274, 5220, 'O Jogo das Chaves [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/464079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cMy9qphoOLJjYJJJQBBul0d94q.jpg'),
(76275, 5221, 'O Túnel Do Tempo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ndYRFk8jCyWStTv3A3Z9IcB8dS.jpg'),
(76276, 5221, 'O Túnel Do Tempo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yAgqkAwf99TbBUljS53jPVV6s5B.jpg'),
(76277, 5221, 'O Túnel Do Tempo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qMdkQTPmMjjiih85U2BOM80F8nI.jpg'),
(76278, 5221, 'O Túnel Do Tempo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWnFDAZH45HjSC7uZyfaQy1CSKx.jpg'),
(76279, 5221, 'O Túnel Do Tempo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4IUej5zci8V9y4JfWxR8ZpQenVZ.jpg'),
(76280, 5221, 'O Túnel Do Tempo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWzJzkIztkWEObWnOl33d3iJH2v.jpg'),
(76281, 5221, 'O Túnel Do Tempo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6vpWIjysTTYRsTDi0pqYkLm8EJw.jpg'),
(76282, 5221, 'O Túnel Do Tempo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7QrdJFwoHlM4CWnzS3btzV8Cdij.jpg'),
(76283, 5221, 'O Túnel Do Tempo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qNPldDE61Lx1MM4aQeGmiMGjn6s.jpg'),
(76284, 5221, 'O Túnel Do Tempo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBlGOTWIiuLqPjFDcqvynRosyda.jpg'),
(76285, 5221, 'O Túnel Do Tempo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8zh8jYDRt1RbqkHiO0xMm78ECTx.jpg'),
(76286, 5221, 'O Túnel Do Tempo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dvwt8np5L1Z1MmlsD7xOyByMPV.jpg'),
(76287, 5221, 'O Túnel Do Tempo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5Pd30zVmwWIvVsBjZlzr2izmx5.jpg'),
(76288, 5221, 'O Túnel Do Tempo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pdLbUR9iaMK4HopcA3dcCNROSy.jpg'),
(76289, 5221, 'O Túnel Do Tempo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6jJxngPM7A5xS051ddBvcNDsTzq.jpg'),
(76290, 5221, 'O Túnel Do Tempo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/19IuNc8Rspgwp75LQfuUxJw942O.jpg'),
(76291, 5221, 'O Túnel Do Tempo S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5K7ErtH1PICz2fsXhpJR6wEvwbr.jpg'),
(76292, 5221, 'O Túnel Do Tempo S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5N309642zyA4bxf1mXWQ36CbCZr.jpg'),
(76293, 5221, 'O Túnel Do Tempo S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/171436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9xvnTohfIHJbo2ThUFyFKgHriYJ.jpg'),
(76294, 5221, 'O Túnel Do Tempo S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/171437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOlMoKzSwSxkIGRetBQ8xkFC5wh.jpg'),
(76295, 5221, 'O Túnel Do Tempo S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/171438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tttleyJpWRBylKqgBMKC7cJuoaJ.jpg'),
(76296, 5221, 'O Túnel Do Tempo S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/171439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pRbTYfU9CWQvIF2O7AUVcQQiOXH.jpg'),
(76297, 5221, 'O Túnel Do Tempo S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/171440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1KHB4p5bDqNRuD0wiSfTwtmiMeh.jpg'),
(76298, 5221, 'O Túnel Do Tempo S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/171441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xEcDIWSyZaMhICANgMn4g66QokP.jpg'),
(76299, 5221, 'O Túnel Do Tempo S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/171442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7UUp0cb8aYCye0A7vbINmULNAdp.jpg'),
(76300, 5221, 'O Túnel Do Tempo S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/171443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jvH3S3ZB27L1vSVwy9YWCTPrPlL.jpg'),
(76301, 5221, 'O Túnel Do Tempo S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/171444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/MHoHxAwYGGXjznQTsbS32mztYN.jpg'),
(76302, 5221, 'O Túnel Do Tempo S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/171445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/roO0OcM3PLbXH7AaX28vYg1Fhiw.jpg'),
(76303, 5221, 'O Túnel Do Tempo S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/171446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zOVJvNzSL7JKHOIHx82CyRRYVgc.jpg'),
(76304, 5221, 'O Túnel Do Tempo S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/171447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/imKl5qKvdpulNbzXuLEISGTPaV2.jpg'),
(76305, 5222, 'Pacificador S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/538eLa2f3FoSwNNzHpHi0J1ZXl6.jpg'),
(76306, 5222, 'Pacificador S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dUAS7fZqjdPcfYnLnxCm40U0LUa.jpg'),
(76307, 5222, 'Pacificador S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyZXot4qqZEOCOOB3Vrv5F4KXRR.jpg'),
(76308, 5222, 'Pacificador S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172141.mp4', 'http://timg.bdta.pro/images/5c9aca7cef14db56aa92147fe849ec39.jpg'),
(76309, 5222, 'Pacificador S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172142.mp4', 'http://timg.bdta.pro/images/0a9d54292676941760d2888ffe869019.jpg'),
(76310, 5222, 'Pacificador S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172143.mp4', 'http://timg.bdta.pro/images/2f8331338edefa2344b81c0420777755.jpg'),
(76311, 5222, 'Pacificador S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172144.mp4', 'http://timg.bdta.pro/images/3ae58a18887620357db33bee5a0e896a.jpg'),
(76312, 5222, 'Pacificador S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172145.mp4', 'http://timg.bdta.pro/images/cd0276531bfdbbce853fbb10e8080b5d.jpg'),
(76313, 5223, 'Pacificador S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/881194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lBw4rwfoLsHAs5pTISgIOFnRk2c.jpg'),
(76314, 5223, 'Pacificador S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/881308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lBw4rwfoLsHAs5pTISgIOFnRk2c.jpg'),
(76315, 5223, 'Pacificador S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/883026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lBw4rwfoLsHAs5pTISgIOFnRk2c.jpg'),
(76316, 5223, 'Pacificador S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/883785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lBw4rwfoLsHAs5pTISgIOFnRk2c.jpg'),
(76317, 5223, 'Pacificador S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/885159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lBw4rwfoLsHAs5pTISgIOFnRk2c.jpg'),
(76318, 5223, 'Pacificador S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/886073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lBw4rwfoLsHAs5pTISgIOFnRk2c.jpg'),
(76319, 5223, 'Pacificador S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/887556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lBw4rwfoLsHAs5pTISgIOFnRk2c.jpg'),
(76320, 5223, 'Pacificador S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/888149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lBw4rwfoLsHAs5pTISgIOFnRk2c.jpg'),
(76321, 5224, 'Remy & Boo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/170754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76322, 5224, 'Remy & Boo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/170755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76323, 5224, 'Remy & Boo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/170756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76324, 5224, 'Remy & Boo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/170757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76325, 5224, 'Remy & Boo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/170758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76326, 5224, 'Remy & Boo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/170759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76327, 5224, 'Remy & Boo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/170760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76328, 5224, 'Remy & Boo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/170761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76329, 5224, 'Remy & Boo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/170762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76330, 5224, 'Remy & Boo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/170763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76331, 5224, 'Remy & Boo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/170764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76332, 5224, 'Remy & Boo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/170765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76333, 5224, 'Remy & Boo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/170766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76334, 5224, 'Remy & Boo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/170767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76335, 5224, 'Remy & Boo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/170768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76336, 5224, 'Remy & Boo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/170769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76337, 5224, 'Remy & Boo S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/170770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76338, 5224, 'Remy & Boo S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/170771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76339, 5224, 'Remy & Boo S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/170772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76340, 5224, 'Remy & Boo S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/170773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76341, 5224, 'Remy & Boo S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/170774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76342, 5224, 'Remy & Boo S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/170775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76343, 5224, 'Remy & Boo S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/170776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76344, 5224, 'Remy & Boo S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/170777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76345, 5224, 'Remy & Boo S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/170778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76346, 5224, 'Remy & Boo S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/170779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76347, 5224, 'Remy & Boo S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/170780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76348, 5224, 'Remy & Boo S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/170781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76349, 5224, 'Remy & Boo S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/170782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76350, 5224, 'Remy & Boo S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/170783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76351, 5224, 'Remy & Boo S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/170784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76352, 5224, 'Remy & Boo S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/170785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76353, 5224, 'Remy & Boo S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/170786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76354, 5224, 'Remy & Boo S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/170787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76355, 5224, 'Remy & Boo S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/170788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76356, 5224, 'Remy & Boo S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/170789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76357, 5224, 'Remy & Boo S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/170790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76358, 5224, 'Remy & Boo S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/170791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76359, 5224, 'Remy & Boo S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/170792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76360, 5224, 'Remy & Boo S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/170793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76361, 5224, 'Remy & Boo S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/170794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76362, 5224, 'Remy & Boo S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/170795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76363, 5224, 'Remy & Boo S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/170796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76364, 5224, 'Remy & Boo S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/170797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76365, 5224, 'Remy & Boo S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/170798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76366, 5224, 'Remy & Boo S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/170799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76367, 5224, 'Remy & Boo S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/170800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76368, 5224, 'Remy & Boo S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/170801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76369, 5224, 'Remy & Boo S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/170802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76370, 5224, 'Remy & Boo S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/170803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76371, 5224, 'Remy & Boo S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/170804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76372, 5224, 'Remy & Boo S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/170805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3fypRYITEs6t3aMcrFxwVsEUXrQ.jpg'),
(76373, 5225, 'Sex and the City S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cFTzuDt8IFnK14z9cTenYtHIWO2.jpg'),
(76374, 5225, 'Sex and the City S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bDU7wSUEbHF8vdG1x296qhaUimA.jpg'),
(76375, 5225, 'Sex and the City S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cReVny9XxK0gUvU2xwJGFlyipnT.jpg'),
(76376, 5225, 'Sex and the City S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wkGCJOONMRjXvNSlD0jo6ESXJRC.jpg'),
(76377, 5225, 'Sex and the City S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rYmCWKWE2XlsBsgbRbfbwcZZzoP.jpg'),
(76378, 5225, 'Sex and the City S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/toLRwhHQGLrbhcpShQbvTpn1pxO.jpg'),
(76379, 5225, 'Sex and the City S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4d0tN36QQajpJ3b3klt0TyW7IbQ.jpg'),
(76380, 5225, 'Sex and the City S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xW15ZJtlmX6SJLTsWY9GnjOWdlc.jpg'),
(76381, 5225, 'Sex and the City S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qIGpn2ORzKR92Z9MdxrlfpSgKcT.jpg'),
(76382, 5225, 'Sex and the City S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tO8OMdTMCSVAOh4HqZZ4H928qpn.jpg'),
(76383, 5225, 'Sex and the City S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jUmxPnRkmPJo1Dkz7kZlD09IcZX.jpg'),
(76384, 5225, 'Sex and the City S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eXcQe2w2nJXKJfZByDwNnoF8KEW.jpg'),
(76385, 5226, 'Sex and the City S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zSlOolmLcoNoL5Mh6j8wDKBIJl8.jpg'),
(76386, 5226, 'Sex and the City S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5EUYZKqMjUtF7CYfzvCt0JICnmD.jpg'),
(76387, 5226, 'Sex and the City S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/irTGNcUvMpG72IC9D5rmGYX3eyN.jpg'),
(76388, 5226, 'Sex and the City S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wx7qtg3P26im39mkI16auftLsqt.jpg'),
(76389, 5226, 'Sex and the City S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8sasfD4MrQxWv5S9ir6Xk7knqg6.jpg'),
(76390, 5226, 'Sex and the City S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkZMT3tUPG0a9pIuAsL1k0VcAT4.jpg'),
(76391, 5226, 'Sex and the City S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lnVCXRsIS9QGZKsmqQEDwGRXn7P.jpg'),
(76392, 5226, 'Sex and the City S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gLdb3SjZz6iMgUtehwn4W4gfyaj.jpg'),
(76393, 5226, 'Sex and the City S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1oqfxn5JJJnl5kReuGC0Drw1iR.jpg'),
(76394, 5226, 'Sex and the City S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mfRKXc98A4MfR64XPsuxnqRho9h.jpg'),
(76395, 5226, 'Sex and the City S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/535Zw5Lviezz2rT8hDnYtRkHhJ4.jpg'),
(76396, 5226, 'Sex and the City S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s4ehuTUVG8yUXQ6uOvyXaiisPd4.jpg'),
(76397, 5226, 'Sex and the City S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2X3nCMx3Ybbh99RbvmwXkaja87.jpg'),
(76398, 5226, 'Sex and the City S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7Ia72y3QQnTqdjoJtQ1uavZg3c.jpg'),
(76399, 5226, 'Sex and the City S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tyFG1A2bssXlZVVcJniNgoL2I4A.jpg'),
(76400, 5226, 'Sex and the City S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cymzjyz2sf9K7qf0EJGeqDWhjgD.jpg'),
(76401, 5226, 'Sex and the City S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBJuY3lLdFOboTKkTq7tmmvJUpG.jpg'),
(76402, 5226, 'Sex and the City S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8xU1UT6uBpmpMYJFM1riwZifCVS.jpg'),
(76403, 5227, 'Sex and the City S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bw4zKMmXScOm1lkwdCWq8uQgpzk.jpg'),
(76404, 5227, 'Sex and the City S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4GEpLmDVPTKpcDypYsjFwxXV9tR.jpg'),
(76405, 5227, 'Sex and the City S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d430ntqFpo2opkPMfOjZRfuCC75.jpg'),
(76406, 5227, 'Sex and the City S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vjA4qRbpuoMCUDDJSmb35H40f9Y.jpg'),
(76407, 5227, 'Sex and the City S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mXCCM97SG3hU3pyuhQ79Qm3ZJb8.jpg'),
(76408, 5227, 'Sex and the City S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uQZxYuTWjWsPsCjq9LnW6hbFSa8.jpg'),
(76409, 5227, 'Sex and the City S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eeiC6EKeBtvSK2WWlwRudD5qMha.jpg'),
(76410, 5227, 'Sex and the City S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gOiUIICuagxhIZ4q6lDfaRjBqND.jpg'),
(76411, 5227, 'Sex and the City S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVlLkH2xGtGadOmUtgZt6hmQns5.jpg'),
(76412, 5227, 'Sex and the City S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7KU1bWYazd8x68jUmcn0A131Zeo.jpg'),
(76413, 5227, 'Sex and the City S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zEJyhOBLp471zECPDAKYf4lzy7u.jpg'),
(76414, 5227, 'Sex and the City S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/56ot2iqmybjeHHA7oj2m8kpPRPd.jpg'),
(76415, 5227, 'Sex and the City S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s46bzs2S210U2EG2bTAH6vk58Gu.jpg'),
(76416, 5227, 'Sex and the City S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ruJln3sVcE22Kz33lxIVjpZnj8p.jpg'),
(76417, 5227, 'Sex and the City S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ywE9RVNNbLavZLZbwbregav5JCj.jpg'),
(76418, 5227, 'Sex and the City S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nrVCol9CYfkvZxvUm34lqXpKZn7.jpg'),
(76419, 5227, 'Sex and the City S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nkJkd5HTd8S3pf3dWLpOetnvz8j.jpg'),
(76420, 5227, 'Sex and the City S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6zDVeRRuBCLXwklYYZQ2QYO7oPm.jpg'),
(76421, 5228, 'Sex and the City S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mM6YQqJSwjMqBtz87mTXTCaWPOG.jpg'),
(76422, 5228, 'Sex and the City S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLMz1l45tGs3kc0iKgKRy38XSAj.jpg'),
(76423, 5228, 'Sex and the City S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kwuoEpiPl7SvutCzujf3qyacl8O.jpg'),
(76424, 5228, 'Sex and the City S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sNuX5DJkvfHdnlUOH50xFTuRZcN.jpg'),
(76425, 5228, 'Sex and the City S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ptUcnHzNos6cTFLUwo86DwBQSM.jpg'),
(76426, 5228, 'Sex and the City S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3R07SEFLPo2SNmVAuQOkV1erbCK.jpg'),
(76427, 5228, 'Sex and the City S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PoGbVabzZ0DwnpGll0bffUPkT0.jpg'),
(76428, 5228, 'Sex and the City S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cTRyv5zgVx14h6yVF1kVTwQYK6N.jpg'),
(76429, 5228, 'Sex and the City S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i54Fn3pShJH8fwlsd0Hk0DPKaYy.jpg'),
(76430, 5228, 'Sex and the City S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gPXLZhNp8bI3qslyJGmQHuJqeSO.jpg'),
(76431, 5228, 'Sex and the City S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rLtIecddX8Ok16NFoJyPerZK93I.jpg'),
(76432, 5228, 'Sex and the City S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5qWw6iPp3SkmdxCh9sU8kUyQhFe.jpg'),
(76433, 5228, 'Sex and the City S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyOrblKruDEJnJHwL5uryTaLQWn.jpg'),
(76434, 5228, 'Sex and the City S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m3ohlkamrQv13nWLAKpvHI7BFej.jpg'),
(76435, 5228, 'Sex and the City S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kiWN6mznY0NmIrYX73YtAfiNX2R.jpg'),
(76436, 5228, 'Sex and the City S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6RZZGv22m45a1bI0NmcE5Y8ZGWa.jpg'),
(76437, 5228, 'Sex and the City S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iaOb0T9rjLX1HAk8ysj3Vfj4Tty.jpg'),
(76438, 5228, 'Sex and the City S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ipsi1aprS08v2eK5jy3yG8iukeu.jpg'),
(76439, 5229, 'Sex and the City S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tf9TtZD6bN7RxGX0Bf25BhFaOPO.jpg'),
(76440, 5229, 'Sex and the City S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nSNqG1Vm75CqWnHo6Jcr1Z1rhD2.jpg'),
(76441, 5229, 'Sex and the City S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9zL8YMymIK1g5S2duEEAZVGl9tz.jpg'),
(76442, 5229, 'Sex and the City S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l950PDRI41DH3j332kR36ujpGAt.jpg'),
(76443, 5229, 'Sex and the City S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/16eODP3iXLR7MREgrZvUIRFNOnB.jpg'),
(76444, 5229, 'Sex and the City S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8GhVOUrIMuGIxsoRnxA34J5H2Qh.jpg'),
(76445, 5229, 'Sex and the City S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tXJBq5R6BI684c11XWA4vIFj3rn.jpg'),
(76446, 5229, 'Sex and the City S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xEIRJRsUaVpp2TCHgwx1ypGsDmT.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(76447, 5230, 'Sex and the City S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2s5HYaAM8Kp52nCHzNchsM2PACj.jpg'),
(76448, 5230, 'Sex and the City S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhAgiuws5hbDyx4R9hf6Q1ainu7.jpg'),
(76449, 5230, 'Sex and the City S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ioZQM3BP9xjgkvES7h1dHC3Ya88.jpg'),
(76450, 5230, 'Sex and the City S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cGmiC27811ZDs4Vc6ZB3GMr3unm.jpg'),
(76451, 5230, 'Sex and the City S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ppymbStuWYES8WunD6YjXn5GAa9.jpg'),
(76452, 5230, 'Sex and the City S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bhzy0vcd02uDuQ4d6igkaj2cH8K.jpg'),
(76453, 5230, 'Sex and the City S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mNnWyir3vdBYlZQLRfddIiZFEJd.jpg'),
(76454, 5230, 'Sex and the City S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mAeJlAkh8xpSoxp39nrUFPcio3R.jpg'),
(76455, 5230, 'Sex and the City S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8oRGWk02rSqhrnbETnd7SqNsSoB.jpg'),
(76456, 5230, 'Sex and the City S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zSDndynidosmmXTgOpEqUeJtCZF.jpg'),
(76457, 5230, 'Sex and the City S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mnIK4UVS4MG9WRF5L6nNLTl4Fhp.jpg'),
(76458, 5230, 'Sex and the City S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2iwS0qXPmFYT5uAyylEHIXVICc.jpg'),
(76459, 5230, 'Sex and the City S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h2j8gDd4QE0CTJROH3ikqj3qrKQ.jpg'),
(76460, 5230, 'Sex and the City S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wU0lH5yum0vi7YYQH9tIOS8YPsT.jpg'),
(76461, 5230, 'Sex and the City S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i3vlhclUagKzyjGzcswhfAYk0jI.jpg'),
(76462, 5230, 'Sex and the City S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Fdp0CWYeWohQzfrdQ3peMZJMgA.jpg'),
(76463, 5230, 'Sex and the City S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2lsZht4dzzffVO1j2jfCBunRBoN.jpg'),
(76464, 5230, 'Sex and the City S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mRobPg4IVMOnuJOqtRPXufbAyb0.jpg'),
(76465, 5230, 'Sex and the City S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/171416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mM6iCJ9urzbEKClSJcx0Az1VMe4.jpg'),
(76466, 5230, 'Sex and the City S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/171417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q2k57Mi8sjKcd5BvQwRNsVy5pwy.jpg'),
(76467, 5231, 'She-Ra e as Princesas do Poder S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/anKxoD4hIkFM1zZI7X2NnBQgDgO.jpg'),
(76468, 5231, 'She-Ra e as Princesas do Poder S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dxlfC6bAZvwvniitxVE3hfzwd3y.jpg'),
(76469, 5231, 'She-Ra e as Princesas do Poder S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/72QA8asDVpFjxJGgvrFp89fC1Uu.jpg'),
(76470, 5231, 'She-Ra e as Princesas do Poder S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tyKsVk4X0gmURgjy7UnZqTQ6VqN.jpg'),
(76471, 5231, 'She-Ra e as Princesas do Poder S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ujUDvaEanw1SEsKVmGZgF5lvn9P.jpg'),
(76472, 5231, 'She-Ra e as Princesas do Poder S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5qzWry5Pmmv2lAjKiNwPWWB14Zw.jpg'),
(76473, 5231, 'She-Ra e as Princesas do Poder S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j9wd60RSsLRTBZScuuClh0Nd8HJ.jpg'),
(76474, 5231, 'She-Ra e as Princesas do Poder S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmiBLNy8mIjVlrhp9oCbQbtnNw3.jpg'),
(76475, 5231, 'She-Ra e as Princesas do Poder S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lqT6a3rjTzmfr8kXUE1OpwXvWtk.jpg'),
(76476, 5231, 'She-Ra e as Princesas do Poder S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yVrc7227EIEiWzxNlT8c3loZjmu.jpg'),
(76477, 5231, 'She-Ra e as Princesas do Poder S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dbs6SLVE7dtTkbCaAQ9uuuHdGS1.jpg'),
(76478, 5231, 'She-Ra e as Princesas do Poder S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rRhWcj9CUsjrLsbKSri6jr8SBsV.jpg'),
(76479, 5231, 'She-Ra e as Princesas do Poder S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AiALJFzdnE79XC7giLDpTgzisAY.jpg'),
(76480, 5232, 'She-Ra e as Princesas do Poder S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pXl01Egh6wG5IU2J8FqmKofN3HV.jpg'),
(76481, 5232, 'She-Ra e as Princesas do Poder S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wwc6JL4tOFWNd1AoZe0TtAsMW2j.jpg'),
(76482, 5232, 'She-Ra e as Princesas do Poder S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kFiXyEIpYHczZr6JJW6Kc4YXJ2e.jpg'),
(76483, 5232, 'She-Ra e as Princesas do Poder S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jKrZSy463oMtDKjqCg6WhZTI2an.jpg'),
(76484, 5232, 'She-Ra e as Princesas do Poder S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2aBWTkDRKWzVxMlPglo4v0Gubch.jpg'),
(76485, 5232, 'She-Ra e as Princesas do Poder S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m3QB73sHZqI3WM5jgPn8UUm2k6x.jpg'),
(76486, 5232, 'She-Ra e as Princesas do Poder S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1awtZyDR3dG7mIbkP97agegwNxW.jpg'),
(76487, 5233, 'She-Ra e as Princesas do Poder S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ojM6UrpBwAQxczv85znlmk8PdXA.jpg'),
(76488, 5233, 'She-Ra e as Princesas do Poder S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hBZHg3zmoJNL6wbRUVowoKfHlJr.jpg'),
(76489, 5233, 'She-Ra e as Princesas do Poder S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/obR6dyYqJI4zN4PVdZf1NuOyx8i.jpg'),
(76490, 5233, 'She-Ra e as Princesas do Poder S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1aD6RxYG5VRGnZhxVFwMhDCOAgx.jpg'),
(76491, 5233, 'She-Ra e as Princesas do Poder S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tbv5ysI8cS4panumaiMXAsYh1mJ.jpg'),
(76492, 5233, 'She-Ra e as Princesas do Poder S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8CsqJurRItO6hDeZ7rAY0k02ykW.jpg'),
(76493, 5234, 'She-Ra e as Princesas do Poder S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xxPk7NBvqZfDxpZxSHe0o2orvc4.jpg'),
(76494, 5234, 'She-Ra e as Princesas do Poder S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/axHWeG362wPmrMfiIT2iSuLrpSz.jpg'),
(76495, 5234, 'She-Ra e as Princesas do Poder S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8JD1hyZN0JzTOwJYJ99IMfINewK.jpg'),
(76496, 5234, 'She-Ra e as Princesas do Poder S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yd4k0klPdJPa02MhSHIkSxg1kjT.jpg'),
(76497, 5234, 'She-Ra e as Princesas do Poder S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zesfaGXYCy28RroDNOJqIHkcZFr.jpg'),
(76498, 5234, 'She-Ra e as Princesas do Poder S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xmbzAs5jZLQTYLrZGOpTr5IDoOR.jpg'),
(76499, 5234, 'She-Ra e as Princesas do Poder S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mMUwWR5zW3InN4HD5maNEStL1o4.jpg'),
(76500, 5234, 'She-Ra e as Princesas do Poder S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tgGOE2EhkEnI8JktmQKcJT36BzJ.jpg'),
(76501, 5234, 'She-Ra e as Princesas do Poder S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qOwyvSDrlB3cl7Z8Ff4EAJRahZF.jpg'),
(76502, 5234, 'She-Ra e as Princesas do Poder S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xMWnwD2j0jVWfVbUHMf2HM8maG9.jpg'),
(76503, 5234, 'She-Ra e as Princesas do Poder S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLPYUinHax684ngwkSsl3B4xXW8.jpg'),
(76504, 5234, 'She-Ra e as Princesas do Poder S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ZLylS3WhVeXfNuHubNNDN2dQSj.jpg'),
(76505, 5234, 'She-Ra e as Princesas do Poder S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Rw9A3wSNtkhsEyznDysRDxK6fC.jpg'),
(76506, 5235, 'She-Ra e as Princesas do Poder S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/84bWkAFwKJEDTqDjG6iLdtFbeE.jpg'),
(76507, 5235, 'She-Ra e as Princesas do Poder S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zh7juCEUpoAr4YX8SvQMOHego86.jpg'),
(76508, 5235, 'She-Ra e as Princesas do Poder S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y9WsrwcuGzckUh0cmclScEsinUU.jpg'),
(76509, 5235, 'She-Ra e as Princesas do Poder S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfV74hB31OdSl174PXKdmTEGyi1.jpg'),
(76510, 5235, 'She-Ra e as Princesas do Poder S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8uuK5wWsUi2az5tRok7ALCHGqv.jpg'),
(76511, 5235, 'She-Ra e as Princesas do Poder S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5bRCPMPO3Y5aueIIXKCjVjNx2Uk.jpg'),
(76512, 5235, 'She-Ra e as Princesas do Poder S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vdOuTYNKPXZpchtDrv9oBHvWxBn.jpg'),
(76513, 5235, 'She-Ra e as Princesas do Poder S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xwEv00JdeGDqaK2wQuA6IfEKbKs.jpg'),
(76514, 5235, 'She-Ra e as Princesas do Poder S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6lYBi07cU4wLCEqJvxcPrOuEqyW.jpg'),
(76515, 5235, 'She-Ra e as Princesas do Poder S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lKY1R14WfcmchMYDNWvOMMNWc9m.jpg'),
(76516, 5235, 'She-Ra e as Princesas do Poder S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/netQrvbvWBHuAG0shzefdgKAAQd.jpg'),
(76517, 5235, 'She-Ra e as Princesas do Poder S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iABGZgH55F9UD2zN7lJfWFqZyPk.jpg'),
(76518, 5235, 'She-Ra e as Princesas do Poder S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xik02U8DpQSm6iCNGTPLMEQ2qfC.jpg'),
(76519, 5236, 'The House S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171271.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/iZjMFSKCrleKolC1gYcz5Rs8bk1.jpg'),
(76520, 5237, 'The Republic of Sarah S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c2wK3rgLWG1aUJQLJamIr5B6GR3.jpg'),
(76521, 5237, 'The Republic of Sarah S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/67vk2NLOtW7MGZXHxyRwYvuWeCO.jpg'),
(76522, 5237, 'The Republic of Sarah S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9XEove3vcV8pTbUHYHHEvoFspbZ.jpg'),
(76523, 5237, 'The Republic of Sarah S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vLqmLpY6cZwY2ddkTzKlN4EoJBx.jpg'),
(76524, 5237, 'The Republic of Sarah S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fQtGdCNbZzV766lfKGaV3xQeWXY.jpg'),
(76525, 5237, 'The Republic of Sarah S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vCakc1WYLSMBb8UQShsrHHbCf4c.jpg'),
(76526, 5237, 'The Republic of Sarah S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rwA2Fnt2ZYihOYEtGXFOpj78vOY.jpg'),
(76527, 5237, 'The Republic of Sarah S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5lD2bgSCcMghMi4b4To0tU1i9a1.jpg'),
(76528, 5237, 'The Republic of Sarah S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1SnAkCNjwPfoLCAiEsg2mC2qAQ.jpg'),
(76529, 5237, 'The Republic of Sarah S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8sIJZ07NVf0nsXptwEKJVgxuSxq.jpg'),
(76530, 5237, 'The Republic of Sarah S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dQZvnXES6uUx3ef78zpiAmnZAFU.jpg'),
(76531, 5237, 'The Republic of Sarah S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jB11ssfU4vmBrBN92aXHcahXXoV.jpg'),
(76532, 5237, 'The Republic of Sarah S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6IOI7eiMvAnlDUy4T2mceUuplrn.jpg'),
(76533, 5238, 'Você Sobreviveria? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/31NoD0DdSH70X5RMPfDKj0KxThu.jpg'),
(76534, 5238, 'Você Sobreviveria? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/31NoD0DdSH70X5RMPfDKj0KxThu.jpg'),
(76535, 5238, 'Você Sobreviveria? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/31NoD0DdSH70X5RMPfDKj0KxThu.jpg'),
(76536, 5238, 'Você Sobreviveria? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/31NoD0DdSH70X5RMPfDKj0KxThu.jpg'),
(76537, 5238, 'Você Sobreviveria? S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/31NoD0DdSH70X5RMPfDKj0KxThu.jpg'),
(76538, 5238, 'Você Sobreviveria? S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/31NoD0DdSH70X5RMPfDKj0KxThu.jpg'),
(76539, 5238, 'Você Sobreviveria? S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/31NoD0DdSH70X5RMPfDKj0KxThu.jpg'),
(76540, 5238, 'Você Sobreviveria? S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/31NoD0DdSH70X5RMPfDKj0KxThu.jpg'),
(76541, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174106.mp4', 'http://timg.bdta.pro/images/09cdfb4c2a3d7d60ac0306637da48a70.jpg'),
(76542, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174107.mp4', 'http://timg.bdta.pro/images/5031e13176b914ee0f65510481eec25b.jpg'),
(76543, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174108.mp4', 'http://timg.bdta.pro/images/eb72f5549c78837fc221ea3db82caccf.jpg'),
(76544, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174109.mp4', 'http://timg.bdta.pro/images/cce2fc3128f472a6d52a13f48d50709c.jpg'),
(76545, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174110.mp4', 'http://timg.bdta.pro/images/a0c4f81635c28c3e5081e7e1d4e0859f.jpg'),
(76546, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174111.mp4', 'http://timg.bdta.pro/images/e09fc7b8248fb3106ef3583ac09cb5a0.jpg'),
(76547, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174112.mp4', 'http://timg.bdta.pro/images/ae6183f802972d7662fa6aec37003e97.jpg'),
(76548, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174113.mp4', 'http://timg.bdta.pro/images/539bc5aa1a9eb637bd9369388ba9281f.jpg'),
(76549, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174114.mp4', 'http://timg.bdta.pro/images/942c596298007f3604d531a6b8c168ce.jpg'),
(76550, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174115.mp4', 'http://timg.bdta.pro/images/49389a1935a6c092a133ca23eb67fb5a.jpg'),
(76551, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/174116.mp4', 'http://timg.bdta.pro/images/59c61cb909ca94ba2a69f68716e7eda2.jpg'),
(76552, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/174117.mp4', 'http://timg.bdta.pro/images/3bf4e7f797e654e1a37ef98ab076ee18.jpg'),
(76553, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/174118.mp4', 'http://timg.bdta.pro/images/3147575cef0b8bb29cc8751e9e44ee37.jpg'),
(76554, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/174119.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76555, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/174120.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76556, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/174121.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76557, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/174122.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76558, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/174123.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76559, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/174124.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76560, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/174125.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76561, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/174126.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76562, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/174127.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76563, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/174128.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76564, 5239, 'A Rocha Encantada: De Volta à Caverna S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/174129.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76565, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174130.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76566, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174131.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76567, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174132.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76568, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174133.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76569, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174134.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76570, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174135.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76571, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174136.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76572, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174137.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76573, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174138.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76574, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174139.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76575, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/174140.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76576, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/174141.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76577, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/174142.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76578, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/174143.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76579, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/174144.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76580, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/174145.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76581, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/174146.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76582, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/174147.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76583, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/174148.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76584, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/174149.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76585, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/174150.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76586, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/174151.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76587, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/174152.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76588, 5240, 'A Rocha Encantada: De Volta à Caverna S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/174153.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76589, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174154.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76590, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174155.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76591, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174156.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76592, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174157.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76593, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174158.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76594, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174159.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76595, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174160.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76596, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174161.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76597, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174162.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76598, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174163.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76599, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/174164.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76600, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/174165.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76601, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/174166.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76602, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/174167.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76603, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/174168.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76604, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/174169.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76605, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/174170.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76606, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/174171.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76607, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/174172.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76608, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/174173.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76609, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/174174.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76610, 5241, 'A Rocha Encantada: De Volta à Caverna S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/174175.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76611, 5242, 'A Rocha Encantada: De Volta à Caverna S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174176.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76612, 5242, 'A Rocha Encantada: De Volta à Caverna S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174177.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76613, 5242, 'A Rocha Encantada: De Volta à Caverna S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174178.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76614, 5242, 'A Rocha Encantada: De Volta à Caverna S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174179.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76615, 5242, 'A Rocha Encantada: De Volta à Caverna S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174180.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76616, 5242, 'A Rocha Encantada: De Volta à Caverna S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174181.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76617, 5242, 'A Rocha Encantada: De Volta à Caverna S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174182.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76618, 5242, 'A Rocha Encantada: De Volta à Caverna S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174183.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76619, 5242, 'A Rocha Encantada: De Volta à Caverna S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174184.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76620, 5242, 'A Rocha Encantada: De Volta à Caverna S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174185.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76621, 5242, 'A Rocha Encantada: De Volta à Caverna S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/174186.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76622, 5242, 'A Rocha Encantada: De Volta à Caverna S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/174187.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76623, 5242, 'A Rocha Encantada: De Volta à Caverna S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/174188.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76624, 5243, 'A Rocha Encantada: De Volta à Caverna S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174189.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76625, 5243, 'A Rocha Encantada: De Volta à Caverna S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174190.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76626, 5243, 'A Rocha Encantada: De Volta à Caverna S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174191.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76627, 5243, 'A Rocha Encantada: De Volta à Caverna S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174192.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76628, 5243, 'A Rocha Encantada: De Volta à Caverna S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174193.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76629, 5243, 'A Rocha Encantada: De Volta à Caverna S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174194.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76630, 5243, 'A Rocha Encantada: De Volta à Caverna S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174195.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76631, 5243, 'A Rocha Encantada: De Volta à Caverna S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174196.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76632, 5243, 'A Rocha Encantada: De Volta à Caverna S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174197.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76633, 5243, 'A Rocha Encantada: De Volta à Caverna S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174198.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76634, 5243, 'A Rocha Encantada: De Volta à Caverna S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/174199.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76635, 5243, 'A Rocha Encantada: De Volta à Caverna S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/174200.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76636, 5243, 'A Rocha Encantada: De Volta à Caverna S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/174201.mp4', 'http://gstaticontent.com/images/9834b2e7fc6c37c6b09a018871b19913.jpg'),
(76637, 5244, 'A Vizinha da Mulher na Janela S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174098.mp4', 'http://timg.bdta.pro/images/f484b423598f2266460d219429ef1205.jpg'),
(76638, 5244, 'A Vizinha da Mulher na Janela S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174099.mp4', 'http://timg.bdta.pro/images/a0eb0d09cbc05c279ccb752797723770.jpg'),
(76639, 5244, 'A Vizinha da Mulher na Janela S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174100.mp4', 'http://timg.bdta.pro/images/21d980d72d1d09d9492022abb778a3b8.jpg'),
(76640, 5244, 'A Vizinha da Mulher na Janela S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174101.mp4', 'http://timg.bdta.pro/images/04d136ab889e814448422d58a7e21de5.jpg'),
(76641, 5244, 'A Vizinha da Mulher na Janela S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174102.mp4', 'http://timg.bdta.pro/images/0f5b09955db845624af730660624845b.jpg'),
(76642, 5244, 'A Vizinha da Mulher na Janela S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174103.mp4', 'http://timg.bdta.pro/images/935248e5d523ab9bf2723eeb88f5fe91.jpg'),
(76643, 5244, 'A Vizinha da Mulher na Janela S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174104.mp4', 'http://timg.bdta.pro/images/06d7862c9c268db0cc173bc9a77c22f9.jpg'),
(76644, 5244, 'A Vizinha da Mulher na Janela S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174105.mp4', 'http://timg.bdta.pro/images/06de3e54aad21008cfff0b856dcf5d67.jpg'),
(76645, 5245, 'All of Us Are Dead S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174086.mp4', 'http://timg.bdta.pro/images/21f5a2915a696b3397a58f693d6bae66.jpg'),
(76646, 5245, 'All of Us Are Dead S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174087.mp4', 'http://timg.bdta.pro/images/0bcb06baec46cd62dc89a904812dc162.jpg'),
(76647, 5245, 'All of Us Are Dead S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174088.mp4', 'http://timg.bdta.pro/images/c750831c2fbc05b52eda6be2081915ce.jpg'),
(76648, 5245, 'All of Us Are Dead S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174089.mp4', 'http://timg.bdta.pro/images/866cd76c6b276523fb806d038716fbea.jpg'),
(76649, 5245, 'All of Us Are Dead S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174090.mp4', 'http://timg.bdta.pro/images/d9466efce2c7e8a675a60ac48e832bda.jpg'),
(76650, 5245, 'All of Us Are Dead S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174091.mp4', 'http://timg.bdta.pro/images/47be7ff27c4ea58d524cf79d0a6a2003.jpg'),
(76651, 5245, 'All of Us Are Dead S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174092.mp4', 'http://timg.bdta.pro/images/ec1c500bece201823682289205c5d3db.jpg'),
(76652, 5245, 'All of Us Are Dead S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174093.mp4', 'http://timg.bdta.pro/images/b46b62eabecd2c67e860c305cb917289.jpg'),
(76653, 5245, 'All of Us Are Dead S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174094.mp4', 'http://timg.bdta.pro/images/817421796f4bdde3167f1f62ea4af976.jpg'),
(76654, 5245, 'All of Us Are Dead S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174095.mp4', 'http://timg.bdta.pro/images/f41d5811aae95ee5e0008752a1b2846c.jpg'),
(76655, 5245, 'All of Us Are Dead S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/174096.mp4', 'http://timg.bdta.pro/images/d616ef45abc8aa68563bef19df8dc7d5.jpg'),
(76656, 5245, 'All of Us Are Dead S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/174097.mp4', 'http://timg.bdta.pro/images/05ea1c8ecf1457a20f36d1c7235fbb71.jpg'),
(76657, 5246, 'Nosso Jeito de Ser S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174078.mp4', 'http://timg.bdta.pro/images/4e6426722298f2961e7206166cb40327.jpg'),
(76658, 5246, 'Nosso Jeito de Ser S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174079.mp4', 'http://timg.bdta.pro/images/5f0d92e62e37cd38d9c0b8ff712cd0c7.jpg'),
(76659, 5246, 'Nosso Jeito de Ser S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174080.mp4', 'http://timg.bdta.pro/images/cd9fc2e63d86e80d5d1153dbee0002c1.jpg'),
(76660, 5246, 'Nosso Jeito de Ser S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174081.mp4', 'http://timg.bdta.pro/images/7a4824c7a66f51d092feaad84b5d28f9.jpg'),
(76661, 5246, 'Nosso Jeito de Ser S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174082.mp4', 'http://timg.bdta.pro/images/001c89edf462690755a92143d6c4c7fa.jpg'),
(76662, 5246, 'Nosso Jeito de Ser S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174083.mp4', 'http://timg.bdta.pro/images/1abd2fa77cb46db264864a7945696a18.jpg'),
(76663, 5246, 'Nosso Jeito de Ser S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174084.mp4', 'http://timg.bdta.pro/images/58982d787ca6d55c93dd98cf1356558a.jpg'),
(76664, 5246, 'Nosso Jeito de Ser S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174085.mp4', 'http://timg.bdta.pro/images/45e8a8fdab16f4a7039c06290693fbb8.jpg'),
(76665, 5247, 'Assassímio da Marvel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174068.mp4', 'http://timg.bdta.pro/images/98d295758b0f3df2fd5ac4cdb0152c43.jpg'),
(76666, 5247, 'Assassímio da Marvel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174069.mp4', 'http://timg.bdta.pro/images/241caf5bf5409bf492fb95ac399428bb.jpg'),
(76667, 5247, 'Assassímio da Marvel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174070.mp4', 'http://timg.bdta.pro/images/d87f77cd5ff98efcc61dfd95038b6663.jpg'),
(76668, 5247, 'Assassímio da Marvel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174071.mp4', 'http://timg.bdta.pro/images/569b3731140fe7039abd4c1f6fd4eb5f.jpg'),
(76669, 5247, 'Assassímio da Marvel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174072.mp4', 'http://timg.bdta.pro/images/73fb8a47a6f64c916ffe071d21dbe36e.jpg'),
(76670, 5247, 'Assassímio da Marvel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174073.mp4', 'http://timg.bdta.pro/images/434040346194ada491b076369fbbf5b2.jpg'),
(76671, 5247, 'Assassímio da Marvel S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174074.mp4', 'http://timg.bdta.pro/images/1e20ee015a9669d9bc193bbc7b1c7b2d.jpg'),
(76672, 5247, 'Assassímio da Marvel S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174075.mp4', 'http://timg.bdta.pro/images/90115982802e71f6205cb8da804981b8.jpg'),
(76673, 5247, 'Assassímio da Marvel S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174076.mp4', 'http://timg.bdta.pro/images/338a41171f6a33eda9218280070e1686.jpg'),
(76674, 5247, 'Assassímio da Marvel S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174077.mp4', 'http://timg.bdta.pro/images/bc9909d5a7820c4db9395dc72c3770d2.jpg'),
(76675, 5248, 'Assassímio da Marvel S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/430770.mp4', 'http://gstaticontent.com/images/531089fca664d2359ddc6c2a0c6c415b.jpg'),
(76676, 5248, 'Assassímio da Marvel S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/430771.mp4', 'http://gstaticontent.com/images/531089fca664d2359ddc6c2a0c6c415b.jpg'),
(76677, 5248, 'Assassímio da Marvel S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/430772.mp4', 'http://gstaticontent.com/images/531089fca664d2359ddc6c2a0c6c415b.jpg'),
(76678, 5248, 'Assassímio da Marvel S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/430773.mp4', 'http://gstaticontent.com/images/531089fca664d2359ddc6c2a0c6c415b.jpg'),
(76679, 5248, 'Assassímio da Marvel S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/430774.mp4', 'http://gstaticontent.com/images/531089fca664d2359ddc6c2a0c6c415b.jpg'),
(76680, 5248, 'Assassímio da Marvel S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/430775.mp4', 'http://gstaticontent.com/images/531089fca664d2359ddc6c2a0c6c415b.jpg'),
(76681, 5248, 'Assassímio da Marvel S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/430776.mp4', 'http://gstaticontent.com/images/531089fca664d2359ddc6c2a0c6c415b.jpg'),
(76682, 5248, 'Assassímio da Marvel S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/430777.mp4', 'http://gstaticontent.com/images/531089fca664d2359ddc6c2a0c6c415b.jpg'),
(76683, 5248, 'Assassímio da Marvel S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/430778.mp4', 'http://gstaticontent.com/images/531089fca664d2359ddc6c2a0c6c415b.jpg'),
(76684, 5248, 'Assassímio da Marvel S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/430779.mp4', 'http://gstaticontent.com/images/531089fca664d2359ddc6c2a0c6c415b.jpg'),
(76685, 5249, 'Caso Roswell O Veredito Final S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174062.mp4', 'http://timg.bdta.pro/images/56413ca42f5da5209ff1bd7780bdfc30.jpg'),
(76686, 5249, 'Caso Roswell O Veredito Final S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174063.mp4', 'http://timg.bdta.pro/images/bf843729b7ed0146a17a863832cdab19.jpg'),
(76687, 5249, 'Caso Roswell O Veredito Final S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174064.mp4', 'http://timg.bdta.pro/images/1347532bbf54cade7efb9ce0fed7cde6.jpg'),
(76688, 5249, 'Caso Roswell O Veredito Final S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174065.mp4', 'http://timg.bdta.pro/images/4bb23adbc82dbd7c05235fac20100a87.jpg'),
(76689, 5249, 'Caso Roswell O Veredito Final S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174066.mp4', 'http://timg.bdta.pro/images/97116aabcd0b1420b0f020d14f3ae9c2.jpg'),
(76690, 5249, 'Caso Roswell O Veredito Final S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174067.mp4', 'http://gstaticontent.com/images/606d6d5e208f36f86683e6c0ef3dcb93.jpg'),
(76691, 5250, 'Melhores Cachorros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198929.mp4', 'http://timg.bdta.pro/images/1ee2d45dc8139db2b578088cd9753b29.jpg'),
(76692, 5250, 'Melhores Cachorros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198930.mp4', 'http://timg.bdta.pro/images/acbb399bf0cee1daddef4a19dff7be8d.jpg'),
(76693, 5250, 'Melhores Cachorros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198931.mp4', 'http://timg.bdta.pro/images/4fe8cb6b0793633e759814bfd59a5e3d.jpg'),
(76694, 5250, 'Melhores Cachorros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198932.mp4', 'http://timg.bdta.pro/images/e0adef03c95ebc2129706b48c8dfd2c7.jpg'),
(76695, 5250, 'Melhores Cachorros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198933.mp4', 'http://timg.bdta.pro/images/f070fc77103b537b1e24f05f6dd3f3f1.jpg'),
(76696, 5250, 'Melhores Cachorros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198934.mp4', 'http://timg.bdta.pro/images/9348dc0ba267dea5972deac278422c30.jpg'),
(76697, 5250, 'Melhores Cachorros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198935.mp4', 'http://timg.bdta.pro/images/bc8bd6261c64a898729aa988bf3fce27.jpg'),
(76698, 5250, 'Melhores Cachorros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198936.mp4', 'http://timg.bdta.pro/images/993073516f7068bb22ab06b7ab4ab8ec.jpg'),
(76699, 5250, 'Melhores Cachorros S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198937.mp4', 'http://timg.bdta.pro/images/9f02f5f68f8aa7020b575375103b53b0.jpg'),
(76700, 5250, 'Melhores Cachorros S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198938.mp4', 'http://timg.bdta.pro/images/45e5756ecf8c2d1aebdfe42719563c83.jpg'),
(76701, 5251, 'Melhores Cachorros S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198939.mp4', 'http://gstaticontent.com/images/3d91134ca4d62fbf4ce8716745a2ce8d.jpg'),
(76702, 5251, 'Melhores Cachorros S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198940.mp4', 'http://gstaticontent.com/images/3d91134ca4d62fbf4ce8716745a2ce8d.jpg'),
(76703, 5251, 'Melhores Cachorros S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198941.mp4', 'http://gstaticontent.com/images/3d91134ca4d62fbf4ce8716745a2ce8d.jpg'),
(76704, 5251, 'Melhores Cachorros S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198942.mp4', 'http://gstaticontent.com/images/3d91134ca4d62fbf4ce8716745a2ce8d.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(76705, 5251, 'Melhores Cachorros S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198943.mp4', 'http://gstaticontent.com/images/3d91134ca4d62fbf4ce8716745a2ce8d.jpg'),
(76706, 5251, 'Melhores Cachorros S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198944.mp4', 'http://gstaticontent.com/images/3d91134ca4d62fbf4ce8716745a2ce8d.jpg'),
(76707, 5251, 'Melhores Cachorros S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198945.mp4', 'http://gstaticontent.com/images/3d91134ca4d62fbf4ce8716745a2ce8d.jpg'),
(76708, 5251, 'Melhores Cachorros S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198946.mp4', 'http://gstaticontent.com/images/3d91134ca4d62fbf4ce8716745a2ce8d.jpg'),
(76709, 5251, 'Melhores Cachorros S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198947.mp4', 'http://gstaticontent.com/images/3d91134ca4d62fbf4ce8716745a2ce8d.jpg'),
(76710, 5251, 'Melhores Cachorros S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198948.mp4', 'http://gstaticontent.com/images/3d91134ca4d62fbf4ce8716745a2ce8d.jpg'),
(76711, 5251, 'Melhores Cachorros S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/198949.mp4', 'http://gstaticontent.com/images/3d91134ca4d62fbf4ce8716745a2ce8d.jpg'),
(76712, 5251, 'Melhores Cachorros S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/198950.mp4', 'http://gstaticontent.com/images/3d91134ca4d62fbf4ce8716745a2ce8d.jpg'),
(76713, 5252, 'DOC – Uma Nova Vida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183134.mp4', 'http://timg.bdta.pro/images/809bb62c6d2a7ce48855e96e5d738738.jpg'),
(76714, 5252, 'DOC – Uma Nova Vida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183135.mp4', 'http://timg.bdta.pro/images/bbb0f939eae31ae686f95ebb6703efb8.jpg'),
(76715, 5252, 'DOC – Uma Nova Vida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183136.mp4', 'http://timg.bdta.pro/images/97a494eb4dc4e924a5e25224f6d0e40e.jpg'),
(76716, 5252, 'DOC – Uma Nova Vida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183137.mp4', 'http://timg.bdta.pro/images/52a1f3711d603c00eab93aeb2473d1ad.jpg'),
(76717, 5252, 'DOC – Uma Nova Vida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183138.mp4', 'http://timg.bdta.pro/images/9c0011d36ce46a7685a64e1a7bf0fa1a.jpg'),
(76718, 5252, 'DOC – Uma Nova Vida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183139.mp4', 'http://timg.bdta.pro/images/a42b8fa1be17f02135b626071d430781.jpg'),
(76719, 5252, 'DOC – Uma Nova Vida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183140.mp4', 'http://timg.bdta.pro/images/d5ec1822571bcc3a805072365c1a8f0f.jpg'),
(76720, 5252, 'DOC – Uma Nova Vida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183141.mp4', 'http://timg.bdta.pro/images/0916e09b5fedb33638163d10a74f13fc.jpg'),
(76721, 5252, 'DOC – Uma Nova Vida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183142.mp4', 'http://timg.bdta.pro/images/bd53dc8c7772187b0bba89a4607a521a.jpg'),
(76722, 5252, 'DOC – Uma Nova Vida S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183143.mp4', 'http://timg.bdta.pro/images/e0c847d7fb90cd579ed22a29bedfa1fc.jpg'),
(76723, 5252, 'DOC – Uma Nova Vida S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183144.mp4', 'http://timg.bdta.pro/images/1e587e07232091e13dec700331ad6c8e.jpg'),
(76724, 5252, 'DOC – Uma Nova Vida S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183145.mp4', 'http://timg.bdta.pro/images/0f33417fd5df0e7150219ef787fc0a09.jpg'),
(76725, 5252, 'DOC – Uma Nova Vida S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/183146.mp4', 'http://timg.bdta.pro/images/0996f9c7eddfaa3681b87d1c3548d6da.jpg'),
(76726, 5252, 'DOC – Uma Nova Vida S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/183147.mp4', 'http://timg.bdta.pro/images/f74f3f489158922950fee1791f5bc96b.jpg'),
(76727, 5252, 'DOC – Uma Nova Vida S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/183148.mp4', 'http://timg.bdta.pro/images/5f1af542e278d0ed4ab7925be0f97086.jpg'),
(76728, 5252, 'DOC – Uma Nova Vida S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/183149.mp4', 'http://timg.bdta.pro/images/92d1a0d4a20777fd40062acbd92fc013.jpg'),
(76729, 5253, 'DOC – Uma Nova Vida S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183150.mp4', 'http://timg.bdta.pro/images/e2dcfcb1543d46650c27ca66302322df.jpg'),
(76730, 5253, 'DOC – Uma Nova Vida S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183151.mp4', 'http://timg.bdta.pro/images/c28fc095db5aee4c2b8b9aece0d26d28.jpg'),
(76731, 5253, 'DOC – Uma Nova Vida S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183152.mp4', 'http://timg.bdta.pro/images/d82c5bce57fb8802fbb0f30093a67f5f.jpg'),
(76732, 5253, 'DOC – Uma Nova Vida S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183153.mp4', 'http://timg.bdta.pro/images/069cf61810b31b1bb3d8144d773c0faa.jpg'),
(76733, 5253, 'DOC – Uma Nova Vida S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183154.mp4', 'http://timg.bdta.pro/images/3d07dee69f66e1ec370f97f210eb30cd.jpg'),
(76734, 5253, 'DOC – Uma Nova Vida S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183155.mp4', 'http://timg.bdta.pro/images/cf4f7d9842355ae40f51cc9c4c61ff97.jpg'),
(76735, 5253, 'DOC – Uma Nova Vida S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183156.mp4', 'http://timg.bdta.pro/images/ce27b7eaed82155a64682f5ae19ea192.jpg'),
(76736, 5253, 'DOC – Uma Nova Vida S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183157.mp4', 'http://timg.bdta.pro/images/e69e9a2088546f46b778dacc6503ffe6.jpg'),
(76737, 5253, 'DOC – Uma Nova Vida S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183158.mp4', 'http://timg.bdta.pro/images/546595edf9d1cfdc559e0b8e4718c0ad.jpg'),
(76738, 5253, 'DOC – Uma Nova Vida S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183159.mp4', 'http://timg.bdta.pro/images/91f917cffbdb43fd9f1e0ae73cae3739.jpg'),
(76739, 5253, 'DOC – Uma Nova Vida S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183160.mp4', 'http://timg.bdta.pro/images/59b00a9f8a630d0dd937f7dcffc0daeb.jpg'),
(76740, 5253, 'DOC – Uma Nova Vida S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183161.mp4', 'http://timg.bdta.pro/images/b5da3c1b8a7ce2d3b134f87a9aeeee2e.jpg'),
(76741, 5253, 'DOC – Uma Nova Vida S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/183162.mp4', 'http://timg.bdta.pro/images/973943897233d63794e1ed443aa7ca29.jpg'),
(76742, 5253, 'DOC – Uma Nova Vida S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/183163.mp4', 'http://timg.bdta.pro/images/0efaee27e4e1871a0178d800e4a05896.jpg'),
(76743, 5253, 'DOC – Uma Nova Vida S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/183164.mp4', 'http://timg.bdta.pro/images/8e73a6b60c574d3e0046dd7dc78d9faf.jpg'),
(76744, 5253, 'DOC – Uma Nova Vida S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/183165.mp4', 'http://timg.bdta.pro/images/e0b8f1492db9397914d00f0e9efaea05.jpg'),
(76745, 5254, 'DOC – Uma Nova Vida S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/628171.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ddMu0CjTpyamrIu28eHPV6Z805h.jpg'),
(76746, 5254, 'DOC – Uma Nova Vida S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/487451.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yTzk1YbYuodxXfulrN7TlpTU7WU.jpg'),
(76747, 5254, 'DOC – Uma Nova Vida S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/487452.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sFqkAkRfpt38a3Md8X5FZ4LHh3n.jpg'),
(76748, 5254, 'DOC – Uma Nova Vida S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/487453.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sMQBdhvNqDK9TfHiXVNWrsPOiFI.jpg'),
(76749, 5254, 'DOC – Uma Nova Vida S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/487454.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uk5wK4TGxwqX9dwwTWwLv0aVxyH.jpg'),
(76750, 5254, 'DOC – Uma Nova Vida S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/487455.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fZYRjxyazHN7l0jqrx0nwkx6yUF.jpg'),
(76751, 5254, 'DOC – Uma Nova Vida S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/487456.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/est5MaVKNkDaaKC00VFH2bfLgoR.jpg'),
(76752, 5254, 'DOC – Uma Nova Vida S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/487457.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nIVVijZAreGI8ypfYYwwZCnXua6.jpg'),
(76753, 5254, 'DOC – Uma Nova Vida S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/487458.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nG1LUFxPHcrmfmXyvhE3QMlKZUV.jpg'),
(76754, 5254, 'DOC – Uma Nova Vida S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/487459.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4VJK37IwBGbomeEU6xyIz1YNqJ4.jpg'),
(76755, 5254, 'DOC – Uma Nova Vida S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/487460.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w6X8ahSaYa1hNdV19rpizwb3GAB.jpg'),
(76756, 5254, 'DOC – Uma Nova Vida S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/487461.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ndG2ZXLYcokN1ZTlxYiHuy4ttsv.jpg'),
(76757, 5254, 'DOC – Uma Nova Vida S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/487462.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ljHWyAi9ACYQpYhXri1FIySRpe7.jpg'),
(76758, 5254, 'DOC – Uma Nova Vida S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/487463.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nF9XzFwFOfwWUrxhckHqC9oRfjz.jpg'),
(76759, 5254, 'DOC – Uma Nova Vida S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/487464.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xdpOsZtWrrVumuoazocMglwNuh4.jpg'),
(76760, 5254, 'DOC – Uma Nova Vida S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/487465.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uKC4vgeSXn8UXkJLH5DCljwaAGc.jpg'),
(76761, 5255, 'DOTA: Dragon’s Blood S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195417.mp4', 'http://timg.bdta.pro/images/9841e4de90c867abce70659489773226.jpg'),
(76762, 5255, 'DOTA: Dragon’s Blood S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195418.mp4', 'http://timg.bdta.pro/images/e6bf404c6131357c877238c94c693dca.jpg'),
(76763, 5255, 'DOTA: Dragon’s Blood S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195419.mp4', 'http://timg.bdta.pro/images/4f0876f59fe2336ecd9b57dbc296ea59.jpg'),
(76764, 5255, 'DOTA: Dragon’s Blood S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195420.mp4', 'http://timg.bdta.pro/images/197f00cae1e7686342889da9acda7c1d.jpg'),
(76765, 5255, 'DOTA: Dragon’s Blood S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195421.mp4', 'http://timg.bdta.pro/images/c9ad02424a010ad3e2c4d33e895fd732.jpg'),
(76766, 5255, 'DOTA: Dragon’s Blood S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195422.mp4', 'http://timg.bdta.pro/images/26348e7272e8ee0949ed7a2ac8c682ec.jpg'),
(76767, 5255, 'DOTA: Dragon’s Blood S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195423.mp4', 'http://timg.bdta.pro/images/8783bd15d1e84a7aa2a249c32a02f856.jpg'),
(76768, 5255, 'DOTA: Dragon’s Blood S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195424.mp4', 'http://timg.bdta.pro/images/d053e40518e0da5792545b52382287a4.jpg'),
(76769, 5256, 'DOTA: Dragon’s Blood S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195425.mp4', 'http://timg.bdta.pro/images/591b89cbc6421528f5e4231ea3482c45.jpg'),
(76770, 5256, 'DOTA: Dragon’s Blood S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195426.mp4', 'http://timg.bdta.pro/images/af50a0f6cca6f1d5533585a8bdbe3b80.jpg'),
(76771, 5256, 'DOTA: Dragon’s Blood S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195427.mp4', 'http://timg.bdta.pro/images/a896ece0cdf7cf2db4d418b83f5508f2.jpg'),
(76772, 5256, 'DOTA: Dragon’s Blood S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195428.mp4', 'http://timg.bdta.pro/images/e8804d32c9ca9683af85faa3f09e4322.jpg'),
(76773, 5256, 'DOTA: Dragon’s Blood S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195429.mp4', 'http://timg.bdta.pro/images/1f8333d9405c46a8cd80828a7214a458.jpg'),
(76774, 5256, 'DOTA: Dragon’s Blood S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195430.mp4', 'http://timg.bdta.pro/images/d40fdaeac0c299ebc4211bf3d420411b.jpg'),
(76775, 5256, 'DOTA: Dragon’s Blood S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195431.mp4', 'http://timg.bdta.pro/images/7aec4d2cdb6d255c69d27bcafef06bf1.jpg'),
(76776, 5256, 'DOTA: Dragon’s Blood S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195432.mp4', 'http://timg.bdta.pro/images/cf3dbdb2d480ae0a13853a11cf85c2bf.jpg'),
(76777, 5257, 'DOTA: Dragon’s Blood S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195433.mp4', 'http://timg.bdta.pro/images/b09d9c086568ed003533ecd7a4a77244.jpg'),
(76778, 5257, 'DOTA: Dragon’s Blood S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195434.mp4', 'http://timg.bdta.pro/images/02499c82f47022c0c0c47130d54401b3.jpg'),
(76779, 5257, 'DOTA: Dragon’s Blood S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195435.mp4', 'http://timg.bdta.pro/images/43945e5f5ed610c95e4ba8e6ed3f71c7.jpg'),
(76780, 5257, 'DOTA: Dragon’s Blood S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195436.mp4', 'http://timg.bdta.pro/images/abaaf6d5b8773cec2124ee46033cc9b1.jpg'),
(76781, 5257, 'DOTA: Dragon’s Blood S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195437.mp4', 'http://timg.bdta.pro/images/0c73e19b1ab7aceb9ac986fe7c8141b4.jpg'),
(76782, 5257, 'DOTA: Dragon’s Blood S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195438.mp4', 'http://timg.bdta.pro/images/dbc411d80c704322410d188a95d3c0ac.jpg'),
(76783, 5257, 'DOTA: Dragon’s Blood S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195439.mp4', 'http://timg.bdta.pro/images/69263dda143b73719670be856a4bd01b.jpg'),
(76784, 5257, 'DOTA: Dragon’s Blood S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195440.mp4', 'http://timg.bdta.pro/images/46f9bf593274f628402462edbe2efaa7.jpg'),
(76785, 5258, 'Economia Doméstica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174055.mp4', 'http://timg.bdta.pro/images/1e70fa30abf1c0d54da300e692631505.jpg'),
(76786, 5258, 'Economia Doméstica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174056.mp4', 'http://timg.bdta.pro/images/d5613b1a7e5ed97ba2a62308d208f18c.jpg'),
(76787, 5258, 'Economia Doméstica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174057.mp4', 'http://timg.bdta.pro/images/00dd1f22a180bdaccd052a8ad03a5b02.jpg'),
(76788, 5258, 'Economia Doméstica S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174058.mp4', 'http://timg.bdta.pro/images/60e09d68ac91d0481557ec2918aae355.jpg'),
(76789, 5258, 'Economia Doméstica S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174059.mp4', 'http://timg.bdta.pro/images/e28ac1994a426540a2d38eb6b9491dbf.jpg'),
(76790, 5258, 'Economia Doméstica S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174060.mp4', 'http://timg.bdta.pro/images/056cf32d61715d6f3b719bf3c890b126.jpg'),
(76791, 5258, 'Economia Doméstica S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174061.mp4', 'http://timg.bdta.pro/images/fcfa79dc9c97606c9fb6ab0b453ba83e.jpg'),
(76792, 5259, 'El Presidente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174047.mp4', 'http://timg.bdta.pro/images/24e2a5b27f781d663291858113922544.jpg'),
(76793, 5259, 'El Presidente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174048.mp4', 'http://timg.bdta.pro/images/35c8ff0d4354812f602a216a3594212c.jpg'),
(76794, 5259, 'El Presidente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174049.mp4', 'http://timg.bdta.pro/images/2b5bdeac2b00ea68821fd9777fb3f26a.jpg'),
(76795, 5259, 'El Presidente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174050.mp4', 'http://timg.bdta.pro/images/17909d979691b264e675ec1edef3e521.jpg'),
(76796, 5259, 'El Presidente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174051.mp4', 'http://timg.bdta.pro/images/2f7b910e0323684b210e1097b97efc1d.jpg'),
(76797, 5259, 'El Presidente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174052.mp4', 'http://timg.bdta.pro/images/7575e90f8fd38fbadfdaf8e879038938.jpg'),
(76798, 5259, 'El Presidente S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174053.mp4', 'http://timg.bdta.pro/images/30389dbfb88c562d40191446f1d3b428.jpg'),
(76799, 5259, 'El Presidente S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174054.mp4', 'http://timg.bdta.pro/images/707ad1aa12715fb1de23e5a1e61c877f.jpg'),
(76800, 5260, 'Express S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206320.mp4', 'http://timg.bdta.pro/images/1c5547e2cdd4959933788f39efd8f799.jpg'),
(76801, 5260, 'Express S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206321.mp4', 'http://timg.bdta.pro/images/729ef6e240e68046994bf3add07c5656.jpg'),
(76802, 5260, 'Express S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206322.mp4', 'http://timg.bdta.pro/images/8abb430f5ef4062f6c38aee271a2d069.jpg'),
(76803, 5260, 'Express S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206323.mp4', 'http://timg.bdta.pro/images/3c21a08771a377bae97025be65539bf4.jpg'),
(76804, 5260, 'Express S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206324.mp4', 'http://timg.bdta.pro/images/a34a12db62d24496b8373f310542f9d2.jpg'),
(76805, 5260, 'Express S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206325.mp4', 'http://timg.bdta.pro/images/8950591c0baca1d6885625ea89046ade.jpg'),
(76806, 5260, 'Express S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206326.mp4', 'http://timg.bdta.pro/images/0cdcc147ea081d67a5af8085877c3a11.jpg'),
(76807, 5260, 'Express S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206327.mp4', 'http://timg.bdta.pro/images/86eee252c8c182d7dd36e87537e91c51.jpg'),
(76808, 5261, 'Express S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206328.mp4', 'http://gstaticontent.com/images/d25845e3cb38ec5576c7e50e3e67f0ea.jpg'),
(76809, 5261, 'Express S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206329.mp4', 'http://gstaticontent.com/images/d25845e3cb38ec5576c7e50e3e67f0ea.jpg'),
(76810, 5261, 'Express S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206330.mp4', 'http://gstaticontent.com/images/d25845e3cb38ec5576c7e50e3e67f0ea.jpg'),
(76811, 5261, 'Express S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206331.mp4', 'http://gstaticontent.com/images/d25845e3cb38ec5576c7e50e3e67f0ea.jpg'),
(76812, 5261, 'Express S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206332.mp4', 'http://gstaticontent.com/images/d25845e3cb38ec5576c7e50e3e67f0ea.jpg'),
(76813, 5261, 'Express S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206333.mp4', 'http://gstaticontent.com/images/d25845e3cb38ec5576c7e50e3e67f0ea.jpg'),
(76814, 5261, 'Express S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206334.mp4', 'http://gstaticontent.com/images/d25845e3cb38ec5576c7e50e3e67f0ea.jpg'),
(76815, 5261, 'Express S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206335.mp4', 'http://gstaticontent.com/images/d25845e3cb38ec5576c7e50e3e67f0ea.jpg'),
(76816, 5262, 'FC Bayern – Por Trás da Lenda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174041.mp4', 'http://timg.bdta.pro/images/fb14c48d5ab2a1f4789e5d664c34f2f6.jpg'),
(76817, 5262, 'FC Bayern – Por Trás da Lenda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174042.mp4', 'http://timg.bdta.pro/images/3b2292d0c98d35755b4f46f44f5e1258.jpg'),
(76818, 5262, 'FC Bayern – Por Trás da Lenda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174043.mp4', 'http://timg.bdta.pro/images/72e270d87e986b0a8e660a9939025ceb.jpg'),
(76819, 5262, 'FC Bayern – Por Trás da Lenda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174044.mp4', 'http://timg.bdta.pro/images/92ce963a1fe4b67180561a8a84e32aa5.jpg'),
(76820, 5262, 'FC Bayern – Por Trás da Lenda S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174045.mp4', 'http://timg.bdta.pro/images/351ad1ceb9853fecc44d93a295298e2a.jpg'),
(76821, 5262, 'FC Bayern – Por Trás da Lenda S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174046.mp4', 'http://timg.bdta.pro/images/493cba177731a442a92cc72da4822cab.jpg'),
(76822, 5263, 'Feria: Segredos Obacuros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174033.mp4', 'http://timg.bdta.pro/images/f2ceb12471dbfcf7741783d6885de97b.jpg'),
(76823, 5263, 'Feria: Segredos Obacuros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174034.mp4', 'http://timg.bdta.pro/images/bca6fb7b51a5846c1f55f9937cee48a2.jpg'),
(76824, 5263, 'Feria: Segredos Obacuros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174035.mp4', 'http://timg.bdta.pro/images/92e43418177fd262baed2fa9058af0d0.jpg'),
(76825, 5263, 'Feria: Segredos Obacuros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174036.mp4', 'http://timg.bdta.pro/images/4add667e8eafb33ab87525f497e17cc2.jpg'),
(76826, 5263, 'Feria: Segredos Obacuros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174037.mp4', 'http://timg.bdta.pro/images/d106b6703131b78bc5a58af0322a1598.jpg'),
(76827, 5263, 'Feria: Segredos Obacuros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174038.mp4', 'http://timg.bdta.pro/images/acb2d48c2b01f25caba8f9c7fdee07a8.jpg'),
(76828, 5263, 'Feria: Segredos Obacuros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174039.mp4', 'http://timg.bdta.pro/images/cb2ffd5013bf191c86eeb0fe10256f3a.jpg'),
(76829, 5263, 'Feria: Segredos Obacuros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174040.mp4', 'http://timg.bdta.pro/images/f0bc9770d84585e0edb9043d1a0943a1.jpg'),
(76830, 5264, 'Fora de Órbita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174027.mp4', 'http://timg.bdta.pro/images/96694cfeaabffcc2eaa289b85868df70.jpg'),
(76831, 5264, 'Fora de Órbita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174028.mp4', 'http://timg.bdta.pro/images/d6b791f80586aadc2061fef4259a17c0.jpg'),
(76832, 5264, 'Fora de Órbita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174029.mp4', 'http://timg.bdta.pro/images/f9f706a5ffa7ccf1bc18d127a5104f9c.jpg'),
(76833, 5264, 'Fora de Órbita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174030.mp4', 'http://timg.bdta.pro/images/f5e43cca8ad4ad5a89e42dfb752efa0f.jpg'),
(76834, 5264, 'Fora de Órbita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174031.mp4', 'http://timg.bdta.pro/images/6ba28de3e3c0eb7238ff2c4ebdb64a64.jpg'),
(76835, 5264, 'Fora de Órbita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174032.mp4', 'http://timg.bdta.pro/images/18d6eae6d445c3cf16cd5d8aae7b70ac.jpg'),
(76836, 5265, 'House of Lies – Casa de Mentiras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173969.mp4', 'http://timg.bdta.pro/images/da0ba108f11a8fb6698275e6a784a891.jpg'),
(76837, 5265, 'House of Lies – Casa de Mentiras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173970.mp4', 'http://timg.bdta.pro/images/ad1b20319a572b22beaf2de61e08ebaa.jpg'),
(76838, 5265, 'House of Lies – Casa de Mentiras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173971.mp4', 'http://timg.bdta.pro/images/1e3b9cde02cfdc32737fa4ab4231729e.jpg'),
(76839, 5265, 'House of Lies – Casa de Mentiras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173972.mp4', 'http://timg.bdta.pro/images/aa372ea0690979e2ac1f18d303e7686b.jpg'),
(76840, 5265, 'House of Lies – Casa de Mentiras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173973.mp4', 'http://timg.bdta.pro/images/e0190d6e3081f1bcb0dbcc7c3e991911.jpg'),
(76841, 5265, 'House of Lies – Casa de Mentiras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173974.mp4', 'http://timg.bdta.pro/images/9022fd1033058dabee5b727c81584191.jpg'),
(76842, 5265, 'House of Lies – Casa de Mentiras S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173975.mp4', 'http://timg.bdta.pro/images/60cee98144ceeeb3132a7cc1b1db43b1.jpg'),
(76843, 5265, 'House of Lies – Casa de Mentiras S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173976.mp4', 'http://timg.bdta.pro/images/64b2e1a64548c5d1636b6d4524c02c5f.jpg'),
(76844, 5265, 'House of Lies – Casa de Mentiras S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173977.mp4', 'http://timg.bdta.pro/images/50fd3c0520fb0cca5bbd6c21d0726a23.jpg'),
(76845, 5265, 'House of Lies – Casa de Mentiras S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173978.mp4', 'http://timg.bdta.pro/images/01de086e6d22ff8bb986574d87ed5405.jpg'),
(76846, 5265, 'House of Lies – Casa de Mentiras S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173979.mp4', 'http://timg.bdta.pro/images/4ea71ffd92dbbfea81043ad4b8c35aa5.jpg'),
(76847, 5265, 'House of Lies – Casa de Mentiras S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173980.mp4', 'http://timg.bdta.pro/images/945ceee6ebaed1255ce2de6fc216a969.jpg'),
(76848, 5266, 'House of Lies – Casa de Mentiras S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173981.mp4', 'http://timg.bdta.pro/images/f1e0ae2d308e9714c318ba5c9f192950.jpg'),
(76849, 5266, 'House of Lies – Casa de Mentiras S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173982.mp4', 'http://timg.bdta.pro/images/eab664bb5da333a8f61455c77b9b3c35.jpg'),
(76850, 5266, 'House of Lies – Casa de Mentiras S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173983.mp4', 'http://timg.bdta.pro/images/5881695a3539cf86d8156ae502c9b4c1.jpg'),
(76851, 5266, 'House of Lies – Casa de Mentiras S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173984.mp4', 'http://timg.bdta.pro/images/b50440992c81a3eefd5369affc34b752.jpg'),
(76852, 5266, 'House of Lies – Casa de Mentiras S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173985.mp4', 'http://timg.bdta.pro/images/c5e7c7a4072c030c24fb911afdb5ca58.jpg'),
(76853, 5266, 'House of Lies – Casa de Mentiras S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173986.mp4', 'http://timg.bdta.pro/images/a0f06a579ed3bec3fdf8a3bc7039c35d.jpg'),
(76854, 5266, 'House of Lies – Casa de Mentiras S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173987.mp4', 'http://timg.bdta.pro/images/6b48c173a1999417c132199c32d6b11b.jpg'),
(76855, 5266, 'House of Lies – Casa de Mentiras S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173988.mp4', 'http://timg.bdta.pro/images/5d16c4c4c8b73501059932a482a212e1.jpg'),
(76856, 5266, 'House of Lies – Casa de Mentiras S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173989.mp4', 'http://timg.bdta.pro/images/4e73093044c7aafc1abc49dc6c84ab8a.jpg'),
(76857, 5266, 'House of Lies – Casa de Mentiras S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173990.mp4', 'http://timg.bdta.pro/images/ecb6057137a08e95a21184ce634ab8ac.jpg'),
(76858, 5266, 'House of Lies – Casa de Mentiras S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173991.mp4', 'http://timg.bdta.pro/images/d315d3ad75b8ec44ca802e760faaeb57.jpg'),
(76859, 5266, 'House of Lies – Casa de Mentiras S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173992.mp4', 'http://timg.bdta.pro/images/eb3b406a59c9ebcc943923e40b9389b4.jpg'),
(76860, 5267, 'House of Lies – Casa de Mentiras S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173993.mp4', 'http://timg.bdta.pro/images/73566254e3564b11a6bb9816aa7e3832.jpg'),
(76861, 5267, 'House of Lies – Casa de Mentiras S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173994.mp4', 'http://timg.bdta.pro/images/b6b27277654efb04e9a7a9821078fada.jpg'),
(76862, 5267, 'House of Lies – Casa de Mentiras S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173995.mp4', 'http://timg.bdta.pro/images/abb5a8fb15e343a6bdeb88dc57b21d8d.jpg'),
(76863, 5267, 'House of Lies – Casa de Mentiras S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173996.mp4', 'http://timg.bdta.pro/images/946ef0379951554b86e3d6a5058eb3c9.jpg'),
(76864, 5267, 'House of Lies – Casa de Mentiras S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173997.mp4', 'http://timg.bdta.pro/images/4bebc96df04b12e2aa1f4d7dbafece55.jpg'),
(76865, 5267, 'House of Lies – Casa de Mentiras S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173998.mp4', 'http://timg.bdta.pro/images/d4ee60ef0b0c15e3370d91e3d3b951d5.jpg'),
(76866, 5267, 'House of Lies – Casa de Mentiras S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173999.mp4', 'http://timg.bdta.pro/images/44f15438a7a7dfa0ccb9cfd1dc392589.jpg'),
(76867, 5267, 'House of Lies – Casa de Mentiras S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174000.mp4', 'http://timg.bdta.pro/images/ebe73efa3c85d5999a106f0a7e452894.jpg'),
(76868, 5267, 'House of Lies – Casa de Mentiras S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174001.mp4', 'http://timg.bdta.pro/images/40b9f061024bb593da8b093b45bea9a6.jpg'),
(76869, 5267, 'House of Lies – Casa de Mentiras S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174002.mp4', 'http://timg.bdta.pro/images/8b975411aa9c1828bee59006e8013b9d.jpg'),
(76870, 5267, 'House of Lies – Casa de Mentiras S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/174003.mp4', 'http://timg.bdta.pro/images/bb7944a010f2385133010e0e4c4fe354.jpg'),
(76871, 5267, 'House of Lies – Casa de Mentiras S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/174004.mp4', 'http://timg.bdta.pro/images/92a060dfb79e52f5cd479cece56247c2.jpg'),
(76872, 5268, 'House of Lies – Casa de Mentiras S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174005.mp4', 'http://timg.bdta.pro/images/4006304d5c3f3a032c3c0bfdc91cb4ab.jpg'),
(76873, 5268, 'House of Lies – Casa de Mentiras S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174006.mp4', 'http://timg.bdta.pro/images/6215e80df0ba7ac79fa299a94640215c.jpg'),
(76874, 5268, 'House of Lies – Casa de Mentiras S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174007.mp4', 'http://timg.bdta.pro/images/bb30803b7b2a78ca1702234c966b1e74.jpg'),
(76875, 5268, 'House of Lies – Casa de Mentiras S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174008.mp4', 'http://timg.bdta.pro/images/fa70a111148fe4803c9bc224adf50f88.jpg'),
(76876, 5268, 'House of Lies – Casa de Mentiras S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174009.mp4', 'http://timg.bdta.pro/images/7418cb01c86f1c14e9bf43f3c370bc48.jpg'),
(76877, 5268, 'House of Lies – Casa de Mentiras S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174010.mp4', 'http://timg.bdta.pro/images/54bd11dfa9645de1331dfaf9125032dd.jpg'),
(76878, 5268, 'House of Lies – Casa de Mentiras S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174011.mp4', 'http://timg.bdta.pro/images/7bb8f96d10f4953414fc6504b7e21ac7.jpg'),
(76879, 5268, 'House of Lies – Casa de Mentiras S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174012.mp4', 'http://timg.bdta.pro/images/ac8802bf78036f183c5a568b95fd6088.jpg'),
(76880, 5268, 'House of Lies – Casa de Mentiras S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174013.mp4', 'http://timg.bdta.pro/images/b491bd071a6244a35b7f9a575369904b.jpg'),
(76881, 5268, 'House of Lies – Casa de Mentiras S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174014.mp4', 'http://timg.bdta.pro/images/439bafd6f733acdcde1dcc2222348d95.jpg'),
(76882, 5268, 'House of Lies – Casa de Mentiras S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/174015.mp4', 'http://timg.bdta.pro/images/bcdecf72b739a160bc0e572b6945922b.jpg'),
(76883, 5268, 'House of Lies – Casa de Mentiras S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/174016.mp4', 'http://timg.bdta.pro/images/e6788a65933964528a72f2a89230e152.jpg'),
(76884, 5269, 'House of Lies – Casa de Mentiras S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/174017.mp4', 'http://timg.bdta.pro/images/690c0755e518f546df95ed401a6f48b6.jpg'),
(76885, 5269, 'House of Lies – Casa de Mentiras S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/174018.mp4', 'http://timg.bdta.pro/images/73821c39586ce8abf7999c2c1140f994.jpg'),
(76886, 5269, 'House of Lies – Casa de Mentiras S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/174019.mp4', 'http://timg.bdta.pro/images/2fa129387fd49894fb5cefb6d9b6363e.jpg'),
(76887, 5269, 'House of Lies – Casa de Mentiras S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/174020.mp4', 'http://timg.bdta.pro/images/a79e8353a92ef5dd8aade92edc72c86f.jpg'),
(76888, 5269, 'House of Lies – Casa de Mentiras S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/174021.mp4', 'http://timg.bdta.pro/images/2c9f6badafdecf90b3e5c4e49a9dcd87.jpg'),
(76889, 5269, 'House of Lies – Casa de Mentiras S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/174022.mp4', 'http://timg.bdta.pro/images/a81d416e8e7223f8820f98a172b9d798.jpg'),
(76890, 5269, 'House of Lies – Casa de Mentiras S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/174023.mp4', 'http://timg.bdta.pro/images/d66168bea5a9719c3544df2efe3a166b.jpg'),
(76891, 5269, 'House of Lies – Casa de Mentiras S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/174024.mp4', 'http://timg.bdta.pro/images/5b66a82e511d937f99e264942b6f287c.jpg'),
(76892, 5269, 'House of Lies – Casa de Mentiras S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/174025.mp4', 'http://timg.bdta.pro/images/68bf4498cb505150d14ad7f0ac9be904.jpg'),
(76893, 5269, 'House of Lies – Casa de Mentiras S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/174026.mp4', 'http://timg.bdta.pro/images/b6d9b9794fcae9a964fc45d7f1803e1f.jpg'),
(76894, 4993, 'Insânia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173961.mp4', 'http://timg.bdta.pro/images/69667778bbbca751d7dbcb9bd8a40437.jpg'),
(76895, 4993, 'Insânia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173962.mp4', 'http://timg.bdta.pro/images/956ae1a92c3567a1a3fb94cae82a38e9.jpg'),
(76896, 4993, 'Insânia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173963.mp4', 'http://timg.bdta.pro/images/a04b652d59cc6722a01b2b634d1e20cd.jpg'),
(76897, 4993, 'Insânia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173964.mp4', 'http://timg.bdta.pro/images/84bf9b9b2fc7c2fdca02550ce01a0db2.jpg'),
(76898, 4993, 'Insânia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173965.mp4', 'http://timg.bdta.pro/images/c756487444763c26d885e354adf77432.jpg'),
(76899, 4993, 'Insânia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173966.mp4', 'http://timg.bdta.pro/images/38bec2347ec9c7d26e05c392c6143bb1.jpg'),
(76900, 4993, 'Insânia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173967.mp4', 'http://timg.bdta.pro/images/4fd75f18d7cf716291548f3589d41e04.jpg'),
(76901, 4993, 'Insânia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173968.mp4', 'http://timg.bdta.pro/images/0698c5d082ce7cd57b247e1e74321e6a.jpg'),
(76902, 5270, 'MalaYerba S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173951.mp4', 'http://timg.bdta.pro/images/8ef0dddd91010c830a5931ea6153e075.jpg'),
(76903, 5270, 'MalaYerba S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173952.mp4', 'http://timg.bdta.pro/images/21d78060dcb6565cc90ace56217fecfd.jpg'),
(76904, 5270, 'MalaYerba S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173953.mp4', 'http://timg.bdta.pro/images/443137c9ab0e32c04e43a38057c4b36c.jpg'),
(76905, 5270, 'MalaYerba S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173954.mp4', 'http://timg.bdta.pro/images/e43e77e895f71911eb3429cedb8113cc.jpg'),
(76906, 5270, 'MalaYerba S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173955.mp4', 'http://timg.bdta.pro/images/b9a71638bda4ab92e537f07c74b8ed7a.jpg'),
(76907, 5270, 'MalaYerba S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173956.mp4', 'http://timg.bdta.pro/images/7c9bf96f8dc2f8308ce7f5641dd8310a.jpg'),
(76908, 5270, 'MalaYerba S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173957.mp4', 'http://timg.bdta.pro/images/7495d0f2a135aaa0251d97709f99ca7f.jpg'),
(76909, 5270, 'MalaYerba S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173958.mp4', 'http://timg.bdta.pro/images/aeb40cdd6d6b8ed86151b736d89d04d1.jpg'),
(76910, 5270, 'MalaYerba S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173959.mp4', 'http://timg.bdta.pro/images/51deafc70680cdb1618f60e1da563cce.jpg'),
(76911, 5270, 'MalaYerba S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173960.mp4', 'http://timg.bdta.pro/images/13b0926e31d7aa07f50190de9ceb94e2.jpg'),
(76912, 5271, 'Merlí: Sapere Aude S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173943.mp4', 'http://timg.bdta.pro/images/f99d125b824b6e75595ecf732b2d68dd.jpg'),
(76913, 5271, 'Merlí: Sapere Aude S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173944.mp4', 'http://timg.bdta.pro/images/28c6a6767227fac7c1ea1d0e1ec9480f.jpg'),
(76914, 5271, 'Merlí: Sapere Aude S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173945.mp4', 'http://timg.bdta.pro/images/27ad58fe76ac90298ef24dab225889c6.jpg'),
(76915, 5271, 'Merlí: Sapere Aude S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173946.mp4', 'http://timg.bdta.pro/images/cc7c409ea0a45a59dbe119b22067228b.jpg'),
(76916, 5271, 'Merlí: Sapere Aude S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173947.mp4', 'http://timg.bdta.pro/images/6b3107334777294628c25dcc3bcf52c1.jpg'),
(76917, 5271, 'Merlí: Sapere Aude S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173948.mp4', 'http://timg.bdta.pro/images/9b9a52583e1841aeb783c95cd5205234.jpg'),
(76918, 5271, 'Merlí: Sapere Aude S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173949.mp4', 'http://timg.bdta.pro/images/fc4617d7cdc3349b5acbb6d2359a3386.jpg'),
(76919, 5271, 'Merlí: Sapere Aude S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173950.mp4', 'http://timg.bdta.pro/images/3f363d7e91f7c206277040c9a1c0173a.jpg'),
(76920, 5272, 'Mestres da Enganação S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173940.mp4', 'http://timg.bdta.pro/images/926841788533c6a39f399a1cb91c6176.jpg'),
(76921, 5272, 'Mestres da Enganação S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173941.mp4', 'http://timg.bdta.pro/images/c939d0ec0c6e6d5ce8c04b3107237902.jpg'),
(76922, 5272, 'Mestres da Enganação S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173942.mp4', 'http://timg.bdta.pro/images/acbdade0c3a42374e07e59eef2d47397.jpg'),
(76923, 5273, 'Metalder - O Homem Máquina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173900.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76924, 5273, 'Metalder - O Homem Máquina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173901.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76925, 5273, 'Metalder - O Homem Máquina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173902.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76926, 5273, 'Metalder - O Homem Máquina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173903.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76927, 5273, 'Metalder - O Homem Máquina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173904.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76928, 5273, 'Metalder - O Homem Máquina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173905.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76929, 5273, 'Metalder - O Homem Máquina S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173906.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76930, 5273, 'Metalder - O Homem Máquina S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173907.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76931, 5273, 'Metalder - O Homem Máquina S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173908.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76932, 5273, 'Metalder - O Homem Máquina S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173909.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76933, 5273, 'Metalder - O Homem Máquina S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173910.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76934, 5273, 'Metalder - O Homem Máquina S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173911.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76935, 5273, 'Metalder - O Homem Máquina S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173912.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76936, 5273, 'Metalder - O Homem Máquina S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/173913.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76937, 5273, 'Metalder - O Homem Máquina S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/173914.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76938, 5273, 'Metalder - O Homem Máquina S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/173915.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76939, 5273, 'Metalder - O Homem Máquina S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/173916.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76940, 5273, 'Metalder - O Homem Máquina S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/173917.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76941, 5273, 'Metalder - O Homem Máquina S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/173918.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76942, 5273, 'Metalder - O Homem Máquina S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/173919.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76943, 5273, 'Metalder - O Homem Máquina S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/173920.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76944, 5273, 'Metalder - O Homem Máquina S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/173921.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76945, 5273, 'Metalder - O Homem Máquina S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/173922.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76946, 5273, 'Metalder - O Homem Máquina S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/173923.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76947, 5273, 'Metalder - O Homem Máquina S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/173924.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76948, 5273, 'Metalder - O Homem Máquina S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/173925.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76949, 5273, 'Metalder - O Homem Máquina S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/173926.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76950, 5273, 'Metalder - O Homem Máquina S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/173927.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76951, 5273, 'Metalder - O Homem Máquina S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/173928.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76952, 5273, 'Metalder - O Homem Máquina S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/173929.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76953, 5273, 'Metalder - O Homem Máquina S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/173930.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76954, 5273, 'Metalder - O Homem Máquina S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/173931.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76955, 5273, 'Metalder - O Homem Máquina S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/173932.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76956, 5273, 'Metalder - O Homem Máquina S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/173933.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76957, 5273, 'Metalder - O Homem Máquina S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/173934.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76958, 5273, 'Metalder - O Homem Máquina S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/173935.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76959, 5273, 'Metalder - O Homem Máquina S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/173936.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76960, 5273, 'Metalder - O Homem Máquina S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/173937.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76961, 5273, 'Metalder - O Homem Máquina S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/173938.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76962, 5273, 'Metalder - O Homem Máquina S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/173939.mp4', 'http://gstaticontent.com/images/50373d16b56d48885f9e6b9657c80bfe.jpg'),
(76963, 5274, 'Nada é o que Parece Ser S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173894.mp4', 'http://timg.bdta.pro/images/8f43a71db55137bdf1f2c8cd3195ec9b.jpg'),
(76964, 5274, 'Nada é o que Parece Ser S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173895.mp4', 'http://timg.bdta.pro/images/6d5087b9a67fced5db2f569b4476ddd3.jpg'),
(76965, 5274, 'Nada é o que Parece Ser S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173896.mp4', 'http://timg.bdta.pro/images/3a562a8eef50d2da26c5b5b46a2d0722.jpg'),
(76966, 5274, 'Nada é o que Parece Ser S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173897.mp4', 'http://timg.bdta.pro/images/815371179b81282e37de7b6f395f274c.jpg'),
(76967, 5274, 'Nada é o que Parece Ser S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173898.mp4', 'http://timg.bdta.pro/images/2c916f2a25bc67ac9e0bd59abaace0e8.jpg'),
(76968, 5274, 'Nada é o que Parece Ser S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173899.mp4', 'http://timg.bdta.pro/images/aec424dd4d1ebd8ce2e893aa86f619e3.jpg'),
(76969, 5275, 'Os Empoderados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173874.mp4', 'http://gstaticontent.com/images/02cb9b4f41b5e72f438bdd1af9ce823a.jpg'),
(76970, 5275, 'Os Empoderados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173875.mp4', 'http://gstaticontent.com/images/02cb9b4f41b5e72f438bdd1af9ce823a.jpg'),
(76971, 5275, 'Os Empoderados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173876.mp4', 'http://gstaticontent.com/images/02cb9b4f41b5e72f438bdd1af9ce823a.jpg'),
(76972, 5275, 'Os Empoderados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173877.mp4', 'http://gstaticontent.com/images/02cb9b4f41b5e72f438bdd1af9ce823a.jpg'),
(76973, 5275, 'Os Empoderados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173878.mp4', 'http://gstaticontent.com/images/02cb9b4f41b5e72f438bdd1af9ce823a.jpg'),
(76974, 5275, 'Os Empoderados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173879.mp4', 'http://gstaticontent.com/images/02cb9b4f41b5e72f438bdd1af9ce823a.jpg'),
(76975, 5275, 'Os Empoderados S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173880.mp4', 'http://gstaticontent.com/images/02cb9b4f41b5e72f438bdd1af9ce823a.jpg'),
(76976, 5275, 'Os Empoderados S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173881.mp4', 'http://gstaticontent.com/images/02cb9b4f41b5e72f438bdd1af9ce823a.jpg'),
(76977, 5275, 'Os Empoderados S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173882.mp4', 'http://gstaticontent.com/images/02cb9b4f41b5e72f438bdd1af9ce823a.jpg'),
(76978, 5275, 'Os Empoderados S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173883.mp4', 'http://gstaticontent.com/images/02cb9b4f41b5e72f438bdd1af9ce823a.jpg'),
(76979, 5275, 'Os Empoderados S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173884.mp4', 'http://gstaticontent.com/images/02cb9b4f41b5e72f438bdd1af9ce823a.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(76980, 5275, 'Os Empoderados S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173885.mp4', 'http://gstaticontent.com/images/02cb9b4f41b5e72f438bdd1af9ce823a.jpg'),
(76981, 5275, 'Os Empoderados S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173886.mp4', 'http://gstaticontent.com/images/02cb9b4f41b5e72f438bdd1af9ce823a.jpg'),
(76982, 5275, 'Os Empoderados S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/173887.mp4', 'http://gstaticontent.com/images/02cb9b4f41b5e72f438bdd1af9ce823a.jpg'),
(76983, 5275, 'Os Empoderados S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/173888.mp4', 'http://gstaticontent.com/images/02cb9b4f41b5e72f438bdd1af9ce823a.jpg'),
(76984, 5275, 'Os Empoderados S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/173889.mp4', 'http://gstaticontent.com/images/02cb9b4f41b5e72f438bdd1af9ce823a.jpg'),
(76985, 5275, 'Os Empoderados S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/173890.mp4', 'http://gstaticontent.com/images/02cb9b4f41b5e72f438bdd1af9ce823a.jpg'),
(76986, 5275, 'Os Empoderados S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/173891.mp4', 'http://gstaticontent.com/images/02cb9b4f41b5e72f438bdd1af9ce823a.jpg'),
(76987, 5275, 'Os Empoderados S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/173892.mp4', 'http://gstaticontent.com/images/02cb9b4f41b5e72f438bdd1af9ce823a.jpg'),
(76988, 5275, 'Os Empoderados S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/173893.mp4', 'http://gstaticontent.com/images/02cb9b4f41b5e72f438bdd1af9ce823a.jpg'),
(76989, 5276, 'Os Enviados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248613.mp4', 'http://timg.bdta.pro/images/e8f4c69794ac0ac90aa3919cdda5be84.jpg'),
(76990, 5276, 'Os Enviados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248614.mp4', 'http://timg.bdta.pro/images/730d66c7080780eee5c175cd23d771d7.jpg'),
(76991, 5276, 'Os Enviados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248615.mp4', 'http://timg.bdta.pro/images/506b09d25730346fb1ae22d01d00df4e.jpg'),
(76992, 5276, 'Os Enviados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248616.mp4', 'http://timg.bdta.pro/images/9eb9638e76237aefdbaa7d26c7a75dfb.jpg'),
(76993, 5276, 'Os Enviados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248617.mp4', 'http://timg.bdta.pro/images/d21dbd3d080a7d659858ddb490609d40.jpg'),
(76994, 5276, 'Os Enviados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248618.mp4', 'http://timg.bdta.pro/images/2f78b79fc17d99daf9632962973f9e57.jpg'),
(76995, 5276, 'Os Enviados S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248619.mp4', 'http://timg.bdta.pro/images/a93a2a440a8e46c5fcabc4dc52929ba8.jpg'),
(76996, 5276, 'Os Enviados S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248620.mp4', 'http://timg.bdta.pro/images/f72d82905f7882dc8491e9582605b10b.jpg'),
(76997, 5277, 'Os Enviados S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248621.mp4', 'http://gstaticontent.com/images/a3094b31818223390e551903f903f86e.jpg'),
(76998, 5277, 'Os Enviados S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248622.mp4', 'http://gstaticontent.com/images/a3094b31818223390e551903f903f86e.jpg'),
(76999, 5277, 'Os Enviados S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248623.mp4', 'http://gstaticontent.com/images/a3094b31818223390e551903f903f86e.jpg'),
(77000, 5277, 'Os Enviados S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248624.mp4', 'http://gstaticontent.com/images/a3094b31818223390e551903f903f86e.jpg'),
(77001, 5277, 'Os Enviados S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248625.mp4', 'http://gstaticontent.com/images/a3094b31818223390e551903f903f86e.jpg'),
(77002, 5277, 'Os Enviados S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248626.mp4', 'http://gstaticontent.com/images/a3094b31818223390e551903f903f86e.jpg'),
(77003, 5277, 'Os Enviados S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248627.mp4', 'http://gstaticontent.com/images/a3094b31818223390e551903f903f86e.jpg'),
(77004, 5277, 'Os Enviados S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248628.mp4', 'http://gstaticontent.com/images/a3094b31818223390e551903f903f86e.jpg'),
(77005, 5278, 'PEN15 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173857.mp4', 'http://timg.bdta.pro/images/788223dc36d1df8f2fa02e4666a41af2.jpg'),
(77006, 5278, 'PEN15 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173858.mp4', 'http://timg.bdta.pro/images/fe1a36089c87ba7c644d9514bb115ac7.jpg'),
(77007, 5278, 'PEN15 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173859.mp4', 'http://timg.bdta.pro/images/d9b7801dfe289151dd0a5c56fb5684a3.jpg'),
(77008, 5278, 'PEN15 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173860.mp4', 'http://timg.bdta.pro/images/16dd53c584bb92099ab29540c94fd994.jpg'),
(77009, 5278, 'PEN15 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173861.mp4', 'http://timg.bdta.pro/images/8bab2c207298ac18cbd651854cc12b82.jpg'),
(77010, 5278, 'PEN15 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173862.mp4', 'http://timg.bdta.pro/images/0f0e2749a9f989cd2f7e89e351b903d4.jpg'),
(77011, 5278, 'PEN15 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173863.mp4', 'http://timg.bdta.pro/images/768307a40cba4ceef2d4819db3fc4636.jpg'),
(77012, 5278, 'PEN15 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173864.mp4', 'http://timg.bdta.pro/images/6ccd0576891dcb18bc649e661b8ba4ec.jpg'),
(77013, 5278, 'PEN15 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173865.mp4', 'http://timg.bdta.pro/images/a3d3b53aa3ca6dc5f11b147a250cde55.jpg'),
(77014, 5278, 'PEN15 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173866.mp4', 'http://timg.bdta.pro/images/fa3037c0c51dccd3fb02e01502ba0fcf.jpg'),
(77015, 5279, 'PEN15 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173867.mp4', 'http://timg.bdta.pro/images/71e14d0e6fb649c8e428d8b88d93d1d8.jpg'),
(77016, 5279, 'PEN15 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173868.mp4', 'http://timg.bdta.pro/images/56c0590265efba4fb37258977d8d8b5a.jpg'),
(77017, 5279, 'PEN15 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173869.mp4', 'http://timg.bdta.pro/images/7262fa6f8c20d12e9f4c3621d5b7ef70.jpg'),
(77018, 5279, 'PEN15 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173870.mp4', 'http://timg.bdta.pro/images/ceb743ea842c36e34264f5a3f99b8a69.jpg'),
(77019, 5279, 'PEN15 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173871.mp4', 'http://timg.bdta.pro/images/0b5db3f62688480813e9e48a92b3ce22.jpg'),
(77020, 5279, 'PEN15 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173872.mp4', 'http://timg.bdta.pro/images/d5f10624f7ce70722b4af88db79614e8.jpg'),
(77021, 5279, 'PEN15 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173873.mp4', 'http://timg.bdta.pro/images/eefb29a0bf33b2bac84d1144c1ae9441.jpg'),
(77022, 5280, 'Soy Georgina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208813.mp4', 'http://timg.bdta.pro/images/25c464011106159eed4c96f923fa3e8b.jpg'),
(77023, 5280, 'Soy Georgina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208814.mp4', 'http://timg.bdta.pro/images/d05d5616394849b6d6d7c4fa406c6163.jpg'),
(77024, 5280, 'Soy Georgina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208815.mp4', 'http://timg.bdta.pro/images/ea10082079e52142ae22a1215450469b.jpg'),
(77025, 5280, 'Soy Georgina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208816.mp4', 'http://timg.bdta.pro/images/27e3d1b3214011327f184dce4cf494fd.jpg'),
(77026, 5280, 'Soy Georgina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208817.mp4', 'http://timg.bdta.pro/images/45bdd0e54b642c1cb59fdb202c005def.jpg'),
(77027, 5280, 'Soy Georgina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208818.mp4', 'http://timg.bdta.pro/images/8b11055539e73bf1c1e7e11afb72c8bd.jpg'),
(77028, 5281, 'Soy Georgina S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5uJ32gcbUTs6NIScVTralvVHEjf.jpg'),
(77029, 5281, 'Soy Georgina S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w0L30Sj1ODjHXwfUAEGM6FChJLn.jpg'),
(77030, 5281, 'Soy Georgina S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ylTJ5AoQwuxFgGnlw6uDMeWueWs.jpg'),
(77031, 5281, 'Soy Georgina S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ALSCkgQHHrQFRfMcnkOAHTSAhd.jpg'),
(77032, 5281, 'Soy Georgina S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dsWNmiIJ6cL1Rby17wH6doA6cni.jpg'),
(77033, 5281, 'Soy Georgina S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3jlHu7XC95jPcNTtQwH2Kk9kFqu.jpg'),
(77034, 5282, 'Soy Georgina S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/458947.mp4', 'http://gstaticontent.com/images/7a7ee92ff6aa3a6e2300949c350216c1.jpg'),
(77035, 5282, 'Soy Georgina S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/458948.mp4', 'http://gstaticontent.com/images/7a7ee92ff6aa3a6e2300949c350216c1.jpg'),
(77036, 5282, 'Soy Georgina S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/458949.mp4', 'http://gstaticontent.com/images/7a7ee92ff6aa3a6e2300949c350216c1.jpg'),
(77037, 5282, 'Soy Georgina S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/458950.mp4', 'http://gstaticontent.com/images/7a7ee92ff6aa3a6e2300949c350216c1.jpg'),
(77038, 5282, 'Soy Georgina S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/458951.mp4', 'http://gstaticontent.com/images/7a7ee92ff6aa3a6e2300949c350216c1.jpg'),
(77039, 5282, 'Soy Georgina S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/458952.mp4', 'http://gstaticontent.com/images/7a7ee92ff6aa3a6e2300949c350216c1.jpg'),
(77040, 5283, 'Space Nova: Uma Família Espacial S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173831.mp4', 'http://timg.bdta.pro/images/5ff6dad6a874791a3d6b62277861a44b.jpg'),
(77041, 5283, 'Space Nova: Uma Família Espacial S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173832.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77042, 5283, 'Space Nova: Uma Família Espacial S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173833.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77043, 5283, 'Space Nova: Uma Família Espacial S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173834.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77044, 5283, 'Space Nova: Uma Família Espacial S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173835.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77045, 5283, 'Space Nova: Uma Família Espacial S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173836.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77046, 5283, 'Space Nova: Uma Família Espacial S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173837.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77047, 5283, 'Space Nova: Uma Família Espacial S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173838.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77048, 5283, 'Space Nova: Uma Família Espacial S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173839.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77049, 5283, 'Space Nova: Uma Família Espacial S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173840.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77050, 5283, 'Space Nova: Uma Família Espacial S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173841.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77051, 5283, 'Space Nova: Uma Família Espacial S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173842.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77052, 5283, 'Space Nova: Uma Família Espacial S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173843.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77053, 5283, 'Space Nova: Uma Família Espacial S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/173844.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77054, 5283, 'Space Nova: Uma Família Espacial S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/173845.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77055, 5283, 'Space Nova: Uma Família Espacial S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/173846.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77056, 5283, 'Space Nova: Uma Família Espacial S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/173847.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77057, 5283, 'Space Nova: Uma Família Espacial S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/173848.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77058, 5283, 'Space Nova: Uma Família Espacial S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/173849.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77059, 5283, 'Space Nova: Uma Família Espacial S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/173850.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77060, 5283, 'Space Nova: Uma Família Espacial S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/173851.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77061, 5283, 'Space Nova: Uma Família Espacial S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/173852.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77062, 5283, 'Space Nova: Uma Família Espacial S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/173853.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77063, 5283, 'Space Nova: Uma Família Espacial S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/173854.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77064, 5283, 'Space Nova: Uma Família Espacial S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/173855.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77065, 5283, 'Space Nova: Uma Família Espacial S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/173856.mp4', 'http://gstaticontent.com/images/04b84a5bc83f7d9dd69a3d5b0e88da95.jpg'),
(77066, 5284, 'Star Wars: Ewoks S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173805.mp4', 'http://timg.bdta.pro/images/742a23cb1af4c1ba6c2c166c611c582e.jpg'),
(77067, 5284, 'Star Wars: Ewoks S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173806.mp4', 'http://timg.bdta.pro/images/9116cb49d8ae376b5eb936cd66dbb27c.jpg'),
(77068, 5284, 'Star Wars: Ewoks S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173807.mp4', 'http://timg.bdta.pro/images/157c24b12941131f7acda3e335228d1a.jpg'),
(77069, 5284, 'Star Wars: Ewoks S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173808.mp4', 'http://timg.bdta.pro/images/6e473f3831063f20d179716b580ac974.jpg'),
(77070, 5284, 'Star Wars: Ewoks S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173809.mp4', 'http://timg.bdta.pro/images/f3187e7618399f4ce8d13e08eee23f49.jpg'),
(77071, 5284, 'Star Wars: Ewoks S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173810.mp4', 'http://timg.bdta.pro/images/1e0f7f8210c0ab8043eae6774966fc12.jpg'),
(77072, 5284, 'Star Wars: Ewoks S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173811.mp4', 'http://timg.bdta.pro/images/2df77e2ad0f31eec4bcbb31f8cb2547f.jpg'),
(77073, 5284, 'Star Wars: Ewoks S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173812.mp4', 'http://timg.bdta.pro/images/569817c291231293918f39a043403e33.jpg'),
(77074, 5284, 'Star Wars: Ewoks S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173813.mp4', 'http://timg.bdta.pro/images/40f02793d89238a632a154ef5624ad1f.jpg'),
(77075, 5284, 'Star Wars: Ewoks S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173814.mp4', 'http://timg.bdta.pro/images/e8c63d9831d02ff703ca7949b82623df.jpg'),
(77076, 5284, 'Star Wars: Ewoks S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173815.mp4', 'http://timg.bdta.pro/images/a9a68c337acd80b81e126997544bdccc.jpg'),
(77077, 5284, 'Star Wars: Ewoks S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173816.mp4', 'http://timg.bdta.pro/images/a497aa288c771fc0475fbd5aff1ebcd4.jpg'),
(77078, 5284, 'Star Wars: Ewoks S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173817.mp4', 'http://timg.bdta.pro/images/4d466c98423520db9b3f2ca4ea8242f1.jpg'),
(77079, 5285, 'Star Wars: Ewoks S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173818.mp4', 'http://gstaticontent.com/images/f71eb1af33aeaa54f81cafd99bca91df.jpg'),
(77080, 5285, 'Star Wars: Ewoks S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173819.mp4', 'http://gstaticontent.com/images/f71eb1af33aeaa54f81cafd99bca91df.jpg'),
(77081, 5285, 'Star Wars: Ewoks S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173820.mp4', 'http://gstaticontent.com/images/f71eb1af33aeaa54f81cafd99bca91df.jpg'),
(77082, 5285, 'Star Wars: Ewoks S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173821.mp4', 'http://gstaticontent.com/images/f71eb1af33aeaa54f81cafd99bca91df.jpg'),
(77083, 5285, 'Star Wars: Ewoks S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173822.mp4', 'http://gstaticontent.com/images/f71eb1af33aeaa54f81cafd99bca91df.jpg'),
(77084, 5285, 'Star Wars: Ewoks S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173823.mp4', 'http://gstaticontent.com/images/f71eb1af33aeaa54f81cafd99bca91df.jpg'),
(77085, 5285, 'Star Wars: Ewoks S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173824.mp4', 'http://gstaticontent.com/images/f71eb1af33aeaa54f81cafd99bca91df.jpg'),
(77086, 5285, 'Star Wars: Ewoks S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173825.mp4', 'http://gstaticontent.com/images/f71eb1af33aeaa54f81cafd99bca91df.jpg'),
(77087, 5285, 'Star Wars: Ewoks S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173826.mp4', 'http://gstaticontent.com/images/f71eb1af33aeaa54f81cafd99bca91df.jpg'),
(77088, 5285, 'Star Wars: Ewoks S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173827.mp4', 'http://gstaticontent.com/images/f71eb1af33aeaa54f81cafd99bca91df.jpg'),
(77089, 5285, 'Star Wars: Ewoks S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173828.mp4', 'http://gstaticontent.com/images/f71eb1af33aeaa54f81cafd99bca91df.jpg'),
(77090, 5285, 'Star Wars: Ewoks S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173829.mp4', 'http://gstaticontent.com/images/f71eb1af33aeaa54f81cafd99bca91df.jpg'),
(77091, 5285, 'Star Wars: Ewoks S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173830.mp4', 'http://gstaticontent.com/images/f71eb1af33aeaa54f81cafd99bca91df.jpg'),
(77092, 5286, 'Temporada de Verão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173797.mp4', 'http://timg.bdta.pro/images/4ff5086990bc61f51cad899d66c7d2df.jpg'),
(77093, 5286, 'Temporada de Verão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173798.mp4', 'http://timg.bdta.pro/images/247fb0eb8893d55efb9ad0f2d6805c5b.jpg'),
(77094, 5286, 'Temporada de Verão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173799.mp4', 'http://timg.bdta.pro/images/42a0d5b0e907c3d82b81dfa8e0b692d4.jpg'),
(77095, 5286, 'Temporada de Verão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173800.mp4', 'http://timg.bdta.pro/images/74c6115bb108058badbb7443aa1a3bcc.jpg'),
(77096, 5286, 'Temporada de Verão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173801.mp4', 'http://timg.bdta.pro/images/638220f347ea03a65d4db0b2ba9e95e1.jpg'),
(77097, 5286, 'Temporada de Verão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173802.mp4', 'http://timg.bdta.pro/images/91255cf814ece4f8947eec9a5955ed25.jpg'),
(77098, 5286, 'Temporada de Verão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173803.mp4', 'http://timg.bdta.pro/images/afef3088dda31a02d36c481f57603a74.jpg'),
(77099, 5286, 'Temporada de Verão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173804.mp4', 'http://timg.bdta.pro/images/8ea1e011d9e50e79bb8084b88c7cb90c.jpg'),
(77100, 5287, 'Terra de Gigantes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173746.mp4', 'http://timg.bdta.pro/images/763f03a8e7753affb66bb80c8e9ca2d9.jpg'),
(77101, 5287, 'Terra de Gigantes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173747.mp4', 'http://timg.bdta.pro/images/8f882d26d78159903784b25295a34384.jpg'),
(77102, 5287, 'Terra de Gigantes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173748.mp4', 'http://timg.bdta.pro/images/a652beb7edd1c0b0f234fbaf4c13b3ac.jpg'),
(77103, 5287, 'Terra de Gigantes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173749.mp4', 'http://timg.bdta.pro/images/ca37052adbbab99375b646a92acdd667.jpg'),
(77104, 5287, 'Terra de Gigantes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173750.mp4', 'http://timg.bdta.pro/images/5d12229769dd3a8acd2004f850b077c3.jpg'),
(77105, 5287, 'Terra de Gigantes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173751.mp4', 'http://timg.bdta.pro/images/1542288c91f81a6bf46a247b52c12e56.jpg'),
(77106, 5287, 'Terra de Gigantes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173752.mp4', 'http://timg.bdta.pro/images/32ef3b8667e7c7c340748ec0d7562ad6.jpg'),
(77107, 5287, 'Terra de Gigantes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173753.mp4', 'http://timg.bdta.pro/images/769fae24def6c375fb6e872a567a3acb.jpg'),
(77108, 5287, 'Terra de Gigantes S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173754.mp4', 'http://timg.bdta.pro/images/2754c3073117128d3f0f653fdd90ec51.jpg'),
(77109, 5287, 'Terra de Gigantes S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173755.mp4', 'http://timg.bdta.pro/images/dab38505f56c4fdee4e348e58fdb7ca1.jpg'),
(77110, 5287, 'Terra de Gigantes S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173756.mp4', 'http://timg.bdta.pro/images/15a17ee715bcb05299212bee75d38801.jpg'),
(77111, 5287, 'Terra de Gigantes S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173757.mp4', 'http://timg.bdta.pro/images/7eb001851fa342fec0547fa56220d812.jpg'),
(77112, 5287, 'Terra de Gigantes S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173758.mp4', 'http://timg.bdta.pro/images/d3828958494752a0ef72a5ed665bf694.jpg'),
(77113, 5287, 'Terra de Gigantes S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/173759.mp4', 'http://timg.bdta.pro/images/04e3952869e395da17f38e17cce892d1.jpg'),
(77114, 5287, 'Terra de Gigantes S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/173760.mp4', 'http://timg.bdta.pro/images/806241b7a7b09c87ae508df4daf056a2.jpg'),
(77115, 5287, 'Terra de Gigantes S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/173761.mp4', 'http://timg.bdta.pro/images/a08e0df00459450f6652abf55205b6d9.jpg'),
(77116, 5287, 'Terra de Gigantes S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/173762.mp4', 'http://timg.bdta.pro/images/da2f17a40aab4ad007de23be9e8d07c9.jpg'),
(77117, 5287, 'Terra de Gigantes S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/173763.mp4', 'http://timg.bdta.pro/images/57699c1145eb87a647c9135a64034bf8.jpg'),
(77118, 5287, 'Terra de Gigantes S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/173764.mp4', 'http://timg.bdta.pro/images/cbaef4f371ecee0753fbbeb98fc32cf5.jpg'),
(77119, 5287, 'Terra de Gigantes S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/173765.mp4', 'http://timg.bdta.pro/images/fe16779ee3984055172ada3cd82f9d18.jpg'),
(77120, 5287, 'Terra de Gigantes S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/173766.mp4', 'http://timg.bdta.pro/images/2f8d96f41d04f5bd0aa5e798da13d906.jpg'),
(77121, 5287, 'Terra de Gigantes S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/173767.mp4', 'http://timg.bdta.pro/images/9797f1d60e6e1d6599621be7db7d5ba9.jpg'),
(77122, 5287, 'Terra de Gigantes S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/173768.mp4', 'http://timg.bdta.pro/images/8ffd13ae5bafa0e478849c84eeb26f30.jpg'),
(77123, 5287, 'Terra de Gigantes S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/173769.mp4', 'http://timg.bdta.pro/images/71884b63d4bc778888a9b584e40843a0.jpg'),
(77124, 5287, 'Terra de Gigantes S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/173770.mp4', 'http://timg.bdta.pro/images/5c7da03da54817d000fb7f2e9d9e09dc.jpg'),
(77125, 5287, 'Terra de Gigantes S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/173771.mp4', 'http://timg.bdta.pro/images/15121420db808ef781aaf9f65dd06f3f.jpg'),
(77126, 5288, 'Terra de Gigantes S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173772.mp4', 'http://timg.bdta.pro/images/d94f400dfbda3941926839df7ba95675.jpg'),
(77127, 5288, 'Terra de Gigantes S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173773.mp4', 'http://timg.bdta.pro/images/311bb1cc32cfedefd26dd66ce46ba988.jpg'),
(77128, 5288, 'Terra de Gigantes S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173774.mp4', 'http://timg.bdta.pro/images/bde6e3f030969151eceb91dc69c093c4.jpg'),
(77129, 5288, 'Terra de Gigantes S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173775.mp4', 'http://timg.bdta.pro/images/db9b2b5984e6e214579ebcd4c713bdea.jpg'),
(77130, 5288, 'Terra de Gigantes S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173776.mp4', 'http://timg.bdta.pro/images/a60ce41778ffb3cce3d2480c1d8f3024.jpg'),
(77131, 5288, 'Terra de Gigantes S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173777.mp4', 'http://timg.bdta.pro/images/4294ade50c9e5d4138c1d207bf3a64b1.jpg'),
(77132, 5288, 'Terra de Gigantes S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173778.mp4', 'http://timg.bdta.pro/images/ebb46e831bafdfe38b37c4c170697218.jpg'),
(77133, 5288, 'Terra de Gigantes S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173779.mp4', 'http://timg.bdta.pro/images/5ba310d599b18a7abf19e61959fdc56a.jpg'),
(77134, 5288, 'Terra de Gigantes S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173780.mp4', 'http://timg.bdta.pro/images/77a580c62fd3bcf95fb9caef7366b820.jpg'),
(77135, 5288, 'Terra de Gigantes S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173781.mp4', 'http://timg.bdta.pro/images/953df5bd8627c7970c55352b21659c3d.jpg'),
(77136, 5288, 'Terra de Gigantes S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173782.mp4', 'http://timg.bdta.pro/images/1a601a2447e34ec5a0ddd2077a1150a0.jpg'),
(77137, 5288, 'Terra de Gigantes S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173783.mp4', 'http://timg.bdta.pro/images/8729b3f0337dfb948523c0063b1223ed.jpg'),
(77138, 5288, 'Terra de Gigantes S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173784.mp4', 'http://timg.bdta.pro/images/706a2b9cd504c9748aec87963b4fdcfd.jpg'),
(77139, 5288, 'Terra de Gigantes S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/173785.mp4', 'http://timg.bdta.pro/images/b1226380657162c1ec8a9fca5fcb91bc.jpg'),
(77140, 5288, 'Terra de Gigantes S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/173786.mp4', 'http://timg.bdta.pro/images/1cf486386866c85dd9b494bc000df4e1.jpg'),
(77141, 5288, 'Terra de Gigantes S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/173787.mp4', 'http://timg.bdta.pro/images/548a4142758c1d4004b9f8240ff1b0c8.jpg'),
(77142, 5288, 'Terra de Gigantes S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/173788.mp4', 'http://timg.bdta.pro/images/dd1b9124c51ca9936ab724352260a8b5.jpg'),
(77143, 5288, 'Terra de Gigantes S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/173789.mp4', 'http://timg.bdta.pro/images/048eeab80996383f52657b88466ea5a6.jpg'),
(77144, 5288, 'Terra de Gigantes S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/173790.mp4', 'http://timg.bdta.pro/images/d6aa0a9614959f893d8c0c0879a8a551.jpg'),
(77145, 5288, 'Terra de Gigantes S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/173791.mp4', 'http://timg.bdta.pro/images/7900f0db37aaf31bb790c4bfc58304de.jpg'),
(77146, 5288, 'Terra de Gigantes S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/173792.mp4', 'http://timg.bdta.pro/images/0d2778752c4aab378badb7e86f11b44c.jpg'),
(77147, 5288, 'Terra de Gigantes S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/173793.mp4', 'http://timg.bdta.pro/images/e686c47be977af48645024ceffc609de.jpg'),
(77148, 5288, 'Terra de Gigantes S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/173794.mp4', 'http://timg.bdta.pro/images/11c1d0967d85b1bffa66b6b6f70c7b05.jpg'),
(77149, 5288, 'Terra de Gigantes S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/173795.mp4', 'http://timg.bdta.pro/images/80097532bbdb6e3dd8069766d2e2e5d1.jpg'),
(77150, 5288, 'Terra de Gigantes S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/173796.mp4', 'http://timg.bdta.pro/images/c273e6b9d44b60fb52ac842752b277e7.jpg'),
(77151, 5289, 'The Gloaming S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173379.mp4', 'http://timg.bdta.pro/images/75235b86fa85cb164c3d47a39176c87b.jpg'),
(77152, 5289, 'The Gloaming S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173380.mp4', 'http://timg.bdta.pro/images/38fa97c8d42c22fa8e598ed92168b9f8.jpg'),
(77153, 5289, 'The Gloaming S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173381.mp4', 'http://timg.bdta.pro/images/6d61b10ad8126bc704f130245807a046.jpg'),
(77154, 5289, 'The Gloaming S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173382.mp4', 'http://timg.bdta.pro/images/b850fd54abffe9b4bf7c103202ab0a41.jpg'),
(77155, 5289, 'The Gloaming S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173383.mp4', 'http://timg.bdta.pro/images/15818915181d8bcd04f960c9c98fffc0.jpg'),
(77156, 5289, 'The Gloaming S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173384.mp4', 'http://timg.bdta.pro/images/66ede8611f8fafe9d16547041fa38682.jpg'),
(77157, 5289, 'The Gloaming S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173385.mp4', 'http://timg.bdta.pro/images/864b5ba73b244f30c1b37e8d538c207c.jpg'),
(77158, 5289, 'The Gloaming S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173386.mp4', 'http://timg.bdta.pro/images/24047b48b673f135a516558f7a8ce60b.jpg'),
(77159, 5290, 'The Leftovers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173718.mp4', 'http://timg.bdta.pro/images/51ec2e9c0d5db40e184be5784cc0fba5.jpg'),
(77160, 5290, 'The Leftovers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173719.mp4', 'http://timg.bdta.pro/images/395a904e028d799fc9ec3b2964023f65.jpg'),
(77161, 5290, 'The Leftovers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173720.mp4', 'http://timg.bdta.pro/images/ff3dbb7b9a5aca42a3537e5d7d937808.jpg'),
(77162, 5290, 'The Leftovers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173721.mp4', 'http://timg.bdta.pro/images/53a5fa6be7240e2054227ad68597a107.jpg'),
(77163, 5290, 'The Leftovers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173722.mp4', 'http://timg.bdta.pro/images/19c44990d5edc651ec80f6f416bcceb4.jpg'),
(77164, 5290, 'The Leftovers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173723.mp4', 'http://timg.bdta.pro/images/7f2e2ae2ac7bc9e986c48fe0e2373591.jpg'),
(77165, 5290, 'The Leftovers S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173724.mp4', 'http://timg.bdta.pro/images/85baf17395115e89771623dfdd5a9559.jpg'),
(77166, 5290, 'The Leftovers S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173725.mp4', 'http://timg.bdta.pro/images/ec2131915cc6c1c67a243fd2507a3745.jpg'),
(77167, 5290, 'The Leftovers S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173726.mp4', 'http://timg.bdta.pro/images/cfa1d8ddaebe10d2a0e663a8d98ae1b6.jpg'),
(77168, 5290, 'The Leftovers S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173727.mp4', 'http://timg.bdta.pro/images/3ecaef5dbfeba2d93a28325e8f646d46.jpg'),
(77169, 5291, 'The Leftovers S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173728.mp4', 'http://timg.bdta.pro/images/03b8836ca6b386524731be5c4b18dc55.jpg'),
(77170, 5291, 'The Leftovers S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173729.mp4', 'http://timg.bdta.pro/images/e8a5a183853da8e3601e60e1cea91bc9.jpg'),
(77171, 5291, 'The Leftovers S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173730.mp4', 'http://timg.bdta.pro/images/9c7083c20672c8cfe31200fbd044fe24.jpg'),
(77172, 5291, 'The Leftovers S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173731.mp4', 'http://timg.bdta.pro/images/7f739ca828d035651faba411f992fde5.jpg'),
(77173, 5291, 'The Leftovers S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173732.mp4', 'http://timg.bdta.pro/images/c0ddc982196121380f697c8aad1256a6.jpg'),
(77174, 5291, 'The Leftovers S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173733.mp4', 'http://timg.bdta.pro/images/a717e1402ba28a64e210a96c11f186d3.jpg'),
(77175, 5291, 'The Leftovers S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173734.mp4', 'http://timg.bdta.pro/images/66a0975e2e720d4afe14d20d241c78d0.jpg'),
(77176, 5291, 'The Leftovers S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173735.mp4', 'http://timg.bdta.pro/images/8b482592e99bbc3f3cdc21ade944854d.jpg'),
(77177, 5291, 'The Leftovers S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173736.mp4', 'http://timg.bdta.pro/images/2fd21ec9bfe75897621007b4c34edea5.jpg'),
(77178, 5291, 'The Leftovers S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173737.mp4', 'http://timg.bdta.pro/images/fa4a85651f1b0801dd9faa91094ac61d.jpg'),
(77179, 5292, 'The Leftovers S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173738.mp4', 'http://timg.bdta.pro/images/1ac6d924df89d28ba262ef0998fae9c2.jpg'),
(77180, 5292, 'The Leftovers S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173739.mp4', 'http://timg.bdta.pro/images/6a4ae6d4888f888112352857a836dbf8.jpg'),
(77181, 5292, 'The Leftovers S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173740.mp4', 'http://timg.bdta.pro/images/2354e6df38be48a51b6fc78e8d1eaa51.jpg'),
(77182, 5292, 'The Leftovers S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173741.mp4', 'http://timg.bdta.pro/images/0f0dbd6f7a9bbb2ebbf3e59daa67dd9b.jpg'),
(77183, 5292, 'The Leftovers S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173742.mp4', 'http://timg.bdta.pro/images/8a3d883524dc3b22279b6de1f9713b08.jpg'),
(77184, 5292, 'The Leftovers S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173743.mp4', 'http://timg.bdta.pro/images/d2fcb599ad11d8a52704efd0d6c26bf1.jpg'),
(77185, 5292, 'The Leftovers S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173744.mp4', 'http://timg.bdta.pro/images/98ca6b091651d70565bfa8b2ddb077f9.jpg'),
(77186, 5292, 'The Leftovers S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173745.mp4', 'http://timg.bdta.pro/images/7e155b351af4bacaab9d3ae61665791a.jpg'),
(77187, 5293, 'The Premise S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173713.mp4', 'http://timg.bdta.pro/images/1b4562d3fc0eaff510b3f82052f61a73.jpg'),
(77188, 5293, 'The Premise S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173714.mp4', 'http://timg.bdta.pro/images/1287b8ecfe2fbe910df2ed28f7803faa.jpg'),
(77189, 5293, 'The Premise S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173715.mp4', 'http://timg.bdta.pro/images/fcf5c21fbc00fcd55fb62b7d925f4fbc.jpg'),
(77190, 5293, 'The Premise S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173716.mp4', 'http://timg.bdta.pro/images/657dda88fc8ebdf92059d0f4f90ef584.jpg'),
(77191, 5293, 'The Premise S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173717.mp4', 'http://timg.bdta.pro/images/bdf1722c87e9a7245f9b1c875d6b114e.jpg'),
(77192, 5294, 'Upright S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173705.mp4', 'http://timg.bdta.pro/images/a8d5d9942f3118801b3045727ff3be79.jpg'),
(77193, 5294, 'Upright S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173706.mp4', 'http://timg.bdta.pro/images/c90ce657cd7d1f4a53e546e6346151c2.jpg'),
(77194, 5294, 'Upright S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173707.mp4', 'http://timg.bdta.pro/images/acfea9eb5d7a4bb9a7bad85d4bfc0f90.jpg'),
(77195, 5294, 'Upright S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173708.mp4', 'http://timg.bdta.pro/images/ec0691ab87c720c9e0ecd81b2498b0b9.jpg'),
(77196, 5294, 'Upright S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173709.mp4', 'http://timg.bdta.pro/images/e5c738eda40fc3421e0cd3f5ac69e313.jpg'),
(77197, 5294, 'Upright S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173710.mp4', 'http://timg.bdta.pro/images/fe04710fefd3954bbd1ee757b7df4480.jpg'),
(77198, 5294, 'Upright S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173711.mp4', 'http://timg.bdta.pro/images/1a2d6fec0a137aa908b7cabf29129a50.jpg'),
(77199, 5294, 'Upright S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173712.mp4', 'http://timg.bdta.pro/images/7f6dae7ff168cafa72d487eea639c12e.jpg'),
(77200, 5295, 'Upright S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445517.mp4', 'http://gstaticontent.com/images/40a860e03c1e2979c7ed0b6bb27453a1.jpg'),
(77201, 5295, 'Upright S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445518.mp4', 'http://gstaticontent.com/images/40a860e03c1e2979c7ed0b6bb27453a1.jpg'),
(77202, 5295, 'Upright S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445519.mp4', 'http://gstaticontent.com/images/40a860e03c1e2979c7ed0b6bb27453a1.jpg'),
(77203, 5295, 'Upright S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445520.mp4', 'http://gstaticontent.com/images/40a860e03c1e2979c7ed0b6bb27453a1.jpg'),
(77204, 5295, 'Upright S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445521.mp4', 'http://gstaticontent.com/images/40a860e03c1e2979c7ed0b6bb27453a1.jpg'),
(77205, 5295, 'Upright S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445522.mp4', 'http://gstaticontent.com/images/40a860e03c1e2979c7ed0b6bb27453a1.jpg'),
(77206, 5295, 'Upright S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445523.mp4', 'http://gstaticontent.com/images/40a860e03c1e2979c7ed0b6bb27453a1.jpg'),
(77207, 5295, 'Upright S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445524.mp4', 'http://gstaticontent.com/images/40a860e03c1e2979c7ed0b6bb27453a1.jpg'),
(77208, 5296, 'We Are Who We Are S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173697.mp4', 'http://timg.bdta.pro/images/5a99edc915f031791285322cebc5d509.jpg'),
(77209, 5296, 'We Are Who We Are S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173698.mp4', 'http://timg.bdta.pro/images/bb3ee6a9959e1138861f0696e09d5b9e.jpg'),
(77210, 5296, 'We Are Who We Are S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173699.mp4', 'http://timg.bdta.pro/images/b1a3b0b560485228de8802fd20823926.jpg'),
(77211, 5296, 'We Are Who We Are S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173700.mp4', 'http://timg.bdta.pro/images/5795fda2cc214945d49800649e2e4060.jpg'),
(77212, 5296, 'We Are Who We Are S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173701.mp4', 'http://timg.bdta.pro/images/dcd8d6652113e6e45ac9506509276f14.jpg'),
(77213, 5296, 'We Are Who We Are S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173702.mp4', 'http://timg.bdta.pro/images/24091658c5d303cea249021ec84e6a1d.jpg'),
(77214, 5296, 'We Are Who We Are S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173703.mp4', 'http://timg.bdta.pro/images/51cfddf8d78c4378148cf04a6ce09642.jpg'),
(77215, 5296, 'We Are Who We Are S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173704.mp4', 'http://timg.bdta.pro/images/c3d93e1cf80406fcff269b93404a8d8b.jpg'),
(77216, 5297, 'Café com Aroma de Mulher [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173291.mp4', 'http://timg.bdta.pro/images/4179b6fe0e8b07d6339af821b357b9b4.jpg'),
(77217, 5297, 'Café com Aroma de Mulher [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173292.mp4', 'http://timg.bdta.pro/images/73d06f92f04addb97a6b2474c844d20b.jpg'),
(77218, 5297, 'Café com Aroma de Mulher [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173293.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77219, 5297, 'Café com Aroma de Mulher [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173294.mp4', 'http://timg.bdta.pro/images/a1bc5f4a693fa2152dfd43d2059595f3.jpg'),
(77220, 5297, 'Café com Aroma de Mulher [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173295.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77221, 5297, 'Café com Aroma de Mulher [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173296.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77222, 5297, 'Café com Aroma de Mulher [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173297.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77223, 5297, 'Café com Aroma de Mulher [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173298.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77224, 5297, 'Café com Aroma de Mulher [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173299.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77225, 5297, 'Café com Aroma de Mulher [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173300.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77226, 5297, 'Café com Aroma de Mulher [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173301.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77227, 5297, 'Café com Aroma de Mulher [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173302.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77228, 5297, 'Café com Aroma de Mulher [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173303.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77229, 5297, 'Café com Aroma de Mulher [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/173304.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77230, 5297, 'Café com Aroma de Mulher [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/173305.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77231, 5297, 'Café com Aroma de Mulher [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/173306.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77232, 5297, 'Café com Aroma de Mulher [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/173307.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77233, 5297, 'Café com Aroma de Mulher [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/173308.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77234, 5297, 'Café com Aroma de Mulher [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/173309.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77235, 5297, 'Café com Aroma de Mulher [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/173310.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77236, 5297, 'Café com Aroma de Mulher [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/173311.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77237, 5297, 'Café com Aroma de Mulher [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/173312.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77238, 5297, 'Café com Aroma de Mulher [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/173313.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77239, 5297, 'Café com Aroma de Mulher [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/173314.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77240, 5297, 'Café com Aroma de Mulher [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/173315.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77241, 5297, 'Café com Aroma de Mulher [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/173316.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77242, 5297, 'Café com Aroma de Mulher [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/173317.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77243, 5297, 'Café com Aroma de Mulher [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/173318.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77244, 5297, 'Café com Aroma de Mulher [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/173319.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77245, 5297, 'Café com Aroma de Mulher [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/173320.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77246, 5297, 'Café com Aroma de Mulher [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/173321.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77247, 5297, 'Café com Aroma de Mulher [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/173322.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77248, 5297, 'Café com Aroma de Mulher [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/173323.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77249, 5297, 'Café com Aroma de Mulher [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/173324.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77250, 5297, 'Café com Aroma de Mulher [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/173325.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77251, 5297, 'Café com Aroma de Mulher [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/173326.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77252, 5297, 'Café com Aroma de Mulher [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/173327.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77253, 5297, 'Café com Aroma de Mulher [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/173328.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77254, 5297, 'Café com Aroma de Mulher [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/173329.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77255, 5297, 'Café com Aroma de Mulher [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/173330.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77256, 5297, 'Café com Aroma de Mulher [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/173331.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77257, 5297, 'Café com Aroma de Mulher [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/173332.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77258, 5297, 'Café com Aroma de Mulher [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/173333.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77259, 5297, 'Café com Aroma de Mulher [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/173334.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77260, 5297, 'Café com Aroma de Mulher [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/173335.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(77261, 5297, 'Café com Aroma de Mulher [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/173336.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77262, 5297, 'Café com Aroma de Mulher [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/173337.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77263, 5297, 'Café com Aroma de Mulher [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/173338.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77264, 5297, 'Café com Aroma de Mulher [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/173339.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77265, 5297, 'Café com Aroma de Mulher [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/173340.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77266, 5297, 'Café com Aroma de Mulher [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/173341.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77267, 5297, 'Café com Aroma de Mulher [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/173342.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77268, 5297, 'Café com Aroma de Mulher [L] S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/173343.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77269, 5297, 'Café com Aroma de Mulher [L] S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/173344.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77270, 5297, 'Café com Aroma de Mulher [L] S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/173345.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77271, 5297, 'Café com Aroma de Mulher [L] S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/173346.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77272, 5297, 'Café com Aroma de Mulher [L] S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/173347.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77273, 5297, 'Café com Aroma de Mulher [L] S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/173348.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77274, 5297, 'Café com Aroma de Mulher [L] S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/173349.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77275, 5297, 'Café com Aroma de Mulher [L] S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/173350.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77276, 5297, 'Café com Aroma de Mulher [L] S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/173351.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77277, 5297, 'Café com Aroma de Mulher [L] S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/173352.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77278, 5297, 'Café com Aroma de Mulher [L] S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/173353.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77279, 5297, 'Café com Aroma de Mulher [L] S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/173354.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77280, 5297, 'Café com Aroma de Mulher [L] S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/173355.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77281, 5297, 'Café com Aroma de Mulher [L] S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/173356.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77282, 5297, 'Café com Aroma de Mulher [L] S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/173357.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77283, 5297, 'Café com Aroma de Mulher [L] S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/173358.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77284, 5297, 'Café com Aroma de Mulher [L] S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/173359.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77285, 5297, 'Café com Aroma de Mulher [L] S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/173360.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77286, 5297, 'Café com Aroma de Mulher [L] S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/173361.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77287, 5297, 'Café com Aroma de Mulher [L] S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/173362.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77288, 5297, 'Café com Aroma de Mulher [L] S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/173363.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77289, 5297, 'Café com Aroma de Mulher [L] S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/173364.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77290, 5297, 'Café com Aroma de Mulher [L] S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/173365.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77291, 5297, 'Café com Aroma de Mulher [L] S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/173366.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77292, 5297, 'Café com Aroma de Mulher [L] S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/173367.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77293, 5297, 'Café com Aroma de Mulher [L] S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/173368.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77294, 5297, 'Café com Aroma de Mulher [L] S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/173369.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77295, 5297, 'Café com Aroma de Mulher [L] S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/173370.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77296, 5297, 'Café com Aroma de Mulher [L] S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/173371.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77297, 5297, 'Café com Aroma de Mulher [L] S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/173372.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77298, 5297, 'Café com Aroma de Mulher [L] S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/173373.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77299, 5297, 'Café com Aroma de Mulher [L] S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/173374.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77300, 5297, 'Café com Aroma de Mulher [L] S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/173375.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77301, 5297, 'Café com Aroma de Mulher [L] S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/173376.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77302, 5297, 'Café com Aroma de Mulher [L] S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/173377.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77303, 5297, 'Café com Aroma de Mulher [L] S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/173378.mp4', 'http://gstaticontent.com/images/f8de2e1e03a20ac19a00ca86278c1760.jpg'),
(77304, 5298, 'Neymar: O Caos Perfeito S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173288.mp4', 'http://timg.bdta.pro/images/28c4f5e2e69d98e0e0b216ee9cf0e845.jpg'),
(77305, 5298, 'Neymar: O Caos Perfeito S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173289.mp4', 'http://timg.bdta.pro/images/0999ecba8870976b0bc2d32c6ebeeb75.jpg'),
(77306, 5298, 'Neymar: O Caos Perfeito S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173290.mp4', 'http://timg.bdta.pro/images/1453e3cf305a716525cf64432bfc6ebb.jpg'),
(77307, 5299, 'À Tona S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173280.mp4', 'http://timg.bdta.pro/images/187a47f94a01ef5b8a87455fa68d4bec.jpg'),
(77308, 5299, 'À Tona S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173281.mp4', 'http://timg.bdta.pro/images/f052deedc472975852d01f6cb131a70a.jpg'),
(77309, 5299, 'À Tona S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173282.mp4', 'http://timg.bdta.pro/images/2edd65499da425eece1e9a566431bfec.jpg'),
(77310, 5299, 'À Tona S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173283.mp4', 'http://timg.bdta.pro/images/e448901df23930679aca5e94e5a4bf50.jpg'),
(77311, 5299, 'À Tona S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173284.mp4', 'http://timg.bdta.pro/images/4829ec055b766cdc2cc2bc215c588444.jpg'),
(77312, 5299, 'À Tona S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173285.mp4', 'http://timg.bdta.pro/images/14d7187f084b2a4d9912791c37b68821.jpg'),
(77313, 5299, 'À Tona S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173286.mp4', 'http://timg.bdta.pro/images/3880e736cc78d3487e58b6ae56307e71.jpg'),
(77314, 5299, 'À Tona S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173287.mp4', 'http://timg.bdta.pro/images/e00256c0f102c54a1bb2dafe097ef87f.jpg'),
(77315, 5300, 'Amor para Recomeçar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173274.mp4', 'http://timg.bdta.pro/images/f6b3c7fc47bcb6a2df3e46f84f29843f.jpg'),
(77316, 5300, 'Amor para Recomeçar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173275.mp4', 'http://timg.bdta.pro/images/5e1eae7a5f76231b0c2b90d9e450563d.jpg'),
(77317, 5300, 'Amor para Recomeçar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173276.mp4', 'http://timg.bdta.pro/images/00b4a8b0b264c6f6386c829762634414.jpg'),
(77318, 5300, 'Amor para Recomeçar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173277.mp4', 'http://timg.bdta.pro/images/0993d03925859069d573424e9ecbe929.jpg'),
(77319, 5300, 'Amor para Recomeçar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173278.mp4', 'http://timg.bdta.pro/images/877b9a8fe01b3e7a82897279e7f2eeb6.jpg'),
(77320, 5300, 'Amor para Recomeçar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173279.mp4', 'http://timg.bdta.pro/images/59b8597b0c2c1ffcaba736bdfa62b554.jpg'),
(77321, 5301, 'And Just Like That... Um novo capítulo de Sex and the City S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227982.mp4', 'http://timg.bdta.pro/images/42cec0368a3725e2ae932c3309027fed.jpg'),
(77322, 5301, 'And Just Like That... Um novo capítulo de Sex and the City S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227983.mp4', 'http://timg.bdta.pro/images/fad6cf10bd6596a0ec94693a2b977eb8.jpg'),
(77323, 5301, 'And Just Like That... Um novo capítulo de Sex and the City S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227984.mp4', 'http://timg.bdta.pro/images/428a0947cfd38ddd27bdc2910beb04ee.jpg'),
(77324, 5301, 'And Just Like That... Um novo capítulo de Sex and the City S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227985.mp4', 'http://timg.bdta.pro/images/36bba86c3562f6d76b7864b65e0f37d0.jpg'),
(77325, 5301, 'And Just Like That... Um novo capítulo de Sex and the City S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227986.mp4', 'http://timg.bdta.pro/images/187be6359ecf6fa283ae046d51ff8b0b.jpg'),
(77326, 5301, 'And Just Like That... Um novo capítulo de Sex and the City S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227987.mp4', 'http://timg.bdta.pro/images/047a0fbaa6e3ab9c3953cc2eb2af3095.jpg'),
(77327, 5301, 'And Just Like That... Um novo capítulo de Sex and the City S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227988.mp4', 'http://timg.bdta.pro/images/d5570668c8dbcbf6b0a1edbf63439cf9.jpg'),
(77328, 5301, 'And Just Like That... Um novo capítulo de Sex and the City S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227989.mp4', 'http://timg.bdta.pro/images/8b8bcf60487f11b5679d0a16ad3b0864.jpg'),
(77329, 5301, 'And Just Like That... Um novo capítulo de Sex and the City S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227990.mp4', 'http://timg.bdta.pro/images/b473c1d41e028f0de3195d125d4b49f8.jpg'),
(77330, 5301, 'And Just Like That... Um novo capítulo de Sex and the City S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227991.mp4', 'http://timg.bdta.pro/images/49d77d49b887dca25580e4f7961b1098.jpg'),
(77331, 5302, 'And Just Like That... Um novo capítulo de Sex and the City S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8RsM7GstlsszfwFkAvShH4eFfeV.jpg'),
(77332, 5302, 'And Just Like That... Um novo capítulo de Sex and the City S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Nd44XN72bSnlF7MSwz94rBh39w.jpg'),
(77333, 5302, 'And Just Like That... Um novo capítulo de Sex and the City S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLqT1SVfzt8RkxcN6HATtT2P5gm.jpg'),
(77334, 5302, 'And Just Like That... Um novo capítulo de Sex and the City S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227995.mp4', 'http://image.tmdb.org/t/p/w1280/xOo4PyScwhwYaDXRWBEEjWN7fSA.jpg'),
(77335, 5302, 'And Just Like That... Um novo capítulo de Sex and the City S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227996.mp4', 'http://image.tmdb.org/t/p/w1280/1zSdL2IzgLWB2fJRCfe7yhKhSOx.jpg'),
(77336, 5302, 'And Just Like That... Um novo capítulo de Sex and the City S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227997.mp4', 'http://image.tmdb.org/t/p/w1280/AlnjfDjwHuznpBnloCB10fld843.jpg'),
(77337, 5302, 'And Just Like That... Um novo capítulo de Sex and the City S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227998.mp4', 'http://image.tmdb.org/t/p/w1280/1sfG4xcwQtBZHbNGpjVmFQvqFj0.jpg'),
(77338, 5302, 'And Just Like That... Um novo capítulo de Sex and the City S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227999.mp4', 'http://image.tmdb.org/t/p/w1280/A97E5q10EVMRZYsdIpj0x9Af5kb.jpg'),
(77339, 5302, 'And Just Like That... Um novo capítulo de Sex and the City S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228000.mp4', 'http://gstaticontent.com/images/487381443f00d24e0e701e1aa4e1f084.jpg'),
(77340, 5302, 'And Just Like That... Um novo capítulo de Sex and the City S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228001.mp4', 'http://image.tmdb.org/t/p/w1280/eWoMCBiOkntQiCxGPZtmWfogKxT.jpg'),
(77341, 5302, 'And Just Like That... Um novo capítulo de Sex and the City S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228002.mp4', 'http://image.tmdb.org/t/p/w1280/t4JWxNrBbmMHoIYCfZ1LKDuOGnu.jpg'),
(77342, 5303, 'And Just Like That... Um novo capítulo de Sex and the City S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/822739.mp4', 'http://gstaticontent.com/images/487381443f00d24e0e701e1aa4e1f084.jpg'),
(77343, 5303, 'And Just Like That... Um novo capítulo de Sex and the City S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/828205.mp4', 'http://gstaticontent.com/images/487381443f00d24e0e701e1aa4e1f084.jpg'),
(77344, 5303, 'And Just Like That... Um novo capítulo de Sex and the City S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/847781.mp4', 'http://gstaticontent.com/images/487381443f00d24e0e701e1aa4e1f084.jpg'),
(77345, 5303, 'And Just Like That... Um novo capítulo de Sex and the City S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/847782.mp4', 'http://gstaticontent.com/images/487381443f00d24e0e701e1aa4e1f084.jpg'),
(77346, 5303, 'And Just Like That... Um novo capítulo de Sex and the City S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/855184.mp4', 'http://gstaticontent.com/images/487381443f00d24e0e701e1aa4e1f084.jpg'),
(77347, 5303, 'And Just Like That... Um novo capítulo de Sex and the City S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/856493.mp4', 'http://gstaticontent.com/images/487381443f00d24e0e701e1aa4e1f084.jpg'),
(77348, 5303, 'And Just Like That... Um novo capítulo de Sex and the City S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/865796.mp4', 'http://gstaticontent.com/images/487381443f00d24e0e701e1aa4e1f084.jpg'),
(77349, 5303, 'And Just Like That... Um novo capítulo de Sex and the City S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/870967.mp4', 'http://gstaticontent.com/images/487381443f00d24e0e701e1aa4e1f084.jpg'),
(77350, 5303, 'And Just Like That... Um novo capítulo de Sex and the City S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/878509.mp4', 'http://gstaticontent.com/images/487381443f00d24e0e701e1aa4e1f084.jpg'),
(77351, 5303, 'And Just Like That... Um novo capítulo de Sex and the City S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/879439.mp4', 'http://gstaticontent.com/images/487381443f00d24e0e701e1aa4e1f084.jpg'),
(77352, 5303, 'And Just Like That... Um novo capítulo de Sex and the City S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/880611.mp4', 'http://gstaticontent.com/images/487381443f00d24e0e701e1aa4e1f084.jpg'),
(77353, 5303, 'And Just Like That... Um novo capítulo de Sex and the City S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/880612.mp4', 'http://gstaticontent.com/images/487381443f00d24e0e701e1aa4e1f084.jpg'),
(77354, 5304, 'Angela Black S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173268.mp4', 'http://timg.bdta.pro/images/8caa12e3221018802cce4644500e707f.jpg'),
(77355, 5304, 'Angela Black S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173269.mp4', 'http://timg.bdta.pro/images/6387d06c0df6ac008d2d09d3d2064aae.jpg'),
(77356, 5304, 'Angela Black S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173270.mp4', 'http://timg.bdta.pro/images/d6291a61ac0200ee33d804423872105e.jpg'),
(77357, 5304, 'Angela Black S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173271.mp4', 'http://timg.bdta.pro/images/fba177a432dc9f7d209a60c8ac803d58.jpg'),
(77358, 5304, 'Angela Black S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173272.mp4', 'http://timg.bdta.pro/images/7c59c636bfc71aa9fcb1f3b8c82ff90c.jpg'),
(77359, 5304, 'Angela Black S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173273.mp4', 'http://timg.bdta.pro/images/9904d82f0b2b0dc685a9c2a0378fc4bb.jpg'),
(77360, 5305, 'Boruto: Naruto Next Generations S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173216.mp4', 'http://timg.bdta.pro/images/e2afe9a8b6c54e8473aee0a7305e6a8c.jpg'),
(77361, 5305, 'Boruto: Naruto Next Generations S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173217.mp4', 'http://timg.bdta.pro/images/b2a2becf4f715659b0b7b211b83eb7fb.jpg'),
(77362, 5305, 'Boruto: Naruto Next Generations S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173218.mp4', 'http://timg.bdta.pro/images/fd59a0afb8561175257553b67ac5fc57.jpg'),
(77363, 5305, 'Boruto: Naruto Next Generations S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173219.mp4', 'http://timg.bdta.pro/images/410cf0edd91df3a0b705456a1734d3c3.jpg'),
(77364, 5305, 'Boruto: Naruto Next Generations S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173220.mp4', 'http://timg.bdta.pro/images/de934e9cf4abc823603a0db11942a19e.jpg'),
(77365, 5305, 'Boruto: Naruto Next Generations S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173221.mp4', 'http://timg.bdta.pro/images/8208379f126d2e611ed87cbe50b67d65.jpg'),
(77366, 5305, 'Boruto: Naruto Next Generations S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173222.mp4', 'http://timg.bdta.pro/images/ded2a2b9053fee8e180ef91cb2943fa0.jpg'),
(77367, 5305, 'Boruto: Naruto Next Generations S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173223.mp4', 'http://timg.bdta.pro/images/976dd850b745e09a2c22c39382c80bb8.jpg'),
(77368, 5305, 'Boruto: Naruto Next Generations S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173224.mp4', 'http://timg.bdta.pro/images/838639b5a0a9efa319afe7d4eb3328ed.jpg'),
(77369, 5305, 'Boruto: Naruto Next Generations S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173225.mp4', 'http://timg.bdta.pro/images/bd1ab2d3be7fc922c3d2cff5e60d28a8.jpg'),
(77370, 5305, 'Boruto: Naruto Next Generations S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173226.mp4', 'http://timg.bdta.pro/images/f4f512469919ae4e6d85eb866edaac8e.jpg'),
(77371, 5305, 'Boruto: Naruto Next Generations S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173227.mp4', 'http://timg.bdta.pro/images/515fa65eed958c71af3576bf9ae4edb4.jpg'),
(77372, 5305, 'Boruto: Naruto Next Generations S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173228.mp4', 'http://timg.bdta.pro/images/3e6cf7898e1a1d2c471f95ea753881ec.jpg'),
(77373, 5305, 'Boruto: Naruto Next Generations S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/173229.mp4', 'http://timg.bdta.pro/images/a606ca81f6faa3d402d9ded7eb03b41c.jpg'),
(77374, 5305, 'Boruto: Naruto Next Generations S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/173230.mp4', 'http://timg.bdta.pro/images/85b411c235dad434e9666c89a6a41218.jpg'),
(77375, 5305, 'Boruto: Naruto Next Generations S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/173231.mp4', 'http://timg.bdta.pro/images/58c8d60c862b2bc65f3bf36047334649.jpg'),
(77376, 5305, 'Boruto: Naruto Next Generations S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/173232.mp4', 'http://timg.bdta.pro/images/ca8533592fcbe714f73c3986b4e7257e.jpg'),
(77377, 5305, 'Boruto: Naruto Next Generations S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/173233.mp4', 'http://timg.bdta.pro/images/f6bae80bb4becef9d324751fb5e6e002.jpg'),
(77378, 5305, 'Boruto: Naruto Next Generations S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/173234.mp4', 'http://timg.bdta.pro/images/2e546d2bf4945c5e69fd15c520cae842.jpg'),
(77379, 5305, 'Boruto: Naruto Next Generations S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/173235.mp4', 'http://timg.bdta.pro/images/1f294d892f7474376595d44510e76330.jpg'),
(77380, 5305, 'Boruto: Naruto Next Generations S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/173236.mp4', 'http://timg.bdta.pro/images/fd12eecb6a209948d78aca73c70dbc5d.jpg'),
(77381, 5305, 'Boruto: Naruto Next Generations S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/173237.mp4', 'http://timg.bdta.pro/images/57f57815d75e3302c277ce700eb1b517.jpg'),
(77382, 5305, 'Boruto: Naruto Next Generations S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/173238.mp4', 'http://timg.bdta.pro/images/485e17d1a44b9c3d533571069713b9dc.jpg'),
(77383, 5305, 'Boruto: Naruto Next Generations S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/173239.mp4', 'http://timg.bdta.pro/images/de03b335a48942a0dcc12f26a2d0bafb.jpg'),
(77384, 5305, 'Boruto: Naruto Next Generations S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/173240.mp4', 'http://timg.bdta.pro/images/edbc16eaef56b664469101a019aad85a.jpg'),
(77385, 5305, 'Boruto: Naruto Next Generations S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/173241.mp4', 'http://timg.bdta.pro/images/94e4880f4821c5271157b4957e8ab009.jpg'),
(77386, 5306, 'Boruto: Naruto Next Generations S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173242.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77387, 5306, 'Boruto: Naruto Next Generations S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173243.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77388, 5306, 'Boruto: Naruto Next Generations S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173244.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77389, 5306, 'Boruto: Naruto Next Generations S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173245.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77390, 5306, 'Boruto: Naruto Next Generations S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173246.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77391, 5306, 'Boruto: Naruto Next Generations S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173247.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77392, 5306, 'Boruto: Naruto Next Generations S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173248.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77393, 5306, 'Boruto: Naruto Next Generations S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173249.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77394, 5306, 'Boruto: Naruto Next Generations S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173250.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77395, 5306, 'Boruto: Naruto Next Generations S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173251.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77396, 5306, 'Boruto: Naruto Next Generations S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173252.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77397, 5306, 'Boruto: Naruto Next Generations S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173253.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77398, 5306, 'Boruto: Naruto Next Generations S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173254.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77399, 5306, 'Boruto: Naruto Next Generations S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/173255.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77400, 5306, 'Boruto: Naruto Next Generations S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/173256.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77401, 5306, 'Boruto: Naruto Next Generations S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/173257.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77402, 5306, 'Boruto: Naruto Next Generations S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/173258.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77403, 5306, 'Boruto: Naruto Next Generations S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/173259.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77404, 5306, 'Boruto: Naruto Next Generations S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/173260.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77405, 5306, 'Boruto: Naruto Next Generations S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/173261.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77406, 5306, 'Boruto: Naruto Next Generations S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/173262.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77407, 5306, 'Boruto: Naruto Next Generations S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/173263.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77408, 5306, 'Boruto: Naruto Next Generations S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/173264.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77409, 5306, 'Boruto: Naruto Next Generations S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/173265.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77410, 5306, 'Boruto: Naruto Next Generations S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/173266.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77411, 5306, 'Boruto: Naruto Next Generations S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/173267.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77412, 5307, 'Boruto: Naruto Next Generations S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/814952.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77413, 5307, 'Boruto: Naruto Next Generations S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/814953.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77414, 5307, 'Boruto: Naruto Next Generations S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/814954.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77415, 5307, 'Boruto: Naruto Next Generations S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/814955.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77416, 5307, 'Boruto: Naruto Next Generations S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/814956.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77417, 5307, 'Boruto: Naruto Next Generations S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/814957.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77418, 5307, 'Boruto: Naruto Next Generations S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/814958.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77419, 5307, 'Boruto: Naruto Next Generations S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/814959.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77420, 5307, 'Boruto: Naruto Next Generations S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/814960.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77421, 5307, 'Boruto: Naruto Next Generations S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/814961.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77422, 5307, 'Boruto: Naruto Next Generations S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264645.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77423, 5307, 'Boruto: Naruto Next Generations S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264646.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77424, 5307, 'Boruto: Naruto Next Generations S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/264647.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77425, 5307, 'Boruto: Naruto Next Generations S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/264648.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77426, 5307, 'Boruto: Naruto Next Generations S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/264649.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77427, 5307, 'Boruto: Naruto Next Generations S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/264650.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77428, 5307, 'Boruto: Naruto Next Generations S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/264651.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77429, 5307, 'Boruto: Naruto Next Generations S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/264652.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77430, 5307, 'Boruto: Naruto Next Generations S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/264653.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77431, 5307, 'Boruto: Naruto Next Generations S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/264654.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77432, 5307, 'Boruto: Naruto Next Generations S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/264655.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77433, 5307, 'Boruto: Naruto Next Generations S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/264656.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77434, 5307, 'Boruto: Naruto Next Generations S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/264657.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77435, 5307, 'Boruto: Naruto Next Generations S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/264658.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77436, 5307, 'Boruto: Naruto Next Generations S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/264659.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77437, 5307, 'Boruto: Naruto Next Generations S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/264660.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77438, 5307, 'Boruto: Naruto Next Generations S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/264661.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77439, 5307, 'Boruto: Naruto Next Generations S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/264662.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77440, 5307, 'Boruto: Naruto Next Generations S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/264663.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77441, 5307, 'Boruto: Naruto Next Generations S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/264664.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77442, 5307, 'Boruto: Naruto Next Generations S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/264665.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77443, 5307, 'Boruto: Naruto Next Generations S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/264666.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77444, 5307, 'Boruto: Naruto Next Generations S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/264667.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77445, 5307, 'Boruto: Naruto Next Generations S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/264668.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77446, 5308, 'Boruto: Naruto Next Generations S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/814962.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77447, 5308, 'Boruto: Naruto Next Generations S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/814963.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77448, 5308, 'Boruto: Naruto Next Generations S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/814964.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77449, 5308, 'Boruto: Naruto Next Generations S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/814965.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77450, 5308, 'Boruto: Naruto Next Generations S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/814966.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77451, 5308, 'Boruto: Naruto Next Generations S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264669.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77452, 5308, 'Boruto: Naruto Next Generations S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264670.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77453, 5308, 'Boruto: Naruto Next Generations S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264671.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77454, 5308, 'Boruto: Naruto Next Generations S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264672.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77455, 5308, 'Boruto: Naruto Next Generations S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264673.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77456, 5308, 'Boruto: Naruto Next Generations S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264674.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77457, 5308, 'Boruto: Naruto Next Generations S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264675.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77458, 5308, 'Boruto: Naruto Next Generations S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/264676.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77459, 5308, 'Boruto: Naruto Next Generations S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/264677.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77460, 5308, 'Boruto: Naruto Next Generations S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/264678.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77461, 5308, 'Boruto: Naruto Next Generations S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/264679.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77462, 5308, 'Boruto: Naruto Next Generations S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/264680.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77463, 5308, 'Boruto: Naruto Next Generations S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/264681.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77464, 5308, 'Boruto: Naruto Next Generations S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/264682.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77465, 5308, 'Boruto: Naruto Next Generations S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/264683.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77466, 5308, 'Boruto: Naruto Next Generations S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/264684.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77467, 5308, 'Boruto: Naruto Next Generations S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/264685.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77468, 5308, 'Boruto: Naruto Next Generations S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/264686.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77469, 5308, 'Boruto: Naruto Next Generations S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/264687.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77470, 5308, 'Boruto: Naruto Next Generations S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/264688.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77471, 5308, 'Boruto: Naruto Next Generations S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/264689.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77472, 5308, 'Boruto: Naruto Next Generations S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/264690.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77473, 5308, 'Boruto: Naruto Next Generations S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/264691.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77474, 5308, 'Boruto: Naruto Next Generations S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/264692.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77475, 5308, 'Boruto: Naruto Next Generations S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/264693.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77476, 5309, 'Boruto: Naruto Next Generations S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/814967.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77477, 5309, 'Boruto: Naruto Next Generations S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/814968.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77478, 5309, 'Boruto: Naruto Next Generations S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/814969.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77479, 5309, 'Boruto: Naruto Next Generations S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264694.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77480, 5309, 'Boruto: Naruto Next Generations S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264695.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77481, 5309, 'Boruto: Naruto Next Generations S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264696.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77482, 5309, 'Boruto: Naruto Next Generations S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264697.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77483, 5309, 'Boruto: Naruto Next Generations S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264698.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77484, 5309, 'Boruto: Naruto Next Generations S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264699.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77485, 5309, 'Boruto: Naruto Next Generations S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264700.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77486, 5309, 'Boruto: Naruto Next Generations S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264701.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77487, 5309, 'Boruto: Naruto Next Generations S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264702.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77488, 5309, 'Boruto: Naruto Next Generations S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/264703.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77489, 5309, 'Boruto: Naruto Next Generations S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/264704.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77490, 5309, 'Boruto: Naruto Next Generations S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/264705.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77491, 5309, 'Boruto: Naruto Next Generations S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/264706.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77492, 5309, 'Boruto: Naruto Next Generations S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/264707.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77493, 5309, 'Boruto: Naruto Next Generations S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/264708.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77494, 5309, 'Boruto: Naruto Next Generations S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/264709.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77495, 5309, 'Boruto: Naruto Next Generations S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/264710.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77496, 5309, 'Boruto: Naruto Next Generations S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/264711.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77497, 5309, 'Boruto: Naruto Next Generations S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/264712.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77498, 5309, 'Boruto: Naruto Next Generations S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/264713.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77499, 5309, 'Boruto: Naruto Next Generations S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/264714.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77500, 5309, 'Boruto: Naruto Next Generations S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/264715.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77501, 5309, 'Boruto: Naruto Next Generations S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/264716.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77502, 5309, 'Boruto: Naruto Next Generations S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/264717.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77503, 5309, 'Boruto: Naruto Next Generations S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/264718.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77504, 5309, 'Boruto: Naruto Next Generations S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/264719.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77505, 5310, 'Boruto: Naruto Next Generations S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/814970.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77506, 5310, 'Boruto: Naruto Next Generations S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/814971.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77507, 5310, 'Boruto: Naruto Next Generations S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/814972.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77508, 5310, 'Boruto: Naruto Next Generations S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/814973.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77509, 5310, 'Boruto: Naruto Next Generations S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/814974.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77510, 5310, 'Boruto: Naruto Next Generations S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/814975.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77511, 5310, 'Boruto: Naruto Next Generations S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/814976.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77512, 5310, 'Boruto: Naruto Next Generations S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/814977.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77513, 5310, 'Boruto: Naruto Next Generations S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/814978.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77514, 5310, 'Boruto: Naruto Next Generations S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/814979.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77515, 5310, 'Boruto: Naruto Next Generations S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264720.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77516, 5310, 'Boruto: Naruto Next Generations S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264721.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77517, 5310, 'Boruto: Naruto Next Generations S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/264722.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77518, 5310, 'Boruto: Naruto Next Generations S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/264723.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(77519, 5310, 'Boruto: Naruto Next Generations S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/264724.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77520, 5310, 'Boruto: Naruto Next Generations S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/264725.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77521, 5310, 'Boruto: Naruto Next Generations S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/264726.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77522, 5310, 'Boruto: Naruto Next Generations S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/264727.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77523, 5310, 'Boruto: Naruto Next Generations S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/264728.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77524, 5310, 'Boruto: Naruto Next Generations S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/264729.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77525, 5310, 'Boruto: Naruto Next Generations S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/264730.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77526, 5310, 'Boruto: Naruto Next Generations S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/264731.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77527, 5310, 'Boruto: Naruto Next Generations S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/264732.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77528, 5310, 'Boruto: Naruto Next Generations S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/264733.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77529, 5310, 'Boruto: Naruto Next Generations S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/264734.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77530, 5310, 'Boruto: Naruto Next Generations S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/264735.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77531, 5310, 'Boruto: Naruto Next Generations S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/264736.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77532, 5310, 'Boruto: Naruto Next Generations S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/264737.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77533, 5310, 'Boruto: Naruto Next Generations S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/264738.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77534, 5310, 'Boruto: Naruto Next Generations S06 E30', 'http://sinalprivado.info:80/series/1533784/1533784/264739.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77535, 5310, 'Boruto: Naruto Next Generations S06 E31', 'http://sinalprivado.info:80/series/1533784/1533784/264740.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77536, 5310, 'Boruto: Naruto Next Generations S06 E32', 'http://sinalprivado.info:80/series/1533784/1533784/264741.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77537, 5310, 'Boruto: Naruto Next Generations S06 E33', 'http://sinalprivado.info:80/series/1533784/1533784/264742.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77538, 5310, 'Boruto: Naruto Next Generations S06 E34', 'http://sinalprivado.info:80/series/1533784/1533784/264743.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77539, 5311, 'Boruto: Naruto Next Generations S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/814980.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77540, 5311, 'Boruto: Naruto Next Generations S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/814981.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77541, 5311, 'Boruto: Naruto Next Generations S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/814982.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77542, 5311, 'Boruto: Naruto Next Generations S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/814983.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77543, 5311, 'Boruto: Naruto Next Generations S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/814984.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77544, 5311, 'Boruto: Naruto Next Generations S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/814985.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77545, 5311, 'Boruto: Naruto Next Generations S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/814986.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77546, 5311, 'Boruto: Naruto Next Generations S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/814987.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77547, 5311, 'Boruto: Naruto Next Generations S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/814988.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77548, 5311, 'Boruto: Naruto Next Generations S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/814989.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77549, 5311, 'Boruto: Naruto Next Generations S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/814990.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77550, 5311, 'Boruto: Naruto Next Generations S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/814991.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77551, 5311, 'Boruto: Naruto Next Generations S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/814992.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77552, 5311, 'Boruto: Naruto Next Generations S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/814993.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77553, 5311, 'Boruto: Naruto Next Generations S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/264744.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77554, 5311, 'Boruto: Naruto Next Generations S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/264745.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77555, 5311, 'Boruto: Naruto Next Generations S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/264746.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77556, 5311, 'Boruto: Naruto Next Generations S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/264747.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77557, 5311, 'Boruto: Naruto Next Generations S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/264748.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77558, 5311, 'Boruto: Naruto Next Generations S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/264749.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77559, 5311, 'Boruto: Naruto Next Generations S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/264750.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77560, 5311, 'Boruto: Naruto Next Generations S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/264751.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77561, 5311, 'Boruto: Naruto Next Generations S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/264752.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77562, 5311, 'Boruto: Naruto Next Generations S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/264753.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77563, 5311, 'Boruto: Naruto Next Generations S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/264754.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77564, 5311, 'Boruto: Naruto Next Generations S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/264755.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77565, 5311, 'Boruto: Naruto Next Generations S07 E27', 'http://sinalprivado.info:80/series/1533784/1533784/264756.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77566, 5311, 'Boruto: Naruto Next Generations S07 E28', 'http://sinalprivado.info:80/series/1533784/1533784/264757.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77567, 5311, 'Boruto: Naruto Next Generations S07 E29', 'http://sinalprivado.info:80/series/1533784/1533784/264758.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77568, 5311, 'Boruto: Naruto Next Generations S07 E30', 'http://sinalprivado.info:80/series/1533784/1533784/264759.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77569, 5311, 'Boruto: Naruto Next Generations S07 E31', 'http://sinalprivado.info:80/series/1533784/1533784/264760.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77570, 5311, 'Boruto: Naruto Next Generations S07 E32', 'http://sinalprivado.info:80/series/1533784/1533784/264761.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77571, 5311, 'Boruto: Naruto Next Generations S07 E33', 'http://sinalprivado.info:80/series/1533784/1533784/264762.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77572, 5311, 'Boruto: Naruto Next Generations S07 E34', 'http://sinalprivado.info:80/series/1533784/1533784/264763.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77573, 5311, 'Boruto: Naruto Next Generations S07 E35', 'http://sinalprivado.info:80/series/1533784/1533784/264764.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77574, 5311, 'Boruto: Naruto Next Generations S07 E36', 'http://sinalprivado.info:80/series/1533784/1533784/264765.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77575, 5311, 'Boruto: Naruto Next Generations S07 E37', 'http://sinalprivado.info:80/series/1533784/1533784/264766.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77576, 5311, 'Boruto: Naruto Next Generations S07 E38', 'http://sinalprivado.info:80/series/1533784/1533784/264767.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77577, 5311, 'Boruto: Naruto Next Generations S07 E39', 'http://sinalprivado.info:80/series/1533784/1533784/264768.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77578, 5311, 'Boruto: Naruto Next Generations S07 E40', 'http://sinalprivado.info:80/series/1533784/1533784/264769.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77579, 5312, 'Boruto: Naruto Next Generations S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/814994.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77580, 5312, 'Boruto: Naruto Next Generations S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/814995.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77581, 5312, 'Boruto: Naruto Next Generations S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/814996.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77582, 5312, 'Boruto: Naruto Next Generations S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/814997.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77583, 5312, 'Boruto: Naruto Next Generations S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/814998.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77584, 5312, 'Boruto: Naruto Next Generations S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264770.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77585, 5312, 'Boruto: Naruto Next Generations S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264771.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77586, 5312, 'Boruto: Naruto Next Generations S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264772.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77587, 5312, 'Boruto: Naruto Next Generations S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264773.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77588, 5312, 'Boruto: Naruto Next Generations S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264774.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77589, 5312, 'Boruto: Naruto Next Generations S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264775.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77590, 5313, 'Boruto: Naruto Next Generations S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/625602.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77591, 5313, 'Boruto: Naruto Next Generations S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/625603.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77592, 5313, 'Boruto: Naruto Next Generations S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/625604.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77593, 5313, 'Boruto: Naruto Next Generations S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/625605.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77594, 5313, 'Boruto: Naruto Next Generations S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/625606.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77595, 5313, 'Boruto: Naruto Next Generations S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/625607.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77596, 5313, 'Boruto: Naruto Next Generations S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/625608.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77597, 5313, 'Boruto: Naruto Next Generations S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/625609.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77598, 5313, 'Boruto: Naruto Next Generations S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/625610.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77599, 5313, 'Boruto: Naruto Next Generations S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/625611.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77600, 5313, 'Boruto: Naruto Next Generations S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/625612.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77601, 5313, 'Boruto: Naruto Next Generations S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/625613.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77602, 5313, 'Boruto: Naruto Next Generations S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/625614.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77603, 5313, 'Boruto: Naruto Next Generations S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/625615.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77604, 5313, 'Boruto: Naruto Next Generations S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/625616.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77605, 5313, 'Boruto: Naruto Next Generations S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/625617.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77606, 5313, 'Boruto: Naruto Next Generations S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/625618.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77607, 5313, 'Boruto: Naruto Next Generations S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/625619.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77608, 5313, 'Boruto: Naruto Next Generations S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/625620.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77609, 5313, 'Boruto: Naruto Next Generations S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/625621.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77610, 5313, 'Boruto: Naruto Next Generations S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/625622.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77611, 5314, 'Boruto: Naruto Next Generations S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/625623.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77612, 5314, 'Boruto: Naruto Next Generations S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/625624.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77613, 5314, 'Boruto: Naruto Next Generations S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/625625.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77614, 5314, 'Boruto: Naruto Next Generations S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/625626.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77615, 5314, 'Boruto: Naruto Next Generations S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/625627.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77616, 5315, 'Boruto: Naruto Next Generations S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/625628.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77617, 5315, 'Boruto: Naruto Next Generations S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/625629.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77618, 5315, 'Boruto: Naruto Next Generations S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/625630.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77619, 5315, 'Boruto: Naruto Next Generations S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/625631.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77620, 5315, 'Boruto: Naruto Next Generations S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/625632.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77621, 5315, 'Boruto: Naruto Next Generations S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/625633.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77622, 5315, 'Boruto: Naruto Next Generations S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/625634.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77623, 5315, 'Boruto: Naruto Next Generations S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/625635.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77624, 5316, 'Boruto: Naruto Next Generations S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/625636.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77625, 5316, 'Boruto: Naruto Next Generations S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/625637.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77626, 5316, 'Boruto: Naruto Next Generations S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/625638.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77627, 5316, 'Boruto: Naruto Next Generations S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/625639.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77628, 5316, 'Boruto: Naruto Next Generations S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/625640.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77629, 5316, 'Boruto: Naruto Next Generations S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/625641.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77630, 5316, 'Boruto: Naruto Next Generations S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/625642.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77631, 5316, 'Boruto: Naruto Next Generations S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/625643.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77632, 5316, 'Boruto: Naruto Next Generations S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/625644.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77633, 5316, 'Boruto: Naruto Next Generations S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/625645.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77634, 5317, 'Boruto: Naruto Next Generations S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/625646.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77635, 5317, 'Boruto: Naruto Next Generations S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/625647.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77636, 5317, 'Boruto: Naruto Next Generations S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/625648.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77637, 5317, 'Boruto: Naruto Next Generations S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/625649.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77638, 5318, 'Boruto: Naruto Next Generations S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/625650.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77639, 5318, 'Boruto: Naruto Next Generations S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/625651.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77640, 5318, 'Boruto: Naruto Next Generations S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/625652.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77641, 5318, 'Boruto: Naruto Next Generations S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/625653.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77642, 5318, 'Boruto: Naruto Next Generations S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/625654.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77643, 5318, 'Boruto: Naruto Next Generations S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/625655.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77644, 5318, 'Boruto: Naruto Next Generations S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/625656.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77645, 5318, 'Boruto: Naruto Next Generations S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/625657.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77646, 5319, 'Boruto: Naruto Next Generations S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/625658.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77647, 5319, 'Boruto: Naruto Next Generations S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/625659.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77648, 5319, 'Boruto: Naruto Next Generations S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/625660.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77649, 5319, 'Boruto: Naruto Next Generations S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/625661.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77650, 5319, 'Boruto: Naruto Next Generations S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/625662.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77651, 5319, 'Boruto: Naruto Next Generations S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/625663.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77652, 5319, 'Boruto: Naruto Next Generations S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/625664.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77653, 5319, 'Boruto: Naruto Next Generations S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/625665.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77654, 5319, 'Boruto: Naruto Next Generations S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/625666.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77655, 5319, 'Boruto: Naruto Next Generations S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/625667.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77656, 5319, 'Boruto: Naruto Next Generations S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/625668.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77657, 5319, 'Boruto: Naruto Next Generations S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/625669.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77658, 5319, 'Boruto: Naruto Next Generations S15 E13', 'http://sinalprivado.info:80/series/1533784/1533784/625670.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77659, 5320, 'Boruto: Naruto Next Generations S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/625671.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77660, 5320, 'Boruto: Naruto Next Generations S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/625672.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77661, 5320, 'Boruto: Naruto Next Generations S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/625673.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77662, 5320, 'Boruto: Naruto Next Generations S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/625674.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77663, 5320, 'Boruto: Naruto Next Generations S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/625675.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77664, 5320, 'Boruto: Naruto Next Generations S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/625676.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77665, 5320, 'Boruto: Naruto Next Generations S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/625677.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77666, 5320, 'Boruto: Naruto Next Generations S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/625678.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77667, 5320, 'Boruto: Naruto Next Generations S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/625679.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77668, 5320, 'Boruto: Naruto Next Generations S16 E10', 'http://sinalprivado.info:80/series/1533784/1533784/625680.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77669, 5320, 'Boruto: Naruto Next Generations S16 E11', 'http://sinalprivado.info:80/series/1533784/1533784/625681.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77670, 5320, 'Boruto: Naruto Next Generations S16 E12', 'http://sinalprivado.info:80/series/1533784/1533784/625682.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77671, 5320, 'Boruto: Naruto Next Generations S16 E13', 'http://sinalprivado.info:80/series/1533784/1533784/625683.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77672, 5320, 'Boruto: Naruto Next Generations S16 E14', 'http://sinalprivado.info:80/series/1533784/1533784/625684.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77673, 5320, 'Boruto: Naruto Next Generations S16 E15', 'http://sinalprivado.info:80/series/1533784/1533784/625685.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77674, 5320, 'Boruto: Naruto Next Generations S16 E16', 'http://sinalprivado.info:80/series/1533784/1533784/625686.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77675, 5321, 'Boruto: Naruto Next Generations S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/625687.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77676, 5321, 'Boruto: Naruto Next Generations S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/625688.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77677, 5321, 'Boruto: Naruto Next Generations S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/625689.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77678, 5321, 'Boruto: Naruto Next Generations S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/625690.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77679, 5321, 'Boruto: Naruto Next Generations S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/625691.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77680, 5321, 'Boruto: Naruto Next Generations S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/625692.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77681, 5321, 'Boruto: Naruto Next Generations S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/625693.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77682, 5321, 'Boruto: Naruto Next Generations S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/625694.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77683, 5321, 'Boruto: Naruto Next Generations S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/625695.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77684, 5321, 'Boruto: Naruto Next Generations S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/625696.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77685, 5321, 'Boruto: Naruto Next Generations S17 E11', 'http://sinalprivado.info:80/series/1533784/1533784/625697.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77686, 5321, 'Boruto: Naruto Next Generations S17 E12', 'http://sinalprivado.info:80/series/1533784/1533784/625698.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77687, 5321, 'Boruto: Naruto Next Generations S17 E13', 'http://sinalprivado.info:80/series/1533784/1533784/625699.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77688, 5321, 'Boruto: Naruto Next Generations S17 E14', 'http://sinalprivado.info:80/series/1533784/1533784/625700.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77689, 5321, 'Boruto: Naruto Next Generations S17 E15', 'http://sinalprivado.info:80/series/1533784/1533784/625701.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77690, 5321, 'Boruto: Naruto Next Generations S17 E16', 'http://sinalprivado.info:80/series/1533784/1533784/625702.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77691, 5321, 'Boruto: Naruto Next Generations S17 E17', 'http://sinalprivado.info:80/series/1533784/1533784/625703.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77692, 5321, 'Boruto: Naruto Next Generations S17 E18', 'http://sinalprivado.info:80/series/1533784/1533784/625704.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77693, 5321, 'Boruto: Naruto Next Generations S17 E19', 'http://sinalprivado.info:80/series/1533784/1533784/625705.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77694, 5321, 'Boruto: Naruto Next Generations S17 E20', 'http://sinalprivado.info:80/series/1533784/1533784/625706.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77695, 5321, 'Boruto: Naruto Next Generations S17 E21', 'http://sinalprivado.info:80/series/1533784/1533784/625707.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77696, 5321, 'Boruto: Naruto Next Generations S17 E22', 'http://sinalprivado.info:80/series/1533784/1533784/625708.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77697, 5321, 'Boruto: Naruto Next Generations S17 E23', 'http://sinalprivado.info:80/series/1533784/1533784/625709.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77698, 5321, 'Boruto: Naruto Next Generations S17 E24', 'http://sinalprivado.info:80/series/1533784/1533784/625710.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77699, 5322, 'Boruto: Naruto Next Generations S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/625711.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77700, 5322, 'Boruto: Naruto Next Generations S18 E02', 'http://sinalprivado.info:80/series/1533784/1533784/625712.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77701, 5322, 'Boruto: Naruto Next Generations S18 E03', 'http://sinalprivado.info:80/series/1533784/1533784/625713.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77702, 5322, 'Boruto: Naruto Next Generations S18 E04', 'http://sinalprivado.info:80/series/1533784/1533784/625714.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77703, 5322, 'Boruto: Naruto Next Generations S18 E05', 'http://sinalprivado.info:80/series/1533784/1533784/625715.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77704, 5322, 'Boruto: Naruto Next Generations S18 E06', 'http://sinalprivado.info:80/series/1533784/1533784/625716.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77705, 5322, 'Boruto: Naruto Next Generations S18 E07', 'http://sinalprivado.info:80/series/1533784/1533784/625717.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77706, 5322, 'Boruto: Naruto Next Generations S18 E08', 'http://sinalprivado.info:80/series/1533784/1533784/625718.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77707, 5322, 'Boruto: Naruto Next Generations S18 E09', 'http://sinalprivado.info:80/series/1533784/1533784/625719.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77708, 5322, 'Boruto: Naruto Next Generations S18 E10', 'http://sinalprivado.info:80/series/1533784/1533784/625720.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77709, 5322, 'Boruto: Naruto Next Generations S18 E11', 'http://sinalprivado.info:80/series/1533784/1533784/625721.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77710, 5323, 'Boruto: Naruto Next Generations S19 E01', 'http://sinalprivado.info:80/series/1533784/1533784/625722.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77711, 5323, 'Boruto: Naruto Next Generations S19 E02', 'http://sinalprivado.info:80/series/1533784/1533784/625723.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77712, 5323, 'Boruto: Naruto Next Generations S19 E03', 'http://sinalprivado.info:80/series/1533784/1533784/625724.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77713, 5323, 'Boruto: Naruto Next Generations S19 E04', 'http://sinalprivado.info:80/series/1533784/1533784/625725.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77714, 5323, 'Boruto: Naruto Next Generations S19 E05', 'http://sinalprivado.info:80/series/1533784/1533784/625726.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77715, 5323, 'Boruto: Naruto Next Generations S19 E06', 'http://sinalprivado.info:80/series/1533784/1533784/625727.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77716, 5323, 'Boruto: Naruto Next Generations S19 E07', 'http://sinalprivado.info:80/series/1533784/1533784/625728.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77717, 5323, 'Boruto: Naruto Next Generations S19 E08', 'http://sinalprivado.info:80/series/1533784/1533784/625729.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77718, 5323, 'Boruto: Naruto Next Generations S19 E09', 'http://sinalprivado.info:80/series/1533784/1533784/625730.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77719, 5323, 'Boruto: Naruto Next Generations S19 E10', 'http://sinalprivado.info:80/series/1533784/1533784/625731.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77720, 5323, 'Boruto: Naruto Next Generations S19 E11', 'http://sinalprivado.info:80/series/1533784/1533784/625732.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77721, 5323, 'Boruto: Naruto Next Generations S19 E12', 'http://sinalprivado.info:80/series/1533784/1533784/625733.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77722, 5323, 'Boruto: Naruto Next Generations S19 E13', 'http://sinalprivado.info:80/series/1533784/1533784/625734.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77723, 5323, 'Boruto: Naruto Next Generations S19 E14', 'http://sinalprivado.info:80/series/1533784/1533784/625735.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77724, 5324, 'Boruto: Naruto Next Generations S20 E01', 'http://sinalprivado.info:80/series/1533784/1533784/625736.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77725, 5324, 'Boruto: Naruto Next Generations S20 E02', 'http://sinalprivado.info:80/series/1533784/1533784/625737.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77726, 5324, 'Boruto: Naruto Next Generations S20 E03', 'http://sinalprivado.info:80/series/1533784/1533784/625738.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77727, 5324, 'Boruto: Naruto Next Generations S20 E04', 'http://sinalprivado.info:80/series/1533784/1533784/625739.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77728, 5324, 'Boruto: Naruto Next Generations S20 E05', 'http://sinalprivado.info:80/series/1533784/1533784/625740.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77729, 5324, 'Boruto: Naruto Next Generations S20 E06', 'http://sinalprivado.info:80/series/1533784/1533784/625741.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77730, 5324, 'Boruto: Naruto Next Generations S20 E07', 'http://sinalprivado.info:80/series/1533784/1533784/625742.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77731, 5324, 'Boruto: Naruto Next Generations S20 E08', 'http://sinalprivado.info:80/series/1533784/1533784/625743.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77732, 5324, 'Boruto: Naruto Next Generations S20 E09', 'http://sinalprivado.info:80/series/1533784/1533784/625744.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77733, 5324, 'Boruto: Naruto Next Generations S20 E10', 'http://sinalprivado.info:80/series/1533784/1533784/625745.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77734, 5324, 'Boruto: Naruto Next Generations S20 E11', 'http://sinalprivado.info:80/series/1533784/1533784/625746.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77735, 5324, 'Boruto: Naruto Next Generations S20 E12', 'http://sinalprivado.info:80/series/1533784/1533784/625747.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77736, 5324, 'Boruto: Naruto Next Generations S20 E13', 'http://sinalprivado.info:80/series/1533784/1533784/625748.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77737, 5324, 'Boruto: Naruto Next Generations S20 E14', 'http://sinalprivado.info:80/series/1533784/1533784/625749.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77738, 5324, 'Boruto: Naruto Next Generations S20 E15', 'http://sinalprivado.info:80/series/1533784/1533784/625750.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77739, 5325, 'Boruto: Naruto Next Generations S21 E01', 'http://sinalprivado.info:80/series/1533784/1533784/625751.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77740, 5325, 'Boruto: Naruto Next Generations S21 E02', 'http://sinalprivado.info:80/series/1533784/1533784/625752.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77741, 5325, 'Boruto: Naruto Next Generations S21 E03', 'http://sinalprivado.info:80/series/1533784/1533784/625753.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77742, 5325, 'Boruto: Naruto Next Generations S21 E04', 'http://sinalprivado.info:80/series/1533784/1533784/625754.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77743, 5325, 'Boruto: Naruto Next Generations S21 E05', 'http://sinalprivado.info:80/series/1533784/1533784/625755.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77744, 5325, 'Boruto: Naruto Next Generations S21 E06', 'http://sinalprivado.info:80/series/1533784/1533784/625756.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77745, 5325, 'Boruto: Naruto Next Generations S21 E07', 'http://sinalprivado.info:80/series/1533784/1533784/625757.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77746, 5326, 'Boruto: Naruto Next Generations S22 E01', 'http://sinalprivado.info:80/series/1533784/1533784/625758.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77747, 5326, 'Boruto: Naruto Next Generations S22 E02', 'http://sinalprivado.info:80/series/1533784/1533784/625759.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77748, 5326, 'Boruto: Naruto Next Generations S22 E03', 'http://sinalprivado.info:80/series/1533784/1533784/625760.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77749, 5326, 'Boruto: Naruto Next Generations S22 E04', 'http://sinalprivado.info:80/series/1533784/1533784/625761.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77750, 5326, 'Boruto: Naruto Next Generations S22 E05', 'http://sinalprivado.info:80/series/1533784/1533784/625762.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77751, 5326, 'Boruto: Naruto Next Generations S22 E06', 'http://sinalprivado.info:80/series/1533784/1533784/815160.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77752, 5326, 'Boruto: Naruto Next Generations S22 E07', 'http://sinalprivado.info:80/series/1533784/1533784/815161.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77753, 5326, 'Boruto: Naruto Next Generations S22 E08', 'http://sinalprivado.info:80/series/1533784/1533784/815162.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77754, 5326, 'Boruto: Naruto Next Generations S22 E09', 'http://sinalprivado.info:80/series/1533784/1533784/815163.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77755, 5326, 'Boruto: Naruto Next Generations S22 E10', 'http://sinalprivado.info:80/series/1533784/1533784/815164.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77756, 5326, 'Boruto: Naruto Next Generations S22 E11', 'http://sinalprivado.info:80/series/1533784/1533784/815165.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77757, 5326, 'Boruto: Naruto Next Generations S22 E12', 'http://sinalprivado.info:80/series/1533784/1533784/815166.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77758, 5326, 'Boruto: Naruto Next Generations S22 E13', 'http://sinalprivado.info:80/series/1533784/1533784/815167.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77759, 5326, 'Boruto: Naruto Next Generations S22 E14', 'http://sinalprivado.info:80/series/1533784/1533784/815168.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77760, 5326, 'Boruto: Naruto Next Generations S22 E15', 'http://sinalprivado.info:80/series/1533784/1533784/815169.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77761, 5326, 'Boruto: Naruto Next Generations S22 E16', 'http://sinalprivado.info:80/series/1533784/1533784/815170.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77762, 5326, 'Boruto: Naruto Next Generations S22 E17', 'http://sinalprivado.info:80/series/1533784/1533784/815171.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77763, 5326, 'Boruto: Naruto Next Generations S22 E18', 'http://sinalprivado.info:80/series/1533784/1533784/815172.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77764, 5326, 'Boruto: Naruto Next Generations S22 E19', 'http://sinalprivado.info:80/series/1533784/1533784/815173.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77765, 5326, 'Boruto: Naruto Next Generations S22 E20', 'http://sinalprivado.info:80/series/1533784/1533784/815174.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77766, 5326, 'Boruto: Naruto Next Generations S22 E21', 'http://sinalprivado.info:80/series/1533784/1533784/815175.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77767, 5326, 'Boruto: Naruto Next Generations S22 E22', 'http://sinalprivado.info:80/series/1533784/1533784/815176.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77768, 5326, 'Boruto: Naruto Next Generations S22 E23', 'http://sinalprivado.info:80/series/1533784/1533784/815177.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77769, 5326, 'Boruto: Naruto Next Generations S22 E24', 'http://sinalprivado.info:80/series/1533784/1533784/815178.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77770, 5326, 'Boruto: Naruto Next Generations S22 E25', 'http://sinalprivado.info:80/series/1533784/1533784/815179.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77771, 5326, 'Boruto: Naruto Next Generations S22 E26', 'http://sinalprivado.info:80/series/1533784/1533784/815180.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77772, 5326, 'Boruto: Naruto Next Generations S22 E27', 'http://sinalprivado.info:80/series/1533784/1533784/815181.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77773, 5326, 'Boruto: Naruto Next Generations S22 E28', 'http://sinalprivado.info:80/series/1533784/1533784/815182.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77774, 5326, 'Boruto: Naruto Next Generations S22 E29', 'http://sinalprivado.info:80/series/1533784/1533784/815183.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77775, 5326, 'Boruto: Naruto Next Generations S22 E30', 'http://sinalprivado.info:80/series/1533784/1533784/815184.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77776, 5326, 'Boruto: Naruto Next Generations S22 E31', 'http://sinalprivado.info:80/series/1533784/1533784/815185.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(77777, 5326, 'Boruto: Naruto Next Generations S22 E32', 'http://sinalprivado.info:80/series/1533784/1533784/815186.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77778, 5326, 'Boruto: Naruto Next Generations S22 E33', 'http://sinalprivado.info:80/series/1533784/1533784/815187.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77779, 5327, 'Boruto: Naruto Next Generations S23 E01', 'http://sinalprivado.info:80/series/1533784/1533784/815188.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77780, 5327, 'Boruto: Naruto Next Generations S23 E02', 'http://sinalprivado.info:80/series/1533784/1533784/815189.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77781, 5327, 'Boruto: Naruto Next Generations S23 E03', 'http://sinalprivado.info:80/series/1533784/1533784/815190.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77782, 5327, 'Boruto: Naruto Next Generations S23 E04', 'http://sinalprivado.info:80/series/1533784/1533784/815191.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77783, 5327, 'Boruto: Naruto Next Generations S23 E05', 'http://sinalprivado.info:80/series/1533784/1533784/815192.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77784, 5327, 'Boruto: Naruto Next Generations S23 E06', 'http://sinalprivado.info:80/series/1533784/1533784/815193.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77785, 5327, 'Boruto: Naruto Next Generations S23 E07', 'http://sinalprivado.info:80/series/1533784/1533784/815194.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77786, 5327, 'Boruto: Naruto Next Generations S23 E08', 'http://sinalprivado.info:80/series/1533784/1533784/815195.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77787, 5327, 'Boruto: Naruto Next Generations S23 E09', 'http://sinalprivado.info:80/series/1533784/1533784/815196.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77788, 5327, 'Boruto: Naruto Next Generations S23 E10', 'http://sinalprivado.info:80/series/1533784/1533784/815197.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77789, 5327, 'Boruto: Naruto Next Generations S23 E11', 'http://sinalprivado.info:80/series/1533784/1533784/815198.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77790, 5327, 'Boruto: Naruto Next Generations S23 E12', 'http://sinalprivado.info:80/series/1533784/1533784/815199.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77791, 5327, 'Boruto: Naruto Next Generations S23 E13', 'http://sinalprivado.info:80/series/1533784/1533784/815200.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77792, 5328, 'Boruto: Naruto Next Generations S24 E01', 'http://sinalprivado.info:80/series/1533784/1533784/815201.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77793, 5328, 'Boruto: Naruto Next Generations S24 E02', 'http://sinalprivado.info:80/series/1533784/1533784/815202.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77794, 5328, 'Boruto: Naruto Next Generations S24 E03', 'http://sinalprivado.info:80/series/1533784/1533784/815203.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77795, 5328, 'Boruto: Naruto Next Generations S24 E04', 'http://sinalprivado.info:80/series/1533784/1533784/815204.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77796, 5328, 'Boruto: Naruto Next Generations S24 E05', 'http://sinalprivado.info:80/series/1533784/1533784/815205.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77797, 5328, 'Boruto: Naruto Next Generations S24 E06', 'http://sinalprivado.info:80/series/1533784/1533784/815206.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77798, 5328, 'Boruto: Naruto Next Generations S24 E07', 'http://sinalprivado.info:80/series/1533784/1533784/815207.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77799, 5328, 'Boruto: Naruto Next Generations S24 E08', 'http://sinalprivado.info:80/series/1533784/1533784/815208.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77800, 5329, 'Boruto: Naruto Next Generations S25 E01', 'http://sinalprivado.info:80/series/1533784/1533784/815209.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77801, 5329, 'Boruto: Naruto Next Generations S25 E02', 'http://sinalprivado.info:80/series/1533784/1533784/815210.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77802, 5329, 'Boruto: Naruto Next Generations S25 E03', 'http://sinalprivado.info:80/series/1533784/1533784/815211.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77803, 5329, 'Boruto: Naruto Next Generations S25 E04', 'http://sinalprivado.info:80/series/1533784/1533784/815212.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77804, 5329, 'Boruto: Naruto Next Generations S25 E05', 'http://sinalprivado.info:80/series/1533784/1533784/815213.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77805, 5330, 'Boruto: Naruto Next Generations S26 E01', 'http://sinalprivado.info:80/series/1533784/1533784/815214.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77806, 5330, 'Boruto: Naruto Next Generations S26 E02', 'http://sinalprivado.info:80/series/1533784/1533784/815215.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77807, 5330, 'Boruto: Naruto Next Generations S26 E03', 'http://sinalprivado.info:80/series/1533784/1533784/815216.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77808, 5330, 'Boruto: Naruto Next Generations S26 E04', 'http://sinalprivado.info:80/series/1533784/1533784/815217.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77809, 5330, 'Boruto: Naruto Next Generations S26 E05', 'http://sinalprivado.info:80/series/1533784/1533784/815218.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77810, 5330, 'Boruto: Naruto Next Generations S26 E06', 'http://sinalprivado.info:80/series/1533784/1533784/815219.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77811, 5330, 'Boruto: Naruto Next Generations S26 E07', 'http://sinalprivado.info:80/series/1533784/1533784/815220.mp4', 'http://gstaticontent.com/images/1998646a0a26c0e42639cd50d132ede5.jpg'),
(77812, 5331, 'Murderville S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173210.mp4', 'http://timg.bdta.pro/images/7e61e172037dbe250283e58a65432f95.jpg'),
(77813, 5331, 'Murderville S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173211.mp4', 'http://timg.bdta.pro/images/481aeb2e92efd5f28d0217901e161bca.jpg'),
(77814, 5331, 'Murderville S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173212.mp4', 'http://timg.bdta.pro/images/5c07d344975414eebda644eec0e87cae.jpg'),
(77815, 5331, 'Murderville S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173213.mp4', 'http://timg.bdta.pro/images/a34de57571d93eefd805c1c70f7ef00b.jpg'),
(77816, 5331, 'Murderville S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173214.mp4', 'http://timg.bdta.pro/images/77993ea7c61dad6b88ed25ad1e75a3d5.jpg'),
(77817, 5331, 'Murderville S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173215.mp4', 'http://timg.bdta.pro/images/4f56779f00a3165dbab66306aca6d711.jpg'),
(77818, 5332, 'O Mistério do Triângulo das Bermudas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173202.mp4', 'http://gstaticontent.com/images/f534b963d26d087e3c4cb72121f2f7ac.jpg'),
(77819, 5332, 'O Mistério do Triângulo das Bermudas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173203.mp4', 'http://gstaticontent.com/images/f534b963d26d087e3c4cb72121f2f7ac.jpg'),
(77820, 5332, 'O Mistério do Triângulo das Bermudas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173204.mp4', 'http://gstaticontent.com/images/f534b963d26d087e3c4cb72121f2f7ac.jpg'),
(77821, 5332, 'O Mistério do Triângulo das Bermudas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173205.mp4', 'http://gstaticontent.com/images/f534b963d26d087e3c4cb72121f2f7ac.jpg'),
(77822, 5332, 'O Mistério do Triângulo das Bermudas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173206.mp4', 'http://gstaticontent.com/images/f534b963d26d087e3c4cb72121f2f7ac.jpg'),
(77823, 5332, 'O Mistério do Triângulo das Bermudas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173207.mp4', 'http://gstaticontent.com/images/f534b963d26d087e3c4cb72121f2f7ac.jpg'),
(77824, 5332, 'O Mistério do Triângulo das Bermudas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173208.mp4', 'http://gstaticontent.com/images/f534b963d26d087e3c4cb72121f2f7ac.jpg'),
(77825, 5332, 'O Mistério do Triângulo das Bermudas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173209.mp4', 'http://gstaticontent.com/images/f534b963d26d087e3c4cb72121f2f7ac.jpg'),
(77826, 5333, 'Power Book IV: Force S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245991.mp4', 'http://timg.bdta.pro/images/4496cdb1f22a35f99d4294a6389a9458.jpg'),
(77827, 5333, 'Power Book IV: Force S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245992.mp4', 'http://timg.bdta.pro/images/b4579facb70579a197e0777234943a3e.jpg'),
(77828, 5333, 'Power Book IV: Force S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245993.mp4', 'http://timg.bdta.pro/images/1bac1a7c6d581bb7f5d8235f777d14f8.jpg'),
(77829, 5333, 'Power Book IV: Force S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245994.mp4', 'http://timg.bdta.pro/images/9f659aaf9c81fca79178b5a3eaea1bec.jpg'),
(77830, 5333, 'Power Book IV: Force S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245995.mp4', 'http://timg.bdta.pro/images/44113c0b1381cf382f59b0d7dbe36968.jpg'),
(77831, 5333, 'Power Book IV: Force S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245996.mp4', 'http://timg.bdta.pro/images/9282d53d96598413275398e50333fa63.jpg'),
(77832, 5333, 'Power Book IV: Force S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245997.mp4', 'http://timg.bdta.pro/images/303dd112362ccd2538f3906321fb32f9.jpg'),
(77833, 5333, 'Power Book IV: Force S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245998.mp4', 'http://timg.bdta.pro/images/f0ff7e7baa84fea51d7d572fd14585f7.jpg'),
(77834, 5333, 'Power Book IV: Force S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245999.mp4', 'http://timg.bdta.pro/images/9b6d67d3d29a900daafc243a26e5cd54.jpg'),
(77835, 5333, 'Power Book IV: Force S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246000.mp4', 'http://timg.bdta.pro/images/10e76bde47a3b02a140f05ccc528f298.jpg'),
(77836, 5334, 'Power Book IV: Force S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246001.mp4', 'http://gstaticontent.com/images/b5ebf9eb7b647af968c6fc8dc7f5c46a.jpg'),
(77837, 5334, 'Power Book IV: Force S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246002.mp4', 'http://gstaticontent.com/images/b5ebf9eb7b647af968c6fc8dc7f5c46a.jpg'),
(77838, 5334, 'Power Book IV: Force S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246003.mp4', 'http://gstaticontent.com/images/b5ebf9eb7b647af968c6fc8dc7f5c46a.jpg'),
(77839, 5334, 'Power Book IV: Force S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246004.mp4', 'http://gstaticontent.com/images/b5ebf9eb7b647af968c6fc8dc7f5c46a.jpg'),
(77840, 5334, 'Power Book IV: Force S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246005.mp4', 'http://gstaticontent.com/images/b5ebf9eb7b647af968c6fc8dc7f5c46a.jpg'),
(77841, 5334, 'Power Book IV: Force S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246006.mp4', 'http://gstaticontent.com/images/b5ebf9eb7b647af968c6fc8dc7f5c46a.jpg'),
(77842, 5334, 'Power Book IV: Force S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246007.mp4', 'http://gstaticontent.com/images/b5ebf9eb7b647af968c6fc8dc7f5c46a.jpg'),
(77843, 5334, 'Power Book IV: Force S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246008.mp4', 'http://gstaticontent.com/images/b5ebf9eb7b647af968c6fc8dc7f5c46a.jpg'),
(77844, 5334, 'Power Book IV: Force S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246009.mp4', 'http://gstaticontent.com/images/b5ebf9eb7b647af968c6fc8dc7f5c46a.jpg'),
(77845, 5334, 'Power Book IV: Force S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246010.mp4', 'http://gstaticontent.com/images/b5ebf9eb7b647af968c6fc8dc7f5c46a.jpg'),
(77846, 5335, 'Power Book IV: Force S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/892197.mp4', 'http://gstaticontent.com/images/b5ebf9eb7b647af968c6fc8dc7f5c46a.jpg'),
(77847, 5335, 'Power Book IV: Force S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/892636.mp4', 'http://gstaticontent.com/images/b5ebf9eb7b647af968c6fc8dc7f5c46a.jpg'),
(77848, 5335, 'Power Book IV: Force S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/893346.mp4', 'http://gstaticontent.com/images/b5ebf9eb7b647af968c6fc8dc7f5c46a.jpg'),
(77849, 5335, 'Power Book IV: Force S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/893568.mp4', 'http://gstaticontent.com/images/b5ebf9eb7b647af968c6fc8dc7f5c46a.jpg'),
(77850, 5335, 'Power Book IV: Force S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/894873.mp4', 'http://gstaticontent.com/images/b5ebf9eb7b647af968c6fc8dc7f5c46a.jpg'),
(77851, 5335, 'Power Book IV: Force S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/895863.mp4', 'http://gstaticontent.com/images/b5ebf9eb7b647af968c6fc8dc7f5c46a.jpg'),
(77852, 5335, 'Power Book IV: Force S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/896659.mp4', 'http://gstaticontent.com/images/b5ebf9eb7b647af968c6fc8dc7f5c46a.jpg'),
(77853, 5335, 'Power Book IV: Force S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/897408.mp4', 'http://gstaticontent.com/images/b5ebf9eb7b647af968c6fc8dc7f5c46a.jpg'),
(77854, 5336, 'Reacher S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261303.mp4', 'http://timg.bdta.pro/images/e542495b3d702ba3036098a0c0ae3731.jpg'),
(77855, 5336, 'Reacher S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261304.mp4', 'http://timg.bdta.pro/images/a800a1a10a826209dfb579254bef58a2.jpg'),
(77856, 5336, 'Reacher S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261305.mp4', 'http://timg.bdta.pro/images/ed243094908b43d7c70d37bbd47cf2a4.jpg'),
(77857, 5336, 'Reacher S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261306.mp4', 'http://timg.bdta.pro/images/06bad86c1129cd34ee6445a536e552b9.jpg'),
(77858, 5336, 'Reacher S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261307.mp4', 'http://timg.bdta.pro/images/57261094cd4a05117958260174b27c5a.jpg'),
(77859, 5336, 'Reacher S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261308.mp4', 'http://timg.bdta.pro/images/241881759695ff2b75c06a2512cd4efb.jpg'),
(77860, 5336, 'Reacher S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261309.mp4', 'http://timg.bdta.pro/images/e9014660998f434eafae2d61457e45ae.jpg'),
(77861, 5336, 'Reacher S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261310.mp4', 'http://timg.bdta.pro/images/5846c4aea415aa7e4092d12e6d94d8a0.jpg'),
(77862, 5337, 'Reacher S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261311.mp4', 'http://gstaticontent.com/images/d89cd0ade60d64026e44f994193646d4.jpg'),
(77863, 5337, 'Reacher S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261312.mp4', 'http://gstaticontent.com/images/d89cd0ade60d64026e44f994193646d4.jpg'),
(77864, 5337, 'Reacher S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261313.mp4', 'http://gstaticontent.com/images/d89cd0ade60d64026e44f994193646d4.jpg'),
(77865, 5337, 'Reacher S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261314.mp4', 'http://gstaticontent.com/images/d89cd0ade60d64026e44f994193646d4.jpg'),
(77866, 5337, 'Reacher S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261315.mp4', 'http://gstaticontent.com/images/d89cd0ade60d64026e44f994193646d4.jpg'),
(77867, 5337, 'Reacher S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261316.mp4', 'http://gstaticontent.com/images/d89cd0ade60d64026e44f994193646d4.jpg'),
(77868, 5337, 'Reacher S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261317.mp4', 'http://gstaticontent.com/images/d89cd0ade60d64026e44f994193646d4.jpg'),
(77869, 5337, 'Reacher S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261318.mp4', 'http://gstaticontent.com/images/d89cd0ade60d64026e44f994193646d4.jpg'),
(77870, 5338, 'Reacher S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/704331.mp4', 'http://gstaticontent.com/images/d89cd0ade60d64026e44f994193646d4.jpg'),
(77871, 5338, 'Reacher S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/704332.mp4', 'http://gstaticontent.com/images/d89cd0ade60d64026e44f994193646d4.jpg'),
(77872, 5338, 'Reacher S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/704333.mp4', 'http://gstaticontent.com/images/d89cd0ade60d64026e44f994193646d4.jpg'),
(77873, 5338, 'Reacher S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/713378.mp4', 'http://gstaticontent.com/images/d89cd0ade60d64026e44f994193646d4.jpg'),
(77874, 5338, 'Reacher S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/717462.mp4', 'http://gstaticontent.com/images/d89cd0ade60d64026e44f994193646d4.jpg'),
(77875, 5338, 'Reacher S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/724436.mp4', 'http://gstaticontent.com/images/d89cd0ade60d64026e44f994193646d4.jpg'),
(77876, 5338, 'Reacher S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/730998.mp4', 'http://gstaticontent.com/images/d89cd0ade60d64026e44f994193646d4.jpg'),
(77877, 5338, 'Reacher S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/741074.mp4', 'http://gstaticontent.com/images/d89cd0ade60d64026e44f994193646d4.jpg'),
(77878, 5339, 'Sobrepostas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173189.mp4', 'http://timg.bdta.pro/images/1a28f3eef1427ad847cc11b5aec538e0.jpg'),
(77879, 5339, 'Sobrepostas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173190.mp4', 'http://timg.bdta.pro/images/de2d883b8bd7e791a816e796cbb2cdd3.jpg'),
(77880, 5339, 'Sobrepostas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173191.mp4', 'http://timg.bdta.pro/images/5a6a833f6e09435b19a0d6038cc780b8.jpg'),
(77881, 5339, 'Sobrepostas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173192.mp4', 'http://timg.bdta.pro/images/3ff0a52a96f0337c63937832cf0a005d.jpg'),
(77882, 5339, 'Sobrepostas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173193.mp4', 'http://timg.bdta.pro/images/4aff6217ec5b30fb96e39d688b0191e3.jpg'),
(77883, 5339, 'Sobrepostas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173194.mp4', 'http://timg.bdta.pro/images/688dcb3ec04565e4a7a7898d8b99be66.jpg'),
(77884, 5339, 'Sobrepostas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/173195.mp4', 'http://timg.bdta.pro/images/627cfb6c018eb5d83bb805f49e46ca66.jpg'),
(77885, 5339, 'Sobrepostas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/173196.mp4', 'http://timg.bdta.pro/images/1a3580f18535c6599ed5066e410006fb.jpg'),
(77886, 5339, 'Sobrepostas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/173197.mp4', 'http://timg.bdta.pro/images/0106d20d32c5271f27ba819eabb99058.jpg'),
(77887, 5339, 'Sobrepostas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/173198.mp4', 'http://gstaticontent.com/images/41f90c8d6018558e048c2c0017b14779.jpg'),
(77888, 5339, 'Sobrepostas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/173199.mp4', 'http://gstaticontent.com/images/41f90c8d6018558e048c2c0017b14779.jpg'),
(77889, 5339, 'Sobrepostas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/173200.mp4', 'http://gstaticontent.com/images/41f90c8d6018558e048c2c0017b14779.jpg'),
(77890, 5339, 'Sobrepostas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/173201.mp4', 'http://gstaticontent.com/images/41f90c8d6018558e048c2c0017b14779.jpg'),
(77891, 5340, 'The Challenge: All Stars S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183080.mp4', 'http://timg.bdta.pro/images/c3e03240e68fecef1f211eebfd24911c.jpg'),
(77892, 5340, 'The Challenge: All Stars S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183081.mp4', 'http://timg.bdta.pro/images/c84ac0666328a51be2b751129d623221.jpg'),
(77893, 5340, 'The Challenge: All Stars S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183082.mp4', 'http://timg.bdta.pro/images/75c5ec8721125fffe754b062150283b8.jpg'),
(77894, 5340, 'The Challenge: All Stars S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183083.mp4', 'http://timg.bdta.pro/images/de46e12074f81486bd6745187008e0fb.jpg'),
(77895, 5340, 'The Challenge: All Stars S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183084.mp4', 'http://timg.bdta.pro/images/6f17803b36656595590cd12975ce3c6a.jpg'),
(77896, 5340, 'The Challenge: All Stars S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183085.mp4', 'http://timg.bdta.pro/images/5064fcb223f0271804d71dd90849c2a9.jpg'),
(77897, 5340, 'The Challenge: All Stars S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183086.mp4', 'http://timg.bdta.pro/images/0c027f623d873195c3a11516eea9eaf3.jpg'),
(77898, 5340, 'The Challenge: All Stars S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183087.mp4', 'http://timg.bdta.pro/images/6eab4229cda8a35a3c8736f886074d93.jpg'),
(77899, 5340, 'The Challenge: All Stars S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183088.mp4', 'http://timg.bdta.pro/images/f62b452713a5257d5f28671ea3c8dc3b.jpg'),
(77900, 5340, 'The Challenge: All Stars S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183089.mp4', 'http://timg.bdta.pro/images/12dafba4d9847d075a14e669c3b41d73.jpg'),
(77901, 5341, 'The Challenge: All Stars S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183090.mp4', 'http://timg.bdta.pro/images/fadfd7928d11ca0d3a87fc5f56e5ded7.jpg'),
(77902, 5341, 'The Challenge: All Stars S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183091.mp4', 'http://timg.bdta.pro/images/c3cd1e320b5237bfc52c29066520b2db.jpg'),
(77903, 5341, 'The Challenge: All Stars S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183092.mp4', 'http://timg.bdta.pro/images/e8f6796d1e6133ff54e8300ae4a5527c.jpg'),
(77904, 5341, 'The Challenge: All Stars S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183093.mp4', 'http://timg.bdta.pro/images/1ecabae31b6248ef1fb0b68a4cb1f345.jpg'),
(77905, 5341, 'The Challenge: All Stars S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183094.mp4', 'http://timg.bdta.pro/images/b9949f42ec6edf1ad0afc957e2a9a906.jpg'),
(77906, 5341, 'The Challenge: All Stars S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183095.mp4', 'http://timg.bdta.pro/images/9b846e162146b1c202660896838bb4bb.jpg'),
(77907, 5341, 'The Challenge: All Stars S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183096.mp4', 'http://timg.bdta.pro/images/481c3aefdd5f189f969d610e42922959.jpg'),
(77908, 5341, 'The Challenge: All Stars S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183097.mp4', 'http://timg.bdta.pro/images/5efffbb67b89f7268e3491a32fffe8c7.jpg'),
(77909, 5341, 'The Challenge: All Stars S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183098.mp4', 'http://timg.bdta.pro/images/647e1ebc55a4442d528de7bfedc02434.jpg'),
(77910, 5341, 'The Challenge: All Stars S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183099.mp4', 'http://timg.bdta.pro/images/fe3458f7f76616d7d8204e93146ab8b5.jpg'),
(77911, 5342, 'The Challenge: All Stars S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183100.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77912, 5342, 'The Challenge: All Stars S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183101.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77913, 5342, 'The Challenge: All Stars S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183102.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77914, 5342, 'The Challenge: All Stars S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183103.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77915, 5342, 'The Challenge: All Stars S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183104.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77916, 5342, 'The Challenge: All Stars S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183105.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77917, 5342, 'The Challenge: All Stars S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183106.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77918, 5342, 'The Challenge: All Stars S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183107.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77919, 5342, 'The Challenge: All Stars S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183108.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77920, 5342, 'The Challenge: All Stars S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183109.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77921, 5343, 'The Challenge: All Stars S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/327120.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77922, 5343, 'The Challenge: All Stars S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/327121.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77923, 5343, 'The Challenge: All Stars S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/330993.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77924, 5343, 'The Challenge: All Stars S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/335775.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77925, 5343, 'The Challenge: All Stars S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/339938.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77926, 5343, 'The Challenge: All Stars S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/351252.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77927, 5343, 'The Challenge: All Stars S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/351253.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77928, 5343, 'The Challenge: All Stars S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/358575.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77929, 5343, 'The Challenge: All Stars S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/605067.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77930, 5343, 'The Challenge: All Stars S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/372896.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77931, 5343, 'The Challenge: All Stars S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/383918.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77932, 5343, 'The Challenge: All Stars S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/388430.mp4', 'http://gstaticontent.com/images/a6512cec7353b0476d343186b499b971.jpg'),
(77933, 5344, 'The Globe: Batalha dos Chefes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173184.mp4', 'http://timg.bdta.pro/images/ad2da0a1b70a71d3780fa77dbefbe832.jpg'),
(77934, 5344, 'The Globe: Batalha dos Chefes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173185.mp4', 'http://timg.bdta.pro/images/dd89e2dd4c415bab53e6fc5305bb6216.jpg'),
(77935, 5344, 'The Globe: Batalha dos Chefes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173186.mp4', 'http://timg.bdta.pro/images/7a44b3aa82fe1f1d609b0c2a0d93a283.jpg'),
(77936, 5344, 'The Globe: Batalha dos Chefes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173187.mp4', 'http://gstaticontent.com/images/415e65a44ff6b4a161def8e85be6a4a0.jpg'),
(77937, 5344, 'The Globe: Batalha dos Chefes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173188.mp4', 'http://gstaticontent.com/images/415e65a44ff6b4a161def8e85be6a4a0.jpg'),
(77938, 5345, 'Um Capitão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/173178.mp4', 'http://timg.bdta.pro/images/6bac9acfc4542d576cf29fcd3915255f.jpg'),
(77939, 5345, 'Um Capitão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/173179.mp4', 'http://timg.bdta.pro/images/ea318722732ee9f0c1dcaf739adc6935.jpg'),
(77940, 5345, 'Um Capitão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/173180.mp4', 'http://timg.bdta.pro/images/b488d95584c6d453efb10f96b6fc71f2.jpg'),
(77941, 5345, 'Um Capitão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/173181.mp4', 'http://timg.bdta.pro/images/2aa816e736d3e8fbc3e6daa9eeb20482.jpg'),
(77942, 5345, 'Um Capitão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/173182.mp4', 'http://timg.bdta.pro/images/2c7ec9c79d0824fc086cb00876e046d8.jpg'),
(77943, 5345, 'Um Capitão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/173183.mp4', 'http://timg.bdta.pro/images/8ff0609416482c4fd6e6e30416241c53.jpg'),
(77944, 5346, 'Yellowjackets S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217336.mp4', 'http://timg.bdta.pro/images/fb5720ba7ca1f04c7f9a4e9608c1b074.jpg'),
(77945, 5346, 'Yellowjackets S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217337.mp4', 'http://timg.bdta.pro/images/a2de55592d463e10aec51fb4746e86d6.jpg'),
(77946, 5346, 'Yellowjackets S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217338.mp4', 'http://timg.bdta.pro/images/efd8eb4ecdd6dce1c63c2bf5d007b116.jpg'),
(77947, 5346, 'Yellowjackets S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217339.mp4', 'http://timg.bdta.pro/images/24574506c7d9d2bf7d5a3e46c0573246.jpg'),
(77948, 5346, 'Yellowjackets S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217340.mp4', 'http://timg.bdta.pro/images/6a9a8441147ee32d0f71d3d7ad717738.jpg'),
(77949, 5346, 'Yellowjackets S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217341.mp4', 'http://timg.bdta.pro/images/e4647222fbfdb9e73214ee47bb960de4.jpg'),
(77950, 5346, 'Yellowjackets S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217342.mp4', 'http://timg.bdta.pro/images/0af88e8cfc644b9fb19de58e861f9911.jpg'),
(77951, 5346, 'Yellowjackets S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217343.mp4', 'http://timg.bdta.pro/images/783049abd6a2752f57c84c90a4da65f2.jpg'),
(77952, 5346, 'Yellowjackets S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217344.mp4', 'http://timg.bdta.pro/images/cdc9205b6da63e2167240fcb20c1e391.jpg'),
(77953, 5346, 'Yellowjackets S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217345.mp4', 'http://timg.bdta.pro/images/2d765e8c1a9205e6eab618f1e44e41cf.jpg'),
(77954, 5347, 'Yellowjackets S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217346.mp4', 'http://image.tmdb.org/t/p/w1280/t9U5kOWwJKSdF0BvfPeVrnIJNmV.jpg'),
(77955, 5347, 'Yellowjackets S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217347.mp4', 'http://image.tmdb.org/t/p/w1280/ykoWQGd6Wu5zjhgJfRWCRLj9Okn.jpg'),
(77956, 5347, 'Yellowjackets S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217348.mp4', 'http://image.tmdb.org/t/p/w1280/a2JtLk4F6IPu12n4Ilrm4sD9YI3.jpg'),
(77957, 5347, 'Yellowjackets S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217349.mp4', 'http://image.tmdb.org/t/p/w1280/odisW1eDxCc7oJFzR6gWKR65hxX.jpg'),
(77958, 5347, 'Yellowjackets S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217350.mp4', 'http://image.tmdb.org/t/p/w1280/z8eFRJkYAAB7Au5VNhVU7P7LX2B.jpg'),
(77959, 5347, 'Yellowjackets S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217351.mp4', 'http://image.tmdb.org/t/p/w1280/pRd9jcmtVoeTIDUVlsSwcPbnvEl.jpg'),
(77960, 5347, 'Yellowjackets S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217352.mp4', 'http://image.tmdb.org/t/p/w1280/ifeczCLVTEzHRjcH0uUN5tbivHO.jpg'),
(77961, 5347, 'Yellowjackets S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217353.mp4', 'http://image.tmdb.org/t/p/w1280/3ZXSndvsvSs1aLWEh872GWWBy5B.jpg'),
(77962, 5347, 'Yellowjackets S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217354.mp4', 'http://image.tmdb.org/t/p/w1280/6yVJu6h0MqYi7ZPc0LgMjaS6O6U.jpg'),
(77963, 5348, 'Yellowjackets S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/696807.mp4', 'http://gstaticontent.com/images/a94084a6857a65ba00f7ff0d6714eca7.jpg'),
(77964, 5348, 'Yellowjackets S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/696808.mp4', 'http://gstaticontent.com/images/a94084a6857a65ba00f7ff0d6714eca7.jpg'),
(77965, 5348, 'Yellowjackets S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/703598.mp4', 'http://gstaticontent.com/images/a94084a6857a65ba00f7ff0d6714eca7.jpg'),
(77966, 5348, 'Yellowjackets S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/713118.mp4', 'http://gstaticontent.com/images/a94084a6857a65ba00f7ff0d6714eca7.jpg'),
(77967, 5348, 'Yellowjackets S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/722652.mp4', 'http://gstaticontent.com/images/a94084a6857a65ba00f7ff0d6714eca7.jpg'),
(77968, 5348, 'Yellowjackets S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/723207.mp4', 'http://gstaticontent.com/images/a94084a6857a65ba00f7ff0d6714eca7.jpg'),
(77969, 5348, 'Yellowjackets S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/730127.mp4', 'http://gstaticontent.com/images/a94084a6857a65ba00f7ff0d6714eca7.jpg'),
(77970, 5348, 'Yellowjackets S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/749905.mp4', 'http://gstaticontent.com/images/a94084a6857a65ba00f7ff0d6714eca7.jpg'),
(77971, 5348, 'Yellowjackets S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/757651.mp4', 'http://gstaticontent.com/images/a94084a6857a65ba00f7ff0d6714eca7.jpg'),
(77972, 5348, 'Yellowjackets S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/762967.mp4', 'http://gstaticontent.com/images/a94084a6857a65ba00f7ff0d6714eca7.jpg'),
(77973, 5349, 'A Idade Dourada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252357.mp4', 'http://timg.bdta.pro/images/f3ee90f595124cffe60a0702a15bc320.jpg'),
(77974, 5349, 'A Idade Dourada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252358.mp4', 'http://timg.bdta.pro/images/1902bf203becfed4b493bffa8a0dd1e8.jpg'),
(77975, 5349, 'A Idade Dourada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252359.mp4', 'http://timg.bdta.pro/images/9cc9ee8eb4963ccbbc1d84a634551252.jpg'),
(77976, 5349, 'A Idade Dourada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252360.mp4', 'http://timg.bdta.pro/images/ac8eeed8e73237e699c300b20d0d142c.jpg'),
(77977, 5349, 'A Idade Dourada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252361.mp4', 'http://timg.bdta.pro/images/01aa3232492cc7ff0712b5f17305e88f.jpg'),
(77978, 5349, 'A Idade Dourada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252362.mp4', 'http://timg.bdta.pro/images/034daf8e6bc5c711f05b4a1da3afa60b.jpg'),
(77979, 5349, 'A Idade Dourada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252363.mp4', 'http://timg.bdta.pro/images/f12dfbdf6b4abd5248e552f6a059933b.jpg'),
(77980, 5349, 'A Idade Dourada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252364.mp4', 'http://timg.bdta.pro/images/3398f72b6c5213fbc7f8b9bfbedf7f50.jpg'),
(77981, 5349, 'A Idade Dourada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252365.mp4', 'http://timg.bdta.pro/images/4ef9c46bcb3741fdd37d24d4d2d8133e.jpg'),
(77982, 5350, 'A Idade Dourada S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252366.mp4', 'http://gstaticontent.com/images/ccc636691a88c727767d451afe97d48f.jpg'),
(77983, 5350, 'A Idade Dourada S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252367.mp4', 'http://gstaticontent.com/images/ccc636691a88c727767d451afe97d48f.jpg'),
(77984, 5350, 'A Idade Dourada S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252368.mp4', 'http://gstaticontent.com/images/ccc636691a88c727767d451afe97d48f.jpg'),
(77985, 5350, 'A Idade Dourada S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252369.mp4', 'http://gstaticontent.com/images/ccc636691a88c727767d451afe97d48f.jpg'),
(77986, 5350, 'A Idade Dourada S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252370.mp4', 'http://gstaticontent.com/images/ccc636691a88c727767d451afe97d48f.jpg'),
(77987, 5350, 'A Idade Dourada S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252371.mp4', 'http://gstaticontent.com/images/ccc636691a88c727767d451afe97d48f.jpg'),
(77988, 5350, 'A Idade Dourada S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252372.mp4', 'http://gstaticontent.com/images/ccc636691a88c727767d451afe97d48f.jpg'),
(77989, 5350, 'A Idade Dourada S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252373.mp4', 'http://gstaticontent.com/images/ccc636691a88c727767d451afe97d48f.jpg'),
(77990, 5351, 'A Idade Dourada S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/849100.mp4', 'http://gstaticontent.com/images/ccc636691a88c727767d451afe97d48f.jpg'),
(77991, 5351, 'A Idade Dourada S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/860004.mp4', 'http://gstaticontent.com/images/ccc636691a88c727767d451afe97d48f.jpg'),
(77992, 5351, 'A Idade Dourada S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/862210.mp4', 'http://gstaticontent.com/images/ccc636691a88c727767d451afe97d48f.jpg'),
(77993, 5351, 'A Idade Dourada S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/868427.mp4', 'http://gstaticontent.com/images/ccc636691a88c727767d451afe97d48f.jpg'),
(77994, 5351, 'A Idade Dourada S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/872566.mp4', 'http://gstaticontent.com/images/ccc636691a88c727767d451afe97d48f.jpg'),
(77995, 5351, 'A Idade Dourada S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/877556.mp4', 'http://gstaticontent.com/images/ccc636691a88c727767d451afe97d48f.jpg'),
(77996, 5351, 'A Idade Dourada S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/879589.mp4', 'http://gstaticontent.com/images/ccc636691a88c727767d451afe97d48f.jpg'),
(77997, 5351, 'A Idade Dourada S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/880073.mp4', 'http://gstaticontent.com/images/ccc636691a88c727767d451afe97d48f.jpg'),
(77998, 5352, 'A Boa Vizinhança S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240644.mp4', 'http://timg.bdta.pro/images/e64e353f9b72a4133269f70ed66c57a1.jpg'),
(77999, 5352, 'A Boa Vizinhança S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240645.mp4', 'http://timg.bdta.pro/images/63e629976d4cbd282a4cdbfe88c1a368.jpg'),
(78000, 5352, 'A Boa Vizinhança S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240646.mp4', 'http://timg.bdta.pro/images/d32efa0749f8dbbfee24afdadcd8aab0.jpg'),
(78001, 5352, 'A Boa Vizinhança S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240647.mp4', 'http://timg.bdta.pro/images/e02d4e31002e3d0855bcce18de9e8070.jpg'),
(78002, 5352, 'A Boa Vizinhança S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240648.mp4', 'http://timg.bdta.pro/images/f94cd8679a17f612c6bd041fc7dd726d.jpg'),
(78003, 5352, 'A Boa Vizinhança S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240649.mp4', 'http://timg.bdta.pro/images/f79c25ab613f12f77a3fcf797572847a.jpg'),
(78004, 5352, 'A Boa Vizinhança S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240650.mp4', 'http://timg.bdta.pro/images/1d67683a343a4d79f7f456567e2e43ec.jpg'),
(78005, 5352, 'A Boa Vizinhança S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240651.mp4', 'http://timg.bdta.pro/images/d93829f99ec7dc0bd1d07bbd4e6cf18a.jpg'),
(78006, 5352, 'A Boa Vizinhança S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240652.mp4', 'http://timg.bdta.pro/images/d97c151a9f866c188689fb4ade80725e.jpg'),
(78007, 5352, 'A Boa Vizinhança S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240653.mp4', 'http://timg.bdta.pro/images/931d420ae58c150cfa51e8beb55172f9.jpg'),
(78008, 5352, 'A Boa Vizinhança S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240654.mp4', 'http://timg.bdta.pro/images/ae1d791de67096b6cc8d25faf34b10f9.jpg'),
(78009, 5352, 'A Boa Vizinhança S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240655.mp4', 'http://timg.bdta.pro/images/a65f19c1ef672f4684b57df8bc73e92a.jpg'),
(78010, 5352, 'A Boa Vizinhança S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/240656.mp4', 'http://timg.bdta.pro/images/846a2e706d4c01d105a832c370e9a7fb.jpg'),
(78011, 5352, 'A Boa Vizinhança S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/240657.mp4', 'http://timg.bdta.pro/images/d459e47ed28e0f0ac50896dcd61d379a.jpg'),
(78012, 5352, 'A Boa Vizinhança S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/240658.mp4', 'http://timg.bdta.pro/images/370806e7a5f96047b05ff64cc0a84dac.jpg'),
(78013, 5352, 'A Boa Vizinhança S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/240659.mp4', 'http://timg.bdta.pro/images/240815c96425ade575d307ceb46fad19.jpg'),
(78014, 5352, 'A Boa Vizinhança S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/240660.mp4', 'http://timg.bdta.pro/images/c23140759f40e1d107da33608d61cee2.jpg'),
(78015, 5352, 'A Boa Vizinhança S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/240661.mp4', 'http://timg.bdta.pro/images/46fc90dfabeae6344ae6725a1c037497.jpg'),
(78016, 5352, 'A Boa Vizinhança S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/240662.mp4', 'http://timg.bdta.pro/images/2bed6ad5be421cf46e569023d7627043.jpg'),
(78017, 5352, 'A Boa Vizinhança S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/240663.mp4', 'http://timg.bdta.pro/images/807e4a8fb22b226a03fb6adb29c2517e.jpg'),
(78018, 5352, 'A Boa Vizinhança S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/240664.mp4', 'http://timg.bdta.pro/images/61b844aa40650f85fa96f729e65469ac.jpg'),
(78019, 5353, 'A Boa Vizinhança S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240665.mp4', 'http://timg.bdta.pro/images/36ec47c304bf4d2ffb47faa0adabfb41.jpg'),
(78020, 5353, 'A Boa Vizinhança S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240666.mp4', 'http://timg.bdta.pro/images/c7637ed9a7d682d1844fcd127cb0455f.jpg'),
(78021, 5353, 'A Boa Vizinhança S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240667.mp4', 'http://timg.bdta.pro/images/e99e2bc1098449411553adaf6324f316.jpg'),
(78022, 5353, 'A Boa Vizinhança S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240668.mp4', 'http://timg.bdta.pro/images/ad12d1f6e6ac6845604834c7215b7c50.jpg'),
(78023, 5353, 'A Boa Vizinhança S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240669.mp4', 'http://timg.bdta.pro/images/3375ac0f3345e020c4a5d970985d2572.jpg'),
(78024, 5353, 'A Boa Vizinhança S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240670.mp4', 'http://timg.bdta.pro/images/e795d1ee8c6a67deeea6f966d009e0bf.jpg'),
(78025, 5353, 'A Boa Vizinhança S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240671.mp4', 'http://timg.bdta.pro/images/539d51c7cf63c9de1a787e445aec7690.jpg'),
(78026, 5353, 'A Boa Vizinhança S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240672.mp4', 'http://timg.bdta.pro/images/8bb97eaf8dd5f66027b24d5eb41c7187.jpg'),
(78027, 5353, 'A Boa Vizinhança S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240673.mp4', 'http://timg.bdta.pro/images/22d7df928d2be9bd7d4e92319f2c1bc8.jpg'),
(78028, 5353, 'A Boa Vizinhança S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240674.mp4', 'http://timg.bdta.pro/images/fd7dc958fdf50ca72726965f99daec23.jpg'),
(78029, 5353, 'A Boa Vizinhança S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240675.mp4', 'http://timg.bdta.pro/images/a25122192762a57ab34ac5eacd488f02.jpg'),
(78030, 5353, 'A Boa Vizinhança S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240676.mp4', 'http://timg.bdta.pro/images/79bb009a6a5fe2e40b21f4c5cf5ab68c.jpg'),
(78031, 5353, 'A Boa Vizinhança S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/240677.mp4', 'http://timg.bdta.pro/images/3c3dcd71e478b7903864f3567bb2064f.jpg'),
(78032, 5353, 'A Boa Vizinhança S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/240678.mp4', 'http://timg.bdta.pro/images/871ff51cc0082ebcc502dd67bee90ada.jpg'),
(78033, 5353, 'A Boa Vizinhança S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/240679.mp4', 'http://timg.bdta.pro/images/02a40f7f0c6d6da08f67cccf569ea903.jpg'),
(78034, 5353, 'A Boa Vizinhança S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/240680.mp4', 'http://timg.bdta.pro/images/83ccb1f824e3ee3a4945e0ff4c321940.jpg'),
(78035, 5353, 'A Boa Vizinhança S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/240681.mp4', 'http://timg.bdta.pro/images/d98ad8b113faccd55c26e872ca073efb.jpg'),
(78036, 5353, 'A Boa Vizinhança S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/240682.mp4', 'http://timg.bdta.pro/images/6788f994626bd0f3833c48cc19c02897.jpg'),
(78037, 5353, 'A Boa Vizinhança S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/240683.mp4', 'http://timg.bdta.pro/images/93f6aa7983327b7da88186886cca08bb.jpg'),
(78038, 5353, 'A Boa Vizinhança S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/240684.mp4', 'http://timg.bdta.pro/images/666bf90965f8d37504616874a01a6587.jpg'),
(78039, 5353, 'A Boa Vizinhança S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/240685.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78040, 5353, 'A Boa Vizinhança S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/240686.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78041, 5354, 'A Boa Vizinhança S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/naNMcAGNUqbdQf1oCbVlk8bNhOQ.jpg'),
(78042, 5354, 'A Boa Vizinhança S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Td6hJ72qMZtOBBzhPjDDjL33Kk.jpg'),
(78043, 5354, 'A Boa Vizinhança S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p8aN6mS161T9Yj8WViHQwwcbHH3.jpg'),
(78044, 5354, 'A Boa Vizinhança S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/10D8uNjKOa8AIwn0Zyrmb6Ojjq8.jpg'),
(78045, 5354, 'A Boa Vizinhança S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wu0ybJV82jXvsVvyBHhVmAL4xNJ.jpg'),
(78046, 5354, 'A Boa Vizinhança S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTvemPPDxnhV5AYZih2Jdh3gpZA.jpg'),
(78047, 5354, 'A Boa Vizinhança S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wxnPPLwGSMsT9KMAGeN18sw2gki.jpg'),
(78048, 5354, 'A Boa Vizinhança S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4A41c0djhzQsZqzcWdmYpqP3HUp.jpg'),
(78049, 5354, 'A Boa Vizinhança S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r49jYID5Su2Cm7pZB0AZwFHV6ef.jpg'),
(78050, 5354, 'A Boa Vizinhança S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSBxqW19LwxVnXJ96w88eHCzQfS.jpg'),
(78051, 5354, 'A Boa Vizinhança S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nbtK5QN0Z9dydy3MRAd91qXyqke.jpg'),
(78052, 5354, 'A Boa Vizinhança S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jHGtWLoM68e8PujICjsoWaCgoV4.jpg'),
(78053, 5354, 'A Boa Vizinhança S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/240699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mcThDRxzMQGRSjbRiGBewTukj1Z.jpg'),
(78054, 5354, 'A Boa Vizinhança S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/240700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4mFvYCP0daA3ZAR8b8OuZ9pKGEl.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(78055, 5354, 'A Boa Vizinhança S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/240701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iRsKdsNfP6K1UTSg9ObYXD8ZtYv.jpg'),
(78056, 5354, 'A Boa Vizinhança S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/240702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cnYKvTvx4AQeDR0z9gX0buDQZyI.jpg'),
(78057, 5354, 'A Boa Vizinhança S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/240703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9XoVk1bcAoVZ52Cn8gSS9n1r35U.jpg'),
(78058, 5354, 'A Boa Vizinhança S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/240704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lLCAQHl5NKEeJJ9eElkHMmyXLzB.jpg'),
(78059, 5355, 'A Boa Vizinhança S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tLI96lizY5jFjAkXWSgA25AcmQe.jpg'),
(78060, 5355, 'A Boa Vizinhança S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8YhX6ZyFqQnFZojGB6mpjKihHlP.jpg'),
(78061, 5355, 'A Boa Vizinhança S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/guVjaLNOmzBWMhzzKXi2gvwkafZ.jpg'),
(78062, 5355, 'A Boa Vizinhança S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5vUxxlHvZR7YoJodRPXmUw0VhTL.jpg'),
(78063, 5355, 'A Boa Vizinhança S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3aE3OSLkjFnHQ9pRmjvDHnlJ7Kz.jpg'),
(78064, 5355, 'A Boa Vizinhança S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wdabvcb2FzvUQAXUXkZn07cOSji.jpg'),
(78065, 5355, 'A Boa Vizinhança S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8DWd7n2hGtKKPKh5IADQY7A8slj.jpg'),
(78066, 5355, 'A Boa Vizinhança S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kYATsrU2iePtxXSKxtkbkoXl1rD.jpg'),
(78067, 5355, 'A Boa Vizinhança S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nsOYl8YtCUBtxVz0yBakkiV1bxi.jpg'),
(78068, 5355, 'A Boa Vizinhança S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yda8n09OujymVcmI1o3Ss0L6Fmd.jpg'),
(78069, 5355, 'A Boa Vizinhança S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mO5a5LLgoWUMzKzrkMlYbwP1lW7.jpg'),
(78070, 5355, 'A Boa Vizinhança S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mSMfT6dJFS2QD9MYYP9KiLEGS9e.jpg'),
(78071, 5355, 'A Boa Vizinhança S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/240717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ozdPNPL5n9dSjQMXCdGrbinxmXL.jpg'),
(78072, 5355, 'A Boa Vizinhança S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/240718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p7qBsZdZva8XPOheoe3Sdbyq2ea.jpg'),
(78073, 5355, 'A Boa Vizinhança S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/240719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7gVX4YytqNSHf2RCfIRpb0Pzq1L.jpg'),
(78074, 5355, 'A Boa Vizinhança S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/240720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uAMKYpRn9W1a4fHzKCYXYTwvAWS.jpg'),
(78075, 5355, 'A Boa Vizinhança S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/240721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wgOuGY6XYhGAsY4MSZa8DGJNJcR.jpg'),
(78076, 5355, 'A Boa Vizinhança S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/240722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/XRKHW66qPyGIzD9TyyJpzT2Gtb.jpg'),
(78077, 5355, 'A Boa Vizinhança S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/240723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jpEIkzpdfvpHYI0UtGlypz4nsUb.jpg'),
(78078, 5355, 'A Boa Vizinhança S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/240724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u8t5hlqne4pDwSAMwEKzhCKCr8L.jpg'),
(78079, 5355, 'A Boa Vizinhança S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/240725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xr93iZB59uJZMLoKFVHDp6NZD31.jpg'),
(78080, 5355, 'A Boa Vizinhança S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/240726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/22XUj7koN3IRqZqWeaR5sF841MW.jpg'),
(78081, 5356, 'A Boa Vizinhança S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sX8hFaTyuvAwC5jmPEbrVXDoM4D.jpg'),
(78082, 5356, 'A Boa Vizinhança S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j0x1fAze4Rcrs8006ABPVoyt0BO.jpg'),
(78083, 5356, 'A Boa Vizinhança S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ppXUSdX1dtmzskydeequsimXAaF.jpg'),
(78084, 5356, 'A Boa Vizinhança S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2r6a3NzC7DvEHxUXwPrVqTuHQIG.jpg'),
(78085, 5356, 'A Boa Vizinhança S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aSnpGfwRkxDl9qbnrlsb0p6iIdT.jpg'),
(78086, 5356, 'A Boa Vizinhança S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e6YHwzUY1g8540GqQO5iPV4LDo.jpg'),
(78087, 5356, 'A Boa Vizinhança S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/euwWyNSGZkB4E4oLEQYGo26ZHTd.jpg'),
(78088, 5356, 'A Boa Vizinhança S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3idzbn7UQGZsETFkmuqLaOGhCWO.jpg'),
(78089, 5356, 'A Boa Vizinhança S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/55u856T57Ngu3SH3Txkbe7HJyOw.jpg'),
(78090, 5356, 'A Boa Vizinhança S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ure1LWfcWDYWB7mEONq226ZyxHd.jpg'),
(78091, 5356, 'A Boa Vizinhança S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j8wtS26qcfrlpa5dopl3qLFEegs.jpg'),
(78092, 5356, 'A Boa Vizinhança S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m4MXx7urGu4k3zVl7mN5kNcP3MV.jpg'),
(78093, 5356, 'A Boa Vizinhança S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/240739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ixPDEigcpB2kND2NBXUySZvobEk.jpg'),
(78094, 5356, 'A Boa Vizinhança S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/240740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zIJcBOz6d7hKWCzhcI4jDuJbgPs.jpg'),
(78095, 5356, 'A Boa Vizinhança S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/240741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b06dM0SIhgbtJ1wf6tFYbJ3tk5Z.jpg'),
(78096, 5356, 'A Boa Vizinhança S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/240742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eIyCTff3tiC8UrghKVtOPaicGTh.jpg'),
(78097, 5356, 'A Boa Vizinhança S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/240743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yVmbaU7xlfXIa8dvFHTRCTWbYRP.jpg'),
(78098, 5356, 'A Boa Vizinhança S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/240744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ftA2Gy0B19mg8RYC8B2NeE1Birt.jpg'),
(78099, 5356, 'A Boa Vizinhança S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/240745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fpumYXbjsElnzqZVQHvJEkKmuxC.jpg'),
(78100, 5356, 'A Boa Vizinhança S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/240746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sf92Gy0RT0ah4xHaEw295v3XtI3.jpg'),
(78101, 5356, 'A Boa Vizinhança S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/240747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3EhxpwvdTBGMfcZWnmAFZ9PaGfw.jpg'),
(78102, 5356, 'A Boa Vizinhança S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/240748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xUJEev7s6gobOpSANEKWg0RrcXS.jpg'),
(78103, 5357, 'A Boa Vizinhança S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413597.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78104, 5357, 'A Boa Vizinhança S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/415245.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78105, 5357, 'A Boa Vizinhança S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/422505.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78106, 5357, 'A Boa Vizinhança S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/428450.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78107, 5357, 'A Boa Vizinhança S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/430130.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78108, 5357, 'A Boa Vizinhança S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/437855.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78109, 5357, 'A Boa Vizinhança S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/443139.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78110, 5357, 'A Boa Vizinhança S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449101.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78111, 5357, 'A Boa Vizinhança S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/453129.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78112, 5357, 'A Boa Vizinhança S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/458742.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78113, 5358, 'A Boa Vizinhança S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/687996.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78114, 5358, 'A Boa Vizinhança S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/687997.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78115, 5358, 'A Boa Vizinhança S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/871881.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78116, 5358, 'A Boa Vizinhança S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/703438.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78117, 5358, 'A Boa Vizinhança S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/871865.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78118, 5358, 'A Boa Vizinhança S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/871866.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78119, 5358, 'A Boa Vizinhança S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/871867.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78120, 5358, 'A Boa Vizinhança S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/871868.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78121, 5358, 'A Boa Vizinhança S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/871869.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78122, 5358, 'A Boa Vizinhança S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/871870.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78123, 5358, 'A Boa Vizinhança S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/871871.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78124, 5358, 'A Boa Vizinhança S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/871872.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78125, 5358, 'A Boa Vizinhança S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/871873.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78126, 5358, 'A Boa Vizinhança S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/871874.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78127, 5358, 'A Boa Vizinhança S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/871875.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78128, 5358, 'A Boa Vizinhança S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/871876.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78129, 5358, 'A Boa Vizinhança S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/871877.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78130, 5358, 'A Boa Vizinhança S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/871878.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78131, 5358, 'A Boa Vizinhança S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/871879.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78132, 5358, 'A Boa Vizinhança S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/871880.mp4', 'http://gstaticontent.com/images/250eb792e23bf26926cac777554e77af.jpg'),
(78133, 5359, 'Além da Ilha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172809.mp4', 'http://gstaticontent.com/images/ca2b7b7c735de27b4ab0eafa46614326.jpg'),
(78134, 5359, 'Além da Ilha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172810.mp4', 'http://gstaticontent.com/images/ca2b7b7c735de27b4ab0eafa46614326.jpg'),
(78135, 5359, 'Além da Ilha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172811.mp4', 'http://gstaticontent.com/images/ca2b7b7c735de27b4ab0eafa46614326.jpg'),
(78136, 5359, 'Além da Ilha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172812.mp4', 'http://gstaticontent.com/images/ca2b7b7c735de27b4ab0eafa46614326.jpg'),
(78137, 5359, 'Além da Ilha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172813.mp4', 'http://gstaticontent.com/images/ca2b7b7c735de27b4ab0eafa46614326.jpg'),
(78138, 5359, 'Além da Ilha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172814.mp4', 'http://gstaticontent.com/images/ca2b7b7c735de27b4ab0eafa46614326.jpg'),
(78139, 5359, 'Além da Ilha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172815.mp4', 'http://gstaticontent.com/images/ca2b7b7c735de27b4ab0eafa46614326.jpg'),
(78140, 5359, 'Além da Ilha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172816.mp4', 'http://gstaticontent.com/images/ca2b7b7c735de27b4ab0eafa46614326.jpg'),
(78141, 5359, 'Além da Ilha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172817.mp4', 'http://gstaticontent.com/images/ca2b7b7c735de27b4ab0eafa46614326.jpg'),
(78142, 5359, 'Além da Ilha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172818.mp4', 'http://gstaticontent.com/images/ca2b7b7c735de27b4ab0eafa46614326.jpg'),
(78143, 5360, 'As Fabulosas Aventuras dos Freak Brothers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258688.mp4', 'http://timg.bdta.pro/images/5cf313ff7bef6efa890758de3940f16c.jpg'),
(78144, 5360, 'As Fabulosas Aventuras dos Freak Brothers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258689.mp4', 'http://timg.bdta.pro/images/c39704b7a1bec603668f7c7695f79cc5.jpg'),
(78145, 5360, 'As Fabulosas Aventuras dos Freak Brothers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258690.mp4', 'http://timg.bdta.pro/images/a79c3dc0ce2a17f7c91b1a1d621d6be2.jpg'),
(78146, 5360, 'As Fabulosas Aventuras dos Freak Brothers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258691.mp4', 'http://timg.bdta.pro/images/5f59e1030a4da5cc4e09991b5244199e.jpg'),
(78147, 5360, 'As Fabulosas Aventuras dos Freak Brothers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258692.mp4', 'http://timg.bdta.pro/images/5fca85d5a295c352f8586bd04b2df127.jpg'),
(78148, 5360, 'As Fabulosas Aventuras dos Freak Brothers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258693.mp4', 'http://timg.bdta.pro/images/ee1d011c55ff35b5a06397bb63ba64c6.jpg'),
(78149, 5360, 'As Fabulosas Aventuras dos Freak Brothers S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258694.mp4', 'http://timg.bdta.pro/images/fdc0c4a3012b7d1eaed9da04f18c2677.jpg'),
(78150, 5360, 'As Fabulosas Aventuras dos Freak Brothers S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258695.mp4', 'http://timg.bdta.pro/images/e13828f7467ecd96dbc6e07d47f7d1f5.jpg'),
(78151, 5361, 'As Fabulosas Aventuras dos Freak Brothers S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258696.mp4', 'http://gstaticontent.com/images/d2626079810355bf4ba59ec158a6ceb3.jpg'),
(78152, 5361, 'As Fabulosas Aventuras dos Freak Brothers S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258697.mp4', 'http://gstaticontent.com/images/d2626079810355bf4ba59ec158a6ceb3.jpg'),
(78153, 5361, 'As Fabulosas Aventuras dos Freak Brothers S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258698.mp4', 'http://gstaticontent.com/images/d2626079810355bf4ba59ec158a6ceb3.jpg'),
(78154, 5361, 'As Fabulosas Aventuras dos Freak Brothers S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258699.mp4', 'http://gstaticontent.com/images/d2626079810355bf4ba59ec158a6ceb3.jpg'),
(78155, 5361, 'As Fabulosas Aventuras dos Freak Brothers S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258700.mp4', 'http://gstaticontent.com/images/d2626079810355bf4ba59ec158a6ceb3.jpg'),
(78156, 5361, 'As Fabulosas Aventuras dos Freak Brothers S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258701.mp4', 'http://gstaticontent.com/images/d2626079810355bf4ba59ec158a6ceb3.jpg'),
(78157, 5361, 'As Fabulosas Aventuras dos Freak Brothers S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258702.mp4', 'http://gstaticontent.com/images/d2626079810355bf4ba59ec158a6ceb3.jpg'),
(78158, 5361, 'As Fabulosas Aventuras dos Freak Brothers S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258703.mp4', 'http://gstaticontent.com/images/d2626079810355bf4ba59ec158a6ceb3.jpg'),
(78159, 5362, 'Brinquedos que Marcam Época S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172797.mp4', 'http://timg.bdta.pro/images/c266c35966ff53e50ec0bc661b5f3962.jpg'),
(78160, 5362, 'Brinquedos que Marcam Época S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172798.mp4', 'http://timg.bdta.pro/images/b7a32ab3dc9c8165ef05f396821ed302.jpg'),
(78161, 5362, 'Brinquedos que Marcam Época S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172799.mp4', 'http://timg.bdta.pro/images/032719213e775572cb9fad0bf8e977a2.jpg'),
(78162, 5362, 'Brinquedos que Marcam Época S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172800.mp4', 'http://timg.bdta.pro/images/2d900f6e24e704f9fd3362e39ea63474.jpg'),
(78163, 5363, 'Brinquedos que Marcam Época S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172801.mp4', 'http://timg.bdta.pro/images/4a999582cba82f54b5acd5ec76f173c2.jpg'),
(78164, 5363, 'Brinquedos que Marcam Época S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172802.mp4', 'http://timg.bdta.pro/images/35ba6a088f4eacfb70141298c129087c.jpg'),
(78165, 5363, 'Brinquedos que Marcam Época S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172803.mp4', 'http://timg.bdta.pro/images/9715736047296dd4c06b66f354b2858b.jpg'),
(78166, 5363, 'Brinquedos que Marcam Época S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172804.mp4', 'http://timg.bdta.pro/images/78c73e1be3c013e7da1df21131d02f4a.jpg'),
(78167, 5364, 'Brinquedos que Marcam Época S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172805.mp4', 'http://timg.bdta.pro/images/aa921c85e0c7c1897928c8367e228557.jpg'),
(78168, 5364, 'Brinquedos que Marcam Época S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172806.mp4', 'http://timg.bdta.pro/images/6aadc1beb8a3866281527fce8e0966d8.jpg'),
(78169, 5364, 'Brinquedos que Marcam Época S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172807.mp4', 'http://timg.bdta.pro/images/ce6d06e548e1c5ac6715aff97c172444.jpg'),
(78170, 5364, 'Brinquedos que Marcam Época S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172808.mp4', 'http://timg.bdta.pro/images/eb46e9c48082a66cc7627b69bcdc10df.jpg'),
(78171, 5365, 'Cecilia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172789.mp4', 'http://timg.bdta.pro/images/d1d6b90d016402dd2a5f21eba444e68d.jpg'),
(78172, 5365, 'Cecilia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172790.mp4', 'http://timg.bdta.pro/images/f0cf1ad6f87fa457588e2b4ca68882c8.jpg'),
(78173, 5365, 'Cecilia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172791.mp4', 'http://timg.bdta.pro/images/b3ca23ef8c2b4570bb9e6f0392c9328e.jpg'),
(78174, 5365, 'Cecilia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172792.mp4', 'http://timg.bdta.pro/images/59e1ff2d806cec0097724efb600122ef.jpg'),
(78175, 5365, 'Cecilia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172793.mp4', 'http://timg.bdta.pro/images/16d76690477edf32999ec93d93120ca2.jpg'),
(78176, 5365, 'Cecilia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172794.mp4', 'http://timg.bdta.pro/images/a53a47965f60a363f07b7deb8a289fab.jpg'),
(78177, 5365, 'Cecilia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172795.mp4', 'http://timg.bdta.pro/images/6186b71fa2f8ca4deff45c162a3c3c21.jpg'),
(78178, 5365, 'Cecilia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172796.mp4', 'http://timg.bdta.pro/images/07d206b457b39c0ff53b0111fc6374dd.jpg'),
(78179, 5366, 'Depois da Festa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231990.mp4', 'http://timg.bdta.pro/images/d77fdfa9c8487f62a662312d9dfcc3c1.jpg'),
(78180, 5366, 'Depois da Festa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231991.mp4', 'http://timg.bdta.pro/images/5ac669c638682c90482e2b7fb9b3c4bc.jpg'),
(78181, 5366, 'Depois da Festa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231992.mp4', 'http://timg.bdta.pro/images/610d3e4540bdc55aaf189423823af193.jpg'),
(78182, 5366, 'Depois da Festa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231993.mp4', 'http://timg.bdta.pro/images/68eb2c3022f308dee8746994d98bcf4a.jpg'),
(78183, 5366, 'Depois da Festa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231994.mp4', 'http://timg.bdta.pro/images/fb512ecb58da0654f633938515f08e21.jpg'),
(78184, 5366, 'Depois da Festa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231995.mp4', 'http://timg.bdta.pro/images/09fe3334560b5776aa60c4aec136590d.jpg'),
(78185, 5366, 'Depois da Festa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231996.mp4', 'http://timg.bdta.pro/images/c9b06defe20eecbb3c5aca951b709d3f.jpg'),
(78186, 5366, 'Depois da Festa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231997.mp4', 'http://timg.bdta.pro/images/d48b0ff66713463e4b9a40b8aa485645.jpg'),
(78187, 5367, 'Depois da Festa S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2h1K0G7IkREydO9z6d1FTjijtH.jpg'),
(78188, 5367, 'Depois da Festa S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/66EWkqvXXO80vnjomuPlTbLSUTk.jpg'),
(78189, 5367, 'Depois da Festa S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232000.mp4', 'http://image.tmdb.org/t/p/w1280/3XRkWMS0ib6AGNrqkNqfCLcvEoQ.jpg'),
(78190, 5367, 'Depois da Festa S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232001.mp4', 'http://image.tmdb.org/t/p/w1280/x8VHQADKsMuhn84cmoiiJWvCMr4.jpg'),
(78191, 5367, 'Depois da Festa S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232002.mp4', 'http://image.tmdb.org/t/p/w1280/w92pFDB22tHMiYAJl672i0rUKss.jpg'),
(78192, 5367, 'Depois da Festa S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232003.mp4', 'http://image.tmdb.org/t/p/w1280/rKCZVyD3RDGuCl9NfMt7K9hwCdd.jpg'),
(78193, 5367, 'Depois da Festa S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232004.mp4', 'http://image.tmdb.org/t/p/w1280/hzT2o0vGR3kdxHMtk4UUG1CPYIC.jpg'),
(78194, 5367, 'Depois da Festa S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232005.mp4', 'http://image.tmdb.org/t/p/w1280/fap2KQOB6qDfIPQzwUiSYeRGLEw.jpg'),
(78195, 5367, 'Depois da Festa S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232006.mp4', 'http://image.tmdb.org/t/p/w1280/zjjZIEqFeysP4VHgKVUXCi05zlP.jpg'),
(78196, 5367, 'Depois da Festa S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232007.mp4', 'http://image.tmdb.org/t/p/w1280/9Qg4RJmvu8bZvqqGnaYT2p4uvnw.jpg'),
(78197, 5368, 'Gus: O Pequeno Cavaleiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172763.mp4', 'http://timg.bdta.pro/images/8d529a80d5c32b7f1366c099d5c4be70.jpg'),
(78198, 5368, 'Gus: O Pequeno Cavaleiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172764.mp4', 'http://timg.bdta.pro/images/0075d39e382dd656b773c64116112925.jpg'),
(78199, 5368, 'Gus: O Pequeno Cavaleiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172765.mp4', 'http://timg.bdta.pro/images/21968fc37e938545307d7fe25de5b8cd.jpg'),
(78200, 5368, 'Gus: O Pequeno Cavaleiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172766.mp4', 'http://timg.bdta.pro/images/caf404dca15d2af62cd1a775745b2afa.jpg'),
(78201, 5368, 'Gus: O Pequeno Cavaleiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172767.mp4', 'http://timg.bdta.pro/images/d81d04b87e2ae884cd9e0b0bafb9875a.jpg'),
(78202, 5368, 'Gus: O Pequeno Cavaleiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172768.mp4', 'http://timg.bdta.pro/images/d3a9bd6c176e2e36eb6893accb6c3dc8.jpg'),
(78203, 5368, 'Gus: O Pequeno Cavaleiro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172769.mp4', 'http://timg.bdta.pro/images/b957711c21e3867de3a76538cde48e50.jpg'),
(78204, 5368, 'Gus: O Pequeno Cavaleiro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172770.mp4', 'http://timg.bdta.pro/images/ea6cbaf3ae7efc9776ba7b6401820948.jpg'),
(78205, 5368, 'Gus: O Pequeno Cavaleiro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172771.mp4', 'http://timg.bdta.pro/images/1878bc4ee1f8302b7933fbeb3afa5679.jpg'),
(78206, 5368, 'Gus: O Pequeno Cavaleiro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172772.mp4', 'http://timg.bdta.pro/images/7554126b6952c97b5cf1c753b2145cea.jpg'),
(78207, 5368, 'Gus: O Pequeno Cavaleiro S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172773.mp4', 'http://timg.bdta.pro/images/362a467f2f84b139b5be92dbc3a922bf.jpg'),
(78208, 5368, 'Gus: O Pequeno Cavaleiro S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172774.mp4', 'http://timg.bdta.pro/images/c229b8ac0940fa399f8356416364a339.jpg'),
(78209, 5368, 'Gus: O Pequeno Cavaleiro S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172775.mp4', 'http://timg.bdta.pro/images/db8238254187079e665a5a6e07caf047.jpg'),
(78210, 5368, 'Gus: O Pequeno Cavaleiro S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172776.mp4', 'http://timg.bdta.pro/images/9ccca801439da0cb24110b769757853f.jpg'),
(78211, 5368, 'Gus: O Pequeno Cavaleiro S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/172777.mp4', 'http://timg.bdta.pro/images/32f39e90542e3a920600a272559ca64f.jpg'),
(78212, 5368, 'Gus: O Pequeno Cavaleiro S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/172778.mp4', 'http://timg.bdta.pro/images/008191348a27163077e588320239e2e1.jpg'),
(78213, 5368, 'Gus: O Pequeno Cavaleiro S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/172779.mp4', 'http://timg.bdta.pro/images/d0d971202108a2194c0ffbcce4975b3d.jpg'),
(78214, 5368, 'Gus: O Pequeno Cavaleiro S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/172780.mp4', 'http://timg.bdta.pro/images/7eab0f7f9f7d8c065c25b81d73dff281.jpg'),
(78215, 5368, 'Gus: O Pequeno Cavaleiro S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/172781.mp4', 'http://timg.bdta.pro/images/fbe252c3025ad8100ee92caef22513c1.jpg'),
(78216, 5368, 'Gus: O Pequeno Cavaleiro S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/172782.mp4', 'http://timg.bdta.pro/images/f1a4a6871f21316d9e07dbd7bb14076d.jpg'),
(78217, 5368, 'Gus: O Pequeno Cavaleiro S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/172783.mp4', 'http://timg.bdta.pro/images/5dba78200244b1a68ebb97464fdd46db.jpg'),
(78218, 5368, 'Gus: O Pequeno Cavaleiro S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/172784.mp4', 'http://timg.bdta.pro/images/f5daac3ec606993b6faa113670909062.jpg'),
(78219, 5368, 'Gus: O Pequeno Cavaleiro S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/172785.mp4', 'http://timg.bdta.pro/images/1cb005b8fea811a2027d89b3d88cc1b5.jpg'),
(78220, 5368, 'Gus: O Pequeno Cavaleiro S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/172786.mp4', 'http://timg.bdta.pro/images/e7694c5e95e848c2687f6d575c28418b.jpg'),
(78221, 5368, 'Gus: O Pequeno Cavaleiro S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/172787.mp4', 'http://timg.bdta.pro/images/de990f130a68db034c2ad3c7f9734929.jpg'),
(78222, 5368, 'Gus: O Pequeno Cavaleiro S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/172788.mp4', 'http://timg.bdta.pro/images/ddc5eb010ffdc540b785b8c62c924370.jpg'),
(78223, 5369, 'Ideias à Venda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172757.mp4', 'http://gstaticontent.com/images/777d5b8427ea9bac67b08b59a68428ea.jpg'),
(78224, 5369, 'Ideias à Venda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172758.mp4', 'http://gstaticontent.com/images/777d5b8427ea9bac67b08b59a68428ea.jpg'),
(78225, 5369, 'Ideias à Venda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172759.mp4', 'http://gstaticontent.com/images/777d5b8427ea9bac67b08b59a68428ea.jpg'),
(78226, 5369, 'Ideias à Venda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172760.mp4', 'http://gstaticontent.com/images/777d5b8427ea9bac67b08b59a68428ea.jpg'),
(78227, 5369, 'Ideias à Venda S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172761.mp4', 'http://gstaticontent.com/images/777d5b8427ea9bac67b08b59a68428ea.jpg'),
(78228, 5369, 'Ideias à Venda S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172762.mp4', 'http://gstaticontent.com/images/777d5b8427ea9bac67b08b59a68428ea.jpg'),
(78229, 5370, 'Inventando Anna S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172748.mp4', 'http://timg.bdta.pro/images/cf6d021d44d355be531c5cd679bccecd.jpg'),
(78230, 5370, 'Inventando Anna S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172749.mp4', 'http://timg.bdta.pro/images/88c8a7bbe3c397b1561f84f6d75f84c9.jpg'),
(78231, 5370, 'Inventando Anna S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172750.mp4', 'http://timg.bdta.pro/images/26cf088eaf4b832f6125e2d7886b9b79.jpg'),
(78232, 5370, 'Inventando Anna S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172751.mp4', 'http://timg.bdta.pro/images/a123845b0f1582413624f501122c2228.jpg'),
(78233, 5370, 'Inventando Anna S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172752.mp4', 'http://timg.bdta.pro/images/6f299f9441ad318fcc3f3d9f9b914ae2.jpg'),
(78234, 5370, 'Inventando Anna S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172753.mp4', 'http://timg.bdta.pro/images/c2038f921bd1c66e0a654d3acdab2968.jpg'),
(78235, 5370, 'Inventando Anna S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172754.mp4', 'http://timg.bdta.pro/images/1bead49b7c8da8ba1a316c29673792ba.jpg'),
(78236, 5370, 'Inventando Anna S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172755.mp4', 'http://timg.bdta.pro/images/d5538f3376cd36c62a0d9268e596b2f4.jpg'),
(78237, 5370, 'Inventando Anna S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172756.mp4', 'http://timg.bdta.pro/images/4cd7bcf39b32ee74d9230cf481ac07b7.jpg'),
(78238, 5371, 'Komi San Wa Comyushou Desu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194668.mp4', 'http://timg.bdta.pro/images/e0ca7d7d060789a3cf76e9ce630d4c60.jpg'),
(78239, 5371, 'Komi San Wa Comyushou Desu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194669.mp4', 'http://timg.bdta.pro/images/ad07e46b3c4e062cae7ca2365683fca3.jpg'),
(78240, 5371, 'Komi San Wa Comyushou Desu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194670.mp4', 'http://timg.bdta.pro/images/b55affbf7dd1a465e6ac2bb86fb70b35.jpg'),
(78241, 5371, 'Komi San Wa Comyushou Desu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194671.mp4', 'http://timg.bdta.pro/images/86f5e65413f4e6dc77a0faac6e86d054.jpg'),
(78242, 5371, 'Komi San Wa Comyushou Desu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194672.mp4', 'http://timg.bdta.pro/images/9f8d0d9ed9b71d0e92cd33356d7b6292.jpg'),
(78243, 5371, 'Komi San Wa Comyushou Desu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194673.mp4', 'http://timg.bdta.pro/images/7b923ed963472fe70fb34541c69e578d.jpg'),
(78244, 5371, 'Komi San Wa Comyushou Desu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194674.mp4', 'http://timg.bdta.pro/images/388929ad8a637ab5d8d04fc2bf1ab183.jpg'),
(78245, 5371, 'Komi San Wa Comyushou Desu S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194675.mp4', 'http://timg.bdta.pro/images/48a0ad70cfb695799523c7884c813b9f.jpg'),
(78246, 5371, 'Komi San Wa Comyushou Desu S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194676.mp4', 'http://timg.bdta.pro/images/0dc1fd4e2feba352e620646fb8dc4daf.jpg'),
(78247, 5371, 'Komi San Wa Comyushou Desu S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194677.mp4', 'http://timg.bdta.pro/images/0a575c2755bee7e57a1604d8f77ab1fd.jpg'),
(78248, 5371, 'Komi San Wa Comyushou Desu S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194678.mp4', 'http://timg.bdta.pro/images/32adbf75877a1ae5ba4c28db1de23ec3.jpg'),
(78249, 5371, 'Komi San Wa Comyushou Desu S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194679.mp4', 'http://timg.bdta.pro/images/b85da670cd5c6e2b6dfb525677f432ac.jpg'),
(78250, 5372, 'Komi San Wa Comyushou Desu S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194680.mp4', 'http://gstaticontent.com/images/6372db2c78b88718b90ee45deb878a14.jpg'),
(78251, 5372, 'Komi San Wa Comyushou Desu S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194681.mp4', 'http://gstaticontent.com/images/6372db2c78b88718b90ee45deb878a14.jpg'),
(78252, 5372, 'Komi San Wa Comyushou Desu S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194682.mp4', 'http://gstaticontent.com/images/6372db2c78b88718b90ee45deb878a14.jpg'),
(78253, 5372, 'Komi San Wa Comyushou Desu S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194683.mp4', 'http://gstaticontent.com/images/6372db2c78b88718b90ee45deb878a14.jpg'),
(78254, 5372, 'Komi San Wa Comyushou Desu S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194684.mp4', 'http://gstaticontent.com/images/6372db2c78b88718b90ee45deb878a14.jpg'),
(78255, 5372, 'Komi San Wa Comyushou Desu S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194685.mp4', 'http://gstaticontent.com/images/6372db2c78b88718b90ee45deb878a14.jpg'),
(78256, 5372, 'Komi San Wa Comyushou Desu S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194686.mp4', 'http://gstaticontent.com/images/6372db2c78b88718b90ee45deb878a14.jpg'),
(78257, 5372, 'Komi San Wa Comyushou Desu S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194687.mp4', 'http://gstaticontent.com/images/6372db2c78b88718b90ee45deb878a14.jpg'),
(78258, 5372, 'Komi San Wa Comyushou Desu S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194688.mp4', 'http://gstaticontent.com/images/6372db2c78b88718b90ee45deb878a14.jpg'),
(78259, 5372, 'Komi San Wa Comyushou Desu S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194689.mp4', 'http://gstaticontent.com/images/6372db2c78b88718b90ee45deb878a14.jpg'),
(78260, 5372, 'Komi San Wa Comyushou Desu S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194690.mp4', 'http://gstaticontent.com/images/6372db2c78b88718b90ee45deb878a14.jpg'),
(78261, 5372, 'Komi San Wa Comyushou Desu S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194691.mp4', 'http://gstaticontent.com/images/6372db2c78b88718b90ee45deb878a14.jpg'),
(78262, 5373, 'Kyuukyoku Shinka Shita Full Dive RPG ga Genjitsu yori mo Kusogee Dattara S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172736.mp4', 'http://timg.bdta.pro/images/3ac2fbb8e53dd86a0a2aeadb2ca3bdcb.jpg'),
(78263, 5373, 'Kyuukyoku Shinka Shita Full Dive RPG ga Genjitsu yori mo Kusogee Dattara S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172737.mp4', 'http://timg.bdta.pro/images/cfd3c909a9caf1e007c9464a21faa5e9.jpg'),
(78264, 5373, 'Kyuukyoku Shinka Shita Full Dive RPG ga Genjitsu yori mo Kusogee Dattara S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172738.mp4', 'http://timg.bdta.pro/images/2c876d215c175dca010675b76ff13729.jpg'),
(78265, 5373, 'Kyuukyoku Shinka Shita Full Dive RPG ga Genjitsu yori mo Kusogee Dattara S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172739.mp4', 'http://timg.bdta.pro/images/0e10dfd671816e16a9bc2d0c637f1d1d.jpg'),
(78266, 5373, 'Kyuukyoku Shinka Shita Full Dive RPG ga Genjitsu yori mo Kusogee Dattara S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172740.mp4', 'http://timg.bdta.pro/images/2d942ec53e23cab40c87e7b45744a8a8.jpg'),
(78267, 5373, 'Kyuukyoku Shinka Shita Full Dive RPG ga Genjitsu yori mo Kusogee Dattara S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172741.mp4', 'http://timg.bdta.pro/images/34a599d49d004f1d39d7479a01bb1acf.jpg'),
(78268, 5373, 'Kyuukyoku Shinka Shita Full Dive RPG ga Genjitsu yori mo Kusogee Dattara S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172742.mp4', 'http://timg.bdta.pro/images/968ab85698a2648d43f64ee6fafb8068.jpg'),
(78269, 5373, 'Kyuukyoku Shinka Shita Full Dive RPG ga Genjitsu yori mo Kusogee Dattara S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172743.mp4', 'http://timg.bdta.pro/images/5a53f706c1f468b7c900af8867d9b097.jpg'),
(78270, 5373, 'Kyuukyoku Shinka Shita Full Dive RPG ga Genjitsu yori mo Kusogee Dattara S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172744.mp4', 'http://timg.bdta.pro/images/1473f01dd54b22a5e236a06b8d544b3b.jpg'),
(78271, 5373, 'Kyuukyoku Shinka Shita Full Dive RPG ga Genjitsu yori mo Kusogee Dattara S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172745.mp4', 'http://timg.bdta.pro/images/3f634b7ae2fe89fd60707d159d31c47f.jpg'),
(78272, 5373, 'Kyuukyoku Shinka Shita Full Dive RPG ga Genjitsu yori mo Kusogee Dattara S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172746.mp4', 'http://timg.bdta.pro/images/098ff72ed0b8f83bf329aa0b6f172684.jpg'),
(78273, 5373, 'Kyuukyoku Shinka Shita Full Dive RPG ga Genjitsu yori mo Kusogee Dattara S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172747.mp4', 'http://timg.bdta.pro/images/434417c6010fee4527c18db265118b9f.jpg'),
(78274, 5374, 'O Acampamento de Lazlo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172683.mp4', 'http://timg.bdta.pro/images/b0ba902b755dd5f597bfec1112dbe423.jpg'),
(78275, 5374, 'O Acampamento de Lazlo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172684.mp4', 'http://timg.bdta.pro/images/fa9206b102ae2c7127278ac5bf0ac1f0.jpg'),
(78276, 5374, 'O Acampamento de Lazlo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172685.mp4', 'http://timg.bdta.pro/images/344ddd28da0d0675ddd1d69a860deb42.jpg'),
(78277, 5374, 'O Acampamento de Lazlo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172686.mp4', 'http://timg.bdta.pro/images/78bef287dd06f292e1e1136f49384bba.jpg'),
(78278, 5374, 'O Acampamento de Lazlo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172687.mp4', 'http://timg.bdta.pro/images/749d9df2ef49c0bcf5d663f3114f2d9a.jpg'),
(78279, 5374, 'O Acampamento de Lazlo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172688.mp4', 'http://timg.bdta.pro/images/623eedc5220473a8d4ed1115ca835a8a.jpg'),
(78280, 5374, 'O Acampamento de Lazlo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172689.mp4', 'http://timg.bdta.pro/images/1780ea263976c40c66bf18335a9cc817.jpg'),
(78281, 5374, 'O Acampamento de Lazlo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172690.mp4', 'http://timg.bdta.pro/images/c1a7c93a99ff1ff77865be44e8fae829.jpg'),
(78282, 5374, 'O Acampamento de Lazlo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172691.mp4', 'http://timg.bdta.pro/images/856bb892d688235cdfdb71b47e4e7bed.jpg'),
(78283, 5374, 'O Acampamento de Lazlo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172692.mp4', 'http://timg.bdta.pro/images/6aee0579d28698f01fdbae7dea7140d0.jpg'),
(78284, 5374, 'O Acampamento de Lazlo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172693.mp4', 'http://timg.bdta.pro/images/8b188f78c2ca4c9b2a7876337348a0f6.jpg'),
(78285, 5374, 'O Acampamento de Lazlo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172694.mp4', 'http://timg.bdta.pro/images/1861054dd3a72e8a001ab3f4868750ff.jpg'),
(78286, 5374, 'O Acampamento de Lazlo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172695.mp4', 'http://timg.bdta.pro/images/e1688d6943f0c456ed7be181bd59e2f7.jpg'),
(78287, 5375, 'O Acampamento de Lazlo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172696.mp4', 'http://timg.bdta.pro/images/b159863648c05f17581e7949dd5745aa.jpg'),
(78288, 5375, 'O Acampamento de Lazlo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172697.mp4', 'http://timg.bdta.pro/images/ce7d8a3d21f3d5acd63acdbf929781aa.jpg'),
(78289, 5375, 'O Acampamento de Lazlo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172698.mp4', 'http://timg.bdta.pro/images/ddb7bf0ada5420b67c0a1eb0ec3a1e88.jpg'),
(78290, 5375, 'O Acampamento de Lazlo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172699.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78291, 5375, 'O Acampamento de Lazlo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172700.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78292, 5375, 'O Acampamento de Lazlo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172701.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78293, 5375, 'O Acampamento de Lazlo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172702.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78294, 5375, 'O Acampamento de Lazlo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172703.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78295, 5375, 'O Acampamento de Lazlo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172704.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78296, 5375, 'O Acampamento de Lazlo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172705.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78297, 5375, 'O Acampamento de Lazlo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172706.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78298, 5375, 'O Acampamento de Lazlo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172707.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78299, 5375, 'O Acampamento de Lazlo S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172708.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78300, 5376, 'O Acampamento de Lazlo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172709.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78301, 5376, 'O Acampamento de Lazlo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172710.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78302, 5376, 'O Acampamento de Lazlo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172711.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78303, 5376, 'O Acampamento de Lazlo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172712.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78304, 5376, 'O Acampamento de Lazlo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172713.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78305, 5376, 'O Acampamento de Lazlo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172714.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78306, 5376, 'O Acampamento de Lazlo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172715.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78307, 5376, 'O Acampamento de Lazlo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172716.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78308, 5376, 'O Acampamento de Lazlo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172717.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78309, 5376, 'O Acampamento de Lazlo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172718.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78310, 5376, 'O Acampamento de Lazlo S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172719.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78311, 5376, 'O Acampamento de Lazlo S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172720.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78312, 5376, 'O Acampamento de Lazlo S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172721.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78313, 5376, 'O Acampamento de Lazlo S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172722.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78314, 5377, 'O Acampamento de Lazlo S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172723.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78315, 5377, 'O Acampamento de Lazlo S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172724.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78316, 5377, 'O Acampamento de Lazlo S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172725.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78317, 5377, 'O Acampamento de Lazlo S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172726.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78318, 5377, 'O Acampamento de Lazlo S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172727.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78319, 5377, 'O Acampamento de Lazlo S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172728.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78320, 5377, 'O Acampamento de Lazlo S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172729.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78321, 5377, 'O Acampamento de Lazlo S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172730.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78322, 5377, 'O Acampamento de Lazlo S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172731.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78323, 5377, 'O Acampamento de Lazlo S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172732.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78324, 5377, 'O Acampamento de Lazlo S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172733.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(78325, 5377, 'O Acampamento de Lazlo S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172734.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78326, 5377, 'O Acampamento de Lazlo S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172735.mp4', 'http://gstaticontent.com/images/0eb485439d75ab5e0738a3e93e02d258.jpg'),
(78327, 5378, 'O Caso Celso Daniel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203569.mp4', 'http://timg.bdta.pro/images/8c722c52d20ed0d73e27d1f67387e6e6.jpg'),
(78328, 5378, 'O Caso Celso Daniel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203570.mp4', 'http://timg.bdta.pro/images/f5f90bae75e644d3519d123807fba472.jpg'),
(78329, 5378, 'O Caso Celso Daniel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203571.mp4', 'http://gstaticontent.com/images/b1c8a6169953acb5896fad49dbf7933e.jpg'),
(78330, 5378, 'O Caso Celso Daniel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203572.mp4', 'http://gstaticontent.com/images/b1c8a6169953acb5896fad49dbf7933e.jpg'),
(78331, 5378, 'O Caso Celso Daniel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203573.mp4', 'http://gstaticontent.com/images/b1c8a6169953acb5896fad49dbf7933e.jpg'),
(78332, 5378, 'O Caso Celso Daniel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203574.mp4', 'http://gstaticontent.com/images/b1c8a6169953acb5896fad49dbf7933e.jpg'),
(78333, 5378, 'O Caso Celso Daniel S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203575.mp4', 'http://gstaticontent.com/images/b1c8a6169953acb5896fad49dbf7933e.jpg'),
(78334, 5378, 'O Caso Celso Daniel S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203576.mp4', 'http://gstaticontent.com/images/b1c8a6169953acb5896fad49dbf7933e.jpg'),
(78335, 5379, 'O Laboratório de Dexter S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172632.mp4', 'http://timg.bdta.pro/images/cfc75874319e9a3202f49ef76060b343.jpg'),
(78336, 5379, 'O Laboratório de Dexter S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172633.mp4', 'http://timg.bdta.pro/images/876b6f2e45cc38e3d00bac9740dd269a.jpg'),
(78337, 5379, 'O Laboratório de Dexter S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172634.mp4', 'http://timg.bdta.pro/images/fbbc2d65a58e90e414792c871ce18380.jpg'),
(78338, 5379, 'O Laboratório de Dexter S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172635.mp4', 'http://timg.bdta.pro/images/85223fac45f55bcd26fe8613602ace1c.jpg'),
(78339, 5379, 'O Laboratório de Dexter S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172636.mp4', 'http://timg.bdta.pro/images/c50b80b01ef995cd872ed255afa60271.jpg'),
(78340, 5379, 'O Laboratório de Dexter S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172637.mp4', 'http://timg.bdta.pro/images/a59470491d3f72af884480a1c470f76b.jpg'),
(78341, 5379, 'O Laboratório de Dexter S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172638.mp4', 'http://timg.bdta.pro/images/7de668da16082c87e8f72a639ac6f4a9.jpg'),
(78342, 5379, 'O Laboratório de Dexter S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172639.mp4', 'http://timg.bdta.pro/images/9b20e08b547ef6712095cd65b80df7a4.jpg'),
(78343, 5379, 'O Laboratório de Dexter S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172640.mp4', 'http://timg.bdta.pro/images/8fc29992468d0fb34e31e4fbd5a77300.jpg'),
(78344, 5379, 'O Laboratório de Dexter S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172641.mp4', 'http://timg.bdta.pro/images/b83ec918bafefa17eded916b80cef42e.jpg'),
(78345, 5379, 'O Laboratório de Dexter S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172642.mp4', 'http://timg.bdta.pro/images/9010dc77711c4b472bf519556989819e.jpg'),
(78346, 5379, 'O Laboratório de Dexter S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172643.mp4', 'http://timg.bdta.pro/images/a3d9d5eaec1e28cc07802b87e01456b5.jpg'),
(78347, 5380, 'O Laboratório de Dexter S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172644.mp4', 'http://timg.bdta.pro/images/64122638fcc86799e297c247217acd9f.jpg'),
(78348, 5380, 'O Laboratório de Dexter S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172645.mp4', 'http://timg.bdta.pro/images/e8de1f5a846fa23d67fcf47cfa1d56ad.jpg'),
(78349, 5380, 'O Laboratório de Dexter S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172646.mp4', 'http://timg.bdta.pro/images/f4dc2c3552f22b21057f9d600d44def1.jpg'),
(78350, 5380, 'O Laboratório de Dexter S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172647.mp4', 'http://timg.bdta.pro/images/9e8a2d7312626a219a23f15a82ec7ae9.jpg'),
(78351, 5380, 'O Laboratório de Dexter S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172648.mp4', 'http://timg.bdta.pro/images/cf186f14dc29320d073c31e0aaa13859.jpg'),
(78352, 5380, 'O Laboratório de Dexter S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172649.mp4', 'http://timg.bdta.pro/images/22d12236ce3da76907b6014547e92730.jpg'),
(78353, 5380, 'O Laboratório de Dexter S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172650.mp4', 'http://timg.bdta.pro/images/c31c4cde561e6a88ef5522b50cd183c4.jpg'),
(78354, 5380, 'O Laboratório de Dexter S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172651.mp4', 'http://timg.bdta.pro/images/05c25c96a92e2e64f0564cc14c6c0251.jpg'),
(78355, 5380, 'O Laboratório de Dexter S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172652.mp4', 'http://timg.bdta.pro/images/8a1e5d87fc589946446e618bbac94fc7.jpg'),
(78356, 5380, 'O Laboratório de Dexter S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172653.mp4', 'http://timg.bdta.pro/images/5437d26cd9fe5b30a9c24bdf63170c06.jpg'),
(78357, 5380, 'O Laboratório de Dexter S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172654.mp4', 'http://timg.bdta.pro/images/b878303841f834532c6611759151574b.jpg'),
(78358, 5380, 'O Laboratório de Dexter S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172655.mp4', 'http://timg.bdta.pro/images/be28d375e35fe7b38689d53572114fca.jpg'),
(78359, 5380, 'O Laboratório de Dexter S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172656.mp4', 'http://timg.bdta.pro/images/f18c49cac6177d4d95fbbb434c5a3e61.jpg'),
(78360, 5381, 'O Laboratório de Dexter S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172657.mp4', 'http://timg.bdta.pro/images/d2e399d6c24c657054ec2b27389b979e.jpg'),
(78361, 5381, 'O Laboratório de Dexter S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172658.mp4', 'http://timg.bdta.pro/images/6eed7e4838fb56bb56f151fd92ebb3a5.jpg'),
(78362, 5381, 'O Laboratório de Dexter S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172659.mp4', 'http://timg.bdta.pro/images/2d37db479e1f57d4fbcb8ab04381081c.jpg'),
(78363, 5381, 'O Laboratório de Dexter S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172660.mp4', 'http://timg.bdta.pro/images/fea589f0003b60f1d92a62fe7bc9c171.jpg'),
(78364, 5381, 'O Laboratório de Dexter S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172661.mp4', 'http://timg.bdta.pro/images/cc25a13bcb456c88c5c3651dc1d56689.jpg'),
(78365, 5381, 'O Laboratório de Dexter S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172662.mp4', 'http://timg.bdta.pro/images/02facf4005cbf510ab6cb02cc90de11d.jpg'),
(78366, 5381, 'O Laboratório de Dexter S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172663.mp4', 'http://timg.bdta.pro/images/7adecd8ad34b8c172d1e31f4bd659b32.jpg'),
(78367, 5381, 'O Laboratório de Dexter S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172664.mp4', 'http://timg.bdta.pro/images/6646fc3a5f6e4c82e68d7ea0a1ae62a4.jpg'),
(78368, 5381, 'O Laboratório de Dexter S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172665.mp4', 'http://timg.bdta.pro/images/c8f545761076a9446d4f294a48d74a10.jpg'),
(78369, 5381, 'O Laboratório de Dexter S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172666.mp4', 'http://timg.bdta.pro/images/88f8ba88830bb557f404e8d597a4cd92.jpg'),
(78370, 5381, 'O Laboratório de Dexter S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172667.mp4', 'http://timg.bdta.pro/images/75475a9e0289c19a6780c1938bc5d7c6.jpg'),
(78371, 5381, 'O Laboratório de Dexter S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172668.mp4', 'http://timg.bdta.pro/images/ac970f7c20bfd9c9cbe8c563e7b7e511.jpg'),
(78372, 5381, 'O Laboratório de Dexter S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172669.mp4', 'http://timg.bdta.pro/images/5f55c3414ea979224b7609bc478d25b1.jpg'),
(78373, 5381, 'O Laboratório de Dexter S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172670.mp4', 'http://timg.bdta.pro/images/557d33dd5268051316ea8a580a35fff9.jpg'),
(78374, 5382, 'O Laboratório de Dexter S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172671.mp4', 'http://timg.bdta.pro/images/3dfbe2ad3fb77deece43d339415402be.jpg'),
(78375, 5382, 'O Laboratório de Dexter S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172672.mp4', 'http://timg.bdta.pro/images/ae057f0a235bad4a04581641ed6bc220.jpg'),
(78376, 5382, 'O Laboratório de Dexter S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172673.mp4', 'http://timg.bdta.pro/images/477f0f5147fef19c0f159d121c0017c4.jpg'),
(78377, 5382, 'O Laboratório de Dexter S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172674.mp4', 'http://timg.bdta.pro/images/7fd78006ca4566f687ca495e2e5cfc94.jpg'),
(78378, 5382, 'O Laboratório de Dexter S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172675.mp4', 'http://timg.bdta.pro/images/f9e8871370c39260f3f0b15a147d39f2.jpg'),
(78379, 5382, 'O Laboratório de Dexter S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172676.mp4', 'http://timg.bdta.pro/images/b6eafb9f6dc4554657f4960cfd0d26fb.jpg'),
(78380, 5382, 'O Laboratório de Dexter S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172677.mp4', 'http://timg.bdta.pro/images/b515b83d521b875a34a96b0e5fc295ae.jpg'),
(78381, 5382, 'O Laboratório de Dexter S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172678.mp4', 'http://timg.bdta.pro/images/9de4df95b622a052ad4d0e382b844171.jpg'),
(78382, 5382, 'O Laboratório de Dexter S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172679.mp4', 'http://timg.bdta.pro/images/c2a5592c0fd6503e1e1ea568173865bc.jpg'),
(78383, 5382, 'O Laboratório de Dexter S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172680.mp4', 'http://timg.bdta.pro/images/16e2e076a3935f02addfd2a913e15907.jpg'),
(78384, 5382, 'O Laboratório de Dexter S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172681.mp4', 'http://timg.bdta.pro/images/3ac2e559987c455f037a236e56d20df4.jpg'),
(78385, 5382, 'O Laboratório de Dexter S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172682.mp4', 'http://timg.bdta.pro/images/5defbdf68415c8296541c9f6a8d950d7.jpg'),
(78386, 5383, 'Pretzel E Os Filhotes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172624.mp4', 'http://gstaticontent.com/images/ee20e24aa5d9509b83f8321d716db8f2.jpg'),
(78387, 5383, 'Pretzel E Os Filhotes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172625.mp4', 'http://gstaticontent.com/images/ee20e24aa5d9509b83f8321d716db8f2.jpg'),
(78388, 5383, 'Pretzel E Os Filhotes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172626.mp4', 'http://gstaticontent.com/images/ee20e24aa5d9509b83f8321d716db8f2.jpg'),
(78389, 5383, 'Pretzel E Os Filhotes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172627.mp4', 'http://gstaticontent.com/images/ee20e24aa5d9509b83f8321d716db8f2.jpg'),
(78390, 5383, 'Pretzel E Os Filhotes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172628.mp4', 'http://gstaticontent.com/images/ee20e24aa5d9509b83f8321d716db8f2.jpg'),
(78391, 5383, 'Pretzel E Os Filhotes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172629.mp4', 'http://gstaticontent.com/images/ee20e24aa5d9509b83f8321d716db8f2.jpg'),
(78392, 5383, 'Pretzel E Os Filhotes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172630.mp4', 'http://gstaticontent.com/images/ee20e24aa5d9509b83f8321d716db8f2.jpg'),
(78393, 5383, 'Pretzel E Os Filhotes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172631.mp4', 'http://gstaticontent.com/images/ee20e24aa5d9509b83f8321d716db8f2.jpg'),
(78394, 5384, 'Professor T S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172618.mp4', 'http://timg.bdta.pro/images/04d51d9f4a02ec886ca6bdbb7abaca21.jpg'),
(78395, 5384, 'Professor T S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172619.mp4', 'http://timg.bdta.pro/images/c561341e64ef1cd142700a4af0651465.jpg'),
(78396, 5384, 'Professor T S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172620.mp4', 'http://timg.bdta.pro/images/55becf19297835bb962413c669dd92cd.jpg'),
(78397, 5384, 'Professor T S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172621.mp4', 'http://timg.bdta.pro/images/0e66363caf1396d1c82c95d95f429197.jpg'),
(78398, 5384, 'Professor T S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172622.mp4', 'http://timg.bdta.pro/images/84cbe0a9aacdfeb00d94f83edb8c0a9a.jpg'),
(78399, 5384, 'Professor T S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172623.mp4', 'http://timg.bdta.pro/images/43146b9059a721ced2bc17fad5c012d7.jpg'),
(78400, 5385, 'Isekai Kizoku ni Tensei suru S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172606.mp4', 'http://timg.bdta.pro/images/0e8b20ee94c105a4cd29bc41458795b8.jpg'),
(78401, 5385, 'Isekai Kizoku ni Tensei suru S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172607.mp4', 'http://timg.bdta.pro/images/7e693566b326f16c951733f701230447.jpg'),
(78402, 5385, 'Isekai Kizoku ni Tensei suru S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172608.mp4', 'http://timg.bdta.pro/images/ffe5115d1e66db651c614feb9d1ad7f7.jpg'),
(78403, 5385, 'Isekai Kizoku ni Tensei suru S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172609.mp4', 'http://timg.bdta.pro/images/e6baf752dcf90e6ddbd37144730f7f8f.jpg'),
(78404, 5385, 'Isekai Kizoku ni Tensei suru S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172610.mp4', 'http://timg.bdta.pro/images/9c3dba345e01c196c8aefcbc6d3386e3.jpg'),
(78405, 5385, 'Isekai Kizoku ni Tensei suru S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172611.mp4', 'http://timg.bdta.pro/images/2fc2d5a87a54abe073e0dc3dce1f05de.jpg'),
(78406, 5385, 'Isekai Kizoku ni Tensei suru S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172612.mp4', 'http://timg.bdta.pro/images/87a6b447acdf670d20b721e5033153a9.jpg'),
(78407, 5385, 'Isekai Kizoku ni Tensei suru S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172613.mp4', 'http://timg.bdta.pro/images/959c1858738f32f550a1350f08a886ce.jpg'),
(78408, 5385, 'Isekai Kizoku ni Tensei suru S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172614.mp4', 'http://timg.bdta.pro/images/8759baeafae1dc1be8c0bf2b830ea202.jpg'),
(78409, 5385, 'Isekai Kizoku ni Tensei suru S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172615.mp4', 'http://timg.bdta.pro/images/3ecb629895c41488d122bba747eb0ccf.jpg'),
(78410, 5385, 'Isekai Kizoku ni Tensei suru S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172616.mp4', 'http://timg.bdta.pro/images/a296c63b3ffcf522b0f3655d527653fe.jpg'),
(78411, 5385, 'Isekai Kizoku ni Tensei suru S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172617.mp4', 'http://timg.bdta.pro/images/6278e7307f36603c1a12acdee5196a57.jpg'),
(78412, 5386, 'Henkyou de Slow Life suru Koto ni Shimashita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172593.mp4', 'http://timg.bdta.pro/images/c0be39ed0d2dae522a3ee4ae215550bb.jpg'),
(78413, 5386, 'Henkyou de Slow Life suru Koto ni Shimashita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172594.mp4', 'http://timg.bdta.pro/images/3d2120805dc013e4803eddb37bad7af6.jpg'),
(78414, 5386, 'Henkyou de Slow Life suru Koto ni Shimashita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172595.mp4', 'http://timg.bdta.pro/images/463e4117d64b852a6ef3c7c0e7eb31cc.jpg'),
(78415, 5386, 'Henkyou de Slow Life suru Koto ni Shimashita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172596.mp4', 'http://timg.bdta.pro/images/3bdf6fbb3ec86e39202e072510a37e1c.jpg'),
(78416, 5386, 'Henkyou de Slow Life suru Koto ni Shimashita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172597.mp4', 'http://timg.bdta.pro/images/5d216f0c91831992aec822d7b71797a2.jpg'),
(78417, 5386, 'Henkyou de Slow Life suru Koto ni Shimashita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172598.mp4', 'http://timg.bdta.pro/images/73a3482496dc2461e86aa66a881523a9.jpg'),
(78418, 5386, 'Henkyou de Slow Life suru Koto ni Shimashita S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172599.mp4', 'http://timg.bdta.pro/images/d4857f6c7f6f2927a0a26342d56b51fd.jpg'),
(78419, 5386, 'Henkyou de Slow Life suru Koto ni Shimashita S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172600.mp4', 'http://timg.bdta.pro/images/d51894bab571a1c4596d6ff0e414c44d.jpg'),
(78420, 5386, 'Henkyou de Slow Life suru Koto ni Shimashita S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172601.mp4', 'http://timg.bdta.pro/images/7db0f74de4b15e1ebf3cd2953f3461ee.jpg'),
(78421, 5386, 'Henkyou de Slow Life suru Koto ni Shimashita S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172602.mp4', 'http://timg.bdta.pro/images/babd10723f93c2b14b11a15a30d93b39.jpg'),
(78422, 5386, 'Henkyou de Slow Life suru Koto ni Shimashita S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172603.mp4', 'http://timg.bdta.pro/images/af8063b478fbe43fff08ed8d4b1c182d.jpg'),
(78423, 5386, 'Henkyou de Slow Life suru Koto ni Shimashita S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172604.mp4', 'http://timg.bdta.pro/images/baff4e9b8138367050c105a3193578ce.jpg'),
(78424, 5386, 'Henkyou de Slow Life suru Koto ni Shimashita S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172605.mp4', 'http://timg.bdta.pro/images/a8560653a15ad5f0f80319db7aa8d74d.jpg'),
(78425, 5387, 'Henkyou de Slow Life suru Koto ni Shimashita S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/272589.mp4', 'http://gstaticontent.com/images/bea518e6160f8d2bdc84c8862d28fc07.jpg'),
(78426, 5387, 'Henkyou de Slow Life suru Koto ni Shimashita S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/275064.mp4', 'http://gstaticontent.com/images/bea518e6160f8d2bdc84c8862d28fc07.jpg'),
(78427, 5387, 'Henkyou de Slow Life suru Koto ni Shimashita S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/282559.mp4', 'http://gstaticontent.com/images/bea518e6160f8d2bdc84c8862d28fc07.jpg'),
(78428, 5387, 'Henkyou de Slow Life suru Koto ni Shimashita S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289917.mp4', 'http://gstaticontent.com/images/bea518e6160f8d2bdc84c8862d28fc07.jpg'),
(78429, 5387, 'Henkyou de Slow Life suru Koto ni Shimashita S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/297122.mp4', 'http://gstaticontent.com/images/bea518e6160f8d2bdc84c8862d28fc07.jpg'),
(78430, 5387, 'Henkyou de Slow Life suru Koto ni Shimashita S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/300565.mp4', 'http://gstaticontent.com/images/bea518e6160f8d2bdc84c8862d28fc07.jpg'),
(78431, 5387, 'Henkyou de Slow Life suru Koto ni Shimashita S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/307205.mp4', 'http://gstaticontent.com/images/bea518e6160f8d2bdc84c8862d28fc07.jpg'),
(78432, 5387, 'Henkyou de Slow Life suru Koto ni Shimashita S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/317226.mp4', 'http://gstaticontent.com/images/bea518e6160f8d2bdc84c8862d28fc07.jpg'),
(78433, 5387, 'Henkyou de Slow Life suru Koto ni Shimashita S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/320438.mp4', 'http://gstaticontent.com/images/bea518e6160f8d2bdc84c8862d28fc07.jpg'),
(78434, 5387, 'Henkyou de Slow Life suru Koto ni Shimashita S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/326709.mp4', 'http://gstaticontent.com/images/bea518e6160f8d2bdc84c8862d28fc07.jpg'),
(78435, 5387, 'Henkyou de Slow Life suru Koto ni Shimashita S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/332196.mp4', 'http://gstaticontent.com/images/bea518e6160f8d2bdc84c8862d28fc07.jpg'),
(78436, 5387, 'Henkyou de Slow Life suru Koto ni Shimashita S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/336985.mp4', 'http://gstaticontent.com/images/bea518e6160f8d2bdc84c8862d28fc07.jpg'),
(78437, 5388, 'Smiling Friends S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172585.mp4', 'http://timg.bdta.pro/images/a1dada6608cea2cc3ba1ad42387670d1.jpg'),
(78438, 5388, 'Smiling Friends S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172586.mp4', 'http://timg.bdta.pro/images/046feee6502f2f1e721878d8f6405595.jpg'),
(78439, 5388, 'Smiling Friends S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172587.mp4', 'http://timg.bdta.pro/images/b41b7941108fb10bc39e061ca7efa174.jpg'),
(78440, 5388, 'Smiling Friends S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172588.mp4', 'http://timg.bdta.pro/images/be42413d5825421aded184b8fceb5bf0.jpg'),
(78441, 5388, 'Smiling Friends S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172589.mp4', 'http://timg.bdta.pro/images/9b80ad2ecb89220032a3ca5031263aed.jpg'),
(78442, 5388, 'Smiling Friends S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172590.mp4', 'http://timg.bdta.pro/images/1088a515be6227126632d955ea91ac23.jpg'),
(78443, 5388, 'Smiling Friends S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172591.mp4', 'http://timg.bdta.pro/images/d4e6ada3a145b265c7acdf563fb88615.jpg'),
(78444, 5388, 'Smiling Friends S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172592.mp4', 'http://timg.bdta.pro/images/85498ff9dd90f29754dc49ed2f2dcb38.jpg'),
(78445, 5389, 'The Boondocks S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172570.mp4', 'http://timg.bdta.pro/images/6818c9037fb4e0a0930560449b01cfc8.jpg'),
(78446, 5389, 'The Boondocks S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172571.mp4', 'http://timg.bdta.pro/images/6f48e1acb5254f2aa7bf2b27ce481b2b.jpg'),
(78447, 5389, 'The Boondocks S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172572.mp4', 'http://timg.bdta.pro/images/61cc1c0a34c9b53940a9f9267f6612aa.jpg'),
(78448, 5389, 'The Boondocks S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172573.mp4', 'http://timg.bdta.pro/images/4b2c7996de30221036d4c351f0a5c66c.jpg'),
(78449, 5389, 'The Boondocks S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172574.mp4', 'http://timg.bdta.pro/images/5738d388bad99427f4cb7fb8ea656f50.jpg'),
(78450, 5389, 'The Boondocks S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172575.mp4', 'http://timg.bdta.pro/images/29f346c4a20c78d4737655f7647ceae2.jpg'),
(78451, 5389, 'The Boondocks S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172576.mp4', 'http://timg.bdta.pro/images/18da4e795afcd5f7aea48e692f469cec.jpg'),
(78452, 5389, 'The Boondocks S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172577.mp4', 'http://timg.bdta.pro/images/958009a868aebfe881b968c8d0aaf173.jpg'),
(78453, 5389, 'The Boondocks S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172578.mp4', 'http://timg.bdta.pro/images/0de51b7c36a29222d0ff3c33f083f5ec.jpg'),
(78454, 5389, 'The Boondocks S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172579.mp4', 'http://timg.bdta.pro/images/933e46e8d670dc7fd63626848ee522e9.jpg'),
(78455, 5389, 'The Boondocks S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172580.mp4', 'http://timg.bdta.pro/images/2267f529867e7f062039eabdb78248a8.jpg'),
(78456, 5389, 'The Boondocks S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172581.mp4', 'http://timg.bdta.pro/images/8f916e1b40c4c8092a8adfe26e067ed3.jpg'),
(78457, 5389, 'The Boondocks S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172582.mp4', 'http://timg.bdta.pro/images/8b898bbedce9e17e32e628cd4786bec3.jpg'),
(78458, 5389, 'The Boondocks S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172583.mp4', 'http://timg.bdta.pro/images/570d9d0c0a8639e6db55a336f1eca5a8.jpg'),
(78459, 5389, 'The Boondocks S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/172584.mp4', 'http://timg.bdta.pro/images/511b1d8645b947e477865bfb1fdd8bb2.jpg'),
(78460, 5390, 'A Lenda de Vox Machina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208205.mp4', 'http://timg.bdta.pro/images/a5962d606282934646c443d6f12fe7dd.jpg'),
(78461, 5390, 'A Lenda de Vox Machina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208206.mp4', 'http://timg.bdta.pro/images/e0b7ec8061094f50b7c32bdf8511101a.jpg'),
(78462, 5390, 'A Lenda de Vox Machina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208207.mp4', 'http://timg.bdta.pro/images/78bd697c523974ec4ea6e448c7054f70.jpg'),
(78463, 5390, 'A Lenda de Vox Machina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208208.mp4', 'http://timg.bdta.pro/images/c3b556275918870eacf295e518022b22.jpg'),
(78464, 5390, 'A Lenda de Vox Machina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208209.mp4', 'http://timg.bdta.pro/images/3b537d9aae4363384bd830dd9fd6eaf7.jpg'),
(78465, 5390, 'A Lenda de Vox Machina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208210.mp4', 'http://timg.bdta.pro/images/10178e458691787d4a28f018ca857338.jpg'),
(78466, 5390, 'A Lenda de Vox Machina S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208211.mp4', 'http://timg.bdta.pro/images/956c9b2f209e966b0b37d9e487d3835f.jpg'),
(78467, 5390, 'A Lenda de Vox Machina S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208212.mp4', 'http://timg.bdta.pro/images/0284129d00a4b772f102b25d57d588cd.jpg'),
(78468, 5390, 'A Lenda de Vox Machina S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208213.mp4', 'http://timg.bdta.pro/images/cd75b3c2de9e39a523e14196600ac40e.jpg'),
(78469, 5390, 'A Lenda de Vox Machina S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208214.mp4', 'http://timg.bdta.pro/images/aa9df1fb3c446f2e85a97d614c614ca6.jpg'),
(78470, 5390, 'A Lenda de Vox Machina S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208215.mp4', 'http://timg.bdta.pro/images/7b3834fdfcb441cdf7a513be345b1228.jpg'),
(78471, 5390, 'A Lenda de Vox Machina S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208216.mp4', 'http://timg.bdta.pro/images/4853c542cac70e78d14ba9c7922ceb5f.jpg'),
(78472, 5391, 'A Lenda de Vox Machina S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iASxOVVY5qyowMPuu6TDEOFwqX9.jpg'),
(78473, 5391, 'A Lenda de Vox Machina S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6yedn2CzU6JOsMb5Slt561Mef4F.jpg'),
(78474, 5391, 'A Lenda de Vox Machina S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2uqx0yyRbWGYvEPyi4jFcZjTZpc.jpg'),
(78475, 5391, 'A Lenda de Vox Machina S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfYLGCk8PjvQDw2SZFkD3e4l5yM.jpg'),
(78476, 5391, 'A Lenda de Vox Machina S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fJuxAxDhUNVny9hA0o3nM6BnaHT.jpg'),
(78477, 5391, 'A Lenda de Vox Machina S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6eqDht8SU8h6NTMOJR5Y7XxktgA.jpg'),
(78478, 5391, 'A Lenda de Vox Machina S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lUxpO4oCfU6ir1ljmoXGhEoy4WF.jpg'),
(78479, 5391, 'A Lenda de Vox Machina S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8nZr4giAh6EEhyfhar9I09QwkI1.jpg'),
(78480, 5391, 'A Lenda de Vox Machina S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/51gMXACMehJE8nmiQ92ENmoigfu.jpg'),
(78481, 5391, 'A Lenda de Vox Machina S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mYVCp6icJj0HxZeWlRXH8WYGLbd.jpg'),
(78482, 5391, 'A Lenda de Vox Machina S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qgF2bIbZa7laCUHd8WLIx1VzwC0.jpg'),
(78483, 5391, 'A Lenda de Vox Machina S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6P4k46hd94u41xzpppaEJPmP6j2.jpg'),
(78484, 5392, 'A Lenda de Vox Machina S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/471011.mp4', 'http://gstaticontent.com/images/4c4da4c6650fe6da146d93f1fb4e8b55.jpg'),
(78485, 5392, 'A Lenda de Vox Machina S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/471012.mp4', 'http://gstaticontent.com/images/4c4da4c6650fe6da146d93f1fb4e8b55.jpg'),
(78486, 5392, 'A Lenda de Vox Machina S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/471013.mp4', 'http://gstaticontent.com/images/4c4da4c6650fe6da146d93f1fb4e8b55.jpg'),
(78487, 5392, 'A Lenda de Vox Machina S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479248.mp4', 'http://gstaticontent.com/images/4c4da4c6650fe6da146d93f1fb4e8b55.jpg'),
(78488, 5392, 'A Lenda de Vox Machina S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479249.mp4', 'http://gstaticontent.com/images/4c4da4c6650fe6da146d93f1fb4e8b55.jpg'),
(78489, 5392, 'A Lenda de Vox Machina S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479250.mp4', 'http://gstaticontent.com/images/4c4da4c6650fe6da146d93f1fb4e8b55.jpg'),
(78490, 5392, 'A Lenda de Vox Machina S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/483595.mp4', 'http://gstaticontent.com/images/4c4da4c6650fe6da146d93f1fb4e8b55.jpg'),
(78491, 5392, 'A Lenda de Vox Machina S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/483596.mp4', 'http://gstaticontent.com/images/4c4da4c6650fe6da146d93f1fb4e8b55.jpg'),
(78492, 5392, 'A Lenda de Vox Machina S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/483597.mp4', 'http://gstaticontent.com/images/4c4da4c6650fe6da146d93f1fb4e8b55.jpg'),
(78493, 5392, 'A Lenda de Vox Machina S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/491847.mp4', 'http://gstaticontent.com/images/4c4da4c6650fe6da146d93f1fb4e8b55.jpg'),
(78494, 5392, 'A Lenda de Vox Machina S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/491848.mp4', 'http://gstaticontent.com/images/4c4da4c6650fe6da146d93f1fb4e8b55.jpg'),
(78495, 5392, 'A Lenda de Vox Machina S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/491849.mp4', 'http://gstaticontent.com/images/4c4da4c6650fe6da146d93f1fb4e8b55.jpg'),
(78496, 5393, 'Aeroporto: Área Restrita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251047.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78497, 5393, 'Aeroporto: Área Restrita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251048.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78498, 5393, 'Aeroporto: Área Restrita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251049.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78499, 5393, 'Aeroporto: Área Restrita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251050.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78500, 5393, 'Aeroporto: Área Restrita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251051.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78501, 5393, 'Aeroporto: Área Restrita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251052.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78502, 5393, 'Aeroporto: Área Restrita S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251053.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78503, 5393, 'Aeroporto: Área Restrita S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251054.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78504, 5393, 'Aeroporto: Área Restrita S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251055.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78505, 5393, 'Aeroporto: Área Restrita S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251056.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78506, 5393, 'Aeroporto: Área Restrita S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251057.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78507, 5393, 'Aeroporto: Área Restrita S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251058.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78508, 5394, 'Aeroporto: Área Restrita S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251059.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78509, 5394, 'Aeroporto: Área Restrita S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251060.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78510, 5394, 'Aeroporto: Área Restrita S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251061.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78511, 5394, 'Aeroporto: Área Restrita S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251062.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78512, 5394, 'Aeroporto: Área Restrita S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251063.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78513, 5394, 'Aeroporto: Área Restrita S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251064.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78514, 5394, 'Aeroporto: Área Restrita S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251065.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78515, 5394, 'Aeroporto: Área Restrita S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251066.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78516, 5394, 'Aeroporto: Área Restrita S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251067.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78517, 5394, 'Aeroporto: Área Restrita S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251068.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78518, 5394, 'Aeroporto: Área Restrita S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251069.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78519, 5394, 'Aeroporto: Área Restrita S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251070.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78520, 5395, 'Aeroporto: Área Restrita S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251071.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78521, 5395, 'Aeroporto: Área Restrita S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251072.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78522, 5395, 'Aeroporto: Área Restrita S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251073.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78523, 5395, 'Aeroporto: Área Restrita S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251074.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78524, 5395, 'Aeroporto: Área Restrita S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251075.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78525, 5395, 'Aeroporto: Área Restrita S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251076.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78526, 5395, 'Aeroporto: Área Restrita S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251077.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78527, 5395, 'Aeroporto: Área Restrita S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251078.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78528, 5395, 'Aeroporto: Área Restrita S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251079.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78529, 5395, 'Aeroporto: Área Restrita S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251080.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78530, 5395, 'Aeroporto: Área Restrita S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251081.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78531, 5395, 'Aeroporto: Área Restrita S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251082.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78532, 5395, 'Aeroporto: Área Restrita S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251083.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78533, 5395, 'Aeroporto: Área Restrita S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251084.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78534, 5395, 'Aeroporto: Área Restrita S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251085.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78535, 5396, 'Aeroporto: Área Restrita S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTk1zOm75J3jnYqV7nu19y0OfVs.jpg'),
(78536, 5396, 'Aeroporto: Área Restrita S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2UqHUrLxP3q7sBxqDEqsd7ijsR.jpg'),
(78537, 5396, 'Aeroporto: Área Restrita S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251088.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78538, 5396, 'Aeroporto: Área Restrita S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251089.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78539, 5396, 'Aeroporto: Área Restrita S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251090.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78540, 5396, 'Aeroporto: Área Restrita S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251091.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78541, 5396, 'Aeroporto: Área Restrita S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251092.mp4', 'http://image.tmdb.org/t/p/w1280/eaENzM2f5kT6AHdazPwyeVSHvxX.jpg'),
(78542, 5396, 'Aeroporto: Área Restrita S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251093.mp4', 'http://image.tmdb.org/t/p/w1280/2snsjuNLjDfPj9KVR8Qd87VldFM.jpg'),
(78543, 5396, 'Aeroporto: Área Restrita S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251094.mp4', 'http://image.tmdb.org/t/p/w1280/xiu5OEl6zWv197Nc2GbkKrQ8e3N.jpg'),
(78544, 5396, 'Aeroporto: Área Restrita S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251095.mp4', 'http://image.tmdb.org/t/p/w1280/w32phtzNsEtinw1xvjfc9EqcjD5.jpg'),
(78545, 5396, 'Aeroporto: Área Restrita S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251096.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78546, 5396, 'Aeroporto: Área Restrita S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251097.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78547, 5397, 'Aeroporto: Área Restrita S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251098.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78548, 5397, 'Aeroporto: Área Restrita S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251099.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78549, 5397, 'Aeroporto: Área Restrita S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251100.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78550, 5397, 'Aeroporto: Área Restrita S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251101.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78551, 5397, 'Aeroporto: Área Restrita S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251102.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78552, 5397, 'Aeroporto: Área Restrita S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251103.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78553, 5397, 'Aeroporto: Área Restrita S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251104.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78554, 5397, 'Aeroporto: Área Restrita S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251105.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78555, 5397, 'Aeroporto: Área Restrita S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251106.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78556, 5397, 'Aeroporto: Área Restrita S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251107.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78557, 5397, 'Aeroporto: Área Restrita S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251108.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78558, 5397, 'Aeroporto: Área Restrita S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251109.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78559, 5398, 'Aeroporto: Área Restrita S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445057.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78560, 5398, 'Aeroporto: Área Restrita S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445058.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78561, 5398, 'Aeroporto: Área Restrita S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/448935.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78562, 5398, 'Aeroporto: Área Restrita S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/448936.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78563, 5398, 'Aeroporto: Área Restrita S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/456773.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78564, 5398, 'Aeroporto: Área Restrita S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/456774.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78565, 5398, 'Aeroporto: Área Restrita S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462157.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78566, 5398, 'Aeroporto: Área Restrita S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462158.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78567, 5398, 'Aeroporto: Área Restrita S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/468278.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78568, 5398, 'Aeroporto: Área Restrita S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/468279.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78569, 5398, 'Aeroporto: Área Restrita S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/475297.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78570, 5398, 'Aeroporto: Área Restrita S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/475298.mp4', 'http://gstaticontent.com/images/5f7a3b53b1f0837f296f3b2fdbc6378d.jpg'),
(78571, 5399, 'Aeroporto: Área Restrita S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/895747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4afPgq9vn42XoY4wWHjd4B3GcR9.jpg'),
(78572, 5399, 'Aeroporto: Área Restrita S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/895748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjtDAeauFWZIfIwTGsWrulcNR9X.jpg'),
(78573, 5399, 'Aeroporto: Área Restrita S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/895749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Dvy2EAzxpX81xMIscDfXEVuuS6.jpg'),
(78574, 5399, 'Aeroporto: Área Restrita S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/895750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rFRcTpqvIWkfUW3Pqp3375RSgBu.jpg'),
(78575, 5399, 'Aeroporto: Área Restrita S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/895751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/thQLGh4YGOuQ86aIbMXzBAE1OSf.jpg'),
(78576, 5399, 'Aeroporto: Área Restrita S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/895752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f9k35ODiFcWYjZfTa9GQpagkQjC.jpg'),
(78577, 5399, 'Aeroporto: Área Restrita S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/895753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dJx8NQItP3zw9lny4Qo8ornKV98.jpg'),
(78578, 5399, 'Aeroporto: Área Restrita S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/895754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3EubLTuXMn8696OjjFS0wZFrTX9.jpg'),
(78579, 5399, 'Aeroporto: Área Restrita S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/895755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/us35nzLorbNP99R4U21I1VKhUJE.jpg'),
(78580, 5399, 'Aeroporto: Área Restrita S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/895756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bSUQ86mEw9Sz23pkJDzLgRmlmQc.jpg'),
(78581, 5399, 'Aeroporto: Área Restrita S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/895757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4DWC8hgfBYR0lT9g9ruHrD3TjmE.jpg'),
(78582, 5399, 'Aeroporto: Área Restrita S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/895758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gMn0OMeIZlcAtsz9ro8DyhBHiH3.jpg'),
(78583, 5400, 'Channel Zero S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172354.mp4', 'http://timg.bdta.pro/images/deb39d04ee4aceaa0bcf5e5945d1a224.jpg'),
(78584, 5400, 'Channel Zero S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172355.mp4', 'http://timg.bdta.pro/images/4b56c0064a2c23c0394eba3cd269a1b1.jpg'),
(78585, 5400, 'Channel Zero S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172356.mp4', 'http://timg.bdta.pro/images/ad1972485aa116350f444cd26747e824.jpg'),
(78586, 5400, 'Channel Zero S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172357.mp4', 'http://timg.bdta.pro/images/58e4a129478246a6bf510c4072c4b73c.jpg'),
(78587, 5400, 'Channel Zero S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172358.mp4', 'http://timg.bdta.pro/images/d2fcebe05c3e60209d0c4fc6ff32dbf3.jpg'),
(78588, 5400, 'Channel Zero S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172359.mp4', 'http://timg.bdta.pro/images/9c65da24e4d50757c4ec2b0c4765a319.jpg'),
(78589, 5401, 'Channel Zero S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172360.mp4', 'http://timg.bdta.pro/images/a0b3649d81bbed14a11e2168430205c5.jpg'),
(78590, 5401, 'Channel Zero S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172361.mp4', 'http://timg.bdta.pro/images/ac63b487438a7e21677a08b6742af064.jpg'),
(78591, 5401, 'Channel Zero S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172362.mp4', 'http://timg.bdta.pro/images/d071ba20c73b502ee839b57fb3bb2c2d.jpg'),
(78592, 5401, 'Channel Zero S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172363.mp4', 'http://timg.bdta.pro/images/58b3c11c7995232b1d484843d565177f.jpg'),
(78593, 5401, 'Channel Zero S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172364.mp4', 'http://timg.bdta.pro/images/f94e6de464c1fe6cc09197b24e9a6b75.jpg'),
(78594, 5401, 'Channel Zero S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172365.mp4', 'http://timg.bdta.pro/images/d402b2be946fe081296d631a52e60b14.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(78595, 5402, 'Channel Zero S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172366.mp4', 'http://timg.bdta.pro/images/9d69bad862c4f8c89d527f6dbfdc0ba0.jpg'),
(78596, 5402, 'Channel Zero S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172367.mp4', 'http://timg.bdta.pro/images/f42023f6c4f35a360bc80b8c9894fdb1.jpg'),
(78597, 5402, 'Channel Zero S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172368.mp4', 'http://timg.bdta.pro/images/8ed0703857ceb64b12ad6372761c3ff7.jpg'),
(78598, 5402, 'Channel Zero S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172369.mp4', 'http://timg.bdta.pro/images/965f530af7428fdd86dab6294a20e504.jpg'),
(78599, 5402, 'Channel Zero S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172370.mp4', 'http://timg.bdta.pro/images/e31f39c9e4d91481c89051c5952cef27.jpg'),
(78600, 5402, 'Channel Zero S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172371.mp4', 'http://timg.bdta.pro/images/cb22c524a367a4d52cf28c4500dd2ea6.jpg'),
(78601, 5403, 'Covert Affairs: Assuntos Confidenciais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172279.mp4', 'http://timg.bdta.pro/images/e35afea85cd223184637e969b1023f6f.jpg'),
(78602, 5403, 'Covert Affairs: Assuntos Confidenciais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172280.mp4', 'http://timg.bdta.pro/images/bf1be75fc26b11abea6dad4a0a6e0aaf.jpg'),
(78603, 5403, 'Covert Affairs: Assuntos Confidenciais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172281.mp4', 'http://timg.bdta.pro/images/e87d8764d0a16f8ced841990c3bd3b94.jpg'),
(78604, 5403, 'Covert Affairs: Assuntos Confidenciais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172282.mp4', 'http://timg.bdta.pro/images/9fec09a4c01c1f9a271ef98f10247abf.jpg'),
(78605, 5403, 'Covert Affairs: Assuntos Confidenciais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172283.mp4', 'http://timg.bdta.pro/images/fee6446281ae05632582c8bab3daabdd.jpg'),
(78606, 5403, 'Covert Affairs: Assuntos Confidenciais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172284.mp4', 'http://timg.bdta.pro/images/ae7c1ed00bdbd8b5bf06c69e4a141b21.jpg'),
(78607, 5403, 'Covert Affairs: Assuntos Confidenciais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172285.mp4', 'http://timg.bdta.pro/images/e49e6eef9271e6c9b66debba20443ce9.jpg'),
(78608, 5403, 'Covert Affairs: Assuntos Confidenciais S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172286.mp4', 'http://timg.bdta.pro/images/d1d6a1542f1705972d9a6636484276f8.jpg'),
(78609, 5403, 'Covert Affairs: Assuntos Confidenciais S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172287.mp4', 'http://timg.bdta.pro/images/fc3a5bb146e876a60ed5d87ab6843bf8.jpg'),
(78610, 5403, 'Covert Affairs: Assuntos Confidenciais S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172288.mp4', 'http://timg.bdta.pro/images/567063f13cf4c6af700a20c4ae3c67f3.jpg'),
(78611, 5403, 'Covert Affairs: Assuntos Confidenciais S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172289.mp4', 'http://timg.bdta.pro/images/59d8865cc2e506e5d3201607799f11f8.jpg'),
(78612, 5404, 'Covert Affairs: Assuntos Confidenciais S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172290.mp4', 'http://timg.bdta.pro/images/bfa5b79f28c58934745a52b4ad411542.jpg'),
(78613, 5404, 'Covert Affairs: Assuntos Confidenciais S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172291.mp4', 'http://timg.bdta.pro/images/84b32b8414d0ff1a6dfa491a2beca2f6.jpg'),
(78614, 5404, 'Covert Affairs: Assuntos Confidenciais S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172292.mp4', 'http://timg.bdta.pro/images/34e086d5cccac7639e74ee1a0647adaa.jpg'),
(78615, 5404, 'Covert Affairs: Assuntos Confidenciais S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172293.mp4', 'http://timg.bdta.pro/images/0d859a4f42c3d8f8cfececc3808b8921.jpg'),
(78616, 5404, 'Covert Affairs: Assuntos Confidenciais S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172294.mp4', 'http://timg.bdta.pro/images/6023e3c55e1ed0d80c740cb676176178.jpg'),
(78617, 5404, 'Covert Affairs: Assuntos Confidenciais S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172295.mp4', 'http://timg.bdta.pro/images/d86ac019bcc28bc8456dc7863b9de676.jpg'),
(78618, 5404, 'Covert Affairs: Assuntos Confidenciais S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172296.mp4', 'http://timg.bdta.pro/images/7fbd4b227d57fed5f9bb0d5070505ff8.jpg'),
(78619, 5404, 'Covert Affairs: Assuntos Confidenciais S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172297.mp4', 'http://timg.bdta.pro/images/8dcd50f49731162ca29691dfd3345249.jpg'),
(78620, 5404, 'Covert Affairs: Assuntos Confidenciais S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172298.mp4', 'http://timg.bdta.pro/images/60916b5362e8db206c341729a4ea208d.jpg'),
(78621, 5404, 'Covert Affairs: Assuntos Confidenciais S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172299.mp4', 'http://timg.bdta.pro/images/774310d2ae756b6d4e6b3b3f6bd43a1f.jpg'),
(78622, 5404, 'Covert Affairs: Assuntos Confidenciais S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172300.mp4', 'http://timg.bdta.pro/images/99221cf3423ae929c3725f10f0c1cd71.jpg'),
(78623, 5404, 'Covert Affairs: Assuntos Confidenciais S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172301.mp4', 'http://timg.bdta.pro/images/41c57683a3dc708e7b9c4fcea019cfce.jpg'),
(78624, 5404, 'Covert Affairs: Assuntos Confidenciais S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172302.mp4', 'http://timg.bdta.pro/images/d65a37b2f3ae357ad26595f01e468e35.jpg'),
(78625, 5404, 'Covert Affairs: Assuntos Confidenciais S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172303.mp4', 'http://timg.bdta.pro/images/3e4266c0929c662bb101154cc69417b7.jpg'),
(78626, 5404, 'Covert Affairs: Assuntos Confidenciais S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/172304.mp4', 'http://timg.bdta.pro/images/8841e7fc29a18566888c19546e9f0e56.jpg'),
(78627, 5404, 'Covert Affairs: Assuntos Confidenciais S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/172305.mp4', 'http://timg.bdta.pro/images/0af8633e52cb31930ee446cd6f4c2332.jpg'),
(78628, 5405, 'Covert Affairs: Assuntos Confidenciais S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172306.mp4', 'http://timg.bdta.pro/images/461657a03894424d870ce147befe798c.jpg'),
(78629, 5405, 'Covert Affairs: Assuntos Confidenciais S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172307.mp4', 'http://timg.bdta.pro/images/4cc04c4bed7f6c4bc88938bbaf3d10f1.jpg'),
(78630, 5405, 'Covert Affairs: Assuntos Confidenciais S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172308.mp4', 'http://timg.bdta.pro/images/370eb7832a6c9ad17444876a6f553526.jpg'),
(78631, 5405, 'Covert Affairs: Assuntos Confidenciais S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172309.mp4', 'http://timg.bdta.pro/images/d3aca05422a80d2109ad9508f9b54a72.jpg'),
(78632, 5405, 'Covert Affairs: Assuntos Confidenciais S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172310.mp4', 'http://timg.bdta.pro/images/e8a5a700d91e70ceaa288abc22ef9176.jpg'),
(78633, 5405, 'Covert Affairs: Assuntos Confidenciais S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172311.mp4', 'http://timg.bdta.pro/images/a3b890f42ebfb4369a6ae9721272bc4b.jpg'),
(78634, 5405, 'Covert Affairs: Assuntos Confidenciais S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172312.mp4', 'http://timg.bdta.pro/images/94a93b94769d5d009a3306c42db001f8.jpg'),
(78635, 5405, 'Covert Affairs: Assuntos Confidenciais S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172313.mp4', 'http://timg.bdta.pro/images/3537be38ef30c046de2cf09bb30f267b.jpg'),
(78636, 5405, 'Covert Affairs: Assuntos Confidenciais S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172314.mp4', 'http://timg.bdta.pro/images/f6b67d2aff506887c07d6baa5b26bf37.jpg'),
(78637, 5405, 'Covert Affairs: Assuntos Confidenciais S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172315.mp4', 'http://timg.bdta.pro/images/bded6af178d202341c2c453b6414b3af.jpg'),
(78638, 5405, 'Covert Affairs: Assuntos Confidenciais S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172316.mp4', 'http://timg.bdta.pro/images/7dc121d55bab1296119811849953a6d4.jpg'),
(78639, 5405, 'Covert Affairs: Assuntos Confidenciais S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172317.mp4', 'http://timg.bdta.pro/images/1a358e69d30eecb4175f2c7dc8f5c336.jpg'),
(78640, 5405, 'Covert Affairs: Assuntos Confidenciais S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172318.mp4', 'http://timg.bdta.pro/images/0dc40198547a527de9da79ffd8d16cab.jpg'),
(78641, 5405, 'Covert Affairs: Assuntos Confidenciais S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172319.mp4', 'http://timg.bdta.pro/images/339b6b6c379e48a0a54e2d4fa6499bb4.jpg'),
(78642, 5405, 'Covert Affairs: Assuntos Confidenciais S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/172320.mp4', 'http://timg.bdta.pro/images/a83a2e1954079fda8756701af4d8540c.jpg'),
(78643, 5405, 'Covert Affairs: Assuntos Confidenciais S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/172321.mp4', 'http://timg.bdta.pro/images/e2b9a771539ef3b267ec0c6c74ce6144.jpg'),
(78644, 5406, 'Covert Affairs: Assuntos Confidenciais S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172322.mp4', 'http://timg.bdta.pro/images/aa79d2548fff88b2aec2b126b9408f9c.jpg'),
(78645, 5406, 'Covert Affairs: Assuntos Confidenciais S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172323.mp4', 'http://timg.bdta.pro/images/c0d362a5e15f78c8a004252b9ae736ed.jpg'),
(78646, 5406, 'Covert Affairs: Assuntos Confidenciais S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172324.mp4', 'http://timg.bdta.pro/images/d949135647ad83c25d2e9a7c7166a395.jpg'),
(78647, 5406, 'Covert Affairs: Assuntos Confidenciais S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172325.mp4', 'http://timg.bdta.pro/images/bfb88c473bb3b5efc395f6d19daafa06.jpg'),
(78648, 5406, 'Covert Affairs: Assuntos Confidenciais S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172326.mp4', 'http://timg.bdta.pro/images/751bf2e7a2d3352cb5dcb6baed95b270.jpg'),
(78649, 5406, 'Covert Affairs: Assuntos Confidenciais S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172327.mp4', 'http://timg.bdta.pro/images/b7a152508976744b438bb4c906ca5989.jpg'),
(78650, 5406, 'Covert Affairs: Assuntos Confidenciais S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172328.mp4', 'http://timg.bdta.pro/images/8411af4b581e7216b174f3eeb9caf513.jpg'),
(78651, 5406, 'Covert Affairs: Assuntos Confidenciais S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172329.mp4', 'http://timg.bdta.pro/images/42fcb7a4d816c2c6d96089e12ad6346f.jpg'),
(78652, 5406, 'Covert Affairs: Assuntos Confidenciais S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172330.mp4', 'http://timg.bdta.pro/images/8e5389d911f7a297c2a2cd5be56a3ffe.jpg'),
(78653, 5406, 'Covert Affairs: Assuntos Confidenciais S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172331.mp4', 'http://timg.bdta.pro/images/9d56b0f3a07aa5ce256d46ab1b4d31d6.jpg'),
(78654, 5406, 'Covert Affairs: Assuntos Confidenciais S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172332.mp4', 'http://timg.bdta.pro/images/3a3cded09439433c46912d6ca5ea1cb1.jpg'),
(78655, 5406, 'Covert Affairs: Assuntos Confidenciais S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172333.mp4', 'http://timg.bdta.pro/images/3da7cfb2465a80759c792b58c4daca9f.jpg'),
(78656, 5406, 'Covert Affairs: Assuntos Confidenciais S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172334.mp4', 'http://timg.bdta.pro/images/b074235b44856096e53faab17213e5a5.jpg'),
(78657, 5406, 'Covert Affairs: Assuntos Confidenciais S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172335.mp4', 'http://timg.bdta.pro/images/21bfec3c280c5bcadad5e38507242de6.jpg'),
(78658, 5406, 'Covert Affairs: Assuntos Confidenciais S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/172336.mp4', 'http://timg.bdta.pro/images/8f97742a363fedddefc678b3b1f9b666.jpg'),
(78659, 5406, 'Covert Affairs: Assuntos Confidenciais S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/172337.mp4', 'http://timg.bdta.pro/images/346b900e1a6db94faf025f06ade75db9.jpg'),
(78660, 5407, 'Covert Affairs: Assuntos Confidenciais S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172338.mp4', 'http://timg.bdta.pro/images/443a47b9f97d521f97fc6886c55a48a0.jpg'),
(78661, 5407, 'Covert Affairs: Assuntos Confidenciais S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172339.mp4', 'http://timg.bdta.pro/images/a217d1091a7d095dbe7a1fdbcd22708a.jpg'),
(78662, 5407, 'Covert Affairs: Assuntos Confidenciais S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172340.mp4', 'http://timg.bdta.pro/images/a3a8a7917f6a37c35d47d588073da143.jpg'),
(78663, 5407, 'Covert Affairs: Assuntos Confidenciais S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172341.mp4', 'http://timg.bdta.pro/images/97bf9e088c148f4c347294e566d0e9d4.jpg'),
(78664, 5407, 'Covert Affairs: Assuntos Confidenciais S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172342.mp4', 'http://timg.bdta.pro/images/57be7edb79ac8f3e791d401e12117d43.jpg'),
(78665, 5407, 'Covert Affairs: Assuntos Confidenciais S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172343.mp4', 'http://timg.bdta.pro/images/3677a5a2b7009a969eb5e71f6bcf83ac.jpg'),
(78666, 5407, 'Covert Affairs: Assuntos Confidenciais S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172344.mp4', 'http://timg.bdta.pro/images/a4ec2e72d1958574a07654139c3b3e3b.jpg'),
(78667, 5407, 'Covert Affairs: Assuntos Confidenciais S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172345.mp4', 'http://timg.bdta.pro/images/ce332e12f104835d93203055f3bfddd7.jpg'),
(78668, 5407, 'Covert Affairs: Assuntos Confidenciais S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172346.mp4', 'http://timg.bdta.pro/images/d2a67b2f18a0ebb7087f4df705120422.jpg'),
(78669, 5407, 'Covert Affairs: Assuntos Confidenciais S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172347.mp4', 'http://timg.bdta.pro/images/b450b1f4ee144953d5aa4548c21f6a59.jpg'),
(78670, 5407, 'Covert Affairs: Assuntos Confidenciais S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172348.mp4', 'http://timg.bdta.pro/images/2b89ee68c6ac55003b3a98487d4c2a11.jpg'),
(78671, 5407, 'Covert Affairs: Assuntos Confidenciais S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172349.mp4', 'http://timg.bdta.pro/images/66a7d771b6d32993de20852ca4a3b5ba.jpg'),
(78672, 5407, 'Covert Affairs: Assuntos Confidenciais S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172350.mp4', 'http://timg.bdta.pro/images/43b550ff995654b8e78ab4921fe15d86.jpg'),
(78673, 5407, 'Covert Affairs: Assuntos Confidenciais S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172351.mp4', 'http://timg.bdta.pro/images/c9a3dde727d48512608b6357120d736d.jpg'),
(78674, 5407, 'Covert Affairs: Assuntos Confidenciais S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/172352.mp4', 'http://timg.bdta.pro/images/fd1a605d6a2120a92eab3b9b8bd6f423.jpg'),
(78675, 5407, 'Covert Affairs: Assuntos Confidenciais S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/172353.mp4', 'http://timg.bdta.pro/images/4c5a33adb6de182d05b8dde41a3cc9d4.jpg'),
(78676, 5408, 'Cuphead: A Série S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201056.mp4', 'http://timg.bdta.pro/images/411a7f94def74cd5c76200c802a10297.jpg'),
(78677, 5408, 'Cuphead: A Série S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201057.mp4', 'http://timg.bdta.pro/images/56ba2faa30f28fab37b30ea1a649da85.jpg'),
(78678, 5408, 'Cuphead: A Série S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201058.mp4', 'http://timg.bdta.pro/images/ba8e03c8d332b5e99f65c21a0c11d426.jpg'),
(78679, 5408, 'Cuphead: A Série S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201059.mp4', 'http://timg.bdta.pro/images/5181001ca5560973c487d4a142d172b5.jpg'),
(78680, 5408, 'Cuphead: A Série S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201060.mp4', 'http://timg.bdta.pro/images/6fcc774af55cd4e64d5c7006e07866d7.jpg'),
(78681, 5408, 'Cuphead: A Série S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201061.mp4', 'http://timg.bdta.pro/images/6f7721958e77f94b89424c98e0a58002.jpg'),
(78682, 5408, 'Cuphead: A Série S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201062.mp4', 'http://timg.bdta.pro/images/7f9933e0669692a468baf1890feef3b0.jpg'),
(78683, 5408, 'Cuphead: A Série S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201063.mp4', 'http://timg.bdta.pro/images/16ca967bcec9c72b55639b36fe989692.jpg'),
(78684, 5408, 'Cuphead: A Série S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201064.mp4', 'http://timg.bdta.pro/images/06331e767cd02612969ecedbc4a09d29.jpg'),
(78685, 5408, 'Cuphead: A Série S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201065.mp4', 'http://timg.bdta.pro/images/ef7ff9206dc0444e914506fd204877c6.jpg'),
(78686, 5408, 'Cuphead: A Série S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201066.mp4', 'http://timg.bdta.pro/images/009bca84fb2cc4c07cd2a7576df3983f.jpg'),
(78687, 5408, 'Cuphead: A Série S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201067.mp4', 'http://timg.bdta.pro/images/d12d1000c2475ab0783a0358987f0fd8.jpg'),
(78688, 5409, 'Cuphead: A Série S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201068.mp4', 'http://timg.bdta.pro/images/5d035075f3f9c317a1b99b5f20504fb4.jpg'),
(78689, 5409, 'Cuphead: A Série S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201069.mp4', 'http://timg.bdta.pro/images/c50fa6bdbb17a804d2874d06502c9384.jpg'),
(78690, 5409, 'Cuphead: A Série S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201070.mp4', 'http://timg.bdta.pro/images/31feb5a3917d76d2dd06eddacf5e5158.jpg'),
(78691, 5409, 'Cuphead: A Série S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201071.mp4', 'http://timg.bdta.pro/images/1439076f3a320d0da953c36fbea0ca6c.jpg'),
(78692, 5409, 'Cuphead: A Série S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201072.mp4', 'http://timg.bdta.pro/images/b68d23e8e10e248e58fd4ec72985e31b.jpg'),
(78693, 5409, 'Cuphead: A Série S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201073.mp4', 'http://timg.bdta.pro/images/415a11bfb42863993d3694387217bd4f.jpg'),
(78694, 5409, 'Cuphead: A Série S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201074.mp4', 'http://timg.bdta.pro/images/af6ed08aa5f55e975bf04e912c4abcb8.jpg'),
(78695, 5409, 'Cuphead: A Série S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201075.mp4', 'http://timg.bdta.pro/images/67b46787a31401fb7e85a99925fdd949.jpg'),
(78696, 5409, 'Cuphead: A Série S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201076.mp4', 'http://timg.bdta.pro/images/a421443da3eeec7cd83aa61d583401fe.jpg'),
(78697, 5409, 'Cuphead: A Série S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201077.mp4', 'http://timg.bdta.pro/images/4da10ea835583f65a523932adfe720c3.jpg'),
(78698, 5409, 'Cuphead: A Série S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201078.mp4', 'http://timg.bdta.pro/images/eeec2652c70c6adfe5682d1cfd01bd34.jpg'),
(78699, 5409, 'Cuphead: A Série S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201079.mp4', 'http://timg.bdta.pro/images/61959faac289f9d0c54568afd348ab8a.jpg'),
(78700, 5409, 'Cuphead: A Série S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201080.mp4', 'http://timg.bdta.pro/images/092cc094858697c7c7e541d6a33ffdfe.jpg'),
(78701, 5410, 'Cuphead: A Série S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7r541KjPM2JG6GJEDuoFk63W7cV.jpg'),
(78702, 5410, 'Cuphead: A Série S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nASxfmxqxMGKTR0gZksCjuZ7leq.jpg'),
(78703, 5410, 'Cuphead: A Série S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9F5sNttntTe4N0gZY3fmzz7crpC.jpg'),
(78704, 5410, 'Cuphead: A Série S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rQaHHfk6dzoxcf08QcRHxSz5jOx.jpg'),
(78705, 5410, 'Cuphead: A Série S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mm8wrJtqQmvysjQEh47RA4I7jNW.jpg'),
(78706, 5410, 'Cuphead: A Série S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1vryWU0HidYah2VQa0HxeL6O0OL.jpg'),
(78707, 5410, 'Cuphead: A Série S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lr2kDF8Nad4zCwmE2T45uIfMjgr.jpg'),
(78708, 5410, 'Cuphead: A Série S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yVfXVq5Inw2nsEcG1yY8r4SOYiu.jpg'),
(78709, 5410, 'Cuphead: A Série S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5hKveJQSKdUNSFmHnKDr5vV8dhB.jpg'),
(78710, 5410, 'Cuphead: A Série S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kFTtTvezK4TQpkJQMdahlnM4PUh.jpg'),
(78711, 5410, 'Cuphead: A Série S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4dwbiPhBhw9gEHO8DsOFwbtSNw2.jpg'),
(78712, 5411, 'Fidelidade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172273.mp4', 'http://timg.bdta.pro/images/d71c784e879790c113e85dfbf874c880.jpg'),
(78713, 5411, 'Fidelidade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172274.mp4', 'http://timg.bdta.pro/images/566d74482733cef879090ca4dff59a57.jpg'),
(78714, 5411, 'Fidelidade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172275.mp4', 'http://timg.bdta.pro/images/0150f32065bde14fe770eb956741c513.jpg'),
(78715, 5411, 'Fidelidade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172276.mp4', 'http://timg.bdta.pro/images/42ccf7cb623b83f527c6951eca48acb7.jpg'),
(78716, 5411, 'Fidelidade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172277.mp4', 'http://timg.bdta.pro/images/b1d4dcd8967fba192e633a4a994cd9ea.jpg'),
(78717, 5411, 'Fidelidade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172278.mp4', 'http://timg.bdta.pro/images/0ea16fb53bfc03d3d802d1ce0ed5685f.jpg'),
(78718, 5412, 'Fishbowl Wives S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172265.mp4', 'http://timg.bdta.pro/images/7084ba20fd7eab4c8eee816d160a8dd6.jpg'),
(78719, 5412, 'Fishbowl Wives S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172266.mp4', 'http://timg.bdta.pro/images/401a646759c5ddeb784416a4477dc7f9.jpg'),
(78720, 5412, 'Fishbowl Wives S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172267.mp4', 'http://timg.bdta.pro/images/b9765bf1204ede50a4a8040451d4197d.jpg'),
(78721, 5412, 'Fishbowl Wives S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172268.mp4', 'http://timg.bdta.pro/images/ada3d6397d1e7ee2d1b8fce777dc877b.jpg'),
(78722, 5412, 'Fishbowl Wives S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172269.mp4', 'http://timg.bdta.pro/images/2cbaf3d1bb2921ca97c504145e7fcdef.jpg'),
(78723, 5412, 'Fishbowl Wives S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172270.mp4', 'http://timg.bdta.pro/images/cd7e1b861968957f1725aaa97759a9bd.jpg'),
(78724, 5412, 'Fishbowl Wives S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172271.mp4', 'http://timg.bdta.pro/images/2033fb6c69988ccdc6598138f749bcca.jpg'),
(78725, 5412, 'Fishbowl Wives S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172272.mp4', 'http://timg.bdta.pro/images/1176d67b70c09bbd08a1a634c2dd1094.jpg'),
(78726, 5413, 'Histórias de Verão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202527.mp4', 'http://gstaticontent.com/images/af78f9b0d134ce1c3df50b5996f57edf.jpg'),
(78727, 5413, 'Histórias de Verão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202528.mp4', 'http://gstaticontent.com/images/af78f9b0d134ce1c3df50b5996f57edf.jpg'),
(78728, 5413, 'Histórias de Verão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202529.mp4', 'http://gstaticontent.com/images/af78f9b0d134ce1c3df50b5996f57edf.jpg'),
(78729, 5413, 'Histórias de Verão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202530.mp4', 'http://gstaticontent.com/images/af78f9b0d134ce1c3df50b5996f57edf.jpg'),
(78730, 5413, 'Histórias de Verão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202531.mp4', 'http://gstaticontent.com/images/af78f9b0d134ce1c3df50b5996f57edf.jpg'),
(78731, 5413, 'Histórias de Verão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202532.mp4', 'http://gstaticontent.com/images/af78f9b0d134ce1c3df50b5996f57edf.jpg'),
(78732, 5413, 'Histórias de Verão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202533.mp4', 'http://gstaticontent.com/images/af78f9b0d134ce1c3df50b5996f57edf.jpg'),
(78733, 5413, 'Histórias de Verão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202534.mp4', 'http://gstaticontent.com/images/af78f9b0d134ce1c3df50b5996f57edf.jpg'),
(78734, 5413, 'Histórias de Verão S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202535.mp4', 'http://gstaticontent.com/images/af78f9b0d134ce1c3df50b5996f57edf.jpg'),
(78735, 5413, 'Histórias de Verão S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202536.mp4', 'http://gstaticontent.com/images/af78f9b0d134ce1c3df50b5996f57edf.jpg'),
(78736, 5413, 'Histórias de Verão S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202537.mp4', 'http://gstaticontent.com/images/af78f9b0d134ce1c3df50b5996f57edf.jpg'),
(78737, 5414, 'Histórias de Verão S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/auYDicAgJGUTi3ywt9VDoA6eqBx.jpg'),
(78738, 5414, 'Histórias de Verão S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lF0jGVrJrGOB9dMHrCzPaZKPvle.jpg'),
(78739, 5414, 'Histórias de Verão S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhDo7hNy1CA4ZksGWf53SEPbc4I.jpg'),
(78740, 5414, 'Histórias de Verão S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7WSEU135NyQEvaVF7AVQRiT5pB0.jpg'),
(78741, 5414, 'Histórias de Verão S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uTsGLQcKg6pRbQOxzGVWOg7ibOg.jpg'),
(78742, 5414, 'Histórias de Verão S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/JQHw4bG0PWWg0qoZpZqIF701am.jpg'),
(78743, 5414, 'Histórias de Verão S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5y5MrO6ZG9mX4oKj1R5lFwk3B2t.jpg'),
(78744, 5414, 'Histórias de Verão S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mN3dj4yrjtvxekc8P8KzGZ6ptFO.jpg'),
(78745, 5415, 'Lincoln\'s Dilemma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172261.mp4', 'http://timg.bdta.pro/images/d2c9f91d14c5358f55681250c5588338.jpg'),
(78746, 5415, 'Lincoln\'s Dilemma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172262.mp4', 'http://timg.bdta.pro/images/194a02e53236367136b910b7d1f26096.jpg'),
(78747, 5415, 'Lincoln\'s Dilemma S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172263.mp4', 'http://timg.bdta.pro/images/30282d287edbbe852d03aa126bcdb44f.jpg'),
(78748, 5415, 'Lincoln\'s Dilemma S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172264.mp4', 'http://timg.bdta.pro/images/03b177b27061e8cd374e63c525dfa8c5.jpg'),
(78749, 5416, 'Odo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172248.mp4', 'http://timg.bdta.pro/images/82693bd78e2848ad9590ad60cdf559c6.jpg'),
(78750, 5416, 'Odo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172249.mp4', 'http://timg.bdta.pro/images/86ab2daaae4f0c05a1d2f6673cd14f6e.jpg'),
(78751, 5416, 'Odo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172250.mp4', 'http://timg.bdta.pro/images/3def047934b4ebef38bcc6aff946c8d9.jpg'),
(78752, 5416, 'Odo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172251.mp4', 'http://timg.bdta.pro/images/916a22a50c1ebc5f7340f4203828cab9.jpg'),
(78753, 5416, 'Odo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172252.mp4', 'http://timg.bdta.pro/images/64cd82694c40a804e67dda7a7eba4b88.jpg'),
(78754, 5416, 'Odo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172253.mp4', 'http://timg.bdta.pro/images/44a52b2bbbdff3d69b71701ac7ea7612.jpg'),
(78755, 5416, 'Odo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172254.mp4', 'http://timg.bdta.pro/images/2d715e119c71b1feb152decef990b8f7.jpg'),
(78756, 5416, 'Odo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172255.mp4', 'http://timg.bdta.pro/images/756da5ef23fdbc47949e7b2fb882c14d.jpg'),
(78757, 5416, 'Odo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172256.mp4', 'http://timg.bdta.pro/images/67941a2e9e1789a66e377c621e6f4b0f.jpg'),
(78758, 5416, 'Odo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172257.mp4', 'http://timg.bdta.pro/images/a1cb11b8b696f11a131cc0ad4263feec.jpg'),
(78759, 5416, 'Odo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172258.mp4', 'http://timg.bdta.pro/images/d72aad0df4f7f4a5c9d4031befa12cc2.jpg'),
(78760, 5416, 'Odo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172259.mp4', 'http://timg.bdta.pro/images/9fa26666c3c1e86241eaf2c3c1bff31a.jpg'),
(78761, 5416, 'Odo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172260.mp4', 'http://timg.bdta.pro/images/5004c37fc18b38c607183303714a12ea.jpg'),
(78762, 5417, 'Onda Boa com Ivete S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172243.mp4', 'http://timg.bdta.pro/images/a76e9909280f2b1dc403f4b3da7ffd23.jpg'),
(78763, 5417, 'Onda Boa com Ivete S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172244.mp4', 'http://timg.bdta.pro/images/496eb24dd9de29fae71337825f6f4fe7.jpg'),
(78764, 5417, 'Onda Boa com Ivete S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172245.mp4', 'http://timg.bdta.pro/images/7abfbc486373a885f57e2b7001b32147.jpg'),
(78765, 5417, 'Onda Boa com Ivete S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172246.mp4', 'http://timg.bdta.pro/images/9df02cb8be575f184619ed16fb9ffc53.jpg'),
(78766, 5417, 'Onda Boa com Ivete S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172247.mp4', 'http://timg.bdta.pro/images/b9a795bbfcb909db6b211d78460f853b.jpg'),
(78767, 5418, 'Padre Brown S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172208.mp4', 'http://timg.bdta.pro/images/44c860a3cca6d6a2f6c38aa7483884da.jpg'),
(78768, 5418, 'Padre Brown S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172209.mp4', 'http://timg.bdta.pro/images/90fba4286c0035f66e2d158bbd1872d0.jpg'),
(78769, 5418, 'Padre Brown S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172210.mp4', 'http://timg.bdta.pro/images/2d75ece2d01a341d620bc7cd9d5b66f0.jpg'),
(78770, 5418, 'Padre Brown S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172211.mp4', 'http://timg.bdta.pro/images/ff4f6dc48e1674befe07171b6eda8153.jpg'),
(78771, 5418, 'Padre Brown S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172212.mp4', 'http://timg.bdta.pro/images/f7f0437b70234e8beea9e680a1342936.jpg'),
(78772, 5418, 'Padre Brown S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172213.mp4', 'http://timg.bdta.pro/images/90dd30404da0fd25c6c454486f16abd8.jpg'),
(78773, 5418, 'Padre Brown S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172214.mp4', 'http://timg.bdta.pro/images/b26f39b86238c14329a42a7d2e573328.jpg'),
(78774, 5418, 'Padre Brown S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172215.mp4', 'http://timg.bdta.pro/images/d496d231c75952714426b4ccfcdf0a8a.jpg'),
(78775, 5418, 'Padre Brown S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172216.mp4', 'http://timg.bdta.pro/images/32ce2f6160635fbdea1e57381ca668de.jpg'),
(78776, 5418, 'Padre Brown S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172217.mp4', 'http://timg.bdta.pro/images/62a8fcdf57053d85dd28b1a24f40bc7e.jpg'),
(78777, 5419, 'Padre Brown S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172218.mp4', 'http://timg.bdta.pro/images/44147954db58fbd70420f2d79d15f012.jpg'),
(78778, 5419, 'Padre Brown S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172219.mp4', 'http://timg.bdta.pro/images/37b88565e47f15a201fa3750f354130b.jpg'),
(78779, 5419, 'Padre Brown S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172220.mp4', 'http://timg.bdta.pro/images/ca5709d921706c745372eef85aedf911.jpg'),
(78780, 5419, 'Padre Brown S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172221.mp4', 'http://timg.bdta.pro/images/60f1ab00d013baaf27eac03a67c041b7.jpg'),
(78781, 5419, 'Padre Brown S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172222.mp4', 'http://timg.bdta.pro/images/d25b2c64ab98f198023ee6c28be59fc6.jpg'),
(78782, 5419, 'Padre Brown S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172223.mp4', 'http://timg.bdta.pro/images/e00afa667173d2329134f2e18cde7de0.jpg'),
(78783, 5419, 'Padre Brown S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172224.mp4', 'http://timg.bdta.pro/images/df8c6ec1be7be8f19fad1fa092d261ce.jpg'),
(78784, 5419, 'Padre Brown S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172225.mp4', 'http://timg.bdta.pro/images/26c8aad119be7763cb308fc0f22d5f1a.jpg'),
(78785, 5419, 'Padre Brown S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172226.mp4', 'http://timg.bdta.pro/images/5d47bd5dc6094446040a7bd8c594bf6c.jpg'),
(78786, 5419, 'Padre Brown S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172227.mp4', 'http://timg.bdta.pro/images/fa11228dfc8f14b2cec1821770977818.jpg'),
(78787, 5420, 'Padre Brown S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172228.mp4', 'http://timg.bdta.pro/images/1e1383ef877a5c2c36c04573d9b65337.jpg'),
(78788, 5420, 'Padre Brown S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172229.mp4', 'http://timg.bdta.pro/images/2b1270d7a53f58ec5472aa3573b2f2de.jpg'),
(78789, 5420, 'Padre Brown S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172230.mp4', 'http://timg.bdta.pro/images/a9fd09834bf8f8c4526715913eb85d69.jpg'),
(78790, 5420, 'Padre Brown S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172231.mp4', 'http://timg.bdta.pro/images/356d1f4402e0bd39e2aaea6e09e5e627.jpg'),
(78791, 5420, 'Padre Brown S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172232.mp4', 'http://timg.bdta.pro/images/0e6193380dae89d71eeb34341d5b8806.jpg'),
(78792, 5420, 'Padre Brown S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172233.mp4', 'http://timg.bdta.pro/images/6b8aff56301e2c6883df24282776cec0.jpg'),
(78793, 5420, 'Padre Brown S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172234.mp4', 'http://timg.bdta.pro/images/7e4a63d84f73e991884f87014bae9032.jpg'),
(78794, 5420, 'Padre Brown S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172235.mp4', 'http://timg.bdta.pro/images/e4fb908cb84aeec6c0294e5e016f6a05.jpg'),
(78795, 5420, 'Padre Brown S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172236.mp4', 'http://timg.bdta.pro/images/289a8cb0c8e04213fd135c38c0f3947c.jpg'),
(78796, 5420, 'Padre Brown S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172237.mp4', 'http://timg.bdta.pro/images/3e1599ed0869e59e5b0c0f7adf2691aa.jpg'),
(78797, 5420, 'Padre Brown S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172238.mp4', 'http://timg.bdta.pro/images/663e9b6daaa58ebe53171fc4a47a360d.jpg'),
(78798, 5420, 'Padre Brown S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172239.mp4', 'http://timg.bdta.pro/images/d03f674475f8fea729873a510c9cd993.jpg'),
(78799, 5420, 'Padre Brown S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172240.mp4', 'http://timg.bdta.pro/images/28e591670e868cfd4d4f4a315ea9e3f7.jpg'),
(78800, 5420, 'Padre Brown S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172241.mp4', 'http://timg.bdta.pro/images/2ba887143406c7376cc5249a65adde09.jpg'),
(78801, 5420, 'Padre Brown S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/172242.mp4', 'http://timg.bdta.pro/images/e79bf65fae546a50ea9c6bf380342468.jpg'),
(78802, 5421, 'Padre Brown S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/694846.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78803, 5421, 'Padre Brown S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/694847.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78804, 5421, 'Padre Brown S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/694848.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78805, 5421, 'Padre Brown S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/694849.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78806, 5421, 'Padre Brown S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/694850.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78807, 5421, 'Padre Brown S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/694851.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78808, 5421, 'Padre Brown S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/694852.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78809, 5421, 'Padre Brown S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/694853.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78810, 5421, 'Padre Brown S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/694854.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78811, 5421, 'Padre Brown S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/694855.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78812, 5422, 'Padre Brown S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/694856.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78813, 5422, 'Padre Brown S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/694857.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78814, 5422, 'Padre Brown S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/694858.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78815, 5422, 'Padre Brown S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/694859.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78816, 5422, 'Padre Brown S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/694860.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78817, 5422, 'Padre Brown S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/694861.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78818, 5422, 'Padre Brown S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/694862.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78819, 5422, 'Padre Brown S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/694863.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78820, 5422, 'Padre Brown S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/694864.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78821, 5422, 'Padre Brown S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/694865.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78822, 5422, 'Padre Brown S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/694866.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78823, 5422, 'Padre Brown S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/694867.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78824, 5422, 'Padre Brown S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/694868.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78825, 5422, 'Padre Brown S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/694869.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78826, 5422, 'Padre Brown S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/694870.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78827, 5423, 'Padre Brown S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/694871.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78828, 5423, 'Padre Brown S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/694872.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78829, 5423, 'Padre Brown S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/694873.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78830, 5423, 'Padre Brown S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/694874.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78831, 5423, 'Padre Brown S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/694875.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78832, 5423, 'Padre Brown S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/694876.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78833, 5423, 'Padre Brown S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/694877.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78834, 5423, 'Padre Brown S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/694878.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78835, 5423, 'Padre Brown S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/694879.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78836, 5423, 'Padre Brown S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/694880.mp4', 'http://gstaticontent.com/images/d072dab42449f7eea4edd2d8a6e5a619.jpg'),
(78837, 5424, 'Pousando no Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172192.mp4', 'http://timg.bdta.pro/images/597e5ef682e2bc504bbe56d3870f21da.jpg'),
(78838, 5424, 'Pousando no Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172193.mp4', 'http://timg.bdta.pro/images/be5fcd4ff1ca8a48c3747b10204804e6.jpg'),
(78839, 5424, 'Pousando no Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172194.mp4', 'http://timg.bdta.pro/images/53b9a9cb7f874a68af7e1f44be230c1e.jpg'),
(78840, 5424, 'Pousando no Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172195.mp4', 'http://timg.bdta.pro/images/0b747d5b99a2eb5302b06025c8faca4b.jpg'),
(78841, 5424, 'Pousando no Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172196.mp4', 'http://timg.bdta.pro/images/186376defe201f8af1d28902902fb191.jpg'),
(78842, 5424, 'Pousando no Amor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172197.mp4', 'http://timg.bdta.pro/images/444ed5102c07812c3a06f712e2a7a17b.jpg'),
(78843, 5424, 'Pousando no Amor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172198.mp4', 'http://timg.bdta.pro/images/c8e7dc747b1253a838558337d694f6a2.jpg'),
(78844, 5424, 'Pousando no Amor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172199.mp4', 'http://timg.bdta.pro/images/cf32156a2715f72623e5beae37294e54.jpg'),
(78845, 5424, 'Pousando no Amor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172200.mp4', 'http://timg.bdta.pro/images/b5bc7dda2f6037685e80bc126fdf4784.jpg'),
(78846, 5424, 'Pousando no Amor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172201.mp4', 'http://timg.bdta.pro/images/a2dad8ce66b516fd3ed07df48240411c.jpg'),
(78847, 5424, 'Pousando no Amor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/172202.mp4', 'http://timg.bdta.pro/images/79d9b6670211da83eacd3b223e0e8b6c.jpg'),
(78848, 5424, 'Pousando no Amor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/172203.mp4', 'http://timg.bdta.pro/images/2504eaf0c6feb65af97b6f36db8d0e6e.jpg'),
(78849, 5424, 'Pousando no Amor S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/172204.mp4', 'http://timg.bdta.pro/images/4cb620993e5f477061eea18b0f384db5.jpg'),
(78850, 5424, 'Pousando no Amor S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/172205.mp4', 'http://timg.bdta.pro/images/d72929d6fa23826b17e44b7d6ccc06f7.jpg'),
(78851, 5424, 'Pousando no Amor S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/172206.mp4', 'http://timg.bdta.pro/images/efd96bd5bca94325074130a5ddda6ae8.jpg'),
(78852, 5424, 'Pousando no Amor S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/172207.mp4', 'http://timg.bdta.pro/images/4594b341f8a6df6afab78abd57df93e2.jpg'),
(78853, 5425, 'Um de Nós Está Mentindo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200816.mp4', 'http://timg.bdta.pro/images/a0623b6938db9449acad4e915730099d.jpg'),
(78854, 5425, 'Um de Nós Está Mentindo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200817.mp4', 'http://timg.bdta.pro/images/2dcaddcda8096824bcc6b752c7f31600.jpg'),
(78855, 5425, 'Um de Nós Está Mentindo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200818.mp4', 'http://timg.bdta.pro/images/61a5fbcf03fe253cbbd73e03100bcb35.jpg'),
(78856, 5425, 'Um de Nós Está Mentindo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200819.mp4', 'http://timg.bdta.pro/images/406dd569118f846a4577940d166dce2f.jpg'),
(78857, 5425, 'Um de Nós Está Mentindo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200820.mp4', 'http://timg.bdta.pro/images/e74893cb3866085faef62d74d6064c8d.jpg'),
(78858, 5425, 'Um de Nós Está Mentindo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200821.mp4', 'http://timg.bdta.pro/images/e3810ea0ad09e81c227db134dcb3f9ea.jpg'),
(78859, 5425, 'Um de Nós Está Mentindo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200822.mp4', 'http://timg.bdta.pro/images/bad07427d8c2bf303acd6e3528418023.jpg'),
(78860, 5425, 'Um de Nós Está Mentindo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200823.mp4', 'http://timg.bdta.pro/images/4db39002ea3eb1c6d53d209c29af09e3.jpg'),
(78861, 5426, 'Um de Nós Está Mentindo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLu53NMk62W4a21OGzh6bUhp1cT.jpg'),
(78862, 5426, 'Um de Nós Está Mentindo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/269i3DfMgUjgWCALvThoiIBltrb.jpg'),
(78863, 5426, 'Um de Nós Está Mentindo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xd11xhY0cmMaGhAP13a3R6sN9iO.jpg'),
(78864, 5426, 'Um de Nós Está Mentindo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mii5hDaNGfxopjJgP7IM3M0i5Om.jpg'),
(78865, 5426, 'Um de Nós Está Mentindo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nwj47NPzU0SsSg4FfNyIQqlKG6R.jpg'),
(78866, 5426, 'Um de Nós Está Mentindo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Emr6ktwh5SWO6sheWci5Iir1Ns.jpg'),
(78867, 5426, 'Um de Nós Está Mentindo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xSBrdRpzFBnFrV2bWH6siiq9MUE.jpg'),
(78868, 5426, 'Um de Nós Está Mentindo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xjM6CIAK8X6MR6KfSKA5PWmx7sL.jpg'),
(78869, 5427, 'Uma Turma Genial S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/172182.mp4', 'http://timg.bdta.pro/images/60f5375c524321847af6929abb0d8b8f.jpg'),
(78870, 5427, 'Uma Turma Genial S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/172183.mp4', 'http://timg.bdta.pro/images/da279fd362b8a49a317287ad3470b652.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(78871, 5427, 'Uma Turma Genial S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/172184.mp4', 'http://timg.bdta.pro/images/48ece140b24fb0acec02402ad2e1b5b2.jpg'),
(78872, 5427, 'Uma Turma Genial S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/172185.mp4', 'http://timg.bdta.pro/images/a1ee574867eb404d0f522b5be3752b7f.jpg'),
(78873, 5427, 'Uma Turma Genial S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/172186.mp4', 'http://timg.bdta.pro/images/5e9dd3db57405ec28b9ae3da3ae34a62.jpg'),
(78874, 5427, 'Uma Turma Genial S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/172187.mp4', 'http://timg.bdta.pro/images/66537dd2c61b9440b67d3219bdf6650f.jpg'),
(78875, 5427, 'Uma Turma Genial S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/172188.mp4', 'http://timg.bdta.pro/images/1c4feb3bbcf54d8082f447072d47360d.jpg'),
(78876, 5427, 'Uma Turma Genial S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/172189.mp4', 'http://timg.bdta.pro/images/8523a2e1e65728a72515565c6400b621.jpg'),
(78877, 5427, 'Uma Turma Genial S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/172190.mp4', 'http://timg.bdta.pro/images/fa44c1a8955fd9db789a6a60ab588b3b.jpg'),
(78878, 5427, 'Uma Turma Genial S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/172191.mp4', 'http://timg.bdta.pro/images/085b244945ee1099ce977989a09a020b.jpg'),
(78879, 5428, 'A Mentira S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171890.mp4', 'http://timg.bdta.pro/images/a84b5d430fc15ce07eb357e793a9a822.jpg'),
(78880, 5428, 'A Mentira S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171891.mp4', 'http://timg.bdta.pro/images/7c6ea2c84ce1ee2cde7b1fe470afd9ec.jpg'),
(78881, 5428, 'A Mentira S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171892.mp4', 'http://timg.bdta.pro/images/6a8089675687633735d36767474b19c7.jpg'),
(78882, 5428, 'A Mentira S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171893.mp4', 'http://timg.bdta.pro/images/eee1096c41c9690dcbf69751bdf395fe.jpg'),
(78883, 5429, 'Alguém Em Algum Lugar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217245.mp4', 'http://timg.bdta.pro/images/fdd3cf3020f17ea906ae20292694d5bc.jpg'),
(78884, 5429, 'Alguém Em Algum Lugar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217246.mp4', 'http://timg.bdta.pro/images/2934784a4e01090c01bb78c0992cbc7c.jpg'),
(78885, 5429, 'Alguém Em Algum Lugar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217247.mp4', 'http://timg.bdta.pro/images/3684894967e4f1e4b8ce10d373ee1dd3.jpg'),
(78886, 5429, 'Alguém Em Algum Lugar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217248.mp4', 'http://timg.bdta.pro/images/4858359ecfb47cccfd6a036e45d8e8c8.jpg'),
(78887, 5429, 'Alguém Em Algum Lugar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217249.mp4', 'http://timg.bdta.pro/images/0038f48b11ad3e2f056cd6916c211a6c.jpg'),
(78888, 5429, 'Alguém Em Algum Lugar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217250.mp4', 'http://timg.bdta.pro/images/36210e22a6340abd51e501779cff1199.jpg'),
(78889, 5429, 'Alguém Em Algum Lugar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217251.mp4', 'http://timg.bdta.pro/images/4123d915bbc84f2747862fbbf5dabafa.jpg'),
(78890, 5430, 'Alguém Em Algum Lugar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217252.mp4', 'http://image.tmdb.org/t/p/w1280/zWtwTsSCRrSPhfQiOHNGp3IEep7.jpg'),
(78891, 5430, 'Alguém Em Algum Lugar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217253.mp4', 'http://image.tmdb.org/t/p/w1280/orNoNw9yFX2zsAy53v43ePtofqC.jpg'),
(78892, 5430, 'Alguém Em Algum Lugar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217254.mp4', 'http://image.tmdb.org/t/p/w1280/5xKvDw4yEflGh4VB3CapWjc92K8.jpg'),
(78893, 5430, 'Alguém Em Algum Lugar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217255.mp4', 'http://image.tmdb.org/t/p/w1280/6SvQm3JtsjGPKqEOD6bnyOgChiw.jpg'),
(78894, 5430, 'Alguém Em Algum Lugar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217256.mp4', 'http://image.tmdb.org/t/p/w1280/ytzfxNtkk7jn53COCcqZs6uFh6O.jpg'),
(78895, 5430, 'Alguém Em Algum Lugar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dTUsOcHfSyGqOaLZ7ROsS1v4oW7.jpg'),
(78896, 5430, 'Alguém Em Algum Lugar S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7DhWJ37JMauwLskdCiu9Hea84tz.jpg'),
(78897, 5431, 'Alguém Em Algum Lugar S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/493421.mp4', 'http://gstaticontent.com/images/50c1c9c9ccfe3cd95a71ccd5104ce920.jpg'),
(78898, 5431, 'Alguém Em Algum Lugar S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/497129.mp4', 'http://gstaticontent.com/images/50c1c9c9ccfe3cd95a71ccd5104ce920.jpg'),
(78899, 5431, 'Alguém Em Algum Lugar S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/503386.mp4', 'http://gstaticontent.com/images/50c1c9c9ccfe3cd95a71ccd5104ce920.jpg'),
(78900, 5431, 'Alguém Em Algum Lugar S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508069.mp4', 'http://gstaticontent.com/images/50c1c9c9ccfe3cd95a71ccd5104ce920.jpg'),
(78901, 5431, 'Alguém Em Algum Lugar S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/512597.mp4', 'http://gstaticontent.com/images/50c1c9c9ccfe3cd95a71ccd5104ce920.jpg'),
(78902, 5431, 'Alguém Em Algum Lugar S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519075.mp4', 'http://gstaticontent.com/images/50c1c9c9ccfe3cd95a71ccd5104ce920.jpg'),
(78903, 5431, 'Alguém Em Algum Lugar S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519076.mp4', 'http://gstaticontent.com/images/50c1c9c9ccfe3cd95a71ccd5104ce920.jpg'),
(78904, 5432, 'As Tartarugas Ninjas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171766.mp4', 'http://timg.bdta.pro/images/e596e063a05bf11cc6970b3f70fe69b3.jpg'),
(78905, 5432, 'As Tartarugas Ninjas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171767.mp4', 'http://timg.bdta.pro/images/c2134bf0a565581ba3c51d9efcf3e71f.jpg'),
(78906, 5432, 'As Tartarugas Ninjas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171768.mp4', 'http://timg.bdta.pro/images/f748aeab88c9d16eadba08ebc65f6ab7.jpg'),
(78907, 5432, 'As Tartarugas Ninjas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171769.mp4', 'http://timg.bdta.pro/images/eee600fa437f6319d4c553a532f0a5a2.jpg'),
(78908, 5432, 'As Tartarugas Ninjas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171770.mp4', 'http://timg.bdta.pro/images/66e8523192ca06d61925eea02fe0b478.jpg'),
(78909, 5432, 'As Tartarugas Ninjas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171771.mp4', 'http://timg.bdta.pro/images/0954bdf70febbda7b77508d1f23b89df.jpg'),
(78910, 5432, 'As Tartarugas Ninjas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171772.mp4', 'http://timg.bdta.pro/images/acc64fb4c65236e84a7696528139c038.jpg'),
(78911, 5432, 'As Tartarugas Ninjas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171773.mp4', 'http://timg.bdta.pro/images/6cfa6369433f64aab3f3321ae67fdcac.jpg'),
(78912, 5432, 'As Tartarugas Ninjas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171774.mp4', 'http://timg.bdta.pro/images/17d4fb6e9fad0c78dbc53a7d2260496e.jpg'),
(78913, 5432, 'As Tartarugas Ninjas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171775.mp4', 'http://timg.bdta.pro/images/051f01e3e5e835eb14c17d2b7fecd70c.jpg'),
(78914, 5432, 'As Tartarugas Ninjas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171776.mp4', 'http://timg.bdta.pro/images/f82c21797df3ec10fdee9197461c9a00.jpg'),
(78915, 5432, 'As Tartarugas Ninjas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171777.mp4', 'http://timg.bdta.pro/images/efcf468367972ead214a2e6798979dfb.jpg'),
(78916, 5432, 'As Tartarugas Ninjas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171778.mp4', 'http://timg.bdta.pro/images/3ca4f4bf9cc4e9da54c49b97bf8eeaad.jpg'),
(78917, 5432, 'As Tartarugas Ninjas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171779.mp4', 'http://timg.bdta.pro/images/40640e6a5af37dd0af4862aef9c2bc23.jpg'),
(78918, 5432, 'As Tartarugas Ninjas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171780.mp4', 'http://timg.bdta.pro/images/e1482906668afe1acbd6502067d5d55f.jpg'),
(78919, 5432, 'As Tartarugas Ninjas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171781.mp4', 'http://timg.bdta.pro/images/fd1a80c89de11a2a97313a154097de5a.jpg'),
(78920, 5432, 'As Tartarugas Ninjas S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171782.mp4', 'http://timg.bdta.pro/images/21ae5e06bf3aa4b0463c1dceccdccc39.jpg'),
(78921, 5432, 'As Tartarugas Ninjas S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171783.mp4', 'http://timg.bdta.pro/images/1aa326e10a8f0121f7445f2ccd3bfeb6.jpg'),
(78922, 5432, 'As Tartarugas Ninjas S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/171784.mp4', 'http://timg.bdta.pro/images/53dac167acf3c9ba87a4892585e6a45e.jpg'),
(78923, 5432, 'As Tartarugas Ninjas S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/171785.mp4', 'http://timg.bdta.pro/images/512d7cac689f8d5af74f786733716218.jpg'),
(78924, 5432, 'As Tartarugas Ninjas S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/171786.mp4', 'http://timg.bdta.pro/images/ef182371c41e0f2b7dddbb75700fbeb3.jpg'),
(78925, 5432, 'As Tartarugas Ninjas S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/171787.mp4', 'http://timg.bdta.pro/images/3c432aad5772ceaf06d8abbb81005cfd.jpg'),
(78926, 5432, 'As Tartarugas Ninjas S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/171788.mp4', 'http://timg.bdta.pro/images/493c0f54eef7e0da2eacbb0feedcd8a8.jpg'),
(78927, 5432, 'As Tartarugas Ninjas S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/171789.mp4', 'http://timg.bdta.pro/images/655cc0dd82f9523b75e5299ee6aad068.jpg'),
(78928, 5432, 'As Tartarugas Ninjas S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/171790.mp4', 'http://timg.bdta.pro/images/50288f05ce7f629508b7db3f9214386d.jpg'),
(78929, 5432, 'As Tartarugas Ninjas S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/171791.mp4', 'http://timg.bdta.pro/images/9697d12c74deb53d70152db8cf0af2c5.jpg'),
(78930, 5433, 'As Tartarugas Ninjas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171792.mp4', 'http://timg.bdta.pro/images/738314d4f33acd1206f57dcd6901cc40.jpg'),
(78931, 5433, 'As Tartarugas Ninjas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171793.mp4', 'http://timg.bdta.pro/images/c81dc41df69c3ca8415cd2bdc2a03dae.jpg'),
(78932, 5433, 'As Tartarugas Ninjas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171794.mp4', 'http://timg.bdta.pro/images/d0aac3bfb1efd73ca34b929f86977a8e.jpg'),
(78933, 5433, 'As Tartarugas Ninjas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171795.mp4', 'http://timg.bdta.pro/images/c3b7f9a6c748b3dba0a153c6ba5fcd45.jpg'),
(78934, 5433, 'As Tartarugas Ninjas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171796.mp4', 'http://timg.bdta.pro/images/d3f66f15a82a057a5e89a60eca150b5d.jpg'),
(78935, 5433, 'As Tartarugas Ninjas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171797.mp4', 'http://timg.bdta.pro/images/6f95f0b1ad4ea49630933e8dfb7d235f.jpg'),
(78936, 5433, 'As Tartarugas Ninjas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171798.mp4', 'http://timg.bdta.pro/images/b78e2febbc8028d3893bd52a9e9f0f2f.jpg'),
(78937, 5433, 'As Tartarugas Ninjas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171799.mp4', 'http://timg.bdta.pro/images/f324d993e2057b00939104408365e855.jpg'),
(78938, 5433, 'As Tartarugas Ninjas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171800.mp4', 'http://timg.bdta.pro/images/b86d0405bc44413fea3cc09471a17c47.jpg'),
(78939, 5433, 'As Tartarugas Ninjas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171801.mp4', 'http://timg.bdta.pro/images/47eedb4a6574a7bad626d9392961117c.jpg'),
(78940, 5433, 'As Tartarugas Ninjas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171802.mp4', 'http://timg.bdta.pro/images/ab265071d15aa67d1c3ec010a4fbc3bb.jpg'),
(78941, 5433, 'As Tartarugas Ninjas S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171803.mp4', 'http://timg.bdta.pro/images/008d17ea44a2d1f62dacd890c03f66b0.jpg'),
(78942, 5433, 'As Tartarugas Ninjas S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171804.mp4', 'http://timg.bdta.pro/images/273ed92c8aa583ffbde388ccfce972e7.jpg'),
(78943, 5433, 'As Tartarugas Ninjas S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171805.mp4', 'http://timg.bdta.pro/images/0fc6c872ac7b6ea10b7269217dedf922.jpg'),
(78944, 5433, 'As Tartarugas Ninjas S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171806.mp4', 'http://timg.bdta.pro/images/158e10477b0cbdf52cdaf20e687e4746.jpg'),
(78945, 5433, 'As Tartarugas Ninjas S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171807.mp4', 'http://timg.bdta.pro/images/63e03de209efbcc1358a236a185ae325.jpg'),
(78946, 5433, 'As Tartarugas Ninjas S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171808.mp4', 'http://timg.bdta.pro/images/3dbc5d4649f467bef54ab0f52bbba7f8.jpg'),
(78947, 5433, 'As Tartarugas Ninjas S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171809.mp4', 'http://timg.bdta.pro/images/09e60a01e5c3e4bc7b14ae95bf563ed3.jpg'),
(78948, 5433, 'As Tartarugas Ninjas S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/171810.mp4', 'http://timg.bdta.pro/images/fee99f2d1c5b7f7eb73fb4d2ba366f5d.jpg'),
(78949, 5433, 'As Tartarugas Ninjas S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/171811.mp4', 'http://timg.bdta.pro/images/6c54ddb5669670a1056b862a4aa16212.jpg'),
(78950, 5433, 'As Tartarugas Ninjas S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/171812.mp4', 'http://timg.bdta.pro/images/f3f0cbdab375aa29b7a771ddb1e0db08.jpg'),
(78951, 5433, 'As Tartarugas Ninjas S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/171813.mp4', 'http://timg.bdta.pro/images/be739a98f88274b25ef1e38649e0c264.jpg'),
(78952, 5433, 'As Tartarugas Ninjas S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/171814.mp4', 'http://timg.bdta.pro/images/8deed7cfa8b79e9bedf4afcc13b58881.jpg'),
(78953, 5433, 'As Tartarugas Ninjas S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/171815.mp4', 'http://timg.bdta.pro/images/cb66aa99aaa90346ef09401e4daf2911.jpg'),
(78954, 5433, 'As Tartarugas Ninjas S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/171816.mp4', 'http://timg.bdta.pro/images/856aa83b35f101ad960b3f43dd9508ad.jpg'),
(78955, 5433, 'As Tartarugas Ninjas S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/171817.mp4', 'http://timg.bdta.pro/images/f16c066f4bc6da35442956b2069c0559.jpg'),
(78956, 5434, 'As Tartarugas Ninjas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171818.mp4', 'http://timg.bdta.pro/images/61c1caafa0028a6bbfba551d50bbfbfa.jpg'),
(78957, 5434, 'As Tartarugas Ninjas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171819.mp4', 'http://timg.bdta.pro/images/7e27db63db660f110e0c51cdce3dce97.jpg'),
(78958, 5434, 'As Tartarugas Ninjas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171820.mp4', 'http://timg.bdta.pro/images/37d2776b1e2e27cc0308dc71b756499b.jpg'),
(78959, 5434, 'As Tartarugas Ninjas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171821.mp4', 'http://timg.bdta.pro/images/8073336fe9f0731d1b80f2bd54d092a3.jpg'),
(78960, 5434, 'As Tartarugas Ninjas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171822.mp4', 'http://timg.bdta.pro/images/7a90bbe234a89ddde52d6af7e0bf4a0c.jpg'),
(78961, 5434, 'As Tartarugas Ninjas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171823.mp4', 'http://timg.bdta.pro/images/3dce8805e331935a9bea917b7b0d23df.jpg'),
(78962, 5434, 'As Tartarugas Ninjas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171824.mp4', 'http://timg.bdta.pro/images/931b2161a735272bb63b9a331975f5b3.jpg'),
(78963, 5434, 'As Tartarugas Ninjas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171825.mp4', 'http://timg.bdta.pro/images/fc3f5aa287994864d976d6deaece534c.jpg'),
(78964, 5434, 'As Tartarugas Ninjas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171826.mp4', 'http://timg.bdta.pro/images/02a21881e52025d44e74abc694885b7c.jpg'),
(78965, 5434, 'As Tartarugas Ninjas S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171827.mp4', 'http://timg.bdta.pro/images/2e7efd04ec94caf47b54383ab5202789.jpg'),
(78966, 5434, 'As Tartarugas Ninjas S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171828.mp4', 'http://timg.bdta.pro/images/36d95fe99619578edd5dd10510b27870.jpg'),
(78967, 5434, 'As Tartarugas Ninjas S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171829.mp4', 'http://timg.bdta.pro/images/aafe81b95b7e4f87e8855c58f56f174c.jpg'),
(78968, 5434, 'As Tartarugas Ninjas S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171830.mp4', 'http://timg.bdta.pro/images/a9aee29554d8d628f4117ebbe8fde4f9.jpg'),
(78969, 5434, 'As Tartarugas Ninjas S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171831.mp4', 'http://timg.bdta.pro/images/737996c295387897e2b03b4494db3e95.jpg'),
(78970, 5434, 'As Tartarugas Ninjas S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171832.mp4', 'http://timg.bdta.pro/images/a9afb09280b597e2b13de7e77c094413.jpg'),
(78971, 5434, 'As Tartarugas Ninjas S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171833.mp4', 'http://timg.bdta.pro/images/4308e74f3e872dfe94edc39204e58299.jpg'),
(78972, 5434, 'As Tartarugas Ninjas S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171834.mp4', 'http://timg.bdta.pro/images/7a2e1f0a0bb2342974383e8b912b16d4.jpg'),
(78973, 5434, 'As Tartarugas Ninjas S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171835.mp4', 'http://timg.bdta.pro/images/ad275f01ed26bd9b91bd00f6102b0370.jpg'),
(78974, 5434, 'As Tartarugas Ninjas S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/171836.mp4', 'http://timg.bdta.pro/images/943f34a56bc16a59ecaf30f852886fcd.jpg'),
(78975, 5434, 'As Tartarugas Ninjas S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/171837.mp4', 'http://timg.bdta.pro/images/cdc218cebcc72ded85683b8353e0ea82.jpg'),
(78976, 5434, 'As Tartarugas Ninjas S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/171838.mp4', 'http://timg.bdta.pro/images/05f0c35abd87d960739edf3dc00ce317.jpg'),
(78977, 5434, 'As Tartarugas Ninjas S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/171839.mp4', 'http://timg.bdta.pro/images/64b69337a5a827dd82760c57a26c5307.jpg'),
(78978, 5434, 'As Tartarugas Ninjas S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/171840.mp4', 'http://timg.bdta.pro/images/462be1142b0590cbfb18d810ad2dc1f6.jpg'),
(78979, 5434, 'As Tartarugas Ninjas S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/171841.mp4', 'http://timg.bdta.pro/images/20205ac635a348d3d9d5e1f5137b1606.jpg'),
(78980, 5434, 'As Tartarugas Ninjas S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/171842.mp4', 'http://timg.bdta.pro/images/3103376da92934c5fcc9a0ce88a20c12.jpg'),
(78981, 5434, 'As Tartarugas Ninjas S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/171843.mp4', 'http://timg.bdta.pro/images/3103376da92934c5fcc9a0ce88a20c12.jpg'),
(78982, 5435, 'As Tartarugas Ninjas S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171844.mp4', 'http://timg.bdta.pro/images/4ae7c383a02bd19fee29fd4d7a19420d.jpg'),
(78983, 5435, 'As Tartarugas Ninjas S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171845.mp4', 'http://timg.bdta.pro/images/828fa9c0886c76d47e088a474d7442b9.jpg'),
(78984, 5435, 'As Tartarugas Ninjas S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171846.mp4', 'http://timg.bdta.pro/images/34d43b0e3a0358d302a9cfc092ecd1ce.jpg'),
(78985, 5435, 'As Tartarugas Ninjas S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171847.mp4', 'http://timg.bdta.pro/images/ffd3c4977b00683af517f7582058234a.jpg'),
(78986, 5435, 'As Tartarugas Ninjas S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171848.mp4', 'http://timg.bdta.pro/images/bdfc3cbc7d456858910bdbf5ad9a34d3.jpg'),
(78987, 5435, 'As Tartarugas Ninjas S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171849.mp4', 'http://timg.bdta.pro/images/60936f61a1f5847d1768d0b4903d0c02.jpg'),
(78988, 5435, 'As Tartarugas Ninjas S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171850.mp4', 'http://timg.bdta.pro/images/29862fbf708c2e4b572be4a503aede1e.jpg'),
(78989, 5435, 'As Tartarugas Ninjas S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171851.mp4', 'http://timg.bdta.pro/images/9b520be2c317a849ea5cdc4e3b39c45c.jpg'),
(78990, 5435, 'As Tartarugas Ninjas S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171852.mp4', 'http://timg.bdta.pro/images/bdf6315c7fd4b80714b5109308408ec1.jpg'),
(78991, 5435, 'As Tartarugas Ninjas S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171853.mp4', 'http://timg.bdta.pro/images/bdf6315c7fd4b80714b5109308408ec1.jpg'),
(78992, 5435, 'As Tartarugas Ninjas S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171854.mp4', 'http://timg.bdta.pro/images/bc4d073cd2ea26dc8950d886e81754c8.jpg'),
(78993, 5435, 'As Tartarugas Ninjas S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171855.mp4', 'http://timg.bdta.pro/images/83a9878bb4810e7737a5c771cb1623d5.jpg'),
(78994, 5435, 'As Tartarugas Ninjas S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171856.mp4', 'http://timg.bdta.pro/images/aeb8ee5394b3c334c7c5d0143ac1ec1c.jpg'),
(78995, 5435, 'As Tartarugas Ninjas S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171857.mp4', 'http://timg.bdta.pro/images/9de334f55d55e7f8edc11d63f854f34d.jpg'),
(78996, 5435, 'As Tartarugas Ninjas S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171858.mp4', 'http://timg.bdta.pro/images/8de299d6f74f0d5a994ad3230f3414bf.jpg'),
(78997, 5435, 'As Tartarugas Ninjas S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171859.mp4', 'http://timg.bdta.pro/images/f8f8700645338c189f9f0b61d899c255.jpg'),
(78998, 5435, 'As Tartarugas Ninjas S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171860.mp4', 'http://timg.bdta.pro/images/cbc2b55a0002931932db112c5099f560.jpg'),
(78999, 5435, 'As Tartarugas Ninjas S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171861.mp4', 'http://timg.bdta.pro/images/a4d828d86fdc82405318a70a3c9b04cb.jpg'),
(79000, 5435, 'As Tartarugas Ninjas S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/171862.mp4', 'http://timg.bdta.pro/images/48bb3e1f2210263689a9facfffaca067.jpg'),
(79001, 5435, 'As Tartarugas Ninjas S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/171863.mp4', 'http://timg.bdta.pro/images/48bb3e1f2210263689a9facfffaca067.jpg'),
(79002, 5435, 'As Tartarugas Ninjas S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/171864.mp4', 'http://timg.bdta.pro/images/24aa4d7f3db9d94b094ffe0b7e2e3ed1.jpg'),
(79003, 5435, 'As Tartarugas Ninjas S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/171865.mp4', 'http://timg.bdta.pro/images/1d8ff36bf85f0f85f0f4dc5fc3720675.jpg'),
(79004, 5435, 'As Tartarugas Ninjas S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/171866.mp4', 'http://timg.bdta.pro/images/7468caf56edef67c73f6fcb2ea214dfd.jpg'),
(79005, 5435, 'As Tartarugas Ninjas S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/171867.mp4', 'http://timg.bdta.pro/images/c7008149bc71f7ca3c48aa0318d65693.jpg'),
(79006, 5435, 'As Tartarugas Ninjas S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/171868.mp4', 'http://timg.bdta.pro/images/77effde95163967f3199e84630c31b06.jpg'),
(79007, 5435, 'As Tartarugas Ninjas S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/171869.mp4', 'http://timg.bdta.pro/images/e40c8c211657eb6e1ae93dbbfa4b4f12.jpg'),
(79008, 5436, 'As Tartarugas Ninjas S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171870.mp4', 'http://gstaticontent.com/images/a10c427148644ccc0588e2acc2e32668.jpg'),
(79009, 5436, 'As Tartarugas Ninjas S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171871.mp4', 'http://gstaticontent.com/images/a10c427148644ccc0588e2acc2e32668.jpg'),
(79010, 5436, 'As Tartarugas Ninjas S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171872.mp4', 'http://gstaticontent.com/images/a10c427148644ccc0588e2acc2e32668.jpg'),
(79011, 5436, 'As Tartarugas Ninjas S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171873.mp4', 'http://gstaticontent.com/images/a10c427148644ccc0588e2acc2e32668.jpg'),
(79012, 5436, 'As Tartarugas Ninjas S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171874.mp4', 'http://gstaticontent.com/images/a10c427148644ccc0588e2acc2e32668.jpg'),
(79013, 5436, 'As Tartarugas Ninjas S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171875.mp4', 'http://gstaticontent.com/images/a10c427148644ccc0588e2acc2e32668.jpg'),
(79014, 5436, 'As Tartarugas Ninjas S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171876.mp4', 'http://gstaticontent.com/images/a10c427148644ccc0588e2acc2e32668.jpg'),
(79015, 5436, 'As Tartarugas Ninjas S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171877.mp4', 'http://gstaticontent.com/images/a10c427148644ccc0588e2acc2e32668.jpg'),
(79016, 5436, 'As Tartarugas Ninjas S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171878.mp4', 'http://gstaticontent.com/images/a10c427148644ccc0588e2acc2e32668.jpg'),
(79017, 5436, 'As Tartarugas Ninjas S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171879.mp4', 'http://gstaticontent.com/images/a10c427148644ccc0588e2acc2e32668.jpg'),
(79018, 5436, 'As Tartarugas Ninjas S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171880.mp4', 'http://gstaticontent.com/images/a10c427148644ccc0588e2acc2e32668.jpg'),
(79019, 5436, 'As Tartarugas Ninjas S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171881.mp4', 'http://gstaticontent.com/images/a10c427148644ccc0588e2acc2e32668.jpg'),
(79020, 5436, 'As Tartarugas Ninjas S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/171882.mp4', 'http://gstaticontent.com/images/a10c427148644ccc0588e2acc2e32668.jpg'),
(79021, 5436, 'As Tartarugas Ninjas S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/171883.mp4', 'http://gstaticontent.com/images/a10c427148644ccc0588e2acc2e32668.jpg'),
(79022, 5436, 'As Tartarugas Ninjas S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/171884.mp4', 'http://gstaticontent.com/images/a10c427148644ccc0588e2acc2e32668.jpg'),
(79023, 5436, 'As Tartarugas Ninjas S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/171885.mp4', 'http://gstaticontent.com/images/a10c427148644ccc0588e2acc2e32668.jpg'),
(79024, 5436, 'As Tartarugas Ninjas S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/171886.mp4', 'http://gstaticontent.com/images/a10c427148644ccc0588e2acc2e32668.jpg'),
(79025, 5436, 'As Tartarugas Ninjas S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/171887.mp4', 'http://gstaticontent.com/images/a10c427148644ccc0588e2acc2e32668.jpg'),
(79026, 5436, 'As Tartarugas Ninjas S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/171888.mp4', 'http://gstaticontent.com/images/a10c427148644ccc0588e2acc2e32668.jpg'),
(79027, 5436, 'As Tartarugas Ninjas S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/171889.mp4', 'http://gstaticontent.com/images/a10c427148644ccc0588e2acc2e32668.jpg'),
(79028, 5437, 'Bubba Wallace: Na Raça S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171760.mp4', 'http://gstaticontent.com/images/adc3409bedcb91404c4d2e19a5014e1f.jpg'),
(79029, 5437, 'Bubba Wallace: Na Raça S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171761.mp4', 'http://gstaticontent.com/images/adc3409bedcb91404c4d2e19a5014e1f.jpg'),
(79030, 5437, 'Bubba Wallace: Na Raça S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171762.mp4', 'http://gstaticontent.com/images/adc3409bedcb91404c4d2e19a5014e1f.jpg'),
(79031, 5437, 'Bubba Wallace: Na Raça S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171763.mp4', 'http://gstaticontent.com/images/adc3409bedcb91404c4d2e19a5014e1f.jpg'),
(79032, 5437, 'Bubba Wallace: Na Raça S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171764.mp4', 'http://gstaticontent.com/images/adc3409bedcb91404c4d2e19a5014e1f.jpg'),
(79033, 5437, 'Bubba Wallace: Na Raça S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171765.mp4', 'http://gstaticontent.com/images/adc3409bedcb91404c4d2e19a5014e1f.jpg'),
(79034, 5438, 'Bump S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198951.mp4', 'http://timg.bdta.pro/images/2666b0ace7ede75c925eae85ecb28b24.jpg'),
(79035, 5438, 'Bump S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198952.mp4', 'http://timg.bdta.pro/images/af585d3b100fa2d7c891cf4d4d14efeb.jpg'),
(79036, 5438, 'Bump S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198953.mp4', 'http://timg.bdta.pro/images/8ef2c5919f3da031d6fd5a798cc4e081.jpg'),
(79037, 5438, 'Bump S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198954.mp4', 'http://timg.bdta.pro/images/9c18d2d0566cd358c120536f6479f25c.jpg'),
(79038, 5438, 'Bump S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198955.mp4', 'http://timg.bdta.pro/images/375c09bc2496985a7d7ff48746578da4.jpg'),
(79039, 5438, 'Bump S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198956.mp4', 'http://timg.bdta.pro/images/5ec4f60027ba289f7389723b32206152.jpg'),
(79040, 5438, 'Bump S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198957.mp4', 'http://timg.bdta.pro/images/557d8c32af275e13ce932536a9193b48.jpg'),
(79041, 5438, 'Bump S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198958.mp4', 'http://timg.bdta.pro/images/6f04f06e16b65939e7b78d5a46eb28f9.jpg'),
(79042, 5438, 'Bump S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198959.mp4', 'http://timg.bdta.pro/images/c29cf1741e3a83c1a2c87c8cfbbfba31.jpg'),
(79043, 5438, 'Bump S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198960.mp4', 'http://timg.bdta.pro/images/2f4fa924b993633f8dc8a1f236d0116f.jpg'),
(79044, 5439, 'Bump S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198961.mp4', 'http://gstaticontent.com/images/2f04d7a7852cca25562b237715ec8441.jpg'),
(79045, 5439, 'Bump S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198962.mp4', 'http://gstaticontent.com/images/2f04d7a7852cca25562b237715ec8441.jpg'),
(79046, 5439, 'Bump S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198963.mp4', 'http://gstaticontent.com/images/2f04d7a7852cca25562b237715ec8441.jpg'),
(79047, 5439, 'Bump S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198964.mp4', 'http://gstaticontent.com/images/2f04d7a7852cca25562b237715ec8441.jpg'),
(79048, 5439, 'Bump S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198965.mp4', 'http://gstaticontent.com/images/2f04d7a7852cca25562b237715ec8441.jpg'),
(79049, 5439, 'Bump S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198966.mp4', 'http://gstaticontent.com/images/2f04d7a7852cca25562b237715ec8441.jpg'),
(79050, 5439, 'Bump S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198967.mp4', 'http://gstaticontent.com/images/2f04d7a7852cca25562b237715ec8441.jpg'),
(79051, 5439, 'Bump S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198968.mp4', 'http://gstaticontent.com/images/2f04d7a7852cca25562b237715ec8441.jpg'),
(79052, 5439, 'Bump S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198969.mp4', 'http://gstaticontent.com/images/2f04d7a7852cca25562b237715ec8441.jpg'),
(79053, 5439, 'Bump S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198970.mp4', 'http://gstaticontent.com/images/2f04d7a7852cca25562b237715ec8441.jpg'),
(79054, 5440, 'Com Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171755.mp4', 'http://timg.bdta.pro/images/12485678ff779ecf1a49403a07e3dd1d.jpg'),
(79055, 5440, 'Com Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171756.mp4', 'http://timg.bdta.pro/images/2002b8824eddcb6c0fc32150019ae4d5.jpg'),
(79056, 5440, 'Com Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171757.mp4', 'http://timg.bdta.pro/images/5d90095add5efc96a7b6df925188b27f.jpg'),
(79057, 5440, 'Com Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171758.mp4', 'http://timg.bdta.pro/images/f46d0c70e3c8e2970c46ef839e88a29a.jpg'),
(79058, 5440, 'Com Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171759.mp4', 'http://timg.bdta.pro/images/97e135129e003f1a487db6737232911c.jpg'),
(79059, 5441, 'Criadores de Diversão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171747.mp4', 'http://gstaticontent.com/images/6e8e19eac3dce2bea371f0bbd8d93878.jpg'),
(79060, 5441, 'Criadores de Diversão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171748.mp4', 'http://gstaticontent.com/images/6e8e19eac3dce2bea371f0bbd8d93878.jpg'),
(79061, 5441, 'Criadores de Diversão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171749.mp4', 'http://gstaticontent.com/images/6e8e19eac3dce2bea371f0bbd8d93878.jpg'),
(79062, 5441, 'Criadores de Diversão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171750.mp4', 'http://gstaticontent.com/images/6e8e19eac3dce2bea371f0bbd8d93878.jpg'),
(79063, 5441, 'Criadores de Diversão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171751.mp4', 'http://gstaticontent.com/images/6e8e19eac3dce2bea371f0bbd8d93878.jpg'),
(79064, 5441, 'Criadores de Diversão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171752.mp4', 'http://gstaticontent.com/images/6e8e19eac3dce2bea371f0bbd8d93878.jpg'),
(79065, 5441, 'Criadores de Diversão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171753.mp4', 'http://gstaticontent.com/images/6e8e19eac3dce2bea371f0bbd8d93878.jpg'),
(79066, 5441, 'Criadores de Diversão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171754.mp4', 'http://gstaticontent.com/images/6e8e19eac3dce2bea371f0bbd8d93878.jpg'),
(79067, 5442, 'De Volta Aos 15 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219041.mp4', 'http://timg.bdta.pro/images/bd0deceb717280d5eb5680aa212c7c10.jpg'),
(79068, 5442, 'De Volta Aos 15 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219042.mp4', 'http://timg.bdta.pro/images/13759ff80e8305155ac822eed11b3896.jpg'),
(79069, 5442, 'De Volta Aos 15 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219043.mp4', 'http://timg.bdta.pro/images/36aa9a155961a8d4a4ba83b21fc41039.jpg'),
(79070, 5442, 'De Volta Aos 15 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219044.mp4', 'http://timg.bdta.pro/images/1da9889e613b0e7b4f25371f3d69310e.jpg'),
(79071, 5442, 'De Volta Aos 15 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219045.mp4', 'http://timg.bdta.pro/images/f1c8c52cf104cee537dca416f953df7e.jpg'),
(79072, 5442, 'De Volta Aos 15 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219046.mp4', 'http://timg.bdta.pro/images/0b3b743b3a1c978447cdc13fbe97cab1.jpg'),
(79073, 5443, 'De Volta Aos 15 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219047.mp4', 'http://gstaticontent.com/images/d57b8be9754cb5e19332f0497c1c40b1.jpg'),
(79074, 5443, 'De Volta Aos 15 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219048.mp4', 'http://gstaticontent.com/images/d57b8be9754cb5e19332f0497c1c40b1.jpg'),
(79075, 5443, 'De Volta Aos 15 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219049.mp4', 'http://gstaticontent.com/images/d57b8be9754cb5e19332f0497c1c40b1.jpg'),
(79076, 5443, 'De Volta Aos 15 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219050.mp4', 'http://gstaticontent.com/images/d57b8be9754cb5e19332f0497c1c40b1.jpg'),
(79077, 5443, 'De Volta Aos 15 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219051.mp4', 'http://gstaticontent.com/images/d57b8be9754cb5e19332f0497c1c40b1.jpg'),
(79078, 5443, 'De Volta Aos 15 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219052.mp4', 'http://gstaticontent.com/images/d57b8be9754cb5e19332f0497c1c40b1.jpg'),
(79079, 5444, 'De Volta Aos 15 S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/437002.mp4', 'http://gstaticontent.com/images/d57b8be9754cb5e19332f0497c1c40b1.jpg'),
(79080, 5444, 'De Volta Aos 15 S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/437003.mp4', 'http://gstaticontent.com/images/d57b8be9754cb5e19332f0497c1c40b1.jpg'),
(79081, 5444, 'De Volta Aos 15 S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/437004.mp4', 'http://gstaticontent.com/images/d57b8be9754cb5e19332f0497c1c40b1.jpg'),
(79082, 5444, 'De Volta Aos 15 S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/437005.mp4', 'http://gstaticontent.com/images/d57b8be9754cb5e19332f0497c1c40b1.jpg'),
(79083, 5444, 'De Volta Aos 15 S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/437006.mp4', 'http://gstaticontent.com/images/d57b8be9754cb5e19332f0497c1c40b1.jpg'),
(79084, 5444, 'De Volta Aos 15 S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/437007.mp4', 'http://gstaticontent.com/images/d57b8be9754cb5e19332f0497c1c40b1.jpg'),
(79085, 5445, 'Elza & Mané: Amor em Linhas Tortas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171743.mp4', 'http://gstaticontent.com/images/53788c2fd671e1c5016aed87caca4535.jpg'),
(79086, 5445, 'Elza & Mané: Amor em Linhas Tortas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171744.mp4', 'http://gstaticontent.com/images/53788c2fd671e1c5016aed87caca4535.jpg'),
(79087, 5445, 'Elza & Mané: Amor em Linhas Tortas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171745.mp4', 'http://gstaticontent.com/images/53788c2fd671e1c5016aed87caca4535.jpg'),
(79088, 5445, 'Elza & Mané: Amor em Linhas Tortas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171746.mp4', 'http://gstaticontent.com/images/53788c2fd671e1c5016aed87caca4535.jpg'),
(79089, 5446, 'As Novas Aventuras de Gasparzinho S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200940.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79090, 5446, 'As Novas Aventuras de Gasparzinho S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200941.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79091, 5446, 'As Novas Aventuras de Gasparzinho S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200942.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79092, 5446, 'As Novas Aventuras de Gasparzinho S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200943.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79093, 5446, 'As Novas Aventuras de Gasparzinho S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200944.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79094, 5446, 'As Novas Aventuras de Gasparzinho S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200945.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79095, 5446, 'As Novas Aventuras de Gasparzinho S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200946.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79096, 5446, 'As Novas Aventuras de Gasparzinho S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200947.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79097, 5446, 'As Novas Aventuras de Gasparzinho S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200948.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79098, 5446, 'As Novas Aventuras de Gasparzinho S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200949.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79099, 5446, 'As Novas Aventuras de Gasparzinho S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200950.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79100, 5446, 'As Novas Aventuras de Gasparzinho S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200951.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79101, 5446, 'As Novas Aventuras de Gasparzinho S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200952.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79102, 5446, 'As Novas Aventuras de Gasparzinho S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/200953.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79103, 5446, 'As Novas Aventuras de Gasparzinho S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/200954.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79104, 5446, 'As Novas Aventuras de Gasparzinho S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/200955.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79105, 5446, 'As Novas Aventuras de Gasparzinho S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/200956.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79106, 5446, 'As Novas Aventuras de Gasparzinho S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/200957.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79107, 5446, 'As Novas Aventuras de Gasparzinho S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/200958.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79108, 5446, 'As Novas Aventuras de Gasparzinho S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/200959.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79109, 5446, 'As Novas Aventuras de Gasparzinho S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/200960.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79110, 5446, 'As Novas Aventuras de Gasparzinho S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/200961.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79111, 5446, 'As Novas Aventuras de Gasparzinho S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/200962.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79112, 5446, 'As Novas Aventuras de Gasparzinho S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/200963.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79113, 5446, 'As Novas Aventuras de Gasparzinho S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/200964.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79114, 5446, 'As Novas Aventuras de Gasparzinho S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/200965.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79115, 5447, 'As Novas Aventuras de Gasparzinho S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200966.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79116, 5447, 'As Novas Aventuras de Gasparzinho S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200967.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79117, 5447, 'As Novas Aventuras de Gasparzinho S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200968.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79118, 5447, 'As Novas Aventuras de Gasparzinho S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200969.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79119, 5447, 'As Novas Aventuras de Gasparzinho S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200970.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79120, 5447, 'As Novas Aventuras de Gasparzinho S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200971.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79121, 5447, 'As Novas Aventuras de Gasparzinho S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200972.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79122, 5447, 'As Novas Aventuras de Gasparzinho S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200973.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79123, 5447, 'As Novas Aventuras de Gasparzinho S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200974.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79124, 5447, 'As Novas Aventuras de Gasparzinho S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200975.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79125, 5447, 'As Novas Aventuras de Gasparzinho S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200976.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79126, 5447, 'As Novas Aventuras de Gasparzinho S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200977.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79127, 5447, 'As Novas Aventuras de Gasparzinho S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200978.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79128, 5447, 'As Novas Aventuras de Gasparzinho S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/200979.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79129, 5447, 'As Novas Aventuras de Gasparzinho S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/200980.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79130, 5447, 'As Novas Aventuras de Gasparzinho S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/200981.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79131, 5447, 'As Novas Aventuras de Gasparzinho S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/200982.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79132, 5447, 'As Novas Aventuras de Gasparzinho S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/200983.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79133, 5447, 'As Novas Aventuras de Gasparzinho S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/200984.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79134, 5447, 'As Novas Aventuras de Gasparzinho S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/200985.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79135, 5447, 'As Novas Aventuras de Gasparzinho S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/200986.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79136, 5447, 'As Novas Aventuras de Gasparzinho S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/200987.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79137, 5447, 'As Novas Aventuras de Gasparzinho S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/200988.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79138, 5447, 'As Novas Aventuras de Gasparzinho S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/200989.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79139, 5447, 'As Novas Aventuras de Gasparzinho S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/200990.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79140, 5447, 'As Novas Aventuras de Gasparzinho S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/200991.mp4', 'http://gstaticontent.com/images/0eb47041ee0907fce23ac781747fda21.jpg'),
(79141, 5448, 'Guardiões da Justiça S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171736.mp4', 'http://timg.bdta.pro/images/546bfb4d631bb1fe1dd16d7bd022fd32.jpg'),
(79142, 5448, 'Guardiões da Justiça S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171737.mp4', 'http://timg.bdta.pro/images/2c16506424e856bb9e37fbd988cb8d4e.jpg'),
(79143, 5448, 'Guardiões da Justiça S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171738.mp4', 'http://timg.bdta.pro/images/bf3c99b4d1752e00972d280ed5f5f137.jpg'),
(79144, 5448, 'Guardiões da Justiça S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171739.mp4', 'http://timg.bdta.pro/images/2cf8368ff0ef868ddfa2f5f77c23a510.jpg'),
(79145, 5448, 'Guardiões da Justiça S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171740.mp4', 'http://timg.bdta.pro/images/8229871ceb3c9f064699656bb31be15c.jpg'),
(79146, 5448, 'Guardiões da Justiça S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171741.mp4', 'http://timg.bdta.pro/images/326f1044ca60c0037f0d2a95f362016a.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(79147, 5448, 'Guardiões da Justiça S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171742.mp4', 'http://timg.bdta.pro/images/f3e30e5da68c9e21460d811a08c9711c.jpg'),
(79148, 5449, 'Inspetora Koo Kyung Yi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171724.mp4', 'http://timg.bdta.pro/images/123899c4d30cdb97993d18a4a4a320e4.jpg'),
(79149, 5449, 'Inspetora Koo Kyung Yi S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171725.mp4', 'http://timg.bdta.pro/images/7c9e7cfab8329daa802b8f52cd1421f1.jpg'),
(79150, 5449, 'Inspetora Koo Kyung Yi S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171726.mp4', 'http://timg.bdta.pro/images/e0cb660b17c9b1c3da298a741a428cd5.jpg'),
(79151, 5449, 'Inspetora Koo Kyung Yi S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171727.mp4', 'http://timg.bdta.pro/images/666c32800c5f0b107cab9a40180243e7.jpg'),
(79152, 5449, 'Inspetora Koo Kyung Yi S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171728.mp4', 'http://timg.bdta.pro/images/d2cdabe963165fb2b5925310b16354f5.jpg'),
(79153, 5449, 'Inspetora Koo Kyung Yi S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171729.mp4', 'http://timg.bdta.pro/images/53a44fb1859b5a93396c2c3a899026bc.jpg'),
(79154, 5449, 'Inspetora Koo Kyung Yi S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/171730.mp4', 'http://timg.bdta.pro/images/5ad195f7b7bb82d3f6218d4e0f197c04.jpg'),
(79155, 5449, 'Inspetora Koo Kyung Yi S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/171731.mp4', 'http://timg.bdta.pro/images/f8edf7dc9d67c0f210756beda42eade4.jpg'),
(79156, 5449, 'Inspetora Koo Kyung Yi S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/171732.mp4', 'http://timg.bdta.pro/images/22d267ea326df89a044b7a25347cef7f.jpg'),
(79157, 5449, 'Inspetora Koo Kyung Yi S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/171733.mp4', 'http://timg.bdta.pro/images/36d30a46522a42cfc4e461bc5f62aba6.jpg'),
(79158, 5449, 'Inspetora Koo Kyung Yi S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/171734.mp4', 'http://timg.bdta.pro/images/a27d0079f8e25f01a1f0f65ff6d27fbd.jpg'),
(79159, 5449, 'Inspetora Koo Kyung Yi S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/171735.mp4', 'http://timg.bdta.pro/images/dccddb995f7124652faf4f8359f6a60e.jpg'),
(79160, 5450, 'Irmaos Voltaggio Batalha de Chefs S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171718.mp4', 'http://gstaticontent.com/images/38a9424152c42cb0b91446a6488da747.jpg'),
(79161, 5450, 'Irmaos Voltaggio Batalha de Chefs S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171719.mp4', 'http://gstaticontent.com/images/38a9424152c42cb0b91446a6488da747.jpg'),
(79162, 5450, 'Irmaos Voltaggio Batalha de Chefs S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171720.mp4', 'http://gstaticontent.com/images/38a9424152c42cb0b91446a6488da747.jpg'),
(79163, 5450, 'Irmaos Voltaggio Batalha de Chefs S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/171721.mp4', 'http://gstaticontent.com/images/38a9424152c42cb0b91446a6488da747.jpg'),
(79164, 5450, 'Irmaos Voltaggio Batalha de Chefs S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/171722.mp4', 'http://gstaticontent.com/images/38a9424152c42cb0b91446a6488da747.jpg'),
(79165, 5450, 'Irmaos Voltaggio Batalha de Chefs S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/171723.mp4', 'http://gstaticontent.com/images/38a9424152c42cb0b91446a6488da747.jpg'),
(79166, 5451, 'jeen-yuhs: Trilogia Kanye S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/171715.mp4', 'http://timg.bdta.pro/images/7e8843f63485cc9005f616833acb1e84.jpg'),
(79167, 5451, 'jeen-yuhs: Trilogia Kanye S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/171716.mp4', 'http://timg.bdta.pro/images/b54451200c06e58345a5e3bdc95b3869.jpg'),
(79168, 5451, 'jeen-yuhs: Trilogia Kanye S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/171717.mp4', 'http://timg.bdta.pro/images/be40d41fb1e06d810c1452f743c5b5d3.jpg'),
(79169, 5452, 'Juvenile Justice S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175610.mp4', 'http://timg.bdta.pro/images/4b3340e7765d223fbdc70f020051bd12.jpg'),
(79170, 5452, 'Juvenile Justice S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175611.mp4', 'http://timg.bdta.pro/images/b1962cff56ba38e666a9d746530444d8.jpg'),
(79171, 5452, 'Juvenile Justice S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175612.mp4', 'http://timg.bdta.pro/images/14c0ae6c53958c4cecbfff9dec38c103.jpg'),
(79172, 5452, 'Juvenile Justice S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175613.mp4', 'http://timg.bdta.pro/images/768609f673ec637f85142c3e91dd8f89.jpg'),
(79173, 5452, 'Juvenile Justice S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175614.mp4', 'http://timg.bdta.pro/images/4911ba91418a11d3d5627e77daf8d7ad.jpg'),
(79174, 5452, 'Juvenile Justice S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175615.mp4', 'http://timg.bdta.pro/images/60ca6c0e087e962bddb27ed3c7f5ff9c.jpg'),
(79175, 5452, 'Juvenile Justice S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175616.mp4', 'http://timg.bdta.pro/images/1436234048536ef6b557deda5d1cb275.jpg'),
(79176, 5452, 'Juvenile Justice S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175617.mp4', 'http://timg.bdta.pro/images/e1b7fd1d45e393658577bf8a8ec98362.jpg'),
(79177, 5452, 'Juvenile Justice S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/175618.mp4', 'http://timg.bdta.pro/images/3f3cf3666fb801f6852e4d0476a44f4c.jpg'),
(79178, 5452, 'Juvenile Justice S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/175619.mp4', 'http://timg.bdta.pro/images/dc4cb80140f8dd048a971a10a58cba70.jpg'),
(79179, 5453, 'La divina gula S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175604.mp4', 'http://gstaticontent.com/images/47e576c04cad7b53ba632e1858f3a5c6.jpg'),
(79180, 5453, 'La divina gula S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175605.mp4', 'http://gstaticontent.com/images/47e576c04cad7b53ba632e1858f3a5c6.jpg'),
(79181, 5453, 'La divina gula S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175606.mp4', 'http://gstaticontent.com/images/47e576c04cad7b53ba632e1858f3a5c6.jpg'),
(79182, 5453, 'La divina gula S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175607.mp4', 'http://gstaticontent.com/images/47e576c04cad7b53ba632e1858f3a5c6.jpg'),
(79183, 5453, 'La divina gula S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175608.mp4', 'http://gstaticontent.com/images/47e576c04cad7b53ba632e1858f3a5c6.jpg'),
(79184, 5453, 'La divina gula S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175609.mp4', 'http://gstaticontent.com/images/47e576c04cad7b53ba632e1858f3a5c6.jpg'),
(79185, 5454, 'Lov3 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175598.mp4', 'http://timg.bdta.pro/images/9cb9fbb0d058105cfb063cabba69888c.jpg'),
(79186, 5454, 'Lov3 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175599.mp4', 'http://timg.bdta.pro/images/97420783ff2c0447d2f9f68e0a958fd7.jpg'),
(79187, 5454, 'Lov3 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175600.mp4', 'http://timg.bdta.pro/images/3ffd10240edf8e416d169e3c9de18278.jpg'),
(79188, 5454, 'Lov3 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175601.mp4', 'http://timg.bdta.pro/images/f87c0997ed5c9c6ff6d673eaa3c35020.jpg'),
(79189, 5454, 'Lov3 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175602.mp4', 'http://timg.bdta.pro/images/737a8b1edf24810ca3bb80ddd3c3e010.jpg'),
(79190, 5454, 'Lov3 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175603.mp4', 'http://timg.bdta.pro/images/f955b7497bfab76560d05d5a3faafb1b.jpg'),
(79191, 5455, 'Meia-Noite no Hotel Pera Palace S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175590.mp4', 'http://timg.bdta.pro/images/a5118eb8dd85f2f77617fa2583b84717.jpg'),
(79192, 5455, 'Meia-Noite no Hotel Pera Palace S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175591.mp4', 'http://timg.bdta.pro/images/841e8faefb8a2dd0e61cd6b96ec17fee.jpg'),
(79193, 5455, 'Meia-Noite no Hotel Pera Palace S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175592.mp4', 'http://timg.bdta.pro/images/7043b77dedf2e6b7cb69f384f629aeca.jpg'),
(79194, 5455, 'Meia-Noite no Hotel Pera Palace S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175593.mp4', 'http://timg.bdta.pro/images/6306cc9a324ce025e9f902d923216ff2.jpg'),
(79195, 5455, 'Meia-Noite no Hotel Pera Palace S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175594.mp4', 'http://timg.bdta.pro/images/668816bc1ac173f6e27a0a56b304785c.jpg'),
(79196, 5455, 'Meia-Noite no Hotel Pera Palace S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175595.mp4', 'http://timg.bdta.pro/images/698e8ed74557f89dbab7b863e8265789.jpg'),
(79197, 5455, 'Meia-Noite no Hotel Pera Palace S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175596.mp4', 'http://timg.bdta.pro/images/98672d74b2687b1eb88abef6db83d050.jpg'),
(79198, 5455, 'Meia-Noite no Hotel Pera Palace S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175597.mp4', 'http://timg.bdta.pro/images/dc0fca5598070cdb879e8626dc8f1b87.jpg'),
(79199, 5456, 'Meia-Noite no Hotel Pera Palace S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/452345.mp4', 'http://gstaticontent.com/images/87cde1acffe9556c588f9de58d2acadd.jpg'),
(79200, 5456, 'Meia-Noite no Hotel Pera Palace S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/452346.mp4', 'http://gstaticontent.com/images/87cde1acffe9556c588f9de58d2acadd.jpg'),
(79201, 5456, 'Meia-Noite no Hotel Pera Palace S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/452347.mp4', 'http://gstaticontent.com/images/87cde1acffe9556c588f9de58d2acadd.jpg'),
(79202, 5456, 'Meia-Noite no Hotel Pera Palace S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/452348.mp4', 'http://gstaticontent.com/images/87cde1acffe9556c588f9de58d2acadd.jpg'),
(79203, 5456, 'Meia-Noite no Hotel Pera Palace S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/452349.mp4', 'http://gstaticontent.com/images/87cde1acffe9556c588f9de58d2acadd.jpg'),
(79204, 5456, 'Meia-Noite no Hotel Pera Palace S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/452350.mp4', 'http://gstaticontent.com/images/87cde1acffe9556c588f9de58d2acadd.jpg'),
(79205, 5456, 'Meia-Noite no Hotel Pera Palace S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/452351.mp4', 'http://gstaticontent.com/images/87cde1acffe9556c588f9de58d2acadd.jpg'),
(79206, 5456, 'Meia-Noite no Hotel Pera Palace S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/452352.mp4', 'http://gstaticontent.com/images/87cde1acffe9556c588f9de58d2acadd.jpg'),
(79207, 5457, 'Mentiras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175584.mp4', 'http://timg.bdta.pro/images/5987ef25e4a310fa1c3481e75a93a621.jpg'),
(79208, 5457, 'Mentiras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175585.mp4', 'http://timg.bdta.pro/images/c17fcf436da1c3ef7d993a55957bb8e6.jpg'),
(79209, 5457, 'Mentiras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175586.mp4', 'http://timg.bdta.pro/images/3ffd09da1da87d6e47f57a6e56da4b34.jpg'),
(79210, 5457, 'Mentiras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175587.mp4', 'http://timg.bdta.pro/images/859f211cf016286ef3862e5d5fd0b4d9.jpg'),
(79211, 5457, 'Mentiras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175588.mp4', 'http://timg.bdta.pro/images/d496b0c0ce6cf81f46169762471bfd8c.jpg'),
(79212, 5457, 'Mentiras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175589.mp4', 'http://timg.bdta.pro/images/c0cd8e5318467f0ba339e8e70f3b27be.jpg'),
(79213, 5458, 'Monstro do Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175530.mp4', 'http://timg.bdta.pro/images/a02f31a99d4bf0abbbd6cc16f8807768.jpg'),
(79214, 5458, 'Monstro do Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175531.mp4', 'http://timg.bdta.pro/images/5738a02670eea93f7a6e16deae7cb5a3.jpg'),
(79215, 5458, 'Monstro do Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175532.mp4', 'http://timg.bdta.pro/images/4ac6bfc63298cdd75cd933f84d232847.jpg'),
(79216, 5458, 'Monstro do Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175533.mp4', 'http://timg.bdta.pro/images/26143a1abc6ee30875f3a19d0a031e7b.jpg'),
(79217, 5458, 'Monstro do Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175534.mp4', 'http://timg.bdta.pro/images/5422e201a635823dab1a0d8f2785d06d.jpg'),
(79218, 5458, 'Monstro do Amor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175535.mp4', 'http://timg.bdta.pro/images/d58ffda068fa43f40dcca7bd3075e438.jpg'),
(79219, 5458, 'Monstro do Amor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175536.mp4', 'http://timg.bdta.pro/images/cefdf28da05743ccd2315550c92364dd.jpg'),
(79220, 5458, 'Monstro do Amor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175537.mp4', 'http://timg.bdta.pro/images/2a6d2ac68ee240f7a3f03ac39a648342.jpg'),
(79221, 5458, 'Monstro do Amor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/175538.mp4', 'http://timg.bdta.pro/images/09e7bf2c2315cf59c9e8236dbcb9b4ad.jpg'),
(79222, 5458, 'Monstro do Amor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/175539.mp4', 'http://timg.bdta.pro/images/66fed387175b3a3f0538e959f252bbbd.jpg'),
(79223, 5458, 'Monstro do Amor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/175540.mp4', 'http://timg.bdta.pro/images/20f2c9431defdacf23b08b74a6ecc42c.jpg'),
(79224, 5458, 'Monstro do Amor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/175541.mp4', 'http://timg.bdta.pro/images/36ab1c57f03bd0e3187f4d33c40798fe.jpg'),
(79225, 5458, 'Monstro do Amor S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/175542.mp4', 'http://timg.bdta.pro/images/0fae497ce03d8d6702055ff2a40acd00.jpg'),
(79226, 5458, 'Monstro do Amor S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/175543.mp4', 'http://timg.bdta.pro/images/022f68e6d0e726b8ecdc4dbf6dd15404.jpg'),
(79227, 5458, 'Monstro do Amor S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/175544.mp4', 'http://timg.bdta.pro/images/7e84b2180cc9ba7398dd3cba6d863615.jpg'),
(79228, 5458, 'Monstro do Amor S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/175545.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79229, 5458, 'Monstro do Amor S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/175546.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79230, 5458, 'Monstro do Amor S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/175547.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79231, 5458, 'Monstro do Amor S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/175548.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79232, 5458, 'Monstro do Amor S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/175549.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79233, 5458, 'Monstro do Amor S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/175550.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79234, 5458, 'Monstro do Amor S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/175551.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79235, 5458, 'Monstro do Amor S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/175552.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79236, 5458, 'Monstro do Amor S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/175553.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79237, 5458, 'Monstro do Amor S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/175554.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79238, 5458, 'Monstro do Amor S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/175555.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79239, 5458, 'Monstro do Amor S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/175556.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79240, 5459, 'Monstro do Amor S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175557.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79241, 5459, 'Monstro do Amor S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175558.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79242, 5459, 'Monstro do Amor S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175559.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79243, 5459, 'Monstro do Amor S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175560.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79244, 5459, 'Monstro do Amor S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175561.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79245, 5459, 'Monstro do Amor S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175562.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79246, 5459, 'Monstro do Amor S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175563.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79247, 5459, 'Monstro do Amor S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175564.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79248, 5459, 'Monstro do Amor S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/175565.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79249, 5459, 'Monstro do Amor S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/175566.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79250, 5459, 'Monstro do Amor S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/175567.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79251, 5459, 'Monstro do Amor S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/175568.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79252, 5459, 'Monstro do Amor S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/175569.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79253, 5459, 'Monstro do Amor S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/175570.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79254, 5459, 'Monstro do Amor S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/175571.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79255, 5459, 'Monstro do Amor S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/175572.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79256, 5459, 'Monstro do Amor S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/175573.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79257, 5459, 'Monstro do Amor S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/175574.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79258, 5459, 'Monstro do Amor S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/175575.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79259, 5459, 'Monstro do Amor S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/175576.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79260, 5459, 'Monstro do Amor S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/175577.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79261, 5459, 'Monstro do Amor S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/175578.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79262, 5459, 'Monstro do Amor S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/175579.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79263, 5459, 'Monstro do Amor S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/175580.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79264, 5459, 'Monstro do Amor S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/175581.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79265, 5459, 'Monstro do Amor S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/175582.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79266, 5459, 'Monstro do Amor S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/175583.mp4', 'http://gstaticontent.com/images/ce5f307bf8304d41b070a9efa25ef582.jpg'),
(79267, 5460, 'Morador Indesejado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175525.mp4', 'http://timg.bdta.pro/images/21d8b44941bfd46aed8bd1f678140775.jpg'),
(79268, 5460, 'Morador Indesejado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175526.mp4', 'http://timg.bdta.pro/images/8faae5604860887ad18f55752abce6c1.jpg'),
(79269, 5460, 'Morador Indesejado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175527.mp4', 'http://timg.bdta.pro/images/5bf4e961a4fd4fc4c6575218dac6b3fd.jpg'),
(79270, 5460, 'Morador Indesejado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175528.mp4', 'http://timg.bdta.pro/images/d78590122c4514248b26aa9153c20edd.jpg'),
(79271, 5460, 'Morador Indesejado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175529.mp4', 'http://timg.bdta.pro/images/8cd7631e981838da2060f819b395b850.jpg'),
(79272, 5461, 'Ninguém Pode Saber S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175517.mp4', 'http://timg.bdta.pro/images/b17d9f399f0648bf69279aa1bea488ef.jpg'),
(79273, 5461, 'Ninguém Pode Saber S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175518.mp4', 'http://timg.bdta.pro/images/1a5cecd36921fc4ad0e684a113dc7d76.jpg'),
(79274, 5461, 'Ninguém Pode Saber S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175519.mp4', 'http://timg.bdta.pro/images/2059ee43e472401654e4d677e1ae8ed5.jpg'),
(79275, 5461, 'Ninguém Pode Saber S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175520.mp4', 'http://timg.bdta.pro/images/898f0989917425bf71465a568c0a60c9.jpg'),
(79276, 5461, 'Ninguém Pode Saber S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175521.mp4', 'http://timg.bdta.pro/images/a8b553866c3664579e4d95b313ee0262.jpg'),
(79277, 5461, 'Ninguém Pode Saber S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175522.mp4', 'http://timg.bdta.pro/images/16d016c214bd41b2bc9389a399067732.jpg'),
(79278, 5461, 'Ninguém Pode Saber S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175523.mp4', 'http://timg.bdta.pro/images/f75f7238ebca0e5cd392dcbd11f2f407.jpg'),
(79279, 5461, 'Ninguém Pode Saber S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175524.mp4', 'http://timg.bdta.pro/images/e18dc05b11cc615813b2088f9e5d002a.jpg'),
(79280, 5462, 'O Jogo da Fama S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175509.mp4', 'http://timg.bdta.pro/images/6f7bbd292fb108062b631f4a9eee011d.jpg'),
(79281, 5462, 'O Jogo da Fama S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175510.mp4', 'http://timg.bdta.pro/images/788ee59359a0a644302a94a9f4fef666.jpg'),
(79282, 5462, 'O Jogo da Fama S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175511.mp4', 'http://timg.bdta.pro/images/5e0361972f852d277c4ddb9de1f8ed9d.jpg'),
(79283, 5462, 'O Jogo da Fama S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175512.mp4', 'http://timg.bdta.pro/images/d00540553a7e98fbf665e9c1211f78fd.jpg'),
(79284, 5462, 'O Jogo da Fama S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175513.mp4', 'http://timg.bdta.pro/images/662615f7f700a79675c2dfc83b5b311e.jpg'),
(79285, 5462, 'O Jogo da Fama S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175514.mp4', 'http://timg.bdta.pro/images/10748aa1eb5ba8e1c1895584f7b14a05.jpg'),
(79286, 5462, 'O Jogo da Fama S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175515.mp4', 'http://timg.bdta.pro/images/1c9fa7012d8e4445c837f9e32161e857.jpg'),
(79287, 5462, 'O Jogo da Fama S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175516.mp4', 'http://timg.bdta.pro/images/a34baeb68648c0ba2f4d83715098d4de.jpg'),
(79288, 5463, 'O Mundo Maravilhoso de Mickey Mouse S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175489.mp4', 'http://timg.bdta.pro/images/301d98a3dd4a999745fa4885c4aa4fe8.jpg'),
(79289, 5463, 'O Mundo Maravilhoso de Mickey Mouse S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175490.mp4', 'http://timg.bdta.pro/images/fdde636e26f79bd5ee51dc753173f25b.jpg'),
(79290, 5463, 'O Mundo Maravilhoso de Mickey Mouse S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175491.mp4', 'http://timg.bdta.pro/images/d478c79b06b4e2b894555ef422f2c768.jpg'),
(79291, 5463, 'O Mundo Maravilhoso de Mickey Mouse S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175492.mp4', 'http://timg.bdta.pro/images/4d34c2d63e36ccdc1293b6cad107127c.jpg'),
(79292, 5463, 'O Mundo Maravilhoso de Mickey Mouse S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175493.mp4', 'http://timg.bdta.pro/images/537fefb151f0db85224ca63766a660bf.jpg'),
(79293, 5463, 'O Mundo Maravilhoso de Mickey Mouse S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175494.mp4', 'http://timg.bdta.pro/images/fa7a0e461ef3a32450e32bd166205d6e.jpg'),
(79294, 5463, 'O Mundo Maravilhoso de Mickey Mouse S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175495.mp4', 'http://timg.bdta.pro/images/a4954dc302838d1b4f9873890e12ea3d.jpg'),
(79295, 5463, 'O Mundo Maravilhoso de Mickey Mouse S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175496.mp4', 'http://timg.bdta.pro/images/1786f627b71bba04a6d49f7f497b1587.jpg'),
(79296, 5463, 'O Mundo Maravilhoso de Mickey Mouse S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/175497.mp4', 'http://timg.bdta.pro/images/d125fe1f25da0a769b53546d1cce0ce1.jpg'),
(79297, 5463, 'O Mundo Maravilhoso de Mickey Mouse S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/175498.mp4', 'http://timg.bdta.pro/images/7fe3559261e94d02d00eebaee98087b8.jpg'),
(79298, 5463, 'O Mundo Maravilhoso de Mickey Mouse S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/175499.mp4', 'http://timg.bdta.pro/images/4608e17f4edebbcfd51743a260d32fed.jpg'),
(79299, 5463, 'O Mundo Maravilhoso de Mickey Mouse S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/175500.mp4', 'http://timg.bdta.pro/images/ca8f332be05ea9dcff6b0ad28421de0c.jpg'),
(79300, 5463, 'O Mundo Maravilhoso de Mickey Mouse S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/175501.mp4', 'http://timg.bdta.pro/images/a2c29a1fd95a38a413a1780417773c05.jpg'),
(79301, 5463, 'O Mundo Maravilhoso de Mickey Mouse S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/175502.mp4', 'http://timg.bdta.pro/images/4cf6d8b2e8d6811f180bfb743ec52d95.jpg'),
(79302, 5463, 'O Mundo Maravilhoso de Mickey Mouse S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/175503.mp4', 'http://timg.bdta.pro/images/1faa4d68bc6df905d0fff47343676d80.jpg'),
(79303, 5463, 'O Mundo Maravilhoso de Mickey Mouse S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/175504.mp4', 'http://timg.bdta.pro/images/d457e39c9172f60b3c16e0560d8130b5.jpg'),
(79304, 5463, 'O Mundo Maravilhoso de Mickey Mouse S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/175505.mp4', 'http://timg.bdta.pro/images/5cdb923eb209fe64745bacb692253c47.jpg'),
(79305, 5463, 'O Mundo Maravilhoso de Mickey Mouse S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/175506.mp4', 'http://timg.bdta.pro/images/d302c8d5cc7088d90fb7973da1bf1e0d.jpg'),
(79306, 5463, 'O Mundo Maravilhoso de Mickey Mouse S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/175507.mp4', 'http://timg.bdta.pro/images/044189cad6c205fe38c3df236819e610.jpg'),
(79307, 5463, 'O Mundo Maravilhoso de Mickey Mouse S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/175508.mp4', 'http://timg.bdta.pro/images/cabf2e823453b153511893835844175e.jpg'),
(79308, 5464, 'Operação Maré Negra: A Travessia Suicida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175485.mp4', 'http://timg.bdta.pro/images/763eca7e49ebb48bd5dd889675454929.jpg'),
(79309, 5464, 'Operação Maré Negra: A Travessia Suicida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175486.mp4', 'http://timg.bdta.pro/images/a43d6b02d2d6bfb6e692ae84d38ca4aa.jpg'),
(79310, 5464, 'Operação Maré Negra: A Travessia Suicida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175487.mp4', 'http://timg.bdta.pro/images/7963e02728b6466d3d6f9289d9f2888d.jpg'),
(79311, 5464, 'Operação Maré Negra: A Travessia Suicida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175488.mp4', 'http://timg.bdta.pro/images/2d1e5810a3c53095438d89f1bbd6eee4.jpg'),
(79312, 5465, 'Os Busbys + 5 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254383.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79313, 5465, 'Os Busbys + 5 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254384.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79314, 5465, 'Os Busbys + 5 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254385.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79315, 5465, 'Os Busbys + 5 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254386.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79316, 5466, 'Os Busbys + 5 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254387.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79317, 5466, 'Os Busbys + 5 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254388.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79318, 5466, 'Os Busbys + 5 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254389.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79319, 5466, 'Os Busbys + 5 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254390.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79320, 5466, 'Os Busbys + 5 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254391.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79321, 5466, 'Os Busbys + 5 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254392.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79322, 5466, 'Os Busbys + 5 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254393.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79323, 5466, 'Os Busbys + 5 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254394.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79324, 5466, 'Os Busbys + 5 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254395.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79325, 5466, 'Os Busbys + 5 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254396.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79326, 5467, 'Os Busbys + 5 S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254397.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79327, 5467, 'Os Busbys + 5 S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254398.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79328, 5467, 'Os Busbys + 5 S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254399.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79329, 5467, 'Os Busbys + 5 S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254400.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79330, 5467, 'Os Busbys + 5 S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254401.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79331, 5467, 'Os Busbys + 5 S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254402.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79332, 5467, 'Os Busbys + 5 S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254403.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79333, 5467, 'Os Busbys + 5 S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254404.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79334, 5467, 'Os Busbys + 5 S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254405.mp4', 'http://gstaticontent.com/images/196ec0c4ca471fc08a3bdd51a084b004.jpg'),
(79335, 5468, 'Por que Odiamos? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175479.mp4', 'http://gstaticontent.com/images/1ebe7399121f97a5c96a144ee27f7ce3.jpg'),
(79336, 5468, 'Por que Odiamos? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175480.mp4', 'http://gstaticontent.com/images/1ebe7399121f97a5c96a144ee27f7ce3.jpg'),
(79337, 5468, 'Por que Odiamos? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175481.mp4', 'http://gstaticontent.com/images/1ebe7399121f97a5c96a144ee27f7ce3.jpg'),
(79338, 5468, 'Por que Odiamos? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175482.mp4', 'http://gstaticontent.com/images/1ebe7399121f97a5c96a144ee27f7ce3.jpg'),
(79339, 5468, 'Por que Odiamos? S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175483.mp4', 'http://gstaticontent.com/images/1ebe7399121f97a5c96a144ee27f7ce3.jpg'),
(79340, 5468, 'Por que Odiamos? S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175484.mp4', 'http://gstaticontent.com/images/1ebe7399121f97a5c96a144ee27f7ce3.jpg'),
(79341, 5469, 'Que Cilada! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206792.mp4', 'http://timg.bdta.pro/images/e22cbc02fdddce618ca0b772c68eddfe.jpg'),
(79342, 5469, 'Que Cilada! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206793.mp4', 'http://timg.bdta.pro/images/b3c43ed22a4e8b1af396cfe536861a8c.jpg'),
(79343, 5469, 'Que Cilada! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206794.mp4', 'http://timg.bdta.pro/images/fd4a5aea6b4d4c8c2a00f6f9263c616d.jpg'),
(79344, 5469, 'Que Cilada! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206795.mp4', 'http://timg.bdta.pro/images/10f6c33f0091c55d57710ab31e669f09.jpg'),
(79345, 5469, 'Que Cilada! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206796.mp4', 'http://timg.bdta.pro/images/c455e3f04ad475305da9e4934c6dc0dc.jpg'),
(79346, 5469, 'Que Cilada! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206797.mp4', 'http://timg.bdta.pro/images/f87831f97b53383fe8a0e262d421a461.jpg'),
(79347, 5470, 'Que Cilada! S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wIIvTvgrNyEWt1tcSZ0fgRjVgyI.jpg'),
(79348, 5470, 'Que Cilada! S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g81MmvZi94xDemgBuoqHx8uPfAj.jpg'),
(79349, 5470, 'Que Cilada! S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWa2ScpObaImpbLxVRpbgMIku9w.jpg'),
(79350, 5470, 'Que Cilada! S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3u9Whpd1oNwfVYKey1OR8BLkTQV.jpg'),
(79351, 5470, 'Que Cilada! S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PIa5yBSws6EOUtdjUfLeofmydf.jpg'),
(79352, 5470, 'Que Cilada! S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vvtgkXVgiPI5dCPyYGUvMnGfgHw.jpg'),
(79353, 5471, 'Quem Era Ela S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175475.mp4', 'http://timg.bdta.pro/images/fe82913f02a0f575dbefdce6ba05ff36.jpg'),
(79354, 5471, 'Quem Era Ela S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175476.mp4', 'http://timg.bdta.pro/images/4484f5318aa2b84667d380bd2451e84a.jpg'),
(79355, 5471, 'Quem Era Ela S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175477.mp4', 'http://timg.bdta.pro/images/727c66efa0b0db81d991b74d71e8533b.jpg'),
(79356, 5471, 'Quem Era Ela S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175478.mp4', 'http://timg.bdta.pro/images/81c4f2c1c42323906bdfbd3fb8f6093e.jpg'),
(79357, 5472, 'Ritmo Selvagem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175467.mp4', 'http://timg.bdta.pro/images/7f0812cc0ae94d46149e924c155b31fe.jpg'),
(79358, 5472, 'Ritmo Selvagem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175468.mp4', 'http://timg.bdta.pro/images/35d06dd9897e5ab57c91ec4c79dde4e7.jpg'),
(79359, 5472, 'Ritmo Selvagem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175469.mp4', 'http://timg.bdta.pro/images/c75d0b52842f645f8f0ec30ab88a076d.jpg'),
(79360, 5472, 'Ritmo Selvagem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175470.mp4', 'http://timg.bdta.pro/images/12810580ce4c27b4b32a294b0d89fb59.jpg'),
(79361, 5472, 'Ritmo Selvagem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175471.mp4', 'http://timg.bdta.pro/images/cdb5d830b90d1996b22f7d314395d2fa.jpg'),
(79362, 5472, 'Ritmo Selvagem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175472.mp4', 'http://timg.bdta.pro/images/b8c992b4a3002ce66b5643baa03a531f.jpg'),
(79363, 5472, 'Ritmo Selvagem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175473.mp4', 'http://timg.bdta.pro/images/cf98de73d17cb3b6815517be04c870eb.jpg'),
(79364, 5472, 'Ritmo Selvagem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175474.mp4', 'http://timg.bdta.pro/images/f784e4f41acd98276c538efe95fdcbc2.jpg'),
(79365, 5473, 'Ruptura S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176063.mp4', 'http://timg.bdta.pro/images/4cc127b8bf44f85da463b085cbf09396.jpg'),
(79366, 5473, 'Ruptura S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176064.mp4', 'http://timg.bdta.pro/images/1d92b122b01c51bd943960d65de7fe63.jpg'),
(79367, 5473, 'Ruptura S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176065.mp4', 'http://timg.bdta.pro/images/c23dbd4a15785147063857388914207e.jpg'),
(79368, 5473, 'Ruptura S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176066.mp4', 'http://timg.bdta.pro/images/f0aeabcbc7286819afef62715a06ab8d.jpg'),
(79369, 5473, 'Ruptura S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176067.mp4', 'http://timg.bdta.pro/images/068c19ddc50402eb4c74305c2e305c2a.jpg'),
(79370, 5473, 'Ruptura S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176068.mp4', 'http://timg.bdta.pro/images/a4e8f31756253baf83bd4762381d100d.jpg'),
(79371, 5473, 'Ruptura S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176069.mp4', 'http://timg.bdta.pro/images/93ee6ee56b970bc2c4e230ad648e3bd9.jpg'),
(79372, 5473, 'Ruptura S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176070.mp4', 'http://timg.bdta.pro/images/7c93880806aab1078d26ca03bee77a2f.jpg'),
(79373, 5473, 'Ruptura S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176071.mp4', 'http://timg.bdta.pro/images/e3aae81b6da1f2fb6306a9a30b1991e4.jpg'),
(79374, 5474, 'Ruptura S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/667487.mp4', 'http://gstaticontent.com/images/10ca127d6f6805ba074bacda2f2f46ff.jpg'),
(79375, 5474, 'Ruptura S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/677230.mp4', 'http://gstaticontent.com/images/10ca127d6f6805ba074bacda2f2f46ff.jpg'),
(79376, 5474, 'Ruptura S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/678385.mp4', 'http://gstaticontent.com/images/10ca127d6f6805ba074bacda2f2f46ff.jpg'),
(79377, 5474, 'Ruptura S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/687162.mp4', 'http://gstaticontent.com/images/10ca127d6f6805ba074bacda2f2f46ff.jpg'),
(79378, 5474, 'Ruptura S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/697525.mp4', 'http://gstaticontent.com/images/10ca127d6f6805ba074bacda2f2f46ff.jpg'),
(79379, 5474, 'Ruptura S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/704296.mp4', 'http://gstaticontent.com/images/10ca127d6f6805ba074bacda2f2f46ff.jpg'),
(79380, 5474, 'Ruptura S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/713298.mp4', 'http://gstaticontent.com/images/10ca127d6f6805ba074bacda2f2f46ff.jpg'),
(79381, 5474, 'Ruptura S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/716989.mp4', 'http://gstaticontent.com/images/10ca127d6f6805ba074bacda2f2f46ff.jpg'),
(79382, 5474, 'Ruptura S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/723803.mp4', 'http://gstaticontent.com/images/10ca127d6f6805ba074bacda2f2f46ff.jpg'),
(79383, 5474, 'Ruptura S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/730324.mp4', 'http://gstaticontent.com/images/10ca127d6f6805ba074bacda2f2f46ff.jpg'),
(79384, 5475, 'Ilhados e Desesperados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258979.mp4', 'http://timg.bdta.pro/images/54c016d4123bac4c4fa3863b612ac7c6.jpg'),
(79385, 5475, 'Ilhados e Desesperados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258980.mp4', 'http://timg.bdta.pro/images/70ebcbf461e63997d26ea90b3a6087c5.jpg'),
(79386, 5475, 'Ilhados e Desesperados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258981.mp4', 'http://timg.bdta.pro/images/05155d380436efbc965005eeacbb4762.jpg'),
(79387, 5475, 'Ilhados e Desesperados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258982.mp4', 'http://timg.bdta.pro/images/09e666c1725ad8f5d1cad4225c2924c7.jpg'),
(79388, 5475, 'Ilhados e Desesperados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258983.mp4', 'http://timg.bdta.pro/images/2ba05da9625097493bff423475b70a60.jpg'),
(79389, 5475, 'Ilhados e Desesperados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258984.mp4', 'http://timg.bdta.pro/images/bd4ee08a2f311aa97ba1fbb3822e3960.jpg'),
(79390, 5475, 'Ilhados e Desesperados S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258985.mp4', 'http://timg.bdta.pro/images/975c76725adaf3f5d8c0b0e27b2250b0.jpg'),
(79391, 5475, 'Ilhados e Desesperados S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258986.mp4', 'http://timg.bdta.pro/images/689c180b85ef8895e0d3ed8788dae8ee.jpg'),
(79392, 5476, 'Ilhados e Desesperados S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6fJREmnWrT9PAbpdzd0S8I1F8Kf.jpg'),
(79393, 5476, 'Ilhados e Desesperados S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jaXb7JPBM7PoadBHfC2T8cG0Knt.jpg'),
(79394, 5476, 'Ilhados e Desesperados S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8dLYto3ONShuZHDnsmedvlpNnEK.jpg'),
(79395, 5476, 'Ilhados e Desesperados S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y5C0TWmeMjNroAq4sHzKrbh5Dfl.jpg'),
(79396, 5476, 'Ilhados e Desesperados S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JFkzlLOcZIz4KtvQrwztz8UqKm.jpg'),
(79397, 5476, 'Ilhados e Desesperados S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dshUxAgBLzAFNbMcqkN5OtcdHRf.jpg'),
(79398, 5476, 'Ilhados e Desesperados S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258993.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79399, 5476, 'Ilhados e Desesperados S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258994.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79400, 5476, 'Ilhados e Desesperados S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258995.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79401, 5476, 'Ilhados e Desesperados S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258996.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79402, 5477, 'Ilhados e Desesperados S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258997.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79403, 5477, 'Ilhados e Desesperados S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258998.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79404, 5477, 'Ilhados e Desesperados S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258999.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79405, 5477, 'Ilhados e Desesperados S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259000.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79406, 5477, 'Ilhados e Desesperados S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259001.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79407, 5477, 'Ilhados e Desesperados S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259002.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79408, 5477, 'Ilhados e Desesperados S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259003.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79409, 5477, 'Ilhados e Desesperados S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259004.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79410, 5477, 'Ilhados e Desesperados S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259005.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79411, 5477, 'Ilhados e Desesperados S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259006.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79412, 5477, 'Ilhados e Desesperados S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259007.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79413, 5478, 'Ilhados e Desesperados S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/688064.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79414, 5478, 'Ilhados e Desesperados S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/688065.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79415, 5478, 'Ilhados e Desesperados S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/688066.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79416, 5478, 'Ilhados e Desesperados S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/688067.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79417, 5478, 'Ilhados e Desesperados S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/688068.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79418, 5478, 'Ilhados e Desesperados S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/688069.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79419, 5478, 'Ilhados e Desesperados S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/688070.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79420, 5478, 'Ilhados e Desesperados S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/688071.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79421, 5478, 'Ilhados e Desesperados S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/688072.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79422, 5478, 'Ilhados e Desesperados S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/688073.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79423, 5478, 'Ilhados e Desesperados S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/692839.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79424, 5478, 'Ilhados e Desesperados S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/692840.mp4', 'http://gstaticontent.com/images/34e5caba76245f36ca1371260a45eb95.jpg'),
(79425, 5479, 'Suspicion S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177758.mp4', 'http://timg.bdta.pro/images/641d8ec7ef65de7dfd8a924703ffdbb3.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(79426, 5479, 'Suspicion S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177759.mp4', 'http://timg.bdta.pro/images/341de50cd1a9fbbb5986f7aaab1f6efb.jpg'),
(79427, 5479, 'Suspicion S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177760.mp4', 'http://timg.bdta.pro/images/2bb010b044853c174be7969a65d7b545.jpg'),
(79428, 5479, 'Suspicion S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177761.mp4', 'http://timg.bdta.pro/images/03e620d1cccf7817390391cc5d7d080b.jpg'),
(79429, 5479, 'Suspicion S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177762.mp4', 'http://timg.bdta.pro/images/c818276467d1bceaa55ed2da4e03911f.jpg'),
(79430, 5479, 'Suspicion S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177763.mp4', 'http://timg.bdta.pro/images/bfc1ccfc6d982e08bf6b3aa913c2aa8a.jpg'),
(79431, 5479, 'Suspicion S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177764.mp4', 'http://timg.bdta.pro/images/91fbc91d7f3077716777da760be0edd3.jpg'),
(79432, 5479, 'Suspicion S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177765.mp4', 'http://timg.bdta.pro/images/92d7412e54bb7630f4315b3346ba894f.jpg'),
(79433, 5480, 'The Boys Apresenta: Diabólicos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175459.mp4', 'http://timg.bdta.pro/images/9d96e96bb30b60d7900f4e609390ecae.jpg'),
(79434, 5480, 'The Boys Apresenta: Diabólicos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175460.mp4', 'http://timg.bdta.pro/images/198a93599d3e8853f5ab95603a02bc52.jpg'),
(79435, 5480, 'The Boys Apresenta: Diabólicos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175461.mp4', 'http://timg.bdta.pro/images/7f67497fb29d46f294314dd34bf6369d.jpg'),
(79436, 5480, 'The Boys Apresenta: Diabólicos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175462.mp4', 'http://timg.bdta.pro/images/1fb1ae059f6b028a30f0466f7e0162fa.jpg'),
(79437, 5480, 'The Boys Apresenta: Diabólicos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175463.mp4', 'http://timg.bdta.pro/images/9d89905c632d3cdfcb4fe6718cd6380e.jpg'),
(79438, 5480, 'The Boys Apresenta: Diabólicos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175464.mp4', 'http://timg.bdta.pro/images/9d0c9eba7026974d282d0069f03fb402.jpg'),
(79439, 5480, 'The Boys Apresenta: Diabólicos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175465.mp4', 'http://timg.bdta.pro/images/de5bbe697d58e191d97c66bd2685e6da.jpg'),
(79440, 5480, 'The Boys Apresenta: Diabólicos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175466.mp4', 'http://timg.bdta.pro/images/a66f7e31048d1469a01c6e036e385394.jpg'),
(79441, 5481, 'Ursinhos Carinhosos e Seus Primos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/561203.mp4', 'http://gstaticontent.com/images/f3516178eb023d1f373d6c1cc47f8555.jpg'),
(79442, 5481, 'Ursinhos Carinhosos e Seus Primos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/561205.mp4', 'http://gstaticontent.com/images/ac5ce2e5e0a80f4e17a961c1850ddb8e.jpg'),
(79443, 5481, 'Ursinhos Carinhosos e Seus Primos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/561207.mp4', 'http://gstaticontent.com/images/c3342a41c1629fa9c00934cd6c6fc6da.jpg'),
(79444, 5481, 'Ursinhos Carinhosos e Seus Primos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/561209.mp4', 'http://gstaticontent.com/images/abde01d5ced569304f003ce2f752e2c0.jpg'),
(79445, 5481, 'Ursinhos Carinhosos e Seus Primos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/561211.mp4', 'http://gstaticontent.com/images/6b830466fa9de5079a6770f5d0f3ba57.jpg'),
(79446, 5481, 'Ursinhos Carinhosos e Seus Primos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/561213.mp4', 'http://gstaticontent.com/images/636d0ce4d64c858dbefdb84857c37669.jpg'),
(79447, 5482, 'Vikings: Valhalla S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205473.mp4', 'http://timg.bdta.pro/images/c764a48e8e6d023ad8c65fc6972da458.jpg'),
(79448, 5482, 'Vikings: Valhalla S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205474.mp4', 'http://timg.bdta.pro/images/6d583c20c45b330559dc1c9b5a059451.jpg'),
(79449, 5482, 'Vikings: Valhalla S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205475.mp4', 'http://timg.bdta.pro/images/763b01f4e2e87a78f8b6b6a413cd61b6.jpg'),
(79450, 5482, 'Vikings: Valhalla S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205476.mp4', 'http://timg.bdta.pro/images/500366ca50bf17340e839d83400945ec.jpg'),
(79451, 5482, 'Vikings: Valhalla S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205477.mp4', 'http://timg.bdta.pro/images/b1ae67271ccecdf890e1d722ea85e2bf.jpg'),
(79452, 5482, 'Vikings: Valhalla S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205478.mp4', 'http://timg.bdta.pro/images/a93b99d2106aabd8a0cd3e6a0b0a46c4.jpg'),
(79453, 5482, 'Vikings: Valhalla S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205479.mp4', 'http://timg.bdta.pro/images/aa0ee2e3e3263ac6cb91b89ba6c8e366.jpg'),
(79454, 5482, 'Vikings: Valhalla S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205480.mp4', 'http://timg.bdta.pro/images/cbdafcaba893ca56367028ad7d5724b5.jpg'),
(79455, 5483, 'Vikings: Valhalla S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m7bGM5PxR3odPS64qJcTGRJn0fG.jpg'),
(79456, 5483, 'Vikings: Valhalla S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTaHhybN2VmYmSRWo0ujurriYsu.jpg'),
(79457, 5483, 'Vikings: Valhalla S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ukdoOnxsqjwdX0SWdTnD1RUheg.jpg'),
(79458, 5483, 'Vikings: Valhalla S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yBZZBficEQAqn7puLOVWmQ7ZXIy.jpg'),
(79459, 5483, 'Vikings: Valhalla S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rXzfFgpSUlArxYx4cDQL7nT4l2p.jpg'),
(79460, 5483, 'Vikings: Valhalla S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sWVQqBiOiCdnbOTmFzcF85KyP0k.jpg'),
(79461, 5483, 'Vikings: Valhalla S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9sWgzAQgVJnwnSfBKIfdvqpgFNI.jpg'),
(79462, 5483, 'Vikings: Valhalla S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nrqimvkCEnABuXNtveT5IoTw0h.jpg'),
(79463, 5484, 'Vikings: Valhalla S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/406126.mp4', 'http://gstaticontent.com/images/04e0643c0cb6f7633a8c52543db8e31b.jpg'),
(79464, 5484, 'Vikings: Valhalla S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/406127.mp4', 'http://gstaticontent.com/images/04e0643c0cb6f7633a8c52543db8e31b.jpg'),
(79465, 5484, 'Vikings: Valhalla S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/406128.mp4', 'http://gstaticontent.com/images/04e0643c0cb6f7633a8c52543db8e31b.jpg'),
(79466, 5484, 'Vikings: Valhalla S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/406129.mp4', 'http://gstaticontent.com/images/04e0643c0cb6f7633a8c52543db8e31b.jpg'),
(79467, 5484, 'Vikings: Valhalla S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/406130.mp4', 'http://gstaticontent.com/images/04e0643c0cb6f7633a8c52543db8e31b.jpg'),
(79468, 5484, 'Vikings: Valhalla S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/406131.mp4', 'http://gstaticontent.com/images/04e0643c0cb6f7633a8c52543db8e31b.jpg'),
(79469, 5484, 'Vikings: Valhalla S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/406132.mp4', 'http://gstaticontent.com/images/04e0643c0cb6f7633a8c52543db8e31b.jpg'),
(79470, 5484, 'Vikings: Valhalla S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/406133.mp4', 'http://gstaticontent.com/images/04e0643c0cb6f7633a8c52543db8e31b.jpg'),
(79471, 5485, 'A Agência S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178468.mp4', 'http://timg.bdta.pro/images/9d73c80c48891fbad6f778b049831d23.jpg'),
(79472, 5485, 'A Agência S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178469.mp4', 'http://timg.bdta.pro/images/84ce88957c0c785570146656545775b0.jpg'),
(79473, 5485, 'A Agência S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178470.mp4', 'http://timg.bdta.pro/images/0b47a404c73950985e6fbca5854ebede.jpg'),
(79474, 5485, 'A Agência S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178471.mp4', 'http://timg.bdta.pro/images/72262f9c149def400e5f5ae1e8c2d716.jpg'),
(79475, 5485, 'A Agência S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178472.mp4', 'http://timg.bdta.pro/images/11021b69dc5b13605c17fa2111c35517.jpg'),
(79476, 5485, 'A Agência S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178473.mp4', 'http://timg.bdta.pro/images/59259a384c03aaf611f1cfcfc82778e3.jpg'),
(79477, 5485, 'A Agência S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178474.mp4', 'http://timg.bdta.pro/images/fd2826270f0b99ec4ddff04f98ad7aed.jpg'),
(79478, 5485, 'A Agência S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178475.mp4', 'http://timg.bdta.pro/images/5b1d063f0e7ff843ae3981f296bbc103.jpg'),
(79479, 5485, 'A Agência S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178476.mp4', 'http://timg.bdta.pro/images/076b75ec350f82c2ad947b970f800a85.jpg'),
(79480, 5485, 'A Agência S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178477.mp4', 'http://timg.bdta.pro/images/f2add3f3f3b520ecd9ab4ec973d6c5da.jpg'),
(79481, 5485, 'A Agência S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/178478.mp4', 'http://timg.bdta.pro/images/129a879cd9ecfeabe12db87298038c5f.jpg'),
(79482, 5485, 'A Agência S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/178479.mp4', 'http://timg.bdta.pro/images/4e8ad0a9d71ef6a179bb14710cde9ad3.jpg'),
(79483, 5485, 'A Agência S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/178480.mp4', 'http://timg.bdta.pro/images/d1920a7b08572d05f5e5cefb1b645964.jpg'),
(79484, 5485, 'A Agência S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/178481.mp4', 'http://timg.bdta.pro/images/2c8b96148732b99414afb98e7b2bff52.jpg'),
(79485, 5485, 'A Agência S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/178482.mp4', 'http://timg.bdta.pro/images/183d02aeb3a59846daf9a4330349aaca.jpg'),
(79486, 5485, 'A Agência S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/178483.mp4', 'http://timg.bdta.pro/images/97ed7bc3c9da874f5f98260cc2ceda12.jpg'),
(79487, 5485, 'A Agência S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/178484.mp4', 'http://timg.bdta.pro/images/a5c92de73d0d170c876f7ee3aacc760a.jpg'),
(79488, 5485, 'A Agência S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/178485.mp4', 'http://timg.bdta.pro/images/cc34767d012d1eab6bf92020559f1e08.jpg'),
(79489, 5485, 'A Agência S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/178486.mp4', 'http://timg.bdta.pro/images/0fc8097357e5b936bf6013e8b3075450.jpg'),
(79490, 5485, 'A Agência S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/178487.mp4', 'http://timg.bdta.pro/images/d40495e877bc20b738dbda60e0900651.jpg'),
(79491, 5485, 'A Agência S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/178488.mp4', 'http://timg.bdta.pro/images/1fdf9d0a3979da39e862fcf01d1fa70d.jpg'),
(79492, 5485, 'A Agência S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/178489.mp4', 'http://timg.bdta.pro/images/3902a3ba7e2e27ecf70004073a176712.jpg'),
(79493, 5485, 'A Agência S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/178490.mp4', 'http://timg.bdta.pro/images/4f53620c7fc53e05665ac698f9529d19.jpg'),
(79494, 5485, 'A Agência S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/178491.mp4', 'http://timg.bdta.pro/images/8bbf33698aa27547f6adf7ed12f64020.jpg'),
(79495, 5485, 'A Agência S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/178492.mp4', 'http://timg.bdta.pro/images/c77cd20ca2c10b8762b6ffb544eab5f8.jpg'),
(79496, 5485, 'A Agência S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/178493.mp4', 'http://timg.bdta.pro/images/f14778a478eeabae21bb0bba1d4f728a.jpg'),
(79497, 5485, 'A Agência S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/178494.mp4', 'http://timg.bdta.pro/images/1f18fdd8d0e623c092e3992a4299ceb6.jpg'),
(79498, 5485, 'A Agência S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/178495.mp4', 'http://timg.bdta.pro/images/24392372ebe47a289fc70a8ca7341df3.jpg'),
(79499, 5485, 'A Agência S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/178496.mp4', 'http://timg.bdta.pro/images/2b7421d09f09e79e886cf058702d4ca8.jpg'),
(79500, 5485, 'A Agência S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/178497.mp4', 'http://timg.bdta.pro/images/3fdb4937e62e117bedfa11a80796e6d2.jpg'),
(79501, 5485, 'A Agência S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/795198.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79502, 5485, 'A Agência S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/795199.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79503, 5485, 'A Agência S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/795200.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79504, 5485, 'A Agência S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/795201.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79505, 5485, 'A Agência S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/795202.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79506, 5485, 'A Agência S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/795203.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79507, 5485, 'A Agência S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/795204.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79508, 5485, 'A Agência S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/795205.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79509, 5485, 'A Agência S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/795206.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79510, 5485, 'A Agência S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/795207.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79511, 5485, 'A Agência S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/795208.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79512, 5485, 'A Agência S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/795209.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79513, 5485, 'A Agência S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/795210.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79514, 5485, 'A Agência S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/795211.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79515, 5485, 'A Agência S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/795212.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79516, 5485, 'A Agência S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/795213.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79517, 5485, 'A Agência S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/795214.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79518, 5485, 'A Agência S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/795215.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79519, 5485, 'A Agência S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/795216.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79520, 5485, 'A Agência S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/795217.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79521, 5485, 'A Agência S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/795218.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79522, 5485, 'A Agência S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/795219.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79523, 5485, 'A Agência S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/795220.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79524, 5485, 'A Agência S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/795221.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79525, 5485, 'A Agência S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/795222.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79526, 5485, 'A Agência S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/795223.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79527, 5485, 'A Agência S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/795224.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79528, 5485, 'A Agência S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/795225.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79529, 5485, 'A Agência S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/795226.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79530, 5485, 'A Agência S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/795227.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79531, 5485, 'A Agência S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/795228.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79532, 5485, 'A Agência S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/795229.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79533, 5485, 'A Agência S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/795230.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79534, 5485, 'A Agência S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/795231.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79535, 5485, 'A Agência S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/795232.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79536, 5485, 'A Agência S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/795233.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79537, 5485, 'A Agência S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/795234.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79538, 5485, 'A Agência S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/795235.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79539, 5485, 'A Agência S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/795236.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79540, 5485, 'A Agência S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/795237.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79541, 5485, 'A Agência S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/795238.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79542, 5485, 'A Agência S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/795239.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79543, 5485, 'A Agência S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/795240.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79544, 5485, 'A Agência S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/795241.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79545, 5485, 'A Agência S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/795242.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79546, 5485, 'A Agência S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/795243.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79547, 5485, 'A Agência S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/795244.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79548, 5485, 'A Agência S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/795245.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79549, 5485, 'A Agência S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/795246.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79550, 5485, 'A Agência S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/795247.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79551, 5485, 'A Agência S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/795248.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79552, 5485, 'A Agência S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/795249.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79553, 5485, 'A Agência S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/795250.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79554, 5485, 'A Agência S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/795251.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79555, 5485, 'A Agência S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/795252.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79556, 5485, 'A Agência S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/795253.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79557, 5485, 'A Agência S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/795254.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79558, 5485, 'A Agência S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/795255.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79559, 5485, 'A Agência S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/795256.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79560, 5485, 'A Agência S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/795257.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79561, 5485, 'A Agência S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/795258.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79562, 5485, 'A Agência S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/795259.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79563, 5485, 'A Agência S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/795260.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79564, 5485, 'A Agência S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/795261.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79565, 5485, 'A Agência S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/795262.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79566, 5485, 'A Agência S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/795263.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79567, 5485, 'A Agência S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/795264.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79568, 5485, 'A Agência S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/795265.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79569, 5485, 'A Agência S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/795266.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79570, 5485, 'A Agência S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/795267.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79571, 5485, 'A Agência S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/795268.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79572, 5485, 'A Agência S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/795269.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79573, 5485, 'A Agência S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/795270.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79574, 5485, 'A Agência S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/795271.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79575, 5485, 'A Agência S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/795272.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79576, 5485, 'A Agência S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/795273.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79577, 5485, 'A Agência S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/795274.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79578, 5485, 'A Agência S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/795275.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79579, 5485, 'A Agência S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/795276.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79580, 5485, 'A Agência S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/795277.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79581, 5485, 'A Agência S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/795278.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79582, 5485, 'A Agência S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/795279.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79583, 5485, 'A Agência S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/795280.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79584, 5485, 'A Agência S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/795281.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79585, 5485, 'A Agência S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/795282.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79586, 5485, 'A Agência S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/795283.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79587, 5485, 'A Agência S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/795284.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79588, 5485, 'A Agência S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/795285.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79589, 5485, 'A Agência S01 E119', 'http://sinalprivado.info:80/series/1533784/1533784/795286.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79590, 5485, 'A Agência S01 E120', 'http://sinalprivado.info:80/series/1533784/1533784/795287.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79591, 5485, 'A Agência S01 E121', 'http://sinalprivado.info:80/series/1533784/1533784/795288.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79592, 5485, 'A Agência S01 E122', 'http://sinalprivado.info:80/series/1533784/1533784/795289.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79593, 5485, 'A Agência S01 E123', 'http://sinalprivado.info:80/series/1533784/1533784/795290.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79594, 5485, 'A Agência S01 E124', 'http://sinalprivado.info:80/series/1533784/1533784/795291.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79595, 5485, 'A Agência S01 E125', 'http://sinalprivado.info:80/series/1533784/1533784/795292.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79596, 5485, 'A Agência S01 E126', 'http://sinalprivado.info:80/series/1533784/1533784/795293.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79597, 5485, 'A Agência S01 E127', 'http://sinalprivado.info:80/series/1533784/1533784/795294.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79598, 5485, 'A Agência S01 E128', 'http://sinalprivado.info:80/series/1533784/1533784/795295.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79599, 5485, 'A Agência S01 E129', 'http://sinalprivado.info:80/series/1533784/1533784/795296.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79600, 5485, 'A Agência S01 E130', 'http://sinalprivado.info:80/series/1533784/1533784/795297.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79601, 5485, 'A Agência S01 E131', 'http://sinalprivado.info:80/series/1533784/1533784/795298.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79602, 5485, 'A Agência S01 E132', 'http://sinalprivado.info:80/series/1533784/1533784/795299.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79603, 5485, 'A Agência S01 E133', 'http://sinalprivado.info:80/series/1533784/1533784/795300.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79604, 5485, 'A Agência S01 E134', 'http://sinalprivado.info:80/series/1533784/1533784/795301.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79605, 5485, 'A Agência S01 E135', 'http://sinalprivado.info:80/series/1533784/1533784/795302.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79606, 5485, 'A Agência S01 E136', 'http://sinalprivado.info:80/series/1533784/1533784/795303.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79607, 5485, 'A Agência S01 E137', 'http://sinalprivado.info:80/series/1533784/1533784/795304.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79608, 5485, 'A Agência S01 E138', 'http://sinalprivado.info:80/series/1533784/1533784/795305.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79609, 5485, 'A Agência S01 E139', 'http://sinalprivado.info:80/series/1533784/1533784/795310.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79610, 5485, 'A Agência S01 E140', 'http://sinalprivado.info:80/series/1533784/1533784/795311.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79611, 5485, 'A Agência S01 E141', 'http://sinalprivado.info:80/series/1533784/1533784/795312.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79612, 5485, 'A Agência S01 E142', 'http://sinalprivado.info:80/series/1533784/1533784/795313.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79613, 5485, 'A Agência S01 E143', 'http://sinalprivado.info:80/series/1533784/1533784/795314.mp4', 'http://gstaticontent.com/images/d55e09b7c50602ec46d36bb414b51bb0.jpg'),
(79614, 5486, 'A Mulher Invisível S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178455.mp4', 'http://gstaticontent.com/images/3e4e67edf0adb5daf9959f2ca09b60c8.jpg'),
(79615, 5486, 'A Mulher Invisível S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178456.mp4', 'http://gstaticontent.com/images/3e4e67edf0adb5daf9959f2ca09b60c8.jpg'),
(79616, 5486, 'A Mulher Invisível S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178457.mp4', 'http://gstaticontent.com/images/3e4e67edf0adb5daf9959f2ca09b60c8.jpg'),
(79617, 5486, 'A Mulher Invisível S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178458.mp4', 'http://gstaticontent.com/images/3e4e67edf0adb5daf9959f2ca09b60c8.jpg'),
(79618, 5486, 'A Mulher Invisível S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178459.mp4', 'http://gstaticontent.com/images/3e4e67edf0adb5daf9959f2ca09b60c8.jpg'),
(79619, 5487, 'A Mulher Invisível S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178460.mp4', 'http://gstaticontent.com/images/3e4e67edf0adb5daf9959f2ca09b60c8.jpg'),
(79620, 5487, 'A Mulher Invisível S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178461.mp4', 'http://gstaticontent.com/images/3e4e67edf0adb5daf9959f2ca09b60c8.jpg'),
(79621, 5487, 'A Mulher Invisível S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178462.mp4', 'http://gstaticontent.com/images/3e4e67edf0adb5daf9959f2ca09b60c8.jpg'),
(79622, 5487, 'A Mulher Invisível S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178463.mp4', 'http://gstaticontent.com/images/3e4e67edf0adb5daf9959f2ca09b60c8.jpg'),
(79623, 5487, 'A Mulher Invisível S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178464.mp4', 'http://gstaticontent.com/images/3e4e67edf0adb5daf9959f2ca09b60c8.jpg'),
(79624, 5487, 'A Mulher Invisível S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178465.mp4', 'http://gstaticontent.com/images/3e4e67edf0adb5daf9959f2ca09b60c8.jpg'),
(79625, 5487, 'A Mulher Invisível S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178466.mp4', 'http://gstaticontent.com/images/3e4e67edf0adb5daf9959f2ca09b60c8.jpg'),
(79626, 5487, 'A Mulher Invisível S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178467.mp4', 'http://gstaticontent.com/images/3e4e67edf0adb5daf9959f2ca09b60c8.jpg'),
(79627, 5488, 'Agente K.C S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178426.mp4', 'http://timg.bdta.pro/images/69673e888ad8d5c84727e914a038c439.jpg'),
(79628, 5488, 'Agente K.C S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178427.mp4', 'http://timg.bdta.pro/images/efd43b62b54efd70aa27f66505844ca7.jpg'),
(79629, 5488, 'Agente K.C S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178428.mp4', 'http://timg.bdta.pro/images/2d529ae17db42faae8812c4a166b0aa3.jpg'),
(79630, 5488, 'Agente K.C S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178429.mp4', 'http://timg.bdta.pro/images/3ee001f851435acba504900e0f21bf79.jpg'),
(79631, 5488, 'Agente K.C S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178430.mp4', 'http://timg.bdta.pro/images/806f8f9ea277de924845b3898f336f25.jpg'),
(79632, 5488, 'Agente K.C S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178431.mp4', 'http://timg.bdta.pro/images/83e2150594e837724b2eefcb9042abc0.jpg'),
(79633, 5488, 'Agente K.C S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178432.mp4', 'http://timg.bdta.pro/images/d3965bddafe42e29313e037248ac5ebb.jpg'),
(79634, 5488, 'Agente K.C S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178433.mp4', 'http://timg.bdta.pro/images/caa6fd0215a0976b0304c8bbf57ed62a.jpg'),
(79635, 5488, 'Agente K.C S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178434.mp4', 'http://timg.bdta.pro/images/ec85fa1c2a111e135badbb9f7478da54.jpg'),
(79636, 5488, 'Agente K.C S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178435.mp4', 'http://timg.bdta.pro/images/2cf8abb9b192e233151c04922aaf43d0.jpg'),
(79637, 5488, 'Agente K.C S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/178436.mp4', 'http://timg.bdta.pro/images/0bd420030f18f5dcacb269c7ae604279.jpg'),
(79638, 5488, 'Agente K.C S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/178437.mp4', 'http://timg.bdta.pro/images/9ceed94706630aa56e6cbb3519a38563.jpg'),
(79639, 5488, 'Agente K.C S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/178438.mp4', 'http://timg.bdta.pro/images/7b632e358049c667b3988c49df5b4403.jpg'),
(79640, 5488, 'Agente K.C S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/178439.mp4', 'http://timg.bdta.pro/images/8ae1915a0b8d4e47c1e671e49dc179ae.jpg'),
(79641, 5488, 'Agente K.C S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/178440.mp4', 'http://timg.bdta.pro/images/f0da00f6c7f0d321ed9ba2537ae18f07.jpg'),
(79642, 5488, 'Agente K.C S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/178441.mp4', 'http://timg.bdta.pro/images/c8f319ce03db2d2ae5eca76cdad4bff9.jpg'),
(79643, 5488, 'Agente K.C S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/178442.mp4', 'http://timg.bdta.pro/images/7f1f87824fd492b1e856d5c59f09c91e.jpg'),
(79644, 5488, 'Agente K.C S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/178443.mp4', 'http://timg.bdta.pro/images/fd475db32ca4485b230d5611e7ab4001.jpg'),
(79645, 5488, 'Agente K.C S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/178444.mp4', 'http://timg.bdta.pro/images/08c6d383c63602c4824603a5b58cad9c.jpg'),
(79646, 5488, 'Agente K.C S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/178445.mp4', 'http://timg.bdta.pro/images/21eeca51fd4469230c54ae8aaee5b223.jpg'),
(79647, 5488, 'Agente K.C S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/178446.mp4', 'http://timg.bdta.pro/images/3f6ecad8a379bba98cdc2a41800707f7.jpg'),
(79648, 5488, 'Agente K.C S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/178447.mp4', 'http://timg.bdta.pro/images/dcaa8bbf47da1f3b095520fd4d438571.jpg'),
(79649, 5488, 'Agente K.C S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/178448.mp4', 'http://timg.bdta.pro/images/c0c46ba1a2cb3eaa7320b3759dd8c682.jpg'),
(79650, 5488, 'Agente K.C S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/178449.mp4', 'http://timg.bdta.pro/images/5af43f0a9f4e0923d3b5ec01db1dd7da.jpg'),
(79651, 5488, 'Agente K.C S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/178450.mp4', 'http://timg.bdta.pro/images/f30a05d076d1ab2da54400e59115ee89.jpg'),
(79652, 5488, 'Agente K.C S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/178451.mp4', 'http://timg.bdta.pro/images/81b746319126f61eb2b602d2598747e2.jpg'),
(79653, 5488, 'Agente K.C S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/178452.mp4', 'http://timg.bdta.pro/images/a7ccf9a6c89ea7c67a6f1aff2438de54.jpg'),
(79654, 5488, 'Agente K.C S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/178453.mp4', 'http://gstaticontent.com/images/46f72cccd2973cff24a8b7ef89c0edbe.jpg'),
(79655, 5488, 'Agente K.C S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/178454.mp4', 'http://gstaticontent.com/images/46f72cccd2973cff24a8b7ef89c0edbe.jpg'),
(79656, 5489, 'As Seguidoras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178420.mp4', 'http://timg.bdta.pro/images/925c19361396965878f70a2bc58200fa.jpg'),
(79657, 5489, 'As Seguidoras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178421.mp4', 'http://timg.bdta.pro/images/94bfce3765dde1652255744a63cbf130.jpg'),
(79658, 5489, 'As Seguidoras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178422.mp4', 'http://timg.bdta.pro/images/32ae42bcfc7999bcdfabe194851c25c9.jpg'),
(79659, 5489, 'As Seguidoras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178423.mp4', 'http://timg.bdta.pro/images/6fdb0f0a0c575df4f3f6190f804cb06e.jpg'),
(79660, 5489, 'As Seguidoras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178424.mp4', 'http://timg.bdta.pro/images/2a8307a4616c185af39f8880bf7134ef.jpg'),
(79661, 5489, 'As Seguidoras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178425.mp4', 'http://timg.bdta.pro/images/08fb3d32a99ce17e6c53ec62af08060c.jpg'),
(79662, 5490, 'Cardinal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202943.mp4', 'http://timg.bdta.pro/images/e8660215d63dba1a0954726876cfd2dc.jpg'),
(79663, 5490, 'Cardinal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202944.mp4', 'http://timg.bdta.pro/images/4ffac7b5780a4449f4ebcf6ebba45c7a.jpg'),
(79664, 5490, 'Cardinal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202945.mp4', 'http://timg.bdta.pro/images/2dc36f54503e9fdb53bdce8d172c3bef.jpg'),
(79665, 5490, 'Cardinal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202946.mp4', 'http://timg.bdta.pro/images/bcb0c175a5c6bea830bcb70e78d31914.jpg'),
(79666, 5490, 'Cardinal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202947.mp4', 'http://timg.bdta.pro/images/eb946882dcc9a4b24db3f713ec89fadb.jpg'),
(79667, 5490, 'Cardinal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202948.mp4', 'http://timg.bdta.pro/images/8e758eb70dc0710fd98dc07e357b9eb1.jpg'),
(79668, 5491, 'Cardinal S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a7VMQRX33pUFGuwqklsZgiGMSIE.jpg'),
(79669, 5491, 'Cardinal S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dDDA8gjgrKN2NpuW3N55yl8lq6V.jpg'),
(79670, 5491, 'Cardinal S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCgFMNM3T0HVE7IUjjucvgjyyBJ.jpg'),
(79671, 5491, 'Cardinal S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eolVmI0Ycych5I6AzkrQ5RdLtCr.jpg'),
(79672, 5491, 'Cardinal S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lWcB7c39qNBQCUNuDQmpZsdUA4H.jpg'),
(79673, 5491, 'Cardinal S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qOwTN8BbLMNv6bophG3Il4rkqa9.jpg'),
(79674, 5492, 'Cardinal S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xsK09r0mCgT3ZWgydNNxYlJv6h4.jpg'),
(79675, 5492, 'Cardinal S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oVetL2Ro1D9PMzcdbTWNpfgbFQv.jpg'),
(79676, 5492, 'Cardinal S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6l2q6lZCte2Hg4z51NggTuJMxc1.jpg'),
(79677, 5492, 'Cardinal S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qutvDTrT5B6lsdpQmvP1ic9LzS7.jpg'),
(79678, 5492, 'Cardinal S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x1YmVkROJ27K7apnJOQrORmsUz1.jpg'),
(79679, 5492, 'Cardinal S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfZuU8B3D99xQJYJRHplo6PdVxX.jpg'),
(79680, 5493, 'Cardinal S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ohMdvLmxr56rq4wzOcY7u5Y2gTf.jpg'),
(79681, 5493, 'Cardinal S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uLy0JkD7Toasu1Jsb4cB0ALDTFr.jpg'),
(79682, 5493, 'Cardinal S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ZBmi489BvEDntQDhliUHXqwsP6.jpg'),
(79683, 5493, 'Cardinal S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cytq4JsxNwvQiBvhGMv7OqVmB9q.jpg'),
(79684, 5493, 'Cardinal S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/auNKBI3eVJU1sHafNZMGMhecZZg.jpg'),
(79685, 5493, 'Cardinal S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gK3iFT6ip1rqW4Plby81nygXVhH.jpg'),
(79686, 5494, 'Diários de Andy Warhol S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178414.mp4', 'http://gstaticontent.com/images/8520c291ddd1fda5020667ec9f9c2ef4.jpg'),
(79687, 5494, 'Diários de Andy Warhol S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178415.mp4', 'http://gstaticontent.com/images/8520c291ddd1fda5020667ec9f9c2ef4.jpg'),
(79688, 5494, 'Diários de Andy Warhol S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178416.mp4', 'http://gstaticontent.com/images/8520c291ddd1fda5020667ec9f9c2ef4.jpg'),
(79689, 5494, 'Diários de Andy Warhol S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178417.mp4', 'http://gstaticontent.com/images/8520c291ddd1fda5020667ec9f9c2ef4.jpg'),
(79690, 5494, 'Diários de Andy Warhol S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178418.mp4', 'http://gstaticontent.com/images/8520c291ddd1fda5020667ec9f9c2ef4.jpg'),
(79691, 5494, 'Diários de Andy Warhol S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178419.mp4', 'http://gstaticontent.com/images/8520c291ddd1fda5020667ec9f9c2ef4.jpg'),
(79692, 5495, 'Uma Família da Pesada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267467.mp4', 'http://timg.bdta.pro/images/62a2c1c1fbd4d4971400f7102b578351.jpg'),
(79693, 5495, 'Uma Família da Pesada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267468.mp4', 'http://timg.bdta.pro/images/0a5331ad053be0dfbfba931f8af72e66.jpg'),
(79694, 5495, 'Uma Família da Pesada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267469.mp4', 'http://timg.bdta.pro/images/d8f1d3dd2a6b4824934c8bd60514b391.jpg'),
(79695, 5495, 'Uma Família da Pesada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267470.mp4', 'http://timg.bdta.pro/images/404ea968155b295efd1805cca6e0c60b.jpg'),
(79696, 5495, 'Uma Família da Pesada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267471.mp4', 'http://timg.bdta.pro/images/ea8a92ca978b826d65ad653c3e345f82.jpg'),
(79697, 5495, 'Uma Família da Pesada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267472.mp4', 'http://timg.bdta.pro/images/0a4cc189c4e841af1dcb786c10dc1384.jpg'),
(79698, 5495, 'Uma Família da Pesada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267473.mp4', 'http://timg.bdta.pro/images/4bc0cbee43554d8bdc020667fe23bdd2.jpg'),
(79699, 5496, 'Uma Família da Pesada S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267474.mp4', 'http://timg.bdta.pro/images/83027397f3bfbfb0ceef1ccadabab977.jpg'),
(79700, 5496, 'Uma Família da Pesada S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267475.mp4', 'http://timg.bdta.pro/images/5730a51364629f46e023dc7988235145.jpg'),
(79701, 5496, 'Uma Família da Pesada S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267476.mp4', 'http://timg.bdta.pro/images/2789ad75d1c22febdfe5667b8e19f885.jpg'),
(79702, 5496, 'Uma Família da Pesada S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267477.mp4', 'http://timg.bdta.pro/images/d7efc30f15a68651298512c01684ee03.jpg'),
(79703, 5496, 'Uma Família da Pesada S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267478.mp4', 'http://timg.bdta.pro/images/4fa3788368464a593f426be0475f1fcd.jpg'),
(79704, 5496, 'Uma Família da Pesada S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267479.mp4', 'http://timg.bdta.pro/images/08e952421166dd6dc3ae6685cc42f078.jpg'),
(79705, 5496, 'Uma Família da Pesada S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267480.mp4', 'http://timg.bdta.pro/images/ed43b13875861f875325d2b451686c67.jpg'),
(79706, 5496, 'Uma Família da Pesada S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267481.mp4', 'http://timg.bdta.pro/images/a0c28b5c6f0da3f35d4671419b2bb83d.jpg'),
(79707, 5496, 'Uma Família da Pesada S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267482.mp4', 'http://timg.bdta.pro/images/12da073e25be7bc2b3b8d8a3cb697f64.jpg'),
(79708, 5496, 'Uma Família da Pesada S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267483.mp4', 'http://timg.bdta.pro/images/4947429e33ade6a76be4a7ed15ff4535.jpg'),
(79709, 5496, 'Uma Família da Pesada S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267484.mp4', 'http://timg.bdta.pro/images/21aeae285d46b591183877d4966b2af7.jpg'),
(79710, 5496, 'Uma Família da Pesada S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267485.mp4', 'http://timg.bdta.pro/images/bab9a3a586030c5f555a140c1bab124f.jpg'),
(79711, 5496, 'Uma Família da Pesada S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267486.mp4', 'http://timg.bdta.pro/images/3ea3d2ffe0fe95720852f383c3415323.jpg'),
(79712, 5496, 'Uma Família da Pesada S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267487.mp4', 'http://timg.bdta.pro/images/525012abb2da001d475c9ac8594d0014.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(79713, 5496, 'Uma Família da Pesada S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267488.mp4', 'http://timg.bdta.pro/images/7f347b9cf7dc6b29ce96b61fe5114a33.jpg'),
(79714, 5496, 'Uma Família da Pesada S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267489.mp4', 'http://timg.bdta.pro/images/39ea3f46c136bd9c1e7ab26e2646c864.jpg'),
(79715, 5496, 'Uma Família da Pesada S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267490.mp4', 'http://timg.bdta.pro/images/f74df1533cfbbbd2d75cc476c83fa951.jpg'),
(79716, 5496, 'Uma Família da Pesada S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267491.mp4', 'http://timg.bdta.pro/images/62d6a3b4d0d975cb62b428f3725f09ac.jpg'),
(79717, 5496, 'Uma Família da Pesada S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267492.mp4', 'http://timg.bdta.pro/images/74e6bb223b199894301d1ec1358f4d17.jpg'),
(79718, 5496, 'Uma Família da Pesada S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267493.mp4', 'http://timg.bdta.pro/images/43e8224a1b30cfde8e2b2585292d5b95.jpg'),
(79719, 5496, 'Uma Família da Pesada S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/267494.mp4', 'http://timg.bdta.pro/images/f5e40d3790788baa20cc4cd3dabc6d40.jpg'),
(79720, 5497, 'Uma Família da Pesada S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267495.mp4', 'http://timg.bdta.pro/images/175ae6f2a6f84b374462ce1f918df4d4.jpg'),
(79721, 5497, 'Uma Família da Pesada S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267496.mp4', 'http://timg.bdta.pro/images/d179f84d1ac9fc2f0575f41fc3de8c09.jpg'),
(79722, 5497, 'Uma Família da Pesada S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267497.mp4', 'http://timg.bdta.pro/images/d50590977263ca7c6f3617c76b0b8bf4.jpg'),
(79723, 5497, 'Uma Família da Pesada S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267498.mp4', 'http://timg.bdta.pro/images/06451f865726fe132774d0735b42f89e.jpg'),
(79724, 5497, 'Uma Família da Pesada S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267499.mp4', 'http://timg.bdta.pro/images/97ee6e46feca0faf9ebe158bd029812e.jpg'),
(79725, 5497, 'Uma Família da Pesada S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267500.mp4', 'http://timg.bdta.pro/images/6b3de58500a191ea17691b2a39455ef0.jpg'),
(79726, 5497, 'Uma Família da Pesada S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267501.mp4', 'http://timg.bdta.pro/images/c970c02db81bfc75d4a922341227eaf6.jpg'),
(79727, 5497, 'Uma Família da Pesada S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267502.mp4', 'http://timg.bdta.pro/images/ab0b02aaff801692e77166687507478d.jpg'),
(79728, 5497, 'Uma Família da Pesada S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267503.mp4', 'http://timg.bdta.pro/images/7d10e77d008f25f556e2b4d6a6095bab.jpg'),
(79729, 5497, 'Uma Família da Pesada S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267504.mp4', 'http://timg.bdta.pro/images/2be8a08d3c712050e2b6f136168f9353.jpg'),
(79730, 5497, 'Uma Família da Pesada S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267505.mp4', 'http://timg.bdta.pro/images/0b4bd8f12bf23cf2b847886a6a8946b2.jpg'),
(79731, 5497, 'Uma Família da Pesada S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267506.mp4', 'http://timg.bdta.pro/images/5a82fc419e4e9bcee3060161577d0fc2.jpg'),
(79732, 5497, 'Uma Família da Pesada S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267507.mp4', 'http://timg.bdta.pro/images/bbdbd26eb0104a1184b0220631baa845.jpg'),
(79733, 5497, 'Uma Família da Pesada S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267508.mp4', 'http://timg.bdta.pro/images/22077c041b1fb291ab7821cbcefbd2cd.jpg'),
(79734, 5497, 'Uma Família da Pesada S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267509.mp4', 'http://timg.bdta.pro/images/c6f9237125a4e247c3b2a3dce469235e.jpg'),
(79735, 5497, 'Uma Família da Pesada S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267510.mp4', 'http://timg.bdta.pro/images/8c3c8f03f805f4914cbfc3a7eaf0340d.jpg'),
(79736, 5497, 'Uma Família da Pesada S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267511.mp4', 'http://timg.bdta.pro/images/0c76f290687941a42d816b29f7e17553.jpg'),
(79737, 5497, 'Uma Família da Pesada S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267512.mp4', 'http://timg.bdta.pro/images/536654cad41f85a6ad492385fba6fb05.jpg'),
(79738, 5497, 'Uma Família da Pesada S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267513.mp4', 'http://timg.bdta.pro/images/ce6b5893db54a1e7b17f62bf4737a1d6.jpg'),
(79739, 5497, 'Uma Família da Pesada S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267514.mp4', 'http://timg.bdta.pro/images/2916301873cfd737f29436d22c7f6d40.jpg'),
(79740, 5497, 'Uma Família da Pesada S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/267515.mp4', 'http://timg.bdta.pro/images/e794c889035a5513d46c8a1bda314b09.jpg'),
(79741, 5497, 'Uma Família da Pesada S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/267516.mp4', 'http://timg.bdta.pro/images/a556bdc24ad5294568fb83a309810719.jpg'),
(79742, 5498, 'Uma Família da Pesada S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267517.mp4', 'http://timg.bdta.pro/images/436f216e897ac25993d27fe50586737f.jpg'),
(79743, 5498, 'Uma Família da Pesada S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267518.mp4', 'http://timg.bdta.pro/images/0e953eb9b6dcfe119d8a9d83a0c22668.jpg'),
(79744, 5498, 'Uma Família da Pesada S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267519.mp4', 'http://timg.bdta.pro/images/c1c5801f688d9079a45695922fc064e4.jpg'),
(79745, 5498, 'Uma Família da Pesada S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267520.mp4', 'http://timg.bdta.pro/images/bb3c016ee889e7a9110d94e0a3288060.jpg'),
(79746, 5498, 'Uma Família da Pesada S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267521.mp4', 'http://timg.bdta.pro/images/53600160596da2fb3fedce810a38e403.jpg'),
(79747, 5498, 'Uma Família da Pesada S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267522.mp4', 'http://timg.bdta.pro/images/e305d43780083f2576d79d51958f115b.jpg'),
(79748, 5498, 'Uma Família da Pesada S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267523.mp4', 'http://timg.bdta.pro/images/aca9d07a00067256ea066810ee8dcd28.jpg'),
(79749, 5498, 'Uma Família da Pesada S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267524.mp4', 'http://timg.bdta.pro/images/50fbff84de17537872a9d39f4e534470.jpg'),
(79750, 5498, 'Uma Família da Pesada S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267525.mp4', 'http://timg.bdta.pro/images/345948dc4260fec0249fe73b30c9c0dc.jpg'),
(79751, 5498, 'Uma Família da Pesada S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267526.mp4', 'http://timg.bdta.pro/images/83afe64925fa434ed3b65bf96c368f75.jpg'),
(79752, 5498, 'Uma Família da Pesada S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267527.mp4', 'http://timg.bdta.pro/images/dc888a69d13dc2981d819355c1cf18e0.jpg'),
(79753, 5498, 'Uma Família da Pesada S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267528.mp4', 'http://timg.bdta.pro/images/76be6c8e5b17dfe6bcd5148ea30142e0.jpg'),
(79754, 5498, 'Uma Família da Pesada S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267529.mp4', 'http://timg.bdta.pro/images/5b0f7310ebfd9dc177abbb097633e830.jpg'),
(79755, 5498, 'Uma Família da Pesada S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267530.mp4', 'http://timg.bdta.pro/images/5beca13761780ecee14272d7b596eb70.jpg'),
(79756, 5498, 'Uma Família da Pesada S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267531.mp4', 'http://timg.bdta.pro/images/e00c046e690854eef5a8bf0b36e19e43.jpg'),
(79757, 5499, 'Uma Família da Pesada S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267532.mp4', 'http://timg.bdta.pro/images/d828c8ef223beed3f42fb0c1cfce6383.jpg'),
(79758, 5499, 'Uma Família da Pesada S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267533.mp4', 'http://timg.bdta.pro/images/8de444800a3b61c3727d5fd2be2c9642.jpg'),
(79759, 5499, 'Uma Família da Pesada S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267534.mp4', 'http://timg.bdta.pro/images/337d20db44e790b177cfbc59b9a51869.jpg'),
(79760, 5499, 'Uma Família da Pesada S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267535.mp4', 'http://timg.bdta.pro/images/320a7fc5668f702834f63edf93452c02.jpg'),
(79761, 5499, 'Uma Família da Pesada S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267536.mp4', 'http://timg.bdta.pro/images/b456d06f36c883efc9e874934d89ed2c.jpg'),
(79762, 5499, 'Uma Família da Pesada S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267537.mp4', 'http://timg.bdta.pro/images/cbc656e954441a468ba89a66c0dce2b3.jpg'),
(79763, 5499, 'Uma Família da Pesada S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267538.mp4', 'http://timg.bdta.pro/images/d09dbc064b2bdc8b0bcabea3ef2eaa1c.jpg'),
(79764, 5499, 'Uma Família da Pesada S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267539.mp4', 'http://timg.bdta.pro/images/a76835bc003cbdc94fe9b10ee1dd002b.jpg'),
(79765, 5499, 'Uma Família da Pesada S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267540.mp4', 'http://timg.bdta.pro/images/d0ae8fe810e33026335ddcdbc99b51fc.jpg'),
(79766, 5499, 'Uma Família da Pesada S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267541.mp4', 'http://timg.bdta.pro/images/5a567d3876a9496c3c5e1517d5ca7f84.jpg'),
(79767, 5499, 'Uma Família da Pesada S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267542.mp4', 'http://timg.bdta.pro/images/13c599dd85b7b3a7f8e37e456c0f0fcf.jpg'),
(79768, 5499, 'Uma Família da Pesada S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267543.mp4', 'http://timg.bdta.pro/images/fc918b9aa5571d394aa637daa893beea.jpg'),
(79769, 5499, 'Uma Família da Pesada S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267544.mp4', 'http://timg.bdta.pro/images/987d97e272425a7a28abf5ebc3f0fb48.jpg'),
(79770, 5499, 'Uma Família da Pesada S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267545.mp4', 'http://timg.bdta.pro/images/dff99c82f985860930940d045f8188c0.jpg'),
(79771, 5499, 'Uma Família da Pesada S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267546.mp4', 'http://timg.bdta.pro/images/80f5284420ee8c3e80201475720b4721.jpg'),
(79772, 5499, 'Uma Família da Pesada S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267547.mp4', 'http://timg.bdta.pro/images/3555af50f662848efc33c30cb3e0c37c.jpg'),
(79773, 5499, 'Uma Família da Pesada S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267548.mp4', 'http://timg.bdta.pro/images/01d9de157a5dac1806e1996e8501b159.jpg'),
(79774, 5499, 'Uma Família da Pesada S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267549.mp4', 'http://timg.bdta.pro/images/03db56cea6b648cd5e4db41b982cb139.jpg'),
(79775, 5500, 'Uma Família da Pesada S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267550.mp4', 'http://timg.bdta.pro/images/88259bddd3e36386d1fd7a7868c4184d.jpg'),
(79776, 5500, 'Uma Família da Pesada S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267551.mp4', 'http://timg.bdta.pro/images/fa5bb1bb4eda8ebf4d852897e7d7138f.jpg'),
(79777, 5500, 'Uma Família da Pesada S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267552.mp4', 'http://timg.bdta.pro/images/fabe8dd3607e1d64d772b1f0fdc5768a.jpg'),
(79778, 5500, 'Uma Família da Pesada S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267553.mp4', 'http://timg.bdta.pro/images/bf3b35c619bebf7783ad62a9792cc865.jpg'),
(79779, 5500, 'Uma Família da Pesada S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267554.mp4', 'http://timg.bdta.pro/images/fa7857a3dba83918b96a983c54668ee3.jpg'),
(79780, 5500, 'Uma Família da Pesada S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267555.mp4', 'http://timg.bdta.pro/images/191bd172248511976fc5b192f95127cc.jpg'),
(79781, 5500, 'Uma Família da Pesada S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267556.mp4', 'http://timg.bdta.pro/images/6af36dcd1f8dfebcf052aea355f5aec7.jpg'),
(79782, 5500, 'Uma Família da Pesada S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267557.mp4', 'http://timg.bdta.pro/images/0f695d43f7744655567ba720efd48777.jpg'),
(79783, 5500, 'Uma Família da Pesada S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267558.mp4', 'http://timg.bdta.pro/images/6f81d14b819aca121e8b8fa9d76dbf4c.jpg'),
(79784, 5500, 'Uma Família da Pesada S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267559.mp4', 'http://timg.bdta.pro/images/e741fa5b0b92c1108264463bd3f6a788.jpg'),
(79785, 5500, 'Uma Família da Pesada S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267560.mp4', 'http://timg.bdta.pro/images/b54c064009170f06e545dd9737066cf9.jpg'),
(79786, 5500, 'Uma Família da Pesada S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267561.mp4', 'http://timg.bdta.pro/images/8d9c44f55449995e4c46bb5e710b70ed.jpg'),
(79787, 5500, 'Uma Família da Pesada S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267562.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(79788, 5500, 'Uma Família da Pesada S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267563.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(79789, 5501, 'Uma Família da Pesada S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267564.mp4', 'http://timg.bdta.pro/images/8f98b376f4bab18d4612993b5d75ee94.jpg'),
(79790, 5501, 'Uma Família da Pesada S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267565.mp4', 'http://timg.bdta.pro/images/9852263b553ad25971c74abea0cc5b0d.jpg'),
(79791, 5501, 'Uma Família da Pesada S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267566.mp4', 'http://timg.bdta.pro/images/619b408413a9a51cf5c5a9e7642dd2de.jpg'),
(79792, 5501, 'Uma Família da Pesada S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267567.mp4', 'http://timg.bdta.pro/images/a84cd6cc543ffa5c349db523bd0dac64.jpg'),
(79793, 5501, 'Uma Família da Pesada S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267568.mp4', 'http://timg.bdta.pro/images/ce9ea35d40b38dd9a6c70cc614d71090.jpg'),
(79794, 5501, 'Uma Família da Pesada S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267569.mp4', 'http://timg.bdta.pro/images/96f1945f216f93c20f70fd8b2ef69d54.jpg'),
(79795, 5501, 'Uma Família da Pesada S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267570.mp4', 'http://timg.bdta.pro/images/c6a8ef210e2c2353a900d858ef056a68.jpg'),
(79796, 5501, 'Uma Família da Pesada S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267571.mp4', 'http://timg.bdta.pro/images/7e4147c4cf66b817fd8fbfcc5ef0ba90.jpg'),
(79797, 5501, 'Uma Família da Pesada S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267572.mp4', 'http://timg.bdta.pro/images/3252c33903cfe37b9dca9451e83055cd.jpg'),
(79798, 5501, 'Uma Família da Pesada S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267573.mp4', 'http://timg.bdta.pro/images/90808f7060ea8926b8195346febaae14.jpg'),
(79799, 5501, 'Uma Família da Pesada S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267574.mp4', 'http://timg.bdta.pro/images/a39823f37a04c66432ebc8a182bd2ac4.jpg'),
(79800, 5501, 'Uma Família da Pesada S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267575.mp4', 'http://timg.bdta.pro/images/3732c22ed61f76ec85f1f5b6ac28b26b.jpg'),
(79801, 5501, 'Uma Família da Pesada S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267576.mp4', 'http://timg.bdta.pro/images/ed5fff3d1846dd4699e88c321ac61d75.jpg'),
(79802, 5501, 'Uma Família da Pesada S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267577.mp4', 'http://timg.bdta.pro/images/2fdd21fdfa5fccdf74236b79fefd58c5.jpg'),
(79803, 5501, 'Uma Família da Pesada S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267578.mp4', 'http://timg.bdta.pro/images/1b5c1688c1466966f2e4b9633e1c09f3.jpg'),
(79804, 5501, 'Uma Família da Pesada S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267579.mp4', 'http://timg.bdta.pro/images/98d2e55d996ab4445075a1b7f85d566a.jpg'),
(79805, 5502, 'Uma Família da Pesada S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267580.mp4', 'http://timg.bdta.pro/images/6c5c0105a9089f50bccd745f4793b96f.jpg'),
(79806, 5502, 'Uma Família da Pesada S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267581.mp4', 'http://timg.bdta.pro/images/08766b36e0149a2f53cfbf16c19c9a4e.jpg'),
(79807, 5502, 'Uma Família da Pesada S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267582.mp4', 'http://timg.bdta.pro/images/75466fce8f97a95633d02e651d2003f7.jpg'),
(79808, 5502, 'Uma Família da Pesada S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267583.mp4', 'http://timg.bdta.pro/images/32e904c71cbc3affe6613e59906dc3aa.jpg'),
(79809, 5502, 'Uma Família da Pesada S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267584.mp4', 'http://timg.bdta.pro/images/6371ad1a88278833dfc82d6101f190fc.jpg'),
(79810, 5502, 'Uma Família da Pesada S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267585.mp4', 'http://timg.bdta.pro/images/abee6fce64fecbbf8e8d51859cc40605.jpg'),
(79811, 5502, 'Uma Família da Pesada S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267586.mp4', 'http://timg.bdta.pro/images/a9753c1216574aff8431d88f85043fc0.jpg'),
(79812, 5502, 'Uma Família da Pesada S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267587.mp4', 'http://timg.bdta.pro/images/c64d5a80d6d4e5e94734a376fe918f60.jpg'),
(79813, 5502, 'Uma Família da Pesada S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267588.mp4', 'http://timg.bdta.pro/images/0c7c140ac11844fdf7ede1a21deb4a95.jpg'),
(79814, 5502, 'Uma Família da Pesada S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267589.mp4', 'http://timg.bdta.pro/images/120e60799ec04cb1cf444a46f39fd4fe.jpg'),
(79815, 5502, 'Uma Família da Pesada S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267590.mp4', 'http://timg.bdta.pro/images/4ff1da2d8d915b7933857c8914566db1.jpg'),
(79816, 5502, 'Uma Família da Pesada S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267591.mp4', 'http://timg.bdta.pro/images/8a66ae3950ce74f3e38fa2ee955a2377.jpg'),
(79817, 5502, 'Uma Família da Pesada S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267592.mp4', 'http://timg.bdta.pro/images/4b7c665f38311e2562ff52e7b18a81c9.jpg'),
(79818, 5502, 'Uma Família da Pesada S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267593.mp4', 'http://timg.bdta.pro/images/c1290b495db322a52e936012f5e709d8.jpg'),
(79819, 5502, 'Uma Família da Pesada S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267594.mp4', 'http://timg.bdta.pro/images/bac43bf542f9c1755b3b3ad130c39489.jpg'),
(79820, 5502, 'Uma Família da Pesada S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267595.mp4', 'http://timg.bdta.pro/images/b5df93cc8fd290f8b31fab97e979aeff.jpg'),
(79821, 5502, 'Uma Família da Pesada S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267596.mp4', 'http://timg.bdta.pro/images/18f8b93acc621aa54b194666802bcafd.jpg'),
(79822, 5502, 'Uma Família da Pesada S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267597.mp4', 'http://timg.bdta.pro/images/25436b01eb33e4e0db8b46001a156c61.jpg'),
(79823, 5502, 'Uma Família da Pesada S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267598.mp4', 'http://timg.bdta.pro/images/491ea7ff183c89a389e876cb3d51bbe5.jpg'),
(79824, 5502, 'Uma Família da Pesada S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267599.mp4', 'http://timg.bdta.pro/images/0d8fb21caf7d0259a08db04cd69e4b80.jpg'),
(79825, 5502, 'Uma Família da Pesada S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/267600.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(79826, 5503, 'Uma Família da Pesada S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267601.mp4', 'http://timg.bdta.pro/images/d9bde43006ffba3f2e749c66a0d41e9e.jpg'),
(79827, 5503, 'Uma Família da Pesada S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267602.mp4', 'http://timg.bdta.pro/images/c9bd716f007b4bddf2379df0f6eb7d04.jpg'),
(79828, 5503, 'Uma Família da Pesada S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267603.mp4', 'http://timg.bdta.pro/images/4f7f1dd7e47305c3c5e80e833b439874.jpg'),
(79829, 5503, 'Uma Família da Pesada S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267604.mp4', 'http://timg.bdta.pro/images/df322960f358f8fa38fa189c58c927b1.jpg'),
(79830, 5503, 'Uma Família da Pesada S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267605.mp4', 'http://timg.bdta.pro/images/ac79064775fa33e1006338da0c9c2bc9.jpg'),
(79831, 5503, 'Uma Família da Pesada S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267606.mp4', 'http://timg.bdta.pro/images/663d56e0bd1fa83e7e32457e4204c6f0.jpg'),
(79832, 5503, 'Uma Família da Pesada S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267607.mp4', 'http://timg.bdta.pro/images/ae089dca41127c7c3a703af5f51fc07a.jpg'),
(79833, 5503, 'Uma Família da Pesada S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267608.mp4', 'http://timg.bdta.pro/images/6bd8ca7f80430c0d89fc6283cfce4766.jpg'),
(79834, 5503, 'Uma Família da Pesada S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267609.mp4', 'http://timg.bdta.pro/images/aa2da537ff8bdf180cd0851562bf6091.jpg'),
(79835, 5503, 'Uma Família da Pesada S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267610.mp4', 'http://timg.bdta.pro/images/6314a891e84f04a65148645e789b158b.jpg'),
(79836, 5503, 'Uma Família da Pesada S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267611.mp4', 'http://timg.bdta.pro/images/92a87cd69c7cc25804e7c285e6414fbe.jpg'),
(79837, 5503, 'Uma Família da Pesada S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267612.mp4', 'http://timg.bdta.pro/images/e334d95d9f0f1bb4a9b2e7f437f34275.jpg'),
(79838, 5503, 'Uma Família da Pesada S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267613.mp4', 'http://timg.bdta.pro/images/25aa3b8bb13c6a4ff1f3815488d15971.jpg'),
(79839, 5503, 'Uma Família da Pesada S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267614.mp4', 'http://timg.bdta.pro/images/333f6fe15251cdbe87f2242c5b905f8f.jpg'),
(79840, 5503, 'Uma Família da Pesada S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267615.mp4', 'http://timg.bdta.pro/images/5ab44d7a84a2f0f890b2816c94a31805.jpg'),
(79841, 5503, 'Uma Família da Pesada S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267616.mp4', 'http://timg.bdta.pro/images/06ccd73ca932fb6c5efe8f6a3ef0a101.jpg'),
(79842, 5503, 'Uma Família da Pesada S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267617.mp4', 'http://timg.bdta.pro/images/99be7636228297e713997ee1228ba25b.jpg'),
(79843, 5503, 'Uma Família da Pesada S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267618.mp4', 'http://timg.bdta.pro/images/863fd468b788aef90b95d3a022f27ec3.jpg'),
(79844, 5504, 'Uma Família da Pesada S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267619.mp4', 'http://timg.bdta.pro/images/01d67f17a4f08b8ba26ae6853b9cdadf.jpg'),
(79845, 5504, 'Uma Família da Pesada S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267620.mp4', 'http://timg.bdta.pro/images/78fd2a7cc68a9db745ca2e1fdf88416f.jpg'),
(79846, 5504, 'Uma Família da Pesada S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267621.mp4', 'http://timg.bdta.pro/images/faec16a8b5f441cfa34a5bccd1f0d5be.jpg'),
(79847, 5504, 'Uma Família da Pesada S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267622.mp4', 'http://timg.bdta.pro/images/cf03263de5bc1bf0e375192216e8202b.jpg'),
(79848, 5504, 'Uma Família da Pesada S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267623.mp4', 'http://timg.bdta.pro/images/070008bf8aca56496aa3f7b539582f2e.jpg'),
(79849, 5504, 'Uma Família da Pesada S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267624.mp4', 'http://timg.bdta.pro/images/bee6e05eb2e480e3e4418ed31f9430cf.jpg'),
(79850, 5504, 'Uma Família da Pesada S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267625.mp4', 'http://timg.bdta.pro/images/78c0b8ac17a733864b337ec482f17b25.jpg'),
(79851, 5504, 'Uma Família da Pesada S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267626.mp4', 'http://timg.bdta.pro/images/5b5acbb56a37cbf3cd2f01d0314202d6.jpg'),
(79852, 5504, 'Uma Família da Pesada S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267627.mp4', 'http://timg.bdta.pro/images/072f046b187a10e090aab192ef4e266b.jpg'),
(79853, 5504, 'Uma Família da Pesada S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267628.mp4', 'http://timg.bdta.pro/images/34ffb8de57319b9bdf56ba7b49a3f123.jpg'),
(79854, 5504, 'Uma Família da Pesada S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267629.mp4', 'http://timg.bdta.pro/images/1914b41cb66b259aa221548d95d4f351.jpg'),
(79855, 5504, 'Uma Família da Pesada S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267630.mp4', 'http://timg.bdta.pro/images/93356272438ea8ed99128df42ffb7ec8.jpg'),
(79856, 5504, 'Uma Família da Pesada S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267631.mp4', 'http://timg.bdta.pro/images/65c48bc6b2b8ff25e69a8dfc9b4630f6.jpg'),
(79857, 5504, 'Uma Família da Pesada S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267632.mp4', 'http://timg.bdta.pro/images/3fbf113db1db8a488cb882bcea613e4a.jpg'),
(79858, 5504, 'Uma Família da Pesada S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267633.mp4', 'http://timg.bdta.pro/images/bc5284b194e01da20a98d6db5209c16b.jpg'),
(79859, 5504, 'Uma Família da Pesada S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267634.mp4', 'http://timg.bdta.pro/images/70c96b6b1c6640356a339a3ad3b9b19a.jpg'),
(79860, 5504, 'Uma Família da Pesada S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267635.mp4', 'http://timg.bdta.pro/images/9d186d0392a09bfada0858f8777326bb.jpg'),
(79861, 5504, 'Uma Família da Pesada S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267636.mp4', 'http://timg.bdta.pro/images/7ad1d1607c66419b033e3978bc2b3b00.jpg'),
(79862, 5504, 'Uma Família da Pesada S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267637.mp4', 'http://timg.bdta.pro/images/8512a971f56c49ec9634491a5713bfcd.jpg'),
(79863, 5504, 'Uma Família da Pesada S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267638.mp4', 'http://timg.bdta.pro/images/623bae48028afee6d33e4458ed6a171e.jpg'),
(79864, 5504, 'Uma Família da Pesada S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/267639.mp4', 'http://timg.bdta.pro/images/52f4cce0a326e8bccbc7b7cf0868cdf4.jpg'),
(79865, 5504, 'Uma Família da Pesada S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/267640.mp4', 'http://timg.bdta.pro/images/c1304e0dff7025b1e47808efff629db3.jpg'),
(79866, 5504, 'Uma Família da Pesada S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/267641.mp4', 'http://timg.bdta.pro/images/44dcef38e3ccd80a32c0d8e000c2340b.jpg'),
(79867, 5505, 'Uma Família da Pesada S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267642.mp4', 'http://timg.bdta.pro/images/8e45496530ba5b841c247e8da4138a22.jpg'),
(79868, 5505, 'Uma Família da Pesada S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267643.mp4', 'http://timg.bdta.pro/images/9d63b20a4cc4f166539e3831c594c58a.jpg'),
(79869, 5505, 'Uma Família da Pesada S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267644.mp4', 'http://timg.bdta.pro/images/b9e8c10c082089c60e71ea68e6765030.jpg'),
(79870, 5505, 'Uma Família da Pesada S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267645.mp4', 'http://timg.bdta.pro/images/c5b019feebe4c28700e49fee3ca4a693.jpg'),
(79871, 5505, 'Uma Família da Pesada S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267646.mp4', 'http://timg.bdta.pro/images/924a2be7e7d9367517380a3bba559d8a.jpg'),
(79872, 5505, 'Uma Família da Pesada S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267647.mp4', 'http://timg.bdta.pro/images/250b9eab2a464e42d5aa1f30eac8b387.jpg'),
(79873, 5505, 'Uma Família da Pesada S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267648.mp4', 'http://timg.bdta.pro/images/5a9764640e7ebd932014024f0a133aab.jpg'),
(79874, 5505, 'Uma Família da Pesada S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267649.mp4', 'http://timg.bdta.pro/images/f6968ab26ddc14e7748999588fbb3f42.jpg'),
(79875, 5505, 'Uma Família da Pesada S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267650.mp4', 'http://timg.bdta.pro/images/2664c7e27b8c166d1f9aa0f0d89de75a.jpg'),
(79876, 5505, 'Uma Família da Pesada S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267651.mp4', 'http://timg.bdta.pro/images/ea8ac8ff0ed26f3777c4ccf4a10f8516.jpg'),
(79877, 5505, 'Uma Família da Pesada S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267652.mp4', 'http://timg.bdta.pro/images/bfbb4296176eebbcde3cd10791f4c696.jpg'),
(79878, 5505, 'Uma Família da Pesada S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267653.mp4', 'http://timg.bdta.pro/images/b1c5d201023ce9fb2f52d1eb56ab609a.jpg'),
(79879, 5505, 'Uma Família da Pesada S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267654.mp4', 'http://timg.bdta.pro/images/5213cae35d9515774ef996eaa23dfc60.jpg'),
(79880, 5505, 'Uma Família da Pesada S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267655.mp4', 'http://timg.bdta.pro/images/75cd436f66fe9a78549bae803a7c971c.jpg'),
(79881, 5505, 'Uma Família da Pesada S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267656.mp4', 'http://timg.bdta.pro/images/23b5b598f16e09b355a8fafb6e29ad35.jpg'),
(79882, 5505, 'Uma Família da Pesada S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267657.mp4', 'http://timg.bdta.pro/images/bd25bde04a1d34a1999000177810455b.jpg'),
(79883, 5505, 'Uma Família da Pesada S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267658.mp4', 'http://timg.bdta.pro/images/ca282410a2f3162ebc94e38a00e7d15e.jpg'),
(79884, 5505, 'Uma Família da Pesada S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267659.mp4', 'http://timg.bdta.pro/images/21e3f1902e9bc38eb2ea738afc6b40d3.jpg'),
(79885, 5505, 'Uma Família da Pesada S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267660.mp4', 'http://timg.bdta.pro/images/b393baa1c18480d684ede9090dee7747.jpg'),
(79886, 5505, 'Uma Família da Pesada S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267661.mp4', 'http://timg.bdta.pro/images/1e309da47805396343ef0b251251c1cd.jpg'),
(79887, 5505, 'Uma Família da Pesada S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/267662.mp4', 'http://timg.bdta.pro/images/1380a88854f05e22293940016df67643.jpg'),
(79888, 5505, 'Uma Família da Pesada S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/267663.mp4', 'http://timg.bdta.pro/images/1be91bf4773648ae5f1c7de8068857cf.jpg'),
(79889, 5506, 'Uma Família da Pesada S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267664.mp4', 'http://timg.bdta.pro/images/1cbf77319f50395bc2a1bdb871bcc517.jpg'),
(79890, 5506, 'Uma Família da Pesada S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267665.mp4', 'http://timg.bdta.pro/images/479a9a23acd2674827517f94d86a8638.jpg'),
(79891, 5506, 'Uma Família da Pesada S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267666.mp4', 'http://timg.bdta.pro/images/91275166dfcf259dff1e217d80fa7175.jpg'),
(79892, 5506, 'Uma Família da Pesada S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267667.mp4', 'http://timg.bdta.pro/images/ed9972c06cd048d02f24ccac6e6fac24.jpg'),
(79893, 5506, 'Uma Família da Pesada S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267668.mp4', 'http://timg.bdta.pro/images/d15fac06ab6597688e668277b58e4762.jpg'),
(79894, 5506, 'Uma Família da Pesada S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267669.mp4', 'http://timg.bdta.pro/images/8e134ad0686ee34c6e5ea0fd87b213c0.jpg'),
(79895, 5506, 'Uma Família da Pesada S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267670.mp4', 'http://timg.bdta.pro/images/ddc56d6a3e9630f63b2cb6197a15871f.jpg'),
(79896, 5506, 'Uma Família da Pesada S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267671.mp4', 'http://timg.bdta.pro/images/0340197c581dc54ff11246acf6c5aaaf.jpg'),
(79897, 5506, 'Uma Família da Pesada S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267672.mp4', 'http://timg.bdta.pro/images/1dc22802e5c6c94e8d778d9a746b9a11.jpg'),
(79898, 5506, 'Uma Família da Pesada S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267673.mp4', 'http://timg.bdta.pro/images/c83ef452b8507fb3ba942ac54f38e534.jpg'),
(79899, 5506, 'Uma Família da Pesada S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267674.mp4', 'http://timg.bdta.pro/images/a1836cdd6ea1a98a5676ee164783b67c.jpg'),
(79900, 5506, 'Uma Família da Pesada S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267675.mp4', 'http://timg.bdta.pro/images/f2a16183c4bcba2cae89cbb894ae74ae.jpg'),
(79901, 5506, 'Uma Família da Pesada S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267676.mp4', 'http://timg.bdta.pro/images/1929a0d31861d0afa9b04675f19b321d.jpg'),
(79902, 5506, 'Uma Família da Pesada S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267677.mp4', 'http://timg.bdta.pro/images/18a3b91a20da114d3d747a017ae037b0.jpg'),
(79903, 5506, 'Uma Família da Pesada S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267678.mp4', 'http://timg.bdta.pro/images/e556541020d0b04fb98e4bc6775e5699.jpg'),
(79904, 5506, 'Uma Família da Pesada S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267679.mp4', 'http://timg.bdta.pro/images/5c43d8e6eae4d6c8caa37a867aaf97d8.jpg'),
(79905, 5506, 'Uma Família da Pesada S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267680.mp4', 'http://timg.bdta.pro/images/25591c58daeaa6221e810dfa443220d0.jpg'),
(79906, 5506, 'Uma Família da Pesada S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267681.mp4', 'http://timg.bdta.pro/images/8f24ae92f7089658800fc91c7b45c351.jpg'),
(79907, 5506, 'Uma Família da Pesada S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267682.mp4', 'http://timg.bdta.pro/images/f18118ea32ea89d4a55ce76aec67b940.jpg'),
(79908, 5506, 'Uma Família da Pesada S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267683.mp4', 'http://timg.bdta.pro/images/f17a8d42e059130220659a71f5dc8650.jpg'),
(79909, 5506, 'Uma Família da Pesada S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/267684.mp4', 'http://timg.bdta.pro/images/5581cff59c29e16b7e5924656ce0c657.jpg'),
(79910, 5507, 'Uma Família da Pesada S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267685.mp4', 'http://timg.bdta.pro/images/7337f96d09549fea29f75a2f46429bce.jpg'),
(79911, 5507, 'Uma Família da Pesada S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267686.mp4', 'http://timg.bdta.pro/images/a713a7ba9d41a80cf533fa7ae8c58bc1.jpg'),
(79912, 5507, 'Uma Família da Pesada S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267687.mp4', 'http://timg.bdta.pro/images/a628cca72d032a8ee731f69ae4faae48.jpg'),
(79913, 5507, 'Uma Família da Pesada S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267688.mp4', 'http://timg.bdta.pro/images/7d6078fc21872854d5f689501a251f64.jpg'),
(79914, 5507, 'Uma Família da Pesada S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267689.mp4', 'http://timg.bdta.pro/images/f42d3ae62df69b08598a326af9a2874c.jpg'),
(79915, 5507, 'Uma Família da Pesada S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267690.mp4', 'http://timg.bdta.pro/images/542c6568f0ff3b15017ece20bb081bd3.jpg'),
(79916, 5507, 'Uma Família da Pesada S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267691.mp4', 'http://timg.bdta.pro/images/7da7bccc920dff9795191e620e9fc81b.jpg'),
(79917, 5507, 'Uma Família da Pesada S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267692.mp4', 'http://timg.bdta.pro/images/b1caea1561e8b0bdbc08d969fc7be3b8.jpg'),
(79918, 5507, 'Uma Família da Pesada S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267693.mp4', 'http://timg.bdta.pro/images/9eced89b814622675fd7d9f6f06b557f.jpg'),
(79919, 5507, 'Uma Família da Pesada S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267694.mp4', 'http://timg.bdta.pro/images/18a4e5606a63c553901040d88f732ac5.jpg'),
(79920, 5507, 'Uma Família da Pesada S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267695.mp4', 'http://timg.bdta.pro/images/c670535c60e31157f7cb1c55ee76bf88.jpg'),
(79921, 5507, 'Uma Família da Pesada S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267696.mp4', 'http://timg.bdta.pro/images/d736ce15a2aa894be497e10402068261.jpg'),
(79922, 5507, 'Uma Família da Pesada S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267697.mp4', 'http://timg.bdta.pro/images/5e78de4c5c7fdd9c9d9bd95a638db00b.jpg'),
(79923, 5507, 'Uma Família da Pesada S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267698.mp4', 'http://timg.bdta.pro/images/057420fcffbcc08b125158d2314d8c0e.jpg'),
(79924, 5507, 'Uma Família da Pesada S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267699.mp4', 'http://timg.bdta.pro/images/2564a255f6098e1f365c555a81cc23c4.jpg'),
(79925, 5507, 'Uma Família da Pesada S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267700.mp4', 'http://timg.bdta.pro/images/4f49003dd780894fd1c7b56b581b3b4b.jpg'),
(79926, 5507, 'Uma Família da Pesada S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267701.mp4', 'http://timg.bdta.pro/images/454fee76e825b2cb9373e32caac4056e.jpg'),
(79927, 5507, 'Uma Família da Pesada S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267702.mp4', 'http://timg.bdta.pro/images/a96b8fd025c751e3e66f115c15969d9b.jpg'),
(79928, 5507, 'Uma Família da Pesada S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267703.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(79929, 5508, 'Uma Família da Pesada S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267704.mp4', 'http://timg.bdta.pro/images/d276bd677ca086058ce002a69a7fbc32.jpg'),
(79930, 5508, 'Uma Família da Pesada S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267705.mp4', 'http://timg.bdta.pro/images/29c1414cacea784187072b6095a9fddd.jpg'),
(79931, 5508, 'Uma Família da Pesada S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267706.mp4', 'http://timg.bdta.pro/images/5a9ead1a60f010b199ebaddb431ea0e2.jpg'),
(79932, 5508, 'Uma Família da Pesada S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267707.mp4', 'http://timg.bdta.pro/images/d444b89982782cefca3a1ed62390095a.jpg'),
(79933, 5508, 'Uma Família da Pesada S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267708.mp4', 'http://timg.bdta.pro/images/4ef96c80dd8c29669e49b2649a852db6.jpg'),
(79934, 5508, 'Uma Família da Pesada S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267709.mp4', 'http://timg.bdta.pro/images/90caa4483015558b5c9bfdbdc40ac61b.jpg'),
(79935, 5508, 'Uma Família da Pesada S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267710.mp4', 'http://timg.bdta.pro/images/f842d05d4bf1e7f98448c4b04adb1370.jpg'),
(79936, 5508, 'Uma Família da Pesada S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267711.mp4', 'http://timg.bdta.pro/images/2d7a0fe8d53cd07ab7009649ed5424ef.jpg'),
(79937, 5508, 'Uma Família da Pesada S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267712.mp4', 'http://timg.bdta.pro/images/08a0fb57898cfa0dd7b38d7bc843a0b1.jpg'),
(79938, 5508, 'Uma Família da Pesada S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267713.mp4', 'http://timg.bdta.pro/images/c764a3852cb3f10442c9db3a835fc021.jpg'),
(79939, 5508, 'Uma Família da Pesada S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267714.mp4', 'http://timg.bdta.pro/images/3092ddecca20edfb364c29b492a414a3.jpg'),
(79940, 5508, 'Uma Família da Pesada S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267715.mp4', 'http://timg.bdta.pro/images/569ddb8a4254a6ea8fedd8cb040d0196.jpg'),
(79941, 5508, 'Uma Família da Pesada S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267716.mp4', 'http://timg.bdta.pro/images/c69fd1ac9da4d8bc185fb2741ddff935.jpg'),
(79942, 5508, 'Uma Família da Pesada S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267717.mp4', 'http://timg.bdta.pro/images/86ade7bef82cfa2394718ab8b20c4539.jpg'),
(79943, 5508, 'Uma Família da Pesada S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267718.mp4', 'http://timg.bdta.pro/images/85d9bd47a9a22c441f905bcb44751ff7.jpg'),
(79944, 5508, 'Uma Família da Pesada S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267719.mp4', 'http://timg.bdta.pro/images/7658762eaa5f47dd5c27874fb9994e3d.jpg'),
(79945, 5508, 'Uma Família da Pesada S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267720.mp4', 'http://timg.bdta.pro/images/fb4423f42b92847f9df4ecf36518c71b.jpg'),
(79946, 5508, 'Uma Família da Pesada S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267721.mp4', 'http://timg.bdta.pro/images/3ae4e6432fdda6eca5625501635d3b07.jpg'),
(79947, 5508, 'Uma Família da Pesada S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267722.mp4', 'http://timg.bdta.pro/images/3e99c3a24762abad946de56c29acab89.jpg'),
(79948, 5508, 'Uma Família da Pesada S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267723.mp4', 'http://timg.bdta.pro/images/5faf5d60325eafa8dbfa84e498a10605.jpg'),
(79949, 5509, 'Uma Família da Pesada S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267724.mp4', 'http://timg.bdta.pro/images/319ba621208b1b9669ceda403307f1ee.jpg'),
(79950, 5509, 'Uma Família da Pesada S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267725.mp4', 'http://timg.bdta.pro/images/a5970a87ae21f060a1035b08d2417b06.jpg'),
(79951, 5509, 'Uma Família da Pesada S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267726.mp4', 'http://timg.bdta.pro/images/567c13b51a38cd00dde6f22274894f6c.jpg'),
(79952, 5509, 'Uma Família da Pesada S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267727.mp4', 'http://timg.bdta.pro/images/c78f2c183e0df13285b01cd3d3202b4c.jpg'),
(79953, 5509, 'Uma Família da Pesada S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267728.mp4', 'http://timg.bdta.pro/images/a7eb6785282d2dcde93d56a462f3ba31.jpg'),
(79954, 5509, 'Uma Família da Pesada S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267729.mp4', 'http://timg.bdta.pro/images/b6a99f68640a18ee1c70f7bdb853eec2.jpg'),
(79955, 5509, 'Uma Família da Pesada S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267730.mp4', 'http://timg.bdta.pro/images/886be44476e286d44e704185d2aa02cf.jpg'),
(79956, 5509, 'Uma Família da Pesada S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267731.mp4', 'http://timg.bdta.pro/images/052a1d11bbb758c3db13961ca33e4cff.jpg'),
(79957, 5509, 'Uma Família da Pesada S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267732.mp4', 'http://timg.bdta.pro/images/8eb2ecbd922b80505b648eb80b119199.jpg'),
(79958, 5509, 'Uma Família da Pesada S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267733.mp4', 'http://timg.bdta.pro/images/199c4151b8f70bd9d5cac1c3fa31bee7.jpg'),
(79959, 5509, 'Uma Família da Pesada S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267734.mp4', 'http://timg.bdta.pro/images/029c3558ca644ff597eed1a0a04e6029.jpg'),
(79960, 5509, 'Uma Família da Pesada S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267735.mp4', 'http://timg.bdta.pro/images/d35dccff9ad4f4afd432391f7b3c335e.jpg'),
(79961, 5509, 'Uma Família da Pesada S15 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267736.mp4', 'http://timg.bdta.pro/images/859d3492b5d0cff94d4138c6a75f739b.jpg'),
(79962, 5509, 'Uma Família da Pesada S15 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267737.mp4', 'http://timg.bdta.pro/images/042efb2f1ed091e1099ed63391ec07b5.jpg'),
(79963, 5509, 'Uma Família da Pesada S15 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267738.mp4', 'http://timg.bdta.pro/images/24c51bff8254378e6b9bda947af6db6b.jpg'),
(79964, 5509, 'Uma Família da Pesada S15 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267739.mp4', 'http://timg.bdta.pro/images/6b7b80c57ce3a70b8ca8a7d74b29e929.jpg'),
(79965, 5509, 'Uma Família da Pesada S15 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267740.mp4', 'http://timg.bdta.pro/images/dcda19ae432fa4a10923ae5e46c118ab.jpg'),
(79966, 5509, 'Uma Família da Pesada S15 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267741.mp4', 'http://timg.bdta.pro/images/218aea93506d6ab1dcb02ec4ae468060.jpg'),
(79967, 5509, 'Uma Família da Pesada S15 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267742.mp4', 'http://timg.bdta.pro/images/ee78a47aade09759daa519a9ad08c90f.jpg'),
(79968, 5509, 'Uma Família da Pesada S15 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267743.mp4', 'http://timg.bdta.pro/images/643e428b506d801a3849b6bbe4df33c9.jpg'),
(79969, 5510, 'Uma Família da Pesada S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267744.mp4', 'http://timg.bdta.pro/images/fe291e1772f67f4532f287ff39affed4.jpg'),
(79970, 5510, 'Uma Família da Pesada S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267745.mp4', 'http://timg.bdta.pro/images/a2e72f01ab418cd308a79e2cb22be3ce.jpg'),
(79971, 5510, 'Uma Família da Pesada S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267746.mp4', 'http://timg.bdta.pro/images/34add51c43e1d72d78f58a91be4317c6.jpg'),
(79972, 5510, 'Uma Família da Pesada S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267747.mp4', 'http://timg.bdta.pro/images/5db70867d40619942e6c7c3e294dd8fe.jpg'),
(79973, 5510, 'Uma Família da Pesada S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267748.mp4', 'http://timg.bdta.pro/images/094cd24fd9144417b7ac0e3e9df97188.jpg'),
(79974, 5510, 'Uma Família da Pesada S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267749.mp4', 'http://timg.bdta.pro/images/2ebf84e6746a64992a38e644f2c7f86f.jpg'),
(79975, 5510, 'Uma Família da Pesada S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267750.mp4', 'http://timg.bdta.pro/images/664550c40f6d304a9a62d55a75e44ee6.jpg'),
(79976, 5510, 'Uma Família da Pesada S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267751.mp4', 'http://timg.bdta.pro/images/6612234295d9bc81c45aca3e4ffd16d5.jpg'),
(79977, 5510, 'Uma Família da Pesada S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267752.mp4', 'http://timg.bdta.pro/images/01e13447fe77d42bc0ca5f4b5f67ba5b.jpg'),
(79978, 5510, 'Uma Família da Pesada S16 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267753.mp4', 'http://timg.bdta.pro/images/5f324dcdf0e1afffd90a47a765eda2ba.jpg'),
(79979, 5510, 'Uma Família da Pesada S16 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267754.mp4', 'http://timg.bdta.pro/images/8a60896860c70bf985865adc2a0a2fdd.jpg'),
(79980, 5510, 'Uma Família da Pesada S16 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267755.mp4', 'http://timg.bdta.pro/images/15090712bbab3820a0af23fc72fcfe96.jpg'),
(79981, 5510, 'Uma Família da Pesada S16 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267756.mp4', 'http://timg.bdta.pro/images/88f735d52e85e8f10fb73cd1a2f58564.jpg'),
(79982, 5510, 'Uma Família da Pesada S16 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267757.mp4', 'http://timg.bdta.pro/images/730975da8234f83f48c445fbf5824d5e.jpg'),
(79983, 5510, 'Uma Família da Pesada S16 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267758.mp4', 'http://timg.bdta.pro/images/3867a39de530f3a1a31b7f74eabcd8e0.jpg'),
(79984, 5510, 'Uma Família da Pesada S16 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267759.mp4', 'http://timg.bdta.pro/images/f7366afa7308434daec5f1df87108495.jpg'),
(79985, 5510, 'Uma Família da Pesada S16 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267760.mp4', 'http://timg.bdta.pro/images/8244d2bd63160807fc3d2e0f5ed8d37b.jpg'),
(79986, 5510, 'Uma Família da Pesada S16 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267761.mp4', 'http://timg.bdta.pro/images/7d30255c98a50398ea3db41790b7da40.jpg'),
(79987, 5510, 'Uma Família da Pesada S16 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267762.mp4', 'http://timg.bdta.pro/images/dcd88eba9104f95105477ec51b56c235.jpg'),
(79988, 5511, 'Uma Família da Pesada S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267763.mp4', 'http://timg.bdta.pro/images/64c0f828ef4100cce03ed928f821e4e3.jpg'),
(79989, 5511, 'Uma Família da Pesada S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267764.mp4', 'http://timg.bdta.pro/images/24b3a3971a1146ce12de6cec9fe8f564.jpg'),
(79990, 5511, 'Uma Família da Pesada S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267765.mp4', 'http://timg.bdta.pro/images/7315a38b6141fc6d5c2f90bd9b5d5481.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(79991, 5511, 'Uma Família da Pesada S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267766.mp4', 'http://timg.bdta.pro/images/95d54fd45da129a494a26005ed8acc56.jpg'),
(79992, 5511, 'Uma Família da Pesada S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267767.mp4', 'http://timg.bdta.pro/images/aa90b50cf56f408f673d2f6f395dd246.jpg'),
(79993, 5511, 'Uma Família da Pesada S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267768.mp4', 'http://timg.bdta.pro/images/b33ce2d91f6b40990181922a580ccdb3.jpg'),
(79994, 5511, 'Uma Família da Pesada S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267769.mp4', 'http://timg.bdta.pro/images/595284181f701d908a9ec2cd2b6a817d.jpg'),
(79995, 5511, 'Uma Família da Pesada S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267770.mp4', 'http://timg.bdta.pro/images/0e300872d8a8679a52688eb5a0b10655.jpg'),
(79996, 5511, 'Uma Família da Pesada S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267771.mp4', 'http://timg.bdta.pro/images/6183651b18fc08f91ca5f8ae25384c05.jpg'),
(79997, 5511, 'Uma Família da Pesada S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267772.mp4', 'http://timg.bdta.pro/images/2018715fdd48dbce7ea9afb4396cfa7e.jpg'),
(79998, 5511, 'Uma Família da Pesada S17 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267773.mp4', 'http://timg.bdta.pro/images/2e1df76896d78ad0620d9bc2fe7512e5.jpg'),
(79999, 5511, 'Uma Família da Pesada S17 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267774.mp4', 'http://timg.bdta.pro/images/e5478194bd679ec11603c352f196b457.jpg'),
(80000, 5511, 'Uma Família da Pesada S17 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267775.mp4', 'http://timg.bdta.pro/images/97de303b98455532358776f26b630da5.jpg'),
(80001, 5511, 'Uma Família da Pesada S17 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267776.mp4', 'http://timg.bdta.pro/images/e4a9e9547b556caa89b3471abc8b21ee.jpg'),
(80002, 5511, 'Uma Família da Pesada S17 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267777.mp4', 'http://timg.bdta.pro/images/a7c3fde9f6a0b84aa40e7b8259ab4c1a.jpg'),
(80003, 5511, 'Uma Família da Pesada S17 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267778.mp4', 'http://timg.bdta.pro/images/5b2430d9527010d4febced77c9d9aee3.jpg'),
(80004, 5511, 'Uma Família da Pesada S17 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267779.mp4', 'http://timg.bdta.pro/images/3c5e226933d230f82d5bff399fd038f8.jpg'),
(80005, 5511, 'Uma Família da Pesada S17 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267780.mp4', 'http://timg.bdta.pro/images/9a4bc37100c9a1f439fd13f708fcfd53.jpg'),
(80006, 5511, 'Uma Família da Pesada S17 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267781.mp4', 'http://timg.bdta.pro/images/db553390f0bdaccc00daaa9e5d5dd572.jpg'),
(80007, 5511, 'Uma Família da Pesada S17 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267782.mp4', 'http://timg.bdta.pro/images/8c9944f8849cc908c2f6cb920eb841c8.jpg'),
(80008, 5512, 'Uma Família da Pesada S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267783.mp4', 'http://timg.bdta.pro/images/12b46b697d58fbc481d27be2eb3b31b4.jpg'),
(80009, 5512, 'Uma Família da Pesada S18 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267784.mp4', 'http://timg.bdta.pro/images/8a88fd13d62c7590fb28c10cf6264ca3.jpg'),
(80010, 5512, 'Uma Família da Pesada S18 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267785.mp4', 'http://timg.bdta.pro/images/7997eb46b3f4979e8c9888c88636260f.jpg'),
(80011, 5512, 'Uma Família da Pesada S18 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267786.mp4', 'http://timg.bdta.pro/images/671c79a69f3b0a8b83b74dcc431cf0ec.jpg'),
(80012, 5512, 'Uma Família da Pesada S18 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267787.mp4', 'http://timg.bdta.pro/images/8e738cce7ccbba8aa4526e6378ecadda.jpg'),
(80013, 5512, 'Uma Família da Pesada S18 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267788.mp4', 'http://timg.bdta.pro/images/d7f5e2ca08343deaad6a682da3650955.jpg'),
(80014, 5512, 'Uma Família da Pesada S18 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267789.mp4', 'http://timg.bdta.pro/images/6439f328835f9b88d6661565a33f20d7.jpg'),
(80015, 5512, 'Uma Família da Pesada S18 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267790.mp4', 'http://timg.bdta.pro/images/72ad8cda85a27520e80cb48ef2fa6241.jpg'),
(80016, 5512, 'Uma Família da Pesada S18 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267791.mp4', 'http://timg.bdta.pro/images/7c6389a8cb77412250ca4efc199c1e9b.jpg'),
(80017, 5512, 'Uma Família da Pesada S18 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267792.mp4', 'http://timg.bdta.pro/images/628a31db49062348305b4c7c4e0e8057.jpg'),
(80018, 5512, 'Uma Família da Pesada S18 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267793.mp4', 'http://timg.bdta.pro/images/b55ba677fcaad60e60b43c3260e41f65.jpg'),
(80019, 5512, 'Uma Família da Pesada S18 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267794.mp4', 'http://timg.bdta.pro/images/7370e286e7d53e43e16a7b5d950a7a84.jpg'),
(80020, 5512, 'Uma Família da Pesada S18 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267795.mp4', 'http://timg.bdta.pro/images/9f5d53218db2cbe6ad42f1ea3a384b3d.jpg'),
(80021, 5512, 'Uma Família da Pesada S18 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267796.mp4', 'http://timg.bdta.pro/images/91fb666b04207318144dae729718c305.jpg'),
(80022, 5512, 'Uma Família da Pesada S18 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267797.mp4', 'http://timg.bdta.pro/images/8f38178098fc845d4f06503c01ba4b3f.jpg'),
(80023, 5512, 'Uma Família da Pesada S18 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267798.mp4', 'http://timg.bdta.pro/images/32fa3f48e27486a633d2bd6a1bb00dc4.jpg'),
(80024, 5512, 'Uma Família da Pesada S18 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267799.mp4', 'http://timg.bdta.pro/images/1db2b08f7b88afb16e18da2517984c71.jpg'),
(80025, 5512, 'Uma Família da Pesada S18 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267800.mp4', 'http://timg.bdta.pro/images/d1f4c8762d48a0aed5dc7ff2b2dbde7d.jpg'),
(80026, 5512, 'Uma Família da Pesada S18 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267801.mp4', 'http://timg.bdta.pro/images/d5de4949a28d85f938e1d27a4311b0d1.jpg'),
(80027, 5512, 'Uma Família da Pesada S18 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267802.mp4', 'http://timg.bdta.pro/images/251d5e07e0630e88a7917b441028c85c.jpg'),
(80028, 5513, 'Uma Família da Pesada S19 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267803.mp4', 'http://timg.bdta.pro/images/e53b107475eecff5384b557d596ab018.jpg'),
(80029, 5513, 'Uma Família da Pesada S19 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267804.mp4', 'http://timg.bdta.pro/images/bc890392943980b44cc69a215afb6be4.jpg'),
(80030, 5513, 'Uma Família da Pesada S19 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267805.mp4', 'http://timg.bdta.pro/images/83c6a26687d43b4a52d399035d31fbe7.jpg'),
(80031, 5513, 'Uma Família da Pesada S19 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267806.mp4', 'http://timg.bdta.pro/images/c7f4f7690e1d652e435cfb70b24a4c3e.jpg'),
(80032, 5513, 'Uma Família da Pesada S19 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267807.mp4', 'http://timg.bdta.pro/images/242d325fe42414edf9be1e2b7ac912e5.jpg'),
(80033, 5513, 'Uma Família da Pesada S19 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267808.mp4', 'http://timg.bdta.pro/images/f30d2fa7ae6344434009319b8126de73.jpg'),
(80034, 5513, 'Uma Família da Pesada S19 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267809.mp4', 'http://timg.bdta.pro/images/21a0017decf0f7cced5056109c2dad64.jpg'),
(80035, 5513, 'Uma Família da Pesada S19 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267810.mp4', 'http://timg.bdta.pro/images/dd35a7dd56ba0052f18c1ba10d7ce821.jpg'),
(80036, 5513, 'Uma Família da Pesada S19 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267811.mp4', 'http://timg.bdta.pro/images/7a19d7144e81dbab4a0a5540a520e1a8.jpg'),
(80037, 5513, 'Uma Família da Pesada S19 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267812.mp4', 'http://timg.bdta.pro/images/19dc6c0584687cef391b58871fd36978.jpg'),
(80038, 5513, 'Uma Família da Pesada S19 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267813.mp4', 'http://timg.bdta.pro/images/8da5c9598b58db374255be899aa79b40.jpg'),
(80039, 5513, 'Uma Família da Pesada S19 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267814.mp4', 'http://timg.bdta.pro/images/64576c71fc5eb097bf1d9ae1736fc252.jpg'),
(80040, 5513, 'Uma Família da Pesada S19 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267815.mp4', 'http://timg.bdta.pro/images/44c87c3b8941e715413ef07124a3db16.jpg'),
(80041, 5513, 'Uma Família da Pesada S19 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267816.mp4', 'http://timg.bdta.pro/images/e9c1ff176f43a0dd9c3613b69fb7d0d7.jpg'),
(80042, 5513, 'Uma Família da Pesada S19 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267817.mp4', 'http://timg.bdta.pro/images/4cc2cd54ea437dbdd6648f395b50f028.jpg'),
(80043, 5513, 'Uma Família da Pesada S19 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267818.mp4', 'http://timg.bdta.pro/images/29a23df7eee55ad2c8ea3542a441ee93.jpg'),
(80044, 5513, 'Uma Família da Pesada S19 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267819.mp4', 'http://timg.bdta.pro/images/0e6545168d814376b8b05a3f7f35c545.jpg'),
(80045, 5513, 'Uma Família da Pesada S19 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267820.mp4', 'http://timg.bdta.pro/images/3fbb4da995eaea6abd9fb1240ce3f774.jpg'),
(80046, 5513, 'Uma Família da Pesada S19 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267821.mp4', 'http://timg.bdta.pro/images/939e98a9f30a824472506353042c39ae.jpg'),
(80047, 5513, 'Uma Família da Pesada S19 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267822.mp4', 'http://timg.bdta.pro/images/c480754be64b9cd939f31f926057bd81.jpg'),
(80048, 5514, 'Uma Família da Pesada S20 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267823.mp4', 'http://timg.bdta.pro/images/517ca353e202a2bb578f132041e9f13c.jpg'),
(80049, 5514, 'Uma Família da Pesada S20 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267824.mp4', 'http://timg.bdta.pro/images/eeac36dc0c9658552fb0c88497adc9a2.jpg'),
(80050, 5514, 'Uma Família da Pesada S20 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267825.mp4', 'http://timg.bdta.pro/images/7898f227baa3f07ec23d8a8f01f22d0b.jpg'),
(80051, 5514, 'Uma Família da Pesada S20 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267826.mp4', 'http://timg.bdta.pro/images/8bb44d1c5f98366a8e9e46eabb81011c.jpg'),
(80052, 5514, 'Uma Família da Pesada S20 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267827.mp4', 'http://timg.bdta.pro/images/aff60082e685a2c115863a52a7d1136f.jpg'),
(80053, 5514, 'Uma Família da Pesada S20 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267828.mp4', 'http://timg.bdta.pro/images/60ecbdbf8f6f53b5d117b104e6e19bde.jpg'),
(80054, 5514, 'Uma Família da Pesada S20 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267829.mp4', 'http://timg.bdta.pro/images/919ac58315bd2e42308d6eeaee2846d5.jpg'),
(80055, 5514, 'Uma Família da Pesada S20 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267830.mp4', 'http://timg.bdta.pro/images/c4c8ad02d7c71f94c904393d0b8ede21.jpg'),
(80056, 5514, 'Uma Família da Pesada S20 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267831.mp4', 'http://timg.bdta.pro/images/2cdd7d6681ff120b28b45a6e3d00f9cc.jpg'),
(80057, 5514, 'Uma Família da Pesada S20 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267832.mp4', 'http://timg.bdta.pro/images/8be8b1ec3858dee21dfbeade826fc939.jpg'),
(80058, 5514, 'Uma Família da Pesada S20 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267833.mp4', 'http://timg.bdta.pro/images/1669af336467303dfc5c0a8a6428306a.jpg'),
(80059, 5514, 'Uma Família da Pesada S20 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267834.mp4', 'http://timg.bdta.pro/images/5cb9c605f69cf010520f31fe772f1802.jpg'),
(80060, 5514, 'Uma Família da Pesada S20 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267835.mp4', 'http://timg.bdta.pro/images/dc69328ea86b7ec8bc8d05116f2ea31d.jpg'),
(80061, 5514, 'Uma Família da Pesada S20 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267836.mp4', 'http://timg.bdta.pro/images/40fecfea237b75c88a33171c46df3494.jpg'),
(80062, 5514, 'Uma Família da Pesada S20 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267837.mp4', 'http://timg.bdta.pro/images/4f9fcf677188034ec2c884916c9359dc.jpg'),
(80063, 5514, 'Uma Família da Pesada S20 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267838.mp4', 'http://timg.bdta.pro/images/a4e6d96c9e133298c8aa38943261f7ab.jpg'),
(80064, 5515, 'Uma Família da Pesada S21 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sgzVYKtr4NnAaOeTJ59zwUCyFIX.jpg'),
(80065, 5515, 'Uma Família da Pesada S21 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/czA61vsl9E5gRewaMh8nzhT1jtI.jpg'),
(80066, 5515, 'Uma Família da Pesada S21 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xz0ZPvhPRC8RbPxVTlS9vJqBmDx.jpg'),
(80067, 5515, 'Uma Família da Pesada S21 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267842.mp4', 'http://image.tmdb.org/t/p/w1280/vFwWsqD4BZDrLhIwZnoibKjsotj.jpg'),
(80068, 5515, 'Uma Família da Pesada S21 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1cpLa9HQ5CfyrsGOblivUr8Ptc5.jpg'),
(80069, 5515, 'Uma Família da Pesada S21 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhdYIATbrPIr8FVEQNS77aQmQ4I.jpg'),
(80070, 5515, 'Uma Família da Pesada S21 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267845.mp4', 'http://image.tmdb.org/t/p/w1280/1MgG1wzKOpo3TPRjSVA80AN4LC0.jpg'),
(80071, 5515, 'Uma Família da Pesada S21 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fC9QhPXmdCsJzrn30EzBoeEQFqy.jpg'),
(80072, 5515, 'Uma Família da Pesada S21 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmPqo8YzArxHU3lm7fskxtkgYuP.jpg'),
(80073, 5515, 'Uma Família da Pesada S21 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bOwN24Mpjsh2ZSSMiIhobWPzQuo.jpg'),
(80074, 5515, 'Uma Família da Pesada S21 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267849.mp4', 'http://image.tmdb.org/t/p/w1280/u0nxLu9xZBjjFCmtSyi6uazULTx.jpg'),
(80075, 5515, 'Uma Família da Pesada S21 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267850.mp4', 'http://image.tmdb.org/t/p/w1280/hvhRB97MqlLvWYwq6o11jqrZgUD.jpg'),
(80076, 5515, 'Uma Família da Pesada S21 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267851.mp4', 'http://image.tmdb.org/t/p/w1280/Ao8A4QCvpcnl5n3gOuItewKdWvV.jpg'),
(80077, 5515, 'Uma Família da Pesada S21 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267852.mp4', 'http://image.tmdb.org/t/p/w1280/mytawT2pfaNRqyvRjodS9EPCsFj.jpg'),
(80078, 5515, 'Uma Família da Pesada S21 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267853.mp4', 'http://image.tmdb.org/t/p/w1280/vaeksLWOxPIqRDbe7CDJB9bHuTY.jpg'),
(80079, 5515, 'Uma Família da Pesada S21 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267854.mp4', 'http://image.tmdb.org/t/p/w1280/mr6MLjLJ2KtuMLkNPb1aqnUVDsN.jpg'),
(80080, 5515, 'Uma Família da Pesada S21 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267855.mp4', 'http://image.tmdb.org/t/p/w1280/bxHkLC8O3eU8alXGxBORTXYP5Lz.jpg'),
(80081, 5515, 'Uma Família da Pesada S21 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267856.mp4', 'http://image.tmdb.org/t/p/w1280/5it9Vnq00Y5z1vKGBtboQ98CdUf.jpg'),
(80082, 5515, 'Uma Família da Pesada S21 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267857.mp4', 'http://image.tmdb.org/t/p/w1280/2ou0R4ULaJO4GiOZkk0bbPDM0Rh.jpg'),
(80083, 5515, 'Uma Família da Pesada S21 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267858.mp4', 'http://image.tmdb.org/t/p/w1280/qbXutJ5V2QNetbAlsbliwvVDFIW.jpg'),
(80084, 5516, 'Uma Família da Pesada S22 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267859.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80085, 5516, 'Uma Família da Pesada S22 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267860.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80086, 5516, 'Uma Família da Pesada S22 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267861.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80087, 5516, 'Uma Família da Pesada S22 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267862.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80088, 5516, 'Uma Família da Pesada S22 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267863.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80089, 5516, 'Uma Família da Pesada S22 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267864.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80090, 5516, 'Uma Família da Pesada S22 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267865.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80091, 5516, 'Uma Família da Pesada S22 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267866.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80092, 5516, 'Uma Família da Pesada S22 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267867.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80093, 5516, 'Uma Família da Pesada S22 E10', 'http://sinalprivado.info:80/series/1533784/1533784/311918.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80094, 5516, 'Uma Família da Pesada S22 E11', 'http://sinalprivado.info:80/series/1533784/1533784/311919.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80095, 5516, 'Uma Família da Pesada S22 E12', 'http://sinalprivado.info:80/series/1533784/1533784/316927.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80096, 5516, 'Uma Família da Pesada S22 E13', 'http://sinalprivado.info:80/series/1533784/1533784/335621.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80097, 5516, 'Uma Família da Pesada S22 E14', 'http://sinalprivado.info:80/series/1533784/1533784/339801.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80098, 5516, 'Uma Família da Pesada S22 E15', 'http://sinalprivado.info:80/series/1533784/1533784/342734.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80099, 5516, 'Uma Família da Pesada S22 E16', 'http://sinalprivado.info:80/series/1533784/1533784/480762.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80100, 5516, 'Uma Família da Pesada S22 E17', 'http://sinalprivado.info:80/series/1533784/1533784/513894.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80101, 5517, 'Uma Família da Pesada S23 E01', 'http://sinalprivado.info:80/series/1533784/1533784/700910.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80102, 5517, 'Uma Família da Pesada S23 E02', 'http://sinalprivado.info:80/series/1533784/1533784/708686.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80103, 5517, 'Uma Família da Pesada S23 E03', 'http://sinalprivado.info:80/series/1533784/1533784/715873.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80104, 5517, 'Uma Família da Pesada S23 E04', 'http://sinalprivado.info:80/series/1533784/1533784/723630.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80105, 5517, 'Uma Família da Pesada S23 E05', 'http://sinalprivado.info:80/series/1533784/1533784/733805.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80106, 5517, 'Uma Família da Pesada S23 E06', 'http://sinalprivado.info:80/series/1533784/1533784/737087.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80107, 5517, 'Uma Família da Pesada S23 E07', 'http://sinalprivado.info:80/series/1533784/1533784/753236.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80108, 5517, 'Uma Família da Pesada S23 E08', 'http://sinalprivado.info:80/series/1533784/1533784/785421.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80109, 5517, 'Uma Família da Pesada S23 E09', 'http://sinalprivado.info:80/series/1533784/1533784/769456.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80110, 5517, 'Uma Família da Pesada S23 E10', 'http://sinalprivado.info:80/series/1533784/1533784/785423.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80111, 5517, 'Uma Família da Pesada S23 E11', 'http://sinalprivado.info:80/series/1533784/1533784/789027.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80112, 5517, 'Uma Família da Pesada S23 E12', 'http://sinalprivado.info:80/series/1533784/1533784/797173.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80113, 5517, 'Uma Família da Pesada S23 E13', 'http://sinalprivado.info:80/series/1533784/1533784/832832.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80114, 5517, 'Uma Família da Pesada S23 E14', 'http://sinalprivado.info:80/series/1533784/1533784/876879.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80115, 5517, 'Uma Família da Pesada S23 E15', 'http://sinalprivado.info:80/series/1533784/1533784/876880.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80116, 5517, 'Uma Família da Pesada S23 E16', 'http://sinalprivado.info:80/series/1533784/1533784/876881.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80117, 5517, 'Uma Família da Pesada S23 E17', 'http://sinalprivado.info:80/series/1533784/1533784/881454.mp4', 'http://gstaticontent.com/images/6a84fc35e4385de29f9dec3b6ca928bf.jpg'),
(80118, 5518, 'Harina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241891.mp4', 'http://timg.bdta.pro/images/027c84e7afc78ea2fc698a0150bfa28e.jpg'),
(80119, 5518, 'Harina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241892.mp4', 'http://timg.bdta.pro/images/473112202081d91026c24cebe8a1b9e8.jpg'),
(80120, 5518, 'Harina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241893.mp4', 'http://timg.bdta.pro/images/758de9f9ec9662cc9d128344811d62e6.jpg'),
(80121, 5518, 'Harina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241894.mp4', 'http://timg.bdta.pro/images/d57982ee981af933ed478618e08c5261.jpg'),
(80122, 5518, 'Harina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241895.mp4', 'http://timg.bdta.pro/images/aa2f9b984f3657404cff808dffd93bc1.jpg'),
(80123, 5518, 'Harina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241896.mp4', 'http://timg.bdta.pro/images/0654c446a255a7cae2aca54b287b9117.jpg'),
(80124, 5518, 'Harina S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241897.mp4', 'http://timg.bdta.pro/images/70d2a028dc8fc51090956923f49eb1f1.jpg'),
(80125, 5518, 'Harina S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241898.mp4', 'http://timg.bdta.pro/images/0f6a908b9ebdb96d4eec76054547d61a.jpg'),
(80126, 5519, 'Harina S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241899.mp4', 'http://gstaticontent.com/images/f6398e43d293ad4d95384d2a44ab0b33.jpg'),
(80127, 5519, 'Harina S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241900.mp4', 'http://gstaticontent.com/images/f6398e43d293ad4d95384d2a44ab0b33.jpg'),
(80128, 5519, 'Harina S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241901.mp4', 'http://gstaticontent.com/images/f6398e43d293ad4d95384d2a44ab0b33.jpg'),
(80129, 5519, 'Harina S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241902.mp4', 'http://gstaticontent.com/images/f6398e43d293ad4d95384d2a44ab0b33.jpg'),
(80130, 5519, 'Harina S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241903.mp4', 'http://gstaticontent.com/images/f6398e43d293ad4d95384d2a44ab0b33.jpg'),
(80131, 5519, 'Harina S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241904.mp4', 'http://gstaticontent.com/images/f6398e43d293ad4d95384d2a44ab0b33.jpg'),
(80132, 5519, 'Harina S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241905.mp4', 'http://gstaticontent.com/images/f6398e43d293ad4d95384d2a44ab0b33.jpg'),
(80133, 5519, 'Harina S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241906.mp4', 'http://gstaticontent.com/images/f6398e43d293ad4d95384d2a44ab0b33.jpg'),
(80134, 5520, 'Homem-Aranha da Marvel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178350.mp4', 'http://timg.bdta.pro/images/9c377f2d02e0c0e54d2e5a288517b853.jpg'),
(80135, 5520, 'Homem-Aranha da Marvel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178351.mp4', 'http://timg.bdta.pro/images/2197aea67e3c35f1e0d35117ec0b24b4.jpg'),
(80136, 5520, 'Homem-Aranha da Marvel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178352.mp4', 'http://timg.bdta.pro/images/0546deca8ffc01e8efb52d55b48f5c78.jpg'),
(80137, 5520, 'Homem-Aranha da Marvel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178353.mp4', 'http://timg.bdta.pro/images/11b8388822efb79c02494ac8626b3f28.jpg'),
(80138, 5520, 'Homem-Aranha da Marvel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178354.mp4', 'http://timg.bdta.pro/images/d9797fa51e0a0adcae5106cb1d9a507d.jpg'),
(80139, 5520, 'Homem-Aranha da Marvel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178355.mp4', 'http://timg.bdta.pro/images/80b86b8d93c554f9a1769bc36a46f8d8.jpg'),
(80140, 5520, 'Homem-Aranha da Marvel S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178356.mp4', 'http://timg.bdta.pro/images/b13cfe880fa0d66dde1b4feb39f656ca.jpg'),
(80141, 5520, 'Homem-Aranha da Marvel S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178357.mp4', 'http://timg.bdta.pro/images/dd04fdecd742f00435ae7a1a42052d30.jpg'),
(80142, 5520, 'Homem-Aranha da Marvel S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178358.mp4', 'http://timg.bdta.pro/images/31df7aad28b0de3319583d4707a71a94.jpg'),
(80143, 5520, 'Homem-Aranha da Marvel S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178359.mp4', 'http://timg.bdta.pro/images/245634e64261bbd6ab33432d983fe075.jpg'),
(80144, 5520, 'Homem-Aranha da Marvel S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/178360.mp4', 'http://timg.bdta.pro/images/ea3452efdced6ea186db81b688d0beb6.jpg'),
(80145, 5520, 'Homem-Aranha da Marvel S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/178361.mp4', 'http://timg.bdta.pro/images/5a6d05b17584ffd7148a6257b072c5fb.jpg'),
(80146, 5520, 'Homem-Aranha da Marvel S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/178362.mp4', 'http://timg.bdta.pro/images/827f37f239788bb39da682a7b6c3593b.jpg'),
(80147, 5520, 'Homem-Aranha da Marvel S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/178363.mp4', 'http://timg.bdta.pro/images/6c057fa413160e0841d12b114fdb1e27.jpg'),
(80148, 5520, 'Homem-Aranha da Marvel S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/178364.mp4', 'http://timg.bdta.pro/images/cdb483d6f21a165cfe1fe073a7440bd9.jpg'),
(80149, 5520, 'Homem-Aranha da Marvel S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/178365.mp4', 'http://timg.bdta.pro/images/1960549c397904fb11edda596bf82ce6.jpg'),
(80150, 5520, 'Homem-Aranha da Marvel S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/178366.mp4', 'http://timg.bdta.pro/images/3dae93c84e3d6f9db48d0cc69b8689d4.jpg'),
(80151, 5520, 'Homem-Aranha da Marvel S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/178367.mp4', 'http://timg.bdta.pro/images/f395babfa652ab2357b93c4d4a6127d2.jpg'),
(80152, 5520, 'Homem-Aranha da Marvel S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/178368.mp4', 'http://timg.bdta.pro/images/bc8bc3ef7c7e5682319fa8f33f6620c6.jpg'),
(80153, 5520, 'Homem-Aranha da Marvel S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/178369.mp4', 'http://timg.bdta.pro/images/8e4572b2b8f4de63a0ac332034518493.jpg'),
(80154, 5520, 'Homem-Aranha da Marvel S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/178370.mp4', 'http://timg.bdta.pro/images/338f8bd161a71e4556263379fbbb8913.jpg'),
(80155, 5520, 'Homem-Aranha da Marvel S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/178371.mp4', 'http://timg.bdta.pro/images/c1bb6942938eec9b44140c3ed573f6f8.jpg'),
(80156, 5520, 'Homem-Aranha da Marvel S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/178372.mp4', 'http://timg.bdta.pro/images/06ffb780c2b59886a29f954a756b7e03.jpg'),
(80157, 5520, 'Homem-Aranha da Marvel S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/178373.mp4', 'http://timg.bdta.pro/images/f1ed83b2033e6536ea9b9c70e85839f8.jpg'),
(80158, 5520, 'Homem-Aranha da Marvel S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/178374.mp4', 'http://timg.bdta.pro/images/950f953bab91d763afc1e3feab92b22e.jpg'),
(80159, 5520, 'Homem-Aranha da Marvel S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/178375.mp4', 'http://gstaticontent.com/images/1fd81814e6d8bdb6814a409cec6ea56d.jpg'),
(80160, 5521, 'Homem-Aranha da Marvel S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178376.mp4', 'http://timg.bdta.pro/images/f7d4090cdce447c54e664c142d9d0f19.jpg'),
(80161, 5521, 'Homem-Aranha da Marvel S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178377.mp4', 'http://timg.bdta.pro/images/280b6ffa8bcd1076849e4351fc5ead7c.jpg'),
(80162, 5521, 'Homem-Aranha da Marvel S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178378.mp4', 'http://timg.bdta.pro/images/3d497bcc689b2ba639c27b3fe2318a90.jpg'),
(80163, 5521, 'Homem-Aranha da Marvel S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178379.mp4', 'http://timg.bdta.pro/images/c2677c44fe31cfba7ddf8f2b709fed97.jpg'),
(80164, 5521, 'Homem-Aranha da Marvel S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178380.mp4', 'http://timg.bdta.pro/images/da9205b8a08b2b68b5fbc30657342dab.jpg'),
(80165, 5521, 'Homem-Aranha da Marvel S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178381.mp4', 'http://timg.bdta.pro/images/696bef55f9e57bc41262d481cd6e995d.jpg'),
(80166, 5521, 'Homem-Aranha da Marvel S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178382.mp4', 'http://timg.bdta.pro/images/ab0ca888d37e412772c88b5de6d80ccf.jpg'),
(80167, 5521, 'Homem-Aranha da Marvel S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178383.mp4', 'http://timg.bdta.pro/images/44e9a15399529d3f1aeb8886cf67cc5c.jpg'),
(80168, 5521, 'Homem-Aranha da Marvel S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178384.mp4', 'http://timg.bdta.pro/images/bd8fa1c46696d54a2604d5d7d45f8557.jpg'),
(80169, 5521, 'Homem-Aranha da Marvel S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178385.mp4', 'http://timg.bdta.pro/images/0af28fca0a8228320083d310751003f3.jpg'),
(80170, 5521, 'Homem-Aranha da Marvel S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/178386.mp4', 'http://timg.bdta.pro/images/cd454ed5127bd37071934779bff87efd.jpg'),
(80171, 5521, 'Homem-Aranha da Marvel S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/178387.mp4', 'http://timg.bdta.pro/images/8da9be54a1d686386340856a953adee1.jpg'),
(80172, 5521, 'Homem-Aranha da Marvel S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/178388.mp4', 'http://timg.bdta.pro/images/209881a62e04c32cff04fc796d5ddb31.jpg'),
(80173, 5521, 'Homem-Aranha da Marvel S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/178389.mp4', 'http://timg.bdta.pro/images/20ac03c80174d9f568899b855bdb2268.jpg'),
(80174, 5521, 'Homem-Aranha da Marvel S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/178390.mp4', 'http://timg.bdta.pro/images/8f959e650a8c68cc81ab43769ce103b4.jpg'),
(80175, 5521, 'Homem-Aranha da Marvel S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/178391.mp4', 'http://timg.bdta.pro/images/c46543f2551bc518632469e0bbc0a3ec.jpg'),
(80176, 5521, 'Homem-Aranha da Marvel S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/178392.mp4', 'http://gstaticontent.com/images/1fd81814e6d8bdb6814a409cec6ea56d.jpg'),
(80177, 5521, 'Homem-Aranha da Marvel S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/178393.mp4', 'http://timg.bdta.pro/images/1bbf8f1734c755875ed17b047984e1c8.jpg'),
(80178, 5521, 'Homem-Aranha da Marvel S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/178394.mp4', 'http://gstaticontent.com/images/1fd81814e6d8bdb6814a409cec6ea56d.jpg'),
(80179, 5521, 'Homem-Aranha da Marvel S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/178395.mp4', 'http://gstaticontent.com/images/1fd81814e6d8bdb6814a409cec6ea56d.jpg'),
(80180, 5521, 'Homem-Aranha da Marvel S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/178396.mp4', 'http://gstaticontent.com/images/1fd81814e6d8bdb6814a409cec6ea56d.jpg'),
(80181, 5521, 'Homem-Aranha da Marvel S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/178397.mp4', 'http://gstaticontent.com/images/1fd81814e6d8bdb6814a409cec6ea56d.jpg'),
(80182, 5521, 'Homem-Aranha da Marvel S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/178398.mp4', 'http://gstaticontent.com/images/1fd81814e6d8bdb6814a409cec6ea56d.jpg'),
(80183, 5521, 'Homem-Aranha da Marvel S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/178399.mp4', 'http://gstaticontent.com/images/1fd81814e6d8bdb6814a409cec6ea56d.jpg'),
(80184, 5521, 'Homem-Aranha da Marvel S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/178400.mp4', 'http://gstaticontent.com/images/1fd81814e6d8bdb6814a409cec6ea56d.jpg'),
(80185, 5521, 'Homem-Aranha da Marvel S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/178401.mp4', 'http://gstaticontent.com/images/1fd81814e6d8bdb6814a409cec6ea56d.jpg'),
(80186, 5522, 'Homem-Aranha da Marvel S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178402.mp4', 'http://timg.bdta.pro/images/3a7f046c3ee7daae108da7fe65c60072.jpg'),
(80187, 5522, 'Homem-Aranha da Marvel S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178403.mp4', 'http://timg.bdta.pro/images/59ef88609c7534815458640c9f07efe6.jpg'),
(80188, 5522, 'Homem-Aranha da Marvel S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178404.mp4', 'http://timg.bdta.pro/images/93a81362c66e37ce2ed3c95dacbef5e7.jpg'),
(80189, 5522, 'Homem-Aranha da Marvel S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178405.mp4', 'http://timg.bdta.pro/images/c599e49a704f947e1413ff0c0058463b.jpg'),
(80190, 5522, 'Homem-Aranha da Marvel S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178406.mp4', 'http://timg.bdta.pro/images/b01146487d11123fe34d4bb78644c504.jpg'),
(80191, 5522, 'Homem-Aranha da Marvel S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178407.mp4', 'http://timg.bdta.pro/images/c8ca67e8d7b92b3ebb3277600343480b.jpg'),
(80192, 5522, 'Homem-Aranha da Marvel S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178408.mp4', 'http://gstaticontent.com/images/1fd81814e6d8bdb6814a409cec6ea56d.jpg'),
(80193, 5522, 'Homem-Aranha da Marvel S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178409.mp4', 'http://gstaticontent.com/images/1fd81814e6d8bdb6814a409cec6ea56d.jpg'),
(80194, 5522, 'Homem-Aranha da Marvel S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178410.mp4', 'http://gstaticontent.com/images/1fd81814e6d8bdb6814a409cec6ea56d.jpg'),
(80195, 5522, 'Homem-Aranha da Marvel S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178411.mp4', 'http://gstaticontent.com/images/1fd81814e6d8bdb6814a409cec6ea56d.jpg'),
(80196, 5522, 'Homem-Aranha da Marvel S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/178412.mp4', 'http://gstaticontent.com/images/1fd81814e6d8bdb6814a409cec6ea56d.jpg'),
(80197, 5522, 'Homem-Aranha da Marvel S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/178413.mp4', 'http://gstaticontent.com/images/1fd81814e6d8bdb6814a409cec6ea56d.jpg'),
(80198, 5523, 'Kotaro Vai Morar Sozinho S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178340.mp4', 'http://timg.bdta.pro/images/3497a3bf6304f27e9f74e7e1dfd29b7c.jpg'),
(80199, 5523, 'Kotaro Vai Morar Sozinho S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178341.mp4', 'http://timg.bdta.pro/images/0de5a81a0bbb1c532e1db7d9c4d9f1b8.jpg'),
(80200, 5523, 'Kotaro Vai Morar Sozinho S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178342.mp4', 'http://timg.bdta.pro/images/2cf480c91e6182c8a8c4a53f983b4b04.jpg'),
(80201, 5523, 'Kotaro Vai Morar Sozinho S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178343.mp4', 'http://timg.bdta.pro/images/e6a08b6ad6f6d16331d3bba2e19facc3.jpg'),
(80202, 5523, 'Kotaro Vai Morar Sozinho S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178344.mp4', 'http://timg.bdta.pro/images/2e0107c7871cf0d62d1ec56b58cf7069.jpg'),
(80203, 5523, 'Kotaro Vai Morar Sozinho S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178345.mp4', 'http://timg.bdta.pro/images/f487e4abc0908a58a2eac70cb5612181.jpg'),
(80204, 5523, 'Kotaro Vai Morar Sozinho S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178346.mp4', 'http://timg.bdta.pro/images/037fefb47d3f4d84dbeb4363e07e7545.jpg'),
(80205, 5523, 'Kotaro Vai Morar Sozinho S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178347.mp4', 'http://timg.bdta.pro/images/fd8d29f09517d5ba95d7ec8dbc68b561.jpg'),
(80206, 5523, 'Kotaro Vai Morar Sozinho S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178348.mp4', 'http://timg.bdta.pro/images/f0a4939d54360630cc9a22bb31635d75.jpg'),
(80207, 5523, 'Kotaro Vai Morar Sozinho S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178349.mp4', 'http://timg.bdta.pro/images/d7dd3cb7894acfa7153cee4ed4102d38.jpg'),
(80208, 5524, 'NCIS Havaí: Investigações Criminais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224121.mp4', 'http://timg.bdta.pro/images/899957a250c3e0984718c09d2f88a477.jpg'),
(80209, 5524, 'NCIS Havaí: Investigações Criminais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224122.mp4', 'http://timg.bdta.pro/images/bb492f1b3502eadf0b303787ce0493a5.jpg'),
(80210, 5524, 'NCIS Havaí: Investigações Criminais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224123.mp4', 'http://timg.bdta.pro/images/e2f09a447b4c7189976691f27a5c65e8.jpg'),
(80211, 5524, 'NCIS Havaí: Investigações Criminais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224124.mp4', 'http://timg.bdta.pro/images/c910d4dfc3d831ae1e2f1cc7fbc35c54.jpg'),
(80212, 5524, 'NCIS Havaí: Investigações Criminais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224125.mp4', 'http://timg.bdta.pro/images/63d1046c680ba1c3e0d7ba11fcfc15bc.jpg'),
(80213, 5524, 'NCIS Havaí: Investigações Criminais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224126.mp4', 'http://timg.bdta.pro/images/1bd3a37a880fa04ddcd1e3cc6abaed08.jpg'),
(80214, 5524, 'NCIS Havaí: Investigações Criminais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224127.mp4', 'http://timg.bdta.pro/images/085232af5ca5fdb505eb31435b18093c.jpg'),
(80215, 5524, 'NCIS Havaí: Investigações Criminais S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224128.mp4', 'http://timg.bdta.pro/images/3d191c5bf0f980a521a6b6cb562967d6.jpg'),
(80216, 5524, 'NCIS Havaí: Investigações Criminais S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224129.mp4', 'http://timg.bdta.pro/images/12b59653258694a788a0a1ad732a2c9f.jpg'),
(80217, 5524, 'NCIS Havaí: Investigações Criminais S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224130.mp4', 'http://timg.bdta.pro/images/a512436d5135eaf9ad8093ca929561a5.jpg'),
(80218, 5524, 'NCIS Havaí: Investigações Criminais S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224131.mp4', 'http://timg.bdta.pro/images/60dc9e1366b2258b7b2d39a14b5ffe3d.jpg'),
(80219, 5524, 'NCIS Havaí: Investigações Criminais S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224132.mp4', 'http://timg.bdta.pro/images/995ed36aa6cda937da1b9fb2e883966d.jpg'),
(80220, 5524, 'NCIS Havaí: Investigações Criminais S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224133.mp4', 'http://timg.bdta.pro/images/1df63bd96acb3602121ba674562378a6.jpg'),
(80221, 5524, 'NCIS Havaí: Investigações Criminais S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224134.mp4', 'http://timg.bdta.pro/images/417db402bdd2da32b0aab26c520ba142.jpg'),
(80222, 5524, 'NCIS Havaí: Investigações Criminais S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224135.mp4', 'http://timg.bdta.pro/images/76ec93b275c68c09f8a9e3319991b10e.jpg'),
(80223, 5524, 'NCIS Havaí: Investigações Criminais S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224136.mp4', 'http://timg.bdta.pro/images/97eddbee039e4c2d75e085df28d39b2b.jpg'),
(80224, 5524, 'NCIS Havaí: Investigações Criminais S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224137.mp4', 'http://timg.bdta.pro/images/55cdcfae990ac12b3a4147ad83104241.jpg'),
(80225, 5524, 'NCIS Havaí: Investigações Criminais S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224138.mp4', 'http://timg.bdta.pro/images/8062d953fb18cc67038d586396d86f21.jpg'),
(80226, 5524, 'NCIS Havaí: Investigações Criminais S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224139.mp4', 'http://timg.bdta.pro/images/d7f73c90e2a59c573e4e070b66dc0788.jpg'),
(80227, 5524, 'NCIS Havaí: Investigações Criminais S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224140.mp4', 'http://timg.bdta.pro/images/fa842d31c0483b35b58d78f7d8f2cff5.jpg'),
(80228, 5524, 'NCIS Havaí: Investigações Criminais S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224141.mp4', 'http://timg.bdta.pro/images/c843919553b65a09e7cd3734431a8612.jpg'),
(80229, 5524, 'NCIS Havaí: Investigações Criminais S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224142.mp4', 'http://timg.bdta.pro/images/5de86425533b7fc7f30a6b45d831a405.jpg'),
(80230, 5525, 'NCIS Havaí: Investigações Criminais S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dUr9EX8CRBQAfZrcR68eLeKjlRj.jpg'),
(80231, 5525, 'NCIS Havaí: Investigações Criminais S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/IBGZl7X9atWj86cDryGEnMGPqg.jpg'),
(80232, 5525, 'NCIS Havaí: Investigações Criminais S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fd2uqxqI7HAQJAE9uOp85hWUsNt.jpg'),
(80233, 5525, 'NCIS Havaí: Investigações Criminais S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eCB6VwMy6c6vLpew1xlQuutMDE3.jpg'),
(80234, 5525, 'NCIS Havaí: Investigações Criminais S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xDgJQvdrF4HiFR3PA2utSyZQD0O.jpg'),
(80235, 5525, 'NCIS Havaí: Investigações Criminais S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2XvtndOtJDy6mA9XPi3ha8VdrQi.jpg'),
(80236, 5525, 'NCIS Havaí: Investigações Criminais S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nN8pjaCUcjuXpaJWHZMHhkM30In.jpg'),
(80237, 5525, 'NCIS Havaí: Investigações Criminais S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2EJMz06pvSW6DRLp3N2u8y5NFVJ.jpg'),
(80238, 5525, 'NCIS Havaí: Investigações Criminais S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gidHUvyvkAoQ906VckdjUrpdrFA.jpg'),
(80239, 5525, 'NCIS Havaí: Investigações Criminais S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/olV5xLJB5IWlK4RTe43AQxYf2ux.jpg'),
(80240, 5525, 'NCIS Havaí: Investigações Criminais S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aMVgjDRGMsIj5nKWOREqwBBNly2.jpg'),
(80241, 5525, 'NCIS Havaí: Investigações Criminais S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yK5Garx2r7Gf4ZZ7NZQjuOiF918.jpg'),
(80242, 5525, 'NCIS Havaí: Investigações Criminais S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWIehIjbVcdoEPM6uDx7A5b3KmN.jpg'),
(80243, 5525, 'NCIS Havaí: Investigações Criminais S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/isgRBATfcuLUF37vbiC5xDI6Rrp.jpg'),
(80244, 5525, 'NCIS Havaí: Investigações Criminais S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/teUgIHftTneGMvnXrWEziaPKR0L.jpg'),
(80245, 5525, 'NCIS Havaí: Investigações Criminais S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j0SqMokwWkB5TNZhdcv52N6B4Ra.jpg'),
(80246, 5525, 'NCIS Havaí: Investigações Criminais S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1992cC3CqJrup8XrBQpFir2mpT.jpg'),
(80247, 5525, 'NCIS Havaí: Investigações Criminais S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCKM0FiX5bWChRad0uYzrQha8XT.jpg'),
(80248, 5525, 'NCIS Havaí: Investigações Criminais S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/opATbuRZJSn1X3NbdNQRRzfjyDv.jpg'),
(80249, 5525, 'NCIS Havaí: Investigações Criminais S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AvpaNU3SCAfWLJWdtHWHagIGoSx.jpg'),
(80250, 5525, 'NCIS Havaí: Investigações Criminais S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2h6c2zQTPR064iL15PPxGPd0ntq.jpg'),
(80251, 5525, 'NCIS Havaí: Investigações Criminais S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eneZdowVv6ovUjnEljm9Vf0Ozcn.jpg'),
(80252, 5526, 'NCIS Havaí: Investigações Criminais S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/383720.mp4', 'http://gstaticontent.com/images/f755e8de69879da25247f1730db74543.jpg'),
(80253, 5526, 'NCIS Havaí: Investigações Criminais S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/383721.mp4', 'http://gstaticontent.com/images/f755e8de69879da25247f1730db74543.jpg'),
(80254, 5526, 'NCIS Havaí: Investigações Criminais S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/383722.mp4', 'http://gstaticontent.com/images/f755e8de69879da25247f1730db74543.jpg'),
(80255, 5526, 'NCIS Havaí: Investigações Criminais S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/383723.mp4', 'http://gstaticontent.com/images/f755e8de69879da25247f1730db74543.jpg'),
(80256, 5526, 'NCIS Havaí: Investigações Criminais S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/383724.mp4', 'http://gstaticontent.com/images/f755e8de69879da25247f1730db74543.jpg'),
(80257, 5526, 'NCIS Havaí: Investigações Criminais S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/383725.mp4', 'http://gstaticontent.com/images/f755e8de69879da25247f1730db74543.jpg'),
(80258, 5526, 'NCIS Havaí: Investigações Criminais S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/383726.mp4', 'http://gstaticontent.com/images/f755e8de69879da25247f1730db74543.jpg'),
(80259, 5526, 'NCIS Havaí: Investigações Criminais S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/383727.mp4', 'http://gstaticontent.com/images/f755e8de69879da25247f1730db74543.jpg'),
(80260, 5526, 'NCIS Havaí: Investigações Criminais S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/383728.mp4', 'http://gstaticontent.com/images/f755e8de69879da25247f1730db74543.jpg'),
(80261, 5526, 'NCIS Havaí: Investigações Criminais S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/383729.mp4', 'http://gstaticontent.com/images/f755e8de69879da25247f1730db74543.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(80262, 5527, 'Os Queridinhos de Byron Bay S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178332.mp4', 'http://gstaticontent.com/images/9940e022b4daf7e0208e1942cbf2d41a.jpg'),
(80263, 5527, 'Os Queridinhos de Byron Bay S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178333.mp4', 'http://gstaticontent.com/images/9940e022b4daf7e0208e1942cbf2d41a.jpg'),
(80264, 5527, 'Os Queridinhos de Byron Bay S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178334.mp4', 'http://gstaticontent.com/images/9940e022b4daf7e0208e1942cbf2d41a.jpg'),
(80265, 5527, 'Os Queridinhos de Byron Bay S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178335.mp4', 'http://gstaticontent.com/images/9940e022b4daf7e0208e1942cbf2d41a.jpg'),
(80266, 5527, 'Os Queridinhos de Byron Bay S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178336.mp4', 'http://gstaticontent.com/images/9940e022b4daf7e0208e1942cbf2d41a.jpg'),
(80267, 5527, 'Os Queridinhos de Byron Bay S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178337.mp4', 'http://gstaticontent.com/images/9940e022b4daf7e0208e1942cbf2d41a.jpg'),
(80268, 5527, 'Os Queridinhos de Byron Bay S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178338.mp4', 'http://gstaticontent.com/images/9940e022b4daf7e0208e1942cbf2d41a.jpg'),
(80269, 5527, 'Os Queridinhos de Byron Bay S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178339.mp4', 'http://gstaticontent.com/images/9940e022b4daf7e0208e1942cbf2d41a.jpg'),
(80270, 5528, 'Os Últimos Dias de Ptolemy Grey S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176072.mp4', 'http://timg.bdta.pro/images/907e5f4311e98abe19077c20ac96281f.jpg'),
(80271, 5528, 'Os Últimos Dias de Ptolemy Grey S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176073.mp4', 'http://timg.bdta.pro/images/88cee554965ad6f10b1b21c7c36eb2cd.jpg'),
(80272, 5528, 'Os Últimos Dias de Ptolemy Grey S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176074.mp4', 'http://timg.bdta.pro/images/3cce94a8ad30a941da4adfb489bf995c.jpg'),
(80273, 5528, 'Os Últimos Dias de Ptolemy Grey S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176075.mp4', 'http://timg.bdta.pro/images/b1eca39a2e9c574b39afea3dec0af563.jpg'),
(80274, 5528, 'Os Últimos Dias de Ptolemy Grey S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176076.mp4', 'http://timg.bdta.pro/images/2f2f9dbe9d9c0d07d1cbc382d6648e37.jpg'),
(80275, 5528, 'Os Últimos Dias de Ptolemy Grey S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176077.mp4', 'http://timg.bdta.pro/images/7f2d57510769f997548f72c12f264d0c.jpg'),
(80276, 5529, 'Pam & Tommy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178324.mp4', 'http://timg.bdta.pro/images/7555ed777ae67f77b630218410ea7450.jpg'),
(80277, 5529, 'Pam & Tommy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178325.mp4', 'http://timg.bdta.pro/images/d85648ec3e2c752b58e858e82df27a2b.jpg'),
(80278, 5529, 'Pam & Tommy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178326.mp4', 'http://timg.bdta.pro/images/f83e9449231efcb14c57d881d47d300f.jpg'),
(80279, 5529, 'Pam & Tommy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178327.mp4', 'http://timg.bdta.pro/images/0a882acdc1db7413953e92c37df1bdcd.jpg'),
(80280, 5529, 'Pam & Tommy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178328.mp4', 'http://timg.bdta.pro/images/9d8dc765f0ae325dc9be4ea69a503610.jpg'),
(80281, 5529, 'Pam & Tommy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178329.mp4', 'http://timg.bdta.pro/images/82d46e09c41301040d77e80181bc17ab.jpg'),
(80282, 5529, 'Pam & Tommy S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178330.mp4', 'http://timg.bdta.pro/images/c572257f633d75e5ae69ee3e8ac051ec.jpg'),
(80283, 5529, 'Pam & Tommy S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178331.mp4', 'http://timg.bdta.pro/images/ec972e6c8a8d439530e3e8948e519697.jpg'),
(80284, 5530, 'Star Trek: Prodigy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203057.mp4', 'http://timg.bdta.pro/images/621daf4586daf4158a7d001c24ec464f.jpg'),
(80285, 5530, 'Star Trek: Prodigy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203058.mp4', 'http://gstaticontent.com/images/915b1267215e7db8dfad01b6e7fe8a98.jpg'),
(80286, 5530, 'Star Trek: Prodigy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203059.mp4', 'http://timg.bdta.pro/images/a5e1084c4e343bfe4cb7db4af4273113.jpg'),
(80287, 5530, 'Star Trek: Prodigy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203060.mp4', 'http://timg.bdta.pro/images/cc05af3f74e4cfca48ca572dd8ceb01b.jpg'),
(80288, 5530, 'Star Trek: Prodigy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203061.mp4', 'http://timg.bdta.pro/images/9778610240ae2b84c2a0e2bfda3f72de.jpg'),
(80289, 5530, 'Star Trek: Prodigy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203062.mp4', 'http://timg.bdta.pro/images/cd4d5e2675ed77ac3b514b8133c9d98f.jpg'),
(80290, 5530, 'Star Trek: Prodigy S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203063.mp4', 'http://timg.bdta.pro/images/a31a785b9500a7d11e9ecd59bf7ada02.jpg'),
(80291, 5530, 'Star Trek: Prodigy S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203064.mp4', 'http://timg.bdta.pro/images/4d6e1a588ea2d1fff036ff05b49530ec.jpg'),
(80292, 5530, 'Star Trek: Prodigy S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203065.mp4', 'http://timg.bdta.pro/images/1b5ccae29635f71395e5a92bdd10a837.jpg'),
(80293, 5530, 'Star Trek: Prodigy S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vyxhxX8FEiwPI8judxd9pig8dwj.jpg'),
(80294, 5530, 'Star Trek: Prodigy S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/smw35oXsO7O7QcbxkSiWOYuoImL.jpg'),
(80295, 5530, 'Star Trek: Prodigy S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cBobaCdU73v15RK75rAsu5otxFA.jpg'),
(80296, 5530, 'Star Trek: Prodigy S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qHngIISihWFyeUvfdRRI6tvYksH.jpg'),
(80297, 5530, 'Star Trek: Prodigy S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/203070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wDz5l4I9l2VBxTsPK4aIA7ZwVWh.jpg'),
(80298, 5530, 'Star Trek: Prodigy S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/203071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zvWkQkxcQZUA5AmEzuziTKGDKmE.jpg'),
(80299, 5530, 'Star Trek: Prodigy S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/203072.mp4', 'http://image.tmdb.org/t/p/w1280/D9PxgRcpTri171vF2eDmS82Mtw.jpg'),
(80300, 5530, 'Star Trek: Prodigy S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/203073.mp4', 'http://image.tmdb.org/t/p/w1280/wDyRKxpk7oKbhv3PikbTpQFTDcu.jpg'),
(80301, 5530, 'Star Trek: Prodigy S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/203074.mp4', 'http://image.tmdb.org/t/p/w1280/5ymyryUQ7pMC82BtupqFzyWXoVg.jpg'),
(80302, 5531, 'Star Trek: Prodigy S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/401387.mp4', 'http://gstaticontent.com/images/915b1267215e7db8dfad01b6e7fe8a98.jpg'),
(80303, 5531, 'Star Trek: Prodigy S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/401388.mp4', 'http://gstaticontent.com/images/915b1267215e7db8dfad01b6e7fe8a98.jpg'),
(80304, 5531, 'Star Trek: Prodigy S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/401389.mp4', 'http://gstaticontent.com/images/915b1267215e7db8dfad01b6e7fe8a98.jpg'),
(80305, 5531, 'Star Trek: Prodigy S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/401390.mp4', 'http://gstaticontent.com/images/915b1267215e7db8dfad01b6e7fe8a98.jpg'),
(80306, 5531, 'Star Trek: Prodigy S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/401391.mp4', 'http://gstaticontent.com/images/915b1267215e7db8dfad01b6e7fe8a98.jpg'),
(80307, 5531, 'Star Trek: Prodigy S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/401392.mp4', 'http://gstaticontent.com/images/915b1267215e7db8dfad01b6e7fe8a98.jpg'),
(80308, 5531, 'Star Trek: Prodigy S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/401393.mp4', 'http://gstaticontent.com/images/915b1267215e7db8dfad01b6e7fe8a98.jpg'),
(80309, 5531, 'Star Trek: Prodigy S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/401394.mp4', 'http://gstaticontent.com/images/915b1267215e7db8dfad01b6e7fe8a98.jpg'),
(80310, 5531, 'Star Trek: Prodigy S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/401395.mp4', 'http://gstaticontent.com/images/915b1267215e7db8dfad01b6e7fe8a98.jpg'),
(80311, 5531, 'Star Trek: Prodigy S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/401396.mp4', 'http://gstaticontent.com/images/915b1267215e7db8dfad01b6e7fe8a98.jpg'),
(80312, 5531, 'Star Trek: Prodigy S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/401397.mp4', 'http://gstaticontent.com/images/915b1267215e7db8dfad01b6e7fe8a98.jpg'),
(80313, 5531, 'Star Trek: Prodigy S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/401398.mp4', 'http://gstaticontent.com/images/915b1267215e7db8dfad01b6e7fe8a98.jpg'),
(80314, 5531, 'Star Trek: Prodigy S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/401399.mp4', 'http://gstaticontent.com/images/915b1267215e7db8dfad01b6e7fe8a98.jpg'),
(80315, 5531, 'Star Trek: Prodigy S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/401400.mp4', 'http://gstaticontent.com/images/915b1267215e7db8dfad01b6e7fe8a98.jpg'),
(80316, 5531, 'Star Trek: Prodigy S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/401401.mp4', 'http://gstaticontent.com/images/915b1267215e7db8dfad01b6e7fe8a98.jpg'),
(80317, 5531, 'Star Trek: Prodigy S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/401402.mp4', 'http://gstaticontent.com/images/915b1267215e7db8dfad01b6e7fe8a98.jpg'),
(80318, 5531, 'Star Trek: Prodigy S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/401403.mp4', 'http://gstaticontent.com/images/915b1267215e7db8dfad01b6e7fe8a98.jpg'),
(80319, 5531, 'Star Trek: Prodigy S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/401404.mp4', 'http://gstaticontent.com/images/915b1267215e7db8dfad01b6e7fe8a98.jpg'),
(80320, 5531, 'Star Trek: Prodigy S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/401405.mp4', 'http://gstaticontent.com/images/915b1267215e7db8dfad01b6e7fe8a98.jpg'),
(80321, 5531, 'Star Trek: Prodigy S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/401406.mp4', 'http://gstaticontent.com/images/915b1267215e7db8dfad01b6e7fe8a98.jpg'),
(80322, 5532, 'Todos Mentem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178318.mp4', 'http://timg.bdta.pro/images/df2802888149efb21f75192a045b7ae9.jpg'),
(80323, 5532, 'Todos Mentem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178319.mp4', 'http://timg.bdta.pro/images/4697f4db74aac2a154b1497f719d5fb7.jpg'),
(80324, 5532, 'Todos Mentem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178320.mp4', 'http://timg.bdta.pro/images/a9d4ded8decf22701709d9f91dcd01fa.jpg'),
(80325, 5532, 'Todos Mentem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178321.mp4', 'http://timg.bdta.pro/images/7add1c7fa4bc4bb6a96e3013b263390a.jpg'),
(80326, 5532, 'Todos Mentem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178322.mp4', 'http://timg.bdta.pro/images/45ce72e21e8e2d008ea2ef81512c4cf3.jpg'),
(80327, 5532, 'Todos Mentem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178323.mp4', 'http://timg.bdta.pro/images/c9d2b5f6661ae6f5f9b7fd3e0e40aa6b.jpg'),
(80328, 5533, 'Vida Após a Morte com Tyler Henry S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178309.mp4', 'http://gstaticontent.com/images/b0f3d9f2b9c28efe925832368fa68868.jpg'),
(80329, 5533, 'Vida Após a Morte com Tyler Henry S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178310.mp4', 'http://gstaticontent.com/images/b0f3d9f2b9c28efe925832368fa68868.jpg'),
(80330, 5533, 'Vida Após a Morte com Tyler Henry S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178311.mp4', 'http://gstaticontent.com/images/b0f3d9f2b9c28efe925832368fa68868.jpg'),
(80331, 5533, 'Vida Após a Morte com Tyler Henry S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178312.mp4', 'http://gstaticontent.com/images/b0f3d9f2b9c28efe925832368fa68868.jpg'),
(80332, 5533, 'Vida Após a Morte com Tyler Henry S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178313.mp4', 'http://gstaticontent.com/images/b0f3d9f2b9c28efe925832368fa68868.jpg'),
(80333, 5533, 'Vida Após a Morte com Tyler Henry S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178314.mp4', 'http://gstaticontent.com/images/b0f3d9f2b9c28efe925832368fa68868.jpg'),
(80334, 5533, 'Vida Após a Morte com Tyler Henry S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178315.mp4', 'http://gstaticontent.com/images/b0f3d9f2b9c28efe925832368fa68868.jpg'),
(80335, 5533, 'Vida Após a Morte com Tyler Henry S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178316.mp4', 'http://gstaticontent.com/images/b0f3d9f2b9c28efe925832368fa68868.jpg'),
(80336, 5533, 'Vida Após a Morte com Tyler Henry S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178317.mp4', 'http://gstaticontent.com/images/b0f3d9f2b9c28efe925832368fa68868.jpg'),
(80337, 5534, '3 Toneladas: Assalto ao Banco Central S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178053.mp4', 'http://gstaticontent.com/images/a9a6b69a517b039f14c1fbe1a11c3faf.jpg'),
(80338, 5534, '3 Toneladas: Assalto ao Banco Central S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178054.mp4', 'http://gstaticontent.com/images/a9a6b69a517b039f14c1fbe1a11c3faf.jpg'),
(80339, 5534, '3 Toneladas: Assalto ao Banco Central S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178055.mp4', 'http://gstaticontent.com/images/a9a6b69a517b039f14c1fbe1a11c3faf.jpg'),
(80340, 5535, 'Dough: O Ganha-Pão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178045.mp4', 'http://timg.bdta.pro/images/d6512317b5d7fb6c53e627d986b4197f.jpg'),
(80341, 5535, 'Dough: O Ganha-Pão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178046.mp4', 'http://timg.bdta.pro/images/1e456c58df5a7d82a8fa1d4ab2b8dfab.jpg'),
(80342, 5535, 'Dough: O Ganha-Pão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178047.mp4', 'http://timg.bdta.pro/images/2bb41a4a3fe684c1e9e52c15b973dec5.jpg'),
(80343, 5535, 'Dough: O Ganha-Pão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178048.mp4', 'http://timg.bdta.pro/images/5cabce9f96f35a05727b8dd752e0e2bb.jpg'),
(80344, 5535, 'Dough: O Ganha-Pão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178049.mp4', 'http://timg.bdta.pro/images/cffe6b0c174b118ae832fdbaf660e2be.jpg'),
(80345, 5535, 'Dough: O Ganha-Pão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178050.mp4', 'http://timg.bdta.pro/images/6eb08e8a28298cc72bb4ee6fb1b262f9.jpg'),
(80346, 5535, 'Dough: O Ganha-Pão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178051.mp4', 'http://timg.bdta.pro/images/250d2282868388e9b3a65bbd934bd6bf.jpg'),
(80347, 5535, 'Dough: O Ganha-Pão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178052.mp4', 'http://timg.bdta.pro/images/da282cdd97870df05d39c4d55f0d65d3.jpg'),
(80348, 5536, 'É o Amor: Família Camargo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178040.mp4', 'http://gstaticontent.com/images/d4e8979774c9a8dad3875d24425521f5.jpg'),
(80349, 5536, 'É o Amor: Família Camargo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178041.mp4', 'http://gstaticontent.com/images/d4e8979774c9a8dad3875d24425521f5.jpg'),
(80350, 5536, 'É o Amor: Família Camargo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178042.mp4', 'http://gstaticontent.com/images/d4e8979774c9a8dad3875d24425521f5.jpg'),
(80351, 5536, 'É o Amor: Família Camargo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178043.mp4', 'http://gstaticontent.com/images/d4e8979774c9a8dad3875d24425521f5.jpg'),
(80352, 5536, 'É o Amor: Família Camargo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178044.mp4', 'http://gstaticontent.com/images/d4e8979774c9a8dad3875d24425521f5.jpg'),
(80353, 5537, 'Faz-me Rir S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178034.mp4', 'http://timg.bdta.pro/images/4ac70b322ed5ecec75750bf9b3d1184a.jpg'),
(80354, 5537, 'Faz-me Rir S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178035.mp4', 'http://timg.bdta.pro/images/ffed9e8e7a65bb4b8f7276b14a00b2e0.jpg'),
(80355, 5537, 'Faz-me Rir S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178036.mp4', 'http://timg.bdta.pro/images/0ad7e14a3b4b06d18921c2986812e32b.jpg'),
(80356, 5537, 'Faz-me Rir S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178037.mp4', 'http://timg.bdta.pro/images/39ea46034ab3ce29e00f4fece4e363cf.jpg'),
(80357, 5537, 'Faz-me Rir S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178038.mp4', 'http://timg.bdta.pro/images/e4f482c97608be295325efe72394fe9c.jpg'),
(80358, 5537, 'Faz-me Rir S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178039.mp4', 'http://timg.bdta.pro/images/dab70bce9df87ddd7dec7588f76f90d5.jpg'),
(80359, 5538, 'How I Met Your Father S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223626.mp4', 'http://timg.bdta.pro/images/776d8e8707121c5ec316b72363f79749.jpg'),
(80360, 5538, 'How I Met Your Father S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223627.mp4', 'http://timg.bdta.pro/images/9c9f99df688bd055436086a46b75d962.jpg'),
(80361, 5538, 'How I Met Your Father S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223628.mp4', 'http://timg.bdta.pro/images/350497933d43f0835828ee265c76116f.jpg'),
(80362, 5538, 'How I Met Your Father S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223629.mp4', 'http://timg.bdta.pro/images/b0300bcf3d2e828664776fcb92d27a35.jpg'),
(80363, 5538, 'How I Met Your Father S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223630.mp4', 'http://timg.bdta.pro/images/0537135c25f52e126b1f5aa6a0a23ef6.jpg'),
(80364, 5538, 'How I Met Your Father S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223631.mp4', 'http://timg.bdta.pro/images/2a39fc095a2057dac1e45d4128e2fa94.jpg'),
(80365, 5538, 'How I Met Your Father S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223632.mp4', 'http://timg.bdta.pro/images/a91399d45b8159c231f48865f5d42e0e.jpg'),
(80366, 5538, 'How I Met Your Father S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223633.mp4', 'http://timg.bdta.pro/images/e3b881c35237820c83b1810b4571a1d4.jpg'),
(80367, 5538, 'How I Met Your Father S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223634.mp4', 'http://timg.bdta.pro/images/74746c91ec5132fe4b30a25cb4ad0813.jpg'),
(80368, 5538, 'How I Met Your Father S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223635.mp4', 'http://timg.bdta.pro/images/56cbf16fee7b4a99265a70a4279d99d0.jpg'),
(80369, 5539, 'How I Met Your Father S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223636.mp4', 'http://image.tmdb.org/t/p/w1280/8uW3c5MvCdQTu1bVKuWAf1TCwnb.jpg'),
(80370, 5539, 'How I Met Your Father S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223637.mp4', 'http://image.tmdb.org/t/p/w1280/2bqaWygVQCb1e2YVchjmkVfyCMz.jpg'),
(80371, 5539, 'How I Met Your Father S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223638.mp4', 'http://image.tmdb.org/t/p/w1280/rIyX4qbZrwi9HZ6HGZyeiI8upBO.jpg'),
(80372, 5539, 'How I Met Your Father S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223639.mp4', 'http://image.tmdb.org/t/p/w1280/8OMNXugYzw40lW4vUhiN22JZfaL.jpg'),
(80373, 5539, 'How I Met Your Father S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223640.mp4', 'http://image.tmdb.org/t/p/w1280/4Na1rDy0sI77L4ud5dQimrg8u94.jpg'),
(80374, 5539, 'How I Met Your Father S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223641.mp4', 'http://image.tmdb.org/t/p/w1280/sqn862xAxnDozx63HAMgU7PPP1t.jpg'),
(80375, 5539, 'How I Met Your Father S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223642.mp4', 'http://image.tmdb.org/t/p/w1280/h0yxbXS5tMcVpNpMJxwfbsmU8SI.jpg'),
(80376, 5539, 'How I Met Your Father S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223643.mp4', 'http://image.tmdb.org/t/p/w1280/vkVaGA8gShw2NB2JYUvj1Qiq5Bo.jpg'),
(80377, 5539, 'How I Met Your Father S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223644.mp4', 'http://image.tmdb.org/t/p/w1280/p44aDrBIjFd84jlhrprZgKuZ07A.jpg'),
(80378, 5539, 'How I Met Your Father S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223645.mp4', 'http://image.tmdb.org/t/p/w1280/hsxgPXKJN7PGBzIY5EEZQK7UUJE.jpg'),
(80379, 5539, 'How I Met Your Father S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223646.mp4', 'http://image.tmdb.org/t/p/w1280/8XpkBdk49ez5NSOp3sy1LX4wIgO.jpg'),
(80380, 5539, 'How I Met Your Father S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223647.mp4', 'http://image.tmdb.org/t/p/w1280/1uBmk3mUac0Xy0r1XMANmH3XKdP.jpg'),
(80381, 5539, 'How I Met Your Father S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/223648.mp4', 'http://image.tmdb.org/t/p/w1280/z5cS7irPG79K2XG332cQFBsve2u.jpg'),
(80382, 5539, 'How I Met Your Father S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/223649.mp4', 'http://image.tmdb.org/t/p/w1280/6xLs0uKW819w01BDOejebg7o8Qw.jpg'),
(80383, 5539, 'How I Met Your Father S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/223650.mp4', 'http://gstaticontent.com/images/374daf47afca034f22ce9e719759a39f.jpg'),
(80384, 5539, 'How I Met Your Father S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/223651.mp4', 'http://image.tmdb.org/t/p/w1280/4KRv09Sy3enhRqZhqh8JHYysdlT.jpg'),
(80385, 5539, 'How I Met Your Father S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/223652.mp4', 'http://image.tmdb.org/t/p/w1280/3gjPtE7hWJ29wvd5dFcqxM2sPYP.jpg'),
(80386, 5539, 'How I Met Your Father S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/223653.mp4', 'http://image.tmdb.org/t/p/w1280/tMhHYgXV8tiYpgTovyiQ5fqj76X.jpg'),
(80387, 5539, 'How I Met Your Father S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/223654.mp4', 'http://image.tmdb.org/t/p/w1280/epnRPEPQ8W4ivezyTn5fYtqqObp.jpg'),
(80388, 5539, 'How I Met Your Father S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/223655.mp4', 'http://image.tmdb.org/t/p/w1280/xpbJqoIzIyQwYGYJTwqmNXI6Zyv.jpg'),
(80389, 5540, 'Isso é um Bolo? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178026.mp4', 'http://timg.bdta.pro/images/86dc9617e437b95e9f35f7e3c2631686.jpg'),
(80390, 5540, 'Isso é um Bolo? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178027.mp4', 'http://timg.bdta.pro/images/2ca1cbaab26c4be83b945407d132ae2a.jpg'),
(80391, 5540, 'Isso é um Bolo? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178028.mp4', 'http://timg.bdta.pro/images/c28034b57aca13d6ae509c53471a6e9c.jpg'),
(80392, 5540, 'Isso é um Bolo? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178029.mp4', 'http://timg.bdta.pro/images/24d240540d08ed0ddc1cc006326693ad.jpg'),
(80393, 5540, 'Isso é um Bolo? S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178030.mp4', 'http://timg.bdta.pro/images/b6b7d89c120868b9a0061491c4b2005a.jpg'),
(80394, 5540, 'Isso é um Bolo? S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178031.mp4', 'http://timg.bdta.pro/images/d67c30b40feea6488aaf80dd70c0c949.jpg'),
(80395, 5540, 'Isso é um Bolo? S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178032.mp4', 'http://timg.bdta.pro/images/f9adb28f1851211053226993308e9cfb.jpg'),
(80396, 5540, 'Isso é um Bolo? S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178033.mp4', 'http://timg.bdta.pro/images/3d9026a875b56afbf4800d241a7f161b.jpg'),
(80397, 5541, 'Isso é um Bolo? S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/888188.mp4', 'http://gstaticontent.com/images/35c6f71ff7d57078ff023b50eafa4a0a.jpg'),
(80398, 5541, 'Isso é um Bolo? S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/888189.mp4', 'http://gstaticontent.com/images/35c6f71ff7d57078ff023b50eafa4a0a.jpg'),
(80399, 5541, 'Isso é um Bolo? S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/888190.mp4', 'http://gstaticontent.com/images/35c6f71ff7d57078ff023b50eafa4a0a.jpg'),
(80400, 5541, 'Isso é um Bolo? S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/888191.mp4', 'http://gstaticontent.com/images/35c6f71ff7d57078ff023b50eafa4a0a.jpg'),
(80401, 5541, 'Isso é um Bolo? S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/888192.mp4', 'http://gstaticontent.com/images/35c6f71ff7d57078ff023b50eafa4a0a.jpg'),
(80402, 5541, 'Isso é um Bolo? S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/888193.mp4', 'http://gstaticontent.com/images/35c6f71ff7d57078ff023b50eafa4a0a.jpg'),
(80403, 5541, 'Isso é um Bolo? S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/888194.mp4', 'http://gstaticontent.com/images/35c6f71ff7d57078ff023b50eafa4a0a.jpg'),
(80404, 5541, 'Isso é um Bolo? S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/888195.mp4', 'http://gstaticontent.com/images/35c6f71ff7d57078ff023b50eafa4a0a.jpg'),
(80405, 5542, 'Isso é um Bolo? S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/888196.mp4', 'http://gstaticontent.com/images/35c6f71ff7d57078ff023b50eafa4a0a.jpg'),
(80406, 5542, 'Isso é um Bolo? S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/888197.mp4', 'http://gstaticontent.com/images/35c6f71ff7d57078ff023b50eafa4a0a.jpg'),
(80407, 5542, 'Isso é um Bolo? S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/888198.mp4', 'http://gstaticontent.com/images/35c6f71ff7d57078ff023b50eafa4a0a.jpg'),
(80408, 5542, 'Isso é um Bolo? S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/888199.mp4', 'http://gstaticontent.com/images/35c6f71ff7d57078ff023b50eafa4a0a.jpg'),
(80409, 5542, 'Isso é um Bolo? S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/888200.mp4', 'http://gstaticontent.com/images/35c6f71ff7d57078ff023b50eafa4a0a.jpg'),
(80410, 5542, 'Isso é um Bolo? S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/888201.mp4', 'http://gstaticontent.com/images/35c6f71ff7d57078ff023b50eafa4a0a.jpg'),
(80411, 5542, 'Isso é um Bolo? S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/888202.mp4', 'http://gstaticontent.com/images/35c6f71ff7d57078ff023b50eafa4a0a.jpg'),
(80412, 5542, 'Isso é um Bolo? S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/888203.mp4', 'http://gstaticontent.com/images/35c6f71ff7d57078ff023b50eafa4a0a.jpg'),
(80413, 5543, 'Monstros da Cracóvia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178018.mp4', 'http://timg.bdta.pro/images/ca2652ffcfd1f3b3a67eb24fe6f7ede8.jpg'),
(80414, 5543, 'Monstros da Cracóvia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178019.mp4', 'http://timg.bdta.pro/images/724d34cfc777e4796c61079ea3903132.jpg'),
(80415, 5543, 'Monstros da Cracóvia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178020.mp4', 'http://timg.bdta.pro/images/bd8d276f23d33ac60e65440e4e9c8dd4.jpg'),
(80416, 5543, 'Monstros da Cracóvia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178021.mp4', 'http://timg.bdta.pro/images/0bd1466d6ee5891f5e4382b4d76e3d4b.jpg'),
(80417, 5543, 'Monstros da Cracóvia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178022.mp4', 'http://timg.bdta.pro/images/1a5835947ca4f897e08914be3c3b5900.jpg'),
(80418, 5543, 'Monstros da Cracóvia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178023.mp4', 'http://timg.bdta.pro/images/2a13e7f126182631fa350101b571dee0.jpg'),
(80419, 5543, 'Monstros da Cracóvia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178024.mp4', 'http://timg.bdta.pro/images/71626db96af8af03f0a1126d9ccce18f.jpg'),
(80420, 5543, 'Monstros da Cracóvia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178025.mp4', 'http://timg.bdta.pro/images/027f77366b1fae6ac40dba5e85ba1959.jpg'),
(80421, 5544, 'O Turista S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178012.mp4', 'http://timg.bdta.pro/images/d14aa7f125f6d2614abb3409913acae1.jpg'),
(80422, 5544, 'O Turista S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178013.mp4', 'http://timg.bdta.pro/images/5e8900925f3daf1df31b2ad6c769d4fd.jpg'),
(80423, 5544, 'O Turista S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178014.mp4', 'http://timg.bdta.pro/images/0ecf2aff4fcff5ab3354357e21102b2f.jpg'),
(80424, 5544, 'O Turista S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178015.mp4', 'http://timg.bdta.pro/images/a1c9b008b2ef6ab38b5c145a1e121d7a.jpg'),
(80425, 5544, 'O Turista S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178016.mp4', 'http://timg.bdta.pro/images/a624ae2689b5d7d68c5a932c49a6ea3b.jpg'),
(80426, 5544, 'O Turista S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178017.mp4', 'http://timg.bdta.pro/images/b7ca9269f862310cb2afeb8f9b6c853c.jpg'),
(80427, 5545, 'O Turista S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/291950.mp4', 'http://gstaticontent.com/images/0dc3efbeac3ff0f415eca03151697aa5.jpg'),
(80428, 5545, 'O Turista S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/291951.mp4', 'http://gstaticontent.com/images/0dc3efbeac3ff0f415eca03151697aa5.jpg'),
(80429, 5545, 'O Turista S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/291952.mp4', 'http://gstaticontent.com/images/0dc3efbeac3ff0f415eca03151697aa5.jpg'),
(80430, 5545, 'O Turista S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/291953.mp4', 'http://gstaticontent.com/images/0dc3efbeac3ff0f415eca03151697aa5.jpg'),
(80431, 5545, 'O Turista S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/291954.mp4', 'http://gstaticontent.com/images/0dc3efbeac3ff0f415eca03151697aa5.jpg'),
(80432, 5545, 'O Turista S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/291955.mp4', 'http://gstaticontent.com/images/0dc3efbeac3ff0f415eca03151697aa5.jpg'),
(80433, 5546, 'Onda de 100 Pés S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230641.mp4', 'http://timg.bdta.pro/images/dc0ea13b59caacbf5066181593ad24ba.jpg'),
(80434, 5546, 'Onda de 100 Pés S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230642.mp4', 'http://timg.bdta.pro/images/ed754800aa8a937d06bc2c14056a3e2d.jpg'),
(80435, 5546, 'Onda de 100 Pés S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230643.mp4', 'http://timg.bdta.pro/images/fe95448322594f3fdce71f54d1c9e704.jpg'),
(80436, 5546, 'Onda de 100 Pés S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230644.mp4', 'http://timg.bdta.pro/images/9fd52bdf20e6d4c59d4c0bdbde23f378.jpg'),
(80437, 5546, 'Onda de 100 Pés S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230645.mp4', 'http://timg.bdta.pro/images/d1061b3f197558cbc64907cd9ae06be1.jpg'),
(80438, 5546, 'Onda de 100 Pés S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230646.mp4', 'http://timg.bdta.pro/images/51c3dc968432025d0be07421baada5e2.jpg'),
(80439, 5547, 'Onda de 100 Pés S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSrgga4W66ZSuAVhoWVVjnr1UZY.jpg'),
(80440, 5547, 'Onda de 100 Pés S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ktFpQ3QbpqN4meTWH7IJimaoQvW.jpg'),
(80441, 5547, 'Onda de 100 Pés S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oKTG5gyHCsvIC9xtGRuAR4Gt6fK.jpg'),
(80442, 5547, 'Onda de 100 Pés S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h49EtyZzsqqUGGKzzabdtKzAYT7.jpg'),
(80443, 5547, 'Onda de 100 Pés S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2hnu4jrBkGjZUzBuhGMNaxgPdVb.jpg'),
(80444, 5547, 'Onda de 100 Pés S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2UBEWojNL1V2CV0YgcKxN97jCFj.jpg'),
(80445, 5548, 'Pisando Fundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178002.mp4', 'http://timg.bdta.pro/images/9fc4be0190731d1e2f1549e8721e1cbf.jpg'),
(80446, 5548, 'Pisando Fundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178003.mp4', 'http://timg.bdta.pro/images/fa2e8e6106537ddc22904e73ec1d2d2e.jpg'),
(80447, 5548, 'Pisando Fundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178004.mp4', 'http://timg.bdta.pro/images/343479e754260fc0506f29f7ffbd3836.jpg'),
(80448, 5548, 'Pisando Fundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178005.mp4', 'http://timg.bdta.pro/images/4d419dc529455eae042ad4bcdb7732ef.jpg'),
(80449, 5548, 'Pisando Fundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178006.mp4', 'http://timg.bdta.pro/images/1923ab2039165f89412203afdd900334.jpg'),
(80450, 5548, 'Pisando Fundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178007.mp4', 'http://timg.bdta.pro/images/69ca8b1a8e30a0398769f94e2b834d25.jpg'),
(80451, 5548, 'Pisando Fundo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178008.mp4', 'http://timg.bdta.pro/images/e2866f26dd53a28cc713ae053d01502f.jpg'),
(80452, 5548, 'Pisando Fundo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178009.mp4', 'http://timg.bdta.pro/images/f0428162bea5eeb831777250767e390e.jpg'),
(80453, 5548, 'Pisando Fundo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178010.mp4', 'http://timg.bdta.pro/images/10007b0a01164b37917e356579009837.jpg'),
(80454, 5548, 'Pisando Fundo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178011.mp4', 'http://timg.bdta.pro/images/03e5fccad04b88765dd98eb43b1cbac4.jpg'),
(80455, 5549, 'Putin: A Russian Spy Story [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177999.mp4', 'http://timg.bdta.pro/images/f3381efaab68230c1803902b3a4424c2.jpg'),
(80456, 5549, 'Putin: A Russian Spy Story [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178000.mp4', 'http://timg.bdta.pro/images/bdf8bda14a5a32b8c2814fb93a5bd106.jpg'),
(80457, 5549, 'Putin: A Russian Spy Story [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178001.mp4', 'http://timg.bdta.pro/images/f2c3b086d60bbed01d0900fba28a351d.jpg'),
(80458, 5550, 'Recursos Humanos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215372.mp4', 'http://timg.bdta.pro/images/0fd4d99c65845a1f5b5ca34581420168.jpg'),
(80459, 5550, 'Recursos Humanos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215373.mp4', 'http://timg.bdta.pro/images/a977f2ac90f154f5a819a117b12eceb7.jpg'),
(80460, 5550, 'Recursos Humanos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215374.mp4', 'http://timg.bdta.pro/images/73f1672c7bd25d86387ecd4e695e5810.jpg'),
(80461, 5550, 'Recursos Humanos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215375.mp4', 'http://timg.bdta.pro/images/ee09110f2f9bb5e3ab573dff5144852e.jpg'),
(80462, 5550, 'Recursos Humanos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215376.mp4', 'http://timg.bdta.pro/images/315ec403fc6756e469577429113ea8f2.jpg'),
(80463, 5550, 'Recursos Humanos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215377.mp4', 'http://timg.bdta.pro/images/a4e9017b7f467c2c21ccc6f7a4ac2598.jpg'),
(80464, 5550, 'Recursos Humanos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215378.mp4', 'http://timg.bdta.pro/images/40fecfe31e486136e42dc7c3b1cd8b0d.jpg'),
(80465, 5550, 'Recursos Humanos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215379.mp4', 'http://timg.bdta.pro/images/3a9260e733700264b324f0f364d3ea39.jpg'),
(80466, 5550, 'Recursos Humanos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215380.mp4', 'http://timg.bdta.pro/images/b91603699e0e074bf30107380d375d09.jpg'),
(80467, 5550, 'Recursos Humanos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215381.mp4', 'http://timg.bdta.pro/images/29c808276a1844b8a53ec38adacbf7d3.jpg'),
(80468, 5551, 'Recursos Humanos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215382.mp4', 'http://gstaticontent.com/images/4a6b21e8366bf7b2affe25ab97e7ebd2.jpg'),
(80469, 5551, 'Recursos Humanos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215383.mp4', 'http://gstaticontent.com/images/4a6b21e8366bf7b2affe25ab97e7ebd2.jpg'),
(80470, 5551, 'Recursos Humanos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215384.mp4', 'http://gstaticontent.com/images/4a6b21e8366bf7b2affe25ab97e7ebd2.jpg'),
(80471, 5551, 'Recursos Humanos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215385.mp4', 'http://gstaticontent.com/images/4a6b21e8366bf7b2affe25ab97e7ebd2.jpg'),
(80472, 5551, 'Recursos Humanos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215386.mp4', 'http://gstaticontent.com/images/4a6b21e8366bf7b2affe25ab97e7ebd2.jpg'),
(80473, 5551, 'Recursos Humanos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215387.mp4', 'http://gstaticontent.com/images/4a6b21e8366bf7b2affe25ab97e7ebd2.jpg'),
(80474, 5551, 'Recursos Humanos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215388.mp4', 'http://gstaticontent.com/images/4a6b21e8366bf7b2affe25ab97e7ebd2.jpg'),
(80475, 5551, 'Recursos Humanos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215389.mp4', 'http://gstaticontent.com/images/4a6b21e8366bf7b2affe25ab97e7ebd2.jpg'),
(80476, 5551, 'Recursos Humanos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215390.mp4', 'http://gstaticontent.com/images/4a6b21e8366bf7b2affe25ab97e7ebd2.jpg'),
(80477, 5551, 'Recursos Humanos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215391.mp4', 'http://gstaticontent.com/images/4a6b21e8366bf7b2affe25ab97e7ebd2.jpg'),
(80478, 5552, 'Terra à Venda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177991.mp4', 'http://timg.bdta.pro/images/21f93e1b80360593812a8da784ec0b33.jpg'),
(80479, 5552, 'Terra à Venda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177992.mp4', 'http://timg.bdta.pro/images/a0a50e54c39ceff9e60c7da4ab144dec.jpg'),
(80480, 5552, 'Terra à Venda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177993.mp4', 'http://timg.bdta.pro/images/f9da9e13ccf197ff5e639a39c91a8824.jpg'),
(80481, 5552, 'Terra à Venda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177994.mp4', 'http://timg.bdta.pro/images/a35cc1f61346e8902323e9de1ab4ca79.jpg'),
(80482, 5552, 'Terra à Venda S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177995.mp4', 'http://timg.bdta.pro/images/843152a9e74afc854be91fe389a34034.jpg'),
(80483, 5552, 'Terra à Venda S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177996.mp4', 'http://timg.bdta.pro/images/a461745113f4447e7903cc9b58093da8.jpg'),
(80484, 5552, 'Terra à Venda S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177997.mp4', 'http://timg.bdta.pro/images/ad9a909a97eecb9cc759d30af95a57a5.jpg'),
(80485, 5552, 'Terra à Venda S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177998.mp4', 'http://timg.bdta.pro/images/38dbfff206c521e03532b4518dcddcaa.jpg'),
(80486, 5553, 'Vai! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177979.mp4', 'http://gstaticontent.com/images/ba4b7a319921a3acafa52f0a7688b061.jpg'),
(80487, 5553, 'Vai! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177980.mp4', 'http://gstaticontent.com/images/ba4b7a319921a3acafa52f0a7688b061.jpg'),
(80488, 5553, 'Vai! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177981.mp4', 'http://gstaticontent.com/images/ba4b7a319921a3acafa52f0a7688b061.jpg'),
(80489, 5553, 'Vai! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177982.mp4', 'http://gstaticontent.com/images/ba4b7a319921a3acafa52f0a7688b061.jpg'),
(80490, 5553, 'Vai! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177983.mp4', 'http://gstaticontent.com/images/ba4b7a319921a3acafa52f0a7688b061.jpg'),
(80491, 5553, 'Vai! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177984.mp4', 'http://gstaticontent.com/images/ba4b7a319921a3acafa52f0a7688b061.jpg'),
(80492, 5553, 'Vai! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177985.mp4', 'http://gstaticontent.com/images/ba4b7a319921a3acafa52f0a7688b061.jpg'),
(80493, 5553, 'Vai! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177986.mp4', 'http://gstaticontent.com/images/ba4b7a319921a3acafa52f0a7688b061.jpg'),
(80494, 5553, 'Vai! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177987.mp4', 'http://gstaticontent.com/images/ba4b7a319921a3acafa52f0a7688b061.jpg'),
(80495, 5553, 'Vai! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177988.mp4', 'http://gstaticontent.com/images/ba4b7a319921a3acafa52f0a7688b061.jpg'),
(80496, 5553, 'Vai! S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177989.mp4', 'http://gstaticontent.com/images/ba4b7a319921a3acafa52f0a7688b061.jpg'),
(80497, 5553, 'Vai! S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177990.mp4', 'http://gstaticontent.com/images/ba4b7a319921a3acafa52f0a7688b061.jpg'),
(80498, 5554, 'Young Famous e African S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217646.mp4', 'http://gstaticontent.com/images/6b9ddd42ab52c1208bf64c12d492e836.jpg'),
(80499, 5554, 'Young Famous e African S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217647.mp4', 'http://gstaticontent.com/images/6b9ddd42ab52c1208bf64c12d492e836.jpg'),
(80500, 5554, 'Young Famous e African S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217648.mp4', 'http://gstaticontent.com/images/6b9ddd42ab52c1208bf64c12d492e836.jpg'),
(80501, 5554, 'Young Famous e African S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217649.mp4', 'http://gstaticontent.com/images/6b9ddd42ab52c1208bf64c12d492e836.jpg'),
(80502, 5554, 'Young Famous e African S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217650.mp4', 'http://gstaticontent.com/images/6b9ddd42ab52c1208bf64c12d492e836.jpg'),
(80503, 5554, 'Young Famous e African S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217651.mp4', 'http://gstaticontent.com/images/6b9ddd42ab52c1208bf64c12d492e836.jpg'),
(80504, 5554, 'Young Famous e African S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217652.mp4', 'http://gstaticontent.com/images/6b9ddd42ab52c1208bf64c12d492e836.jpg'),
(80505, 5555, 'Young Famous e African S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dsLkALGGLqW9Aysnf7dEt3gg8bd.jpg'),
(80506, 5555, 'Young Famous e African S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ardgC6vMAe15ZTrW5Dv0CPXOm75.jpg'),
(80507, 5555, 'Young Famous e African S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kmZZgDmRXcxwQLgzNcPIWD1Iiwh.jpg'),
(80508, 5555, 'Young Famous e African S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/do4NGrQjJeqEeWcvfYUlxqcQsnO.jpg'),
(80509, 5555, 'Young Famous e African S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k5sJbSQXQoqg1g5qiisLO4m6UTo.jpg'),
(80510, 5555, 'Young Famous e African S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kgFpv7iAgif1YYqZkXeN6TsQmOv.jpg'),
(80511, 5555, 'Young Famous e African S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/29Dav7e8QhPzOapAe1oZ415l8np.jpg'),
(80512, 5555, 'Young Famous e African S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bMiWfZw8hS7LR4sl7SRZxgQNy0b.jpg'),
(80513, 5555, 'Young Famous e African S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8prK8VAkhLtraRv7jFc3L8e6XMs.jpg'),
(80514, 5556, 'Young Famous e African S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/667090.mp4', 'http://gstaticontent.com/images/6b9ddd42ab52c1208bf64c12d492e836.jpg'),
(80515, 5556, 'Young Famous e African S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/667091.mp4', 'http://gstaticontent.com/images/6b9ddd42ab52c1208bf64c12d492e836.jpg'),
(80516, 5556, 'Young Famous e African S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/667092.mp4', 'http://gstaticontent.com/images/6b9ddd42ab52c1208bf64c12d492e836.jpg'),
(80517, 5556, 'Young Famous e African S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/667093.mp4', 'http://gstaticontent.com/images/6b9ddd42ab52c1208bf64c12d492e836.jpg'),
(80518, 5556, 'Young Famous e African S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/667094.mp4', 'http://gstaticontent.com/images/6b9ddd42ab52c1208bf64c12d492e836.jpg'),
(80519, 5556, 'Young Famous e African S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/667095.mp4', 'http://gstaticontent.com/images/6b9ddd42ab52c1208bf64c12d492e836.jpg'),
(80520, 5556, 'Young Famous e African S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/667096.mp4', 'http://gstaticontent.com/images/6b9ddd42ab52c1208bf64c12d492e836.jpg'),
(80521, 5556, 'Young Famous e African S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/667097.mp4', 'http://gstaticontent.com/images/6b9ddd42ab52c1208bf64c12d492e836.jpg'),
(80522, 5557, 'A Ilha da Fantasia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215552.mp4', 'http://timg.bdta.pro/images/88cf15b26eb8dbe65bf678785f00d151.jpg'),
(80523, 5557, 'A Ilha da Fantasia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215553.mp4', 'http://timg.bdta.pro/images/960ab5a6fe895aef274ec6ff4fe89595.jpg'),
(80524, 5557, 'A Ilha da Fantasia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215554.mp4', 'http://timg.bdta.pro/images/f20453e4cb6182999c59d438db390b4e.jpg'),
(80525, 5557, 'A Ilha da Fantasia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215555.mp4', 'http://timg.bdta.pro/images/44284d7941fa03fa5d8f0578f73568d6.jpg'),
(80526, 5557, 'A Ilha da Fantasia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215556.mp4', 'http://timg.bdta.pro/images/769d9ea93e7cfe1b1c1fe4c34bc1c497.jpg'),
(80527, 5557, 'A Ilha da Fantasia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215557.mp4', 'http://timg.bdta.pro/images/57f07ede8e216e4cc4d0cc36b6e857e0.jpg'),
(80528, 5557, 'A Ilha da Fantasia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215558.mp4', 'http://timg.bdta.pro/images/4d0f72155c31143249600d44c0ee851c.jpg'),
(80529, 5557, 'A Ilha da Fantasia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215559.mp4', 'http://timg.bdta.pro/images/6dc05b6adf6de53cfb81db178c122376.jpg'),
(80530, 5557, 'A Ilha da Fantasia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215560.mp4', 'http://timg.bdta.pro/images/d2e62350a504f2f770798d24842183c9.jpg'),
(80531, 5557, 'A Ilha da Fantasia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215561.mp4', 'http://timg.bdta.pro/images/4a75bef0fa4edf9f2f5b2eb7b8842e9f.jpg'),
(80532, 5558, 'A Ilha da Fantasia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gVE5aly0zkdqwPd4YNdLnuQ0OiX.jpg'),
(80533, 5558, 'A Ilha da Fantasia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ofOYfQ7Ht98a8EZEFvODO67qWnN.jpg'),
(80534, 5558, 'A Ilha da Fantasia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/793aNLn0MuOrEL4mHPSCbAzhmwx.jpg'),
(80535, 5558, 'A Ilha da Fantasia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/czMj2v4L35EFUwENDpLtB0deoqh.jpg'),
(80536, 5558, 'A Ilha da Fantasia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6flmL6H5oBT9tNHJyMZmdDv3Tzg.jpg'),
(80537, 5558, 'A Ilha da Fantasia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/di0q1iJQ2LEFrIfMLCjXpmxiNN9.jpg'),
(80538, 5558, 'A Ilha da Fantasia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/avxM06Z0TcUtNl5A83Vw00xUgG9.jpg'),
(80539, 5558, 'A Ilha da Fantasia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5xKWM2MkNM8DWKUmkvszrXfDQSl.jpg'),
(80540, 5558, 'A Ilha da Fantasia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5ph2cfkgriYISoY0lFhWLvMsaA.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(80541, 5558, 'A Ilha da Fantasia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8BNs0ujHh5WwVwRXFSnu6KREAY1.jpg'),
(80542, 5558, 'A Ilha da Fantasia S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q2hm2zaPtOfmVJCnWp4oqfQMKJu.jpg'),
(80543, 5558, 'A Ilha da Fantasia S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dtzqqd4YonYh8rL3Zl6ulkrjLhl.jpg'),
(80544, 5558, 'A Ilha da Fantasia S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hCKXeiTNdGay5zfAGocR13i5t6k.jpg'),
(80545, 5559, 'A Maldição de Akakor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177706.mp4', 'http://timg.bdta.pro/images/369664305ae5dec258d661332e9b2565.jpg'),
(80546, 5559, 'A Maldição de Akakor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177707.mp4', 'http://timg.bdta.pro/images/2f0085bd75d892f6bc9a702f95f1f32e.jpg'),
(80547, 5559, 'A Maldição de Akakor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177708.mp4', 'http://timg.bdta.pro/images/6f004b7435d58b33d44235fa676725f8.jpg'),
(80548, 5559, 'A Maldição de Akakor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177709.mp4', 'http://timg.bdta.pro/images/29e39a75ddbc078ea78007f3a7f2f303.jpg'),
(80549, 5559, 'A Maldição de Akakor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177710.mp4', 'http://timg.bdta.pro/images/471a81c12b3e5921d5976c5a9ac7e5c3.jpg'),
(80550, 5559, 'A Maldição de Akakor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177711.mp4', 'http://gstaticontent.com/images/c86d40d3ce84388fbe3a49b39f885d1b.jpg'),
(80551, 5560, 'All American S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215461.mp4', 'http://timg.bdta.pro/images/e95c7bd4953f0ad08931d4d25444608a.jpg'),
(80552, 5560, 'All American S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215462.mp4', 'http://timg.bdta.pro/images/054d43c143699ad764ba091fc74be16c.jpg'),
(80553, 5560, 'All American S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215463.mp4', 'http://timg.bdta.pro/images/d2fb2bc467d7553d642f095c8d756681.jpg'),
(80554, 5560, 'All American S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215464.mp4', 'http://timg.bdta.pro/images/d18c594b42c2a09d7509575ee1cbc674.jpg'),
(80555, 5560, 'All American S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215465.mp4', 'http://timg.bdta.pro/images/20f73d79c2c12f093841e381839d0727.jpg'),
(80556, 5560, 'All American S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215466.mp4', 'http://timg.bdta.pro/images/02c4eb7415a038837009507104f5071f.jpg'),
(80557, 5560, 'All American S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215467.mp4', 'http://timg.bdta.pro/images/bc410a9ab735235dfa2f5aeb095625ab.jpg'),
(80558, 5560, 'All American S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215468.mp4', 'http://timg.bdta.pro/images/d52bba53f9115b7543fb2ec717be6d84.jpg'),
(80559, 5560, 'All American S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215469.mp4', 'http://timg.bdta.pro/images/0ee52ac2d733a0f4c82dcbf0fec3172c.jpg'),
(80560, 5560, 'All American S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215470.mp4', 'http://timg.bdta.pro/images/07776b1c4602b74fc0003f53090eddb4.jpg'),
(80561, 5560, 'All American S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215471.mp4', 'http://timg.bdta.pro/images/12d94c0ae32c08c369fb9b720b66668a.jpg'),
(80562, 5560, 'All American S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215472.mp4', 'http://timg.bdta.pro/images/10b4e882f8f94e3ad674a308bb8a79d0.jpg'),
(80563, 5560, 'All American S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215473.mp4', 'http://timg.bdta.pro/images/96d4f437b7f0f21dc03e8000dead752e.jpg'),
(80564, 5560, 'All American S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215474.mp4', 'http://timg.bdta.pro/images/d3c49251e7b1406f096fc492cc5e08d1.jpg'),
(80565, 5560, 'All American S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215475.mp4', 'http://timg.bdta.pro/images/a52b209649d7455a2672bd7cfefa930e.jpg'),
(80566, 5560, 'All American S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215476.mp4', 'http://timg.bdta.pro/images/8eb0f85f41aaa173ab32f848a843aa9e.jpg'),
(80567, 5561, 'All American S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215477.mp4', 'http://timg.bdta.pro/images/0dae60a49cd16773414bd602ff6dd690.jpg'),
(80568, 5561, 'All American S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215478.mp4', 'http://timg.bdta.pro/images/a84d0ac6d6216ea8509e9c8509535572.jpg'),
(80569, 5561, 'All American S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215479.mp4', 'http://timg.bdta.pro/images/b5cc59be70cbb93f3f07be98ceba5cec.jpg'),
(80570, 5561, 'All American S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215480.mp4', 'http://timg.bdta.pro/images/514655e4861512239bda3471a5b9ec7b.jpg'),
(80571, 5561, 'All American S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215481.mp4', 'http://timg.bdta.pro/images/db6fcb2839723cb3b3ad97eba8b97e86.jpg'),
(80572, 5561, 'All American S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215482.mp4', 'http://timg.bdta.pro/images/deda40f88efbd954cd780c6c23851608.jpg'),
(80573, 5561, 'All American S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215483.mp4', 'http://timg.bdta.pro/images/5d09cbfdaa2b1e303b079b01a8ad1b52.jpg'),
(80574, 5561, 'All American S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215484.mp4', 'http://timg.bdta.pro/images/b44d6d2bbae1dea509df6abc81cab94e.jpg'),
(80575, 5561, 'All American S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215485.mp4', 'http://timg.bdta.pro/images/46635edbc117c6acc03f480da6562ae2.jpg'),
(80576, 5561, 'All American S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215486.mp4', 'http://timg.bdta.pro/images/7586197e1f685219f06e4b16c65c8f11.jpg'),
(80577, 5561, 'All American S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215487.mp4', 'http://timg.bdta.pro/images/7fcaa3f54d2793a944e93eb362360eaa.jpg'),
(80578, 5561, 'All American S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215488.mp4', 'http://timg.bdta.pro/images/eeb81b169f47b9fbb8e2be3d385e653b.jpg'),
(80579, 5561, 'All American S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215489.mp4', 'http://timg.bdta.pro/images/a7c96dba30cb73378e9b1e2bb62e3900.jpg'),
(80580, 5561, 'All American S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215490.mp4', 'http://timg.bdta.pro/images/699fa06a61df6bb782db271d798af8be.jpg'),
(80581, 5561, 'All American S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215491.mp4', 'http://timg.bdta.pro/images/2f165537c1fd61b8d84d37e67d9eb529.jpg'),
(80582, 5561, 'All American S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215492.mp4', 'http://timg.bdta.pro/images/9128be2f03899a029c82e032e8d85bda.jpg'),
(80583, 5562, 'All American S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215493.mp4', 'http://timg.bdta.pro/images/3c566c5d395589f100344a45f9246a78.jpg'),
(80584, 5562, 'All American S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215494.mp4', 'http://timg.bdta.pro/images/0e1473e260d6682b02ffd801f4372fa1.jpg'),
(80585, 5562, 'All American S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215495.mp4', 'http://timg.bdta.pro/images/334407b5ad470c50e0a04b915f01e56e.jpg'),
(80586, 5562, 'All American S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215496.mp4', 'http://timg.bdta.pro/images/a5ca998c1b36dc875aed59c80695f72c.jpg'),
(80587, 5562, 'All American S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215497.mp4', 'http://timg.bdta.pro/images/136658009880370171653a1f1eddc291.jpg'),
(80588, 5562, 'All American S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215498.mp4', 'http://timg.bdta.pro/images/60515dc62887ddd5b4a56c778e83430d.jpg'),
(80589, 5562, 'All American S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215499.mp4', 'http://timg.bdta.pro/images/acb780f9b917fb68f3ba77dc0b7a9f52.jpg'),
(80590, 5562, 'All American S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215500.mp4', 'http://timg.bdta.pro/images/ae73dcfc5505e3a4d92169a865d8c4b5.jpg'),
(80591, 5562, 'All American S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215501.mp4', 'http://timg.bdta.pro/images/0e16a105ef8cab7ea851bf7c5563de9b.jpg'),
(80592, 5562, 'All American S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215502.mp4', 'http://timg.bdta.pro/images/59477625b47e87f06f48219bcbf55ee7.jpg'),
(80593, 5562, 'All American S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215503.mp4', 'http://timg.bdta.pro/images/4b741d890afdc6655dae0195c7baa64d.jpg'),
(80594, 5562, 'All American S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215504.mp4', 'http://timg.bdta.pro/images/8441ddfe02ac9652b086e6d0ce5112ca.jpg'),
(80595, 5562, 'All American S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215505.mp4', 'http://timg.bdta.pro/images/d2ae77c2b65d133897311728de862c27.jpg'),
(80596, 5562, 'All American S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215506.mp4', 'http://timg.bdta.pro/images/7004bdb7b06b239232745b2849dc99f6.jpg'),
(80597, 5562, 'All American S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215507.mp4', 'http://timg.bdta.pro/images/cb4536aa90a4bec020adb90bd315ca5a.jpg'),
(80598, 5562, 'All American S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215508.mp4', 'http://timg.bdta.pro/images/4f5589a0f3b99c0e400914fc5ea2f7c4.jpg'),
(80599, 5562, 'All American S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/215509.mp4', 'http://timg.bdta.pro/images/a1a8d423ebfa0f139c2c2120fe134eaf.jpg'),
(80600, 5562, 'All American S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/215510.mp4', 'http://timg.bdta.pro/images/aad4297127f21dacb1548fd1f3019d10.jpg'),
(80601, 5562, 'All American S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/215511.mp4', 'http://timg.bdta.pro/images/2bc5c099ef58449a590ff8600ef9df72.jpg'),
(80602, 5563, 'All American S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215512.mp4', 'http://timg.bdta.pro/images/cbc91da24763080029698ed9805fdea7.jpg'),
(80603, 5563, 'All American S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215513.mp4', 'http://timg.bdta.pro/images/7bb23aa78a2d6ce0dfecb50d445d8008.jpg'),
(80604, 5563, 'All American S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215514.mp4', 'http://timg.bdta.pro/images/be6d75d61a8d376a1762bc6122ce55a7.jpg'),
(80605, 5563, 'All American S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215515.mp4', 'http://timg.bdta.pro/images/e858f98fb3abd0a77499e4318a33fe0b.jpg'),
(80606, 5563, 'All American S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215516.mp4', 'http://timg.bdta.pro/images/f68de043fdcb1f684e52453e5a6f4ffc.jpg'),
(80607, 5563, 'All American S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215517.mp4', 'http://timg.bdta.pro/images/b2464b15db71a1f3df568edadd9f44c4.jpg'),
(80608, 5563, 'All American S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215518.mp4', 'http://timg.bdta.pro/images/8173778d5aa7502d22673441bcf3324e.jpg'),
(80609, 5563, 'All American S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215519.mp4', 'http://timg.bdta.pro/images/905f59fd0aa55464b5294bf5a9aa276c.jpg'),
(80610, 5563, 'All American S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215520.mp4', 'http://timg.bdta.pro/images/cbd1bdd57eb0e0887486cb8626cca3c0.jpg'),
(80611, 5563, 'All American S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215521.mp4', 'http://gstaticontent.com/images/b3c9046d40ac137bb6b306037fe5c790.jpg'),
(80612, 5563, 'All American S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215522.mp4', 'http://gstaticontent.com/images/b3c9046d40ac137bb6b306037fe5c790.jpg'),
(80613, 5563, 'All American S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215523.mp4', 'http://timg.bdta.pro/images/2a5d83c855f42efdf40b396eeec3af16.jpg'),
(80614, 5563, 'All American S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215524.mp4', 'http://timg.bdta.pro/images/3839628cd7ac15abbd28898616a6fd0f.jpg'),
(80615, 5563, 'All American S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215525.mp4', 'http://timg.bdta.pro/images/05de3324fd1c26230674911dbb1aaba1.jpg'),
(80616, 5563, 'All American S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215526.mp4', 'http://gstaticontent.com/images/b3c9046d40ac137bb6b306037fe5c790.jpg'),
(80617, 5563, 'All American S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215527.mp4', 'http://timg.bdta.pro/images/9d191ce3374e244c3e1dccaf4870d9f2.jpg'),
(80618, 5563, 'All American S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/215528.mp4', 'http://timg.bdta.pro/images/d76e9a9e477d597b87cb34f077eaceae.jpg'),
(80619, 5563, 'All American S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/215529.mp4', 'http://timg.bdta.pro/images/813bbb9f86f787632cb0e9cedc993914.jpg'),
(80620, 5563, 'All American S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/215530.mp4', 'http://timg.bdta.pro/images/9ce2bfdab6f117668c07a6fe4aa8746b.jpg'),
(80621, 5563, 'All American S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/215531.mp4', 'http://timg.bdta.pro/images/8e15a3439b15faf00ea208146540796f.jpg'),
(80622, 5564, 'All American S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215532.mp4', 'http://image.tmdb.org/t/p/w1280/gXcEkVUbWajRx2DfzsbjfQouSik.jpg'),
(80623, 5564, 'All American S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7OvPlcbKWmTt8sLscMmofF5N6VU.jpg'),
(80624, 5564, 'All American S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7F3szoOcNzWUJ4W1RL1lgy0cEL.jpg'),
(80625, 5564, 'All American S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215535.mp4', 'http://image.tmdb.org/t/p/w1280/kihMCOoixdJpxff1xwZ3AbSRL0J.jpg'),
(80626, 5564, 'All American S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215536.mp4', 'http://image.tmdb.org/t/p/w1280/o7YVR0QrK6WZd7a8BxgPUMUnxfg.jpg'),
(80627, 5564, 'All American S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d2c8580KHfio0BM1Xo2kgLvG4WQ.jpg'),
(80628, 5564, 'All American S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t5EWsHsiuxYrL7NK4GlruRSFgWK.jpg'),
(80629, 5564, 'All American S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215539.mp4', 'http://image.tmdb.org/t/p/w1280/oCQki1zrtP4KB93NrRKobV7BEf3.jpg'),
(80630, 5564, 'All American S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215540.mp4', 'http://image.tmdb.org/t/p/w1280/vMUDZ5fuK1OCuLn586som50LqDx.jpg'),
(80631, 5564, 'All American S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215541.mp4', 'http://image.tmdb.org/t/p/w1280/ux6R0DFMkQDqupclny7MmUeHgvr.jpg'),
(80632, 5564, 'All American S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215542.mp4', 'http://image.tmdb.org/t/p/w1280/1aKmJ1baYAxoaF1nHsHPJextvMm.jpg'),
(80633, 5564, 'All American S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215543.mp4', 'http://image.tmdb.org/t/p/w1280/6rnDMFr3ZVc3K95pVqrXIfpY1cE.jpg'),
(80634, 5564, 'All American S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215544.mp4', 'http://image.tmdb.org/t/p/w1280/iuhHPZaGHAVSY8E6TEGTrk2FJFx.jpg'),
(80635, 5564, 'All American S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215545.mp4', 'http://image.tmdb.org/t/p/w1280/yIVPgztbSULKHJDbsq3i2B372T0.jpg'),
(80636, 5564, 'All American S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215546.mp4', 'http://image.tmdb.org/t/p/w1280/7dJ8merupDJ9Y21mpHqdkcWj7w8.jpg'),
(80637, 5564, 'All American S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215547.mp4', 'http://image.tmdb.org/t/p/w1280/aFqKW498Q5cUff0aP6eCRV69649.jpg'),
(80638, 5564, 'All American S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/215548.mp4', 'http://image.tmdb.org/t/p/w1280/xNGsM5FqXzvbnHkVGTYGXU2VaTa.jpg'),
(80639, 5564, 'All American S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/215549.mp4', 'http://gstaticontent.com/images/b3c9046d40ac137bb6b306037fe5c790.jpg'),
(80640, 5564, 'All American S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/215550.mp4', 'http://gstaticontent.com/images/b3c9046d40ac137bb6b306037fe5c790.jpg'),
(80641, 5564, 'All American S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/215551.mp4', 'http://gstaticontent.com/images/b3c9046d40ac137bb6b306037fe5c790.jpg'),
(80642, 5565, 'Amsterdam S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177696.mp4', 'http://timg.bdta.pro/images/b28a7eb7afd9b3d28763472a04d2534d.jpg'),
(80643, 5565, 'Amsterdam S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177697.mp4', 'http://timg.bdta.pro/images/8d91cefdf9c9873d1a3319e183a0419c.jpg'),
(80644, 5565, 'Amsterdam S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177698.mp4', 'http://timg.bdta.pro/images/8076faaa6724427874ae7b50e2d1cf46.jpg'),
(80645, 5565, 'Amsterdam S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177699.mp4', 'http://timg.bdta.pro/images/131b20e33311b19ec74cc23cdaadc3a6.jpg'),
(80646, 5565, 'Amsterdam S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177700.mp4', 'http://timg.bdta.pro/images/c56cadb49610c2bbf8409a64d23ffce3.jpg'),
(80647, 5565, 'Amsterdam S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177701.mp4', 'http://timg.bdta.pro/images/f6bdf0e3efe2bb7969566eab6b0f9f6d.jpg'),
(80648, 5565, 'Amsterdam S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177702.mp4', 'http://timg.bdta.pro/images/e831961bd486e5cb9fadad7caa637193.jpg'),
(80649, 5565, 'Amsterdam S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177703.mp4', 'http://timg.bdta.pro/images/97b44c8dd196c2a770c7374eb00dae79.jpg'),
(80650, 5565, 'Amsterdam S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177704.mp4', 'http://timg.bdta.pro/images/8ab4a84433cae240df2e16b72b131b7b.jpg'),
(80651, 5565, 'Amsterdam S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177705.mp4', 'http://timg.bdta.pro/images/b789c0c338fce0f0f18ce5a6a4b49165.jpg'),
(80652, 5566, 'Bulgasal: Almas Imortais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177680.mp4', 'http://timg.bdta.pro/images/c52066611a3d38376b21d75642c96559.jpg'),
(80653, 5566, 'Bulgasal: Almas Imortais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177681.mp4', 'http://timg.bdta.pro/images/8116ca919450a281290f8a6cea35f97e.jpg'),
(80654, 5566, 'Bulgasal: Almas Imortais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177682.mp4', 'http://timg.bdta.pro/images/7034f51811dffc7ad4f7c918084f3c9b.jpg'),
(80655, 5566, 'Bulgasal: Almas Imortais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177683.mp4', 'http://timg.bdta.pro/images/4626268b6fd6273e7d6c9d541b29edc0.jpg'),
(80656, 5566, 'Bulgasal: Almas Imortais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177684.mp4', 'http://timg.bdta.pro/images/3990a16659e67c32209b355505a56b67.jpg'),
(80657, 5566, 'Bulgasal: Almas Imortais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177685.mp4', 'http://timg.bdta.pro/images/0301d02d3801179bda2fe17eca7e768e.jpg'),
(80658, 5566, 'Bulgasal: Almas Imortais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177686.mp4', 'http://timg.bdta.pro/images/173f7a3293b3d7597f336637ced59840.jpg'),
(80659, 5566, 'Bulgasal: Almas Imortais S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177687.mp4', 'http://timg.bdta.pro/images/798c1b5b41ce05998cc8e4fef9f7d1da.jpg'),
(80660, 5566, 'Bulgasal: Almas Imortais S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177688.mp4', 'http://timg.bdta.pro/images/0d1f48db9218fdd3071efe530397ef01.jpg'),
(80661, 5566, 'Bulgasal: Almas Imortais S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177689.mp4', 'http://timg.bdta.pro/images/416c60f1acd0e2a9e57e941d900925f0.jpg'),
(80662, 5566, 'Bulgasal: Almas Imortais S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177690.mp4', 'http://timg.bdta.pro/images/f90d5cb85e58bb8c3b57112086545439.jpg'),
(80663, 5566, 'Bulgasal: Almas Imortais S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177691.mp4', 'http://timg.bdta.pro/images/85e83349b022da6c7fc59172c40662c2.jpg'),
(80664, 5566, 'Bulgasal: Almas Imortais S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/177692.mp4', 'http://timg.bdta.pro/images/0240ca72174dd9c30990b781106f4d6e.jpg'),
(80665, 5566, 'Bulgasal: Almas Imortais S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/177693.mp4', 'http://timg.bdta.pro/images/7a310b3d91a8377b4edbe50c2ee7772d.jpg'),
(80666, 5566, 'Bulgasal: Almas Imortais S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/177694.mp4', 'http://timg.bdta.pro/images/7adb8a6952c803b347e16bc1522e1f05.jpg'),
(80667, 5566, 'Bulgasal: Almas Imortais S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/177695.mp4', 'http://timg.bdta.pro/images/1f864e01662fb363e10e7a30de26f971.jpg'),
(80668, 5567, 'Cocoricó S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176681.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80669, 5567, 'Cocoricó S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176682.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80670, 5567, 'Cocoricó S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176683.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80671, 5567, 'Cocoricó S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176684.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80672, 5567, 'Cocoricó S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176685.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80673, 5567, 'Cocoricó S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176686.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80674, 5567, 'Cocoricó S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176687.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80675, 5567, 'Cocoricó S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176688.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80676, 5567, 'Cocoricó S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176689.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80677, 5567, 'Cocoricó S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176690.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80678, 5567, 'Cocoricó S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/176691.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80679, 5567, 'Cocoricó S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/176692.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80680, 5567, 'Cocoricó S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/176693.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80681, 5567, 'Cocoricó S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/176694.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80682, 5567, 'Cocoricó S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/176695.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80683, 5567, 'Cocoricó S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/176696.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80684, 5567, 'Cocoricó S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/176697.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80685, 5567, 'Cocoricó S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/176698.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80686, 5567, 'Cocoricó S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/176699.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80687, 5567, 'Cocoricó S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/176700.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80688, 5567, 'Cocoricó S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/176701.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80689, 5567, 'Cocoricó S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/176702.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80690, 5567, 'Cocoricó S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/176703.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80691, 5567, 'Cocoricó S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/176704.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80692, 5567, 'Cocoricó S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/176705.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80693, 5567, 'Cocoricó S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/176706.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80694, 5567, 'Cocoricó S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/176707.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80695, 5567, 'Cocoricó S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/176708.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80696, 5567, 'Cocoricó S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/176709.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80697, 5567, 'Cocoricó S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/176710.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80698, 5567, 'Cocoricó S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/176711.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80699, 5567, 'Cocoricó S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/176712.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80700, 5567, 'Cocoricó S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/176713.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80701, 5567, 'Cocoricó S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/176714.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80702, 5567, 'Cocoricó S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/176715.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80703, 5567, 'Cocoricó S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/176716.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80704, 5567, 'Cocoricó S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/176717.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80705, 5567, 'Cocoricó S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/176718.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80706, 5567, 'Cocoricó S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/176719.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80707, 5567, 'Cocoricó S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/176720.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80708, 5567, 'Cocoricó S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/176721.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80709, 5567, 'Cocoricó S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/176722.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80710, 5567, 'Cocoricó S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/176723.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80711, 5567, 'Cocoricó S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/176724.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80712, 5567, 'Cocoricó S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/176725.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80713, 5567, 'Cocoricó S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/176726.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80714, 5567, 'Cocoricó S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/176727.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80715, 5567, 'Cocoricó S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/176728.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80716, 5567, 'Cocoricó S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/176729.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80717, 5567, 'Cocoricó S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/176730.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80718, 5567, 'Cocoricó S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/176731.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80719, 5568, 'Cocoricó S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176732.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80720, 5568, 'Cocoricó S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176733.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80721, 5568, 'Cocoricó S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176734.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80722, 5568, 'Cocoricó S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176735.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80723, 5568, 'Cocoricó S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176736.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80724, 5568, 'Cocoricó S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176737.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80725, 5568, 'Cocoricó S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176738.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80726, 5568, 'Cocoricó S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176739.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80727, 5568, 'Cocoricó S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176740.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80728, 5568, 'Cocoricó S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176741.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80729, 5568, 'Cocoricó S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/176742.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80730, 5568, 'Cocoricó S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/176743.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80731, 5568, 'Cocoricó S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/176744.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80732, 5568, 'Cocoricó S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/176745.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80733, 5568, 'Cocoricó S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/176746.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80734, 5568, 'Cocoricó S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/176747.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80735, 5568, 'Cocoricó S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/176748.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80736, 5568, 'Cocoricó S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/176749.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80737, 5568, 'Cocoricó S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/176750.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80738, 5568, 'Cocoricó S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/176751.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80739, 5568, 'Cocoricó S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/176752.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80740, 5568, 'Cocoricó S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/176753.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80741, 5568, 'Cocoricó S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/176754.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80742, 5568, 'Cocoricó S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/176755.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80743, 5568, 'Cocoricó S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/176756.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80744, 5568, 'Cocoricó S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/176757.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80745, 5568, 'Cocoricó S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/176758.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80746, 5568, 'Cocoricó S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/176759.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80747, 5568, 'Cocoricó S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/176760.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80748, 5568, 'Cocoricó S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/176761.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80749, 5568, 'Cocoricó S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/176762.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80750, 5568, 'Cocoricó S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/176763.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80751, 5568, 'Cocoricó S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/176764.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80752, 5568, 'Cocoricó S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/176765.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80753, 5568, 'Cocoricó S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/176766.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80754, 5568, 'Cocoricó S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/176767.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80755, 5568, 'Cocoricó S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/176768.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80756, 5568, 'Cocoricó S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/176769.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80757, 5568, 'Cocoricó S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/176770.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80758, 5568, 'Cocoricó S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/176771.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80759, 5568, 'Cocoricó S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/176772.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80760, 5568, 'Cocoricó S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/176773.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80761, 5568, 'Cocoricó S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/176774.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80762, 5568, 'Cocoricó S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/176775.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80763, 5568, 'Cocoricó S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/176776.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80764, 5568, 'Cocoricó S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/176777.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80765, 5568, 'Cocoricó S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/176778.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80766, 5568, 'Cocoricó S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/176779.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80767, 5568, 'Cocoricó S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/176780.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80768, 5568, 'Cocoricó S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/176781.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80769, 5568, 'Cocoricó S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/176782.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80770, 5568, 'Cocoricó S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/176783.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80771, 5568, 'Cocoricó S02 E53', 'http://sinalprivado.info:80/series/1533784/1533784/176784.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80772, 5568, 'Cocoricó S02 E54', 'http://sinalprivado.info:80/series/1533784/1533784/176785.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80773, 5568, 'Cocoricó S02 E55', 'http://sinalprivado.info:80/series/1533784/1533784/176786.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80774, 5568, 'Cocoricó S02 E56', 'http://sinalprivado.info:80/series/1533784/1533784/176787.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80775, 5568, 'Cocoricó S02 E57', 'http://sinalprivado.info:80/series/1533784/1533784/176788.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80776, 5568, 'Cocoricó S02 E58', 'http://sinalprivado.info:80/series/1533784/1533784/176789.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80777, 5568, 'Cocoricó S02 E59', 'http://sinalprivado.info:80/series/1533784/1533784/176790.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80778, 5568, 'Cocoricó S02 E60', 'http://sinalprivado.info:80/series/1533784/1533784/176791.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80779, 5568, 'Cocoricó S02 E61', 'http://sinalprivado.info:80/series/1533784/1533784/176792.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80780, 5568, 'Cocoricó S02 E62', 'http://sinalprivado.info:80/series/1533784/1533784/176793.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80781, 5568, 'Cocoricó S02 E63', 'http://sinalprivado.info:80/series/1533784/1533784/176794.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80782, 5568, 'Cocoricó S02 E64', 'http://sinalprivado.info:80/series/1533784/1533784/176795.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80783, 5568, 'Cocoricó S02 E65', 'http://sinalprivado.info:80/series/1533784/1533784/176796.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80784, 5568, 'Cocoricó S02 E66', 'http://sinalprivado.info:80/series/1533784/1533784/176797.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80785, 5568, 'Cocoricó S02 E67', 'http://sinalprivado.info:80/series/1533784/1533784/176798.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80786, 5568, 'Cocoricó S02 E68', 'http://sinalprivado.info:80/series/1533784/1533784/176799.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80787, 5568, 'Cocoricó S02 E69', 'http://sinalprivado.info:80/series/1533784/1533784/176800.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80788, 5568, 'Cocoricó S02 E70', 'http://sinalprivado.info:80/series/1533784/1533784/176801.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80789, 5568, 'Cocoricó S02 E71', 'http://sinalprivado.info:80/series/1533784/1533784/176802.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80790, 5568, 'Cocoricó S02 E72', 'http://sinalprivado.info:80/series/1533784/1533784/176803.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80791, 5569, 'Cocoricó S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176804.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80792, 5569, 'Cocoricó S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176805.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80793, 5569, 'Cocoricó S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176806.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80794, 5569, 'Cocoricó S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176807.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80795, 5569, 'Cocoricó S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176808.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80796, 5569, 'Cocoricó S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176809.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80797, 5569, 'Cocoricó S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176810.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80798, 5569, 'Cocoricó S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176811.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80799, 5569, 'Cocoricó S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176812.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80800, 5569, 'Cocoricó S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176813.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80801, 5569, 'Cocoricó S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/176814.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80802, 5569, 'Cocoricó S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/176815.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80803, 5569, 'Cocoricó S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/176816.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80804, 5569, 'Cocoricó S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/176817.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80805, 5569, 'Cocoricó S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/176818.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80806, 5569, 'Cocoricó S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/176819.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80807, 5569, 'Cocoricó S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/176820.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80808, 5569, 'Cocoricó S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/176821.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80809, 5569, 'Cocoricó S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/176822.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80810, 5569, 'Cocoricó S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/176823.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80811, 5569, 'Cocoricó S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/176824.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80812, 5569, 'Cocoricó S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/176825.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80813, 5569, 'Cocoricó S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/176826.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80814, 5570, 'Cocoricó S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176827.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80815, 5570, 'Cocoricó S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176828.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80816, 5570, 'Cocoricó S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176829.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80817, 5570, 'Cocoricó S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176830.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80818, 5570, 'Cocoricó S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176831.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80819, 5570, 'Cocoricó S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176832.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80820, 5570, 'Cocoricó S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176833.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80821, 5570, 'Cocoricó S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176834.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80822, 5570, 'Cocoricó S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176835.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80823, 5570, 'Cocoricó S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176836.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80824, 5570, 'Cocoricó S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/176837.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80825, 5570, 'Cocoricó S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/176838.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80826, 5570, 'Cocoricó S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/176839.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80827, 5570, 'Cocoricó S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/176840.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80828, 5570, 'Cocoricó S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/176841.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80829, 5570, 'Cocoricó S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/176842.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80830, 5570, 'Cocoricó S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/176843.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80831, 5570, 'Cocoricó S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/176844.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(80832, 5570, 'Cocoricó S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/176845.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80833, 5570, 'Cocoricó S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/176846.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80834, 5570, 'Cocoricó S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/176847.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80835, 5570, 'Cocoricó S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/176848.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80836, 5571, 'Cocoricó S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176849.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80837, 5571, 'Cocoricó S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176850.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80838, 5571, 'Cocoricó S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176851.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80839, 5571, 'Cocoricó S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176852.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80840, 5571, 'Cocoricó S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176853.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80841, 5571, 'Cocoricó S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176854.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80842, 5571, 'Cocoricó S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176855.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80843, 5571, 'Cocoricó S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176856.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80844, 5571, 'Cocoricó S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176857.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80845, 5571, 'Cocoricó S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176858.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80846, 5571, 'Cocoricó S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/176859.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80847, 5571, 'Cocoricó S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/176860.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80848, 5571, 'Cocoricó S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/176861.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80849, 5571, 'Cocoricó S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/176862.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80850, 5571, 'Cocoricó S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/176863.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80851, 5571, 'Cocoricó S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/176864.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80852, 5571, 'Cocoricó S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/176865.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80853, 5571, 'Cocoricó S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/176866.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80854, 5571, 'Cocoricó S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/176867.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80855, 5571, 'Cocoricó S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/176868.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80856, 5571, 'Cocoricó S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/176869.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80857, 5571, 'Cocoricó S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/176870.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80858, 5571, 'Cocoricó S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/176871.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80859, 5571, 'Cocoricó S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/176872.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80860, 5571, 'Cocoricó S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/176873.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80861, 5571, 'Cocoricó S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/176874.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80862, 5571, 'Cocoricó S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/176875.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80863, 5572, 'Cocoricó S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176876.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80864, 5572, 'Cocoricó S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176877.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80865, 5572, 'Cocoricó S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176878.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80866, 5572, 'Cocoricó S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176879.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80867, 5572, 'Cocoricó S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176880.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80868, 5572, 'Cocoricó S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176881.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80869, 5572, 'Cocoricó S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176882.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80870, 5572, 'Cocoricó S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176883.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80871, 5572, 'Cocoricó S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176884.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80872, 5572, 'Cocoricó S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176885.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80873, 5572, 'Cocoricó S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/176886.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80874, 5572, 'Cocoricó S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/176887.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80875, 5572, 'Cocoricó S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/176888.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80876, 5572, 'Cocoricó S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/176889.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80877, 5572, 'Cocoricó S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/176890.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80878, 5572, 'Cocoricó S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/176891.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80879, 5572, 'Cocoricó S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/176892.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80880, 5572, 'Cocoricó S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/176893.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80881, 5572, 'Cocoricó S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/176894.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80882, 5572, 'Cocoricó S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/176895.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80883, 5572, 'Cocoricó S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/176896.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80884, 5572, 'Cocoricó S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/176897.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80885, 5572, 'Cocoricó S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/176898.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80886, 5572, 'Cocoricó S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/176899.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80887, 5572, 'Cocoricó S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/176900.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80888, 5572, 'Cocoricó S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/176901.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80889, 5572, 'Cocoricó S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/176902.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80890, 5572, 'Cocoricó S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/176903.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80891, 5572, 'Cocoricó S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/176904.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80892, 5572, 'Cocoricó S06 E30', 'http://sinalprivado.info:80/series/1533784/1533784/176905.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80893, 5572, 'Cocoricó S06 E31', 'http://sinalprivado.info:80/series/1533784/1533784/176906.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80894, 5572, 'Cocoricó S06 E32', 'http://sinalprivado.info:80/series/1533784/1533784/176907.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80895, 5572, 'Cocoricó S06 E33', 'http://sinalprivado.info:80/series/1533784/1533784/176908.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80896, 5572, 'Cocoricó S06 E34', 'http://sinalprivado.info:80/series/1533784/1533784/176909.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80897, 5572, 'Cocoricó S06 E35', 'http://sinalprivado.info:80/series/1533784/1533784/176910.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80898, 5572, 'Cocoricó S06 E36', 'http://sinalprivado.info:80/series/1533784/1533784/176911.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80899, 5572, 'Cocoricó S06 E37', 'http://sinalprivado.info:80/series/1533784/1533784/176912.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80900, 5572, 'Cocoricó S06 E38', 'http://sinalprivado.info:80/series/1533784/1533784/176913.mp4', 'http://gstaticontent.com/images/42edece36adbd4c5d2214d9e1e990954.jpg'),
(80901, 5573, 'Crimes que Viralizaram S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263514.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80902, 5573, 'Crimes que Viralizaram S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263515.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80903, 5573, 'Crimes que Viralizaram S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263516.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80904, 5573, 'Crimes que Viralizaram S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263517.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80905, 5573, 'Crimes que Viralizaram S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263518.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80906, 5573, 'Crimes que Viralizaram S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263519.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80907, 5573, 'Crimes que Viralizaram S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263520.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80908, 5573, 'Crimes que Viralizaram S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263521.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80909, 5573, 'Crimes que Viralizaram S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263522.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80910, 5573, 'Crimes que Viralizaram S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263523.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80911, 5573, 'Crimes que Viralizaram S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263524.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80912, 5573, 'Crimes que Viralizaram S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263525.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80913, 5573, 'Crimes que Viralizaram S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263526.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80914, 5573, 'Crimes que Viralizaram S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263527.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80915, 5573, 'Crimes que Viralizaram S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263528.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80916, 5573, 'Crimes que Viralizaram S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263529.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80917, 5573, 'Crimes que Viralizaram S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/263530.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80918, 5573, 'Crimes que Viralizaram S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/263531.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80919, 5573, 'Crimes que Viralizaram S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/263532.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80920, 5573, 'Crimes que Viralizaram S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/263533.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80921, 5574, 'Crimes que Viralizaram S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263534.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80922, 5574, 'Crimes que Viralizaram S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263535.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80923, 5574, 'Crimes que Viralizaram S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263536.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80924, 5574, 'Crimes que Viralizaram S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263537.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80925, 5574, 'Crimes que Viralizaram S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263538.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80926, 5574, 'Crimes que Viralizaram S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263539.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80927, 5574, 'Crimes que Viralizaram S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263540.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80928, 5574, 'Crimes que Viralizaram S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263541.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80929, 5574, 'Crimes que Viralizaram S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263542.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80930, 5574, 'Crimes que Viralizaram S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263543.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80931, 5574, 'Crimes que Viralizaram S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263544.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80932, 5574, 'Crimes que Viralizaram S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263545.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80933, 5574, 'Crimes que Viralizaram S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263546.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80934, 5574, 'Crimes que Viralizaram S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263547.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80935, 5574, 'Crimes que Viralizaram S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263548.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80936, 5574, 'Crimes que Viralizaram S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263549.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80937, 5574, 'Crimes que Viralizaram S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/263550.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80938, 5575, 'Crimes que Viralizaram S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263551.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80939, 5575, 'Crimes que Viralizaram S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263552.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80940, 5575, 'Crimes que Viralizaram S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263553.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80941, 5575, 'Crimes que Viralizaram S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263554.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80942, 5575, 'Crimes que Viralizaram S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263555.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80943, 5575, 'Crimes que Viralizaram S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263556.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80944, 5575, 'Crimes que Viralizaram S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263557.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80945, 5575, 'Crimes que Viralizaram S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263558.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80946, 5575, 'Crimes que Viralizaram S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263559.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80947, 5575, 'Crimes que Viralizaram S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263560.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80948, 5575, 'Crimes que Viralizaram S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263561.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80949, 5575, 'Crimes que Viralizaram S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263562.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80950, 5576, 'Crimes que Viralizaram S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/806219.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80951, 5576, 'Crimes que Viralizaram S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/806220.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80952, 5576, 'Crimes que Viralizaram S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/806221.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80953, 5576, 'Crimes que Viralizaram S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/806222.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80954, 5576, 'Crimes que Viralizaram S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/806223.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80955, 5576, 'Crimes que Viralizaram S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/806224.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80956, 5576, 'Crimes que Viralizaram S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/806225.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80957, 5576, 'Crimes que Viralizaram S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/806226.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80958, 5576, 'Crimes que Viralizaram S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/806227.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80959, 5576, 'Crimes que Viralizaram S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/806228.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80960, 5576, 'Crimes que Viralizaram S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/806229.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80961, 5576, 'Crimes que Viralizaram S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/806230.mp4', 'http://gstaticontent.com/images/661d346a4f2ef88ecdff39b0d1b0fb95.jpg'),
(80962, 5577, 'Expedição Extrema S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177674.mp4', 'http://timg.bdta.pro/images/52fd4ff6e3a62b85ba2b8663f3d20fd3.jpg'),
(80963, 5577, 'Expedição Extrema S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177675.mp4', 'http://timg.bdta.pro/images/6ae7cff27f1099d630b83320d655f7de.jpg'),
(80964, 5577, 'Expedição Extrema S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177676.mp4', 'http://timg.bdta.pro/images/e32cdf02af3b948a82015137ffaf1f33.jpg'),
(80965, 5577, 'Expedição Extrema S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177677.mp4', 'http://timg.bdta.pro/images/ff7de065a02f38d49f309cbfaea9f619.jpg'),
(80966, 5577, 'Expedição Extrema S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177678.mp4', 'http://timg.bdta.pro/images/b61c5beeb9115a834083305133e39afc.jpg'),
(80967, 5577, 'Expedição Extrema S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177679.mp4', 'http://timg.bdta.pro/images/2256d29dba193452a875a7c5590de183.jpg'),
(80968, 5578, 'Fundamentos do Prazer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177671.mp4', 'http://timg.bdta.pro/images/a08a9c332f2155f2f798c59e3e35c0e3.jpg'),
(80969, 5578, 'Fundamentos do Prazer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177672.mp4', 'http://timg.bdta.pro/images/77ba210c9d870ee13b9fe1963b9e1d2c.jpg'),
(80970, 5578, 'Fundamentos do Prazer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177673.mp4', 'http://timg.bdta.pro/images/63d9ea1d8f60eaf7919dce6dff3d5dff.jpg'),
(80971, 5579, 'Halo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181078.mp4', 'http://timg.bdta.pro/images/796d45e9aa2c36ed1195081e049967a0.jpg'),
(80972, 5579, 'Halo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181079.mp4', 'http://timg.bdta.pro/images/89856c3a0d5bd85cc3bd329c8903848e.jpg'),
(80973, 5579, 'Halo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181080.mp4', 'http://timg.bdta.pro/images/c8cf9c164bf82f76e1099eb8b0e88f88.jpg'),
(80974, 5579, 'Halo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181081.mp4', 'http://timg.bdta.pro/images/2be8690df5bd6f393dfabe66018adfa5.jpg'),
(80975, 5579, 'Halo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181082.mp4', 'http://timg.bdta.pro/images/05458f8d19377a081fa427ae16d4c5da.jpg'),
(80976, 5579, 'Halo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181083.mp4', 'http://timg.bdta.pro/images/14748127e5e4b038d88a1c1330d23e19.jpg'),
(80977, 5579, 'Halo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181084.mp4', 'http://timg.bdta.pro/images/40e49d4fffe20785aba75453d06139e7.jpg'),
(80978, 5579, 'Halo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181085.mp4', 'http://timg.bdta.pro/images/12402a4ea69115c3bea82be3a9d8d445.jpg'),
(80979, 5579, 'Halo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181086.mp4', 'http://timg.bdta.pro/images/0d7a4f1e08fb50e28d26a2215da58673.jpg'),
(80980, 5580, 'Halo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/271177.mp4', 'http://gstaticontent.com/images/13a269813d231d4583c3a50e855c7a32.jpg'),
(80981, 5580, 'Halo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/271178.mp4', 'http://gstaticontent.com/images/13a269813d231d4583c3a50e855c7a32.jpg'),
(80982, 5580, 'Halo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/272881.mp4', 'http://gstaticontent.com/images/13a269813d231d4583c3a50e855c7a32.jpg'),
(80983, 5580, 'Halo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278934.mp4', 'http://gstaticontent.com/images/13a269813d231d4583c3a50e855c7a32.jpg'),
(80984, 5580, 'Halo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/288274.mp4', 'http://gstaticontent.com/images/13a269813d231d4583c3a50e855c7a32.jpg'),
(80985, 5580, 'Halo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/296806.mp4', 'http://gstaticontent.com/images/13a269813d231d4583c3a50e855c7a32.jpg'),
(80986, 5580, 'Halo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/299956.mp4', 'http://gstaticontent.com/images/13a269813d231d4583c3a50e855c7a32.jpg'),
(80987, 5580, 'Halo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/304634.mp4', 'http://gstaticontent.com/images/13a269813d231d4583c3a50e855c7a32.jpg'),
(80988, 5581, 'Jellystone! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177641.mp4', 'http://timg.bdta.pro/images/b79eed0883eb6992ef8b6c90aa2236f4.jpg'),
(80989, 5581, 'Jellystone! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177642.mp4', 'http://timg.bdta.pro/images/500c9684b01601485258669f3f5214b0.jpg'),
(80990, 5581, 'Jellystone! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177643.mp4', 'http://timg.bdta.pro/images/b0fa0d06bfa31fbfbc75c284d0fd10e5.jpg'),
(80991, 5581, 'Jellystone! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177644.mp4', 'http://timg.bdta.pro/images/a8f81ee261ab81bc04dfc70abb9bdf0d.jpg'),
(80992, 5581, 'Jellystone! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177645.mp4', 'http://timg.bdta.pro/images/4d6a96fbd0f3e2e29336f35f9c0d34d7.jpg'),
(80993, 5581, 'Jellystone! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177646.mp4', 'http://timg.bdta.pro/images/60ef38e865a9c1c564b47eec748a827b.jpg'),
(80994, 5581, 'Jellystone! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177647.mp4', 'http://timg.bdta.pro/images/e9d743e1d9d0602333260f65192713de.jpg'),
(80995, 5581, 'Jellystone! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177648.mp4', 'http://timg.bdta.pro/images/620ff2c2b37b69d589f01751cec60dc8.jpg'),
(80996, 5581, 'Jellystone! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177649.mp4', 'http://timg.bdta.pro/images/2148ebf06f3501569cfa92138c0bcacf.jpg'),
(80997, 5581, 'Jellystone! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177650.mp4', 'http://timg.bdta.pro/images/73dd5f74e8a27d6cf8221447e433a8e9.jpg'),
(80998, 5581, 'Jellystone! S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177651.mp4', 'http://timg.bdta.pro/images/47ae2fa447cf9759af04fed40e69e0d4.jpg'),
(80999, 5582, 'Jellystone! S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177652.mp4', 'http://timg.bdta.pro/images/a365708f5d7a48c1812353ca6ed922a3.jpg'),
(81000, 5582, 'Jellystone! S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177653.mp4', 'http://timg.bdta.pro/images/c6d53946a9d57a2c65ae504ca18f9945.jpg'),
(81001, 5582, 'Jellystone! S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177654.mp4', 'http://timg.bdta.pro/images/bee065516b66628c2da848047affc1ba.jpg'),
(81002, 5582, 'Jellystone! S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177655.mp4', 'http://timg.bdta.pro/images/cf7a6ec13b8d78cc935cdd797f4700db.jpg'),
(81003, 5582, 'Jellystone! S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177656.mp4', 'http://timg.bdta.pro/images/957d1d4bd543fb80f6eba94d9e6e0809.jpg'),
(81004, 5582, 'Jellystone! S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177657.mp4', 'http://timg.bdta.pro/images/cceb030110b9da92aa633a8458938b5f.jpg'),
(81005, 5582, 'Jellystone! S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177658.mp4', 'http://timg.bdta.pro/images/4da52d24207d9dba7df0373907629457.jpg'),
(81006, 5582, 'Jellystone! S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177659.mp4', 'http://timg.bdta.pro/images/c21750b78dc579de00a087479ffaec8f.jpg'),
(81007, 5582, 'Jellystone! S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177660.mp4', 'http://timg.bdta.pro/images/6289af2a99de6661076b6e35e3d4cb96.jpg'),
(81008, 5582, 'Jellystone! S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177661.mp4', 'http://timg.bdta.pro/images/57fcc99e96d3f7159c688f9f56929c65.jpg'),
(81009, 5582, 'Jellystone! S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177662.mp4', 'http://timg.bdta.pro/images/e2ec9033a20c9fb623ab35f99d87deb5.jpg'),
(81010, 5582, 'Jellystone! S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177663.mp4', 'http://timg.bdta.pro/images/b0903fcb65c4199bd0ef5aad25f14924.jpg'),
(81011, 5582, 'Jellystone! S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/177664.mp4', 'http://timg.bdta.pro/images/8d584a07b1f6504e00b02f48cbf0d639.jpg'),
(81012, 5582, 'Jellystone! S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/177665.mp4', 'http://timg.bdta.pro/images/7277fce027574011cb83422d265b8449.jpg'),
(81013, 5582, 'Jellystone! S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/177666.mp4', 'http://timg.bdta.pro/images/00390bff3bbd71e1f39726283709df25.jpg'),
(81014, 5582, 'Jellystone! S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/177667.mp4', 'http://timg.bdta.pro/images/35a96cebcfc089865417cdab16ce8207.jpg'),
(81015, 5582, 'Jellystone! S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/177668.mp4', 'http://timg.bdta.pro/images/3015006f713bdb7021e41da7c13efd78.jpg'),
(81016, 5582, 'Jellystone! S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/177669.mp4', 'http://timg.bdta.pro/images/e5612b217ce60430c3368058f7db37b5.jpg'),
(81017, 5582, 'Jellystone! S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/177670.mp4', 'http://timg.bdta.pro/images/1b725c5f942e56cf29e4a390d0c2b074.jpg'),
(81018, 5583, 'La Garçonne: Dupla Identidade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177635.mp4', 'http://timg.bdta.pro/images/251ecf26a87f81ca2b92c6051fb4a817.jpg'),
(81019, 5583, 'La Garçonne: Dupla Identidade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177636.mp4', 'http://timg.bdta.pro/images/6e756b9c0c7d3a75f0836b752c3d3748.jpg'),
(81020, 5583, 'La Garçonne: Dupla Identidade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177637.mp4', 'http://timg.bdta.pro/images/20ce1cf1246dff91d3376516c6aedfa4.jpg'),
(81021, 5583, 'La Garçonne: Dupla Identidade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177638.mp4', 'http://timg.bdta.pro/images/b5d8c29da5fa51e77234a2bee9e09d14.jpg'),
(81022, 5583, 'La Garçonne: Dupla Identidade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177639.mp4', 'http://timg.bdta.pro/images/80989ce0399fe5a472827966f594c763.jpg'),
(81023, 5583, 'La Garçonne: Dupla Identidade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177640.mp4', 'http://timg.bdta.pro/images/96dfdb4bb291feaf0b30927627e66109.jpg'),
(81024, 5584, 'Men in Kilts: A Roadtrip with Sam and Graham S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177627.mp4', 'http://timg.bdta.pro/images/0aa524f82e7c9b4518f66cd1f4b2b334.jpg'),
(81025, 5584, 'Men in Kilts: A Roadtrip with Sam and Graham S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177628.mp4', 'http://timg.bdta.pro/images/0ff401ac4af33c57a9f3e2fca540b344.jpg'),
(81026, 5584, 'Men in Kilts: A Roadtrip with Sam and Graham S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177629.mp4', 'http://timg.bdta.pro/images/e3105bb39d947b14fa189cc913038b81.jpg'),
(81027, 5584, 'Men in Kilts: A Roadtrip with Sam and Graham S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177630.mp4', 'http://timg.bdta.pro/images/e0b949f2b75068c7ad31004d7af60720.jpg'),
(81028, 5584, 'Men in Kilts: A Roadtrip with Sam and Graham S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177631.mp4', 'http://timg.bdta.pro/images/d9cc995929695dea1c8a831d74ba2e68.jpg'),
(81029, 5584, 'Men in Kilts: A Roadtrip with Sam and Graham S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177632.mp4', 'http://timg.bdta.pro/images/099d1fd6a0b5c3d7a989f94785fcf972.jpg'),
(81030, 5584, 'Men in Kilts: A Roadtrip with Sam and Graham S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177633.mp4', 'http://timg.bdta.pro/images/c4e74c228bdf650228f81769bb91d1fd.jpg'),
(81031, 5584, 'Men in Kilts: A Roadtrip with Sam and Graham S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177634.mp4', 'http://timg.bdta.pro/images/b875666eb01fce208914252d6f539c5c.jpg'),
(81032, 5585, 'Não Foi Minha Culpa: México S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177617.mp4', 'http://timg.bdta.pro/images/9a1b9fe0601f348c7a8cef31191e5b1a.jpg'),
(81033, 5585, 'Não Foi Minha Culpa: México S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177618.mp4', 'http://timg.bdta.pro/images/6573efcaf0de2431f898fffd565ddade.jpg'),
(81034, 5585, 'Não Foi Minha Culpa: México S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177619.mp4', 'http://timg.bdta.pro/images/afd7084cd2b27dbe99b87b9c275c7f2f.jpg'),
(81035, 5585, 'Não Foi Minha Culpa: México S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177620.mp4', 'http://timg.bdta.pro/images/9310dc4f8d52be830f4d2f2736f6e039.jpg'),
(81036, 5585, 'Não Foi Minha Culpa: México S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177621.mp4', 'http://timg.bdta.pro/images/62c6704437f1737a9a42ed4b656cde90.jpg'),
(81037, 5585, 'Não Foi Minha Culpa: México S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177622.mp4', 'http://timg.bdta.pro/images/9de24d48c3703ed6bc0efc91e47c30dd.jpg'),
(81038, 5585, 'Não Foi Minha Culpa: México S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177623.mp4', 'http://timg.bdta.pro/images/cea3f445a2d157913707444ae24a4b12.jpg'),
(81039, 5585, 'Não Foi Minha Culpa: México S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177624.mp4', 'http://timg.bdta.pro/images/3ec8e2e9572e2e14f016888ea2db8466.jpg'),
(81040, 5585, 'Não Foi Minha Culpa: México S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177625.mp4', 'http://timg.bdta.pro/images/3f6884981bae7e2d8482bc88353e0e95.jpg'),
(81041, 5585, 'Não Foi Minha Culpa: México S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177626.mp4', 'http://timg.bdta.pro/images/780772b1373594d47c390969db438947.jpg'),
(81042, 5586, 'Nossa Bandeira é a Morte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243648.mp4', 'http://timg.bdta.pro/images/8de2e339a259cfcb4e6e422bf8b5e41d.jpg'),
(81043, 5586, 'Nossa Bandeira é a Morte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243649.mp4', 'http://timg.bdta.pro/images/6d7aec52e3934dfb941efe8f21fe6546.jpg'),
(81044, 5586, 'Nossa Bandeira é a Morte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243650.mp4', 'http://timg.bdta.pro/images/e1a2d811a42af858d27c3ce6c8468fe3.jpg'),
(81045, 5586, 'Nossa Bandeira é a Morte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243651.mp4', 'http://timg.bdta.pro/images/8c2c6e74ebd292bba47f344d954ff084.jpg'),
(81046, 5586, 'Nossa Bandeira é a Morte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243652.mp4', 'http://timg.bdta.pro/images/91895eb12d5071c015412216b9ed11b1.jpg'),
(81047, 5586, 'Nossa Bandeira é a Morte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243653.mp4', 'http://timg.bdta.pro/images/a26ff348f80c6fdcfdeb2cd115445a83.jpg'),
(81048, 5586, 'Nossa Bandeira é a Morte S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243654.mp4', 'http://timg.bdta.pro/images/7a8140c86e5960d037894a1acba8283c.jpg'),
(81049, 5586, 'Nossa Bandeira é a Morte S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243655.mp4', 'http://timg.bdta.pro/images/93b6881f4c793dad9697b1833b4885d1.jpg'),
(81050, 5586, 'Nossa Bandeira é a Morte S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243656.mp4', 'http://timg.bdta.pro/images/d35e0f9ba950607a23c8466d0424d4ec.jpg'),
(81051, 5586, 'Nossa Bandeira é a Morte S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243657.mp4', 'http://timg.bdta.pro/images/36fbf335b307a1544b5f8ba833887bcf.jpg'),
(81052, 5587, 'Nossa Bandeira é a Morte S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243658.mp4', 'http://gstaticontent.com/images/5f186cc3ff78442d317c140c4f58df0e.jpg'),
(81053, 5587, 'Nossa Bandeira é a Morte S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243659.mp4', 'http://gstaticontent.com/images/5f186cc3ff78442d317c140c4f58df0e.jpg'),
(81054, 5587, 'Nossa Bandeira é a Morte S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243660.mp4', 'http://gstaticontent.com/images/5f186cc3ff78442d317c140c4f58df0e.jpg'),
(81055, 5587, 'Nossa Bandeira é a Morte S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243661.mp4', 'http://gstaticontent.com/images/5f186cc3ff78442d317c140c4f58df0e.jpg'),
(81056, 5587, 'Nossa Bandeira é a Morte S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243662.mp4', 'http://gstaticontent.com/images/5f186cc3ff78442d317c140c4f58df0e.jpg'),
(81057, 5587, 'Nossa Bandeira é a Morte S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243663.mp4', 'http://gstaticontent.com/images/5f186cc3ff78442d317c140c4f58df0e.jpg'),
(81058, 5587, 'Nossa Bandeira é a Morte S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243664.mp4', 'http://gstaticontent.com/images/5f186cc3ff78442d317c140c4f58df0e.jpg'),
(81059, 5587, 'Nossa Bandeira é a Morte S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243665.mp4', 'http://gstaticontent.com/images/5f186cc3ff78442d317c140c4f58df0e.jpg'),
(81060, 5588, 'Pé na Cova S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177546.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81061, 5588, 'Pé na Cova S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177547.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81062, 5588, 'Pé na Cova S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177548.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81063, 5588, 'Pé na Cova S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177549.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81064, 5588, 'Pé na Cova S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177550.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81065, 5588, 'Pé na Cova S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177551.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81066, 5588, 'Pé na Cova S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177552.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81067, 5588, 'Pé na Cova S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177553.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81068, 5588, 'Pé na Cova S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177554.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81069, 5588, 'Pé na Cova S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177555.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81070, 5588, 'Pé na Cova S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177556.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81071, 5588, 'Pé na Cova S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177557.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81072, 5588, 'Pé na Cova S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/177558.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81073, 5588, 'Pé na Cova S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/177559.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81074, 5588, 'Pé na Cova S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/177560.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81075, 5588, 'Pé na Cova S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/177561.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81076, 5588, 'Pé na Cova S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/177562.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81077, 5588, 'Pé na Cova S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/177563.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81078, 5588, 'Pé na Cova S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/177564.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81079, 5588, 'Pé na Cova S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/177565.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81080, 5588, 'Pé na Cova S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/177566.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81081, 5588, 'Pé na Cova S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/177567.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81082, 5589, 'Pé na Cova S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177568.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81083, 5589, 'Pé na Cova S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177569.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81084, 5589, 'Pé na Cova S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177570.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81085, 5589, 'Pé na Cova S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177571.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81086, 5589, 'Pé na Cova S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177572.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81087, 5589, 'Pé na Cova S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177573.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81088, 5589, 'Pé na Cova S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177574.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81089, 5589, 'Pé na Cova S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177575.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81090, 5589, 'Pé na Cova S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177576.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81091, 5589, 'Pé na Cova S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177577.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81092, 5589, 'Pé na Cova S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177578.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81093, 5590, 'Pé na Cova S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177579.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81094, 5590, 'Pé na Cova S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177580.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81095, 5590, 'Pé na Cova S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177581.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81096, 5590, 'Pé na Cova S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177582.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81097, 5590, 'Pé na Cova S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177583.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81098, 5590, 'Pé na Cova S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177584.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81099, 5590, 'Pé na Cova S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177585.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81100, 5590, 'Pé na Cova S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177586.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81101, 5590, 'Pé na Cova S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177587.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81102, 5590, 'Pé na Cova S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177588.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81103, 5590, 'Pé na Cova S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177589.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81104, 5590, 'Pé na Cova S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177590.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81105, 5590, 'Pé na Cova S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/177591.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81106, 5590, 'Pé na Cova S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/177592.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81107, 5591, 'Pé na Cova S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177593.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81108, 5591, 'Pé na Cova S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177594.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81109, 5591, 'Pé na Cova S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177595.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81110, 5591, 'Pé na Cova S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177596.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81111, 5591, 'Pé na Cova S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177597.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81112, 5591, 'Pé na Cova S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177598.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81113, 5591, 'Pé na Cova S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177599.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81114, 5591, 'Pé na Cova S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177600.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(81115, 5591, 'Pé na Cova S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177601.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81116, 5591, 'Pé na Cova S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177602.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81117, 5591, 'Pé na Cova S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177603.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81118, 5591, 'Pé na Cova S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177604.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81119, 5592, 'Pé na Cova S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177605.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81120, 5592, 'Pé na Cova S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177606.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81121, 5592, 'Pé na Cova S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177607.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81122, 5592, 'Pé na Cova S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177608.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81123, 5592, 'Pé na Cova S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177609.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81124, 5592, 'Pé na Cova S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177610.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81125, 5592, 'Pé na Cova S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177611.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81126, 5592, 'Pé na Cova S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177612.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81127, 5592, 'Pé na Cova S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177613.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81128, 5592, 'Pé na Cova S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177614.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81129, 5592, 'Pé na Cova S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177615.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81130, 5592, 'Pé na Cova S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177616.mp4', 'http://gstaticontent.com/images/efd4044165f30b488ca8e4b3562b0dda.jpg'),
(81131, 5593, 'Raising Hope S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177458.mp4', 'http://timg.bdta.pro/images/839832cce0d6f572225d50ebf800a059.jpg'),
(81132, 5593, 'Raising Hope S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177459.mp4', 'http://timg.bdta.pro/images/7aec1a26611bdfeb700a234c79ab57af.jpg'),
(81133, 5593, 'Raising Hope S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177460.mp4', 'http://timg.bdta.pro/images/79cc6b5a276b9c65d81e4bb7b3c33899.jpg'),
(81134, 5593, 'Raising Hope S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177461.mp4', 'http://timg.bdta.pro/images/68385ea471333dbcdb3b40cff6f9202a.jpg'),
(81135, 5593, 'Raising Hope S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177462.mp4', 'http://timg.bdta.pro/images/3d7468a63fd0da33bb9767a6aba4429a.jpg'),
(81136, 5593, 'Raising Hope S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177463.mp4', 'http://timg.bdta.pro/images/bbdaaf88f335720abb2be1833b5acbd1.jpg'),
(81137, 5593, 'Raising Hope S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177464.mp4', 'http://timg.bdta.pro/images/ff68e6354fcc3b364ce5da5242bfbf79.jpg'),
(81138, 5593, 'Raising Hope S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177465.mp4', 'http://timg.bdta.pro/images/1b2f184cb755feb636a3bb0a0e8b6023.jpg'),
(81139, 5593, 'Raising Hope S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177466.mp4', 'http://timg.bdta.pro/images/7a68380b2655410870bba8a84205f1d7.jpg'),
(81140, 5593, 'Raising Hope S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177467.mp4', 'http://timg.bdta.pro/images/b42d3b27ee23a0ea6bc0be6cec621c88.jpg'),
(81141, 5593, 'Raising Hope S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177468.mp4', 'http://timg.bdta.pro/images/72e6b7eb283c6c0bee2cbe18fcd75f68.jpg'),
(81142, 5593, 'Raising Hope S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177469.mp4', 'http://timg.bdta.pro/images/8511cfbb6b29faca347862223eb747e2.jpg'),
(81143, 5593, 'Raising Hope S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/177470.mp4', 'http://timg.bdta.pro/images/df8cbd3977ffe4f8b3fdf5f4717af452.jpg'),
(81144, 5593, 'Raising Hope S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/177471.mp4', 'http://timg.bdta.pro/images/1b3c90f0d3436c20005f2a0ff88cd85b.jpg'),
(81145, 5593, 'Raising Hope S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/177472.mp4', 'http://timg.bdta.pro/images/8c0e1bb82875fcc4af555ca25a339c8f.jpg'),
(81146, 5593, 'Raising Hope S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/177473.mp4', 'http://timg.bdta.pro/images/a1f71d092f342a24c952095017663df8.jpg'),
(81147, 5593, 'Raising Hope S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/177474.mp4', 'http://timg.bdta.pro/images/dd788dc8a3b82acd4a6f8e00c7396127.jpg'),
(81148, 5593, 'Raising Hope S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/177475.mp4', 'http://timg.bdta.pro/images/38f81171bccf3a28f93f94c619c07109.jpg'),
(81149, 5593, 'Raising Hope S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/177476.mp4', 'http://timg.bdta.pro/images/e8f4d1f2f60e9c1c854a0a77347a4385.jpg'),
(81150, 5593, 'Raising Hope S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/177477.mp4', 'http://timg.bdta.pro/images/c42d5c985dbfc89016c07052f2548bda.jpg'),
(81151, 5593, 'Raising Hope S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/177478.mp4', 'http://timg.bdta.pro/images/bd73aa7e82a05dedd5777b4ec09cbff6.jpg'),
(81152, 5593, 'Raising Hope S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/177479.mp4', 'http://timg.bdta.pro/images/016a26ebdace81537c8602e9ef2d3e9a.jpg'),
(81153, 5594, 'Raising Hope S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177480.mp4', 'http://timg.bdta.pro/images/26522cebaad75dc7ba466992bfec903e.jpg'),
(81154, 5594, 'Raising Hope S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177481.mp4', 'http://timg.bdta.pro/images/faf854aed1a866a0c7f474178798cff4.jpg'),
(81155, 5594, 'Raising Hope S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177482.mp4', 'http://timg.bdta.pro/images/98d9ea5cafb9ce488f7eb2ddb6079b35.jpg'),
(81156, 5594, 'Raising Hope S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177483.mp4', 'http://timg.bdta.pro/images/71c5555304c3dc0ef7367cb26649752b.jpg'),
(81157, 5594, 'Raising Hope S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177484.mp4', 'http://timg.bdta.pro/images/001871c55a8b1c00c9621ead0299c27e.jpg'),
(81158, 5594, 'Raising Hope S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177485.mp4', 'http://timg.bdta.pro/images/d3321c3df0ddc6eea4c3755c0bce0df6.jpg'),
(81159, 5594, 'Raising Hope S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177486.mp4', 'http://timg.bdta.pro/images/b353016c41d450dc5902f3cef6f3f44e.jpg'),
(81160, 5594, 'Raising Hope S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177487.mp4', 'http://timg.bdta.pro/images/07b15c4640825d4fbe1e339ee1f672e2.jpg'),
(81161, 5594, 'Raising Hope S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177488.mp4', 'http://timg.bdta.pro/images/e5da561c681cfa7104f63140ba421356.jpg'),
(81162, 5594, 'Raising Hope S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177489.mp4', 'http://timg.bdta.pro/images/c58c4622d5c76d2cf5387a2d7c440895.jpg'),
(81163, 5594, 'Raising Hope S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177490.mp4', 'http://timg.bdta.pro/images/15d11332eed5e0164ca9e8f390292b87.jpg'),
(81164, 5594, 'Raising Hope S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177491.mp4', 'http://timg.bdta.pro/images/707c3e40dd04b5124b6b5e8918024ab7.jpg'),
(81165, 5594, 'Raising Hope S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/177492.mp4', 'http://timg.bdta.pro/images/2ce1354f68b1e796033a1e45513cd12f.jpg'),
(81166, 5594, 'Raising Hope S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/177493.mp4', 'http://timg.bdta.pro/images/e67067df5237e9d629e10167d9c3244a.jpg'),
(81167, 5594, 'Raising Hope S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/177494.mp4', 'http://timg.bdta.pro/images/87905a38682d37208a49f0beaa4112b9.jpg'),
(81168, 5594, 'Raising Hope S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/177495.mp4', 'http://timg.bdta.pro/images/2e7809f2c9503e46f030f421cb7b8ed8.jpg'),
(81169, 5594, 'Raising Hope S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/177496.mp4', 'http://timg.bdta.pro/images/53823f54d7756d5a2c9628d747c7ad1c.jpg'),
(81170, 5594, 'Raising Hope S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/177497.mp4', 'http://timg.bdta.pro/images/4883395b325b37477f16844889cd3b33.jpg'),
(81171, 5594, 'Raising Hope S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/177498.mp4', 'http://timg.bdta.pro/images/46fcb79405a551439627268a733b8f05.jpg'),
(81172, 5594, 'Raising Hope S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/177499.mp4', 'http://timg.bdta.pro/images/f1c4f77b5ee54f44709d85767d46c3a2.jpg'),
(81173, 5594, 'Raising Hope S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/177500.mp4', 'http://timg.bdta.pro/images/55c13ed1f9d766b0f2e15db79add240b.jpg'),
(81174, 5594, 'Raising Hope S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/177501.mp4', 'http://timg.bdta.pro/images/c27bd987a37f032114f0d811a5900c78.jpg'),
(81175, 5595, 'Raising Hope S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177502.mp4', 'http://timg.bdta.pro/images/d5ee68b4424ea66f4ba85052a87644b3.jpg'),
(81176, 5595, 'Raising Hope S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177503.mp4', 'http://timg.bdta.pro/images/f25a1975e130ca9e2e45835a07467c9b.jpg'),
(81177, 5595, 'Raising Hope S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177504.mp4', 'http://timg.bdta.pro/images/c33d46d455c9692f746e4bbda52758e1.jpg'),
(81178, 5595, 'Raising Hope S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177505.mp4', 'http://timg.bdta.pro/images/0f8e467f79c4584cae547d3c7d27c217.jpg'),
(81179, 5595, 'Raising Hope S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177506.mp4', 'http://timg.bdta.pro/images/74a5b28f4e95a15431a410fff1e3080a.jpg'),
(81180, 5595, 'Raising Hope S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177507.mp4', 'http://timg.bdta.pro/images/dfdbfa563fb3a070e9a021ccd5294cc8.jpg'),
(81181, 5595, 'Raising Hope S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177508.mp4', 'http://timg.bdta.pro/images/0df5d69a3948519b6094cad0f390e1c3.jpg'),
(81182, 5595, 'Raising Hope S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177509.mp4', 'http://timg.bdta.pro/images/1aaded4b8d04a851eed5f6154cffe09e.jpg'),
(81183, 5595, 'Raising Hope S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177510.mp4', 'http://timg.bdta.pro/images/94f6a252bb57b5962e105cf7b60c3c66.jpg'),
(81184, 5595, 'Raising Hope S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177511.mp4', 'http://timg.bdta.pro/images/9d06e7b4b63ff1c509499cc4e4786a2d.jpg'),
(81185, 5595, 'Raising Hope S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177512.mp4', 'http://timg.bdta.pro/images/4b7b5aaff45dd6af5e0623f03b01940d.jpg'),
(81186, 5595, 'Raising Hope S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177513.mp4', 'http://timg.bdta.pro/images/111346099ced444f93a0ee89c7f521ca.jpg'),
(81187, 5595, 'Raising Hope S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/177514.mp4', 'http://timg.bdta.pro/images/99bc79d07c5ef834ffcb6aac867c9e81.jpg'),
(81188, 5595, 'Raising Hope S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/177515.mp4', 'http://timg.bdta.pro/images/11cf9d5a2e422214800451d59b3a36c3.jpg'),
(81189, 5595, 'Raising Hope S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/177516.mp4', 'http://timg.bdta.pro/images/b5508153111f85ce3d54dacbc58ded42.jpg'),
(81190, 5595, 'Raising Hope S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/177517.mp4', 'http://timg.bdta.pro/images/cad7f30e83f50e2c2997fc6709a4ecf9.jpg'),
(81191, 5595, 'Raising Hope S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/177518.mp4', 'http://timg.bdta.pro/images/e8f1a2bd8ae87783ad187093748e261a.jpg'),
(81192, 5595, 'Raising Hope S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/177519.mp4', 'http://timg.bdta.pro/images/aa84100174af2ff1643908195b9ad99b.jpg'),
(81193, 5595, 'Raising Hope S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/177520.mp4', 'http://timg.bdta.pro/images/3ca33fcd9dd25ffe9319fc1742e4fe85.jpg'),
(81194, 5595, 'Raising Hope S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/177521.mp4', 'http://timg.bdta.pro/images/affc8000ed7826cdf42db200ab2e5133.jpg'),
(81195, 5595, 'Raising Hope S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/177522.mp4', 'http://timg.bdta.pro/images/561a96714bc4ab63c7bbb667898a8688.jpg'),
(81196, 5595, 'Raising Hope S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/177523.mp4', 'http://timg.bdta.pro/images/6d5166b95106e342d5cde6388f8e7604.jpg'),
(81197, 5596, 'Raising Hope S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177524.mp4', 'http://timg.bdta.pro/images/41e5d04c36ac15ca7bd81c386ca751c5.jpg'),
(81198, 5596, 'Raising Hope S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177525.mp4', 'http://timg.bdta.pro/images/e73360f301f523421d01dee47af1aff1.jpg'),
(81199, 5596, 'Raising Hope S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177526.mp4', 'http://timg.bdta.pro/images/3f802b6adf76f4ad72162c6e309e82cf.jpg'),
(81200, 5596, 'Raising Hope S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177527.mp4', 'http://timg.bdta.pro/images/a52e891193b8b839f651c644567f4f12.jpg'),
(81201, 5596, 'Raising Hope S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177528.mp4', 'http://timg.bdta.pro/images/1879972731db64d39a87db781cedd3a4.jpg'),
(81202, 5596, 'Raising Hope S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177529.mp4', 'http://timg.bdta.pro/images/8283b7c2042a950c3c297819ac4f6a6a.jpg'),
(81203, 5596, 'Raising Hope S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177530.mp4', 'http://timg.bdta.pro/images/227c2e47759af3886d5611b32de66e75.jpg'),
(81204, 5596, 'Raising Hope S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177531.mp4', 'http://timg.bdta.pro/images/ea07604fd1136f30ba0926b2e822457e.jpg'),
(81205, 5596, 'Raising Hope S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/177532.mp4', 'http://timg.bdta.pro/images/11511a06dd24e7d8d9c35c2818f1efc4.jpg'),
(81206, 5596, 'Raising Hope S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/177533.mp4', 'http://timg.bdta.pro/images/acd7295436ee29b8ddb0d26e73362c17.jpg'),
(81207, 5596, 'Raising Hope S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/177534.mp4', 'http://timg.bdta.pro/images/fce0893e7d8b59482a80a43b229c90a7.jpg'),
(81208, 5596, 'Raising Hope S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/177535.mp4', 'http://timg.bdta.pro/images/156928ee826ef0b3a272140b88b4df75.jpg'),
(81209, 5596, 'Raising Hope S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/177536.mp4', 'http://timg.bdta.pro/images/a30ffa968823ed69301323a174c8ab95.jpg'),
(81210, 5596, 'Raising Hope S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/177537.mp4', 'http://timg.bdta.pro/images/179c1abbf692cd0dd2c91f6276a8af93.jpg'),
(81211, 5596, 'Raising Hope S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/177538.mp4', 'http://timg.bdta.pro/images/d10b695f0528a063025581ac8df671e7.jpg'),
(81212, 5596, 'Raising Hope S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/177539.mp4', 'http://timg.bdta.pro/images/3ca22e2c5c9f6b8c36ec3569fff2d48c.jpg'),
(81213, 5596, 'Raising Hope S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/177540.mp4', 'http://timg.bdta.pro/images/bf0a0757fea7355f1ff7e9209f49a8b0.jpg'),
(81214, 5596, 'Raising Hope S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/177541.mp4', 'http://timg.bdta.pro/images/6cfe6e31c02f54e7cb69204adec9a211.jpg'),
(81215, 5596, 'Raising Hope S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/177542.mp4', 'http://timg.bdta.pro/images/ce9cfcae79ab9a49b583dcd80cd56da6.jpg'),
(81216, 5596, 'Raising Hope S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/177543.mp4', 'http://timg.bdta.pro/images/3167245621884515dcc3680fb29ca260.jpg'),
(81217, 5596, 'Raising Hope S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/177544.mp4', 'http://timg.bdta.pro/images/fbf6820e521d656821ab16725002bf38.jpg'),
(81218, 5596, 'Raising Hope S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/177545.mp4', 'http://timg.bdta.pro/images/d48f030b9cdc24ea7e9b13d66584b235.jpg'),
(81219, 5597, 'Rumo ao Desconhecido: Especial De Volta para o Futuro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177454.mp4', 'http://timg.bdta.pro/images/f1936e6a74c5dfdb7b1e13663431d028.jpg'),
(81220, 5597, 'Rumo ao Desconhecido: Especial De Volta para o Futuro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177455.mp4', 'http://timg.bdta.pro/images/d39f80a4c377ced65d105b65c3b99d83.jpg'),
(81221, 5597, 'Rumo ao Desconhecido: Especial De Volta para o Futuro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177456.mp4', 'http://timg.bdta.pro/images/a8a97a605b3ffa95694ac935b09150fe.jpg'),
(81222, 5597, 'Rumo ao Desconhecido: Especial De Volta para o Futuro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177457.mp4', 'http://timg.bdta.pro/images/18bd17286333176444c8aabab51224a5.jpg'),
(81223, 5598, 'Submersa: O Desaparecimento de Kim Wall S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177452.mp4', 'http://gstaticontent.com/images/dbd0e022c9cb995613222b6b383b02d4.jpg'),
(81224, 5598, 'Submersa: O Desaparecimento de Kim Wall S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177453.mp4', 'http://gstaticontent.com/images/dbd0e022c9cb995613222b6b383b02d4.jpg'),
(81225, 5599, 'Taboo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177444.mp4', 'http://timg.bdta.pro/images/2ee6daf69013fe34f45e1d101425f19a.jpg'),
(81226, 5599, 'Taboo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177445.mp4', 'http://timg.bdta.pro/images/24260577e8fd6309b6ef9d6c9c205a34.jpg'),
(81227, 5599, 'Taboo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177446.mp4', 'http://timg.bdta.pro/images/1bbfa7bf13fa45b336b67b09d153287b.jpg'),
(81228, 5599, 'Taboo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177447.mp4', 'http://timg.bdta.pro/images/903fec52bb7bc3ecc87310911ae5b9de.jpg'),
(81229, 5599, 'Taboo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177448.mp4', 'http://timg.bdta.pro/images/ed1d63322bc3a3068efd6311d14668c7.jpg'),
(81230, 5599, 'Taboo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177449.mp4', 'http://timg.bdta.pro/images/16ed4ab38efa2d5d937dcee867c5c61e.jpg'),
(81231, 5599, 'Taboo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177450.mp4', 'http://timg.bdta.pro/images/cbf7b8bcd793fecca29b0e2e64ce60b0.jpg'),
(81232, 5599, 'Taboo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177451.mp4', 'http://timg.bdta.pro/images/ce16c675fbe73255fc13b7a92f704e13.jpg'),
(81233, 5600, 'Teenage Euthanasia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234778.mp4', 'http://timg.bdta.pro/images/7d028e4f015cbc825007e5d38f6e8acd.jpg'),
(81234, 5600, 'Teenage Euthanasia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234779.mp4', 'http://timg.bdta.pro/images/8befab0d9a6e8f54493c3b08f3a49e56.jpg'),
(81235, 5600, 'Teenage Euthanasia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234780.mp4', 'http://timg.bdta.pro/images/4bb464516a80d17ed69db2315882a23d.jpg'),
(81236, 5600, 'Teenage Euthanasia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234781.mp4', 'http://timg.bdta.pro/images/1390acce64d652c393a5f7c5a3ff7449.jpg'),
(81237, 5600, 'Teenage Euthanasia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234782.mp4', 'http://timg.bdta.pro/images/34fd75a69dc28e5e994de5391e4f6fbb.jpg'),
(81238, 5600, 'Teenage Euthanasia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234783.mp4', 'http://timg.bdta.pro/images/b19f38a57ab7fb655aba27591beea719.jpg'),
(81239, 5600, 'Teenage Euthanasia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234784.mp4', 'http://timg.bdta.pro/images/2ae668873dbaddf5673b02b5b270b45b.jpg'),
(81240, 5601, 'Teenage Euthanasia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234785.mp4', 'http://image.tmdb.org/t/p/w1280/rDY9IZRtHEB0avRe9U4iyUu1hDf.jpg'),
(81241, 5601, 'Teenage Euthanasia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234786.mp4', 'http://image.tmdb.org/t/p/w1280/oCXRrg5OAtze5DhhSMaeCQesjdk.jpg'),
(81242, 5601, 'Teenage Euthanasia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234787.mp4', 'http://image.tmdb.org/t/p/w1280/ndavX9Sq4TWPO7qaC29ql2iWCFk.jpg'),
(81243, 5601, 'Teenage Euthanasia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234788.mp4', 'http://image.tmdb.org/t/p/w1280/9wm5qOyLiutfyJaZ4ml9nKfg3lL.jpg'),
(81244, 5601, 'Teenage Euthanasia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234789.mp4', 'http://image.tmdb.org/t/p/w1280/48hjPbOg9XtjAhW96pxuGuKdd4T.jpg'),
(81245, 5601, 'Teenage Euthanasia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234790.mp4', 'http://image.tmdb.org/t/p/w1280/lJnUfMmg0RLzwtZmmMVUpseMRhr.jpg'),
(81246, 5601, 'Teenage Euthanasia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234791.mp4', 'http://gstaticontent.com/images/0a712b828b0b0c03a9d0434325935956.jpg'),
(81247, 5601, 'Teenage Euthanasia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234792.mp4', 'http://gstaticontent.com/images/0a712b828b0b0c03a9d0434325935956.jpg'),
(81248, 5601, 'Teenage Euthanasia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234793.mp4', 'http://gstaticontent.com/images/0a712b828b0b0c03a9d0434325935956.jpg'),
(81249, 5601, 'Teenage Euthanasia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234794.mp4', 'http://gstaticontent.com/images/0a712b828b0b0c03a9d0434325935956.jpg'),
(81250, 5602, 'Um Lobo como Eu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177438.mp4', 'http://timg.bdta.pro/images/96de4589ccd74230911d2014fddb81f4.jpg'),
(81251, 5602, 'Um Lobo como Eu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177439.mp4', 'http://timg.bdta.pro/images/a42d791a0fb87b1fe9aa7ed9cb815ed8.jpg'),
(81252, 5602, 'Um Lobo como Eu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177440.mp4', 'http://timg.bdta.pro/images/8e6cf60b879bcbdcfe48886c93761359.jpg'),
(81253, 5602, 'Um Lobo como Eu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177441.mp4', 'http://timg.bdta.pro/images/9d7a2e22c0d0197ab5e4fee671e3ffd3.jpg'),
(81254, 5602, 'Um Lobo como Eu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177442.mp4', 'http://timg.bdta.pro/images/d5a362785e125afd1d7c8a2fe85a362c.jpg'),
(81255, 5602, 'Um Lobo como Eu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177443.mp4', 'http://timg.bdta.pro/images/f06c144d9e8906c5d85082635360fd82.jpg'),
(81256, 5603, 'Um Lobo como Eu S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/272442.mp4', 'http://gstaticontent.com/images/55cdd8379e0f9cee48f9b625bfc26494.jpg'),
(81257, 5603, 'Um Lobo como Eu S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/272443.mp4', 'http://gstaticontent.com/images/55cdd8379e0f9cee48f9b625bfc26494.jpg'),
(81258, 5603, 'Um Lobo como Eu S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/272444.mp4', 'http://gstaticontent.com/images/55cdd8379e0f9cee48f9b625bfc26494.jpg'),
(81259, 5603, 'Um Lobo como Eu S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/272445.mp4', 'http://gstaticontent.com/images/55cdd8379e0f9cee48f9b625bfc26494.jpg'),
(81260, 5603, 'Um Lobo como Eu S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/272446.mp4', 'http://gstaticontent.com/images/55cdd8379e0f9cee48f9b625bfc26494.jpg'),
(81261, 5603, 'Um Lobo como Eu S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/272447.mp4', 'http://gstaticontent.com/images/55cdd8379e0f9cee48f9b625bfc26494.jpg'),
(81262, 5603, 'Um Lobo como Eu S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/272448.mp4', 'http://gstaticontent.com/images/55cdd8379e0f9cee48f9b625bfc26494.jpg'),
(81263, 5604, 'Universos Paralelos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177432.mp4', 'http://timg.bdta.pro/images/2b2fe9db8b1c341a97ca02c9f812f89c.jpg'),
(81264, 5604, 'Universos Paralelos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177433.mp4', 'http://timg.bdta.pro/images/42bbc475b72597aafd6d800538672a75.jpg'),
(81265, 5604, 'Universos Paralelos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177434.mp4', 'http://timg.bdta.pro/images/7a83ffc7efb3373a5c5b1a7bd35655b7.jpg'),
(81266, 5604, 'Universos Paralelos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177435.mp4', 'http://timg.bdta.pro/images/a54b6041940313a9e840c32438c5d392.jpg'),
(81267, 5604, 'Universos Paralelos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177436.mp4', 'http://timg.bdta.pro/images/e376baa9f7e43612e613ce8088bb4104.jpg'),
(81268, 5604, 'Universos Paralelos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177437.mp4', 'http://timg.bdta.pro/images/434b3bf113221f36d9e071091250b9d3.jpg'),
(81269, 5605, 'WeCrashed S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178600.mp4', 'http://timg.bdta.pro/images/b615a051ee647637677d7977fcd3cecd.jpg'),
(81270, 5605, 'WeCrashed S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178601.mp4', 'http://timg.bdta.pro/images/ce0cd7fa1ae15efda9f20fa728a6a3e5.jpg'),
(81271, 5605, 'WeCrashed S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178602.mp4', 'http://timg.bdta.pro/images/918373721b35b30ab27b99ac6c45948a.jpg'),
(81272, 5605, 'WeCrashed S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178603.mp4', 'http://timg.bdta.pro/images/2c3e850ec0ba606b16ba035edf5b0bec.jpg'),
(81273, 5605, 'WeCrashed S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178604.mp4', 'http://timg.bdta.pro/images/6623db3642e999e23cebd03641467c18.jpg'),
(81274, 5605, 'WeCrashed S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178605.mp4', 'http://timg.bdta.pro/images/6cd5d2e0bfdd2a16123112c0a0c01d2a.jpg'),
(81275, 5605, 'WeCrashed S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178606.mp4', 'http://timg.bdta.pro/images/2470ecf1de8462bfb6326df4fcc2775a.jpg'),
(81276, 5605, 'WeCrashed S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178607.mp4', 'http://timg.bdta.pro/images/57ddbf4982ae05e37d4bb2220e4dfd47.jpg'),
(81277, 5606, 'À Prova de Risco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177013.mp4', 'http://timg.bdta.pro/images/e0699d9373a8fc48e7187ed8169df675.jpg'),
(81278, 5606, 'À Prova de Risco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177014.mp4', 'http://timg.bdta.pro/images/4905e4d6e670d7565835f7b2f95a00e1.jpg'),
(81279, 5606, 'À Prova de Risco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177015.mp4', 'http://timg.bdta.pro/images/c4d237e3a2536569b2dae8f024612f00.jpg'),
(81280, 5606, 'À Prova de Risco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177016.mp4', 'http://timg.bdta.pro/images/30d071c1d80140db67d6a74e84d97503.jpg'),
(81281, 5606, 'À Prova de Risco S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177017.mp4', 'http://timg.bdta.pro/images/e128fb4fc78d18de33b166ac8a231be3.jpg'),
(81282, 5606, 'À Prova de Risco S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177018.mp4', 'http://timg.bdta.pro/images/61b4a3c8003b622829cbb8b1035ef610.jpg'),
(81283, 5607, 'As Vidas Secretas da Família Uysal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/177005.mp4', 'http://timg.bdta.pro/images/bb1b55cbcaf7cfd3d319df2c677a7281.jpg'),
(81284, 5607, 'As Vidas Secretas da Família Uysal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177006.mp4', 'http://timg.bdta.pro/images/202643ebe0ae6dd38958068c8d28cd32.jpg'),
(81285, 5607, 'As Vidas Secretas da Família Uysal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177007.mp4', 'http://timg.bdta.pro/images/914b0cc95a935709256dad2c3ae659be.jpg'),
(81286, 5607, 'As Vidas Secretas da Família Uysal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177008.mp4', 'http://timg.bdta.pro/images/6dedd0a58858977090b4a574146aa021.jpg'),
(81287, 5607, 'As Vidas Secretas da Família Uysal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177009.mp4', 'http://timg.bdta.pro/images/998bdc5bef7c1df54d8c9b49e4179ddd.jpg'),
(81288, 5607, 'As Vidas Secretas da Família Uysal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177010.mp4', 'http://timg.bdta.pro/images/54aba45f95088e0780792ea326c558d6.jpg'),
(81289, 5607, 'As Vidas Secretas da Família Uysal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/177011.mp4', 'http://timg.bdta.pro/images/847edacacd922e6c3b82b9e961a0b915.jpg'),
(81290, 5607, 'As Vidas Secretas da Família Uysal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/177012.mp4', 'http://timg.bdta.pro/images/0d0b211e0f67bc59a179a9ebfec8493a.jpg'),
(81291, 5608, 'Cavaleiro da Lua S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178702.mp4', 'http://timg.bdta.pro/images/06229068c43564f98671d67bd1c4b5d2.jpg'),
(81292, 5608, 'Cavaleiro da Lua S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178703.mp4', 'http://timg.bdta.pro/images/48883597d7320bba209ca309edd88802.jpg'),
(81293, 5608, 'Cavaleiro da Lua S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178704.mp4', 'http://timg.bdta.pro/images/83388bfa9543ac11ca75c556aff4d251.jpg'),
(81294, 5608, 'Cavaleiro da Lua S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178705.mp4', 'http://timg.bdta.pro/images/edbaf1bb9854e477fd81928b2c74eeff.jpg'),
(81295, 5608, 'Cavaleiro da Lua S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178706.mp4', 'http://timg.bdta.pro/images/33dd54f310e70b6de5f24f37fcfbe706.jpg'),
(81296, 5608, 'Cavaleiro da Lua S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178707.mp4', 'http://timg.bdta.pro/images/8a0df8501dcca0194da439f57da42684.jpg'),
(81297, 5609, 'Em Busca de Atlantida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176999.mp4', 'http://timg.bdta.pro/images/c71ebebdb8609aa7a60d3f21c8aa4cce.jpg'),
(81298, 5609, 'Em Busca de Atlantida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/177000.mp4', 'http://timg.bdta.pro/images/518da6e41616bbb97baba98e1862e66b.jpg'),
(81299, 5609, 'Em Busca de Atlantida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/177001.mp4', 'http://timg.bdta.pro/images/c8c0699ad248fecbcdb3c44e2efd81d2.jpg'),
(81300, 5609, 'Em Busca de Atlantida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/177002.mp4', 'http://timg.bdta.pro/images/ab3a761087969681505ca228fa6aa0a6.jpg'),
(81301, 5609, 'Em Busca de Atlantida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/177003.mp4', 'http://timg.bdta.pro/images/65fa819332f0d64dfcb4220ba3c1e9cc.jpg'),
(81302, 5609, 'Em Busca de Atlantida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/177004.mp4', 'http://timg.bdta.pro/images/64ca034e5e02d8b64efb0333bc013716.jpg'),
(81303, 5610, 'Lakers: Hora de Vencer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236659.mp4', 'http://timg.bdta.pro/images/e45dc153c06ef540f76468236aa197fb.jpg'),
(81304, 5610, 'Lakers: Hora de Vencer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236660.mp4', 'http://timg.bdta.pro/images/6d127bad0d7c51d2ecb90c6ea590aa51.jpg'),
(81305, 5610, 'Lakers: Hora de Vencer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236661.mp4', 'http://timg.bdta.pro/images/da07c08a3111e4f66582f4f4c7869600.jpg'),
(81306, 5610, 'Lakers: Hora de Vencer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236662.mp4', 'http://timg.bdta.pro/images/afda98da5a9dc6d735adc40fae64e4f9.jpg'),
(81307, 5610, 'Lakers: Hora de Vencer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236663.mp4', 'http://timg.bdta.pro/images/92db82f74d352de4e74b8772946912a9.jpg'),
(81308, 5610, 'Lakers: Hora de Vencer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236664.mp4', 'http://timg.bdta.pro/images/8657be3248fb887bf17d984a7109c0cf.jpg'),
(81309, 5610, 'Lakers: Hora de Vencer S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236665.mp4', 'http://timg.bdta.pro/images/2649e467ccd83bd7ac0c00cd615a70ce.jpg'),
(81310, 5610, 'Lakers: Hora de Vencer S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236666.mp4', 'http://timg.bdta.pro/images/aa089a46f4b48cc30fb6be1d07f1bcc6.jpg'),
(81311, 5610, 'Lakers: Hora de Vencer S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236667.mp4', 'http://timg.bdta.pro/images/8cc97cdd7fd1522630a8466e5416704d.jpg'),
(81312, 5610, 'Lakers: Hora de Vencer S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236668.mp4', 'http://timg.bdta.pro/images/347f4e160c5cf9fa4ca25ccf15e8eb9d.jpg'),
(81313, 5611, 'Lakers: Hora de Vencer S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236669.mp4', 'http://image.tmdb.org/t/p/w1280/tUzLm6on90lJZlcNgMsKbtDE0U2.jpg'),
(81314, 5611, 'Lakers: Hora de Vencer S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236670.mp4', 'http://image.tmdb.org/t/p/w1280/h9yk11svwpVpW0yI47uhCger0Ge.jpg'),
(81315, 5611, 'Lakers: Hora de Vencer S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236671.mp4', 'http://image.tmdb.org/t/p/w1280/5oitQXPxoPZtJkykiBhmcweKesv.jpg'),
(81316, 5611, 'Lakers: Hora de Vencer S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236672.mp4', 'http://image.tmdb.org/t/p/w1280/mOFkoQCsprVfh7SG3qILTi76g9G.jpg'),
(81317, 5611, 'Lakers: Hora de Vencer S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236673.mp4', 'http://image.tmdb.org/t/p/w1280/fFZ7zL0LTsbIJar1n4iLi7vQYxj.jpg'),
(81318, 5611, 'Lakers: Hora de Vencer S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236674.mp4', 'http://gstaticontent.com/images/6ed0db6b3160a2416b6426e3f178571c.jpg'),
(81319, 5611, 'Lakers: Hora de Vencer S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236675.mp4', 'http://gstaticontent.com/images/6ed0db6b3160a2416b6426e3f178571c.jpg'),
(81320, 5612, 'O Último Ônibus do Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176989.mp4', 'http://timg.bdta.pro/images/560bbb06047650e301c49a081f95dd38.jpg'),
(81321, 5612, 'O Último Ônibus do Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176990.mp4', 'http://timg.bdta.pro/images/34df01cc674a87ec2a93b641f469c713.jpg'),
(81322, 5612, 'O Último Ônibus do Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176991.mp4', 'http://timg.bdta.pro/images/a5f5f289fae6ffa080ebd82cc45f6294.jpg'),
(81323, 5612, 'O Último Ônibus do Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176992.mp4', 'http://timg.bdta.pro/images/bf4899b10617278d05a2558823d3149f.jpg'),
(81324, 5612, 'O Último Ônibus do Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176993.mp4', 'http://timg.bdta.pro/images/826caa23d557b1ef24bfcb5b54f1299d.jpg'),
(81325, 5612, 'O Último Ônibus do Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176994.mp4', 'http://timg.bdta.pro/images/672b60cdefd4616088fe9a4a1a1ef7c9.jpg'),
(81326, 5612, 'O Último Ônibus do Mundo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176995.mp4', 'http://timg.bdta.pro/images/09dc745d073ea3c80cb136ee50e580af.jpg'),
(81327, 5612, 'O Último Ônibus do Mundo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176996.mp4', 'http://timg.bdta.pro/images/ad7ad78ce2aa8e4ddef392828121ecf3.jpg'),
(81328, 5612, 'O Último Ônibus do Mundo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176997.mp4', 'http://timg.bdta.pro/images/d33604bb5a65d9a08fa75015c2a33601.jpg'),
(81329, 5612, 'O Último Ônibus do Mundo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176998.mp4', 'http://timg.bdta.pro/images/a8e91034dd51bb38c56b121e41bcb6a9.jpg'),
(81330, 5613, 'Os Cavaleiros de Castelcorvo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176974.mp4', 'http://timg.bdta.pro/images/82c276c42e99c99e9618837e1c54fcf4.jpg'),
(81331, 5613, 'Os Cavaleiros de Castelcorvo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176975.mp4', 'http://timg.bdta.pro/images/68c050a8a1dc1915a05b435d90f0397f.jpg'),
(81332, 5613, 'Os Cavaleiros de Castelcorvo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176976.mp4', 'http://timg.bdta.pro/images/cb89b8da9aed32972345ea37a23ee279.jpg'),
(81333, 5613, 'Os Cavaleiros de Castelcorvo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176977.mp4', 'http://timg.bdta.pro/images/070259b017e6a357ef23e69261ac1c7a.jpg'),
(81334, 5613, 'Os Cavaleiros de Castelcorvo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176978.mp4', 'http://timg.bdta.pro/images/6f5a69742bf00d3cec9592004399906d.jpg'),
(81335, 5613, 'Os Cavaleiros de Castelcorvo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176979.mp4', 'http://timg.bdta.pro/images/60fa6dc818c58f602671dc0f8bb2a475.jpg'),
(81336, 5613, 'Os Cavaleiros de Castelcorvo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176980.mp4', 'http://timg.bdta.pro/images/9ae1db5d862a5204df40a1dbb9bf02f9.jpg'),
(81337, 5613, 'Os Cavaleiros de Castelcorvo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176981.mp4', 'http://timg.bdta.pro/images/b9863a2ad93c907f9abfb47c4cb81821.jpg'),
(81338, 5613, 'Os Cavaleiros de Castelcorvo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176982.mp4', 'http://timg.bdta.pro/images/6644db58ee3ed8bb9f5495009dd40b1b.jpg'),
(81339, 5613, 'Os Cavaleiros de Castelcorvo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176983.mp4', 'http://timg.bdta.pro/images/9606106250c8e89cfc8051d610a17c6c.jpg'),
(81340, 5613, 'Os Cavaleiros de Castelcorvo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/176984.mp4', 'http://timg.bdta.pro/images/4deac6edbdf98dc8f345964d277374a0.jpg'),
(81341, 5613, 'Os Cavaleiros de Castelcorvo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/176985.mp4', 'http://timg.bdta.pro/images/b8dea6b30e948c7dbbb62a0aa3e92d00.jpg'),
(81342, 5613, 'Os Cavaleiros de Castelcorvo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/176986.mp4', 'http://timg.bdta.pro/images/cfb646912c2197b55202587561f091e4.jpg'),
(81343, 5613, 'Os Cavaleiros de Castelcorvo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/176987.mp4', 'http://timg.bdta.pro/images/ab669349f16403d5205a96be6a00fd02.jpg'),
(81344, 5613, 'Os Cavaleiros de Castelcorvo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/176988.mp4', 'http://timg.bdta.pro/images/6ae336a863753fd6c6b281259eefd879.jpg'),
(81345, 5614, 'Pachinko S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178616.mp4', 'http://timg.bdta.pro/images/90c722296b5687f5b5f20017968452ff.jpg'),
(81346, 5614, 'Pachinko S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178617.mp4', 'http://timg.bdta.pro/images/05f9d977b925fd71e5d4d0c4bdfbef67.jpg'),
(81347, 5614, 'Pachinko S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178618.mp4', 'http://timg.bdta.pro/images/330937fe72922e566b93c64dbc6f429a.jpg'),
(81348, 5614, 'Pachinko S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178619.mp4', 'http://timg.bdta.pro/images/78a9888e0458cabcd19bae55db6ea7e6.jpg'),
(81349, 5614, 'Pachinko S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178620.mp4', 'http://timg.bdta.pro/images/c89ef139c0b89c3c9a9c20813ea323a0.jpg'),
(81350, 5614, 'Pachinko S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178621.mp4', 'http://timg.bdta.pro/images/0ae25cedbd93f76eb71e42c2570541e5.jpg'),
(81351, 5614, 'Pachinko S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178622.mp4', 'http://timg.bdta.pro/images/bf564617fe95e25614559145ac787782.jpg'),
(81352, 5614, 'Pachinko S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178623.mp4', 'http://timg.bdta.pro/images/65ee5ea68fbd1997abc37f649132ddb9.jpg'),
(81353, 5615, 'Pachinko S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439306.mp4', 'http://gstaticontent.com/images/5128b1f79a1bbc21ba2b9c9b25f8a43b.jpg'),
(81354, 5615, 'Pachinko S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/441605.mp4', 'http://gstaticontent.com/images/5128b1f79a1bbc21ba2b9c9b25f8a43b.jpg'),
(81355, 5615, 'Pachinko S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445869.mp4', 'http://gstaticontent.com/images/5128b1f79a1bbc21ba2b9c9b25f8a43b.jpg'),
(81356, 5615, 'Pachinko S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/454739.mp4', 'http://gstaticontent.com/images/5128b1f79a1bbc21ba2b9c9b25f8a43b.jpg'),
(81357, 5615, 'Pachinko S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/459419.mp4', 'http://gstaticontent.com/images/5128b1f79a1bbc21ba2b9c9b25f8a43b.jpg'),
(81358, 5615, 'Pachinko S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/467010.mp4', 'http://gstaticontent.com/images/5128b1f79a1bbc21ba2b9c9b25f8a43b.jpg'),
(81359, 5615, 'Pachinko S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/472715.mp4', 'http://gstaticontent.com/images/5128b1f79a1bbc21ba2b9c9b25f8a43b.jpg'),
(81360, 5615, 'Pachinko S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/476031.mp4', 'http://gstaticontent.com/images/5128b1f79a1bbc21ba2b9c9b25f8a43b.jpg'),
(81361, 5616, 'Pintando com John S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176962.mp4', 'http://timg.bdta.pro/images/f17ee6465fc0ad9bb44abf211f53e19a.jpg'),
(81362, 5616, 'Pintando com John S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176963.mp4', 'http://timg.bdta.pro/images/74435cb1607f0c5d7f32f1117cdfd70e.jpg'),
(81363, 5616, 'Pintando com John S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176964.mp4', 'http://timg.bdta.pro/images/fb8686b667261299901c322ee642db60.jpg'),
(81364, 5616, 'Pintando com John S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176965.mp4', 'http://timg.bdta.pro/images/81b003309ae079050f243c540af2bd1c.jpg'),
(81365, 5616, 'Pintando com John S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176966.mp4', 'http://timg.bdta.pro/images/d822ddb3f67a881284b4fbefc213933d.jpg'),
(81366, 5616, 'Pintando com John S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176967.mp4', 'http://timg.bdta.pro/images/b3eab5c58a2cf80e044a068afa7a55aa.jpg'),
(81367, 5617, 'Pintando com John S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176968.mp4', 'http://timg.bdta.pro/images/f40ba665719882e479cd81f257230ed0.jpg'),
(81368, 5617, 'Pintando com John S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176969.mp4', 'http://timg.bdta.pro/images/0d07781ec3f3c4201f4833bb4e99e364.jpg'),
(81369, 5617, 'Pintando com John S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176970.mp4', 'http://gstaticontent.com/images/93a32645440d648808c46f60fce9fa34.jpg'),
(81370, 5617, 'Pintando com John S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176971.mp4', 'http://gstaticontent.com/images/93a32645440d648808c46f60fce9fa34.jpg'),
(81371, 5617, 'Pintando com John S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176972.mp4', 'http://gstaticontent.com/images/93a32645440d648808c46f60fce9fa34.jpg'),
(81372, 5617, 'Pintando com John S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176973.mp4', 'http://gstaticontent.com/images/93a32645440d648808c46f60fce9fa34.jpg'),
(81373, 5618, 'Porni S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176956.mp4', 'http://timg.bdta.pro/images/06a264ffa6ec698db83344e01597f379.jpg'),
(81374, 5618, 'Porni S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176957.mp4', 'http://timg.bdta.pro/images/740df5674f5c0880e77a51f05416c15f.jpg'),
(81375, 5618, 'Porni S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176958.mp4', 'http://timg.bdta.pro/images/68dd393b2128b985ff8e2cc4b5c1b985.jpg'),
(81376, 5618, 'Porni S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176959.mp4', 'http://timg.bdta.pro/images/72dc82da6fe29cca772245525020a016.jpg'),
(81377, 5618, 'Porni S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176960.mp4', 'http://timg.bdta.pro/images/7862dca3a59728bfe839533fdd405afa.jpg'),
(81378, 5618, 'Porni S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176961.mp4', 'http://timg.bdta.pro/images/5e58c3730c132a4c162b19bc992c5342.jpg'),
(81379, 5619, 'Pretendente Surpresa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181516.mp4', 'http://timg.bdta.pro/images/9bb907311efce810e07220952ea10663.jpg'),
(81380, 5619, 'Pretendente Surpresa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181517.mp4', 'http://timg.bdta.pro/images/803b14b4f7c84205b51f599f47cd3fad.jpg'),
(81381, 5619, 'Pretendente Surpresa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181518.mp4', 'http://timg.bdta.pro/images/98431f3937488f54f4f55c983441c3bf.jpg'),
(81382, 5619, 'Pretendente Surpresa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181519.mp4', 'http://timg.bdta.pro/images/b7fcd263bbf42a984f64f66c396fbe31.jpg'),
(81383, 5619, 'Pretendente Surpresa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181520.mp4', 'http://timg.bdta.pro/images/b4486023a46e665b32f9c006f3650f32.jpg'),
(81384, 5619, 'Pretendente Surpresa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181521.mp4', 'http://timg.bdta.pro/images/cca76ef62ee1051a4b20817dc33fb7d9.jpg'),
(81385, 5619, 'Pretendente Surpresa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181522.mp4', 'http://timg.bdta.pro/images/f1e7d7c10a6f8e099130fd362959bd49.jpg'),
(81386, 5619, 'Pretendente Surpresa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181523.mp4', 'http://timg.bdta.pro/images/8db445d73f114ce3c71815d67dc3c3d8.jpg'),
(81387, 5619, 'Pretendente Surpresa S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181524.mp4', 'http://timg.bdta.pro/images/3c8f486d8277bb5b50dbeafb0942756c.jpg'),
(81388, 5619, 'Pretendente Surpresa S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181525.mp4', 'http://timg.bdta.pro/images/b6c42fe455af300cc0daee38db57d95a.jpg'),
(81389, 5619, 'Pretendente Surpresa S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/181526.mp4', 'http://timg.bdta.pro/images/224207b6c625871774626f8028def36e.jpg'),
(81390, 5619, 'Pretendente Surpresa S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/181527.mp4', 'http://timg.bdta.pro/images/8ea57ae68bb904d22b5e2293ed131aa5.jpg'),
(81391, 5620, 'Queen of the Universe S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176950.mp4', 'http://timg.bdta.pro/images/b43473ba185e5f78d041cb19f140a6c8.jpg'),
(81392, 5620, 'Queen of the Universe S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176951.mp4', 'http://timg.bdta.pro/images/b3cc4757b3bf4c87694035f52cc79eb9.jpg'),
(81393, 5620, 'Queen of the Universe S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176952.mp4', 'http://timg.bdta.pro/images/9b3ee94102e13a2975eff98162498ffb.jpg'),
(81394, 5620, 'Queen of the Universe S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176953.mp4', 'http://timg.bdta.pro/images/c61d19962e0282e75b96aad6f444ffd7.jpg'),
(81395, 5620, 'Queen of the Universe S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176954.mp4', 'http://gstaticontent.com/images/e1c63316109b363ba145b450f145f218.jpg'),
(81396, 5620, 'Queen of the Universe S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176955.mp4', 'http://gstaticontent.com/images/e1c63316109b363ba145b450f145f218.jpg'),
(81397, 5621, 'Señorita 89 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175665.mp4', 'http://timg.bdta.pro/images/7434a1a7d09d7840109f8f0531247382.jpg'),
(81398, 5621, 'Señorita 89 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175666.mp4', 'http://timg.bdta.pro/images/2bbd794a9433f8f92e04477c359eb58e.jpg'),
(81399, 5621, 'Señorita 89 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175667.mp4', 'http://timg.bdta.pro/images/e1c3f7e304038a91753a6b7634f04837.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(81400, 5621, 'Señorita 89 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175668.mp4', 'http://timg.bdta.pro/images/082c9059c2a31ef74b66c9449adfec1d.jpg'),
(81401, 5621, 'Señorita 89 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175669.mp4', 'http://timg.bdta.pro/images/57ff91071a001575490139d0e3a3731d.jpg'),
(81402, 5621, 'Señorita 89 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175670.mp4', 'http://gstaticontent.com/images/5d1a3a55804dabb225fb524706fef161.jpg'),
(81403, 5621, 'Señorita 89 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175671.mp4', 'http://gstaticontent.com/images/5d1a3a55804dabb225fb524706fef161.jpg'),
(81404, 5621, 'Señorita 89 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175672.mp4', 'http://gstaticontent.com/images/5d1a3a55804dabb225fb524706fef161.jpg'),
(81405, 5622, 'Señorita 89 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/884043.mp4', 'http://gstaticontent.com/images/5d1a3a55804dabb225fb524706fef161.jpg'),
(81406, 5622, 'Señorita 89 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/884044.mp4', 'http://gstaticontent.com/images/5d1a3a55804dabb225fb524706fef161.jpg'),
(81407, 5622, 'Señorita 89 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/884045.mp4', 'http://gstaticontent.com/images/5d1a3a55804dabb225fb524706fef161.jpg'),
(81408, 5622, 'Señorita 89 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/884046.mp4', 'http://gstaticontent.com/images/5d1a3a55804dabb225fb524706fef161.jpg'),
(81409, 5622, 'Señorita 89 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/884047.mp4', 'http://gstaticontent.com/images/5d1a3a55804dabb225fb524706fef161.jpg'),
(81410, 5622, 'Señorita 89 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/884048.mp4', 'http://gstaticontent.com/images/5d1a3a55804dabb225fb524706fef161.jpg'),
(81411, 5622, 'Señorita 89 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/884049.mp4', 'http://gstaticontent.com/images/5d1a3a55804dabb225fb524706fef161.jpg'),
(81412, 5623, 'Slow Horses S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256779.mp4', 'http://timg.bdta.pro/images/d2db6cb43355c4fd3a012c6a598e12d8.jpg'),
(81413, 5623, 'Slow Horses S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256780.mp4', 'http://timg.bdta.pro/images/d7811ed45b88041937fb65c7dcb74d4a.jpg'),
(81414, 5623, 'Slow Horses S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256781.mp4', 'http://timg.bdta.pro/images/a0504db7f84024a093c62d81e534b48b.jpg'),
(81415, 5623, 'Slow Horses S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256782.mp4', 'http://timg.bdta.pro/images/fb64488b483a9b5e1e43355887c0e558.jpg'),
(81416, 5623, 'Slow Horses S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256783.mp4', 'http://timg.bdta.pro/images/ba1471e714c1414998966d69e822e3d7.jpg'),
(81417, 5623, 'Slow Horses S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256784.mp4', 'http://timg.bdta.pro/images/6b61d43c3f5d3efb6b8a8a715f36a262.jpg'),
(81418, 5624, 'Slow Horses S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/henDWWSmXd0Crdb6YnocCxejO0m.jpg'),
(81419, 5624, 'Slow Horses S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6EH3YmOXblz91dw6H64ZcHpy2H5.jpg'),
(81420, 5624, 'Slow Horses S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256787.mp4', 'http://image.tmdb.org/t/p/w1280/wVV3QZ4S5vNEY6A67oTjPLtfImX.jpg'),
(81421, 5624, 'Slow Horses S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256788.mp4', 'http://image.tmdb.org/t/p/w1280/wCnfdJi05f5GCSNu3GJmOStJPGM.jpg'),
(81422, 5624, 'Slow Horses S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ijk03WqLprKSWfnjO94dEbK04iI.jpg'),
(81423, 5624, 'Slow Horses S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j7NQIxyVruZtOm8i6Q3FjS08OUy.jpg'),
(81424, 5625, 'Slow Horses S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256791.mp4', 'http://gstaticontent.com/images/d13614d5771c2e506c0a2de18ee5fc8a.jpg'),
(81425, 5625, 'Slow Horses S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256792.mp4', 'http://gstaticontent.com/images/d13614d5771c2e506c0a2de18ee5fc8a.jpg'),
(81426, 5625, 'Slow Horses S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256793.mp4', 'http://gstaticontent.com/images/d13614d5771c2e506c0a2de18ee5fc8a.jpg'),
(81427, 5625, 'Slow Horses S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256794.mp4', 'http://gstaticontent.com/images/d13614d5771c2e506c0a2de18ee5fc8a.jpg'),
(81428, 5625, 'Slow Horses S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256795.mp4', 'http://gstaticontent.com/images/d13614d5771c2e506c0a2de18ee5fc8a.jpg'),
(81429, 5625, 'Slow Horses S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256796.mp4', 'http://gstaticontent.com/images/d13614d5771c2e506c0a2de18ee5fc8a.jpg'),
(81430, 5626, 'Slow Horses S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/450012.mp4', 'http://gstaticontent.com/images/d13614d5771c2e506c0a2de18ee5fc8a.jpg'),
(81431, 5626, 'Slow Horses S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/451958.mp4', 'http://gstaticontent.com/images/d13614d5771c2e506c0a2de18ee5fc8a.jpg'),
(81432, 5626, 'Slow Horses S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/457175.mp4', 'http://gstaticontent.com/images/d13614d5771c2e506c0a2de18ee5fc8a.jpg'),
(81433, 5626, 'Slow Horses S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/463693.mp4', 'http://gstaticontent.com/images/d13614d5771c2e506c0a2de18ee5fc8a.jpg'),
(81434, 5626, 'Slow Horses S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/469187.mp4', 'http://gstaticontent.com/images/d13614d5771c2e506c0a2de18ee5fc8a.jpg'),
(81435, 5626, 'Slow Horses S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/484893.mp4', 'http://gstaticontent.com/images/d13614d5771c2e506c0a2de18ee5fc8a.jpg'),
(81436, 5627, 'Slow Horses S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/886059.mp4', 'http://gstaticontent.com/images/d13614d5771c2e506c0a2de18ee5fc8a.jpg'),
(81437, 5627, 'Slow Horses S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/887552.mp4', 'http://gstaticontent.com/images/d13614d5771c2e506c0a2de18ee5fc8a.jpg'),
(81438, 5627, 'Slow Horses S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/888141.mp4', 'http://gstaticontent.com/images/d13614d5771c2e506c0a2de18ee5fc8a.jpg'),
(81439, 5627, 'Slow Horses S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/889614.mp4', 'http://gstaticontent.com/images/d13614d5771c2e506c0a2de18ee5fc8a.jpg'),
(81440, 5627, 'Slow Horses S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/890674.mp4', 'http://gstaticontent.com/images/d13614d5771c2e506c0a2de18ee5fc8a.jpg'),
(81441, 5627, 'Slow Horses S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/890675.mp4', 'http://gstaticontent.com/images/d13614d5771c2e506c0a2de18ee5fc8a.jpg'),
(81442, 5628, 'Supercães S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176941.mp4', 'http://gstaticontent.com/images/8bcfc68cf014dfe9b328bc064e5e1392.jpg'),
(81443, 5628, 'Supercães S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176942.mp4', 'http://gstaticontent.com/images/8bcfc68cf014dfe9b328bc064e5e1392.jpg'),
(81444, 5628, 'Supercães S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176943.mp4', 'http://gstaticontent.com/images/8bcfc68cf014dfe9b328bc064e5e1392.jpg'),
(81445, 5628, 'Supercães S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176944.mp4', 'http://gstaticontent.com/images/8bcfc68cf014dfe9b328bc064e5e1392.jpg'),
(81446, 5628, 'Supercães S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176945.mp4', 'http://gstaticontent.com/images/8bcfc68cf014dfe9b328bc064e5e1392.jpg'),
(81447, 5628, 'Supercães S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176946.mp4', 'http://gstaticontent.com/images/8bcfc68cf014dfe9b328bc064e5e1392.jpg'),
(81448, 5628, 'Supercães S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176947.mp4', 'http://gstaticontent.com/images/8bcfc68cf014dfe9b328bc064e5e1392.jpg'),
(81449, 5628, 'Supercães S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176948.mp4', 'http://gstaticontent.com/images/8bcfc68cf014dfe9b328bc064e5e1392.jpg'),
(81450, 5628, 'Supercães S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176949.mp4', 'http://gstaticontent.com/images/8bcfc68cf014dfe9b328bc064e5e1392.jpg'),
(81451, 5629, 'The Home Edit - A Arte de Organizar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176925.mp4', 'http://gstaticontent.com/images/17f9e2149774144bd9a14e05ec6a242c.jpg'),
(81452, 5629, 'The Home Edit - A Arte de Organizar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176926.mp4', 'http://gstaticontent.com/images/17f9e2149774144bd9a14e05ec6a242c.jpg'),
(81453, 5629, 'The Home Edit - A Arte de Organizar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176927.mp4', 'http://gstaticontent.com/images/17f9e2149774144bd9a14e05ec6a242c.jpg'),
(81454, 5629, 'The Home Edit - A Arte de Organizar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176928.mp4', 'http://gstaticontent.com/images/17f9e2149774144bd9a14e05ec6a242c.jpg'),
(81455, 5629, 'The Home Edit - A Arte de Organizar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176929.mp4', 'http://gstaticontent.com/images/17f9e2149774144bd9a14e05ec6a242c.jpg'),
(81456, 5629, 'The Home Edit - A Arte de Organizar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176930.mp4', 'http://gstaticontent.com/images/17f9e2149774144bd9a14e05ec6a242c.jpg'),
(81457, 5629, 'The Home Edit - A Arte de Organizar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176931.mp4', 'http://gstaticontent.com/images/17f9e2149774144bd9a14e05ec6a242c.jpg'),
(81458, 5629, 'The Home Edit - A Arte de Organizar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176932.mp4', 'http://gstaticontent.com/images/17f9e2149774144bd9a14e05ec6a242c.jpg'),
(81459, 5630, 'The Home Edit - A Arte de Organizar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176933.mp4', 'http://gstaticontent.com/images/17f9e2149774144bd9a14e05ec6a242c.jpg'),
(81460, 5630, 'The Home Edit - A Arte de Organizar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176934.mp4', 'http://gstaticontent.com/images/17f9e2149774144bd9a14e05ec6a242c.jpg'),
(81461, 5630, 'The Home Edit - A Arte de Organizar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176935.mp4', 'http://gstaticontent.com/images/17f9e2149774144bd9a14e05ec6a242c.jpg'),
(81462, 5630, 'The Home Edit - A Arte de Organizar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176936.mp4', 'http://gstaticontent.com/images/17f9e2149774144bd9a14e05ec6a242c.jpg'),
(81463, 5630, 'The Home Edit - A Arte de Organizar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176937.mp4', 'http://gstaticontent.com/images/17f9e2149774144bd9a14e05ec6a242c.jpg'),
(81464, 5630, 'The Home Edit - A Arte de Organizar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176938.mp4', 'http://gstaticontent.com/images/17f9e2149774144bd9a14e05ec6a242c.jpg'),
(81465, 5630, 'The Home Edit - A Arte de Organizar S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176939.mp4', 'http://gstaticontent.com/images/17f9e2149774144bd9a14e05ec6a242c.jpg'),
(81466, 5630, 'The Home Edit - A Arte de Organizar S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176940.mp4', 'http://gstaticontent.com/images/17f9e2149774144bd9a14e05ec6a242c.jpg'),
(81467, 5631, 'The Newsreader S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181510.mp4', 'http://timg.bdta.pro/images/448ae4596c02a720452c3ce9e45d53fb.jpg'),
(81468, 5631, 'The Newsreader S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181511.mp4', 'http://timg.bdta.pro/images/689391a4659f0d09d489220722a8ae48.jpg'),
(81469, 5631, 'The Newsreader S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181512.mp4', 'http://timg.bdta.pro/images/f5a915579cd7e06004a5370881242871.jpg'),
(81470, 5631, 'The Newsreader S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181513.mp4', 'http://timg.bdta.pro/images/be07d2ec193ff97b094778539b5084ff.jpg'),
(81471, 5631, 'The Newsreader S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181514.mp4', 'http://timg.bdta.pro/images/6a7a16e4186d4039c992654e4a72ed47.jpg'),
(81472, 5631, 'The Newsreader S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181515.mp4', 'http://timg.bdta.pro/images/0e70d77f0cfa19a18bfe5156c072477d.jpg'),
(81473, 5632, 'The Newsreader S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/863791.mp4', 'http://gstaticontent.com/images/f5fe4df60f5a05496307a3e49748d08b.jpg'),
(81474, 5632, 'The Newsreader S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/863792.mp4', 'http://gstaticontent.com/images/f5fe4df60f5a05496307a3e49748d08b.jpg'),
(81475, 5632, 'The Newsreader S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/863793.mp4', 'http://gstaticontent.com/images/f5fe4df60f5a05496307a3e49748d08b.jpg'),
(81476, 5632, 'The Newsreader S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/863794.mp4', 'http://gstaticontent.com/images/f5fe4df60f5a05496307a3e49748d08b.jpg'),
(81477, 5632, 'The Newsreader S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/863795.mp4', 'http://gstaticontent.com/images/f5fe4df60f5a05496307a3e49748d08b.jpg'),
(81478, 5632, 'The Newsreader S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/863796.mp4', 'http://gstaticontent.com/images/f5fe4df60f5a05496307a3e49748d08b.jpg'),
(81479, 5633, 'The Newsreader S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/863797.mp4', 'http://gstaticontent.com/images/f5fe4df60f5a05496307a3e49748d08b.jpg'),
(81480, 5633, 'The Newsreader S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/863798.mp4', 'http://gstaticontent.com/images/f5fe4df60f5a05496307a3e49748d08b.jpg'),
(81481, 5633, 'The Newsreader S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/863799.mp4', 'http://gstaticontent.com/images/f5fe4df60f5a05496307a3e49748d08b.jpg'),
(81482, 5633, 'The Newsreader S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/863800.mp4', 'http://gstaticontent.com/images/f5fe4df60f5a05496307a3e49748d08b.jpg'),
(81483, 5633, 'The Newsreader S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/863801.mp4', 'http://gstaticontent.com/images/f5fe4df60f5a05496307a3e49748d08b.jpg'),
(81484, 5633, 'The Newsreader S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/863802.mp4', 'http://gstaticontent.com/images/f5fe4df60f5a05496307a3e49748d08b.jpg'),
(81485, 5634, 'Thermae Romae Novae S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176914.mp4', 'http://timg.bdta.pro/images/b5f13b4269fbbe119195df30e25561cd.jpg'),
(81486, 5634, 'Thermae Romae Novae S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176915.mp4', 'http://timg.bdta.pro/images/1af0482c20c724fc2960c43d89ce0571.jpg'),
(81487, 5634, 'Thermae Romae Novae S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176916.mp4', 'http://timg.bdta.pro/images/fd63a472d9577fe48e2db29c149701af.jpg'),
(81488, 5634, 'Thermae Romae Novae S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176917.mp4', 'http://timg.bdta.pro/images/5333b00a9b9c75a616a2b4514143759e.jpg'),
(81489, 5634, 'Thermae Romae Novae S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176918.mp4', 'http://timg.bdta.pro/images/16ecf1a922a7aa63dde476759157c745.jpg'),
(81490, 5634, 'Thermae Romae Novae S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176919.mp4', 'http://timg.bdta.pro/images/89aeab69cf47026cd1e4a065c5254843.jpg'),
(81491, 5634, 'Thermae Romae Novae S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176920.mp4', 'http://timg.bdta.pro/images/b25c74c5723e33ffec15fa4954c0217a.jpg'),
(81492, 5634, 'Thermae Romae Novae S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176921.mp4', 'http://timg.bdta.pro/images/ab5ba021170bdde3c4f9f38cdaa4a7f3.jpg'),
(81493, 5634, 'Thermae Romae Novae S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176922.mp4', 'http://timg.bdta.pro/images/ccbb24e19d23d210aed0e69103b5af78.jpg'),
(81494, 5634, 'Thermae Romae Novae S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176923.mp4', 'http://timg.bdta.pro/images/a8b0749b665fbe4bee8bc90a18dfddee.jpg'),
(81495, 5634, 'Thermae Romae Novae S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/176924.mp4', 'http://timg.bdta.pro/images/da2c126745e7d154d3936d18ff3cffc7.jpg'),
(81496, 5635, 'A Faxineira S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202873.mp4', 'http://timg.bdta.pro/images/1541193ab22768f882bdae026ea94b90.jpg'),
(81497, 5635, 'A Faxineira S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202874.mp4', 'http://timg.bdta.pro/images/9f13ee16548eb793ec1ae304a36844fb.jpg'),
(81498, 5635, 'A Faxineira S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202875.mp4', 'http://timg.bdta.pro/images/b0f4b36e4db65b7f6f42e40c460d7c35.jpg'),
(81499, 5635, 'A Faxineira S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202876.mp4', 'http://timg.bdta.pro/images/83565bcd4054ea13795721e385f961b8.jpg'),
(81500, 5635, 'A Faxineira S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202877.mp4', 'http://timg.bdta.pro/images/eafdd5099409d5c8763b6bdda92e9c9a.jpg'),
(81501, 5635, 'A Faxineira S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202878.mp4', 'http://timg.bdta.pro/images/1e9cf68122370c81efb6efb713cc4ec3.jpg'),
(81502, 5635, 'A Faxineira S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202879.mp4', 'http://timg.bdta.pro/images/c95d8f77f4590c193f447fdd25763abd.jpg'),
(81503, 5635, 'A Faxineira S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202880.mp4', 'http://timg.bdta.pro/images/189a356abe63e988c9bc260d34cdb2d0.jpg'),
(81504, 5635, 'A Faxineira S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202881.mp4', 'http://timg.bdta.pro/images/d33515d9687b5fbadcb446c4f39ae418.jpg'),
(81505, 5635, 'A Faxineira S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202882.mp4', 'http://timg.bdta.pro/images/a66e4bc56d079bc47c70c2ac43d460d6.jpg'),
(81506, 5636, 'A Faxineira S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cVigD7qxQiCr9swyhsl6vtkM91R.jpg'),
(81507, 5636, 'A Faxineira S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hfMivH5HCCybpFRBBHgKR4PY5Nl.jpg'),
(81508, 5636, 'A Faxineira S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/suLtbmmvusOu9jA6cdJuZAELUlq.jpg'),
(81509, 5636, 'A Faxineira S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eZ9nlvcUBso7aXfEVj2aLHCrGr.jpg'),
(81510, 5636, 'A Faxineira S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iV28X7t9n0n00sMOmfyx2ZMSl4Z.jpg'),
(81511, 5636, 'A Faxineira S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKmCgEvH8l1bFLHhpqf94aUJhCM.jpg'),
(81512, 5636, 'A Faxineira S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202889.mp4', 'http://image.tmdb.org/t/p/w1280/eIfzZRKgT8Ycvafh9OCLs9M9siC.jpg'),
(81513, 5636, 'A Faxineira S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9YLQGfCBjEnJH9WDMsyHNaN1DeN.jpg'),
(81514, 5636, 'A Faxineira S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lMn4UaHSH1Jv2Lw5r5CvcqGrzK.jpg'),
(81515, 5636, 'A Faxineira S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q8vLiC1N2Si0XJVRLSwYmbhee41.jpg'),
(81516, 5636, 'A Faxineira S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rwzgxQFC8jSh4ck6rJoPdPXxV70.jpg'),
(81517, 5636, 'A Faxineira S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nXikce1NFghilKSuWqg6WdqafuC.jpg'),
(81518, 5637, 'A Faxineira S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/305610.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81519, 5637, 'A Faxineira S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/313428.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81520, 5637, 'A Faxineira S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326352.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81521, 5637, 'A Faxineira S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/388197.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81522, 5637, 'A Faxineira S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/388198.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81523, 5637, 'A Faxineira S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/388199.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81524, 5637, 'A Faxineira S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/388200.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81525, 5637, 'A Faxineira S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/388201.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81526, 5637, 'A Faxineira S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/388202.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81527, 5637, 'A Faxineira S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/388203.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81528, 5637, 'A Faxineira S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/388204.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81529, 5637, 'A Faxineira S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/388205.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81530, 5638, 'A Faxineira S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/761945.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81531, 5638, 'A Faxineira S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/768831.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81532, 5638, 'A Faxineira S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/771476.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81533, 5638, 'A Faxineira S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/781710.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81534, 5638, 'A Faxineira S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/795167.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81535, 5638, 'A Faxineira S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/796267.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81536, 5638, 'A Faxineira S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/801492.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81537, 5638, 'A Faxineira S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/814465.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81538, 5638, 'A Faxineira S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/822782.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81539, 5638, 'A Faxineira S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/828323.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81540, 5638, 'A Faxineira S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/842062.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81541, 5638, 'A Faxineira S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/847828.mp4', 'http://gstaticontent.com/images/b6f324f15769d5521f6c9f566d70d4ee.jpg'),
(81542, 5639, 'A Retaliação S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176190.mp4', 'http://timg.bdta.pro/images/2fd7ee55ce96aebadb374462c9c09599.jpg'),
(81543, 5639, 'A Retaliação S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176191.mp4', 'http://timg.bdta.pro/images/7e0c19aa8b7941233489da99790ac74f.jpg'),
(81544, 5639, 'A Retaliação S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176192.mp4', 'http://timg.bdta.pro/images/8771bb213cadbac7afb6a5c837c8ce98.jpg'),
(81545, 5639, 'A Retaliação S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176193.mp4', 'http://timg.bdta.pro/images/aa62edf7bf0374d3eeb7c97d5f299c68.jpg'),
(81546, 5639, 'A Retaliação S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176194.mp4', 'http://timg.bdta.pro/images/bbf181bcf3c81d530261224f4c3910de.jpg'),
(81547, 5639, 'A Retaliação S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176195.mp4', 'http://timg.bdta.pro/images/7b1f1461b154d44f3ad02bccd2fdbb96.jpg'),
(81548, 5639, 'A Retaliação S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176196.mp4', 'http://timg.bdta.pro/images/22c94a7d3cdf6017e967271cfe154d50.jpg'),
(81549, 5639, 'A Retaliação S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176197.mp4', 'http://timg.bdta.pro/images/269915d58f15f47c649b6c16996beb57.jpg'),
(81550, 5640, 'Disque Prazer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176184.mp4', 'http://timg.bdta.pro/images/cc90131feab04360ad57d2eeb6b46cec.jpg'),
(81551, 5640, 'Disque Prazer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176185.mp4', 'http://timg.bdta.pro/images/94bddcbe887951465f20e0c32640e117.jpg'),
(81552, 5640, 'Disque Prazer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176186.mp4', 'http://timg.bdta.pro/images/b0676387c7a3986d00a8db5f6175bf4e.jpg'),
(81553, 5640, 'Disque Prazer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176187.mp4', 'http://timg.bdta.pro/images/9c81b2944783c2591e97a6df2b083e38.jpg'),
(81554, 5640, 'Disque Prazer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176188.mp4', 'http://timg.bdta.pro/images/050152281c775243e70ea28087bd100b.jpg'),
(81555, 5640, 'Disque Prazer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176189.mp4', 'http://timg.bdta.pro/images/d9fbd5a9ff5a285f062013a278bcfba7.jpg'),
(81556, 5641, 'Our Kind of People S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176172.mp4', 'http://timg.bdta.pro/images/3a8cf55d6d6f59fbb92a755b13a62764.jpg'),
(81557, 5641, 'Our Kind of People S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176173.mp4', 'http://timg.bdta.pro/images/9f4fbc99a8943e52ec81ff892210e174.jpg'),
(81558, 5641, 'Our Kind of People S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176174.mp4', 'http://timg.bdta.pro/images/5c7cc0f05c08f018092f6f28e893a420.jpg'),
(81559, 5641, 'Our Kind of People S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176175.mp4', 'http://timg.bdta.pro/images/d9f8a8081cabe825254741e85f0086cd.jpg'),
(81560, 5641, 'Our Kind of People S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176176.mp4', 'http://gstaticontent.com/images/709c23d3f4c1000a8fbb3e4f9537b340.jpg'),
(81561, 5641, 'Our Kind of People S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176177.mp4', 'http://gstaticontent.com/images/709c23d3f4c1000a8fbb3e4f9537b340.jpg'),
(81562, 5641, 'Our Kind of People S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176178.mp4', 'http://gstaticontent.com/images/709c23d3f4c1000a8fbb3e4f9537b340.jpg'),
(81563, 5641, 'Our Kind of People S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176179.mp4', 'http://gstaticontent.com/images/709c23d3f4c1000a8fbb3e4f9537b340.jpg'),
(81564, 5641, 'Our Kind of People S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176180.mp4', 'http://gstaticontent.com/images/709c23d3f4c1000a8fbb3e4f9537b340.jpg'),
(81565, 5641, 'Our Kind of People S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176181.mp4', 'http://gstaticontent.com/images/709c23d3f4c1000a8fbb3e4f9537b340.jpg'),
(81566, 5641, 'Our Kind of People S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/176182.mp4', 'http://gstaticontent.com/images/709c23d3f4c1000a8fbb3e4f9537b340.jpg'),
(81567, 5641, 'Our Kind of People S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/176183.mp4', 'http://gstaticontent.com/images/709c23d3f4c1000a8fbb3e4f9537b340.jpg'),
(81568, 5642, 'Segredos e Crimes de Jimmy Savile S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176170.mp4', 'http://gstaticontent.com/images/d5767cadbb8e762ce94104f21aa265d3.jpg'),
(81569, 5642, 'Segredos e Crimes de Jimmy Savile S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176171.mp4', 'http://gstaticontent.com/images/d5767cadbb8e762ce94104f21aa265d3.jpg'),
(81570, 5643, 'Senzo: Murder of a Soccer Star S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176165.mp4', 'http://gstaticontent.com/images/47c5ecb94bde9bd4e57258d108c9b5f2.jpg'),
(81571, 5643, 'Senzo: Murder of a Soccer Star S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176166.mp4', 'http://gstaticontent.com/images/47c5ecb94bde9bd4e57258d108c9b5f2.jpg'),
(81572, 5643, 'Senzo: Murder of a Soccer Star S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176167.mp4', 'http://gstaticontent.com/images/47c5ecb94bde9bd4e57258d108c9b5f2.jpg'),
(81573, 5643, 'Senzo: Murder of a Soccer Star S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176168.mp4', 'http://gstaticontent.com/images/47c5ecb94bde9bd4e57258d108c9b5f2.jpg'),
(81574, 5643, 'Senzo: Murder of a Soccer Star S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176169.mp4', 'http://gstaticontent.com/images/47c5ecb94bde9bd4e57258d108c9b5f2.jpg'),
(81575, 5644, 'Ted Bundy As Sobreviventes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176161.mp4', 'http://gstaticontent.com/images/203e5671fc2585d16a795b13d753feef.png'),
(81576, 5644, 'Ted Bundy As Sobreviventes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176162.mp4', 'http://gstaticontent.com/images/203e5671fc2585d16a795b13d753feef.png'),
(81577, 5644, 'Ted Bundy As Sobreviventes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176163.mp4', 'http://gstaticontent.com/images/203e5671fc2585d16a795b13d753feef.png'),
(81578, 5644, 'Ted Bundy As Sobreviventes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176164.mp4', 'http://gstaticontent.com/images/203e5671fc2585d16a795b13d753feef.png'),
(81579, 5645, 'Terapia Alternativa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176151.mp4', 'http://timg.bdta.pro/images/460856a29d64d051f0ff9366c282d19b.jpg'),
(81580, 5645, 'Terapia Alternativa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176152.mp4', 'http://timg.bdta.pro/images/c7710002c7ada6ab197d4142fec50257.jpg'),
(81581, 5645, 'Terapia Alternativa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176153.mp4', 'http://timg.bdta.pro/images/08b8cd27ed635de881d2a3fea5b8ca20.jpg'),
(81582, 5645, 'Terapia Alternativa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176154.mp4', 'http://timg.bdta.pro/images/30486e453c858ab0af2919e1ec86ffe7.jpg'),
(81583, 5645, 'Terapia Alternativa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176155.mp4', 'http://timg.bdta.pro/images/de31e3568531b9544502c9fac35164a2.jpg'),
(81584, 5645, 'Terapia Alternativa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176156.mp4', 'http://timg.bdta.pro/images/7fdd161876aee7553e2a5d935e830ced.jpg'),
(81585, 5645, 'Terapia Alternativa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176157.mp4', 'http://timg.bdta.pro/images/2763e874aaef51e6525618bb5d594b28.jpg'),
(81586, 5645, 'Terapia Alternativa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176158.mp4', 'http://timg.bdta.pro/images/00312c20077d1a34b637c8317b5b98cc.jpg'),
(81587, 5645, 'Terapia Alternativa S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176159.mp4', 'http://timg.bdta.pro/images/2fc86ceb366e89527ef80dbaf5c6282c.jpg'),
(81588, 5645, 'Terapia Alternativa S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176160.mp4', 'http://timg.bdta.pro/images/822602d4ca0686828e8b4cc4b512a0cb.jpg'),
(81589, 5646, 'The Big Leap S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176140.mp4', 'http://timg.bdta.pro/images/fb2a4cb11b8d9ccb19315e968d84b175.jpg'),
(81590, 5646, 'The Big Leap S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176141.mp4', 'http://timg.bdta.pro/images/37f02adfd6b945c9fcc72de6e2129c3f.jpg'),
(81591, 5646, 'The Big Leap S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176142.mp4', 'http://timg.bdta.pro/images/4b07624d59f8329c80c11529a90e8b65.jpg'),
(81592, 5646, 'The Big Leap S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176143.mp4', 'http://timg.bdta.pro/images/2daf6c0a4caab39178bfa1a51b4c05f4.jpg'),
(81593, 5646, 'The Big Leap S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176144.mp4', 'http://timg.bdta.pro/images/edb002196daccbf71087503d02b9df16.jpg'),
(81594, 5646, 'The Big Leap S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176145.mp4', 'http://timg.bdta.pro/images/c98f48de9660b679e34bd7d761c9984a.jpg'),
(81595, 5646, 'The Big Leap S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176146.mp4', 'http://timg.bdta.pro/images/86f5a25b3f528477ee05c21364110c9c.jpg'),
(81596, 5646, 'The Big Leap S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/176147.mp4', 'http://timg.bdta.pro/images/fb0a751d2da7b8ae8ea41f16589c32e5.jpg'),
(81597, 5646, 'The Big Leap S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/176148.mp4', 'http://timg.bdta.pro/images/7b8f7503cbf88875b62088c7582bc14e.jpg'),
(81598, 5646, 'The Big Leap S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/176149.mp4', 'http://timg.bdta.pro/images/f55c3f2db1a8920567adbf6c7e634284.jpg'),
(81599, 5646, 'The Big Leap S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/176150.mp4', 'http://gstaticontent.com/images/f1e483dde66a2c2b545391e8f7860ec6.jpg'),
(81600, 5647, 'The Hardy Boys S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199439.mp4', 'http://timg.bdta.pro/images/986c2a3dfa8947448df557913d984ecf.jpg'),
(81601, 5647, 'The Hardy Boys S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199440.mp4', 'http://timg.bdta.pro/images/1b12390699372a653b052a648120ef3b.jpg'),
(81602, 5647, 'The Hardy Boys S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199441.mp4', 'http://timg.bdta.pro/images/2966e3a23fffdeddc076e26449fdf48b.jpg'),
(81603, 5647, 'The Hardy Boys S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199442.mp4', 'http://timg.bdta.pro/images/6d681efa1021f445c39280fde2181238.jpg'),
(81604, 5647, 'The Hardy Boys S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199443.mp4', 'http://timg.bdta.pro/images/8b1fd737afc4313002d942d6cfce8f3e.jpg'),
(81605, 5647, 'The Hardy Boys S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199444.mp4', 'http://timg.bdta.pro/images/88d25db6d300cb4a507b456c8139cbd3.jpg'),
(81606, 5647, 'The Hardy Boys S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199445.mp4', 'http://timg.bdta.pro/images/cd19e64dd7159525db006a22af959848.jpg'),
(81607, 5647, 'The Hardy Boys S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199446.mp4', 'http://timg.bdta.pro/images/deda8297e2bfe6c5de39ad433c978b46.jpg'),
(81608, 5647, 'The Hardy Boys S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199447.mp4', 'http://timg.bdta.pro/images/f51c3a71ca4b9aa46cb476966eba3075.jpg'),
(81609, 5647, 'The Hardy Boys S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199448.mp4', 'http://timg.bdta.pro/images/b679193f3dc93150b81077c9f2265ef7.jpg'),
(81610, 5647, 'The Hardy Boys S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199449.mp4', 'http://timg.bdta.pro/images/56633d9579d1ae0c8e60d69795e8cd87.jpg'),
(81611, 5647, 'The Hardy Boys S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199450.mp4', 'http://timg.bdta.pro/images/7fd3b23dd18d24c318ab68116e3f60a1.jpg'),
(81612, 5647, 'The Hardy Boys S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/199451.mp4', 'http://timg.bdta.pro/images/47bc8c1dc3ba51ddc9754e3020406bb2.jpg'),
(81613, 5648, 'The Hardy Boys S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199452.mp4', 'http://timg.bdta.pro/images/a2550f1df3e7844be6d6c9acbf94d4d7.jpg'),
(81614, 5648, 'The Hardy Boys S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199453.mp4', 'http://timg.bdta.pro/images/dfc6e7eeeeb9a5383b95153385e92055.jpg'),
(81615, 5648, 'The Hardy Boys S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199454.mp4', 'http://timg.bdta.pro/images/267e7ae519f9bef3ffcdb0b645af39db.jpg'),
(81616, 5648, 'The Hardy Boys S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199455.mp4', 'http://timg.bdta.pro/images/acfaad523e6ecadc7eecd4075547bcd2.jpg'),
(81617, 5648, 'The Hardy Boys S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199456.mp4', 'http://timg.bdta.pro/images/31370c4e54efdab388a6c581ac1d71ef.jpg'),
(81618, 5648, 'The Hardy Boys S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199457.mp4', 'http://timg.bdta.pro/images/09c6c32683728cea9a52e6b9ce6df628.jpg'),
(81619, 5648, 'The Hardy Boys S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199458.mp4', 'http://timg.bdta.pro/images/1e6fe8f916954078a411fb0d560515dd.jpg'),
(81620, 5648, 'The Hardy Boys S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199459.mp4', 'http://timg.bdta.pro/images/8003430f79d49b8aee8bb40f793ecd76.jpg'),
(81621, 5648, 'The Hardy Boys S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199460.mp4', 'http://timg.bdta.pro/images/8f748a1d4b7a3526ba7488efce719064.jpg'),
(81622, 5648, 'The Hardy Boys S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199461.mp4', 'http://timg.bdta.pro/images/86efa8a8dd343236e9028e7c80aa00f8.jpg'),
(81623, 5649, 'The Hardy Boys S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/753415.mp4', 'http://gstaticontent.com/images/b82e76d0053b18e3eb78fded0c99d8ec.jpg'),
(81624, 5649, 'The Hardy Boys S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/753416.mp4', 'http://gstaticontent.com/images/b82e76d0053b18e3eb78fded0c99d8ec.jpg'),
(81625, 5649, 'The Hardy Boys S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/753417.mp4', 'http://gstaticontent.com/images/b82e76d0053b18e3eb78fded0c99d8ec.jpg'),
(81626, 5649, 'The Hardy Boys S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/753418.mp4', 'http://gstaticontent.com/images/b82e76d0053b18e3eb78fded0c99d8ec.jpg'),
(81627, 5649, 'The Hardy Boys S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/753419.mp4', 'http://gstaticontent.com/images/b82e76d0053b18e3eb78fded0c99d8ec.jpg'),
(81628, 5649, 'The Hardy Boys S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/753420.mp4', 'http://gstaticontent.com/images/b82e76d0053b18e3eb78fded0c99d8ec.jpg'),
(81629, 5649, 'The Hardy Boys S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/753421.mp4', 'http://gstaticontent.com/images/b82e76d0053b18e3eb78fded0c99d8ec.jpg'),
(81630, 5649, 'The Hardy Boys S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/753422.mp4', 'http://gstaticontent.com/images/b82e76d0053b18e3eb78fded0c99d8ec.jpg'),
(81631, 5650, 'This Is Going to Hurt S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/176133.mp4', 'http://timg.bdta.pro/images/8fc371a3659ac92811c8a03dcd5dc60a.jpg'),
(81632, 5650, 'This Is Going to Hurt S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/176134.mp4', 'http://timg.bdta.pro/images/8b9203e27f0c39ff6844d59493d2d344.jpg'),
(81633, 5650, 'This Is Going to Hurt S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/176135.mp4', 'http://timg.bdta.pro/images/3554f53b6a8ebc7ca51515d746841098.jpg'),
(81634, 5650, 'This Is Going to Hurt S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/176136.mp4', 'http://timg.bdta.pro/images/ba1e39913c77a4e6b55610f19d7fa494.jpg'),
(81635, 5650, 'This Is Going to Hurt S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/176137.mp4', 'http://timg.bdta.pro/images/0635087d6f0c86667b8203105ee29a62.jpg'),
(81636, 5650, 'This Is Going to Hurt S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/176138.mp4', 'http://timg.bdta.pro/images/65aaa253c945cde081bbae2118be376b.jpg'),
(81637, 5650, 'This Is Going to Hurt S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/176139.mp4', 'http://timg.bdta.pro/images/e4b7c8a30e6dc6502f77c2790407e9d7.jpg'),
(81638, 5651, 'A Sogra Que Te Pariu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212191.mp4', 'http://gstaticontent.com/images/0e66559702d03959216268524778d7db.jpg'),
(81639, 5651, 'A Sogra Que Te Pariu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212192.mp4', 'http://gstaticontent.com/images/0e66559702d03959216268524778d7db.jpg'),
(81640, 5651, 'A Sogra Que Te Pariu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212193.mp4', 'http://gstaticontent.com/images/0e66559702d03959216268524778d7db.jpg'),
(81641, 5651, 'A Sogra Que Te Pariu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212194.mp4', 'http://gstaticontent.com/images/0e66559702d03959216268524778d7db.jpg'),
(81642, 5651, 'A Sogra Que Te Pariu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212195.mp4', 'http://gstaticontent.com/images/0e66559702d03959216268524778d7db.jpg'),
(81643, 5651, 'A Sogra Que Te Pariu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212196.mp4', 'http://gstaticontent.com/images/0e66559702d03959216268524778d7db.jpg'),
(81644, 5651, 'A Sogra Que Te Pariu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212197.mp4', 'http://gstaticontent.com/images/0e66559702d03959216268524778d7db.jpg'),
(81645, 5651, 'A Sogra Que Te Pariu S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212198.mp4', 'http://gstaticontent.com/images/0e66559702d03959216268524778d7db.jpg'),
(81646, 5651, 'A Sogra Que Te Pariu S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212199.mp4', 'http://gstaticontent.com/images/0e66559702d03959216268524778d7db.jpg'),
(81647, 5651, 'A Sogra Que Te Pariu S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212200.mp4', 'http://gstaticontent.com/images/0e66559702d03959216268524778d7db.jpg'),
(81648, 5652, 'A Sogra Que Te Pariu S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sv71mfwsJ4uCoYtU1caV4flq8W1.jpg'),
(81649, 5652, 'A Sogra Que Te Pariu S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Au9plCQ2YSaEnIH1HQoJh9U5kMD.jpg'),
(81650, 5652, 'A Sogra Que Te Pariu S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k5cu1aB4xaqQPtwVFaYYgjLCUGv.jpg'),
(81651, 5652, 'A Sogra Que Te Pariu S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvQPR0pJdlEwYmXaUzau9wRg79N.jpg'),
(81652, 5652, 'A Sogra Que Te Pariu S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u1B0wMA1OgmYqQ0zaBDWNKWfNFL.jpg'),
(81653, 5652, 'A Sogra Que Te Pariu S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gDbGT26FFbeyy7Uw87EsXT58klY.jpg'),
(81654, 5652, 'A Sogra Que Te Pariu S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3DeaYgSlEpIFaeMyq8hZxnZbkW.jpg'),
(81655, 5652, 'A Sogra Que Te Pariu S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nLyzykvm2pboixadwXX24keOL6i.jpg'),
(81656, 5652, 'A Sogra Que Te Pariu S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fE2yfR2qUOrr5kxuf4B9yNYR4pj.jpg'),
(81657, 5652, 'A Sogra Que Te Pariu S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ofwqQ2ncHyp2jO7aWQKNEJB0ADA.jpg'),
(81658, 5653, 'Além da Margem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181638.mp4', 'http://timg.bdta.pro/images/0f8d37505a9c202330c0637cb16937ac.jpg'),
(81659, 5653, 'Além da Margem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181639.mp4', 'http://timg.bdta.pro/images/fbb6c34697be2072acc9ed0acc30fe29.jpg'),
(81660, 5653, 'Além da Margem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181640.mp4', 'http://timg.bdta.pro/images/715b0b9f385caa8e4ac481b498441066.jpg'),
(81661, 5653, 'Além da Margem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181641.mp4', 'http://timg.bdta.pro/images/6edb3a399aaee6644dd49aa65ef00b6d.jpg'),
(81662, 5653, 'Além da Margem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181642.mp4', 'http://timg.bdta.pro/images/57bf8e6437bed40e173c0c0159f6cd32.jpg'),
(81663, 5653, 'Além da Margem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181643.mp4', 'http://timg.bdta.pro/images/ad55705722bb92be319e3d9f1faaccbe.jpg'),
(81664, 5653, 'Além da Margem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181644.mp4', 'http://timg.bdta.pro/images/28a6b9129d7d84d496d86c0a5102d3e5.jpg'),
(81665, 5653, 'Além da Margem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181645.mp4', 'http://timg.bdta.pro/images/c0d07cc69bcfede147a002f018113b54.jpg'),
(81666, 5654, 'Além da Margem S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353322.mp4', 'http://gstaticontent.com/images/87ae28b48416574c263f72d3c622e517.jpg'),
(81667, 5654, 'Além da Margem S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353323.mp4', 'http://gstaticontent.com/images/87ae28b48416574c263f72d3c622e517.jpg'),
(81668, 5654, 'Além da Margem S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353324.mp4', 'http://gstaticontent.com/images/87ae28b48416574c263f72d3c622e517.jpg'),
(81669, 5654, 'Além da Margem S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353325.mp4', 'http://gstaticontent.com/images/87ae28b48416574c263f72d3c622e517.jpg'),
(81670, 5654, 'Além da Margem S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353326.mp4', 'http://gstaticontent.com/images/87ae28b48416574c263f72d3c622e517.jpg'),
(81671, 5654, 'Além da Margem S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353327.mp4', 'http://gstaticontent.com/images/87ae28b48416574c263f72d3c622e517.jpg'),
(81672, 5654, 'Além da Margem S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353328.mp4', 'http://gstaticontent.com/images/87ae28b48416574c263f72d3c622e517.jpg'),
(81673, 5655, 'Anjos Ignorantes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175651.mp4', 'http://timg.bdta.pro/images/401b6313a4d1292984c1ac63a3a2199f.jpg'),
(81674, 5655, 'Anjos Ignorantes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175652.mp4', 'http://timg.bdta.pro/images/1462d37a9c06cbc91fcf129cb83dad53.jpg'),
(81675, 5655, 'Anjos Ignorantes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175653.mp4', 'http://timg.bdta.pro/images/868b006bc31effa1dbf768a2e7940ab5.jpg'),
(81676, 5655, 'Anjos Ignorantes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175654.mp4', 'http://timg.bdta.pro/images/b69c883951d7b6995dadae8bf19f9ccd.jpg'),
(81677, 5655, 'Anjos Ignorantes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175655.mp4', 'http://timg.bdta.pro/images/ef5e66fa2cbeef030e245cc9c833da3a.jpg'),
(81678, 5655, 'Anjos Ignorantes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175656.mp4', 'http://timg.bdta.pro/images/49c2a499454b795e6296506752ee7b62.jpg'),
(81679, 5655, 'Anjos Ignorantes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175657.mp4', 'http://timg.bdta.pro/images/127907c4c05f8de17accfdddd83914cb.jpg'),
(81680, 5655, 'Anjos Ignorantes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175658.mp4', 'http://timg.bdta.pro/images/3f9f7d40973ee8717e59c460073e0b64.jpg'),
(81681, 5656, 'Chewing Gum [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175639.mp4', 'http://timg.bdta.pro/images/b351cf5165bb000b4116ae1558684359.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(81682, 5656, 'Chewing Gum [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175640.mp4', 'http://timg.bdta.pro/images/44bd38ee1600a89014c719acfbd07540.jpg'),
(81683, 5656, 'Chewing Gum [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175641.mp4', 'http://timg.bdta.pro/images/548f9bdd52f5bc49a34f935790640764.jpg'),
(81684, 5656, 'Chewing Gum [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175642.mp4', 'http://timg.bdta.pro/images/266658f6eaf579f57bc88bb6e7bdd0be.jpg'),
(81685, 5656, 'Chewing Gum [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175643.mp4', 'http://timg.bdta.pro/images/5de995ec1fead4b0ef0dcd449a731be8.jpg'),
(81686, 5656, 'Chewing Gum [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175644.mp4', 'http://timg.bdta.pro/images/dcd489974b4dfad0f06ed8aa3db6b5ff.jpg'),
(81687, 5657, 'Chewing Gum [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175645.mp4', 'http://timg.bdta.pro/images/440cbe819a1cc8fa81307f05945e631b.jpg'),
(81688, 5657, 'Chewing Gum [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175646.mp4', 'http://timg.bdta.pro/images/c79044732351d25e0e404759ecfa7629.jpg'),
(81689, 5657, 'Chewing Gum [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175647.mp4', 'http://timg.bdta.pro/images/28af46a8c99a804013d30fbdab350d7f.jpg'),
(81690, 5657, 'Chewing Gum [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175648.mp4', 'http://timg.bdta.pro/images/112402369dc0ee535ed318bc56edaded.jpg'),
(81691, 5657, 'Chewing Gum [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175649.mp4', 'http://timg.bdta.pro/images/9b6f40c8ab65413d68870a60b4c62103.jpg'),
(81692, 5657, 'Chewing Gum [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175650.mp4', 'http://timg.bdta.pro/images/0bf763bcd5431368ec7f9385ca831113.jpg'),
(81693, 5658, 'Como Sobreviver Solteiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175621.mp4', 'http://timg.bdta.pro/images/c12d5b388fa6f818b4bb4b8fb5030edd.jpg'),
(81694, 5658, 'Como Sobreviver Solteiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175622.mp4', 'http://timg.bdta.pro/images/3e13def743821c4c91d00f71f87666d9.jpg'),
(81695, 5658, 'Como Sobreviver Solteiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175623.mp4', 'http://timg.bdta.pro/images/458fee3f22980b86eb1e91d42b899478.jpg'),
(81696, 5658, 'Como Sobreviver Solteiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175624.mp4', 'http://timg.bdta.pro/images/55d4d01d1137205b9312abc361eb1b55.jpg'),
(81697, 5658, 'Como Sobreviver Solteiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175625.mp4', 'http://timg.bdta.pro/images/b7ece12b1cea004d36d979d2a87c1d21.jpg'),
(81698, 5658, 'Como Sobreviver Solteiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175626.mp4', 'http://timg.bdta.pro/images/a7dd48cebc3e55419cdc6d4dc9cfa4fb.jpg'),
(81699, 5658, 'Como Sobreviver Solteiro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175627.mp4', 'http://timg.bdta.pro/images/1b380a3649965734813c58910bc377d9.jpg'),
(81700, 5658, 'Como Sobreviver Solteiro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175628.mp4', 'http://timg.bdta.pro/images/2bfed3d87efbb21ad9b7c747bc9b71e4.jpg'),
(81701, 5658, 'Como Sobreviver Solteiro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/175629.mp4', 'http://timg.bdta.pro/images/2efb9193c7a4d3b23b65f045d1efc6af.jpg'),
(81702, 5658, 'Como Sobreviver Solteiro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/175630.mp4', 'http://timg.bdta.pro/images/e28c1c3a9067d06519b1f4d0cd6121f3.jpg'),
(81703, 5659, 'Como Sobreviver Solteiro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175631.mp4', 'http://gstaticontent.com/images/b8866e67fa90f1c279c7ce8a7d523acb.jpg'),
(81704, 5659, 'Como Sobreviver Solteiro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175632.mp4', 'http://gstaticontent.com/images/b8866e67fa90f1c279c7ce8a7d523acb.jpg'),
(81705, 5659, 'Como Sobreviver Solteiro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175633.mp4', 'http://gstaticontent.com/images/b8866e67fa90f1c279c7ce8a7d523acb.jpg'),
(81706, 5659, 'Como Sobreviver Solteiro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175634.mp4', 'http://gstaticontent.com/images/b8866e67fa90f1c279c7ce8a7d523acb.jpg'),
(81707, 5659, 'Como Sobreviver Solteiro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175635.mp4', 'http://gstaticontent.com/images/b8866e67fa90f1c279c7ce8a7d523acb.jpg'),
(81708, 5659, 'Como Sobreviver Solteiro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175636.mp4', 'http://gstaticontent.com/images/b8866e67fa90f1c279c7ce8a7d523acb.jpg'),
(81709, 5659, 'Como Sobreviver Solteiro S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/175637.mp4', 'http://gstaticontent.com/images/b8866e67fa90f1c279c7ce8a7d523acb.jpg'),
(81710, 5659, 'Como Sobreviver Solteiro S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/175638.mp4', 'http://gstaticontent.com/images/b8866e67fa90f1c279c7ce8a7d523acb.jpg'),
(81711, 5660, 'Como Sobreviver Solteiro S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/444797.mp4', 'http://gstaticontent.com/images/b8866e67fa90f1c279c7ce8a7d523acb.jpg'),
(81712, 5660, 'Como Sobreviver Solteiro S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/444798.mp4', 'http://gstaticontent.com/images/b8866e67fa90f1c279c7ce8a7d523acb.jpg'),
(81713, 5660, 'Como Sobreviver Solteiro S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/444799.mp4', 'http://gstaticontent.com/images/b8866e67fa90f1c279c7ce8a7d523acb.jpg'),
(81714, 5660, 'Como Sobreviver Solteiro S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/444800.mp4', 'http://gstaticontent.com/images/b8866e67fa90f1c279c7ce8a7d523acb.jpg'),
(81715, 5660, 'Como Sobreviver Solteiro S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/444801.mp4', 'http://gstaticontent.com/images/b8866e67fa90f1c279c7ce8a7d523acb.jpg'),
(81716, 5660, 'Como Sobreviver Solteiro S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/444802.mp4', 'http://gstaticontent.com/images/b8866e67fa90f1c279c7ce8a7d523acb.jpg'),
(81717, 5660, 'Como Sobreviver Solteiro S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/444803.mp4', 'http://gstaticontent.com/images/b8866e67fa90f1c279c7ce8a7d523acb.jpg'),
(81718, 5660, 'Como Sobreviver Solteiro S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/444804.mp4', 'http://gstaticontent.com/images/b8866e67fa90f1c279c7ce8a7d523acb.jpg'),
(81719, 5661, 'Crossing Swords S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181798.mp4', 'http://timg.bdta.pro/images/3d1d2afeb557c95317dd193371103a47.jpg'),
(81720, 5661, 'Crossing Swords S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181799.mp4', 'http://timg.bdta.pro/images/1a49d4748bc56bfc37fd440fc971426e.jpg'),
(81721, 5661, 'Crossing Swords S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181800.mp4', 'http://timg.bdta.pro/images/9f7ac6b0fed5da0ac3b5bde3ff864d79.jpg'),
(81722, 5661, 'Crossing Swords S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181801.mp4', 'http://timg.bdta.pro/images/d1e668d50b0d84c766d6dae7dfd67e6a.jpg'),
(81723, 5661, 'Crossing Swords S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181802.mp4', 'http://timg.bdta.pro/images/e9c0baa5ace6294d301e141f12c452a5.jpg'),
(81724, 5661, 'Crossing Swords S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181803.mp4', 'http://timg.bdta.pro/images/686eac362444e0d0d4030b9860dee176.jpg'),
(81725, 5661, 'Crossing Swords S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181804.mp4', 'http://timg.bdta.pro/images/f7516efb6370b600c47010fb6706af4a.jpg'),
(81726, 5661, 'Crossing Swords S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181805.mp4', 'http://timg.bdta.pro/images/0d3023accc1768022de96310785a7a6d.jpg'),
(81727, 5661, 'Crossing Swords S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181806.mp4', 'http://timg.bdta.pro/images/b619b455ae52217e778c010fa90dd33e.jpg'),
(81728, 5661, 'Crossing Swords S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181807.mp4', 'http://timg.bdta.pro/images/cc73b3da82bb571753de691274db8bde.jpg'),
(81729, 5662, 'Crossing Swords S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181808.mp4', 'http://timg.bdta.pro/images/c8132faef87df3346b7e77f44457c1d4.jpg'),
(81730, 5662, 'Crossing Swords S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181809.mp4', 'http://timg.bdta.pro/images/1ef909813e5c5fb65049c67e89050a94.jpg'),
(81731, 5662, 'Crossing Swords S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181810.mp4', 'http://timg.bdta.pro/images/0a703c110e2bc33e89e49b439d88fd18.jpg'),
(81732, 5662, 'Crossing Swords S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181811.mp4', 'http://timg.bdta.pro/images/848ac85890ab5950e32d036684e91095.jpg'),
(81733, 5662, 'Crossing Swords S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181812.mp4', 'http://timg.bdta.pro/images/a2a744b3cea5e315b699b5030a260c1b.jpg'),
(81734, 5662, 'Crossing Swords S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181813.mp4', 'http://timg.bdta.pro/images/04ff4fc5fabee3ae0cddea6b231678b4.jpg'),
(81735, 5662, 'Crossing Swords S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181814.mp4', 'http://timg.bdta.pro/images/7295223a0ef2e50f45823b231f8bb4ea.jpg'),
(81736, 5662, 'Crossing Swords S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181815.mp4', 'http://timg.bdta.pro/images/2c61318da005ef79774a90c46a92259c.jpg'),
(81737, 5662, 'Crossing Swords S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181816.mp4', 'http://timg.bdta.pro/images/d32f445f93606508bb343938c5256934.jpg'),
(81738, 5662, 'Crossing Swords S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181817.mp4', 'http://timg.bdta.pro/images/9cb9fb764784155996a447a02aee6645.jpg'),
(81739, 5663, 'DMZ S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179290.mp4', 'http://timg.bdta.pro/images/ba292e29e1174d67449f80e3f0692f13.jpg'),
(81740, 5663, 'DMZ S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179291.mp4', 'http://timg.bdta.pro/images/b8e005a54de9094b0322006feb40d9a8.jpg'),
(81741, 5663, 'DMZ S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179292.mp4', 'http://timg.bdta.pro/images/d6fe88b5b158765877e32686aac0451b.jpg'),
(81742, 5663, 'DMZ S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179293.mp4', 'http://gstaticontent.com/images/138f16b325cf38f5bfa7b21e9ccf4da4.jpg'),
(81743, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179869.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81744, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179870.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81745, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179871.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81746, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179872.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81747, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179873.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81748, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179874.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81749, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179875.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81750, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179876.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81751, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179877.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81752, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179878.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81753, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179879.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81754, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179880.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81755, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/179881.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81756, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/179882.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81757, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/179883.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81758, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/179884.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81759, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/179885.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81760, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/179886.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81761, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/179887.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81762, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/179888.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81763, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/179889.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81764, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/179890.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81765, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/179891.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81766, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/179892.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81767, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/179893.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81768, 5664, 'D.P.A. - Detetives do Prédio Azul S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/179894.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81769, 5665, 'D.P.A. - Detetives do Prédio Azul S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179895.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81770, 5665, 'D.P.A. - Detetives do Prédio Azul S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179896.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81771, 5665, 'D.P.A. - Detetives do Prédio Azul S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179897.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81772, 5665, 'D.P.A. - Detetives do Prédio Azul S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179898.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81773, 5665, 'D.P.A. - Detetives do Prédio Azul S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179899.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81774, 5665, 'D.P.A. - Detetives do Prédio Azul S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179900.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81775, 5665, 'D.P.A. - Detetives do Prédio Azul S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179901.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81776, 5665, 'D.P.A. - Detetives do Prédio Azul S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179902.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81777, 5665, 'D.P.A. - Detetives do Prédio Azul S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179903.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81778, 5665, 'D.P.A. - Detetives do Prédio Azul S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179904.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81779, 5665, 'D.P.A. - Detetives do Prédio Azul S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179905.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81780, 5665, 'D.P.A. - Detetives do Prédio Azul S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179906.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81781, 5665, 'D.P.A. - Detetives do Prédio Azul S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/179907.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81782, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179908.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81783, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179909.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81784, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179910.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81785, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179911.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81786, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179912.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81787, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179913.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81788, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179914.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81789, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179915.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81790, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179916.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81791, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179917.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81792, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179918.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81793, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179919.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81794, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/179920.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81795, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/179921.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81796, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/179922.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81797, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/179923.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81798, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/179924.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81799, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/179925.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81800, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/179926.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81801, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/179927.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81802, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/179928.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81803, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/179929.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81804, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/179930.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81805, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/179931.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81806, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/179932.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81807, 5666, 'D.P.A. - Detetives do Prédio Azul S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/179933.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81808, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179934.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81809, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179935.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81810, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179936.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81811, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179937.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81812, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179938.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81813, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179939.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81814, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179940.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81815, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179941.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81816, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179942.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81817, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179943.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81818, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179944.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81819, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179945.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81820, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/179946.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81821, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/179947.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81822, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/179948.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81823, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/179949.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81824, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/179950.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81825, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/179951.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81826, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/179952.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81827, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/179953.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81828, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/179954.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81829, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/179955.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81830, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/179956.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81831, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/179957.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81832, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/179958.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81833, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/179959.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81834, 5667, 'D.P.A. - Detetives do Prédio Azul S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/179960.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81835, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179961.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81836, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179962.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81837, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179963.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81838, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179964.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81839, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179965.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81840, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179966.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81841, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179967.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81842, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179968.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81843, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179969.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81844, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179970.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81845, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179971.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81846, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179972.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81847, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/179973.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81848, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/179974.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81849, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/179975.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81850, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/179976.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81851, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/179977.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81852, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/179978.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81853, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/179979.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81854, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/179980.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81855, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/179981.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81856, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/179982.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81857, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/179983.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81858, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/179984.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81859, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/179985.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81860, 5668, 'D.P.A. - Detetives do Prédio Azul S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/179986.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81861, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179987.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81862, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179988.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81863, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179989.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81864, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179990.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81865, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179991.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81866, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179992.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81867, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179993.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81868, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179994.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81869, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179995.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81870, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179996.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81871, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179997.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81872, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179998.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81873, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/179999.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81874, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/180000.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81875, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/180001.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81876, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/180002.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81877, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/180003.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81878, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/180004.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81879, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/180005.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81880, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/180006.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81881, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/180007.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81882, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/180008.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81883, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/180009.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81884, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/180010.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81885, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/180011.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81886, 5669, 'D.P.A. - Detetives do Prédio Azul S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/180012.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81887, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180013.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81888, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180014.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81889, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180015.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81890, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180016.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81891, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180017.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81892, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180018.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81893, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180019.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81894, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180020.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81895, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180021.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81896, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180022.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81897, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/180023.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81898, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/180024.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81899, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/180025.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81900, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/180026.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81901, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/180027.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81902, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/180028.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81903, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/180029.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81904, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/180030.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81905, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/180031.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81906, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/180032.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81907, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/180033.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81908, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/180034.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81909, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/180035.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81910, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/180036.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81911, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/180037.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81912, 5670, 'D.P.A. - Detetives do Prédio Azul S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/180038.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81913, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180039.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81914, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180040.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81915, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180041.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81916, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180042.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81917, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180043.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81918, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180044.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81919, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180045.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81920, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180046.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81921, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180047.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81922, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180048.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81923, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/180049.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81924, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/180050.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81925, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/180051.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81926, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/180052.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81927, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/180053.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81928, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/180054.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81929, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/180055.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81930, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/180056.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81931, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/180057.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81932, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/180058.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81933, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/180059.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81934, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/180060.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81935, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/180061.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81936, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/180062.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81937, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E25', 'http://sinalprivado.info:80/series/1533784/1533784/180063.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81938, 5671, 'D.P.A. - Detetives do Prédio Azul S08 E26', 'http://sinalprivado.info:80/series/1533784/1533784/180064.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81939, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180065.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81940, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180066.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81941, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180067.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81942, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180068.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(81943, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180069.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81944, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180070.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81945, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180071.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81946, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180072.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81947, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180073.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81948, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180074.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81949, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/180075.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81950, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/180076.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81951, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/180077.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81952, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/180078.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81953, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/180079.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81954, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/180080.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81955, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/180081.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81956, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/180082.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81957, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/180083.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81958, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/180084.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81959, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/180085.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81960, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/180086.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81961, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/180087.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81962, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/180088.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81963, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E25', 'http://sinalprivado.info:80/series/1533784/1533784/180089.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81964, 5672, 'D.P.A. - Detetives do Prédio Azul S09 E26', 'http://sinalprivado.info:80/series/1533784/1533784/180090.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81965, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180091.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81966, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180092.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81967, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180093.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81968, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180094.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81969, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180095.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81970, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180096.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81971, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180097.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81972, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180098.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81973, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180099.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81974, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180100.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81975, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/180101.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81976, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/180102.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81977, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/180103.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81978, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/180104.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81979, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/180105.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81980, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/180106.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81981, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/180107.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81982, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/180108.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81983, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/180109.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81984, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/180110.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81985, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/180111.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81986, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/180112.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81987, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/180113.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81988, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E24', 'http://sinalprivado.info:80/series/1533784/1533784/180114.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81989, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E25', 'http://sinalprivado.info:80/series/1533784/1533784/180115.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81990, 5673, 'D.P.A. - Detetives do Prédio Azul S10 E26', 'http://sinalprivado.info:80/series/1533784/1533784/180116.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81991, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180117.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81992, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180118.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81993, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180119.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81994, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180120.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81995, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180121.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81996, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180122.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81997, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180123.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81998, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180124.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(81999, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180125.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82000, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180126.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82001, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/180127.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82002, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/180128.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82003, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/180129.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82004, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/180130.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82005, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/180131.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82006, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/180132.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82007, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/180133.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82008, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/180134.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82009, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/180135.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82010, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/180136.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82011, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/180137.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82012, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/180138.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82013, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E23', 'http://sinalprivado.info:80/series/1533784/1533784/180139.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82014, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E24', 'http://sinalprivado.info:80/series/1533784/1533784/180140.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82015, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E25', 'http://sinalprivado.info:80/series/1533784/1533784/180141.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82016, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E26', 'http://sinalprivado.info:80/series/1533784/1533784/180142.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82017, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E27', 'http://sinalprivado.info:80/series/1533784/1533784/180143.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82018, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E28', 'http://sinalprivado.info:80/series/1533784/1533784/180144.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82019, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E29', 'http://sinalprivado.info:80/series/1533784/1533784/180145.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82020, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E30', 'http://sinalprivado.info:80/series/1533784/1533784/180146.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82021, 5674, 'D.P.A. - Detetives do Prédio Azul S11 E31', 'http://sinalprivado.info:80/series/1533784/1533784/180147.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82022, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180148.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82023, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180149.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82024, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180150.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82025, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180151.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82026, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180152.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82027, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180153.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82028, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180154.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82029, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180155.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82030, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180156.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82031, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180157.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82032, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/180158.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82033, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/180159.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82034, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/180160.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82035, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/180161.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82036, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/180162.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82037, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/180163.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82038, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/180164.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82039, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/180165.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82040, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/180166.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82041, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/180167.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82042, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/180168.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82043, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/180169.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82044, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E23', 'http://sinalprivado.info:80/series/1533784/1533784/180170.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82045, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E24', 'http://sinalprivado.info:80/series/1533784/1533784/180171.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82046, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E25', 'http://sinalprivado.info:80/series/1533784/1533784/180172.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82047, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E26', 'http://sinalprivado.info:80/series/1533784/1533784/180173.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82048, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E27', 'http://sinalprivado.info:80/series/1533784/1533784/180174.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82049, 5675, 'D.P.A. - Detetives do Prédio Azul S12 E28', 'http://sinalprivado.info:80/series/1533784/1533784/180175.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82050, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180176.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82051, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180177.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82052, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180178.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82053, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180179.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82054, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180180.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82055, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180181.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82056, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180182.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82057, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180183.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82058, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180184.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82059, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180185.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82060, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/180186.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82061, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/180187.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82062, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/180188.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82063, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/180189.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82064, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/180190.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82065, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/180191.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82066, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/180192.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82067, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/180193.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82068, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/180194.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82069, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/180195.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82070, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/180196.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82071, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/180197.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82072, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E23', 'http://sinalprivado.info:80/series/1533784/1533784/180198.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82073, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E24', 'http://sinalprivado.info:80/series/1533784/1533784/180199.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82074, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E25', 'http://sinalprivado.info:80/series/1533784/1533784/180200.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82075, 5676, 'D.P.A. - Detetives do Prédio Azul S13 E26', 'http://sinalprivado.info:80/series/1533784/1533784/180201.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82076, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180202.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82077, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180203.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82078, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180204.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82079, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180205.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82080, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180206.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82081, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180207.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82082, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180208.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82083, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180209.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82084, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180210.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82085, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180211.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82086, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/180212.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82087, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/180213.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82088, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/180214.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82089, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/180215.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82090, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/180216.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82091, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/180217.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82092, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/180218.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82093, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/180219.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82094, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/180220.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82095, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/180221.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82096, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E21', 'http://sinalprivado.info:80/series/1533784/1533784/180222.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82097, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E22', 'http://sinalprivado.info:80/series/1533784/1533784/180223.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82098, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E23', 'http://sinalprivado.info:80/series/1533784/1533784/180224.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82099, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E24', 'http://sinalprivado.info:80/series/1533784/1533784/180225.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82100, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E25', 'http://sinalprivado.info:80/series/1533784/1533784/180226.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82101, 5677, 'D.P.A. - Detetives do Prédio Azul S14 E26', 'http://sinalprivado.info:80/series/1533784/1533784/180227.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82102, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180228.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82103, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180229.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82104, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180230.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82105, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180231.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82106, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180232.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82107, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180233.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82108, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180234.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82109, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180235.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82110, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180236.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82111, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180237.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82112, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E11', 'http://sinalprivado.info:80/series/1533784/1533784/180238.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82113, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E12', 'http://sinalprivado.info:80/series/1533784/1533784/180239.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82114, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E13', 'http://sinalprivado.info:80/series/1533784/1533784/180240.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82115, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E14', 'http://sinalprivado.info:80/series/1533784/1533784/180241.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82116, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E15', 'http://sinalprivado.info:80/series/1533784/1533784/180242.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82117, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E16', 'http://sinalprivado.info:80/series/1533784/1533784/180243.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82118, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E17', 'http://sinalprivado.info:80/series/1533784/1533784/180244.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82119, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E18', 'http://sinalprivado.info:80/series/1533784/1533784/180245.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82120, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E19', 'http://sinalprivado.info:80/series/1533784/1533784/180246.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82121, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E20', 'http://sinalprivado.info:80/series/1533784/1533784/180247.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82122, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E21', 'http://sinalprivado.info:80/series/1533784/1533784/180248.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82123, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E22', 'http://sinalprivado.info:80/series/1533784/1533784/180249.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82124, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E23', 'http://sinalprivado.info:80/series/1533784/1533784/180250.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82125, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E24', 'http://sinalprivado.info:80/series/1533784/1533784/180251.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82126, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E25', 'http://sinalprivado.info:80/series/1533784/1533784/180252.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82127, 5678, 'D.P.A. - Detetives do Prédio Azul S16 E26', 'http://sinalprivado.info:80/series/1533784/1533784/180253.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82128, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/890190.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82129, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/890191.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82130, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/890192.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82131, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/890193.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82132, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/890194.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82133, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/890195.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82134, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/890196.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82135, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/890197.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82136, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/890198.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82137, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/890199.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82138, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E11', 'http://sinalprivado.info:80/series/1533784/1533784/890200.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82139, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E12', 'http://sinalprivado.info:80/series/1533784/1533784/890201.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82140, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E13', 'http://sinalprivado.info:80/series/1533784/1533784/890202.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82141, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E14', 'http://sinalprivado.info:80/series/1533784/1533784/890203.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82142, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E15', 'http://sinalprivado.info:80/series/1533784/1533784/890204.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82143, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E16', 'http://sinalprivado.info:80/series/1533784/1533784/890205.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82144, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E17', 'http://sinalprivado.info:80/series/1533784/1533784/890206.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82145, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E18', 'http://sinalprivado.info:80/series/1533784/1533784/890207.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82146, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E19', 'http://sinalprivado.info:80/series/1533784/1533784/890208.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82147, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E20', 'http://sinalprivado.info:80/series/1533784/1533784/890209.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82148, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E21', 'http://sinalprivado.info:80/series/1533784/1533784/890210.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82149, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E22', 'http://sinalprivado.info:80/series/1533784/1533784/890211.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82150, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E23', 'http://sinalprivado.info:80/series/1533784/1533784/890212.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82151, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E24', 'http://sinalprivado.info:80/series/1533784/1533784/890213.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82152, 5679, 'D.P.A. - Detetives do Prédio Azul S17 E25', 'http://sinalprivado.info:80/series/1533784/1533784/890214.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82153, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/890215.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82154, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E02', 'http://sinalprivado.info:80/series/1533784/1533784/890216.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82155, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E03', 'http://sinalprivado.info:80/series/1533784/1533784/890217.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82156, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E04', 'http://sinalprivado.info:80/series/1533784/1533784/890218.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82157, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E05', 'http://sinalprivado.info:80/series/1533784/1533784/890219.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82158, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E06', 'http://sinalprivado.info:80/series/1533784/1533784/890220.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82159, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E07', 'http://sinalprivado.info:80/series/1533784/1533784/890221.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82160, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E08', 'http://sinalprivado.info:80/series/1533784/1533784/890222.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82161, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E09', 'http://sinalprivado.info:80/series/1533784/1533784/890223.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82162, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E10', 'http://sinalprivado.info:80/series/1533784/1533784/890224.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82163, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E11', 'http://sinalprivado.info:80/series/1533784/1533784/890225.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82164, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E12', 'http://sinalprivado.info:80/series/1533784/1533784/890226.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82165, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E13', 'http://sinalprivado.info:80/series/1533784/1533784/890227.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82166, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E14', 'http://sinalprivado.info:80/series/1533784/1533784/890228.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82167, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E15', 'http://sinalprivado.info:80/series/1533784/1533784/890229.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82168, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E16', 'http://sinalprivado.info:80/series/1533784/1533784/890230.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82169, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E17', 'http://sinalprivado.info:80/series/1533784/1533784/890231.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82170, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E18', 'http://sinalprivado.info:80/series/1533784/1533784/890232.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82171, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E19', 'http://sinalprivado.info:80/series/1533784/1533784/890233.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82172, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E20', 'http://sinalprivado.info:80/series/1533784/1533784/890234.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82173, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E21', 'http://sinalprivado.info:80/series/1533784/1533784/890235.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82174, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E22', 'http://sinalprivado.info:80/series/1533784/1533784/890236.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82175, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E23', 'http://sinalprivado.info:80/series/1533784/1533784/890237.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82176, 5680, 'D.P.A. - Detetives do Prédio Azul S18 E24', 'http://sinalprivado.info:80/series/1533784/1533784/890238.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82177, 5681, 'D.P.A. - Detetives do Prédio Azul S19 E01', 'http://sinalprivado.info:80/series/1533784/1533784/890239.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82178, 5681, 'D.P.A. - Detetives do Prédio Azul S19 E02', 'http://sinalprivado.info:80/series/1533784/1533784/890240.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82179, 5681, 'D.P.A. - Detetives do Prédio Azul S19 E03', 'http://sinalprivado.info:80/series/1533784/1533784/890241.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82180, 5681, 'D.P.A. - Detetives do Prédio Azul S19 E04', 'http://sinalprivado.info:80/series/1533784/1533784/890242.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82181, 5681, 'D.P.A. - Detetives do Prédio Azul S19 E05', 'http://sinalprivado.info:80/series/1533784/1533784/890243.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82182, 5681, 'D.P.A. - Detetives do Prédio Azul S19 E06', 'http://sinalprivado.info:80/series/1533784/1533784/890244.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82183, 5681, 'D.P.A. - Detetives do Prédio Azul S19 E07', 'http://sinalprivado.info:80/series/1533784/1533784/890245.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82184, 5681, 'D.P.A. - Detetives do Prédio Azul S19 E08', 'http://sinalprivado.info:80/series/1533784/1533784/890246.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82185, 5681, 'D.P.A. - Detetives do Prédio Azul S19 E09', 'http://sinalprivado.info:80/series/1533784/1533784/890247.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82186, 5681, 'D.P.A. - Detetives do Prédio Azul S19 E10', 'http://sinalprivado.info:80/series/1533784/1533784/890248.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82187, 5681, 'D.P.A. - Detetives do Prédio Azul S19 E11', 'http://sinalprivado.info:80/series/1533784/1533784/890249.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82188, 5681, 'D.P.A. - Detetives do Prédio Azul S19 E12', 'http://sinalprivado.info:80/series/1533784/1533784/890250.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82189, 5681, 'D.P.A. - Detetives do Prédio Azul S19 E13', 'http://sinalprivado.info:80/series/1533784/1533784/890251.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82190, 5681, 'D.P.A. - Detetives do Prédio Azul S19 E14', 'http://sinalprivado.info:80/series/1533784/1533784/890252.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82191, 5681, 'D.P.A. - Detetives do Prédio Azul S19 E15', 'http://sinalprivado.info:80/series/1533784/1533784/890253.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82192, 5681, 'D.P.A. - Detetives do Prédio Azul S19 E16', 'http://sinalprivado.info:80/series/1533784/1533784/890254.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82193, 5681, 'D.P.A. - Detetives do Prédio Azul S19 E17', 'http://sinalprivado.info:80/series/1533784/1533784/890255.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82194, 5681, 'D.P.A. - Detetives do Prédio Azul S19 E18', 'http://sinalprivado.info:80/series/1533784/1533784/890256.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82195, 5681, 'D.P.A. - Detetives do Prédio Azul S19 E19', 'http://sinalprivado.info:80/series/1533784/1533784/890257.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82196, 5681, 'D.P.A. - Detetives do Prédio Azul S19 E20', 'http://sinalprivado.info:80/series/1533784/1533784/890258.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82197, 5681, 'D.P.A. - Detetives do Prédio Azul S19 E21', 'http://sinalprivado.info:80/series/1533784/1533784/890259.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(82198, 5682, 'D.P.A. - Detetives do Prédio Azul S20 E01', 'http://sinalprivado.info:80/series/1533784/1533784/890260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dCHrGCbmEKjZy4rAOU5oewi9MEM.jpg'),
(82199, 5682, 'D.P.A. - Detetives do Prédio Azul S20 E02', 'http://sinalprivado.info:80/series/1533784/1533784/890261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6X8BNYUomSFjfseF3K1P2W0CxLT.jpg'),
(82200, 5682, 'D.P.A. - Detetives do Prédio Azul S20 E03', 'http://sinalprivado.info:80/series/1533784/1533784/890262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4hxcb81ba5zeQYg4jp6qZVTWwt.jpg'),
(82201, 5682, 'D.P.A. - Detetives do Prédio Azul S20 E04', 'http://sinalprivado.info:80/series/1533784/1533784/890263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h66grroD9GVhOrHiRbwS3Rm9mxy.jpg'),
(82202, 5682, 'D.P.A. - Detetives do Prédio Azul S20 E05', 'http://sinalprivado.info:80/series/1533784/1533784/890264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzalOIkpnlun8qsqCWlLpnc3mSW.jpg'),
(82203, 5682, 'D.P.A. - Detetives do Prédio Azul S20 E06', 'http://sinalprivado.info:80/series/1533784/1533784/890265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sJjeg0hcMKtv8dc7zcV07tGV3dM.jpg'),
(82204, 5682, 'D.P.A. - Detetives do Prédio Azul S20 E07', 'http://sinalprivado.info:80/series/1533784/1533784/890266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ffoVVup0EB3FF8EXVz5rfBGlWbq.jpg'),
(82205, 5682, 'D.P.A. - Detetives do Prédio Azul S20 E08', 'http://sinalprivado.info:80/series/1533784/1533784/890267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7vlHKXziPFfWK1xKH6K4eVh2Pwl.jpg'),
(82206, 5682, 'D.P.A. - Detetives do Prédio Azul S20 E09', 'http://sinalprivado.info:80/series/1533784/1533784/890268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m4Igi2UtBKfyeNkw5ynG0WM6jnm.jpg'),
(82207, 5682, 'D.P.A. - Detetives do Prédio Azul S20 E10', 'http://sinalprivado.info:80/series/1533784/1533784/890269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOMMDTfJEvYHcTTWt08hiDIOVCR.jpg'),
(82208, 5682, 'D.P.A. - Detetives do Prédio Azul S20 E11', 'http://sinalprivado.info:80/series/1533784/1533784/890270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8iH9xHmEFUAeyTjIVLWisJ2vMvX.jpg'),
(82209, 5682, 'D.P.A. - Detetives do Prédio Azul S20 E12', 'http://sinalprivado.info:80/series/1533784/1533784/890271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lODDyj4tPrPjpTrgjqHRTUIJ9a6.jpg'),
(82210, 5682, 'D.P.A. - Detetives do Prédio Azul S20 E13', 'http://sinalprivado.info:80/series/1533784/1533784/890272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8vnMbg2M68zxYTdkXKARUafVARg.jpg'),
(82211, 5682, 'D.P.A. - Detetives do Prédio Azul S20 E14', 'http://sinalprivado.info:80/series/1533784/1533784/890273.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82212, 5682, 'D.P.A. - Detetives do Prédio Azul S20 E15', 'http://sinalprivado.info:80/series/1533784/1533784/890274.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82213, 5682, 'D.P.A. - Detetives do Prédio Azul S20 E16', 'http://sinalprivado.info:80/series/1533784/1533784/890275.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82214, 5682, 'D.P.A. - Detetives do Prédio Azul S20 E17', 'http://sinalprivado.info:80/series/1533784/1533784/890276.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82215, 5682, 'D.P.A. - Detetives do Prédio Azul S20 E18', 'http://sinalprivado.info:80/series/1533784/1533784/890277.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82216, 5682, 'D.P.A. - Detetives do Prédio Azul S20 E19', 'http://sinalprivado.info:80/series/1533784/1533784/890278.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82217, 5682, 'D.P.A. - Detetives do Prédio Azul S20 E20', 'http://sinalprivado.info:80/series/1533784/1533784/890279.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82218, 5682, 'D.P.A. - Detetives do Prédio Azul S20 E21', 'http://sinalprivado.info:80/series/1533784/1533784/890280.mp4', 'http://gstaticontent.com/images/ee5f79c1eabbd1d0b38348883eb3d765.jpg'),
(82219, 5683, 'Dragões: Equipe de Resgate ‑ Heróis do Céu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179278.mp4', 'http://timg.bdta.pro/images/c62f8f75e8c5e1cb9bd0959b61c2634f.jpg'),
(82220, 5683, 'Dragões: Equipe de Resgate ‑ Heróis do Céu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179279.mp4', 'http://timg.bdta.pro/images/7aa0bef53dd227249b6c14b7e472ddf1.jpg'),
(82221, 5683, 'Dragões: Equipe de Resgate ‑ Heróis do Céu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179280.mp4', 'http://timg.bdta.pro/images/15e33453b1287dfcd435616771909bc1.jpg'),
(82222, 5683, 'Dragões: Equipe de Resgate ‑ Heróis do Céu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179281.mp4', 'http://timg.bdta.pro/images/e07fd6db64441d549e3bf1ba05cecc0f.jpg'),
(82223, 5683, 'Dragões: Equipe de Resgate ‑ Heróis do Céu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179282.mp4', 'http://timg.bdta.pro/images/8fd39ee69a0c6aad8bf7e3b6fcd8cf08.jpg'),
(82224, 5683, 'Dragões: Equipe de Resgate ‑ Heróis do Céu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179283.mp4', 'http://timg.bdta.pro/images/d05905b4eff4b2ad73ce9597d26b8b85.jpg'),
(82225, 5683, 'Dragões: Equipe de Resgate ‑ Heróis do Céu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179284.mp4', 'http://gstaticontent.com/images/d58c5bd5a3c166d5b393663522e9b519.jpg'),
(82226, 5683, 'Dragões: Equipe de Resgate ‑ Heróis do Céu S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179285.mp4', 'http://gstaticontent.com/images/d58c5bd5a3c166d5b393663522e9b519.jpg'),
(82227, 5683, 'Dragões: Equipe de Resgate ‑ Heróis do Céu S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179286.mp4', 'http://gstaticontent.com/images/d58c5bd5a3c166d5b393663522e9b519.jpg'),
(82228, 5683, 'Dragões: Equipe de Resgate ‑ Heróis do Céu S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179287.mp4', 'http://gstaticontent.com/images/d58c5bd5a3c166d5b393663522e9b519.jpg'),
(82229, 5683, 'Dragões: Equipe de Resgate ‑ Heróis do Céu S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179288.mp4', 'http://gstaticontent.com/images/d58c5bd5a3c166d5b393663522e9b519.jpg'),
(82230, 5683, 'Dragões: Equipe de Resgate ‑ Heróis do Céu S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179289.mp4', 'http://gstaticontent.com/images/d58c5bd5a3c166d5b393663522e9b519.jpg'),
(82231, 5684, 'Elite Histórias Breves: Carla Samuel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179275.mp4', 'http://timg.bdta.pro/images/7fc5b12300df3bed5f0a9235ce6c4dde.jpg'),
(82232, 5684, 'Elite Histórias Breves: Carla Samuel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179276.mp4', 'http://timg.bdta.pro/images/3bab99c347bce6cd13a5452c538db981.jpg'),
(82233, 5684, 'Elite Histórias Breves: Carla Samuel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179277.mp4', 'http://timg.bdta.pro/images/0bc38b9dd61a3e20a46484901de28c9d.jpg'),
(82234, 5685, 'Elite Histórias Breves: Guzmán Caye Rebe [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179272.mp4', 'http://timg.bdta.pro/images/32a72246cda34d460c91960972562385.jpg'),
(82235, 5685, 'Elite Histórias Breves: Guzmán Caye Rebe [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179273.mp4', 'http://timg.bdta.pro/images/a41d16cf238a0212d3e55565fbf3e926.jpg'),
(82236, 5685, 'Elite Histórias Breves: Guzmán Caye Rebe [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179274.mp4', 'http://timg.bdta.pro/images/36cda9e28fbbf37a054ed9f07cb7dc77.jpg'),
(82237, 5686, 'Elite Histórias Breves: Nadia Guzmán [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179269.mp4', 'http://timg.bdta.pro/images/7c3f62c670c330701e3369a697c5f551.jpg'),
(82238, 5686, 'Elite Histórias Breves: Nadia Guzmán [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179270.mp4', 'http://timg.bdta.pro/images/74241656313d95f457c6ace42494a880.jpg'),
(82239, 5686, 'Elite Histórias Breves: Nadia Guzmán [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179271.mp4', 'http://timg.bdta.pro/images/ac14a1552477a1a3437b6e5547c47501.jpg'),
(82240, 5687, 'Elite Histórias Breves: Omar Ander Alexis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179266.mp4', 'http://timg.bdta.pro/images/7fdd7d2df509ebad9680b55cc2441ba0.jpg'),
(82241, 5687, 'Elite Histórias Breves: Omar Ander Alexis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179267.mp4', 'http://timg.bdta.pro/images/a2132972de6ef417a5c02e506cbbc07b.jpg'),
(82242, 5687, 'Elite Histórias Breves: Omar Ander Alexis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179268.mp4', 'http://timg.bdta.pro/images/7554083e5c0b86f90f868fc4887d2122.jpg'),
(82243, 5688, 'Elite Histórias Breves: Patrick S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179263.mp4', 'http://timg.bdta.pro/images/790c10042663ca48eaadb78b73533033.jpg'),
(82244, 5688, 'Elite Histórias Breves: Patrick S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179264.mp4', 'http://timg.bdta.pro/images/479fdd64ed44f31ba02032a29bb3c6a6.jpg'),
(82245, 5688, 'Elite Histórias Breves: Patrick S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179265.mp4', 'http://timg.bdta.pro/images/bc728b53cfe3edcbe5641eb480bb2c91.jpg'),
(82246, 5689, 'Elite Histórias Breves: Phillipe Caye Felipe S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179260.mp4', 'http://timg.bdta.pro/images/35472cae4ba0a4b9b182b360f93e0168.jpg'),
(82247, 5689, 'Elite Histórias Breves: Phillipe Caye Felipe S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179261.mp4', 'http://timg.bdta.pro/images/449631e44c5c0c0ad62c5a454193b015.jpg'),
(82248, 5689, 'Elite Histórias Breves: Phillipe Caye Felipe S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179262.mp4', 'http://timg.bdta.pro/images/2ac2b207d5bf3c8c8bc7665aa744138c.jpg'),
(82249, 5690, 'Élite Historias Breves: Samuel Omar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179257.mp4', 'http://timg.bdta.pro/images/f69210753a1ad1d183199eacd7804999.jpg'),
(82250, 5690, 'Élite Historias Breves: Samuel Omar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179258.mp4', 'http://timg.bdta.pro/images/d3335dadf375b67224c67a867560d2a0.jpg'),
(82251, 5690, 'Élite Historias Breves: Samuel Omar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179259.mp4', 'http://timg.bdta.pro/images/f01b2773ffeda6fb4fc83246c2ce2934.jpg'),
(82252, 5691, 'From [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179247.mp4', 'http://timg.bdta.pro/images/226152ecc6e88062076d2459edd7908b.jpg'),
(82253, 5691, 'From [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179248.mp4', 'http://timg.bdta.pro/images/496fcce8ac498890924514d02d5d70a1.jpg'),
(82254, 5691, 'From [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179249.mp4', 'http://timg.bdta.pro/images/ab4dbaa505477f1b98b98d8abbceb3c7.jpg'),
(82255, 5691, 'From [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179250.mp4', 'http://timg.bdta.pro/images/279e6b35a42980dd4294e78153455430.jpg'),
(82256, 5691, 'From [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179251.mp4', 'http://timg.bdta.pro/images/cbcbf4d3ba6a2244a5d47fc989e13508.jpg'),
(82257, 5691, 'From [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179252.mp4', 'http://timg.bdta.pro/images/3ff8e16a7c6e60d7a3d651fe988cdcf4.jpg'),
(82258, 5691, 'From [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179253.mp4', 'http://timg.bdta.pro/images/4ff7be471edcbdc5a0949fd4a616eed1.jpg'),
(82259, 5691, 'From [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179254.mp4', 'http://timg.bdta.pro/images/138e026dbe26d547d155d0b92b25502c.jpg'),
(82260, 5691, 'From [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179255.mp4', 'http://timg.bdta.pro/images/c3dd66daf6bf721f47820f9797237296.jpg'),
(82261, 5691, 'From [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179256.mp4', 'http://timg.bdta.pro/images/2e6057e2bed10cf70897b7ad1548eeb9.jpg'),
(82262, 5692, 'Minx: Uma Para Elas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179237.mp4', 'http://timg.bdta.pro/images/426f84ccb520ffe57905326b8da4faa0.jpg'),
(82263, 5692, 'Minx: Uma Para Elas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179238.mp4', 'http://timg.bdta.pro/images/17ec21bdc1ccf9837e2de91625f51fca.jpg'),
(82264, 5692, 'Minx: Uma Para Elas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179239.mp4', 'http://timg.bdta.pro/images/49a204a0298ec220ba7398dbdb09b0df.jpg'),
(82265, 5692, 'Minx: Uma Para Elas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179240.mp4', 'http://timg.bdta.pro/images/cf18e4e5798ef3f115642c07deadb0b6.jpg'),
(82266, 5692, 'Minx: Uma Para Elas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179241.mp4', 'http://timg.bdta.pro/images/300f2539eff513d99c4fa12945d757e2.jpg'),
(82267, 5692, 'Minx: Uma Para Elas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179242.mp4', 'http://timg.bdta.pro/images/80348709de3064737e4d19164814b036.jpg'),
(82268, 5692, 'Minx: Uma Para Elas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179243.mp4', 'http://timg.bdta.pro/images/7c00b43948144b32fc20d3996938f188.jpg'),
(82269, 5692, 'Minx: Uma Para Elas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179244.mp4', 'http://timg.bdta.pro/images/936d460abcf1f798f39a2383c4fde18c.jpg'),
(82270, 5692, 'Minx: Uma Para Elas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179245.mp4', 'http://timg.bdta.pro/images/99b92f840bbe9ad4ba70a2d18051169c.jpg'),
(82271, 5692, 'Minx: Uma Para Elas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179246.mp4', 'http://timg.bdta.pro/images/804403cb7b27eca3b2bf53e5d6341cad.jpg'),
(82272, 5693, 'Mistérios Animais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217433.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82273, 5693, 'Mistérios Animais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217434.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82274, 5693, 'Mistérios Animais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217435.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82275, 5693, 'Mistérios Animais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217436.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82276, 5693, 'Mistérios Animais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217437.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82277, 5693, 'Mistérios Animais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217438.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82278, 5693, 'Mistérios Animais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217439.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82279, 5693, 'Mistérios Animais S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217440.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82280, 5693, 'Mistérios Animais S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217441.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82281, 5693, 'Mistérios Animais S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217442.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82282, 5693, 'Mistérios Animais S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217443.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82283, 5693, 'Mistérios Animais S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217444.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82284, 5694, 'Mistérios Animais S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217445.mp4', 'http://image.tmdb.org/t/p/w1280/2e9Md60yPNkyA2OOelNeWGNOJSt.jpg'),
(82285, 5695, 'Mistérios Animais S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217446.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82286, 5695, 'Mistérios Animais S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217447.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82287, 5695, 'Mistérios Animais S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217448.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82288, 5695, 'Mistérios Animais S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217449.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82289, 5695, 'Mistérios Animais S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217450.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82290, 5695, 'Mistérios Animais S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217451.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82291, 5695, 'Mistérios Animais S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217452.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82292, 5696, 'Mistérios Animais S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/852360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4RYw9qWxZPcYGczzDBO7JivFAXR.jpg'),
(82293, 5696, 'Mistérios Animais S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/852362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oXlJgE9Qs0NOyHWSZfzkXuh2St8.jpg'),
(82294, 5696, 'Mistérios Animais S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/852363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ebB9JylVEBor9oT9snydWpS4X6A.jpg'),
(82295, 5696, 'Mistérios Animais S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/852364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tm9rCs8MnjUOyPAc4BvYzNb4rZV.jpg'),
(82296, 5696, 'Mistérios Animais S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/852366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/YaIdX6gEOZSMk029RF4yiQ5C9q.jpg'),
(82297, 5696, 'Mistérios Animais S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/852367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exSwnPd0P1mKoV6IPHpKCgefSXW.jpg'),
(82298, 5696, 'Mistérios Animais S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/852368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/79cNBiBvDGnhbpof65gP5nKvpH8.jpg'),
(82299, 5696, 'Mistérios Animais S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/852369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4dpm6jOL4M7UwpJjN1qDY2NkibA.jpg'),
(82300, 5697, 'Mistérios Animais S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/852370.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82301, 5697, 'Mistérios Animais S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/852371.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82302, 5697, 'Mistérios Animais S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/852372.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82303, 5697, 'Mistérios Animais S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/852373.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82304, 5697, 'Mistérios Animais S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/852374.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82305, 5697, 'Mistérios Animais S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/852375.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82306, 5697, 'Mistérios Animais S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/852376.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82307, 5697, 'Mistérios Animais S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/852377.mp4', 'http://gstaticontent.com/images/d37cfc8023d5aada6a54773f6e67a01d.jpg'),
(82308, 5698, 'No Xadrez S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179231.mp4', 'http://timg.bdta.pro/images/125838aa426fe96d36907bcaeefeb489.jpg'),
(82309, 5698, 'No Xadrez S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179232.mp4', 'http://timg.bdta.pro/images/f596062370eb8ad2f0e22a803b52d874.jpg'),
(82310, 5698, 'No Xadrez S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179233.mp4', 'http://timg.bdta.pro/images/c7a3bb8460b09d7a319d7386e2c2e87d.jpg'),
(82311, 5698, 'No Xadrez S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179234.mp4', 'http://timg.bdta.pro/images/3feca7977716db39c9d353863568c6d3.jpg'),
(82312, 5698, 'No Xadrez S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179235.mp4', 'http://timg.bdta.pro/images/05f942566b21e6c85c970d93813d7dd0.jpg'),
(82313, 5698, 'No Xadrez S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179236.mp4', 'http://timg.bdta.pro/images/fc0cad015e6dc80b20cba3d951a6291e.jpg'),
(82314, 5699, 'O Dono de Kingstown S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224429.mp4', 'http://timg.bdta.pro/images/e6a981c4c6c2c4757bb2e0fa26b59a85.jpg'),
(82315, 5699, 'O Dono de Kingstown S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224430.mp4', 'http://timg.bdta.pro/images/19ad304dd70e26a1236b2d39edad4b0e.jpg'),
(82316, 5699, 'O Dono de Kingstown S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224431.mp4', 'http://timg.bdta.pro/images/8caf579ab17781dd7f19f14d556044ce.jpg'),
(82317, 5699, 'O Dono de Kingstown S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224432.mp4', 'http://timg.bdta.pro/images/903c8fbabab3e906c648ea8e818985bb.jpg'),
(82318, 5699, 'O Dono de Kingstown S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224433.mp4', 'http://timg.bdta.pro/images/061b532f0c3da2ac8d256e834e61d885.jpg'),
(82319, 5699, 'O Dono de Kingstown S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224434.mp4', 'http://timg.bdta.pro/images/940585b93bc3a6842a5811aafb654142.jpg'),
(82320, 5699, 'O Dono de Kingstown S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224435.mp4', 'http://timg.bdta.pro/images/215a555a69de80840832ede5ea13a11b.jpg'),
(82321, 5699, 'O Dono de Kingstown S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224436.mp4', 'http://timg.bdta.pro/images/6f86a72eea77874dffe0973d6b080dc4.jpg'),
(82322, 5699, 'O Dono de Kingstown S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224437.mp4', 'http://timg.bdta.pro/images/27905195f07814e8934a18e0167a2052.jpg'),
(82323, 5699, 'O Dono de Kingstown S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224438.mp4', 'http://timg.bdta.pro/images/a742cad444309d025742b794ac026028.jpg'),
(82324, 5700, 'O Dono de Kingstown S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224439.mp4', 'http://image.tmdb.org/t/p/w1280/xPJTOp008m194qQaPhWZaga6RhT.jpg'),
(82325, 5700, 'O Dono de Kingstown S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224440.mp4', 'http://image.tmdb.org/t/p/w1280/Blp8cgmKu6Gs4BoniFESugKhXl.jpg'),
(82326, 5700, 'O Dono de Kingstown S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uiqCmyyPZ7vy6zvkIOM51wVteg8.jpg'),
(82327, 5700, 'O Dono de Kingstown S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhpH5uGTW5Vu7dzFuA7QO9qcaGQ.jpg'),
(82328, 5700, 'O Dono de Kingstown S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqNiqQw4UrLbxYTynlu2jzV14Y9.jpg'),
(82329, 5700, 'O Dono de Kingstown S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kbijzk41OhEOq7Hmvlp3KmKcduu.jpg'),
(82330, 5700, 'O Dono de Kingstown S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/itqX7XjMOcPFynhTzoGYHV7YQer.jpg'),
(82331, 5700, 'O Dono de Kingstown S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7BdKzQ35kjQ0umCvQRi8K4wztaw.jpg'),
(82332, 5700, 'O Dono de Kingstown S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xYhFvSHxlw3mydBhtgDcdOUG08v.jpg'),
(82333, 5700, 'O Dono de Kingstown S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hlvBshYU94Tra3I3tDXViRVONxx.jpg'),
(82334, 5701, 'O Dono de Kingstown S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/613798.mp4', 'http://gstaticontent.com/images/27aac57edd03f358c76289330b63c1e1.jpg'),
(82335, 5701, 'O Dono de Kingstown S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/377755.mp4', 'http://gstaticontent.com/images/27aac57edd03f358c76289330b63c1e1.jpg'),
(82336, 5701, 'O Dono de Kingstown S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/387328.mp4', 'http://gstaticontent.com/images/27aac57edd03f358c76289330b63c1e1.jpg'),
(82337, 5701, 'O Dono de Kingstown S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/392362.mp4', 'http://gstaticontent.com/images/27aac57edd03f358c76289330b63c1e1.jpg'),
(82338, 5701, 'O Dono de Kingstown S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/395821.mp4', 'http://gstaticontent.com/images/27aac57edd03f358c76289330b63c1e1.jpg'),
(82339, 5701, 'O Dono de Kingstown S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/402873.mp4', 'http://gstaticontent.com/images/27aac57edd03f358c76289330b63c1e1.jpg'),
(82340, 5701, 'O Dono de Kingstown S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/408499.mp4', 'http://gstaticontent.com/images/27aac57edd03f358c76289330b63c1e1.jpg'),
(82341, 5701, 'O Dono de Kingstown S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/415599.mp4', 'http://gstaticontent.com/images/27aac57edd03f358c76289330b63c1e1.jpg'),
(82342, 5701, 'O Dono de Kingstown S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/419445.mp4', 'http://gstaticontent.com/images/27aac57edd03f358c76289330b63c1e1.jpg'),
(82343, 5701, 'O Dono de Kingstown S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/424452.mp4', 'http://gstaticontent.com/images/27aac57edd03f358c76289330b63c1e1.jpg'),
(82344, 5702, 'O Dono de Kingstown S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/890061.mp4', 'http://gstaticontent.com/images/27aac57edd03f358c76289330b63c1e1.jpg'),
(82345, 5702, 'O Dono de Kingstown S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/891030.mp4', 'http://gstaticontent.com/images/27aac57edd03f358c76289330b63c1e1.jpg'),
(82346, 5702, 'O Dono de Kingstown S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/892200.mp4', 'http://gstaticontent.com/images/27aac57edd03f358c76289330b63c1e1.jpg'),
(82347, 5702, 'O Dono de Kingstown S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/892642.mp4', 'http://gstaticontent.com/images/27aac57edd03f358c76289330b63c1e1.jpg'),
(82348, 5702, 'O Dono de Kingstown S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/893347.mp4', 'http://gstaticontent.com/images/27aac57edd03f358c76289330b63c1e1.jpg'),
(82349, 5702, 'O Dono de Kingstown S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/893575.mp4', 'http://gstaticontent.com/images/27aac57edd03f358c76289330b63c1e1.jpg'),
(82350, 5702, 'O Dono de Kingstown S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/894881.mp4', 'http://gstaticontent.com/images/27aac57edd03f358c76289330b63c1e1.jpg'),
(82351, 5702, 'O Dono de Kingstown S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/896218.mp4', 'http://gstaticontent.com/images/27aac57edd03f358c76289330b63c1e1.jpg'),
(82352, 5702, 'O Dono de Kingstown S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/896664.mp4', 'http://gstaticontent.com/images/27aac57edd03f358c76289330b63c1e1.jpg'),
(82353, 5702, 'O Dono de Kingstown S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/897441.mp4', 'http://gstaticontent.com/images/27aac57edd03f358c76289330b63c1e1.jpg'),
(82354, 5703, 'O Ultimato: Ou Casa ou Vaza S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179221.mp4', 'http://timg.bdta.pro/images/14957d5938fe929dcfffdba177d1d692.jpg'),
(82355, 5703, 'O Ultimato: Ou Casa ou Vaza S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179222.mp4', 'http://timg.bdta.pro/images/744bca0013af108125d935328cea7db9.jpg'),
(82356, 5703, 'O Ultimato: Ou Casa ou Vaza S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179223.mp4', 'http://timg.bdta.pro/images/244fdb67b885b4243bd2a54a86b90980.jpg'),
(82357, 5703, 'O Ultimato: Ou Casa ou Vaza S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179224.mp4', 'http://timg.bdta.pro/images/4622f02f297c9e80cf20188e89ca9620.jpg'),
(82358, 5703, 'O Ultimato: Ou Casa ou Vaza S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179225.mp4', 'http://timg.bdta.pro/images/7434be8dc338f50423180b4255911040.jpg'),
(82359, 5703, 'O Ultimato: Ou Casa ou Vaza S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179226.mp4', 'http://timg.bdta.pro/images/1f6b071b248cc6deb84b6ff692a972d9.jpg'),
(82360, 5703, 'O Ultimato: Ou Casa ou Vaza S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179227.mp4', 'http://timg.bdta.pro/images/4bfe8e4e35ace710354ea34a904e0aa4.jpg'),
(82361, 5703, 'O Ultimato: Ou Casa ou Vaza S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179228.mp4', 'http://timg.bdta.pro/images/b868c22fe0fc271b4b0e6eb4d79d07c2.jpg'),
(82362, 5703, 'O Ultimato: Ou Casa ou Vaza S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179229.mp4', 'http://timg.bdta.pro/images/47a94eea5589a3928a6da7ba5f594df3.jpg'),
(82363, 5703, 'O Ultimato: Ou Casa ou Vaza S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179230.mp4', 'http://timg.bdta.pro/images/29bf962b9be0ef2f15e42d3e2f182e53.jpg'),
(82364, 5704, 'O Ultimato: Ou Casa ou Vaza S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/523231.mp4', 'http://gstaticontent.com/images/8dc9c4ecd496b43624b6ec9281998df2.jpg'),
(82365, 5704, 'O Ultimato: Ou Casa ou Vaza S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/523232.mp4', 'http://gstaticontent.com/images/8dc9c4ecd496b43624b6ec9281998df2.jpg'),
(82366, 5704, 'O Ultimato: Ou Casa ou Vaza S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/523233.mp4', 'http://gstaticontent.com/images/8dc9c4ecd496b43624b6ec9281998df2.jpg'),
(82367, 5704, 'O Ultimato: Ou Casa ou Vaza S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/523234.mp4', 'http://gstaticontent.com/images/8dc9c4ecd496b43624b6ec9281998df2.jpg'),
(82368, 5704, 'O Ultimato: Ou Casa ou Vaza S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/523235.mp4', 'http://gstaticontent.com/images/8dc9c4ecd496b43624b6ec9281998df2.jpg'),
(82369, 5704, 'O Ultimato: Ou Casa ou Vaza S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/523236.mp4', 'http://gstaticontent.com/images/8dc9c4ecd496b43624b6ec9281998df2.jpg'),
(82370, 5704, 'O Ultimato: Ou Casa ou Vaza S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/523237.mp4', 'http://gstaticontent.com/images/8dc9c4ecd496b43624b6ec9281998df2.jpg'),
(82371, 5704, 'O Ultimato: Ou Casa ou Vaza S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/523238.mp4', 'http://gstaticontent.com/images/8dc9c4ecd496b43624b6ec9281998df2.jpg'),
(82372, 5704, 'O Ultimato: Ou Casa ou Vaza S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/523239.mp4', 'http://gstaticontent.com/images/8dc9c4ecd496b43624b6ec9281998df2.jpg'),
(82373, 5704, 'O Ultimato: Ou Casa ou Vaza S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/523240.mp4', 'http://gstaticontent.com/images/8dc9c4ecd496b43624b6ec9281998df2.jpg'),
(82374, 5705, 'O Ultimato: Ou Casa ou Vaza S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/523241.mp4', 'http://gstaticontent.com/images/8dc9c4ecd496b43624b6ec9281998df2.jpg'),
(82375, 5705, 'O Ultimato: Ou Casa ou Vaza S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/523242.mp4', 'http://gstaticontent.com/images/8dc9c4ecd496b43624b6ec9281998df2.jpg'),
(82376, 5705, 'O Ultimato: Ou Casa ou Vaza S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/523243.mp4', 'http://gstaticontent.com/images/8dc9c4ecd496b43624b6ec9281998df2.jpg'),
(82377, 5705, 'O Ultimato: Ou Casa ou Vaza S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/523244.mp4', 'http://gstaticontent.com/images/8dc9c4ecd496b43624b6ec9281998df2.jpg'),
(82378, 5705, 'O Ultimato: Ou Casa ou Vaza S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/523245.mp4', 'http://gstaticontent.com/images/8dc9c4ecd496b43624b6ec9281998df2.jpg'),
(82379, 5705, 'O Ultimato: Ou Casa ou Vaza S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/741398.mp4', 'http://gstaticontent.com/images/8dc9c4ecd496b43624b6ec9281998df2.jpg'),
(82380, 5705, 'O Ultimato: Ou Casa ou Vaza S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/741399.mp4', 'http://gstaticontent.com/images/8dc9c4ecd496b43624b6ec9281998df2.jpg'),
(82381, 5705, 'O Ultimato: Ou Casa ou Vaza S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/741400.mp4', 'http://gstaticontent.com/images/8dc9c4ecd496b43624b6ec9281998df2.jpg'),
(82382, 5705, 'O Ultimato: Ou Casa ou Vaza S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/741401.mp4', 'http://gstaticontent.com/images/8dc9c4ecd496b43624b6ec9281998df2.jpg'),
(82383, 5705, 'O Ultimato: Ou Casa ou Vaza S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/741402.mp4', 'http://gstaticontent.com/images/8dc9c4ecd496b43624b6ec9281998df2.jpg'),
(82384, 5706, 'Os Parques Nacionais Mais Fascinantes do Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179211.mp4', 'http://timg.bdta.pro/images/67635a85080f4684e4abf0f6e17e6a69.jpg'),
(82385, 5706, 'Os Parques Nacionais Mais Fascinantes do Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179212.mp4', 'http://timg.bdta.pro/images/5f4537ba349f86297af3966dcbec5db6.jpg'),
(82386, 5706, 'Os Parques Nacionais Mais Fascinantes do Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179213.mp4', 'http://timg.bdta.pro/images/b3a7bbf86bd71fffae6188ead65c7632.jpg'),
(82387, 5706, 'Os Parques Nacionais Mais Fascinantes do Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179214.mp4', 'http://timg.bdta.pro/images/52d8585c73e8c16dc276a646d634b649.jpg'),
(82388, 5706, 'Os Parques Nacionais Mais Fascinantes do Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179215.mp4', 'http://timg.bdta.pro/images/aa96e806b933598d5234ab74e524068f.jpg'),
(82389, 5706, 'Os Parques Nacionais Mais Fascinantes do Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179216.mp4', 'http://gstaticontent.com/images/753352289c7c25efc218c7225ef16c08.jpg'),
(82390, 5706, 'Os Parques Nacionais Mais Fascinantes do Mundo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179217.mp4', 'http://gstaticontent.com/images/753352289c7c25efc218c7225ef16c08.jpg'),
(82391, 5706, 'Os Parques Nacionais Mais Fascinantes do Mundo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179218.mp4', 'http://gstaticontent.com/images/753352289c7c25efc218c7225ef16c08.jpg'),
(82392, 5706, 'Os Parques Nacionais Mais Fascinantes do Mundo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179219.mp4', 'http://gstaticontent.com/images/753352289c7c25efc218c7225ef16c08.jpg'),
(82393, 5706, 'Os Parques Nacionais Mais Fascinantes do Mundo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179220.mp4', 'http://gstaticontent.com/images/753352289c7c25efc218c7225ef16c08.jpg'),
(82394, 5707, 'Ousama Ranking S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179184.mp4', 'http://timg.bdta.pro/images/ee6adbf06ec66b737311d351850b6de6.jpg'),
(82395, 5707, 'Ousama Ranking S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179185.mp4', 'http://timg.bdta.pro/images/8f280c7c66a2ee7f32f3373289fd15dd.jpg'),
(82396, 5707, 'Ousama Ranking S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179186.mp4', 'http://timg.bdta.pro/images/974b3fa25c6e3452ac1b8473a37a4333.jpg'),
(82397, 5707, 'Ousama Ranking S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179187.mp4', 'http://timg.bdta.pro/images/198adcd8d44b8735aafd5c518fea9938.jpg'),
(82398, 5707, 'Ousama Ranking S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179188.mp4', 'http://timg.bdta.pro/images/862f96f154c14ea76f4dbd8c789dfbaa.jpg'),
(82399, 5707, 'Ousama Ranking S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179189.mp4', 'http://timg.bdta.pro/images/da15763652efe858166dfb90394a7800.jpg'),
(82400, 5707, 'Ousama Ranking S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179190.mp4', 'http://timg.bdta.pro/images/c942248fc9666a319a492940395599a9.jpg'),
(82401, 5707, 'Ousama Ranking S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179191.mp4', 'http://timg.bdta.pro/images/c7946423dab6eddfe4b70a928ca888f0.jpg'),
(82402, 5707, 'Ousama Ranking S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179192.mp4', 'http://timg.bdta.pro/images/e7dd280aa644b8c8dc4b3e04e262f1fa.jpg'),
(82403, 5707, 'Ousama Ranking S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179193.mp4', 'http://timg.bdta.pro/images/fc9564e2149dd4a4a469164f1d79303d.jpg'),
(82404, 5707, 'Ousama Ranking S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179194.mp4', 'http://timg.bdta.pro/images/844fb60ecf6ebbf30da5be74026e28e6.jpg'),
(82405, 5707, 'Ousama Ranking S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179195.mp4', 'http://timg.bdta.pro/images/f7d62dff8c63414e4f674c5b92ee7a04.jpg'),
(82406, 5707, 'Ousama Ranking S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/179196.mp4', 'http://timg.bdta.pro/images/5fbbca32df4842102aa53c7d68a315da.jpg'),
(82407, 5707, 'Ousama Ranking S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/179197.mp4', 'http://timg.bdta.pro/images/d00b4f99dc636f4b9b080d2a602addef.jpg'),
(82408, 5707, 'Ousama Ranking S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/179198.mp4', 'http://timg.bdta.pro/images/7b598a952f58480970ce45c096a023d7.jpg'),
(82409, 5707, 'Ousama Ranking S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/179199.mp4', 'http://timg.bdta.pro/images/dab60851e5332791b50d8f638d337b25.jpg'),
(82410, 5707, 'Ousama Ranking S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/179200.mp4', 'http://timg.bdta.pro/images/19826c37f8df5e2319df10a3d85c3beb.jpg'),
(82411, 5707, 'Ousama Ranking S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/179201.mp4', 'http://timg.bdta.pro/images/ce784c227ddca5885f6cf8544629aaf8.jpg'),
(82412, 5707, 'Ousama Ranking S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/179202.mp4', 'http://timg.bdta.pro/images/a9faea959e97922b42e3da77314a7cec.jpg'),
(82413, 5707, 'Ousama Ranking S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/179203.mp4', 'http://timg.bdta.pro/images/b00ef869bbb03f007b43fa5d3b75f834.jpg'),
(82414, 5707, 'Ousama Ranking S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/179204.mp4', 'http://timg.bdta.pro/images/2929d6f6872e136affaf0161b2aede28.jpg'),
(82415, 5707, 'Ousama Ranking S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/179205.mp4', 'http://timg.bdta.pro/images/27d0f5c47c74d991e8e7dd516099af96.jpg'),
(82416, 5707, 'Ousama Ranking S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/179206.mp4', 'http://timg.bdta.pro/images/3371ac9c307652490545a67d87ebaab8.jpg'),
(82417, 5707, 'Ousama Ranking S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/179207.mp4', 'http://gstaticontent.com/images/290d2e3f4cc067d4d7528d277c223667.jpg'),
(82418, 5707, 'Ousama Ranking S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/179208.mp4', 'http://gstaticontent.com/images/290d2e3f4cc067d4d7528d277c223667.jpg'),
(82419, 5707, 'Ousama Ranking S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/179209.mp4', 'http://gstaticontent.com/images/290d2e3f4cc067d4d7528d277c223667.jpg'),
(82420, 5707, 'Ousama Ranking S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/179210.mp4', 'http://gstaticontent.com/images/290d2e3f4cc067d4d7528d277c223667.jpg'),
(82421, 5708, 'Quase Feliz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179166.mp4', 'http://timg.bdta.pro/images/284345f10dd9a7b78de78bc89439f6b2.jpg'),
(82422, 5708, 'Quase Feliz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179167.mp4', 'http://timg.bdta.pro/images/e1a659b107186ebd8a86427b24a70359.jpg'),
(82423, 5708, 'Quase Feliz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179168.mp4', 'http://timg.bdta.pro/images/8610601ca78297f0121bea7df596ebf6.jpg'),
(82424, 5708, 'Quase Feliz S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179169.mp4', 'http://timg.bdta.pro/images/60e7dcb6496b93b12db0eee634348c68.jpg'),
(82425, 5708, 'Quase Feliz S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179170.mp4', 'http://timg.bdta.pro/images/35244eb203f55396bf601cc51fd8a947.jpg'),
(82426, 5708, 'Quase Feliz S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179171.mp4', 'http://timg.bdta.pro/images/1659e829867b7697272d82ccc82e9a9d.jpg'),
(82427, 5708, 'Quase Feliz S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179172.mp4', 'http://timg.bdta.pro/images/3c8ee123c626572d85e13e01adef4709.jpg'),
(82428, 5708, 'Quase Feliz S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179173.mp4', 'http://timg.bdta.pro/images/99445603b9944da59302db6db2f4ca2a.jpg'),
(82429, 5708, 'Quase Feliz S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179174.mp4', 'http://timg.bdta.pro/images/412a1f410d599beb20d25e7f541c0656.jpg'),
(82430, 5708, 'Quase Feliz S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179175.mp4', 'http://timg.bdta.pro/images/19c95aa46d6c257ea7cd3289dd7496e3.jpg'),
(82431, 5709, 'Quase Feliz S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179176.mp4', 'http://gstaticontent.com/images/5d48057c7b8cbdb67871f606e57f1908.jpg'),
(82432, 5709, 'Quase Feliz S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179177.mp4', 'http://gstaticontent.com/images/5d48057c7b8cbdb67871f606e57f1908.jpg'),
(82433, 5709, 'Quase Feliz S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179178.mp4', 'http://gstaticontent.com/images/5d48057c7b8cbdb67871f606e57f1908.jpg'),
(82434, 5709, 'Quase Feliz S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179179.mp4', 'http://gstaticontent.com/images/5d48057c7b8cbdb67871f606e57f1908.jpg'),
(82435, 5709, 'Quase Feliz S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179180.mp4', 'http://gstaticontent.com/images/5d48057c7b8cbdb67871f606e57f1908.jpg'),
(82436, 5709, 'Quase Feliz S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179181.mp4', 'http://gstaticontent.com/images/5d48057c7b8cbdb67871f606e57f1908.jpg'),
(82437, 5709, 'Quase Feliz S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179182.mp4', 'http://gstaticontent.com/images/5d48057c7b8cbdb67871f606e57f1908.jpg'),
(82438, 5709, 'Quase Feliz S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179183.mp4', 'http://gstaticontent.com/images/5d48057c7b8cbdb67871f606e57f1908.jpg'),
(82439, 5710, 'Queen Stars Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179158.mp4', 'http://timg.bdta.pro/images/59dca02e9be97591f49404c1c6cd0348.jpg'),
(82440, 5710, 'Queen Stars Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179159.mp4', 'http://timg.bdta.pro/images/75918e0534b06b900f160e243cd2a5ef.jpg'),
(82441, 5710, 'Queen Stars Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179160.mp4', 'http://timg.bdta.pro/images/9edfd2bce233dfbcb73c96444e470904.jpg'),
(82442, 5710, 'Queen Stars Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179161.mp4', 'http://timg.bdta.pro/images/ed402cefc405d05983eba4430baa7efc.jpg'),
(82443, 5710, 'Queen Stars Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179162.mp4', 'http://timg.bdta.pro/images/6ea4ce65af71b90523936080d066cd69.jpg'),
(82444, 5710, 'Queen Stars Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179163.mp4', 'http://timg.bdta.pro/images/7a5a53aef93622902ff52fbf5f04ddc0.jpg'),
(82445, 5710, 'Queen Stars Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179164.mp4', 'http://timg.bdta.pro/images/84a260ee30786f046fb8ff81928520cc.jpg'),
(82446, 5710, 'Queen Stars Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179165.mp4', 'http://timg.bdta.pro/images/aaceb821624dea88a812f997c9fe41d5.jpg'),
(82447, 5711, 'Rugido S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179150.mp4', 'http://timg.bdta.pro/images/fe1354ae95da0516f056c0982594492c.jpg'),
(82448, 5711, 'Rugido S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179151.mp4', 'http://timg.bdta.pro/images/b8efa2719fc655a469269ed2ce704f3d.jpg'),
(82449, 5711, 'Rugido S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179152.mp4', 'http://timg.bdta.pro/images/0ff4ef07ccce1e967ef654537807ce30.jpg'),
(82450, 5711, 'Rugido S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179153.mp4', 'http://timg.bdta.pro/images/0fa9e6aaae51836bf2a8147673aa2a25.jpg'),
(82451, 5711, 'Rugido S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179154.mp4', 'http://timg.bdta.pro/images/cb703ca5faa88c9821c76360b7d146cd.jpg'),
(82452, 5711, 'Rugido S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179155.mp4', 'http://timg.bdta.pro/images/91fb62a0be034d1bfdef73f12fc496b7.jpg'),
(82453, 5711, 'Rugido S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179156.mp4', 'http://timg.bdta.pro/images/8db6c9711cafb4b1a1edc1de8e9a8b34.jpg'),
(82454, 5711, 'Rugido S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179157.mp4', 'http://timg.bdta.pro/images/23c07666cfb91d57311fa9e28a80bea9.jpg'),
(82455, 5712, 'Sentença S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179144.mp4', 'http://gstaticontent.com/images/36846a96debbcd63716868f39db49bfa.jpg'),
(82456, 5712, 'Sentença S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179145.mp4', 'http://timg.bdta.pro/images/de0a6930147ed29c213fd0d1212f82d8.jpg'),
(82457, 5712, 'Sentença S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179146.mp4', 'http://gstaticontent.com/images/36846a96debbcd63716868f39db49bfa.jpg'),
(82458, 5712, 'Sentença S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179147.mp4', 'http://gstaticontent.com/images/36846a96debbcd63716868f39db49bfa.jpg'),
(82459, 5712, 'Sentença S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179148.mp4', 'http://gstaticontent.com/images/36846a96debbcd63716868f39db49bfa.jpg'),
(82460, 5712, 'Sentença S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179149.mp4', 'http://gstaticontent.com/images/36846a96debbcd63716868f39db49bfa.jpg'),
(82461, 5713, 'Shining Vale S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179136.mp4', 'http://timg.bdta.pro/images/117a487508c003a7a10756328adc3466.jpg'),
(82462, 5713, 'Shining Vale S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179137.mp4', 'http://timg.bdta.pro/images/2673955d3bc1c2ba99e4abab99dd7040.jpg'),
(82463, 5713, 'Shining Vale S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179138.mp4', 'http://timg.bdta.pro/images/879d575693ae7a1e257a5fa6735d82ca.jpg'),
(82464, 5713, 'Shining Vale S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179139.mp4', 'http://timg.bdta.pro/images/05cba6357ed192611130456a48364fb6.jpg'),
(82465, 5713, 'Shining Vale S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179140.mp4', 'http://timg.bdta.pro/images/19ad033e9d8c4b560b325d93cf89403e.jpg'),
(82466, 5713, 'Shining Vale S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179141.mp4', 'http://timg.bdta.pro/images/4fb439186b12751870c6c9e655912fcd.jpg'),
(82467, 5713, 'Shining Vale S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179142.mp4', 'http://timg.bdta.pro/images/8ba5ac2c46863a2d9477811163f4c025.jpg'),
(82468, 5713, 'Shining Vale S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179143.mp4', 'http://timg.bdta.pro/images/0ca13ef5a8749c4ee4a1acaeb9e896c6.jpg'),
(82469, 5714, 'Sociedade do Cansaço S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179126.mp4', 'http://gstaticontent.com/images/89d479a4af51d413499ef01d76e207d5.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(82470, 5714, 'Sociedade do Cansaço S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179127.mp4', 'http://gstaticontent.com/images/89d479a4af51d413499ef01d76e207d5.jpg'),
(82471, 5714, 'Sociedade do Cansaço S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179128.mp4', 'http://gstaticontent.com/images/89d479a4af51d413499ef01d76e207d5.jpg'),
(82472, 5714, 'Sociedade do Cansaço S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179129.mp4', 'http://gstaticontent.com/images/89d479a4af51d413499ef01d76e207d5.jpg'),
(82473, 5714, 'Sociedade do Cansaço S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179130.mp4', 'http://gstaticontent.com/images/89d479a4af51d413499ef01d76e207d5.jpg'),
(82474, 5714, 'Sociedade do Cansaço S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179131.mp4', 'http://gstaticontent.com/images/89d479a4af51d413499ef01d76e207d5.jpg'),
(82475, 5714, 'Sociedade do Cansaço S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179132.mp4', 'http://gstaticontent.com/images/89d479a4af51d413499ef01d76e207d5.jpg'),
(82476, 5714, 'Sociedade do Cansaço S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179133.mp4', 'http://gstaticontent.com/images/89d479a4af51d413499ef01d76e207d5.jpg'),
(82477, 5714, 'Sociedade do Cansaço S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179134.mp4', 'http://gstaticontent.com/images/89d479a4af51d413499ef01d76e207d5.jpg'),
(82478, 5714, 'Sociedade do Cansaço S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179135.mp4', 'http://gstaticontent.com/images/89d479a4af51d413499ef01d76e207d5.jpg'),
(82479, 5715, 'Sono Bisque Doll wa Koi wo Suru S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179114.mp4', 'http://timg.bdta.pro/images/03d3d0c219423c11c25279dd21f6f2c7.jpg'),
(82480, 5715, 'Sono Bisque Doll wa Koi wo Suru S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179115.mp4', 'http://timg.bdta.pro/images/fd0430d87de13148fd45374d8cb844ad.jpg'),
(82481, 5715, 'Sono Bisque Doll wa Koi wo Suru S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179116.mp4', 'http://timg.bdta.pro/images/7a8986d3e1c8d6a980c4869a160b744d.jpg'),
(82482, 5715, 'Sono Bisque Doll wa Koi wo Suru S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179117.mp4', 'http://timg.bdta.pro/images/16f86ed9dd58331b160d8b78a8a12e61.jpg'),
(82483, 5715, 'Sono Bisque Doll wa Koi wo Suru S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179118.mp4', 'http://timg.bdta.pro/images/128eef6616637833ce2c7a7f869d0598.jpg'),
(82484, 5715, 'Sono Bisque Doll wa Koi wo Suru S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179119.mp4', 'http://timg.bdta.pro/images/3aba6d9aa3caad1991a0b8349d8d7421.jpg'),
(82485, 5715, 'Sono Bisque Doll wa Koi wo Suru S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179120.mp4', 'http://timg.bdta.pro/images/b0d53c70bc19e62fafae52020aca6d82.jpg'),
(82486, 5715, 'Sono Bisque Doll wa Koi wo Suru S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179121.mp4', 'http://timg.bdta.pro/images/5288b0023167254950811c0f85c67554.jpg'),
(82487, 5715, 'Sono Bisque Doll wa Koi wo Suru S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179122.mp4', 'http://timg.bdta.pro/images/6758f929cf09cc72224b4972da07e9ab.jpg'),
(82488, 5715, 'Sono Bisque Doll wa Koi wo Suru S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179123.mp4', 'http://timg.bdta.pro/images/9076dff6841bc155530c551949380369.jpg'),
(82489, 5715, 'Sono Bisque Doll wa Koi wo Suru S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179124.mp4', 'http://timg.bdta.pro/images/268460a6542325ee20dfb0e9fa747f2c.jpg'),
(82490, 5715, 'Sono Bisque Doll wa Koi wo Suru S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179125.mp4', 'http://timg.bdta.pro/images/3f583e6c27c62a82ed3da48ee6637a29.jpg'),
(82491, 5716, 'The Oblongs S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179101.mp4', 'http://timg.bdta.pro/images/4eda83a862e39777933e54ef60ed2c67.jpg'),
(82492, 5716, 'The Oblongs S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179102.mp4', 'http://timg.bdta.pro/images/9fd48e671df40c66263ac39c14f9dd2b.jpg'),
(82493, 5716, 'The Oblongs S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179103.mp4', 'http://timg.bdta.pro/images/6ed747786f821628f5715d018b6747d0.jpg'),
(82494, 5716, 'The Oblongs S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179104.mp4', 'http://timg.bdta.pro/images/47f4042c218c0d562155d0ed82e14d2c.jpg'),
(82495, 5716, 'The Oblongs S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179105.mp4', 'http://timg.bdta.pro/images/f134d817361cd0226ebc5bc2eb288f62.jpg'),
(82496, 5716, 'The Oblongs S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179106.mp4', 'http://timg.bdta.pro/images/f631daf7e7355f212cd70f12d287f109.jpg'),
(82497, 5716, 'The Oblongs S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179107.mp4', 'http://timg.bdta.pro/images/16bd34054fa9a0139e80d0386cf30474.jpg'),
(82498, 5716, 'The Oblongs S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179108.mp4', 'http://timg.bdta.pro/images/f0c71caf7c9c6c593a4207f6e6a6c010.jpg'),
(82499, 5716, 'The Oblongs S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179109.mp4', 'http://gstaticontent.com/images/e3a6e52b23050e43408653cd68c42ee9.jpg'),
(82500, 5716, 'The Oblongs S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179110.mp4', 'http://gstaticontent.com/images/e3a6e52b23050e43408653cd68c42ee9.jpg'),
(82501, 5716, 'The Oblongs S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179111.mp4', 'http://gstaticontent.com/images/e3a6e52b23050e43408653cd68c42ee9.jpg'),
(82502, 5716, 'The Oblongs S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179112.mp4', 'http://gstaticontent.com/images/e3a6e52b23050e43408653cd68c42ee9.jpg'),
(82503, 5716, 'The Oblongs S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/179113.mp4', 'http://gstaticontent.com/images/e3a6e52b23050e43408653cd68c42ee9.jpg'),
(82504, 5717, 'The Wall BR S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179088.mp4', 'http://gstaticontent.com/images/b35b06e15b41b93d4857a50eb94a17f7.jpg'),
(82505, 5717, 'The Wall BR S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179089.mp4', 'http://gstaticontent.com/images/b35b06e15b41b93d4857a50eb94a17f7.jpg'),
(82506, 5717, 'The Wall BR S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179090.mp4', 'http://gstaticontent.com/images/b35b06e15b41b93d4857a50eb94a17f7.jpg'),
(82507, 5717, 'The Wall BR S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179091.mp4', 'http://gstaticontent.com/images/b35b06e15b41b93d4857a50eb94a17f7.jpg'),
(82508, 5717, 'The Wall BR S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179092.mp4', 'http://gstaticontent.com/images/b35b06e15b41b93d4857a50eb94a17f7.jpg'),
(82509, 5717, 'The Wall BR S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179093.mp4', 'http://gstaticontent.com/images/b35b06e15b41b93d4857a50eb94a17f7.jpg'),
(82510, 5717, 'The Wall BR S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179094.mp4', 'http://gstaticontent.com/images/b35b06e15b41b93d4857a50eb94a17f7.jpg'),
(82511, 5717, 'The Wall BR S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179095.mp4', 'http://gstaticontent.com/images/b35b06e15b41b93d4857a50eb94a17f7.jpg'),
(82512, 5717, 'The Wall BR S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179096.mp4', 'http://gstaticontent.com/images/b35b06e15b41b93d4857a50eb94a17f7.jpg'),
(82513, 5717, 'The Wall BR S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179097.mp4', 'http://gstaticontent.com/images/b35b06e15b41b93d4857a50eb94a17f7.jpg'),
(82514, 5717, 'The Wall BR S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179098.mp4', 'http://gstaticontent.com/images/b35b06e15b41b93d4857a50eb94a17f7.jpg'),
(82515, 5717, 'The Wall BR S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179099.mp4', 'http://gstaticontent.com/images/b35b06e15b41b93d4857a50eb94a17f7.jpg'),
(82516, 5717, 'The Wall BR S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/179100.mp4', 'http://gstaticontent.com/images/b35b06e15b41b93d4857a50eb94a17f7.jpg'),
(82517, 5718, 'Tokyo Vice [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178608.mp4', 'http://timg.bdta.pro/images/92a202435fa8f2d84092532ffff761fb.jpg'),
(82518, 5718, 'Tokyo Vice [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178609.mp4', 'http://timg.bdta.pro/images/9324c8b0f78b16f182ac2df46500b1d6.jpg'),
(82519, 5718, 'Tokyo Vice [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178610.mp4', 'http://timg.bdta.pro/images/1a61b44e21d44cb0413d60de24ca86ec.jpg'),
(82520, 5718, 'Tokyo Vice [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178611.mp4', 'http://timg.bdta.pro/images/bd19128bbb5dd791f1999c975498678b.jpg'),
(82521, 5718, 'Tokyo Vice [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178612.mp4', 'http://timg.bdta.pro/images/d807bc7afd6bf14dc81243ffc86c49c3.jpg'),
(82522, 5718, 'Tokyo Vice [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178613.mp4', 'http://timg.bdta.pro/images/cb475730b949720a5da246fef1efe00e.jpg'),
(82523, 5718, 'Tokyo Vice [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178614.mp4', 'http://timg.bdta.pro/images/430118b5f8b847829dc18bacb8114d45.jpg'),
(82524, 5718, 'Tokyo Vice [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178615.mp4', 'http://timg.bdta.pro/images/d8e2cd92d13b6e0e7db08f41217c0b36.jpg'),
(82525, 5719, 'Topo Gigio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179061.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82526, 5719, 'Topo Gigio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179062.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82527, 5719, 'Topo Gigio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179063.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82528, 5719, 'Topo Gigio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179064.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82529, 5719, 'Topo Gigio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179065.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82530, 5719, 'Topo Gigio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179066.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82531, 5719, 'Topo Gigio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179067.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82532, 5719, 'Topo Gigio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179068.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82533, 5719, 'Topo Gigio S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179069.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82534, 5719, 'Topo Gigio S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179070.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82535, 5719, 'Topo Gigio S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179071.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82536, 5719, 'Topo Gigio S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179072.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82537, 5719, 'Topo Gigio S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/179073.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82538, 5719, 'Topo Gigio S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/179074.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82539, 5719, 'Topo Gigio S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/179075.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82540, 5719, 'Topo Gigio S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/179076.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82541, 5719, 'Topo Gigio S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/179077.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82542, 5719, 'Topo Gigio S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/179078.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82543, 5719, 'Topo Gigio S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/179079.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82544, 5719, 'Topo Gigio S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/179080.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82545, 5719, 'Topo Gigio S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/179081.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82546, 5719, 'Topo Gigio S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/179082.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82547, 5719, 'Topo Gigio S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/179083.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82548, 5719, 'Topo Gigio S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/179084.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82549, 5719, 'Topo Gigio S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/179085.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82550, 5719, 'Topo Gigio S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/179086.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82551, 5719, 'Topo Gigio S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/179087.mp4', 'http://gstaticontent.com/images/6c51cd5cfaff1bbe13113faf36f6abb3.jpg'),
(82552, 5720, 'Anatomia de um Escândalo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/175659.mp4', 'http://timg.bdta.pro/images/d7aefda864752c4b8a1283ddf371b6cb.jpg'),
(82553, 5720, 'Anatomia de um Escândalo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/175660.mp4', 'http://timg.bdta.pro/images/5c56feec0189d2bd2fb928f5b5af9c60.jpg'),
(82554, 5720, 'Anatomia de um Escândalo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/175661.mp4', 'http://timg.bdta.pro/images/44e895c78863a7a7938d0d0d523476b2.jpg'),
(82555, 5720, 'Anatomia de um Escândalo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/175662.mp4', 'http://timg.bdta.pro/images/4f1c73e4a3a24d68ec3222e7f2546ad9.jpg'),
(82556, 5720, 'Anatomia de um Escândalo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/175663.mp4', 'http://timg.bdta.pro/images/c479551f6570e589a8285c8d008595ad.jpg'),
(82557, 5720, 'Anatomia de um Escândalo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/175664.mp4', 'http://timg.bdta.pro/images/0a7e5bdd8d17992a6ca78ee3a8378296.jpg'),
(82558, 5721, 'A Família Radical: Maior e Melhor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204313.mp4', 'http://timg.bdta.pro/images/4a8aef47dd1e0db4dfcd137d11664047.jpg'),
(82559, 5721, 'A Família Radical: Maior e Melhor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204314.mp4', 'http://timg.bdta.pro/images/dd2d1802a325a0e2aa121ee6c1bb5901.jpg'),
(82560, 5721, 'A Família Radical: Maior e Melhor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204315.mp4', 'http://timg.bdta.pro/images/97682a806306dbdb19d20bd7ffab32ce.jpg'),
(82561, 5721, 'A Família Radical: Maior e Melhor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204316.mp4', 'http://timg.bdta.pro/images/d52a4b1e964b6953af99a545c28ddf59.jpg'),
(82562, 5721, 'A Família Radical: Maior e Melhor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204317.mp4', 'http://timg.bdta.pro/images/d54e393cea41b8e185b19550db1f8ebf.jpg'),
(82563, 5721, 'A Família Radical: Maior e Melhor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204318.mp4', 'http://timg.bdta.pro/images/0661b65ac33ca08ecb6cbb343e529a93.jpg'),
(82564, 5721, 'A Família Radical: Maior e Melhor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204319.mp4', 'http://timg.bdta.pro/images/fe92f10ca3d741889d15d17da08f5721.jpg'),
(82565, 5721, 'A Família Radical: Maior e Melhor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204320.mp4', 'http://timg.bdta.pro/images/756ce42f71e6104c42e7bc127a86f8c8.jpg'),
(82566, 5721, 'A Família Radical: Maior e Melhor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204321.mp4', 'http://timg.bdta.pro/images/ae55774e79d56ffc6f4fbf1af869a424.jpg'),
(82567, 5721, 'A Família Radical: Maior e Melhor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204322.mp4', 'http://timg.bdta.pro/images/a1c8a224fdd77a70dd29684127a05f19.jpg'),
(82568, 5722, 'A Família Radical: Maior e Melhor S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/20YHfNU31Qkr7a82vvI8IUUjXhi.jpg'),
(82569, 5722, 'A Família Radical: Maior e Melhor S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ILFDoOyOA3mMRFWLG6bn6d6g0m.jpg'),
(82570, 5722, 'A Família Radical: Maior e Melhor S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJER8PUcpx6yBz1sZWNgQBVC0cA.jpg'),
(82571, 5722, 'A Família Radical: Maior e Melhor S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3HRBHANSfbP9I9BaiksFzB7ifuR.jpg'),
(82572, 5722, 'A Família Radical: Maior e Melhor S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i3k0ADewAMWbXkbtijt0CNQKs5a.jpg'),
(82573, 5722, 'A Família Radical: Maior e Melhor S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Fggxy1y0FMNzkNbdeDcv69cjgb.jpg'),
(82574, 5722, 'A Família Radical: Maior e Melhor S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2B1dF92gvtG3roYZyg7IDdSmpdP.jpg'),
(82575, 5722, 'A Família Radical: Maior e Melhor S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kZrn17iK2kgJzI6uDGMI2rhOPQ.jpg'),
(82576, 5722, 'A Família Radical: Maior e Melhor S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9qlfEg6XTjmf7ZfnRWNyf1B9eot.jpg'),
(82577, 5722, 'A Família Radical: Maior e Melhor S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wxleuR9G3J0IwXHM6sfDtGchT6q.jpg'),
(82578, 5723, 'A Sorte de Loli S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178958.mp4', 'http://timg.bdta.pro/images/325534ee67844e8b91a29d2b0117c3fa.jpg'),
(82579, 5723, 'A Sorte de Loli S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178959.mp4', 'http://timg.bdta.pro/images/a8d3842e8454f29c360e7cea8a31220f.jpg'),
(82580, 5723, 'A Sorte de Loli S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178960.mp4', 'http://timg.bdta.pro/images/e062e33cd80130973439c87356a4720c.jpg'),
(82581, 5723, 'A Sorte de Loli S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178961.mp4', 'http://timg.bdta.pro/images/18a227150acd24fcf6632e45ec4d08f2.jpg'),
(82582, 5723, 'A Sorte de Loli S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178962.mp4', 'http://timg.bdta.pro/images/45940f506deb73b8f33edad23e0d65de.jpg'),
(82583, 5723, 'A Sorte de Loli S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178963.mp4', 'http://timg.bdta.pro/images/2b59b3180b58faa7c1740804fcad7690.jpg'),
(82584, 5723, 'A Sorte de Loli S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178964.mp4', 'http://timg.bdta.pro/images/6f91df283a045e32ff79db58234d8f41.jpg'),
(82585, 5723, 'A Sorte de Loli S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178965.mp4', 'http://timg.bdta.pro/images/6a7a073d9addb2cbe20892bb49cc1294.jpg'),
(82586, 5723, 'A Sorte de Loli S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178966.mp4', 'http://timg.bdta.pro/images/a55c4a4e2116b1fb41a4125aa776fa05.jpg'),
(82587, 5723, 'A Sorte de Loli S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178967.mp4', 'http://timg.bdta.pro/images/986d0161dfc5e60322d335e0cd7c0113.jpg'),
(82588, 5723, 'A Sorte de Loli S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/178968.mp4', 'http://timg.bdta.pro/images/89b98c3f28ebdc51647ca3b19809e1e7.jpg'),
(82589, 5723, 'A Sorte de Loli S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/178969.mp4', 'http://timg.bdta.pro/images/62b812fe06a54c1c269a99228a105551.jpg'),
(82590, 5723, 'A Sorte de Loli S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/178970.mp4', 'http://timg.bdta.pro/images/14143ea132ade8e15b82a6f3093d1902.jpg'),
(82591, 5723, 'A Sorte de Loli S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/178971.mp4', 'http://timg.bdta.pro/images/7d1ae883e49e21f1585cba6c4a206ef7.jpg'),
(82592, 5723, 'A Sorte de Loli S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/178972.mp4', 'http://timg.bdta.pro/images/220ec3ee111e09106dcfd1d9d28ee706.jpg'),
(82593, 5723, 'A Sorte de Loli S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/178973.mp4', 'http://timg.bdta.pro/images/d8d958d730ee3b825a5792c3cee85fe8.jpg'),
(82594, 5723, 'A Sorte de Loli S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/178974.mp4', 'http://timg.bdta.pro/images/73deead7c7e34588029754033c9dc244.jpg'),
(82595, 5723, 'A Sorte de Loli S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/178975.mp4', 'http://timg.bdta.pro/images/30781759a1c30e33fa0b591bd116686e.jpg'),
(82596, 5723, 'A Sorte de Loli S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/178976.mp4', 'http://timg.bdta.pro/images/37b143b40e69b8352cbfaeaeb3f212ae.jpg'),
(82597, 5723, 'A Sorte de Loli S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/178977.mp4', 'http://timg.bdta.pro/images/c22fd7b7bb5e28cb308589485bc0d2f6.jpg'),
(82598, 5723, 'A Sorte de Loli S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/178978.mp4', 'http://timg.bdta.pro/images/79bb5091341b5ede4e84599519e0c828.jpg'),
(82599, 5723, 'A Sorte de Loli S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/178979.mp4', 'http://timg.bdta.pro/images/d9aa54849aa7e0977a2d82924601dbaf.jpg'),
(82600, 5723, 'A Sorte de Loli S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/178980.mp4', 'http://timg.bdta.pro/images/a57c60cac8b4f3e9183ff1b6b79879a1.jpg'),
(82601, 5723, 'A Sorte de Loli S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/178981.mp4', 'http://timg.bdta.pro/images/ac40ee783c5e2a17f31193b4aff01193.jpg'),
(82602, 5723, 'A Sorte de Loli S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/178982.mp4', 'http://timg.bdta.pro/images/10efa446c3e265f514758290d5658111.jpg'),
(82603, 5723, 'A Sorte de Loli S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/178983.mp4', 'http://timg.bdta.pro/images/0a644f5fcb4564e5605dc083adc39da5.jpg'),
(82604, 5723, 'A Sorte de Loli S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/178984.mp4', 'http://timg.bdta.pro/images/895b0a467a32e49050b6a1457647307d.jpg'),
(82605, 5723, 'A Sorte de Loli S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/178985.mp4', 'http://timg.bdta.pro/images/b4c21ac5072cbe4f88b8b615a6c08df5.jpg'),
(82606, 5723, 'A Sorte de Loli S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/178986.mp4', 'http://timg.bdta.pro/images/f9e7119249211d7b433ddee97f55d566.jpg'),
(82607, 5723, 'A Sorte de Loli S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/178987.mp4', 'http://timg.bdta.pro/images/14d0df43a1d279c5a78657de78d1b894.jpg'),
(82608, 5723, 'A Sorte de Loli S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/178988.mp4', 'http://timg.bdta.pro/images/c869bbbe137f1fae28d86c4d75856802.jpg'),
(82609, 5723, 'A Sorte de Loli S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/178989.mp4', 'http://timg.bdta.pro/images/bdbc048f6a710b37790f9b403007ade4.jpg'),
(82610, 5723, 'A Sorte de Loli S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/178990.mp4', 'http://timg.bdta.pro/images/2630cb7753a64254138fe85375658a82.jpg'),
(82611, 5723, 'A Sorte de Loli S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/178991.mp4', 'http://timg.bdta.pro/images/1fcab26d12c8f79f1e6f6eb1abf116d7.jpg'),
(82612, 5723, 'A Sorte de Loli S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/178992.mp4', 'http://timg.bdta.pro/images/0f1da1b6de22b8091dfbd9eca0c030c9.jpg'),
(82613, 5723, 'A Sorte de Loli S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/178993.mp4', 'http://timg.bdta.pro/images/bac9142fc838b56217447dc119d41802.jpg'),
(82614, 5723, 'A Sorte de Loli S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/178994.mp4', 'http://timg.bdta.pro/images/a7982f9e3b0f3a19ce7593c3c7a47c4a.jpg'),
(82615, 5723, 'A Sorte de Loli S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/178995.mp4', 'http://timg.bdta.pro/images/3a6c7bcfd979911e2642aef6bdd05b37.jpg'),
(82616, 5723, 'A Sorte de Loli S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/178996.mp4', 'http://timg.bdta.pro/images/27d9bc155e6d0120c78732df32fd01cd.jpg'),
(82617, 5723, 'A Sorte de Loli S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/178997.mp4', 'http://timg.bdta.pro/images/f6813f481e3d6d59f4ce6e88bdd2c76d.jpg'),
(82618, 5723, 'A Sorte de Loli S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/178998.mp4', 'http://timg.bdta.pro/images/b5c294166f2e6673c3e53553e85db1d8.jpg'),
(82619, 5723, 'A Sorte de Loli S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/178999.mp4', 'http://timg.bdta.pro/images/f402212ede869b0352b74b5540a9b99d.jpg'),
(82620, 5723, 'A Sorte de Loli S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/179000.mp4', 'http://timg.bdta.pro/images/9585e98c7d3d614b986fce7b56f7e093.jpg'),
(82621, 5723, 'A Sorte de Loli S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/179001.mp4', 'http://timg.bdta.pro/images/b14d440b6ba44d0871d42a94150c1c90.jpg'),
(82622, 5723, 'A Sorte de Loli S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/179002.mp4', 'http://timg.bdta.pro/images/93d825a7a250b7666890dde2d5273e6d.jpg'),
(82623, 5723, 'A Sorte de Loli S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/179003.mp4', 'http://timg.bdta.pro/images/ce5887634bf934fe837e4d7f7288f685.jpg'),
(82624, 5723, 'A Sorte de Loli S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/179004.mp4', 'http://timg.bdta.pro/images/4b102d57f3fdebcfd97afd20e4d4f1e1.jpg'),
(82625, 5723, 'A Sorte de Loli S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/179005.mp4', 'http://timg.bdta.pro/images/ce162e034e8dfbe32e0a907b48c0ab6a.jpg'),
(82626, 5723, 'A Sorte de Loli S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/179006.mp4', 'http://timg.bdta.pro/images/c5bc302b8028058f8631bcca014ba8d9.jpg'),
(82627, 5723, 'A Sorte de Loli S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/179007.mp4', 'http://timg.bdta.pro/images/f4bcb917036e3dc1b6a863d975f454c0.jpg'),
(82628, 5723, 'A Sorte de Loli S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/179008.mp4', 'http://timg.bdta.pro/images/8d0357df53d40ae5381a338aacdf632b.jpg'),
(82629, 5723, 'A Sorte de Loli S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/179009.mp4', 'http://timg.bdta.pro/images/a36bc66b3936fd2090b78efec7ad6a55.jpg'),
(82630, 5723, 'A Sorte de Loli S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/179010.mp4', 'http://timg.bdta.pro/images/c34e7fa2cb28b80c2deb3c8d4a084207.jpg'),
(82631, 5723, 'A Sorte de Loli S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/179011.mp4', 'http://timg.bdta.pro/images/fd323c15f2c13dd83f8b00a5d54de86a.jpg'),
(82632, 5723, 'A Sorte de Loli S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/179012.mp4', 'http://timg.bdta.pro/images/3fa1a927480681b31dc15674b8f18094.jpg'),
(82633, 5723, 'A Sorte de Loli S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/179013.mp4', 'http://timg.bdta.pro/images/14203af1bdf1d6d391f0222f55421cb1.jpg'),
(82634, 5723, 'A Sorte de Loli S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/179014.mp4', 'http://timg.bdta.pro/images/dee43e3ec558ed1ca913c5e6dc67fbf4.jpg'),
(82635, 5723, 'A Sorte de Loli S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/179015.mp4', 'http://timg.bdta.pro/images/9dabe52226140a259a0d10004e3fcb07.jpg'),
(82636, 5723, 'A Sorte de Loli S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/179016.mp4', 'http://timg.bdta.pro/images/ed0e25a1135a042fe08e759ad4cbc3e4.jpg'),
(82637, 5723, 'A Sorte de Loli S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/179017.mp4', 'http://timg.bdta.pro/images/c1fd69f1e506390bc0c79738ff146bf5.jpg'),
(82638, 5723, 'A Sorte de Loli S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/179018.mp4', 'http://timg.bdta.pro/images/d7017d05b45a0f81a7b21725b916f674.jpg'),
(82639, 5723, 'A Sorte de Loli S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/179019.mp4', 'http://timg.bdta.pro/images/af0cfcd849d2c1bf8787f31a2e5f5d0f.jpg'),
(82640, 5723, 'A Sorte de Loli S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/179020.mp4', 'http://timg.bdta.pro/images/4582f327a9f5f608d27edb156b6e66b4.jpg'),
(82641, 5723, 'A Sorte de Loli S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/179021.mp4', 'http://timg.bdta.pro/images/46e962688fd4d6ca7449a8d3350d27e2.jpg'),
(82642, 5723, 'A Sorte de Loli S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/179022.mp4', 'http://timg.bdta.pro/images/28264fd745fa068d710172ae826078cf.jpg'),
(82643, 5723, 'A Sorte de Loli S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/179023.mp4', 'http://timg.bdta.pro/images/f911b6ef3acd68de476ed4116c3a5b4d.jpg'),
(82644, 5723, 'A Sorte de Loli S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/179024.mp4', 'http://timg.bdta.pro/images/4bb319fbc3e6752f2e88b6d7fdb47fbd.jpg'),
(82645, 5723, 'A Sorte de Loli S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/179025.mp4', 'http://timg.bdta.pro/images/e3fc2fe13b0ea9560fcb0ddf5354e975.jpg'),
(82646, 5723, 'A Sorte de Loli S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/179026.mp4', 'http://timg.bdta.pro/images/37b7da3e5dd376218e4ca4f2ed4c5a87.jpg'),
(82647, 5723, 'A Sorte de Loli S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/179027.mp4', 'http://timg.bdta.pro/images/d57bc561894254b13ccd10b950964a7e.jpg'),
(82648, 5723, 'A Sorte de Loli S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/179028.mp4', 'http://timg.bdta.pro/images/486844c58ec9c0fb1323cc3e1d4dbedc.jpg'),
(82649, 5723, 'A Sorte de Loli S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/179029.mp4', 'http://timg.bdta.pro/images/fff2b00afad8f719627c86d845dc5d29.jpg'),
(82650, 5723, 'A Sorte de Loli S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/179030.mp4', 'http://timg.bdta.pro/images/77362d8e20961d4b7ea975f8446df07d.jpg'),
(82651, 5723, 'A Sorte de Loli S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/179031.mp4', 'http://timg.bdta.pro/images/35d8f019307c73c1155ae119f43f3124.jpg'),
(82652, 5723, 'A Sorte de Loli S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/179032.mp4', 'http://timg.bdta.pro/images/2c066b44143783f2460c01cbfb7d690b.jpg'),
(82653, 5723, 'A Sorte de Loli S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/179033.mp4', 'http://timg.bdta.pro/images/0e225e2bbaa467ce9e1f6f5568946560.jpg'),
(82654, 5723, 'A Sorte de Loli S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/179034.mp4', 'http://timg.bdta.pro/images/5eda446596a58131381912dd68abc1eb.jpg'),
(82655, 5723, 'A Sorte de Loli S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/179035.mp4', 'http://timg.bdta.pro/images/67574251056d32d27025917d2d428b65.jpg'),
(82656, 5723, 'A Sorte de Loli S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/179036.mp4', 'http://timg.bdta.pro/images/08d1e943cfc559d47910570a08bcd9ba.jpg'),
(82657, 5723, 'A Sorte de Loli S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/179037.mp4', 'http://timg.bdta.pro/images/d9bdbe5a93e43b529c5e621203e2eadb.jpg'),
(82658, 5723, 'A Sorte de Loli S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/179038.mp4', 'http://timg.bdta.pro/images/53399d506261b3727abf2cfb63a1f6b9.jpg'),
(82659, 5723, 'A Sorte de Loli S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/179039.mp4', 'http://timg.bdta.pro/images/d398599122b4c9ba44928698f5cd627e.jpg'),
(82660, 5723, 'A Sorte de Loli S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/179040.mp4', 'http://timg.bdta.pro/images/3de0b8b3735dd3183018da7ff85367a3.jpg'),
(82661, 5723, 'A Sorte de Loli S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/179041.mp4', 'http://timg.bdta.pro/images/5165153a41ea5d84ec31d5c272d9c8ff.jpg'),
(82662, 5723, 'A Sorte de Loli S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/179042.mp4', 'http://timg.bdta.pro/images/1de5f5a11c5ac04737441717631bddb0.jpg'),
(82663, 5723, 'A Sorte de Loli S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/179043.mp4', 'http://timg.bdta.pro/images/a9724a5c8568b0b1cd112187e0848aa3.jpg'),
(82664, 5723, 'A Sorte de Loli S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/179044.mp4', 'http://timg.bdta.pro/images/95a7a8b2e30655c4f61c288ea5c7f333.jpg'),
(82665, 5723, 'A Sorte de Loli S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/179045.mp4', 'http://timg.bdta.pro/images/cfd705c0851d489034f9d5eebff01b35.jpg'),
(82666, 5723, 'A Sorte de Loli S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/179046.mp4', 'http://timg.bdta.pro/images/9c954abd17cc73695920a70c26057c41.jpg'),
(82667, 5723, 'A Sorte de Loli S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/179047.mp4', 'http://timg.bdta.pro/images/715d9a30c96ee9cf1f8be294b2f36eda.jpg'),
(82668, 5723, 'A Sorte de Loli S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/179048.mp4', 'http://timg.bdta.pro/images/f52549512aef1810113957d05ecdab5b.jpg'),
(82669, 5723, 'A Sorte de Loli S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/179049.mp4', 'http://timg.bdta.pro/images/3c1917d386b2e9a8503b359f53b3f39a.jpg'),
(82670, 5723, 'A Sorte de Loli S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/179050.mp4', 'http://timg.bdta.pro/images/9ccde28ba225fc0f6bb21afefc3aaf41.jpg'),
(82671, 5723, 'A Sorte de Loli S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/179051.mp4', 'http://timg.bdta.pro/images/f57a70d9f122c5e8516a4fd2281c3aeb.jpg'),
(82672, 5723, 'A Sorte de Loli S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/179052.mp4', 'http://timg.bdta.pro/images/32762fba93173184abd2d829ffbae6ad.jpg'),
(82673, 5723, 'A Sorte de Loli S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/179053.mp4', 'http://timg.bdta.pro/images/6b1191d95f9dad33b10b1d64bd22f32c.jpg'),
(82674, 5723, 'A Sorte de Loli S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/179054.mp4', 'http://timg.bdta.pro/images/5a272a6aaa1d2ede16aae9ed40579445.jpg'),
(82675, 5723, 'A Sorte de Loli S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/179055.mp4', 'http://timg.bdta.pro/images/7b70b894fbb55fc531745ec87641b773.jpg'),
(82676, 5723, 'A Sorte de Loli S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/179056.mp4', 'http://timg.bdta.pro/images/b48079af3a34977a3745f93d1fd22cfd.jpg'),
(82677, 5723, 'A Sorte de Loli S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/179057.mp4', 'http://timg.bdta.pro/images/e4f600547d95da27e8fd025f61a3be56.jpg'),
(82678, 5723, 'A Sorte de Loli S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/179058.mp4', 'http://timg.bdta.pro/images/b010bb5b3b3f26e993532bd136cb47f7.jpg'),
(82679, 5723, 'A Sorte de Loli S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/179059.mp4', 'http://timg.bdta.pro/images/4511e5357e11f92b45e63043ee78e982.jpg'),
(82680, 5723, 'A Sorte de Loli S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/179060.mp4', 'http://timg.bdta.pro/images/a54cd789774b0a7fa431be8067fe3fe8.jpg'),
(82681, 5724, 'Abbott Elementary S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208171.mp4', 'http://timg.bdta.pro/images/c8cb4678c74a837d79bcb5e090f79275.jpg'),
(82682, 5724, 'Abbott Elementary S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208172.mp4', 'http://timg.bdta.pro/images/bacbeda59c6b27e4d64cdb6ef7ce8b6c.jpg'),
(82683, 5724, 'Abbott Elementary S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208173.mp4', 'http://timg.bdta.pro/images/bf0e6c30f5f3b95b40a3143d61c79fab.jpg'),
(82684, 5724, 'Abbott Elementary S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208174.mp4', 'http://timg.bdta.pro/images/3b4c0faa4554caacc698aef92fb32d76.jpg'),
(82685, 5724, 'Abbott Elementary S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208175.mp4', 'http://timg.bdta.pro/images/2c305dec326e8af825c0cf8535fd6e1c.jpg'),
(82686, 5724, 'Abbott Elementary S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208176.mp4', 'http://timg.bdta.pro/images/dc69983c4baf9039da8eeda694007e04.jpg'),
(82687, 5724, 'Abbott Elementary S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208177.mp4', 'http://timg.bdta.pro/images/c45ac8b67168ce2d727e20dee605a69f.jpg'),
(82688, 5724, 'Abbott Elementary S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208178.mp4', 'http://timg.bdta.pro/images/f5e0c69ff466b7e89967cc67030041b6.jpg'),
(82689, 5724, 'Abbott Elementary S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208179.mp4', 'http://gstaticontent.com/images/9037c88527bb7f99c493f73cf25a008d.jpg'),
(82690, 5724, 'Abbott Elementary S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208180.mp4', 'http://gstaticontent.com/images/9037c88527bb7f99c493f73cf25a008d.jpg'),
(82691, 5724, 'Abbott Elementary S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208181.mp4', 'http://gstaticontent.com/images/9037c88527bb7f99c493f73cf25a008d.jpg'),
(82692, 5724, 'Abbott Elementary S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208182.mp4', 'http://gstaticontent.com/images/9037c88527bb7f99c493f73cf25a008d.jpg'),
(82693, 5724, 'Abbott Elementary S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/208183.mp4', 'http://gstaticontent.com/images/9037c88527bb7f99c493f73cf25a008d.jpg'),
(82694, 5725, 'Abbott Elementary S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dhFtWBUeNSIW5frUHbXNBWBeYMg.jpg'),
(82695, 5725, 'Abbott Elementary S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/46EFLIog9D70C2Eo9tIPYnqrHks.jpg'),
(82696, 5725, 'Abbott Elementary S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A0M64HqvDFVGgp1L5csF1BiVqO2.jpg'),
(82697, 5725, 'Abbott Elementary S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g4p97LVrEP0jz1SChPe37WAGTmz.jpg'),
(82698, 5725, 'Abbott Elementary S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aMSG0DdjbkQAyQfYE74DdBOOHiB.jpg'),
(82699, 5725, 'Abbott Elementary S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208189.mp4', 'http://image.tmdb.org/t/p/w1280/8iNPwlifYEO8ols9HNN2KBmd9av.jpg'),
(82700, 5725, 'Abbott Elementary S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208190.mp4', 'http://image.tmdb.org/t/p/w1280/8XcTMS1WRUELo9PhBg9SI2hTqbc.jpg'),
(82701, 5725, 'Abbott Elementary S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9w8hknFkZXcQfmAtbI8D0WsBCk2.jpg'),
(82702, 5725, 'Abbott Elementary S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208192.mp4', 'http://image.tmdb.org/t/p/w1280/dtzegreWMMtjISwDxTPjt5vImHX.jpg'),
(82703, 5725, 'Abbott Elementary S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208193.mp4', 'http://image.tmdb.org/t/p/w1280/ru5EvS134BqrUFc806IrhauDqgh.jpg'),
(82704, 5725, 'Abbott Elementary S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208194.mp4', 'http://image.tmdb.org/t/p/w1280/fJNTicTc5X5u97TlygqllbOPjl8.jpg'),
(82705, 5725, 'Abbott Elementary S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/303107.mp4', 'http://gstaticontent.com/images/9037c88527bb7f99c493f73cf25a008d.jpg'),
(82706, 5725, 'Abbott Elementary S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/303108.mp4', 'http://gstaticontent.com/images/9037c88527bb7f99c493f73cf25a008d.jpg'),
(82707, 5725, 'Abbott Elementary S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/303109.mp4', 'http://gstaticontent.com/images/9037c88527bb7f99c493f73cf25a008d.jpg'),
(82708, 5725, 'Abbott Elementary S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/303110.mp4', 'http://gstaticontent.com/images/9037c88527bb7f99c493f73cf25a008d.jpg'),
(82709, 5725, 'Abbott Elementary S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/303111.mp4', 'http://gstaticontent.com/images/9037c88527bb7f99c493f73cf25a008d.jpg'),
(82710, 5725, 'Abbott Elementary S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/303112.mp4', 'http://gstaticontent.com/images/9037c88527bb7f99c493f73cf25a008d.jpg'),
(82711, 5725, 'Abbott Elementary S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/303113.mp4', 'http://gstaticontent.com/images/9037c88527bb7f99c493f73cf25a008d.jpg'),
(82712, 5725, 'Abbott Elementary S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/303114.mp4', 'http://gstaticontent.com/images/9037c88527bb7f99c493f73cf25a008d.jpg'),
(82713, 5725, 'Abbott Elementary S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/303115.mp4', 'http://gstaticontent.com/images/9037c88527bb7f99c493f73cf25a008d.jpg'),
(82714, 5725, 'Abbott Elementary S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/303116.mp4', 'http://gstaticontent.com/images/9037c88527bb7f99c493f73cf25a008d.jpg'),
(82715, 5725, 'Abbott Elementary S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/303117.mp4', 'http://gstaticontent.com/images/9037c88527bb7f99c493f73cf25a008d.jpg'),
(82716, 5726, 'Confie em Mim S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178952.mp4', 'http://timg.bdta.pro/images/fae9f2c13e777d375d1455422c3f18f7.jpg'),
(82717, 5726, 'Confie em Mim S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178953.mp4', 'http://timg.bdta.pro/images/ff3dcfe9fd6656057f53826c094535f1.jpg'),
(82718, 5726, 'Confie em Mim S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178954.mp4', 'http://timg.bdta.pro/images/67c0c6dd116c74ed05a11dc47679c7cd.jpg'),
(82719, 5726, 'Confie em Mim S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178955.mp4', 'http://timg.bdta.pro/images/0c578304b4ad5d0c5de1290a48077ba0.jpg'),
(82720, 5726, 'Confie em Mim S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178956.mp4', 'http://timg.bdta.pro/images/92a639c6dbb66a54b460534fb8d6fd39.jpg'),
(82721, 5726, 'Confie em Mim S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178957.mp4', 'http://timg.bdta.pro/images/252e1c8b00d718f96f7c7d382979464e.jpg'),
(82722, 5727, 'Conversando com um Serial Killer: O Palhaço Assassino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178949.mp4', 'http://timg.bdta.pro/images/91fa5cd2df138facb63a5fa34fb439ee.jpg'),
(82723, 5727, 'Conversando com um Serial Killer: O Palhaço Assassino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178950.mp4', 'http://timg.bdta.pro/images/40140e7407f5601904d257f36b1548af.jpg'),
(82724, 5727, 'Conversando com um Serial Killer: O Palhaço Assassino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178951.mp4', 'http://timg.bdta.pro/images/ea6e98d93c3b16b3cd5e14ef0a37468d.jpg'),
(82725, 5728, 'Coração Marcado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211855.mp4', 'http://timg.bdta.pro/images/84729b77b7a7e1014eb0b85f642bdab0.jpg'),
(82726, 5728, 'Coração Marcado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211856.mp4', 'http://timg.bdta.pro/images/e8b9b2f7c0d1f6baaa6c3f40a11fa953.jpg'),
(82727, 5728, 'Coração Marcado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211857.mp4', 'http://timg.bdta.pro/images/7f874d94ebe5a553476dc5288fea0320.jpg'),
(82728, 5728, 'Coração Marcado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211858.mp4', 'http://timg.bdta.pro/images/06da20152a1d9a8e9e93c3c5210bb4bb.jpg'),
(82729, 5728, 'Coração Marcado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211859.mp4', 'http://timg.bdta.pro/images/889e2dc9e234f6250bdcbb8815b23de7.jpg'),
(82730, 5728, 'Coração Marcado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211860.mp4', 'http://timg.bdta.pro/images/99e6baef9a1be301213ba9b3da86701b.jpg'),
(82731, 5728, 'Coração Marcado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211861.mp4', 'http://timg.bdta.pro/images/40a2e29d45950fd329444ffffa58bb1d.jpg'),
(82732, 5728, 'Coração Marcado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211862.mp4', 'http://timg.bdta.pro/images/cfee787024953757675cecc9c74c80a0.jpg'),
(82733, 5728, 'Coração Marcado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211863.mp4', 'http://timg.bdta.pro/images/4f131b6410b797a63862f1dca20b72d7.jpg'),
(82734, 5728, 'Coração Marcado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211864.mp4', 'http://timg.bdta.pro/images/178ed0febf6821e4b5006b52c7a8f4ba.jpg'),
(82735, 5728, 'Coração Marcado S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211865.mp4', 'http://timg.bdta.pro/images/67e3b90fdd283c92a7d35e24941265ac.jpg'),
(82736, 5728, 'Coração Marcado S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211866.mp4', 'http://timg.bdta.pro/images/d1853274bb738832b770892394f8cba2.jpg'),
(82737, 5728, 'Coração Marcado S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211867.mp4', 'http://timg.bdta.pro/images/a2f1a72cb72c4cf29a2c49c590901594.jpg'),
(82738, 5728, 'Coração Marcado S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/211868.mp4', 'http://timg.bdta.pro/images/671e322a5e3a0487945a2749bc4b03e2.jpg'),
(82739, 5729, 'Coração Marcado S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mVGSJqrKQmpytVZskiTO6f7JLVT.jpg'),
(82740, 5729, 'Coração Marcado S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xo1UU9PbGDxzP0B1i1YjK7PUz6x.jpg'),
(82741, 5729, 'Coração Marcado S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zPI0joOeSC4lnVuzGPTWPAA0iHI.jpg'),
(82742, 5729, 'Coração Marcado S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3uMi1yhdyr2xd85Up71IxRUervN.jpg'),
(82743, 5729, 'Coração Marcado S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fIcdeFGJeagIWyr9jw6jn2zX8Tf.jpg'),
(82744, 5729, 'Coração Marcado S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c26jVNKYKyjyPnZctEgT4GWcATX.jpg'),
(82745, 5729, 'Coração Marcado S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHozCQdhjYOIzy5i3itzrp41GRF.jpg'),
(82746, 5729, 'Coração Marcado S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7tml9GGOqrWrABcGdsaHdhrpYsv.jpg'),
(82747, 5729, 'Coração Marcado S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xYWRC2Cuv8crOMvQUBfDcf18fPK.jpg'),
(82748, 5729, 'Coração Marcado S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/grczrq3fspearkuq7HDWnjNOJEm.jpg'),
(82749, 5730, 'Greta Thunberg: Um Ano para Mudar O Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178946.mp4', 'http://timg.bdta.pro/images/71b3996d303a151be71abcc1a3445755.jpg'),
(82750, 5730, 'Greta Thunberg: Um Ano para Mudar O Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178947.mp4', 'http://timg.bdta.pro/images/a04da2257af502394cf54263120e22ef.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(82751, 5730, 'Greta Thunberg: Um Ano para Mudar O Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178948.mp4', 'http://timg.bdta.pro/images/a9bd857bceba97d38cd02267c40746ec.jpg'),
(82752, 5731, 'Heartstopper S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226269.mp4', 'http://timg.bdta.pro/images/25026e84fd329de5dd48c11b742f2d3e.jpg'),
(82753, 5731, 'Heartstopper S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226270.mp4', 'http://timg.bdta.pro/images/39224f317b79296a381caa541e9ed6e5.jpg'),
(82754, 5731, 'Heartstopper S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226271.mp4', 'http://timg.bdta.pro/images/5182590f29580035daa95582fe6cb6bd.jpg'),
(82755, 5731, 'Heartstopper S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226272.mp4', 'http://timg.bdta.pro/images/98d60723c4b66f441c055ed4241ea739.jpg'),
(82756, 5731, 'Heartstopper S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226273.mp4', 'http://timg.bdta.pro/images/624525e5ac3413a341595ee23872872d.jpg'),
(82757, 5731, 'Heartstopper S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226274.mp4', 'http://timg.bdta.pro/images/8f1b609437502573cdaa2994d8eb7f83.jpg'),
(82758, 5731, 'Heartstopper S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226275.mp4', 'http://timg.bdta.pro/images/e2abac03c5380c5e278c19592783a16f.jpg'),
(82759, 5731, 'Heartstopper S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226276.mp4', 'http://timg.bdta.pro/images/6659b8a5fd6f446efca92dabecb76aed.jpg'),
(82760, 5732, 'Heartstopper S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xgPWJUahXyajUL10TYEO77gezhq.jpg'),
(82761, 5732, 'Heartstopper S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iZ6ZYxvgyY9vQHhXVIzHZEUlCif.jpg'),
(82762, 5732, 'Heartstopper S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLRXbeKxOTbmzRdjc7cg1AopXzD.jpg'),
(82763, 5732, 'Heartstopper S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z1dQxHqXZY5FK7GDH95wQry51Cr.jpg'),
(82764, 5732, 'Heartstopper S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vOSa7CXHJvhaWkpic0tKowFVInS.jpg'),
(82765, 5732, 'Heartstopper S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ki2vpT7ZQmgOid7ZAy7M8PKrH2L.jpg'),
(82766, 5732, 'Heartstopper S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3PZjDWw1wBPWx5jXoyQ5OsanV9.jpg'),
(82767, 5732, 'Heartstopper S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tn2iYtq9Nw3eeVix4N3zRlvIfod.jpg'),
(82768, 5733, 'Heartstopper S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/470305.mp4', 'http://gstaticontent.com/images/2fe5b2e4064d8ccf3ffd72f68091ef8a.jpg'),
(82769, 5733, 'Heartstopper S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/470306.mp4', 'http://gstaticontent.com/images/2fe5b2e4064d8ccf3ffd72f68091ef8a.jpg'),
(82770, 5733, 'Heartstopper S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/470307.mp4', 'http://gstaticontent.com/images/2fe5b2e4064d8ccf3ffd72f68091ef8a.jpg'),
(82771, 5733, 'Heartstopper S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/470308.mp4', 'http://gstaticontent.com/images/2fe5b2e4064d8ccf3ffd72f68091ef8a.jpg'),
(82772, 5733, 'Heartstopper S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/470309.mp4', 'http://gstaticontent.com/images/2fe5b2e4064d8ccf3ffd72f68091ef8a.jpg'),
(82773, 5733, 'Heartstopper S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/470310.mp4', 'http://gstaticontent.com/images/2fe5b2e4064d8ccf3ffd72f68091ef8a.jpg'),
(82774, 5733, 'Heartstopper S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/470311.mp4', 'http://gstaticontent.com/images/2fe5b2e4064d8ccf3ffd72f68091ef8a.jpg'),
(82775, 5733, 'Heartstopper S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/470312.mp4', 'http://gstaticontent.com/images/2fe5b2e4064d8ccf3ffd72f68091ef8a.jpg'),
(82776, 5734, 'Josie e as Gatinhas no Espaço S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178930.mp4', 'http://timg.bdta.pro/images/7ddbe699c647e34572d1c3e5219acfb4.jpg'),
(82777, 5734, 'Josie e as Gatinhas no Espaço S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178931.mp4', 'http://timg.bdta.pro/images/0e278cbf9c636eda21ad64f0b5be0614.jpg'),
(82778, 5734, 'Josie e as Gatinhas no Espaço S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178932.mp4', 'http://timg.bdta.pro/images/c2a8b79c69448bd726f7212703ee7ba5.jpg'),
(82779, 5734, 'Josie e as Gatinhas no Espaço S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178933.mp4', 'http://gstaticontent.com/images/f90981f6c8e53a1eafc73812cad6f781.jpg'),
(82780, 5734, 'Josie e as Gatinhas no Espaço S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178934.mp4', 'http://gstaticontent.com/images/f90981f6c8e53a1eafc73812cad6f781.jpg'),
(82781, 5734, 'Josie e as Gatinhas no Espaço S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178935.mp4', 'http://gstaticontent.com/images/f90981f6c8e53a1eafc73812cad6f781.jpg'),
(82782, 5734, 'Josie e as Gatinhas no Espaço S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178936.mp4', 'http://gstaticontent.com/images/f90981f6c8e53a1eafc73812cad6f781.jpg'),
(82783, 5734, 'Josie e as Gatinhas no Espaço S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178937.mp4', 'http://gstaticontent.com/images/f90981f6c8e53a1eafc73812cad6f781.jpg'),
(82784, 5734, 'Josie e as Gatinhas no Espaço S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178938.mp4', 'http://gstaticontent.com/images/f90981f6c8e53a1eafc73812cad6f781.jpg'),
(82785, 5734, 'Josie e as Gatinhas no Espaço S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178939.mp4', 'http://gstaticontent.com/images/f90981f6c8e53a1eafc73812cad6f781.jpg'),
(82786, 5734, 'Josie e as Gatinhas no Espaço S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/178940.mp4', 'http://gstaticontent.com/images/f90981f6c8e53a1eafc73812cad6f781.jpg'),
(82787, 5734, 'Josie e as Gatinhas no Espaço S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/178941.mp4', 'http://gstaticontent.com/images/f90981f6c8e53a1eafc73812cad6f781.jpg'),
(82788, 5734, 'Josie e as Gatinhas no Espaço S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/178942.mp4', 'http://gstaticontent.com/images/f90981f6c8e53a1eafc73812cad6f781.jpg'),
(82789, 5734, 'Josie e as Gatinhas no Espaço S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/178943.mp4', 'http://gstaticontent.com/images/f90981f6c8e53a1eafc73812cad6f781.jpg'),
(82790, 5734, 'Josie e as Gatinhas no Espaço S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/178944.mp4', 'http://gstaticontent.com/images/f90981f6c8e53a1eafc73812cad6f781.jpg'),
(82791, 5734, 'Josie e as Gatinhas no Espaço S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/178945.mp4', 'http://gstaticontent.com/images/f90981f6c8e53a1eafc73812cad6f781.jpg'),
(82792, 5735, 'Kentaro Hiyama: O Homem que Engravidou S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178922.mp4', 'http://gstaticontent.com/images/5670191cf5c40bcf9868472cf3bb08f3.jpg'),
(82793, 5735, 'Kentaro Hiyama: O Homem que Engravidou S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178923.mp4', 'http://gstaticontent.com/images/5670191cf5c40bcf9868472cf3bb08f3.jpg'),
(82794, 5735, 'Kentaro Hiyama: O Homem que Engravidou S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178924.mp4', 'http://gstaticontent.com/images/5670191cf5c40bcf9868472cf3bb08f3.jpg'),
(82795, 5735, 'Kentaro Hiyama: O Homem que Engravidou S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178925.mp4', 'http://gstaticontent.com/images/5670191cf5c40bcf9868472cf3bb08f3.jpg'),
(82796, 5735, 'Kentaro Hiyama: O Homem que Engravidou S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178926.mp4', 'http://gstaticontent.com/images/5670191cf5c40bcf9868472cf3bb08f3.jpg'),
(82797, 5735, 'Kentaro Hiyama: O Homem que Engravidou S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178927.mp4', 'http://gstaticontent.com/images/5670191cf5c40bcf9868472cf3bb08f3.jpg'),
(82798, 5735, 'Kentaro Hiyama: O Homem que Engravidou S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178928.mp4', 'http://gstaticontent.com/images/5670191cf5c40bcf9868472cf3bb08f3.jpg'),
(82799, 5735, 'Kentaro Hiyama: O Homem que Engravidou S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178929.mp4', 'http://gstaticontent.com/images/5670191cf5c40bcf9868472cf3bb08f3.jpg'),
(82800, 5736, 'Leonardo Da Vinci S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178914.mp4', 'http://timg.bdta.pro/images/eb9824dfc88c3c4c8c6199aade039f45.jpg'),
(82801, 5736, 'Leonardo Da Vinci S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178915.mp4', 'http://timg.bdta.pro/images/bbb7b526431899fb1a24ebaa41fd7e0d.jpg'),
(82802, 5736, 'Leonardo Da Vinci S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178916.mp4', 'http://timg.bdta.pro/images/23cd16112cacf42fa4ccbfb3076d8943.jpg'),
(82803, 5736, 'Leonardo Da Vinci S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178917.mp4', 'http://timg.bdta.pro/images/4a53533ff57e3927f4047d94217e3e41.jpg'),
(82804, 5736, 'Leonardo Da Vinci S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178918.mp4', 'http://timg.bdta.pro/images/4bc148eda0fbe851de2c89bb0515046c.jpg'),
(82805, 5736, 'Leonardo Da Vinci S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178919.mp4', 'http://timg.bdta.pro/images/72309d26b40c52d57faf84f68770db96.jpg'),
(82806, 5736, 'Leonardo Da Vinci S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178920.mp4', 'http://timg.bdta.pro/images/baee5a2396921b33d2647514091d2114.jpg'),
(82807, 5736, 'Leonardo Da Vinci S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178921.mp4', 'http://timg.bdta.pro/images/e3f47f46a37d8c3fe97aea23d61beecb.jpg'),
(82808, 5737, 'Milo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178888.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82809, 5737, 'Milo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178889.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82810, 5737, 'Milo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178890.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82811, 5737, 'Milo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178891.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82812, 5737, 'Milo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178892.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82813, 5737, 'Milo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178893.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82814, 5737, 'Milo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178894.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82815, 5737, 'Milo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178895.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82816, 5737, 'Milo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178896.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82817, 5737, 'Milo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178897.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82818, 5737, 'Milo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/178898.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82819, 5737, 'Milo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/178899.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82820, 5737, 'Milo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/178900.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82821, 5737, 'Milo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/178901.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82822, 5737, 'Milo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/178902.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82823, 5737, 'Milo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/178903.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82824, 5737, 'Milo S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/178904.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82825, 5737, 'Milo S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/178905.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82826, 5737, 'Milo S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/178906.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82827, 5737, 'Milo S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/178907.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82828, 5737, 'Milo S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/178908.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82829, 5737, 'Milo S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/178909.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82830, 5737, 'Milo S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/178910.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82831, 5737, 'Milo S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/178911.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82832, 5737, 'Milo S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/178912.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82833, 5737, 'Milo S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/178913.mp4', 'http://gstaticontent.com/images/85a88459025a98f0bfd2a739af8c819d.jpg'),
(82834, 5738, 'O Piloto Invisível S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178885.mp4', 'http://gstaticontent.com/images/c5e399969598752d2df05ac3947d544a.jpg'),
(82835, 5738, 'O Piloto Invisível S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178886.mp4', 'http://gstaticontent.com/images/c5e399969598752d2df05ac3947d544a.jpg'),
(82836, 5738, 'O Piloto Invisível S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178887.mp4', 'http://gstaticontent.com/images/c5e399969598752d2df05ac3947d544a.jpg'),
(82837, 5739, 'O Submarino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178878.mp4', 'http://timg.bdta.pro/images/a644d771fd3955d1d607e0b5726827ff.jpg'),
(82838, 5739, 'O Submarino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178879.mp4', 'http://timg.bdta.pro/images/4547713ea8dff585066927e50c9a3dc7.jpg'),
(82839, 5739, 'O Submarino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178880.mp4', 'http://timg.bdta.pro/images/317d1ed86b4a748892d4cc0d745468bf.jpg'),
(82840, 5739, 'O Submarino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178881.mp4', 'http://timg.bdta.pro/images/152a5ba18565efd2356d3da1f39e1338.jpg'),
(82841, 5739, 'O Submarino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178882.mp4', 'http://timg.bdta.pro/images/42836042d19d12906859eca62c5a2275.jpg'),
(82842, 5739, 'O Submarino S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178883.mp4', 'http://timg.bdta.pro/images/dabe6c2f742fddb40929823d108236bd.jpg'),
(82843, 5739, 'O Submarino S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178884.mp4', 'http://timg.bdta.pro/images/c144ce123e9b823bdd0cd6fb55327f08.jpg'),
(82844, 5740, 'Pivoting: Rodando Na Vida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178868.mp4', 'http://timg.bdta.pro/images/5face56101a258f2352ed5a1ce444aa9.jpg'),
(82845, 5740, 'Pivoting: Rodando Na Vida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178869.mp4', 'http://gstaticontent.com/images/9e16736392a4c7cc8039c85bf6539572.jpg'),
(82846, 5740, 'Pivoting: Rodando Na Vida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178870.mp4', 'http://gstaticontent.com/images/9e16736392a4c7cc8039c85bf6539572.jpg'),
(82847, 5740, 'Pivoting: Rodando Na Vida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178871.mp4', 'http://gstaticontent.com/images/9e16736392a4c7cc8039c85bf6539572.jpg'),
(82848, 5740, 'Pivoting: Rodando Na Vida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178872.mp4', 'http://gstaticontent.com/images/9e16736392a4c7cc8039c85bf6539572.jpg'),
(82849, 5740, 'Pivoting: Rodando Na Vida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178873.mp4', 'http://gstaticontent.com/images/9e16736392a4c7cc8039c85bf6539572.jpg'),
(82850, 5740, 'Pivoting: Rodando Na Vida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178874.mp4', 'http://gstaticontent.com/images/9e16736392a4c7cc8039c85bf6539572.jpg'),
(82851, 5740, 'Pivoting: Rodando Na Vida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178875.mp4', 'http://gstaticontent.com/images/9e16736392a4c7cc8039c85bf6539572.jpg'),
(82852, 5740, 'Pivoting: Rodando Na Vida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178876.mp4', 'http://gstaticontent.com/images/9e16736392a4c7cc8039c85bf6539572.jpg'),
(82853, 5740, 'Pivoting: Rodando Na Vida S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178877.mp4', 'http://gstaticontent.com/images/9e16736392a4c7cc8039c85bf6539572.jpg'),
(82854, 5741, 'Sabikui Bisco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178856.mp4', 'http://timg.bdta.pro/images/c0247c31b96df68dcd5515a380db1c09.jpg'),
(82855, 5741, 'Sabikui Bisco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178857.mp4', 'http://timg.bdta.pro/images/0d7ff8db98bc08c023f1f49435b04575.jpg'),
(82856, 5741, 'Sabikui Bisco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178858.mp4', 'http://timg.bdta.pro/images/b0a805f4c7ccbfc084f5867d4b338e44.jpg'),
(82857, 5741, 'Sabikui Bisco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178859.mp4', 'http://timg.bdta.pro/images/24f1d1f2c52352c94f7e50baa758dc1c.jpg'),
(82858, 5741, 'Sabikui Bisco S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178860.mp4', 'http://timg.bdta.pro/images/00b8c300fa2aa435533811f60df09cf3.jpg'),
(82859, 5741, 'Sabikui Bisco S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178861.mp4', 'http://timg.bdta.pro/images/ab65582cf7dd2828dc29aae848412b43.jpg'),
(82860, 5741, 'Sabikui Bisco S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178862.mp4', 'http://timg.bdta.pro/images/097c4f7e34911ba9887f80c4da145949.jpg'),
(82861, 5741, 'Sabikui Bisco S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178863.mp4', 'http://timg.bdta.pro/images/f308e29f8f6d1545f1f51e0691c6602c.jpg'),
(82862, 5741, 'Sabikui Bisco S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178864.mp4', 'http://timg.bdta.pro/images/ff441f4a30d18cc45dbf33118bca93b0.jpg'),
(82863, 5741, 'Sabikui Bisco S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178865.mp4', 'http://timg.bdta.pro/images/98098b465974aafd969c68a0dd586e94.jpg'),
(82864, 5741, 'Sabikui Bisco S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/178866.mp4', 'http://timg.bdta.pro/images/44c0fd9cc39a3fdf4088397267c92aa0.jpg'),
(82865, 5741, 'Sabikui Bisco S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/178867.mp4', 'http://timg.bdta.pro/images/a5d8811dfe855aa557cd4a0cd42d7877.jpg'),
(82866, 5742, '1883 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178846.mp4', 'http://timg.bdta.pro/images/3e6fd9217684b580efdc9b8b22f2f761.jpg'),
(82867, 5742, '1883 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178847.mp4', 'http://timg.bdta.pro/images/62dd77811fc69f3b92c5aee598ce9038.jpg'),
(82868, 5742, '1883 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178848.mp4', 'http://timg.bdta.pro/images/8b50754ea85782416de0ea04dc10086c.jpg'),
(82869, 5742, '1883 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178849.mp4', 'http://timg.bdta.pro/images/42cde72d929feb25f4ed023bb1349d95.jpg'),
(82870, 5742, '1883 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178850.mp4', 'http://timg.bdta.pro/images/c5770ca8389aba67a92e897d2cdb4206.jpg'),
(82871, 5742, '1883 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178851.mp4', 'http://timg.bdta.pro/images/c7949addcaea718be5a02099bc7bb5f9.jpg'),
(82872, 5742, '1883 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178852.mp4', 'http://timg.bdta.pro/images/c3b65ec5a5a6f58b1dffd2450ea03e63.jpg'),
(82873, 5742, '1883 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178853.mp4', 'http://timg.bdta.pro/images/24fc65ee8ccc2375e201f12dfd18dc4e.jpg'),
(82874, 5742, '1883 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178854.mp4', 'http://timg.bdta.pro/images/ebb9e25a3bf0652ca27bd8f64ff2ece0.jpg'),
(82875, 5742, '1883 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178855.mp4', 'http://timg.bdta.pro/images/b5a38bd44137cbd7800e7a482aeb77dd.jpg'),
(82876, 5743, 'A Árvore Familiar dos Croods S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251110.mp4', 'http://timg.bdta.pro/images/cbd0d77f6bea78a81f89862e8dc74935.jpg'),
(82877, 5743, 'A Árvore Familiar dos Croods S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251111.mp4', 'http://timg.bdta.pro/images/69ab65eef5ad8d0c599d5523f23b664f.jpg'),
(82878, 5743, 'A Árvore Familiar dos Croods S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251112.mp4', 'http://timg.bdta.pro/images/1c1490bab87da3b0a9558ba7c905eacf.jpg'),
(82879, 5743, 'A Árvore Familiar dos Croods S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251113.mp4', 'http://timg.bdta.pro/images/71e58e287d9a2bcdec6e8a044acb8bae.jpg'),
(82880, 5743, 'A Árvore Familiar dos Croods S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251114.mp4', 'http://timg.bdta.pro/images/e288a9f47cc81a7d8ed667651856d051.jpg'),
(82881, 5743, 'A Árvore Familiar dos Croods S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251115.mp4', 'http://timg.bdta.pro/images/78411c4886c970d90674f478824fca4e.jpg'),
(82882, 5744, 'A Árvore Familiar dos Croods S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251116.mp4', 'http://timg.bdta.pro/images/6aa983faedafd896c66b818bdb116465.jpg'),
(82883, 5744, 'A Árvore Familiar dos Croods S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251117.mp4', 'http://timg.bdta.pro/images/b81e72360ad38ee00bd859e53a52682d.jpg'),
(82884, 5744, 'A Árvore Familiar dos Croods S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251118.mp4', 'http://timg.bdta.pro/images/0a5ff1cacc2ccd19aa1432452390304e.jpg'),
(82885, 5744, 'A Árvore Familiar dos Croods S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251119.mp4', 'http://timg.bdta.pro/images/8eae5db783d2444d7d1193d6f7731d13.jpg'),
(82886, 5744, 'A Árvore Familiar dos Croods S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251120.mp4', 'http://timg.bdta.pro/images/f07467d8b21447cdaae4ba58dfbf1bf8.jpg'),
(82887, 5744, 'A Árvore Familiar dos Croods S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251121.mp4', 'http://timg.bdta.pro/images/8b1de0c8b488d783181d2203ee94975f.jpg'),
(82888, 5744, 'A Árvore Familiar dos Croods S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251122.mp4', 'http://timg.bdta.pro/images/e19904fd2131d4af7f3a3d5f1be070d6.jpg'),
(82889, 5745, 'A Árvore Familiar dos Croods S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251123.mp4', 'http://timg.bdta.pro/images/3813ddb877aa9e4aa6fb3f4b53d0a4a0.jpg'),
(82890, 5745, 'A Árvore Familiar dos Croods S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251124.mp4', 'http://timg.bdta.pro/images/e0bfb14bd20b9ba6a94e49ce07c033fc.jpg'),
(82891, 5745, 'A Árvore Familiar dos Croods S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251125.mp4', 'http://timg.bdta.pro/images/55e87e57b4356ef9ca90c5560c395354.jpg'),
(82892, 5745, 'A Árvore Familiar dos Croods S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251126.mp4', 'http://timg.bdta.pro/images/8b07af21baa8bc35e761a02fdcaf50ac.jpg'),
(82893, 5745, 'A Árvore Familiar dos Croods S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251127.mp4', 'http://timg.bdta.pro/images/f4ff12e26b05b0873da5faf67cbebbc1.jpg'),
(82894, 5745, 'A Árvore Familiar dos Croods S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251128.mp4', 'http://timg.bdta.pro/images/1cfb516df731f596055a20946b7b82f5.jpg'),
(82895, 5746, 'A Árvore Familiar dos Croods S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251129.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82896, 5746, 'A Árvore Familiar dos Croods S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251130.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82897, 5746, 'A Árvore Familiar dos Croods S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251131.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82898, 5746, 'A Árvore Familiar dos Croods S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251132.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82899, 5746, 'A Árvore Familiar dos Croods S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251133.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82900, 5746, 'A Árvore Familiar dos Croods S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251134.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82901, 5746, 'A Árvore Familiar dos Croods S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251135.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82902, 5747, 'A Árvore Familiar dos Croods S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251136.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82903, 5747, 'A Árvore Familiar dos Croods S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251137.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82904, 5747, 'A Árvore Familiar dos Croods S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251138.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82905, 5747, 'A Árvore Familiar dos Croods S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251139.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82906, 5747, 'A Árvore Familiar dos Croods S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251140.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82907, 5747, 'A Árvore Familiar dos Croods S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251141.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82908, 5748, 'A Árvore Familiar dos Croods S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251142.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82909, 5748, 'A Árvore Familiar dos Croods S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251143.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82910, 5748, 'A Árvore Familiar dos Croods S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251144.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82911, 5748, 'A Árvore Familiar dos Croods S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251145.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82912, 5748, 'A Árvore Familiar dos Croods S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251146.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82913, 5748, 'A Árvore Familiar dos Croods S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251147.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82914, 5748, 'A Árvore Familiar dos Croods S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251148.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82915, 5749, 'A Árvore Familiar dos Croods S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251149.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82916, 5749, 'A Árvore Familiar dos Croods S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251150.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82917, 5749, 'A Árvore Familiar dos Croods S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251151.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82918, 5749, 'A Árvore Familiar dos Croods S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251152.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82919, 5749, 'A Árvore Familiar dos Croods S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251153.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82920, 5749, 'A Árvore Familiar dos Croods S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251154.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82921, 5750, 'A Árvore Familiar dos Croods S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251155.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82922, 5750, 'A Árvore Familiar dos Croods S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251156.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82923, 5750, 'A Árvore Familiar dos Croods S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251157.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82924, 5750, 'A Árvore Familiar dos Croods S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251158.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82925, 5750, 'A Árvore Familiar dos Croods S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251159.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82926, 5750, 'A Árvore Familiar dos Croods S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251160.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82927, 5750, 'A Árvore Familiar dos Croods S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251161.mp4', 'http://gstaticontent.com/images/bb4b692d4f92f7ada5277773f5108650.jpg'),
(82928, 5751, 'A Escolha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178815.mp4', 'http://timg.bdta.pro/images/45491d26453ab9f2b1f7a6b6f489fa2e.jpg'),
(82929, 5751, 'A Escolha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178816.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82930, 5751, 'A Escolha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178817.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82931, 5751, 'A Escolha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178818.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82932, 5751, 'A Escolha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178819.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82933, 5751, 'A Escolha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178820.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82934, 5751, 'A Escolha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178821.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82935, 5751, 'A Escolha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178822.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82936, 5751, 'A Escolha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178823.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82937, 5751, 'A Escolha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178824.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82938, 5751, 'A Escolha S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/178825.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82939, 5751, 'A Escolha S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/178826.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82940, 5751, 'A Escolha S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/178827.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82941, 5751, 'A Escolha S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/178828.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82942, 5751, 'A Escolha S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/178829.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82943, 5751, 'A Escolha S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/178830.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82944, 5751, 'A Escolha S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/178831.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82945, 5751, 'A Escolha S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/178832.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82946, 5751, 'A Escolha S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/178833.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82947, 5751, 'A Escolha S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/178834.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82948, 5751, 'A Escolha S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/178835.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82949, 5751, 'A Escolha S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/178836.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82950, 5751, 'A Escolha S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/178837.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82951, 5751, 'A Escolha S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/178838.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82952, 5751, 'A Escolha S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/178839.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82953, 5751, 'A Escolha S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/178840.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82954, 5751, 'A Escolha S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/178841.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82955, 5751, 'A Escolha S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/178842.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82956, 5751, 'A Escolha S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/178843.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82957, 5751, 'A Escolha S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/178844.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82958, 5751, 'A Escolha S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/178845.mp4', 'http://gstaticontent.com/images/ca7c640663c39c95f1a0f695a3a77944.jpg'),
(82959, 5752, 'A Oferta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179381.mp4', 'http://timg.bdta.pro/images/676bcd6a20f16dd2baa94792c219a812.jpg'),
(82960, 5752, 'A Oferta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179382.mp4', 'http://timg.bdta.pro/images/d062b4379f7a9e95378a6408ae3332a5.jpg'),
(82961, 5752, 'A Oferta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179383.mp4', 'http://timg.bdta.pro/images/a2dce30c443eb2b5b1307a9f1e5a6b27.jpg'),
(82962, 5752, 'A Oferta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179384.mp4', 'http://timg.bdta.pro/images/6a148ea50ffb1613de5a6e60d31ad0d9.jpg'),
(82963, 5752, 'A Oferta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179385.mp4', 'http://timg.bdta.pro/images/8e820d8f3880b3e8dad8779deb97f922.jpg'),
(82964, 5752, 'A Oferta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179386.mp4', 'http://timg.bdta.pro/images/981ead84744919beda0e2eee88598c69.jpg'),
(82965, 5752, 'A Oferta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179387.mp4', 'http://timg.bdta.pro/images/305e68a9edbec7c893958a4c2342a35d.jpg'),
(82966, 5752, 'A Oferta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179388.mp4', 'http://timg.bdta.pro/images/c70544f9af92d282612fe2d6d2a70dee.jpg'),
(82967, 5752, 'A Oferta S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179389.mp4', 'http://timg.bdta.pro/images/d01e1fad0193ada4bed50f622ebf1e92.jpg'),
(82968, 5752, 'A Oferta S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179390.mp4', 'http://timg.bdta.pro/images/83cbbfaafd851497cfde1e608f2adc97.jpg'),
(82969, 5753, 'A Primeira-dama S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183871.mp4', 'http://timg.bdta.pro/images/4e83c7e9525f2148eb516ec8f592485f.jpg'),
(82970, 5753, 'A Primeira-dama S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183872.mp4', 'http://timg.bdta.pro/images/c5fa330c830141ed26ec96a2ee2f3850.jpg'),
(82971, 5753, 'A Primeira-dama S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183873.mp4', 'http://timg.bdta.pro/images/52964b208e00faf9dd8099d9f23543fc.jpg'),
(82972, 5753, 'A Primeira-dama S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183874.mp4', 'http://timg.bdta.pro/images/b4e2fb69bcd7ae06fca8a901976c6dc5.jpg'),
(82973, 5753, 'A Primeira-dama S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183875.mp4', 'http://timg.bdta.pro/images/20cea42184a5747f7924847aff9f28f0.jpg'),
(82974, 5753, 'A Primeira-dama S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183876.mp4', 'http://timg.bdta.pro/images/5cd8d8a8eb58d3014efd8668aebc4599.jpg'),
(82975, 5753, 'A Primeira-dama S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183877.mp4', 'http://timg.bdta.pro/images/cbc8e3bba83e0fe524529106726b0841.jpg'),
(82976, 5753, 'A Primeira-dama S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183878.mp4', 'http://timg.bdta.pro/images/09741a7db66684cf6629296b1dc0781f.jpg'),
(82977, 5753, 'A Primeira-dama S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183879.mp4', 'http://timg.bdta.pro/images/4f0251ed624a8db2216f4b83a3f594b0.jpg'),
(82978, 5753, 'A Primeira-dama S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183880.mp4', 'http://timg.bdta.pro/images/3783c4b8ecadf99439be9aa12bdfd83a.jpg'),
(82979, 5754, 'Agência S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178807.mp4', 'http://gstaticontent.com/images/00c303502faaa42de46746c849409902.jpg'),
(82980, 5754, 'Agência S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178808.mp4', 'http://gstaticontent.com/images/00c303502faaa42de46746c849409902.jpg'),
(82981, 5754, 'Agência S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178809.mp4', 'http://gstaticontent.com/images/00c303502faaa42de46746c849409902.jpg'),
(82982, 5754, 'Agência S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178810.mp4', 'http://gstaticontent.com/images/00c303502faaa42de46746c849409902.jpg'),
(82983, 5754, 'Agência S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178811.mp4', 'http://gstaticontent.com/images/00c303502faaa42de46746c849409902.jpg'),
(82984, 5754, 'Agência S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178812.mp4', 'http://gstaticontent.com/images/00c303502faaa42de46746c849409902.jpg'),
(82985, 5754, 'Agência S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178813.mp4', 'http://gstaticontent.com/images/00c303502faaa42de46746c849409902.jpg'),
(82986, 5754, 'Agência S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178814.mp4', 'http://gstaticontent.com/images/00c303502faaa42de46746c849409902.jpg'),
(82987, 5755, 'As 7 Vidas de Lea S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178800.mp4', 'http://gstaticontent.com/images/aa0d2d5b0483af5dc62317cde24c1f5a.jpg'),
(82988, 5755, 'As 7 Vidas de Lea S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178801.mp4', 'http://gstaticontent.com/images/aa0d2d5b0483af5dc62317cde24c1f5a.jpg'),
(82989, 5755, 'As 7 Vidas de Lea S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178802.mp4', 'http://gstaticontent.com/images/aa0d2d5b0483af5dc62317cde24c1f5a.jpg'),
(82990, 5755, 'As 7 Vidas de Lea S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178803.mp4', 'http://gstaticontent.com/images/aa0d2d5b0483af5dc62317cde24c1f5a.jpg'),
(82991, 5755, 'As 7 Vidas de Lea S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178804.mp4', 'http://gstaticontent.com/images/aa0d2d5b0483af5dc62317cde24c1f5a.jpg'),
(82992, 5755, 'As 7 Vidas de Lea S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178805.mp4', 'http://gstaticontent.com/images/aa0d2d5b0483af5dc62317cde24c1f5a.jpg'),
(82993, 5755, 'As 7 Vidas de Lea S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178806.mp4', 'http://gstaticontent.com/images/aa0d2d5b0483af5dc62317cde24c1f5a.jpg'),
(82994, 5756, 'As Crônicas de Usagi: O Coelho Samurai S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194692.mp4', 'http://timg.bdta.pro/images/dd89f66ee3153fda252e9ca760cba327.jpg'),
(82995, 5756, 'As Crônicas de Usagi: O Coelho Samurai S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194693.mp4', 'http://timg.bdta.pro/images/ce58ae4ac6bf6184cfaedc95049bfeed.jpg'),
(82996, 5756, 'As Crônicas de Usagi: O Coelho Samurai S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194694.mp4', 'http://timg.bdta.pro/images/13755a0d97f9acc1e4d53e1157169130.jpg'),
(82997, 5756, 'As Crônicas de Usagi: O Coelho Samurai S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194695.mp4', 'http://timg.bdta.pro/images/c91c7418bf1b6fe8ac199cba7c98c4ce.jpg'),
(82998, 5756, 'As Crônicas de Usagi: O Coelho Samurai S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194696.mp4', 'http://timg.bdta.pro/images/2b57ad59f8728a5a45aa87a63236fc1a.jpg'),
(82999, 5756, 'As Crônicas de Usagi: O Coelho Samurai S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194697.mp4', 'http://timg.bdta.pro/images/70e334fd00d77033e433551283d61b4b.jpg'),
(83000, 5756, 'As Crônicas de Usagi: O Coelho Samurai S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194698.mp4', 'http://timg.bdta.pro/images/9b6af16f0eda9dba036f379627890da9.jpg'),
(83001, 5756, 'As Crônicas de Usagi: O Coelho Samurai S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194699.mp4', 'http://timg.bdta.pro/images/83da0b1a133824136fef1038cac9d1b7.jpg'),
(83002, 5756, 'As Crônicas de Usagi: O Coelho Samurai S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194700.mp4', 'http://timg.bdta.pro/images/710ea977d0ce6c6ad8b28fe0738d8bf4.jpg'),
(83003, 5756, 'As Crônicas de Usagi: O Coelho Samurai S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194701.mp4', 'http://timg.bdta.pro/images/158f2d73712bb3ef64b8b83fc22c2446.jpg'),
(83004, 5757, 'As Crônicas de Usagi: O Coelho Samurai S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194702.mp4', 'http://timg.bdta.pro/images/b729561d2af716c7695431e1b056892d.jpg'),
(83005, 5757, 'As Crônicas de Usagi: O Coelho Samurai S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194703.mp4', 'http://timg.bdta.pro/images/380981cf306af0b35d3e638004c7d309.jpg'),
(83006, 5757, 'As Crônicas de Usagi: O Coelho Samurai S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194704.mp4', 'http://timg.bdta.pro/images/8c53a982c7039dc71cbe05f8ef85236f.jpg'),
(83007, 5757, 'As Crônicas de Usagi: O Coelho Samurai S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194705.mp4', 'http://timg.bdta.pro/images/6824af645167ef497b621ac87a019aef.jpg'),
(83008, 5757, 'As Crônicas de Usagi: O Coelho Samurai S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194706.mp4', 'http://timg.bdta.pro/images/347a748a76da11f4b68fb3334c082ee7.jpg'),
(83009, 5757, 'As Crônicas de Usagi: O Coelho Samurai S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194707.mp4', 'http://timg.bdta.pro/images/a855b2d8f3107bffb0a33450c90c4dec.jpg'),
(83010, 5757, 'As Crônicas de Usagi: O Coelho Samurai S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194708.mp4', 'http://timg.bdta.pro/images/63f3f4564b8fe94c3a19c632d98b59fe.jpg'),
(83011, 5757, 'As Crônicas de Usagi: O Coelho Samurai S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194709.mp4', 'http://timg.bdta.pro/images/57e0e0bff54aeb9a829e0a291e2988cc.jpg'),
(83012, 5757, 'As Crônicas de Usagi: O Coelho Samurai S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194710.mp4', 'http://timg.bdta.pro/images/dcc300c4d2a9497501ad12b1f3ac25c4.jpg'),
(83013, 5757, 'As Crônicas de Usagi: O Coelho Samurai S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194711.mp4', 'http://timg.bdta.pro/images/57f3a3d5fa902c61d58b228782c1b281.jpg'),
(83014, 5758, 'Birdgirl S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178794.mp4', 'http://timg.bdta.pro/images/ec5051ed8f11b73558368463f0950f7b.jpg'),
(83015, 5758, 'Birdgirl S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178795.mp4', 'http://timg.bdta.pro/images/a815f77782c35b5d2dcae3df252f3b22.jpg'),
(83016, 5758, 'Birdgirl S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178796.mp4', 'http://timg.bdta.pro/images/66bc4fd5fc789f8e873533c0d26f6695.jpg'),
(83017, 5758, 'Birdgirl S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178797.mp4', 'http://timg.bdta.pro/images/b5404ca6a48ac3f85f58bba1283a605c.jpg'),
(83018, 5758, 'Birdgirl S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178798.mp4', 'http://timg.bdta.pro/images/68ed25285aa503ee7367d6fa60a3129d.jpg'),
(83019, 5758, 'Birdgirl S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178799.mp4', 'http://timg.bdta.pro/images/b7053b7765195cdf7d1dc610e41d7bca.jpg'),
(83020, 5759, 'Birdgirl S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/761170.mp4', 'http://gstaticontent.com/images/08e8c311a2f3deb46ae9afce45dc688e.jpg'),
(83021, 5759, 'Birdgirl S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/761171.mp4', 'http://gstaticontent.com/images/08e8c311a2f3deb46ae9afce45dc688e.jpg'),
(83022, 5759, 'Birdgirl S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/761172.mp4', 'http://gstaticontent.com/images/08e8c311a2f3deb46ae9afce45dc688e.jpg'),
(83023, 5759, 'Birdgirl S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/761173.mp4', 'http://gstaticontent.com/images/08e8c311a2f3deb46ae9afce45dc688e.jpg'),
(83024, 5759, 'Birdgirl S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/761174.mp4', 'http://gstaticontent.com/images/08e8c311a2f3deb46ae9afce45dc688e.jpg'),
(83025, 5759, 'Birdgirl S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/761175.mp4', 'http://gstaticontent.com/images/08e8c311a2f3deb46ae9afce45dc688e.jpg'),
(83026, 5760, 'Breathe: Pelas Sombras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178782.mp4', 'http://timg.bdta.pro/images/02d7ffd7a09a4450f96c2ad3874adaf9.jpg'),
(83027, 5760, 'Breathe: Pelas Sombras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178783.mp4', 'http://timg.bdta.pro/images/0037408e6d3077a14650eadd5c457a96.jpg'),
(83028, 5760, 'Breathe: Pelas Sombras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178784.mp4', 'http://timg.bdta.pro/images/3ea32d25c51eee7cf773355bb3de6cee.jpg'),
(83029, 5760, 'Breathe: Pelas Sombras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178785.mp4', 'http://timg.bdta.pro/images/d4aa50d108c43cff84dc35fb009d9084.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(83030, 5760, 'Breathe: Pelas Sombras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178786.mp4', 'http://timg.bdta.pro/images/11b60cd04507ae3e04de3b240f171193.jpg'),
(83031, 5760, 'Breathe: Pelas Sombras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178787.mp4', 'http://timg.bdta.pro/images/4b8c03f40f00c58caed2251f42c74b4b.jpg'),
(83032, 5760, 'Breathe: Pelas Sombras S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178788.mp4', 'http://timg.bdta.pro/images/b7eae7d8fa785fe40e4d9ef6d13c1577.jpg'),
(83033, 5760, 'Breathe: Pelas Sombras S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178789.mp4', 'http://timg.bdta.pro/images/c2817bb6dbdbb9a8a48d7ae3662b03f8.jpg'),
(83034, 5760, 'Breathe: Pelas Sombras S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178790.mp4', 'http://timg.bdta.pro/images/90ef47da90b90a949c63d969cdfb5fde.jpg'),
(83035, 5760, 'Breathe: Pelas Sombras S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178791.mp4', 'http://timg.bdta.pro/images/36e8b6bf4eef60930f1c415e656fa9ab.jpg'),
(83036, 5760, 'Breathe: Pelas Sombras S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/178792.mp4', 'http://timg.bdta.pro/images/c212949e66f17897d8b3235f34b678a3.jpg'),
(83037, 5760, 'Breathe: Pelas Sombras S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/178793.mp4', 'http://timg.bdta.pro/images/c7680fef4fc7da1ef3c760c042f285ad.jpg'),
(83038, 5761, 'Breathe: Pelas Sombras S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/448357.mp4', 'http://gstaticontent.com/images/6f5f3566b98a7eb565a6e8f0442cdf74.jpg'),
(83039, 5761, 'Breathe: Pelas Sombras S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/448358.mp4', 'http://gstaticontent.com/images/6f5f3566b98a7eb565a6e8f0442cdf74.jpg'),
(83040, 5761, 'Breathe: Pelas Sombras S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/448359.mp4', 'http://gstaticontent.com/images/6f5f3566b98a7eb565a6e8f0442cdf74.jpg'),
(83041, 5761, 'Breathe: Pelas Sombras S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/448360.mp4', 'http://gstaticontent.com/images/6f5f3566b98a7eb565a6e8f0442cdf74.jpg'),
(83042, 5761, 'Breathe: Pelas Sombras S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/448361.mp4', 'http://gstaticontent.com/images/6f5f3566b98a7eb565a6e8f0442cdf74.jpg'),
(83043, 5761, 'Breathe: Pelas Sombras S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/448362.mp4', 'http://gstaticontent.com/images/6f5f3566b98a7eb565a6e8f0442cdf74.jpg'),
(83044, 5761, 'Breathe: Pelas Sombras S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/448363.mp4', 'http://gstaticontent.com/images/6f5f3566b98a7eb565a6e8f0442cdf74.jpg'),
(83045, 5761, 'Breathe: Pelas Sombras S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/448364.mp4', 'http://gstaticontent.com/images/6f5f3566b98a7eb565a6e8f0442cdf74.jpg'),
(83046, 5762, 'Buscando a Frida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181554.mp4', 'http://timg.bdta.pro/images/7bca2e2408de61d66f1c4321e26ae770.jpg'),
(83047, 5762, 'Buscando a Frida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181555.mp4', 'http://timg.bdta.pro/images/0fceaac8f2783287f6de98159f58bafe.jpg'),
(83048, 5762, 'Buscando a Frida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181556.mp4', 'http://timg.bdta.pro/images/5400ed2238ce9c5ce16f413c6a7c617b.jpg'),
(83049, 5762, 'Buscando a Frida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181557.mp4', 'http://timg.bdta.pro/images/e235e3e1ed0c16c92cc9c50b8b295553.jpg'),
(83050, 5762, 'Buscando a Frida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181558.mp4', 'http://timg.bdta.pro/images/67b7ea212e86270d4fc854a06af46b96.jpg'),
(83051, 5762, 'Buscando a Frida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181559.mp4', 'http://timg.bdta.pro/images/4ca7f4513b8222bed08db8a0ee1462c4.jpg'),
(83052, 5762, 'Buscando a Frida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181560.mp4', 'http://timg.bdta.pro/images/a88ff6bb79ee5bfb3b32e1141116ee7b.jpg'),
(83053, 5762, 'Buscando a Frida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181561.mp4', 'http://timg.bdta.pro/images/cdbfd35c863bb46f1f4dec751eabfb71.jpg'),
(83054, 5762, 'Buscando a Frida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181562.mp4', 'http://timg.bdta.pro/images/0c61c2f3aee9eeb858d92988d13cee8c.jpg'),
(83055, 5762, 'Buscando a Frida S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181563.mp4', 'http://timg.bdta.pro/images/55d1d7941635143186ca1bf9d67780b0.jpg'),
(83056, 5762, 'Buscando a Frida S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/181564.mp4', 'http://timg.bdta.pro/images/382a9700d44760b298bd44a65adee66f.jpg'),
(83057, 5762, 'Buscando a Frida S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/181565.mp4', 'http://timg.bdta.pro/images/af188c496eedd9affc893a46c7494ca0.jpg'),
(83058, 5762, 'Buscando a Frida S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/181566.mp4', 'http://timg.bdta.pro/images/030a4045c7bab948af8743dedd984cea.jpg'),
(83059, 5762, 'Buscando a Frida S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/181567.mp4', 'http://timg.bdta.pro/images/21cb01f5bcd3936db147cd0ca7591a9c.jpg'),
(83060, 5762, 'Buscando a Frida S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/181568.mp4', 'http://timg.bdta.pro/images/aae0e42bc515374a8d2e79c6caa039db.jpg'),
(83061, 5762, 'Buscando a Frida S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/181569.mp4', 'http://timg.bdta.pro/images/fa37e25473593b78cb253826377edcd9.jpg'),
(83062, 5762, 'Buscando a Frida S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/181570.mp4', 'http://timg.bdta.pro/images/4a5613d3128e9456c348b2872a224183.jpg'),
(83063, 5762, 'Buscando a Frida S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/181571.mp4', 'http://timg.bdta.pro/images/d4d1f9a2caa7c6b0fd247783c47bc46e.jpg'),
(83064, 5762, 'Buscando a Frida S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/181572.mp4', 'http://timg.bdta.pro/images/f00ff676666dc7cce0ec6e8586bf068e.jpg'),
(83065, 5762, 'Buscando a Frida S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/181573.mp4', 'http://timg.bdta.pro/images/e03f966251a1e5953b0d871b39e2ea7b.jpg'),
(83066, 5762, 'Buscando a Frida S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/181574.mp4', 'http://timg.bdta.pro/images/a9a36ef3142b5fd3b2fa28c8bdff508f.jpg'),
(83067, 5762, 'Buscando a Frida S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/181575.mp4', 'http://timg.bdta.pro/images/cc57682d687b18f13002a7a23d95f6d2.jpg'),
(83068, 5762, 'Buscando a Frida S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/181576.mp4', 'http://timg.bdta.pro/images/07d66b1db871355bd8f8c9d5c44b5abe.jpg'),
(83069, 5762, 'Buscando a Frida S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/181577.mp4', 'http://timg.bdta.pro/images/93e6d4cc001e6fc2b2204c8b9235539c.jpg'),
(83070, 5762, 'Buscando a Frida S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/181578.mp4', 'http://timg.bdta.pro/images/285fc1bd6eacaca5b28bb25b1908d817.jpg'),
(83071, 5762, 'Buscando a Frida S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/181579.mp4', 'http://timg.bdta.pro/images/c9f0d3c908f8c734123c283b967236ad.jpg'),
(83072, 5762, 'Buscando a Frida S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/181580.mp4', 'http://timg.bdta.pro/images/c288108beffdb43886f2022ace8a1751.jpg'),
(83073, 5762, 'Buscando a Frida S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/181581.mp4', 'http://timg.bdta.pro/images/05ce1264fc7a777c24a4a955521ef756.jpg'),
(83074, 5762, 'Buscando a Frida S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/181582.mp4', 'http://timg.bdta.pro/images/fc3b5b94bc9c8837c5bb7334fbbe5b57.jpg'),
(83075, 5762, 'Buscando a Frida S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/181583.mp4', 'http://timg.bdta.pro/images/6fc7fbf95192d0b66538970b77b63293.jpg'),
(83076, 5762, 'Buscando a Frida S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/181584.mp4', 'http://timg.bdta.pro/images/7ed11f092bd34d00fc7641d6f90e8c6b.jpg'),
(83077, 5762, 'Buscando a Frida S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/181585.mp4', 'http://timg.bdta.pro/images/c69ad42ecdf8afee40f95bd1ca40b68b.jpg'),
(83078, 5762, 'Buscando a Frida S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/181586.mp4', 'http://timg.bdta.pro/images/23a2c970c489492a6937ee706dc1efd1.jpg'),
(83079, 5762, 'Buscando a Frida S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/181587.mp4', 'http://timg.bdta.pro/images/cbfe437a5b2d3afe5eb7e195ea42f8f5.jpg'),
(83080, 5762, 'Buscando a Frida S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/181588.mp4', 'http://timg.bdta.pro/images/6f98e88fd89ec8ae568f7dcb4a1ae44c.jpg'),
(83081, 5762, 'Buscando a Frida S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/181589.mp4', 'http://timg.bdta.pro/images/677942178ee61608c0ef58efed40cea9.jpg'),
(83082, 5762, 'Buscando a Frida S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/181590.mp4', 'http://timg.bdta.pro/images/29325e02ad2efefbdd06c1f72fc36ba5.jpg'),
(83083, 5762, 'Buscando a Frida S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/181591.mp4', 'http://timg.bdta.pro/images/119bee3242f2d0b028edf681909a611d.jpg'),
(83084, 5762, 'Buscando a Frida S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/181592.mp4', 'http://timg.bdta.pro/images/64cefad18510b5f6cdee851fc0adc1df.jpg'),
(83085, 5762, 'Buscando a Frida S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/181593.mp4', 'http://timg.bdta.pro/images/a4cc46d975b9b4eaffe2429bc73da17d.jpg'),
(83086, 5762, 'Buscando a Frida S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/181594.mp4', 'http://timg.bdta.pro/images/62f338f97ffe90882384ffc0ad0ca55b.jpg'),
(83087, 5762, 'Buscando a Frida S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/181595.mp4', 'http://timg.bdta.pro/images/5b2e4f94222de2e55bc2c10304d8c537.jpg'),
(83088, 5762, 'Buscando a Frida S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/181596.mp4', 'http://timg.bdta.pro/images/4427b6c3543f4f3f770d61b57103593f.jpg'),
(83089, 5762, 'Buscando a Frida S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/181597.mp4', 'http://timg.bdta.pro/images/88eede92ad173d790b46e1e150a30eb4.jpg'),
(83090, 5762, 'Buscando a Frida S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/181598.mp4', 'http://timg.bdta.pro/images/314daccd4585edd9f05d260405f58109.jpg'),
(83091, 5762, 'Buscando a Frida S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/181599.mp4', 'http://timg.bdta.pro/images/e156944ac148014418415fdd23c801dd.jpg'),
(83092, 5762, 'Buscando a Frida S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/181600.mp4', 'http://timg.bdta.pro/images/48190e3b86e0ede58564b6419bdffd81.jpg'),
(83093, 5762, 'Buscando a Frida S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/181601.mp4', 'http://timg.bdta.pro/images/e76bd61ba17279eb1d631eacf9d61fe7.jpg'),
(83094, 5762, 'Buscando a Frida S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/181602.mp4', 'http://timg.bdta.pro/images/6ab034d87b61410783a754ef5846f6ab.jpg'),
(83095, 5762, 'Buscando a Frida S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/181603.mp4', 'http://timg.bdta.pro/images/f005352f48483b010ac0ae0e51f9f98b.jpg'),
(83096, 5762, 'Buscando a Frida S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/181604.mp4', 'http://timg.bdta.pro/images/7177a8279b234b1711a21a83f8aee657.jpg'),
(83097, 5762, 'Buscando a Frida S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/181605.mp4', 'http://timg.bdta.pro/images/0fa896915b33cec32848f72e8a8b8d01.jpg'),
(83098, 5762, 'Buscando a Frida S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/181606.mp4', 'http://timg.bdta.pro/images/6fc641ab63b51ee971cb6ff08f0d4eb9.jpg'),
(83099, 5762, 'Buscando a Frida S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/181607.mp4', 'http://timg.bdta.pro/images/855ce8953f366dc668fb1c67b1abf6b4.jpg'),
(83100, 5762, 'Buscando a Frida S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/181608.mp4', 'http://timg.bdta.pro/images/dade7293f410c84e324de89f4f6419ef.jpg'),
(83101, 5762, 'Buscando a Frida S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/181609.mp4', 'http://timg.bdta.pro/images/2d1694217aaea20a159f8dfafde3526b.jpg'),
(83102, 5762, 'Buscando a Frida S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/181610.mp4', 'http://timg.bdta.pro/images/a952638648a035838ce6e1d3e4d98f03.jpg'),
(83103, 5762, 'Buscando a Frida S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/181611.mp4', 'http://timg.bdta.pro/images/d3463653ce1847de4d1e8967c5342270.jpg'),
(83104, 5762, 'Buscando a Frida S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/181612.mp4', 'http://timg.bdta.pro/images/f0dff24b04ac31d709c28a3da4dcd3f0.jpg'),
(83105, 5762, 'Buscando a Frida S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/181613.mp4', 'http://timg.bdta.pro/images/d3ce7bfc5e74ae9308774abe75d0146f.jpg'),
(83106, 5762, 'Buscando a Frida S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/181614.mp4', 'http://timg.bdta.pro/images/7302ee9be054f0a97e4d94e3964bbda7.jpg'),
(83107, 5762, 'Buscando a Frida S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/181615.mp4', 'http://timg.bdta.pro/images/2065a8983f6f3f9a770e3c285c050fc1.jpg'),
(83108, 5762, 'Buscando a Frida S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/181616.mp4', 'http://timg.bdta.pro/images/fb0a0d9572d3cef4e1d80f414e019943.jpg'),
(83109, 5762, 'Buscando a Frida S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/181617.mp4', 'http://timg.bdta.pro/images/af77b84d59bde8f4e79e1aff4985e3c3.jpg'),
(83110, 5762, 'Buscando a Frida S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/181618.mp4', 'http://timg.bdta.pro/images/1f2c2132d5c9d769d22845b3f4255763.jpg'),
(83111, 5762, 'Buscando a Frida S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/181619.mp4', 'http://timg.bdta.pro/images/c68055fe4b03f54458f6ab8a88ff538e.jpg'),
(83112, 5762, 'Buscando a Frida S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/181620.mp4', 'http://timg.bdta.pro/images/e7042ae4694cb1f7895d8b48047e068a.jpg'),
(83113, 5762, 'Buscando a Frida S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/181621.mp4', 'http://timg.bdta.pro/images/86e9eb083fa0e567544b17009f79aebd.jpg'),
(83114, 5762, 'Buscando a Frida S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/181622.mp4', 'http://timg.bdta.pro/images/8be219dc5171c517ccf79dd13864f323.jpg'),
(83115, 5762, 'Buscando a Frida S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/181623.mp4', 'http://timg.bdta.pro/images/4398d258098a72994af998b50975acc4.jpg'),
(83116, 5762, 'Buscando a Frida S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/181624.mp4', 'http://timg.bdta.pro/images/0c87d412151d7602961ca1aa7b426c73.jpg'),
(83117, 5762, 'Buscando a Frida S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/181625.mp4', 'http://timg.bdta.pro/images/fae92fb6d2636459089022fbc0ee0fba.jpg'),
(83118, 5762, 'Buscando a Frida S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/181626.mp4', 'http://timg.bdta.pro/images/f24c3c11086e4764933a94b0ea1fb99c.jpg'),
(83119, 5762, 'Buscando a Frida S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/181627.mp4', 'http://timg.bdta.pro/images/9e37eb5b6f5614c8de0da776c82156ed.jpg'),
(83120, 5762, 'Buscando a Frida S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/181628.mp4', 'http://timg.bdta.pro/images/f39b50927f5851815c6a25c2e7036a35.jpg'),
(83121, 5762, 'Buscando a Frida S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/181629.mp4', 'http://timg.bdta.pro/images/9ccbb8bbc48af1497337cc37775343cc.jpg'),
(83122, 5762, 'Buscando a Frida S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/181630.mp4', 'http://timg.bdta.pro/images/77a7d990bd1eb3af3c0ad90c69c7075e.jpg'),
(83123, 5762, 'Buscando a Frida S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/181631.mp4', 'http://timg.bdta.pro/images/a9187db8535c4551d42f274b64127335.jpg'),
(83124, 5762, 'Buscando a Frida S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/181632.mp4', 'http://timg.bdta.pro/images/6bd1d6176bb13154f1f38587ce996012.jpg'),
(83125, 5762, 'Buscando a Frida S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/181633.mp4', 'http://timg.bdta.pro/images/6824a9a2c4f462557da28622057ac4c2.jpg'),
(83126, 5762, 'Buscando a Frida S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/181634.mp4', 'http://timg.bdta.pro/images/f4551cf7baea79d41b5badf6633cbfea.jpg'),
(83127, 5762, 'Buscando a Frida S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/181635.mp4', 'http://timg.bdta.pro/images/25ad6b5d860aabd2fe09732e1013d7d7.jpg'),
(83128, 5762, 'Buscando a Frida S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/181636.mp4', 'http://timg.bdta.pro/images/54e4f52cff919971be056ab6739c66c4.jpg'),
(83129, 5762, 'Buscando a Frida S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/181637.mp4', 'http://timg.bdta.pro/images/b897a9b4f898daa5036dbc705351cb63.jpg'),
(83130, 5763, 'Confissões de Mulheres de 50 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178772.mp4', 'http://gstaticontent.com/images/1b896a37e04652c83cec2c22b4bf5cce.jpg'),
(83131, 5763, 'Confissões de Mulheres de 50 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178773.mp4', 'http://gstaticontent.com/images/1b896a37e04652c83cec2c22b4bf5cce.jpg'),
(83132, 5763, 'Confissões de Mulheres de 50 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178774.mp4', 'http://gstaticontent.com/images/1b896a37e04652c83cec2c22b4bf5cce.jpg'),
(83133, 5763, 'Confissões de Mulheres de 50 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178775.mp4', 'http://gstaticontent.com/images/1b896a37e04652c83cec2c22b4bf5cce.jpg'),
(83134, 5763, 'Confissões de Mulheres de 50 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178776.mp4', 'http://gstaticontent.com/images/1b896a37e04652c83cec2c22b4bf5cce.jpg'),
(83135, 5763, 'Confissões de Mulheres de 50 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178777.mp4', 'http://gstaticontent.com/images/1b896a37e04652c83cec2c22b4bf5cce.jpg'),
(83136, 5763, 'Confissões de Mulheres de 50 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178778.mp4', 'http://gstaticontent.com/images/1b896a37e04652c83cec2c22b4bf5cce.jpg'),
(83137, 5763, 'Confissões de Mulheres de 50 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178779.mp4', 'http://gstaticontent.com/images/1b896a37e04652c83cec2c22b4bf5cce.jpg'),
(83138, 5763, 'Confissões de Mulheres de 50 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178780.mp4', 'http://gstaticontent.com/images/1b896a37e04652c83cec2c22b4bf5cce.jpg'),
(83139, 5763, 'Confissões de Mulheres de 50 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178781.mp4', 'http://gstaticontent.com/images/1b896a37e04652c83cec2c22b4bf5cce.jpg'),
(83140, 5764, 'Do Esboço à Realidade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178766.mp4', 'http://timg.bdta.pro/images/4c026396fc967a86184f94346170df04.jpg'),
(83141, 5764, 'Do Esboço à Realidade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178767.mp4', 'http://timg.bdta.pro/images/a23d945f976e75a38c0ae58dab21b7a2.jpg'),
(83142, 5764, 'Do Esboço à Realidade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178768.mp4', 'http://timg.bdta.pro/images/4323fca74710ba874b56cb4d5170a44c.jpg'),
(83143, 5764, 'Do Esboço à Realidade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178769.mp4', 'http://timg.bdta.pro/images/ed20a4ee12fac6bda1915017a6fbd35d.jpg'),
(83144, 5764, 'Do Esboço à Realidade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178770.mp4', 'http://timg.bdta.pro/images/7206e0309a01ada226ebabfc9c3bc2cc.jpg'),
(83145, 5764, 'Do Esboço à Realidade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178771.mp4', 'http://timg.bdta.pro/images/2496cbc8c967dd5ed63f8e428421e6c8.jpg'),
(83146, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178740.mp4', 'http://timg.bdta.pro/images/6655ad6b85c335a53e73063c09a30ce1.jpg'),
(83147, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178741.mp4', 'http://timg.bdta.pro/images/f95bcce7ca9084bb61fb7f2244c51211.jpg'),
(83148, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178742.mp4', 'http://timg.bdta.pro/images/5d6e70fb719aca3770264b367e5f5919.jpg'),
(83149, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178743.mp4', 'http://timg.bdta.pro/images/4936b26fb8064d1669c7f171a6b6b258.jpg'),
(83150, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178744.mp4', 'http://timg.bdta.pro/images/ed31d6fee4bf8627751b103f7d54622d.jpg'),
(83151, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178745.mp4', 'http://timg.bdta.pro/images/a3811f2b6ff8426d9654e8cac9839f97.jpg'),
(83152, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178746.mp4', 'http://timg.bdta.pro/images/b14f587fcf11e330952eb3ea605fdf3b.jpg'),
(83153, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178747.mp4', 'http://timg.bdta.pro/images/9a6dfc9daf9895bdc1d9310a63ce3bed.jpg'),
(83154, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178748.mp4', 'http://timg.bdta.pro/images/7a56d9618553cc14f16e11b7413f15a5.jpg'),
(83155, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178749.mp4', 'http://timg.bdta.pro/images/ed3823f4e8e6f62858204b4f2ed00a87.jpg'),
(83156, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/178750.mp4', 'http://timg.bdta.pro/images/43ecb68a45131215f43e1799c5cee8ab.jpg'),
(83157, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/178751.mp4', 'http://timg.bdta.pro/images/f369ac4727db53ce753d6b081ae31fc9.jpg'),
(83158, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/178752.mp4', 'http://timg.bdta.pro/images/3f9115f3236b58ccbf0afc5f154cfb6a.jpg'),
(83159, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/178753.mp4', 'http://timg.bdta.pro/images/5afb64d70a0f00a95e01baf4c3e297d4.jpg'),
(83160, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/178754.mp4', 'http://timg.bdta.pro/images/66556970fde7e4b2dbb85742e8f3fda5.jpg'),
(83161, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/178755.mp4', 'http://timg.bdta.pro/images/8438f9a9e86e77438ab70b1669616aaa.jpg'),
(83162, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/178756.mp4', 'http://timg.bdta.pro/images/5146217fb9d07414401725c8a63e1585.jpg'),
(83163, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/178757.mp4', 'http://timg.bdta.pro/images/0f63f51580903732b847d6c9ae3ce88a.jpg'),
(83164, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/178758.mp4', 'http://timg.bdta.pro/images/cf58d643962dfc61f13a3e919f84e300.jpg'),
(83165, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/178759.mp4', 'http://timg.bdta.pro/images/0e6fa57455d4368f62f9fdb43eb46bff.jpg'),
(83166, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/178760.mp4', 'http://timg.bdta.pro/images/5c28f67dc937c0282e7e4879d120b960.jpg'),
(83167, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/178761.mp4', 'http://timg.bdta.pro/images/5a9287ccb7f65fe04ec95a68583e1d8a.jpg'),
(83168, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/178762.mp4', 'http://timg.bdta.pro/images/d61ecdd644cf5eb81eb1a84eaa570e88.jpg'),
(83169, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/178763.mp4', 'http://timg.bdta.pro/images/ab4f23780e5490dbd3a34b25af46c7c0.jpg'),
(83170, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/178764.mp4', 'http://timg.bdta.pro/images/4243affabecffa1fb989c27b376b07f3.jpg'),
(83171, 5765, 'Genjitsu Shugi Yuusha no Oukoku Saikenki S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/178765.mp4', 'http://timg.bdta.pro/images/74ec63017a1406117bede7ab86678f03.jpg'),
(83172, 5766, 'Iluminadas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179843.mp4', 'http://timg.bdta.pro/images/42f1ce6426486b718a07047d24ec6b43.jpg'),
(83173, 5766, 'Iluminadas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179844.mp4', 'http://timg.bdta.pro/images/30053b6bd202839b352e293a320d6768.jpg'),
(83174, 5766, 'Iluminadas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179845.mp4', 'http://timg.bdta.pro/images/b88e85839c84418384f9a7eca3975659.jpg'),
(83175, 5766, 'Iluminadas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179846.mp4', 'http://timg.bdta.pro/images/2a17344c33e4033d87cd9f9b163af90a.jpg'),
(83176, 5766, 'Iluminadas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179847.mp4', 'http://timg.bdta.pro/images/d4b8f2f93a2217c1ed286d728feaa661.jpg'),
(83177, 5766, 'Iluminadas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179848.mp4', 'http://timg.bdta.pro/images/bfa63cf4e1d231053b1ec03f54e5b399.jpg'),
(83178, 5766, 'Iluminadas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179849.mp4', 'http://timg.bdta.pro/images/02f0bbb69d105677b66bed462434e47c.jpg'),
(83179, 5766, 'Iluminadas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179850.mp4', 'http://timg.bdta.pro/images/2d9bd1d75356cbdf56c02c13ac6f6f3d.jpg'),
(83180, 5767, 'O Blefe de 1 Milhão! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178730.mp4', 'http://gstaticontent.com/images/da92dce2c3d480ffa8cbc3118e9666e9.jpg'),
(83181, 5767, 'O Blefe de 1 Milhão! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178731.mp4', 'http://gstaticontent.com/images/da92dce2c3d480ffa8cbc3118e9666e9.jpg'),
(83182, 5767, 'O Blefe de 1 Milhão! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178732.mp4', 'http://gstaticontent.com/images/da92dce2c3d480ffa8cbc3118e9666e9.jpg'),
(83183, 5767, 'O Blefe de 1 Milhão! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178733.mp4', 'http://gstaticontent.com/images/da92dce2c3d480ffa8cbc3118e9666e9.jpg'),
(83184, 5767, 'O Blefe de 1 Milhão! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178734.mp4', 'http://gstaticontent.com/images/da92dce2c3d480ffa8cbc3118e9666e9.jpg'),
(83185, 5767, 'O Blefe de 1 Milhão! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178735.mp4', 'http://gstaticontent.com/images/da92dce2c3d480ffa8cbc3118e9666e9.jpg'),
(83186, 5767, 'O Blefe de 1 Milhão! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178736.mp4', 'http://gstaticontent.com/images/da92dce2c3d480ffa8cbc3118e9666e9.jpg'),
(83187, 5767, 'O Blefe de 1 Milhão! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178737.mp4', 'http://gstaticontent.com/images/da92dce2c3d480ffa8cbc3118e9666e9.jpg'),
(83188, 5767, 'O Blefe de 1 Milhão! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178738.mp4', 'http://gstaticontent.com/images/da92dce2c3d480ffa8cbc3118e9666e9.jpg'),
(83189, 5767, 'O Blefe de 1 Milhão! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178739.mp4', 'http://gstaticontent.com/images/da92dce2c3d480ffa8cbc3118e9666e9.jpg'),
(83190, 5768, 'Phoenix Rising: Renascendo das Cinzas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178728.mp4', 'http://gstaticontent.com/images/226fe5311a7c8a2e7f1048d8af513f5d.jpg'),
(83191, 5768, 'Phoenix Rising: Renascendo das Cinzas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178729.mp4', 'http://gstaticontent.com/images/226fe5311a7c8a2e7f1048d8af513f5d.jpg'),
(83192, 5769, 'Tensai Ouji no Akaji Kokka Saisei Jutsu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178716.mp4', 'http://timg.bdta.pro/images/3644ce5459291cbe2b57fa7156bcdee4.jpg'),
(83193, 5769, 'Tensai Ouji no Akaji Kokka Saisei Jutsu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178717.mp4', 'http://timg.bdta.pro/images/3ade11e83a0bc08874a86d3c0334bca7.jpg'),
(83194, 5769, 'Tensai Ouji no Akaji Kokka Saisei Jutsu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178718.mp4', 'http://timg.bdta.pro/images/2afb3f6cd8c8b623352ad0eec26b692c.jpg'),
(83195, 5769, 'Tensai Ouji no Akaji Kokka Saisei Jutsu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178719.mp4', 'http://timg.bdta.pro/images/9b1a93667e69a7168fde74c6fc4f4c10.jpg'),
(83196, 5769, 'Tensai Ouji no Akaji Kokka Saisei Jutsu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178720.mp4', 'http://timg.bdta.pro/images/77a4d1b7cb3dc38b35ec0adf946a3d58.jpg'),
(83197, 5769, 'Tensai Ouji no Akaji Kokka Saisei Jutsu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178721.mp4', 'http://timg.bdta.pro/images/653cf89e482a5c617daef7a563390197.jpg'),
(83198, 5769, 'Tensai Ouji no Akaji Kokka Saisei Jutsu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178722.mp4', 'http://timg.bdta.pro/images/20822527fd08defeaedc1d89a0ae5e5c.jpg'),
(83199, 5769, 'Tensai Ouji no Akaji Kokka Saisei Jutsu S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178723.mp4', 'http://timg.bdta.pro/images/99cf5aaf190ba1b7e9e951e8e48ddb17.jpg'),
(83200, 5769, 'Tensai Ouji no Akaji Kokka Saisei Jutsu S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178724.mp4', 'http://timg.bdta.pro/images/7a6eebdc8178a5d57848b7d45d59536a.jpg'),
(83201, 5769, 'Tensai Ouji no Akaji Kokka Saisei Jutsu S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178725.mp4', 'http://timg.bdta.pro/images/03e47ddad20fa289ea3a50ad69da08a5.jpg'),
(83202, 5769, 'Tensai Ouji no Akaji Kokka Saisei Jutsu S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/178726.mp4', 'http://timg.bdta.pro/images/e00c3e404ace6c1f703af241ff8fa76f.jpg'),
(83203, 5769, 'Tensai Ouji no Akaji Kokka Saisei Jutsu S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/178727.mp4', 'http://timg.bdta.pro/images/e1c5aafc19e10536870abfc04ee2d2d4.jpg'),
(83204, 5770, 'Vamos Tchecar! [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178708.mp4', 'http://timg.bdta.pro/images/fbae75d73c6245b9f9a9915e144ee664.jpg'),
(83205, 5770, 'Vamos Tchecar! [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178709.mp4', 'http://timg.bdta.pro/images/c5a9b1ceadbf75a550a2c75d9ed3fd37.jpg'),
(83206, 5770, 'Vamos Tchecar! [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178710.mp4', 'http://gstaticontent.com/images/0b1656c1442c8019d85070bd9517fd30.jpg'),
(83207, 5770, 'Vamos Tchecar! [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178711.mp4', 'http://gstaticontent.com/images/0b1656c1442c8019d85070bd9517fd30.jpg'),
(83208, 5770, 'Vamos Tchecar! [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178712.mp4', 'http://gstaticontent.com/images/0b1656c1442c8019d85070bd9517fd30.jpg'),
(83209, 5770, 'Vamos Tchecar! [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178713.mp4', 'http://gstaticontent.com/images/0b1656c1442c8019d85070bd9517fd30.jpg'),
(83210, 5770, 'Vamos Tchecar! [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178714.mp4', 'http://gstaticontent.com/images/0b1656c1442c8019d85070bd9517fd30.jpg'),
(83211, 5770, 'Vamos Tchecar! [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178715.mp4', 'http://gstaticontent.com/images/0b1656c1442c8019d85070bd9517fd30.jpg'),
(83212, 5771, 'Bem-vindos ao Éden S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211879.mp4', 'http://timg.bdta.pro/images/e6b9cf5e6680636ad9ada24f6c8531c7.jpg'),
(83213, 5771, 'Bem-vindos ao Éden S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211880.mp4', 'http://timg.bdta.pro/images/d3f6d8ce0b79ebd86af8882893c39f59.jpg'),
(83214, 5771, 'Bem-vindos ao Éden S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211881.mp4', 'http://timg.bdta.pro/images/7e9c977849f24a58d8b8dd6c4ef79c5f.jpg'),
(83215, 5771, 'Bem-vindos ao Éden S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211882.mp4', 'http://timg.bdta.pro/images/e446f0323f31a27c4a8cbe6da661818c.jpg'),
(83216, 5771, 'Bem-vindos ao Éden S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211883.mp4', 'http://timg.bdta.pro/images/2ea2c8f78a7833247f8230102786ce52.jpg'),
(83217, 5771, 'Bem-vindos ao Éden S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211884.mp4', 'http://timg.bdta.pro/images/8b464511d6999587d1d4932b21705f01.jpg'),
(83218, 5771, 'Bem-vindos ao Éden S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211885.mp4', 'http://timg.bdta.pro/images/8835422b4ad985c03ab7d95ee9ad895f.jpg'),
(83219, 5771, 'Bem-vindos ao Éden S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211886.mp4', 'http://timg.bdta.pro/images/a99687000efffcee603af02d58ffffb0.jpg'),
(83220, 5772, 'Bem-vindos ao Éden S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8AH4AX2fm3zeN4ZWHhuJ9eq4mt5.jpg'),
(83221, 5772, 'Bem-vindos ao Éden S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qWnYCi1yIz0iBoQQxEQ0M5BwvWg.jpg'),
(83222, 5772, 'Bem-vindos ao Éden S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yLe1fje62UIlIsI3NFclH8Qc4o3.jpg'),
(83223, 5772, 'Bem-vindos ao Éden S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/osTBTXlnn9aSwWmm4FuLc3G8PvQ.jpg'),
(83224, 5772, 'Bem-vindos ao Éden S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iZBkgdTeqSyG34rGSEGzPqeuBEP.jpg'),
(83225, 5772, 'Bem-vindos ao Éden S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wwaNfOcyYqKmUq0G1l6DByKLvEp.jpg'),
(83226, 5772, 'Bem-vindos ao Éden S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oM9n87Mga4FktI2o8GWYJ2KKR5Z.jpg'),
(83227, 5772, 'Bem-vindos ao Éden S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sItjK6qM77zxRdoib3su8cXcUbi.jpg'),
(83228, 5773, 'Clark S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178594.mp4', 'http://timg.bdta.pro/images/2140937f2eca3ef0de2c190c0881e5f5.jpg'),
(83229, 5773, 'Clark S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178595.mp4', 'http://timg.bdta.pro/images/d20c334bcd8929d5c81ccf3e03cb7418.jpg'),
(83230, 5773, 'Clark S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178596.mp4', 'http://timg.bdta.pro/images/d9afe865f3bb02bba6ba39908ae14ec6.jpg'),
(83231, 5773, 'Clark S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178597.mp4', 'http://timg.bdta.pro/images/8bb0dee82152659f42c561d781d5f270.jpg'),
(83232, 5773, 'Clark S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178598.mp4', 'http://timg.bdta.pro/images/6a0e44ab2dba319cc12f4e2258d8285d.jpg'),
(83233, 5773, 'Clark S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178599.mp4', 'http://timg.bdta.pro/images/d00abb0af8939c60ef4c330a09070763.jpg'),
(83234, 5774, 'Julia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251422.mp4', 'http://timg.bdta.pro/images/c1cf2784bea2792fb242b1a00061126b.jpg'),
(83235, 5774, 'Julia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251423.mp4', 'http://timg.bdta.pro/images/2c35345975626442549f767983546b31.jpg'),
(83236, 5774, 'Julia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251424.mp4', 'http://timg.bdta.pro/images/f4124e3163826a35c7ada63293979199.jpg'),
(83237, 5774, 'Julia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251425.mp4', 'http://timg.bdta.pro/images/30c79c1055cc8b320541a911a006fda4.jpg'),
(83238, 5774, 'Julia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251426.mp4', 'http://timg.bdta.pro/images/f0b95f67eaac528f2d0e6b3bf2491ee4.jpg'),
(83239, 5774, 'Julia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251427.mp4', 'http://timg.bdta.pro/images/a357d21e4965fa0a4c0c25c096c025f8.jpg'),
(83240, 5774, 'Julia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251428.mp4', 'http://timg.bdta.pro/images/c20876614a4557f987fe81dd1b24d855.jpg'),
(83241, 5774, 'Julia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251429.mp4', 'http://timg.bdta.pro/images/34de5ee67d7d2aad33c077a25f0925d8.jpg'),
(83242, 5775, 'Julia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251430.mp4', 'http://gstaticontent.com/images/7c3ce5d014c55423e82463bfc618566d.jpg'),
(83243, 5775, 'Julia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251431.mp4', 'http://gstaticontent.com/images/7c3ce5d014c55423e82463bfc618566d.jpg'),
(83244, 5775, 'Julia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251432.mp4', 'http://gstaticontent.com/images/7c3ce5d014c55423e82463bfc618566d.jpg'),
(83245, 5775, 'Julia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251433.mp4', 'http://gstaticontent.com/images/7c3ce5d014c55423e82463bfc618566d.jpg'),
(83246, 5775, 'Julia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251434.mp4', 'http://gstaticontent.com/images/7c3ce5d014c55423e82463bfc618566d.jpg'),
(83247, 5775, 'Julia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251435.mp4', 'http://gstaticontent.com/images/7c3ce5d014c55423e82463bfc618566d.jpg'),
(83248, 5775, 'Julia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251436.mp4', 'http://gstaticontent.com/images/7c3ce5d014c55423e82463bfc618566d.jpg'),
(83249, 5775, 'Julia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251437.mp4', 'http://gstaticontent.com/images/7c3ce5d014c55423e82463bfc618566d.jpg'),
(83250, 5776, 'Lei da Selva - A História do Jogo do Bicho S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178590.mp4', 'http://gstaticontent.com/images/5792f15d202a3c953fdb9d7074e51b67.jpg'),
(83251, 5776, 'Lei da Selva - A História do Jogo do Bicho S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178591.mp4', 'http://gstaticontent.com/images/5792f15d202a3c953fdb9d7074e51b67.jpg'),
(83252, 5776, 'Lei da Selva - A História do Jogo do Bicho S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178592.mp4', 'http://gstaticontent.com/images/5792f15d202a3c953fdb9d7074e51b67.jpg'),
(83253, 5776, 'Lei da Selva - A História do Jogo do Bicho S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178593.mp4', 'http://gstaticontent.com/images/5792f15d202a3c953fdb9d7074e51b67.jpg'),
(83254, 5777, 'O Som da Magia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178584.mp4', 'http://timg.bdta.pro/images/c737aecfd45547253490596270d04f9a.jpg'),
(83255, 5777, 'O Som da Magia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178585.mp4', 'http://timg.bdta.pro/images/69a95164b0bd553855729a03165953f8.jpg'),
(83256, 5777, 'O Som da Magia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178586.mp4', 'http://timg.bdta.pro/images/19b7dda43a9ebee20bb579db57ebee84.jpg'),
(83257, 5777, 'O Som da Magia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178587.mp4', 'http://timg.bdta.pro/images/2d10d03c9178866285f6cd9d448535e7.jpg'),
(83258, 5777, 'O Som da Magia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178588.mp4', 'http://timg.bdta.pro/images/ae3383a7749171f75f5eb21bf9b05e92.jpg'),
(83259, 5777, 'O Som da Magia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178589.mp4', 'http://timg.bdta.pro/images/7cc8cbcd2062eefce7011a000e59065d.jpg'),
(83260, 5778, 'Queens S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178571.mp4', 'http://timg.bdta.pro/images/a468bad2d42b5003a424303d8753ed18.jpg'),
(83261, 5778, 'Queens S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178572.mp4', 'http://timg.bdta.pro/images/667abbf66041022ba5f12673a9168eb8.jpg'),
(83262, 5778, 'Queens S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178573.mp4', 'http://timg.bdta.pro/images/7d49f54601554365c73155c0fb096426.jpg'),
(83263, 5778, 'Queens S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178574.mp4', 'http://timg.bdta.pro/images/008ef267a6eac4d01eddd2f22fc13232.jpg'),
(83264, 5778, 'Queens S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178575.mp4', 'http://timg.bdta.pro/images/8a05997d297c4578642509bfa3eda528.jpg'),
(83265, 5778, 'Queens S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178576.mp4', 'http://timg.bdta.pro/images/23d9e7de97e9e5cca1926d8e079d26ce.jpg'),
(83266, 5778, 'Queens S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178577.mp4', 'http://timg.bdta.pro/images/ab4346b4f29d3539b373b824c75d99bd.jpg'),
(83267, 5778, 'Queens S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178578.mp4', 'http://timg.bdta.pro/images/7e48adc0c2aad8a135346f5dd92ccda6.jpg'),
(83268, 5778, 'Queens S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178579.mp4', 'http://gstaticontent.com/images/981c7784159f726a130d00316ab8e1d9.jpg'),
(83269, 5778, 'Queens S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178580.mp4', 'http://gstaticontent.com/images/981c7784159f726a130d00316ab8e1d9.jpg'),
(83270, 5778, 'Queens S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/178581.mp4', 'http://gstaticontent.com/images/981c7784159f726a130d00316ab8e1d9.jpg'),
(83271, 5778, 'Queens S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/178582.mp4', 'http://gstaticontent.com/images/981c7784159f726a130d00316ab8e1d9.jpg'),
(83272, 5778, 'Queens S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/178583.mp4', 'http://gstaticontent.com/images/981c7784159f726a130d00316ab8e1d9.jpg'),
(83273, 5779, 'Reação Nuclear S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178567.mp4', 'http://gstaticontent.com/images/1dc85e7029b6ab5e77c6ac9ec07d39ca.jpg'),
(83274, 5779, 'Reação Nuclear S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178568.mp4', 'http://gstaticontent.com/images/1dc85e7029b6ab5e77c6ac9ec07d39ca.jpg'),
(83275, 5779, 'Reação Nuclear S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178569.mp4', 'http://gstaticontent.com/images/1dc85e7029b6ab5e77c6ac9ec07d39ca.jpg'),
(83276, 5779, 'Reação Nuclear S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178570.mp4', 'http://gstaticontent.com/images/1dc85e7029b6ab5e77c6ac9ec07d39ca.jpg'),
(83277, 5780, 'Red Election S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178557.mp4', 'http://timg.bdta.pro/images/a9dbe93a18d910df96aed8c7d9eadba9.jpg'),
(83278, 5780, 'Red Election S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178558.mp4', 'http://timg.bdta.pro/images/439cf165ce2e0b95db27acd207ba1e1d.jpg'),
(83279, 5780, 'Red Election S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178559.mp4', 'http://timg.bdta.pro/images/fad9856d8a21eac461a2dbe3df428627.jpg'),
(83280, 5780, 'Red Election S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178560.mp4', 'http://timg.bdta.pro/images/87c4513e30c9a87e951159f1a8772a64.jpg'),
(83281, 5780, 'Red Election S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178561.mp4', 'http://timg.bdta.pro/images/763c513962006430aed72c50f2a0ac93.jpg'),
(83282, 5780, 'Red Election S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178562.mp4', 'http://timg.bdta.pro/images/cb08cd44843c4f670bcbf050dff96c20.jpg'),
(83283, 5780, 'Red Election S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178563.mp4', 'http://timg.bdta.pro/images/9c37d0e8798407cca6e164571456b51e.jpg'),
(83284, 5780, 'Red Election S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178564.mp4', 'http://timg.bdta.pro/images/c4fec729ad13880beb53c75b2fbf27a9.jpg'),
(83285, 5780, 'Red Election S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178565.mp4', 'http://timg.bdta.pro/images/b240598cfc64607f106778306c51c025.jpg'),
(83286, 5780, 'Red Election S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178566.mp4', 'http://timg.bdta.pro/images/97d4861bb9cf93fc137c757cdb4c0cf4.jpg'),
(83287, 5781, 'The Game S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207073.mp4', 'http://timg.bdta.pro/images/c217f7a70aa943d223cd4f52131bf92c.jpg'),
(83288, 5781, 'The Game S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207074.mp4', 'http://timg.bdta.pro/images/c322af31d57a1a722fafb8e5aa8ea911.jpg'),
(83289, 5781, 'The Game S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207075.mp4', 'http://timg.bdta.pro/images/c5d74555e55d3f0e81966adecd042967.jpg'),
(83290, 5781, 'The Game S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207076.mp4', 'http://timg.bdta.pro/images/9917e9e6c7c3ae31c929f4f570bec365.jpg'),
(83291, 5781, 'The Game S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207077.mp4', 'http://timg.bdta.pro/images/9cfc1617866cd5228a87a34b26ed25f0.jpg'),
(83292, 5781, 'The Game S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207078.mp4', 'http://timg.bdta.pro/images/138dba461d7cca040e65cb7b0b3ab56a.jpg'),
(83293, 5781, 'The Game S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207079.mp4', 'http://timg.bdta.pro/images/40af501fc01c95d63ee33f578a286141.jpg'),
(83294, 5781, 'The Game S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207080.mp4', 'http://timg.bdta.pro/images/c41bb7f4c9b0b1774014c0aee8f3c601.jpg'),
(83295, 5781, 'The Game S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207081.mp4', 'http://timg.bdta.pro/images/90a25f87487ceff4ced9920b913e0ab6.jpg'),
(83296, 5781, 'The Game S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207082.mp4', 'http://gstaticontent.com/images/ffc69d2bbabe2c458dd8ab36bb30daab.jpg'),
(83297, 5782, 'The Game S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207083.mp4', 'http://image.tmdb.org/t/p/w1280/r14Sm7fyShWkAdYsClC0nUGZ8xF.jpg'),
(83298, 5782, 'The Game S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m9aTiRS7Z78JkNoDaaX9oLeVzJP.jpg'),
(83299, 5782, 'The Game S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qImdzREnp0gh2gaDKcESI6sthec.jpg'),
(83300, 5782, 'The Game S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207086.mp4', 'http://gstaticontent.com/images/ffc69d2bbabe2c458dd8ab36bb30daab.jpg'),
(83301, 5782, 'The Game S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207087.mp4', 'http://image.tmdb.org/t/p/w1280/tzHTW5tNlgumSly6tBIeeg8MhUo.jpg'),
(83302, 5782, 'The Game S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207088.mp4', 'http://image.tmdb.org/t/p/w1280/sDS5rbq9IPT2rQ33SCbJ1PJhRzp.jpg'),
(83303, 5782, 'The Game S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207089.mp4', 'http://image.tmdb.org/t/p/w1280/yexJXFFvN8RBrSgi5DdzackNevC.jpg'),
(83304, 5782, 'The Game S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207090.mp4', 'http://image.tmdb.org/t/p/w1280/sAbmx3imuC7MtJmxceYGr8VRhie.jpg'),
(83305, 5782, 'The Game S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207091.mp4', 'http://gstaticontent.com/images/ffc69d2bbabe2c458dd8ab36bb30daab.jpg'),
(83306, 5782, 'The Game S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207092.mp4', 'http://gstaticontent.com/images/ffc69d2bbabe2c458dd8ab36bb30daab.jpg'),
(83307, 5783, 'Trinta e Nove S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178545.mp4', 'http://timg.bdta.pro/images/2bca8b1fa3c0f4ddf44194a2d4ee8770.jpg'),
(83308, 5783, 'Trinta e Nove S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178546.mp4', 'http://timg.bdta.pro/images/ad5b79d1063b4a36ddf91cd3a5995146.jpg'),
(83309, 5783, 'Trinta e Nove S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178547.mp4', 'http://timg.bdta.pro/images/bdf04196485f0ac2eebf5cc37213818a.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(83310, 5783, 'Trinta e Nove S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178548.mp4', 'http://timg.bdta.pro/images/df444f1c50785736fa0414a233501e87.jpg'),
(83311, 5783, 'Trinta e Nove S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178549.mp4', 'http://timg.bdta.pro/images/585043fd844241fa74596692fbe1f13d.jpg'),
(83312, 5783, 'Trinta e Nove S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178550.mp4', 'http://timg.bdta.pro/images/e7ff34c69e95ff72e09b7ea17d00ea9f.jpg'),
(83313, 5783, 'Trinta e Nove S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178551.mp4', 'http://timg.bdta.pro/images/205d5de3e72766f07b9f0fc66e2cb31c.jpg'),
(83314, 5783, 'Trinta e Nove S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178552.mp4', 'http://timg.bdta.pro/images/11e40d079ca63e531860368e7a3eeca0.jpg'),
(83315, 5783, 'Trinta e Nove S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178553.mp4', 'http://timg.bdta.pro/images/43df1bfcf552fa912898e99a4fe002a2.jpg'),
(83316, 5783, 'Trinta e Nove S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178554.mp4', 'http://timg.bdta.pro/images/b5793e5e266b8d4f0f806dfc7a268639.jpg'),
(83317, 5783, 'Trinta e Nove S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/178555.mp4', 'http://timg.bdta.pro/images/23dc0685742e415984c7ed72c3587fd8.jpg'),
(83318, 5783, 'Trinta e Nove S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/178556.mp4', 'http://timg.bdta.pro/images/4676cd20d54c299647b4c87a77e08fa5.jpg'),
(83319, 5784, 'União de Sangue S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178541.mp4', 'http://timg.bdta.pro/images/c175582afbc9882fa4d63be4d7229cb9.jpg'),
(83320, 5784, 'União de Sangue S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178542.mp4', 'http://timg.bdta.pro/images/58ae42869413810aa1d29f0c54623981.jpg'),
(83321, 5784, 'União de Sangue S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178543.mp4', 'http://timg.bdta.pro/images/2363d56c390c1567534a8bf5d5ca0e44.jpg'),
(83322, 5784, 'União de Sangue S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178544.mp4', 'http://timg.bdta.pro/images/5f2d19163e191caaf3dd8e4f4f3e4562.jpg'),
(83323, 5785, '42 Dias de Escuridão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178535.mp4', 'http://timg.bdta.pro/images/501702244b53f80aad6fbd309ac03ad6.jpg'),
(83324, 5785, '42 Dias de Escuridão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178536.mp4', 'http://timg.bdta.pro/images/40c7d785143c7847ad6b548c10f80c5f.jpg'),
(83325, 5785, '42 Dias de Escuridão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178537.mp4', 'http://timg.bdta.pro/images/3fd8d340086daa5c11df654453d9bc43.jpg'),
(83326, 5785, '42 Dias de Escuridão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178538.mp4', 'http://timg.bdta.pro/images/8bd66450b16d0d957b52af71c1eb15d9.jpg'),
(83327, 5785, '42 Dias de Escuridão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178539.mp4', 'http://timg.bdta.pro/images/aff067413ce5ffbd75b0e2d3896cf5ae.jpg'),
(83328, 5785, '42 Dias de Escuridão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178540.mp4', 'http://timg.bdta.pro/images/7cd8f6c0287fbcc4eb9a57ac6c8361a2.jpg'),
(83329, 5786, 'A Caçadora de Pedófilos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178529.mp4', 'http://timg.bdta.pro/images/3de5c6ca332de7d70acb9419ee2af6bf.jpg'),
(83330, 5786, 'A Caçadora de Pedófilos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178530.mp4', 'http://timg.bdta.pro/images/6d6d830e750070dbde488349f6c5f7fb.jpg'),
(83331, 5786, 'A Caçadora de Pedófilos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178531.mp4', 'http://timg.bdta.pro/images/1ac6726d2b4f994412908e82bc90f401.jpg'),
(83332, 5786, 'A Caçadora de Pedófilos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178532.mp4', 'http://timg.bdta.pro/images/5933c657e3c35e1c059fb2b7cd895699.jpg'),
(83333, 5786, 'A Caçadora de Pedófilos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178533.mp4', 'http://timg.bdta.pro/images/5b8ee79724ffcfa2480eb3432db345ea.jpg'),
(83334, 5786, 'A Caçadora de Pedófilos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178534.mp4', 'http://timg.bdta.pro/images/d7d7eaefbd71a55209ea0f2bb808f531.jpg'),
(83335, 5787, 'A Escada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179592.mp4', 'http://timg.bdta.pro/images/bfcdbf9935bab9e22d60e95c4c23d6aa.jpg'),
(83336, 5787, 'A Escada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179593.mp4', 'http://timg.bdta.pro/images/930062be42892b334b88d07ccb2a9fe1.jpg'),
(83337, 5787, 'A Escada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179594.mp4', 'http://timg.bdta.pro/images/062a8df55b0ffb5589fead3bd4edda96.jpg'),
(83338, 5787, 'A Escada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179595.mp4', 'http://timg.bdta.pro/images/cf44ec0d4b647367c230ad6db24d0a9b.jpg'),
(83339, 5787, 'A Escada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179596.mp4', 'http://timg.bdta.pro/images/5f2edeffc67107a7b607e0dfc9008431.jpg'),
(83340, 5787, 'A Escada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179597.mp4', 'http://timg.bdta.pro/images/3d14d6d33f3d8c437eab35635aa4c4e1.jpg'),
(83341, 5787, 'A Escada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179598.mp4', 'http://timg.bdta.pro/images/08862aeb84c4cfeddde37d092498abe7.jpg'),
(83342, 5787, 'A Escada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179599.mp4', 'http://timg.bdta.pro/images/e8759ca558d7e3ebd55d0a65f5369db6.jpg'),
(83343, 5788, 'A Serpente do Essex S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179586.mp4', 'http://timg.bdta.pro/images/c42c4778a44ee990876063dd253a27bf.jpg'),
(83344, 5788, 'A Serpente do Essex S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179587.mp4', 'http://timg.bdta.pro/images/2693958f7ae0e0a3ba977a26e718b1d9.jpg'),
(83345, 5788, 'A Serpente do Essex S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179588.mp4', 'http://timg.bdta.pro/images/e0b730f584c930781d574b06f5acb929.jpg'),
(83346, 5788, 'A Serpente do Essex S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179589.mp4', 'http://timg.bdta.pro/images/b9c5323c67debb0eb2261f8484b26af2.jpg'),
(83347, 5788, 'A Serpente do Essex S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179590.mp4', 'http://timg.bdta.pro/images/85774c81d418cbc4e8c24a6dba7fd05b.jpg'),
(83348, 5788, 'A Serpente do Essex S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179591.mp4', 'http://timg.bdta.pro/images/f5b0fb25f5051ca987edbafe607fc025.jpg'),
(83349, 5789, 'Beleza Impiedosa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178523.mp4', 'http://timg.bdta.pro/images/7c125b8010a10bd4d71a01704e686750.jpg'),
(83350, 5789, 'Beleza Impiedosa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178524.mp4', 'http://timg.bdta.pro/images/7bdaf35ff5eef5389284c6c3f7b1e0a2.jpg'),
(83351, 5789, 'Beleza Impiedosa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178525.mp4', 'http://timg.bdta.pro/images/a867a057f42058813de2375fd41f9e10.jpg'),
(83352, 5789, 'Beleza Impiedosa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178526.mp4', 'http://timg.bdta.pro/images/fd827dfc350d1eb44898c50ebcf55e26.jpg'),
(83353, 5789, 'Beleza Impiedosa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178527.mp4', 'http://timg.bdta.pro/images/2484b2ea5e0142f3c12f3501c140fbd6.jpg'),
(83354, 5789, 'Beleza Impiedosa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178528.mp4', 'http://timg.bdta.pro/images/4589f02bb1a27129941e24a7f97b646e.jpg'),
(83355, 5790, 'Beleza Impiedosa S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/398015.mp4', 'http://gstaticontent.com/images/5a840fdc9fe9e84a8e605a43af1c3ace.jpg'),
(83356, 5790, 'Beleza Impiedosa S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/398016.mp4', 'http://gstaticontent.com/images/5a840fdc9fe9e84a8e605a43af1c3ace.jpg'),
(83357, 5790, 'Beleza Impiedosa S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/398017.mp4', 'http://gstaticontent.com/images/5a840fdc9fe9e84a8e605a43af1c3ace.jpg'),
(83358, 5790, 'Beleza Impiedosa S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/398018.mp4', 'http://gstaticontent.com/images/5a840fdc9fe9e84a8e605a43af1c3ace.jpg'),
(83359, 5790, 'Beleza Impiedosa S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/398019.mp4', 'http://gstaticontent.com/images/5a840fdc9fe9e84a8e605a43af1c3ace.jpg'),
(83360, 5790, 'Beleza Impiedosa S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/398020.mp4', 'http://gstaticontent.com/images/5a840fdc9fe9e84a8e605a43af1c3ace.jpg'),
(83361, 5791, 'Clima do Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178507.mp4', 'http://timg.bdta.pro/images/23ec428f10aa90b275f9283cf8f2c717.jpg'),
(83362, 5791, 'Clima do Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178508.mp4', 'http://timg.bdta.pro/images/ba5fc9128eb21b3e6ddf165b3f13c628.jpg'),
(83363, 5791, 'Clima do Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178509.mp4', 'http://timg.bdta.pro/images/6130e01ac6816f33fe67c4e97a2cc93b.jpg'),
(83364, 5791, 'Clima do Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178510.mp4', 'http://timg.bdta.pro/images/2aa8e2fdc975d8f78fc6cd18bf9849c1.jpg'),
(83365, 5791, 'Clima do Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178511.mp4', 'http://timg.bdta.pro/images/23cc6ade2424e6d03db6450d431d2800.jpg'),
(83366, 5791, 'Clima do Amor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178512.mp4', 'http://timg.bdta.pro/images/fdac29d2fee5475c96b6397dcdf4ad68.jpg'),
(83367, 5791, 'Clima do Amor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178513.mp4', 'http://timg.bdta.pro/images/91f49681e7bec14fd0739a6734b73239.jpg'),
(83368, 5791, 'Clima do Amor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178514.mp4', 'http://timg.bdta.pro/images/278d10d76028e2be0335c21905430dfe.jpg'),
(83369, 5791, 'Clima do Amor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/178515.mp4', 'http://timg.bdta.pro/images/029792056113a6535de1f48ea58af49a.jpg'),
(83370, 5791, 'Clima do Amor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/178516.mp4', 'http://timg.bdta.pro/images/614a31da05cf816f4536997b659a7467.jpg'),
(83371, 5791, 'Clima do Amor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/178517.mp4', 'http://timg.bdta.pro/images/5066bd2d707ea3c332b827a1d0c83551.jpg'),
(83372, 5791, 'Clima do Amor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/178518.mp4', 'http://timg.bdta.pro/images/fa7c67b03a5af29834af97ba7753b678.jpg'),
(83373, 5791, 'Clima do Amor S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/178519.mp4', 'http://timg.bdta.pro/images/3bc49b6cb7506d4c7a7182bc8dd6295e.jpg'),
(83374, 5791, 'Clima do Amor S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/178520.mp4', 'http://timg.bdta.pro/images/9c183b38c88624aea2b12f280404b8b9.jpg'),
(83375, 5791, 'Clima do Amor S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/178521.mp4', 'http://timg.bdta.pro/images/ee616dd61071cf0256e6c330f45f8a39.jpg'),
(83376, 5791, 'Clima do Amor S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/178522.mp4', 'http://timg.bdta.pro/images/23b04933119ae9fcd40a9b5f975a7f51.jpg'),
(83377, 5792, 'De Volta à Terra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/178499.mp4', 'http://timg.bdta.pro/images/855e8aad367fdb00b006ca59dee1e0d2.jpg'),
(83378, 5792, 'De Volta à Terra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/178500.mp4', 'http://timg.bdta.pro/images/f6b5fa94fa73069a2b281f96cc3683d1.jpg'),
(83379, 5792, 'De Volta à Terra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/178501.mp4', 'http://timg.bdta.pro/images/06b7b11e6317575e4bf70d5a4932fd90.jpg'),
(83380, 5792, 'De Volta à Terra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/178502.mp4', 'http://timg.bdta.pro/images/d8bb6f8da383f958c146f37956206da4.jpg'),
(83381, 5792, 'De Volta à Terra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/178503.mp4', 'http://timg.bdta.pro/images/d6d9df14a2e8adc87bd63d1cbe11ca6f.jpg'),
(83382, 5792, 'De Volta à Terra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/178504.mp4', 'http://timg.bdta.pro/images/2f7ba6c21d65142241d06e5ea50c9599.jpg'),
(83383, 5792, 'De Volta à Terra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/178505.mp4', 'http://timg.bdta.pro/images/d64a133a232f29a3e326bc7c1f524d32.jpg'),
(83384, 5792, 'De Volta à Terra S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/178506.mp4', 'http://timg.bdta.pro/images/f8a9d0af24e18e18decbbb5a845b1a3e.jpg'),
(83385, 5793, 'Ershan Kuneri Um Produtor Atrevido S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181790.mp4', 'http://timg.bdta.pro/images/3005e15e55fce98b1db33f659b081dc3.jpg'),
(83386, 5793, 'Ershan Kuneri Um Produtor Atrevido S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181791.mp4', 'http://timg.bdta.pro/images/c0ddd62b231e4997616a61e9f8727fb1.jpg'),
(83387, 5793, 'Ershan Kuneri Um Produtor Atrevido S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181792.mp4', 'http://timg.bdta.pro/images/10f9fd5befc908ee8c6de065c9be9d40.jpg'),
(83388, 5793, 'Ershan Kuneri Um Produtor Atrevido S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181793.mp4', 'http://timg.bdta.pro/images/4762b6154127c594c024427563e18376.jpg'),
(83389, 5793, 'Ershan Kuneri Um Produtor Atrevido S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181794.mp4', 'http://timg.bdta.pro/images/bbf84bb042a4e1c032aaae2c07631d3e.jpg'),
(83390, 5793, 'Ershan Kuneri Um Produtor Atrevido S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181795.mp4', 'http://timg.bdta.pro/images/a3fc60925ba88d1c3da5d14072eabb7a.jpg'),
(83391, 5793, 'Ershan Kuneri Um Produtor Atrevido S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181796.mp4', 'http://timg.bdta.pro/images/8a4410b6fa608bfcafefa6388b92cc54.jpg'),
(83392, 5793, 'Ershan Kuneri Um Produtor Atrevido S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181797.mp4', 'http://timg.bdta.pro/images/026f4485217eb565d0564a4adedc28f8.jpg'),
(83393, 5794, 'Ershan Kuneri Um Produtor Atrevido S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/478349.mp4', 'http://gstaticontent.com/images/99e0d7c58656e10562926abb969453f2.jpg'),
(83394, 5794, 'Ershan Kuneri Um Produtor Atrevido S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/478350.mp4', 'http://gstaticontent.com/images/99e0d7c58656e10562926abb969453f2.jpg'),
(83395, 5794, 'Ershan Kuneri Um Produtor Atrevido S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/478351.mp4', 'http://gstaticontent.com/images/99e0d7c58656e10562926abb969453f2.jpg'),
(83396, 5794, 'Ershan Kuneri Um Produtor Atrevido S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/478352.mp4', 'http://gstaticontent.com/images/99e0d7c58656e10562926abb969453f2.jpg'),
(83397, 5794, 'Ershan Kuneri Um Produtor Atrevido S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/478353.mp4', 'http://gstaticontent.com/images/99e0d7c58656e10562926abb969453f2.jpg'),
(83398, 5794, 'Ershan Kuneri Um Produtor Atrevido S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/478354.mp4', 'http://gstaticontent.com/images/99e0d7c58656e10562926abb969453f2.jpg'),
(83399, 5794, 'Ershan Kuneri Um Produtor Atrevido S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/478355.mp4', 'http://gstaticontent.com/images/99e0d7c58656e10562926abb969453f2.jpg'),
(83400, 5794, 'Ershan Kuneri Um Produtor Atrevido S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/478356.mp4', 'http://gstaticontent.com/images/99e0d7c58656e10562926abb969453f2.jpg'),
(83401, 5795, 'Justiça por Malik Oussekine S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181786.mp4', 'http://timg.bdta.pro/images/4ed4c4f5449c8a0760dd41c6dc6d3fa0.jpg'),
(83402, 5795, 'Justiça por Malik Oussekine S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181787.mp4', 'http://timg.bdta.pro/images/803d3297777d14fc64b4f5419f04d996.jpg'),
(83403, 5795, 'Justiça por Malik Oussekine S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181788.mp4', 'http://timg.bdta.pro/images/b8013a3b0a17a75dff93bb9f084d9ef0.jpg'),
(83404, 5795, 'Justiça por Malik Oussekine S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181789.mp4', 'http://timg.bdta.pro/images/29424a9dd79a61ce3326a44c0543d23c.jpg'),
(83405, 5796, 'Leadale no Daichi nite S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181774.mp4', 'http://timg.bdta.pro/images/55ab6a5f0206ad57d6a4095f78a915be.jpg'),
(83406, 5796, 'Leadale no Daichi nite S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181775.mp4', 'http://timg.bdta.pro/images/13423d38a5d99b136b0a1ba1d210726c.jpg'),
(83407, 5796, 'Leadale no Daichi nite S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181776.mp4', 'http://timg.bdta.pro/images/28201a257396cc9459e5e9dd1c6f2d6e.jpg'),
(83408, 5796, 'Leadale no Daichi nite S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181777.mp4', 'http://timg.bdta.pro/images/a599adde04db169c4a8d6be6f7d6323c.jpg'),
(83409, 5796, 'Leadale no Daichi nite S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181778.mp4', 'http://timg.bdta.pro/images/fe1c361197f762902a36fd82c53a042f.jpg'),
(83410, 5796, 'Leadale no Daichi nite S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181779.mp4', 'http://timg.bdta.pro/images/2864617e15427e87318c1a00ff01bb3e.jpg'),
(83411, 5796, 'Leadale no Daichi nite S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181780.mp4', 'http://timg.bdta.pro/images/6c7b152cc32a7b7a074d738c3b2d0178.jpg'),
(83412, 5796, 'Leadale no Daichi nite S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181781.mp4', 'http://timg.bdta.pro/images/11ae94a16f8f6739ea00d04a3bf5adca.jpg'),
(83413, 5796, 'Leadale no Daichi nite S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181782.mp4', 'http://timg.bdta.pro/images/0a8c64d422070fa07148156c5daacacc.jpg'),
(83414, 5796, 'Leadale no Daichi nite S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181783.mp4', 'http://timg.bdta.pro/images/89b4068c90bb28b3ef9580945f6db594.jpg'),
(83415, 5796, 'Leadale no Daichi nite S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/181784.mp4', 'http://timg.bdta.pro/images/17f2b74896d9d2823bc3dc232ca949b4.jpg'),
(83416, 5796, 'Leadale no Daichi nite S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/181785.mp4', 'http://timg.bdta.pro/images/bae678c18c9a3360899d885a294c3f13.jpg'),
(83417, 5797, 'Magia Record: Mahou Shoujo Madoka☆Magica Gaiden S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181761.mp4', 'http://timg.bdta.pro/images/3e20de51bb54790a98837299df46f6ec.jpg'),
(83418, 5797, 'Magia Record: Mahou Shoujo Madoka☆Magica Gaiden S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181762.mp4', 'http://timg.bdta.pro/images/7c4f43fa572525b2aae0cedb3f06c9bd.jpg'),
(83419, 5797, 'Magia Record: Mahou Shoujo Madoka☆Magica Gaiden S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181763.mp4', 'http://timg.bdta.pro/images/6b68c66550266e3b710be0f4ec60d6d2.jpg'),
(83420, 5797, 'Magia Record: Mahou Shoujo Madoka☆Magica Gaiden S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181764.mp4', 'http://timg.bdta.pro/images/17ba2f4dd649fdceba6b2fb7c09c3b31.jpg'),
(83421, 5797, 'Magia Record: Mahou Shoujo Madoka☆Magica Gaiden S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181765.mp4', 'http://timg.bdta.pro/images/ed97bfeb33ea82e10ab6b97a08417a95.jpg'),
(83422, 5797, 'Magia Record: Mahou Shoujo Madoka☆Magica Gaiden S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181766.mp4', 'http://timg.bdta.pro/images/b6ae0394a3803b1d03cf5844430ed8fe.jpg'),
(83423, 5797, 'Magia Record: Mahou Shoujo Madoka☆Magica Gaiden S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181767.mp4', 'http://timg.bdta.pro/images/eea39404df246b1ecfa0df61ab20897f.jpg'),
(83424, 5797, 'Magia Record: Mahou Shoujo Madoka☆Magica Gaiden S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181768.mp4', 'http://timg.bdta.pro/images/5840eed0f1f3f695a0575bd808b0fa87.jpg'),
(83425, 5797, 'Magia Record: Mahou Shoujo Madoka☆Magica Gaiden S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181769.mp4', 'http://timg.bdta.pro/images/bea2bd7a3da03df7b35e5ab31b7f6fb8.jpg'),
(83426, 5797, 'Magia Record: Mahou Shoujo Madoka☆Magica Gaiden S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181770.mp4', 'http://timg.bdta.pro/images/a8e0dc7dd3f8ca07ccac3c3554b61e35.jpg'),
(83427, 5797, 'Magia Record: Mahou Shoujo Madoka☆Magica Gaiden S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/181771.mp4', 'http://timg.bdta.pro/images/bee9adb4bd9b1309eb158a2fdc1524b0.jpg'),
(83428, 5797, 'Magia Record: Mahou Shoujo Madoka☆Magica Gaiden S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/181772.mp4', 'http://timg.bdta.pro/images/e5238ff2c0ff792bf518d0f5bb97ba90.jpg'),
(83429, 5797, 'Magia Record: Mahou Shoujo Madoka☆Magica Gaiden S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/181773.mp4', 'http://timg.bdta.pro/images/6815b478f0514edec69951dfd63399f5.jpg'),
(83430, 5798, 'MaveriX S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181751.mp4', 'http://timg.bdta.pro/images/60c7a68db9c8a61adac5c4404cb0c315.jpg'),
(83431, 5798, 'MaveriX S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181752.mp4', 'http://timg.bdta.pro/images/6eb0cf08a9c4662a1413faf17980675b.jpg'),
(83432, 5798, 'MaveriX S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181753.mp4', 'http://timg.bdta.pro/images/dbc755f417f713c92cb2630a32db4e34.jpg'),
(83433, 5798, 'MaveriX S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181754.mp4', 'http://timg.bdta.pro/images/5ec2979a7cc3bc417073302bcc12ab99.jpg'),
(83434, 5798, 'MaveriX S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181755.mp4', 'http://timg.bdta.pro/images/9795685be346dd33d17d1fa9cbe33b33.jpg'),
(83435, 5798, 'MaveriX S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181756.mp4', 'http://timg.bdta.pro/images/d7598b7f9f039de13b7331f2ca116d0f.jpg'),
(83436, 5798, 'MaveriX S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181757.mp4', 'http://timg.bdta.pro/images/6a7b0d5e96572a95031ec276fd0af5bd.jpg'),
(83437, 5798, 'MaveriX S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181758.mp4', 'http://timg.bdta.pro/images/9679721b730b4f015e2ee0d2aa0a6658.jpg'),
(83438, 5798, 'MaveriX S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181759.mp4', 'http://timg.bdta.pro/images/06fd2a2990133856f04c92283d1aecea.jpg'),
(83439, 5798, 'MaveriX S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181760.mp4', 'http://timg.bdta.pro/images/1dcf8ae75be7cb1b1327ccf46ee17cb0.jpg'),
(83440, 5799, 'O Poder e a Lei S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226249.mp4', 'http://timg.bdta.pro/images/2c10dddf3651e8676a7d36afc0375007.jpg'),
(83441, 5799, 'O Poder e a Lei S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226250.mp4', 'http://timg.bdta.pro/images/77df30ee991f70a6bddf7f3d61556293.jpg'),
(83442, 5799, 'O Poder e a Lei S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226251.mp4', 'http://timg.bdta.pro/images/20ee5d0cfba548e6111a832f064c05ad.jpg'),
(83443, 5799, 'O Poder e a Lei S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226252.mp4', 'http://timg.bdta.pro/images/ba59d2cbda7b2207a81015164b20ccd0.jpg'),
(83444, 5799, 'O Poder e a Lei S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226253.mp4', 'http://timg.bdta.pro/images/3e2382e220353dc132b732d6bec3a6e5.jpg'),
(83445, 5799, 'O Poder e a Lei S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226254.mp4', 'http://timg.bdta.pro/images/59d1d063725564bc870118a5f6244a52.jpg'),
(83446, 5799, 'O Poder e a Lei S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226255.mp4', 'http://timg.bdta.pro/images/afcb1e30c2cfc82d0c63e4464088e514.jpg'),
(83447, 5799, 'O Poder e a Lei S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226256.mp4', 'http://timg.bdta.pro/images/7fe7044a62ec9df15a1299061e27ab9c.jpg'),
(83448, 5799, 'O Poder e a Lei S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226257.mp4', 'http://timg.bdta.pro/images/c5c82863439c8b70ccd7619550ab96cb.jpg'),
(83449, 5799, 'O Poder e a Lei S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226258.mp4', 'http://timg.bdta.pro/images/17d836a73bf927fde3e9613e8793e30a.jpg'),
(83450, 5800, 'O Poder e a Lei S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ee4t8ZkGFLTufyvqnpFhT7xmDkz.jpg'),
(83451, 5800, 'O Poder e a Lei S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dxM48AVl4Zyz8yOJpzTVncvSvs6.jpg'),
(83452, 5800, 'O Poder e a Lei S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dUOgGviyNPpCwrZ0dA7dgtTpZwK.jpg'),
(83453, 5800, 'O Poder e a Lei S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o8V4wSYfyw610VllPlRsAX5WOKN.jpg'),
(83454, 5800, 'O Poder e a Lei S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s56QqA9B1RWGzsk76OcXhEWnh8r.jpg'),
(83455, 5800, 'O Poder e a Lei S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hdB5XVkO9as1Bv9LV1joIe5AjX7.jpg'),
(83456, 5800, 'O Poder e a Lei S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6NydttG69CQDa1fPbxhOYlpEj27.jpg'),
(83457, 5800, 'O Poder e a Lei S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/scvbM1ppuiXZVkqb8CQgF1Fpp7r.jpg'),
(83458, 5800, 'O Poder e a Lei S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jHODs58495F3leijjU1BkW5jAwi.jpg'),
(83459, 5800, 'O Poder e a Lei S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jV7VHGCg4ZhYUosuQbPGxNbvpMR.jpg'),
(83460, 5801, 'O Poder e a Lei S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/482500.mp4', 'http://gstaticontent.com/images/172c4e0eb28091d87512e3a29e8c988b.jpg'),
(83461, 5801, 'O Poder e a Lei S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/482501.mp4', 'http://gstaticontent.com/images/172c4e0eb28091d87512e3a29e8c988b.jpg'),
(83462, 5801, 'O Poder e a Lei S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/482502.mp4', 'http://gstaticontent.com/images/172c4e0eb28091d87512e3a29e8c988b.jpg'),
(83463, 5801, 'O Poder e a Lei S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/482503.mp4', 'http://gstaticontent.com/images/172c4e0eb28091d87512e3a29e8c988b.jpg'),
(83464, 5801, 'O Poder e a Lei S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/482504.mp4', 'http://gstaticontent.com/images/172c4e0eb28091d87512e3a29e8c988b.jpg'),
(83465, 5801, 'O Poder e a Lei S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/482505.mp4', 'http://gstaticontent.com/images/172c4e0eb28091d87512e3a29e8c988b.jpg'),
(83466, 5801, 'O Poder e a Lei S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/482506.mp4', 'http://gstaticontent.com/images/172c4e0eb28091d87512e3a29e8c988b.jpg'),
(83467, 5801, 'O Poder e a Lei S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/482507.mp4', 'http://gstaticontent.com/images/172c4e0eb28091d87512e3a29e8c988b.jpg'),
(83468, 5801, 'O Poder e a Lei S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/482508.mp4', 'http://gstaticontent.com/images/172c4e0eb28091d87512e3a29e8c988b.jpg'),
(83469, 5801, 'O Poder e a Lei S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/482509.mp4', 'http://gstaticontent.com/images/172c4e0eb28091d87512e3a29e8c988b.jpg'),
(83470, 5802, 'Retrato Falado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181741.mp4', 'http://gstaticontent.com/images/5f39fdd1bff8d38e605ee8415fecbde5.jpg'),
(83471, 5802, 'Retrato Falado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181742.mp4', 'http://gstaticontent.com/images/5f39fdd1bff8d38e605ee8415fecbde5.jpg'),
(83472, 5802, 'Retrato Falado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181743.mp4', 'http://gstaticontent.com/images/5f39fdd1bff8d38e605ee8415fecbde5.jpg'),
(83473, 5802, 'Retrato Falado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181744.mp4', 'http://gstaticontent.com/images/5f39fdd1bff8d38e605ee8415fecbde5.jpg'),
(83474, 5802, 'Retrato Falado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181745.mp4', 'http://gstaticontent.com/images/5f39fdd1bff8d38e605ee8415fecbde5.jpg'),
(83475, 5802, 'Retrato Falado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181746.mp4', 'http://gstaticontent.com/images/5f39fdd1bff8d38e605ee8415fecbde5.jpg'),
(83476, 5802, 'Retrato Falado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181747.mp4', 'http://gstaticontent.com/images/5f39fdd1bff8d38e605ee8415fecbde5.jpg'),
(83477, 5802, 'Retrato Falado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181748.mp4', 'http://gstaticontent.com/images/5f39fdd1bff8d38e605ee8415fecbde5.jpg'),
(83478, 5802, 'Retrato Falado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181749.mp4', 'http://gstaticontent.com/images/5f39fdd1bff8d38e605ee8415fecbde5.jpg'),
(83479, 5802, 'Retrato Falado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181750.mp4', 'http://gstaticontent.com/images/5f39fdd1bff8d38e605ee8415fecbde5.jpg'),
(83480, 5803, 'Shikkakumon no Saikyou Kenja S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181729.mp4', 'http://timg.bdta.pro/images/2c5467ddad0a0a45b88c575e7d9c084a.jpg'),
(83481, 5803, 'Shikkakumon no Saikyou Kenja S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181730.mp4', 'http://timg.bdta.pro/images/acc12a106ce4adaf65d28af9164128e7.jpg'),
(83482, 5803, 'Shikkakumon no Saikyou Kenja S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181731.mp4', 'http://timg.bdta.pro/images/4e7173bdd84a638f17f59b231ca6d45e.jpg'),
(83483, 5803, 'Shikkakumon no Saikyou Kenja S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181732.mp4', 'http://timg.bdta.pro/images/454826adc2a2763cae642ad4095da9f4.jpg'),
(83484, 5803, 'Shikkakumon no Saikyou Kenja S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181733.mp4', 'http://timg.bdta.pro/images/b0349c9dedf7e6f0a6c4e1083ee7abd4.jpg'),
(83485, 5803, 'Shikkakumon no Saikyou Kenja S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181734.mp4', 'http://timg.bdta.pro/images/8202c384d6a10c13f4fc05d6fc7dfcff.jpg'),
(83486, 5803, 'Shikkakumon no Saikyou Kenja S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181735.mp4', 'http://timg.bdta.pro/images/99597711921ee23f4dece97bdea4ebbb.jpg'),
(83487, 5803, 'Shikkakumon no Saikyou Kenja S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181736.mp4', 'http://timg.bdta.pro/images/ecd3b1f37f3662beb27ad5af383d83ed.jpg'),
(83488, 5803, 'Shikkakumon no Saikyou Kenja S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181737.mp4', 'http://timg.bdta.pro/images/991254455d3d42c835be988947c331d6.jpg'),
(83489, 5803, 'Shikkakumon no Saikyou Kenja S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181738.mp4', 'http://timg.bdta.pro/images/481e61f61482e9d306cae57aad2d61f5.jpg'),
(83490, 5803, 'Shikkakumon no Saikyou Kenja S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/181739.mp4', 'http://timg.bdta.pro/images/c32e5f78893c31f4bfa2f4ca6aca42b7.jpg'),
(83491, 5803, 'Shikkakumon no Saikyou Kenja S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/181740.mp4', 'http://timg.bdta.pro/images/634b4da68eed7a494d64eeb7eb8558ab.jpg'),
(83492, 5804, 'Super Pumped: A Guerra Pela Uber S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181722.mp4', 'http://timg.bdta.pro/images/a636c58858c4be08bc9c618d0b1e0e03.jpg'),
(83493, 5804, 'Super Pumped: A Guerra Pela Uber S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181723.mp4', 'http://timg.bdta.pro/images/cc9333beb32351ad95603ee2cb9e9ae2.jpg'),
(83494, 5804, 'Super Pumped: A Guerra Pela Uber S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181724.mp4', 'http://timg.bdta.pro/images/a466e240e15412345a08b50c33d7a000.jpg'),
(83495, 5804, 'Super Pumped: A Guerra Pela Uber S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181725.mp4', 'http://timg.bdta.pro/images/f13f3ede581b027d9adbb1487fc162c4.jpg'),
(83496, 5804, 'Super Pumped: A Guerra Pela Uber S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181726.mp4', 'http://timg.bdta.pro/images/71a4117096ede69170a687aebc7a731f.jpg'),
(83497, 5804, 'Super Pumped: A Guerra Pela Uber S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181727.mp4', 'http://timg.bdta.pro/images/8ef0fdf045ac0373f9ea316badbc8d9e.jpg'),
(83498, 5804, 'Super Pumped: A Guerra Pela Uber S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181728.mp4', 'http://timg.bdta.pro/images/80e9682a4e4fe2725cdca1c011a90ffb.jpg'),
(83499, 5805, 'The Kids in the Hall S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181714.mp4', 'http://timg.bdta.pro/images/8f1e104a4323f5293e9ffbe3ae0b30cc.jpg'),
(83500, 5805, 'The Kids in the Hall S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181715.mp4', 'http://timg.bdta.pro/images/a2a16dcfd097ccd0ba34d0a4336bcd63.jpg'),
(83501, 5805, 'The Kids in the Hall S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181716.mp4', 'http://timg.bdta.pro/images/727e8dc3492308d2d30eab0d9c9549ad.jpg'),
(83502, 5805, 'The Kids in the Hall S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181717.mp4', 'http://timg.bdta.pro/images/69c4574680cce35c28694613b959b7a8.jpg'),
(83503, 5805, 'The Kids in the Hall S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181718.mp4', 'http://timg.bdta.pro/images/033bfa469a2162fe8f2fce2deea2b5fc.jpg'),
(83504, 5805, 'The Kids in the Hall S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181719.mp4', 'http://timg.bdta.pro/images/31f566194c486958dcea16578ac45c99.jpg'),
(83505, 5805, 'The Kids in the Hall S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181720.mp4', 'http://timg.bdta.pro/images/e02f820ef2d584668715786ededbd473.jpg'),
(83506, 5805, 'The Kids in the Hall S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181721.mp4', 'http://timg.bdta.pro/images/edbee758cf6b4a023f9ef5744a5babcb.jpg'),
(83507, 5806, 'Vinte e Um S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181698.mp4', 'http://timg.bdta.pro/images/860952e279fd2c8835b72f620c67c078.jpg'),
(83508, 5806, 'Vinte e Um S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181699.mp4', 'http://timg.bdta.pro/images/531afbef2f01f4cca30d25f04ee999c5.jpg'),
(83509, 5806, 'Vinte e Um S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181700.mp4', 'http://timg.bdta.pro/images/8109c902304dd4b2c494fa14aee492f9.jpg'),
(83510, 5806, 'Vinte e Um S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181701.mp4', 'http://timg.bdta.pro/images/1b3cb95cf442e1496d1c90b9c19ff9fe.jpg'),
(83511, 5806, 'Vinte e Um S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181702.mp4', 'http://timg.bdta.pro/images/77ece37bf2df422555c3bded7f1183bd.jpg'),
(83512, 5806, 'Vinte e Um S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181703.mp4', 'http://timg.bdta.pro/images/78c5dfbc12d28ef36efe0daa770015e2.jpg'),
(83513, 5806, 'Vinte e Um S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181704.mp4', 'http://timg.bdta.pro/images/7aede0b96aeef05845925637ed1c1ee9.jpg'),
(83514, 5806, 'Vinte e Um S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181705.mp4', 'http://timg.bdta.pro/images/62017667da4a9b9e50d3616ec2912124.jpg'),
(83515, 5806, 'Vinte e Um S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181706.mp4', 'http://timg.bdta.pro/images/c0d7663e2a759c176441bdd1bdeed80a.jpg'),
(83516, 5806, 'Vinte e Um S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181707.mp4', 'http://timg.bdta.pro/images/e4a6a070c239e9d2353ba861f900f412.jpg'),
(83517, 5806, 'Vinte e Um S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/181708.mp4', 'http://timg.bdta.pro/images/a0eb9c76162824947b39d9802f2c14e0.jpg'),
(83518, 5806, 'Vinte e Um S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/181709.mp4', 'http://timg.bdta.pro/images/c07fe3e4fe37ec853083b67c207c91b5.jpg'),
(83519, 5806, 'Vinte e Um S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/181710.mp4', 'http://timg.bdta.pro/images/5fc03bed3b8a26c0e0a8bede92a0952c.jpg'),
(83520, 5806, 'Vinte e Um S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/181711.mp4', 'http://timg.bdta.pro/images/0b94078175f8e575bf4bba9b54068bba.jpg'),
(83521, 5806, 'Vinte e Um S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/181712.mp4', 'http://timg.bdta.pro/images/69d3447ec180a909a5b6680ba417cfe8.jpg'),
(83522, 5806, 'Vinte e Um S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/181713.mp4', 'http://timg.bdta.pro/images/4b61e5fdb8aef7da9c084b3353c6c3f6.jpg'),
(83523, 5807, 'Anos-luz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181186.mp4', 'http://timg.bdta.pro/images/c326ce377f55c64742290f79581a9ad8.jpg'),
(83524, 5807, 'Anos-luz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181187.mp4', 'http://timg.bdta.pro/images/3c38d161218a02e6e52e74c302fa4e44.jpg'),
(83525, 5807, 'Anos-luz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181188.mp4', 'http://timg.bdta.pro/images/c646bd5582a2e68084eaa613e23c143b.jpg'),
(83526, 5807, 'Anos-luz S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181189.mp4', 'http://timg.bdta.pro/images/7c1e3406cbd4161c8d7e08cd25f4543e.jpg'),
(83527, 5807, 'Anos-luz S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181190.mp4', 'http://timg.bdta.pro/images/1c51df56ce761919b64149403e8a0024.jpg'),
(83528, 5807, 'Anos-luz S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181191.mp4', 'http://timg.bdta.pro/images/ee5c2ec9dce36f30ab65dce2334c5fa6.jpg'),
(83529, 5807, 'Anos-luz S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181192.mp4', 'http://timg.bdta.pro/images/8b52cff52b373a4eda6622b1e6b775f2.jpg'),
(83530, 5807, 'Anos-luz S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181193.mp4', 'http://timg.bdta.pro/images/4765985eb9b73dadc6f0cf521ad615a9.jpg'),
(83531, 5808, 'Bel-Air S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217109.mp4', 'http://timg.bdta.pro/images/56e3edd191234c65866be2d06b6705c0.jpg'),
(83532, 5808, 'Bel-Air S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217110.mp4', 'http://timg.bdta.pro/images/7415b7df98ea1c26b1e0082a13f4371b.jpg'),
(83533, 5808, 'Bel-Air S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217111.mp4', 'http://timg.bdta.pro/images/2cba04f4be62ecfbcf0c7c9a1f3e8941.jpg'),
(83534, 5808, 'Bel-Air S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217112.mp4', 'http://timg.bdta.pro/images/f0dcb28197189397c3f578ba014ae5df.jpg'),
(83535, 5808, 'Bel-Air S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217113.mp4', 'http://timg.bdta.pro/images/3c6d00844e0d09bc90e115750eac2325.jpg'),
(83536, 5808, 'Bel-Air S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217114.mp4', 'http://timg.bdta.pro/images/2a564e7e173483aa4c1cf4a22d34cd7c.jpg'),
(83537, 5808, 'Bel-Air S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217115.mp4', 'http://timg.bdta.pro/images/3e54f4b49c83b0fe43e511406afabf0f.jpg'),
(83538, 5808, 'Bel-Air S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217116.mp4', 'http://timg.bdta.pro/images/87231f8a81b3da2d1b7aff399ace45f2.jpg'),
(83539, 5808, 'Bel-Air S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217117.mp4', 'http://timg.bdta.pro/images/cca1ced539e617a3dbc69fb300e064e2.jpg'),
(83540, 5808, 'Bel-Air S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217118.mp4', 'http://timg.bdta.pro/images/617391efa44602029b6ea2ce63cbd859.jpg'),
(83541, 5809, 'Bel-Air S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ygmUXyD5aay3c8K1N9xGo86CZJ.jpg'),
(83542, 5809, 'Bel-Air S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4yiDTDZ6yQATZoz8R3TyGVCr6vj.jpg'),
(83543, 5809, 'Bel-Air S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sTVW3Q6mCdrPX6TfALA78SwykgF.jpg'),
(83544, 5809, 'Bel-Air S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j7iOckkWNKzjp1OTkkhX4gTCIXR.jpg'),
(83545, 5809, 'Bel-Air S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfQOab9fHDHGrn2Li1IdzJjWS7w.jpg'),
(83546, 5809, 'Bel-Air S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vAlygjPuC38ovHouiXToBafiH3j.jpg'),
(83547, 5809, 'Bel-Air S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rG2WUOBcJlKcCGuhNqnHSJl11Wd.jpg'),
(83548, 5809, 'Bel-Air S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2uBHTdX07NkyBpAx74v2fYjyuEY.jpg'),
(83549, 5809, 'Bel-Air S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6J8R7MhF4abEWO09zUqbweTaUQJ.jpg'),
(83550, 5809, 'Bel-Air S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l0zzk9CqR01vadl5pbnnt6gJ4Ua.jpg'),
(83551, 5810, 'Bel-Air S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/470753.mp4', 'http://gstaticontent.com/images/febccbcb982000a40f7f09bf5f2b25f0.jpg'),
(83552, 5810, 'Bel-Air S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/470754.mp4', 'http://gstaticontent.com/images/febccbcb982000a40f7f09bf5f2b25f0.jpg'),
(83553, 5810, 'Bel-Air S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/470755.mp4', 'http://gstaticontent.com/images/febccbcb982000a40f7f09bf5f2b25f0.jpg'),
(83554, 5810, 'Bel-Air S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/470756.mp4', 'http://gstaticontent.com/images/febccbcb982000a40f7f09bf5f2b25f0.jpg'),
(83555, 5810, 'Bel-Air S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/470757.mp4', 'http://gstaticontent.com/images/febccbcb982000a40f7f09bf5f2b25f0.jpg'),
(83556, 5810, 'Bel-Air S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/470758.mp4', 'http://gstaticontent.com/images/febccbcb982000a40f7f09bf5f2b25f0.jpg'),
(83557, 5810, 'Bel-Air S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/470759.mp4', 'http://gstaticontent.com/images/febccbcb982000a40f7f09bf5f2b25f0.jpg'),
(83558, 5810, 'Bel-Air S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/470760.mp4', 'http://gstaticontent.com/images/febccbcb982000a40f7f09bf5f2b25f0.jpg'),
(83559, 5810, 'Bel-Air S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/470761.mp4', 'http://gstaticontent.com/images/febccbcb982000a40f7f09bf5f2b25f0.jpg'),
(83560, 5810, 'Bel-Air S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/470762.mp4', 'http://gstaticontent.com/images/febccbcb982000a40f7f09bf5f2b25f0.jpg'),
(83561, 5811, 'Bosch: O Legado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238928.mp4', 'http://timg.bdta.pro/images/f9426333d6dbdca1082f1193b3304244.jpg'),
(83562, 5811, 'Bosch: O Legado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238929.mp4', 'http://timg.bdta.pro/images/bc014954a68b646f5af3b873dde71d3b.jpg'),
(83563, 5811, 'Bosch: O Legado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238930.mp4', 'http://timg.bdta.pro/images/1ef9afac3f63b3e0943ecd78e956173c.jpg'),
(83564, 5811, 'Bosch: O Legado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238931.mp4', 'http://timg.bdta.pro/images/77509569b14342ab9d079c193038c1af.jpg'),
(83565, 5811, 'Bosch: O Legado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238932.mp4', 'http://timg.bdta.pro/images/c3dd4715596a3bde2ae03f03fb5347ff.jpg'),
(83566, 5811, 'Bosch: O Legado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238933.mp4', 'http://timg.bdta.pro/images/92d13a467aeb90a5823cef37f63880c8.jpg'),
(83567, 5811, 'Bosch: O Legado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238934.mp4', 'http://timg.bdta.pro/images/cb3b6e7ce9bc803179ec86d04fe74293.jpg'),
(83568, 5811, 'Bosch: O Legado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238935.mp4', 'http://timg.bdta.pro/images/f52802df8798f14e9b94f747bf6e31cc.jpg'),
(83569, 5811, 'Bosch: O Legado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238936.mp4', 'http://timg.bdta.pro/images/7ee1cb414daa3dc07de2f6cc97de2e13.jpg'),
(83570, 5811, 'Bosch: O Legado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238937.mp4', 'http://timg.bdta.pro/images/dc7c319709318df4a9b4957dfe55b2f6.jpg'),
(83571, 5812, 'Bosch: O Legado S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238938.mp4', 'http://gstaticontent.com/images/8d8b3245d78c6c605de14236082fbc12.jpg'),
(83572, 5812, 'Bosch: O Legado S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238939.mp4', 'http://gstaticontent.com/images/8d8b3245d78c6c605de14236082fbc12.jpg'),
(83573, 5812, 'Bosch: O Legado S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238940.mp4', 'http://gstaticontent.com/images/8d8b3245d78c6c605de14236082fbc12.jpg'),
(83574, 5812, 'Bosch: O Legado S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238941.mp4', 'http://gstaticontent.com/images/8d8b3245d78c6c605de14236082fbc12.jpg'),
(83575, 5812, 'Bosch: O Legado S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238942.mp4', 'http://gstaticontent.com/images/8d8b3245d78c6c605de14236082fbc12.jpg'),
(83576, 5812, 'Bosch: O Legado S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238943.mp4', 'http://gstaticontent.com/images/8d8b3245d78c6c605de14236082fbc12.jpg'),
(83577, 5812, 'Bosch: O Legado S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238944.mp4', 'http://gstaticontent.com/images/8d8b3245d78c6c605de14236082fbc12.jpg'),
(83578, 5812, 'Bosch: O Legado S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238945.mp4', 'http://gstaticontent.com/images/8d8b3245d78c6c605de14236082fbc12.jpg'),
(83579, 5812, 'Bosch: O Legado S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238946.mp4', 'http://gstaticontent.com/images/8d8b3245d78c6c605de14236082fbc12.jpg'),
(83580, 5812, 'Bosch: O Legado S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238947.mp4', 'http://gstaticontent.com/images/8d8b3245d78c6c605de14236082fbc12.jpg'),
(83581, 5813, 'Bosch: O Legado S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/742883.mp4', 'http://gstaticontent.com/images/8d8b3245d78c6c605de14236082fbc12.jpg'),
(83582, 5813, 'Bosch: O Legado S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/742884.mp4', 'http://gstaticontent.com/images/8d8b3245d78c6c605de14236082fbc12.jpg'),
(83583, 5813, 'Bosch: O Legado S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/742885.mp4', 'http://gstaticontent.com/images/8d8b3245d78c6c605de14236082fbc12.jpg'),
(83584, 5813, 'Bosch: O Legado S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/742886.mp4', 'http://gstaticontent.com/images/8d8b3245d78c6c605de14236082fbc12.jpg'),
(83585, 5813, 'Bosch: O Legado S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/755824.mp4', 'http://gstaticontent.com/images/8d8b3245d78c6c605de14236082fbc12.jpg'),
(83586, 5813, 'Bosch: O Legado S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/755825.mp4', 'http://gstaticontent.com/images/8d8b3245d78c6c605de14236082fbc12.jpg'),
(83587, 5813, 'Bosch: O Legado S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/768537.mp4', 'http://gstaticontent.com/images/8d8b3245d78c6c605de14236082fbc12.jpg'),
(83588, 5813, 'Bosch: O Legado S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/768538.mp4', 'http://gstaticontent.com/images/8d8b3245d78c6c605de14236082fbc12.jpg'),
(83589, 5813, 'Bosch: O Legado S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/777028.mp4', 'http://gstaticontent.com/images/8d8b3245d78c6c605de14236082fbc12.jpg'),
(83590, 5813, 'Bosch: O Legado S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/777029.mp4', 'http://gstaticontent.com/images/8d8b3245d78c6c605de14236082fbc12.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(83591, 5814, 'Chega de Bagunca com Stacey Solomon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181179.mp4', 'http://gstaticontent.com/images/7c7e292ea8a3797b5e77103f25d3be8c.jpg'),
(83592, 5814, 'Chega de Bagunca com Stacey Solomon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181180.mp4', 'http://gstaticontent.com/images/7c7e292ea8a3797b5e77103f25d3be8c.jpg'),
(83593, 5814, 'Chega de Bagunca com Stacey Solomon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181181.mp4', 'http://gstaticontent.com/images/7c7e292ea8a3797b5e77103f25d3be8c.jpg'),
(83594, 5814, 'Chega de Bagunca com Stacey Solomon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181182.mp4', 'http://gstaticontent.com/images/7c7e292ea8a3797b5e77103f25d3be8c.jpg'),
(83595, 5814, 'Chega de Bagunca com Stacey Solomon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181183.mp4', 'http://gstaticontent.com/images/7c7e292ea8a3797b5e77103f25d3be8c.jpg'),
(83596, 5814, 'Chega de Bagunca com Stacey Solomon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181184.mp4', 'http://gstaticontent.com/images/7c7e292ea8a3797b5e77103f25d3be8c.jpg'),
(83597, 5814, 'Chega de Bagunca com Stacey Solomon S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181185.mp4', 'http://gstaticontent.com/images/7c7e292ea8a3797b5e77103f25d3be8c.jpg'),
(83598, 5815, 'Descobrindo o Egito S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181177.mp4', 'http://timg.bdta.pro/images/70a7c3f11aaf6261bcf3e469b4139dad.jpg'),
(83599, 5815, 'Descobrindo o Egito S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181178.mp4', 'http://timg.bdta.pro/images/7274c1756d647d09d755f621626ecc74.jpg'),
(83600, 5816, 'Entrevías S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181169.mp4', 'http://timg.bdta.pro/images/2626285d0825040e8690dbeab98428c5.jpg'),
(83601, 5816, 'Entrevías S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181170.mp4', 'http://timg.bdta.pro/images/2d96835f11223d6ca9cff2a27bd52312.jpg'),
(83602, 5816, 'Entrevías S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181171.mp4', 'http://timg.bdta.pro/images/651a7e5db1b624af3a4d456ecf2d8a55.jpg'),
(83603, 5816, 'Entrevías S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181172.mp4', 'http://timg.bdta.pro/images/a72f31df9d86155c9d8cb905ab4b81e9.jpg'),
(83604, 5816, 'Entrevías S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181173.mp4', 'http://timg.bdta.pro/images/ca0e16e16a6d3614589d594d8067b682.jpg'),
(83605, 5816, 'Entrevías S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181174.mp4', 'http://timg.bdta.pro/images/c4e928664ec00278077fa052ec8dfdb3.jpg'),
(83606, 5816, 'Entrevías S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181175.mp4', 'http://timg.bdta.pro/images/74e57195ef46786e42a77d7014b0323d.jpg'),
(83607, 5816, 'Entrevías S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181176.mp4', 'http://timg.bdta.pro/images/01e1122f7958776960ccfec73246ca53.jpg'),
(83608, 5817, 'Entrevías S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/296202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ved5TlKT9p2prYKdcZd4hnCMXa1.jpg'),
(83609, 5817, 'Entrevías S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/296203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9uyjBZL12z1NSRan81nEw03DRWN.jpg'),
(83610, 5817, 'Entrevías S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/296204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kkLFJ8e08JBtJhYTlMVo6B6i7Ku.jpg'),
(83611, 5817, 'Entrevías S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/296205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oj7aQJRlontgnGAlrrDDKE1caPJ.jpg'),
(83612, 5817, 'Entrevías S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/296206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ei6WVVDGj1k7f2HVyOdvBGHvegI.jpg'),
(83613, 5817, 'Entrevías S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/296207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rzQm7q88pKEzKT0GQ9WqlbPBGsC.jpg'),
(83614, 5817, 'Entrevías S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/296208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2AMKiazU8AZyzF9Iz7YQfZ4tTTD.jpg'),
(83615, 5817, 'Entrevías S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/296209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFGMC75l6P0YdCHdQ9X1xM0wABg.jpg'),
(83616, 5818, 'Entrevías S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/296210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c2u8d3g8uHKw7ARqO5bTHJV315C.jpg'),
(83617, 5818, 'Entrevías S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/296211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hG1ks6j6QMHAIE0TwHp6NuDDEOc.jpg'),
(83618, 5818, 'Entrevías S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/296212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6oFCkKZ8ZiukZvMfcNsAui4v8H5.jpg'),
(83619, 5818, 'Entrevías S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/296213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ztXJSr0JKX7Qkxo8X6jR8GlFtRj.jpg'),
(83620, 5818, 'Entrevías S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/296214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZ3dslm3Dpxb2dfQez2iwlFYwwa.jpg'),
(83621, 5818, 'Entrevías S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/296215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jg63clux6ozHEzZhZ0ik5lXzwxa.jpg'),
(83622, 5818, 'Entrevías S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/296216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dluuHMsMUq2z1CWPkz4fpd14OSE.jpg'),
(83623, 5818, 'Entrevías S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/296217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uG74bB1j18VE6bsG9ummcR07uM5.jpg'),
(83624, 5819, 'Entrevías S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/686753.mp4', 'http://gstaticontent.com/images/1a32f457c12942c0575479fbe8a9f2db.jpg'),
(83625, 5819, 'Entrevías S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/686754.mp4', 'http://gstaticontent.com/images/1a32f457c12942c0575479fbe8a9f2db.jpg'),
(83626, 5819, 'Entrevías S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/686755.mp4', 'http://gstaticontent.com/images/1a32f457c12942c0575479fbe8a9f2db.jpg'),
(83627, 5819, 'Entrevías S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/686756.mp4', 'http://gstaticontent.com/images/1a32f457c12942c0575479fbe8a9f2db.jpg'),
(83628, 5819, 'Entrevías S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/686757.mp4', 'http://gstaticontent.com/images/1a32f457c12942c0575479fbe8a9f2db.jpg'),
(83629, 5819, 'Entrevías S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/686758.mp4', 'http://gstaticontent.com/images/1a32f457c12942c0575479fbe8a9f2db.jpg'),
(83630, 5819, 'Entrevías S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/686759.mp4', 'http://gstaticontent.com/images/1a32f457c12942c0575479fbe8a9f2db.jpg'),
(83631, 5819, 'Entrevías S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/686760.mp4', 'http://gstaticontent.com/images/1a32f457c12942c0575479fbe8a9f2db.jpg'),
(83632, 5820, 'La Brea: A Terra Perdida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261347.mp4', 'http://timg.bdta.pro/images/1105e66341766c4310ee3d908740b5b5.jpg'),
(83633, 5820, 'La Brea: A Terra Perdida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261348.mp4', 'http://timg.bdta.pro/images/d32117d07923d55380c6803054a19020.jpg'),
(83634, 5820, 'La Brea: A Terra Perdida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261349.mp4', 'http://timg.bdta.pro/images/679027fa089790869743b23d1a5daf09.jpg'),
(83635, 5820, 'La Brea: A Terra Perdida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261350.mp4', 'http://timg.bdta.pro/images/bb2f035bc7d630c419443c7696d90624.jpg'),
(83636, 5820, 'La Brea: A Terra Perdida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261351.mp4', 'http://timg.bdta.pro/images/bf400b19dfa6c97523ddfcb8a523c74d.jpg'),
(83637, 5820, 'La Brea: A Terra Perdida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261352.mp4', 'http://timg.bdta.pro/images/90e30dca6875939e0a16dfd6b59f6c41.jpg'),
(83638, 5820, 'La Brea: A Terra Perdida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261353.mp4', 'http://timg.bdta.pro/images/80410df595cdf73728cc799b3ae19e18.jpg'),
(83639, 5820, 'La Brea: A Terra Perdida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261354.mp4', 'http://timg.bdta.pro/images/dd25bdccd8b0edd0ddd0e59f4d112005.jpg'),
(83640, 5820, 'La Brea: A Terra Perdida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261355.mp4', 'http://timg.bdta.pro/images/e3c2cb49b40fb17a363bc565af1913e7.jpg'),
(83641, 5820, 'La Brea: A Terra Perdida S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261356.mp4', 'http://timg.bdta.pro/images/54fdb9d52032c119cc3b4665a6c384d5.jpg'),
(83642, 5821, 'La Brea: A Terra Perdida S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZFMHgTO6mxA4Zm0u9JIgViuZje.jpg'),
(83643, 5821, 'La Brea: A Terra Perdida S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jp5VYCSmLfpnIe8Sdct9cIqNUU2.jpg'),
(83644, 5821, 'La Brea: A Terra Perdida S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261359.mp4', 'http://image.tmdb.org/t/p/w1280/zszRuNzDnDHpBejuTl92m9VnBIG.jpg'),
(83645, 5821, 'La Brea: A Terra Perdida S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261360.mp4', 'http://image.tmdb.org/t/p/w1280/vpJEHgSvWDHQR0CrxDGV6qKzcDl.jpg'),
(83646, 5821, 'La Brea: A Terra Perdida S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261361.mp4', 'http://image.tmdb.org/t/p/w1280/tuhsvXsHISPijXBcz5WTmveDDxm.jpg'),
(83647, 5821, 'La Brea: A Terra Perdida S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261362.mp4', 'http://image.tmdb.org/t/p/w1280/hUed9UgeUHUZWrLbx92fy8ZLjLO.jpg'),
(83648, 5821, 'La Brea: A Terra Perdida S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261363.mp4', 'http://image.tmdb.org/t/p/w1280/seMF0BI1OCM9LZgvBAaRY0IcW3A.jpg'),
(83649, 5821, 'La Brea: A Terra Perdida S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261364.mp4', 'http://image.tmdb.org/t/p/w1280/gzQeosDQC7TxVm3OQUVMx2ZbzF2.jpg'),
(83650, 5821, 'La Brea: A Terra Perdida S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261365.mp4', 'http://image.tmdb.org/t/p/w1280/732BRsQGHtHrmMcEPzm87UDNwkI.jpg'),
(83651, 5821, 'La Brea: A Terra Perdida S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261366.mp4', 'http://image.tmdb.org/t/p/w1280/sMo3N2SjVQ8o3VEJTBSbnnw06Tu.jpg'),
(83652, 5821, 'La Brea: A Terra Perdida S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/261367.mp4', 'http://image.tmdb.org/t/p/w1280/17vHnfYhgnsNUozyxOJQYAE8QGm.jpg'),
(83653, 5821, 'La Brea: A Terra Perdida S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/261368.mp4', 'http://image.tmdb.org/t/p/w1280/estGqQotrXNoOFnMhCco0PAHhjx.jpg'),
(83654, 5821, 'La Brea: A Terra Perdida S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/261369.mp4', 'http://gstaticontent.com/images/0ebb1c6c6546d23ae1e2031b64e386e9.jpg'),
(83655, 5821, 'La Brea: A Terra Perdida S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/261370.mp4', 'http://gstaticontent.com/images/0ebb1c6c6546d23ae1e2031b64e386e9.jpg'),
(83656, 5822, 'La Brea: A Terra Perdida S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261371.mp4', 'http://gstaticontent.com/images/0ebb1c6c6546d23ae1e2031b64e386e9.jpg'),
(83657, 5822, 'La Brea: A Terra Perdida S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261372.mp4', 'http://gstaticontent.com/images/0ebb1c6c6546d23ae1e2031b64e386e9.jpg'),
(83658, 5822, 'La Brea: A Terra Perdida S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pze7T5rj5uiqlEnD95eWl9dkZky.jpg'),
(83659, 5822, 'La Brea: A Terra Perdida S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/36boxSViw5fL3QwWgwe82GRafoT.jpg'),
(83660, 5822, 'La Brea: A Terra Perdida S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nST2T5NpV9iE0KOh2DXYoaAyD2j.jpg'),
(83661, 5822, 'La Brea: A Terra Perdida S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3cNTpM9rK0yfSJaa9HMgelzJzUF.jpg'),
(83662, 5823, 'Life & Beth S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181159.mp4', 'http://timg.bdta.pro/images/4039fcd48b4c7febbe9bc410640ae6cb.jpg'),
(83663, 5823, 'Life & Beth S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181160.mp4', 'http://timg.bdta.pro/images/3395dc47a55dc2ce916b3724c5f083cd.jpg'),
(83664, 5823, 'Life & Beth S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181161.mp4', 'http://timg.bdta.pro/images/7cf8ad08722a654b1ab3f8b8b0252858.jpg'),
(83665, 5823, 'Life & Beth S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181162.mp4', 'http://timg.bdta.pro/images/d7281f01539f06a4183583d852eec4be.jpg'),
(83666, 5823, 'Life & Beth S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181163.mp4', 'http://timg.bdta.pro/images/218ad7d7ee36130266da71c97c86b071.jpg'),
(83667, 5823, 'Life & Beth S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181164.mp4', 'http://timg.bdta.pro/images/d2198f269582ffd8bac5908023f2e203.jpg'),
(83668, 5823, 'Life & Beth S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181165.mp4', 'http://timg.bdta.pro/images/293e5a94ad35a7453e44628e55045aa7.jpg'),
(83669, 5823, 'Life & Beth S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181166.mp4', 'http://timg.bdta.pro/images/02dfc2f1d21a276f9d6fff3412681223.jpg'),
(83670, 5823, 'Life & Beth S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181167.mp4', 'http://timg.bdta.pro/images/06caf9ea4317eb45a5b94e3e2dde76ad.jpg'),
(83671, 5823, 'Life & Beth S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181168.mp4', 'http://timg.bdta.pro/images/f119cb9bc48835a77693a64281c15210.jpg'),
(83672, 5824, 'Naomi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181146.mp4', 'http://timg.bdta.pro/images/0ea9baaa101d11c4bb8bab8241753a00.jpg'),
(83673, 5824, 'Naomi S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181147.mp4', 'http://timg.bdta.pro/images/220b4c226bc7f7047837d59cba7d6170.jpg'),
(83674, 5824, 'Naomi S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181148.mp4', 'http://timg.bdta.pro/images/4d90508b7d4c06a1d8fca049b809f0f5.jpg'),
(83675, 5824, 'Naomi S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181149.mp4', 'http://timg.bdta.pro/images/2fcffa5fe585319cf23a3396460a4e2d.jpg'),
(83676, 5824, 'Naomi S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181150.mp4', 'http://timg.bdta.pro/images/486fff8b7108674dec09c49792b23dbb.jpg'),
(83677, 5824, 'Naomi S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181151.mp4', 'http://timg.bdta.pro/images/87b36dd004a7bc943a606bf26fd13490.jpg'),
(83678, 5824, 'Naomi S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181152.mp4', 'http://timg.bdta.pro/images/7d9a71514e76e90ed837d4f50090e809.jpg'),
(83679, 5824, 'Naomi S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181153.mp4', 'http://timg.bdta.pro/images/79390d586670c162b25b0b706b6c0693.jpg'),
(83680, 5824, 'Naomi S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181154.mp4', 'http://timg.bdta.pro/images/479a4a348a0ff7cecc9ec4f55cb7043e.jpg'),
(83681, 5824, 'Naomi S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181155.mp4', 'http://timg.bdta.pro/images/12e4f2b22703a135ea15dfe6d247284a.jpg'),
(83682, 5824, 'Naomi S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/181156.mp4', 'http://timg.bdta.pro/images/88f6a0e268e927c074ffe98dd8a598ae.jpg'),
(83683, 5824, 'Naomi S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/181157.mp4', 'http://timg.bdta.pro/images/ec00303773850254ca964b302c30d043.jpg'),
(83684, 5824, 'Naomi S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/181158.mp4', 'http://timg.bdta.pro/images/70664f6d4f3a20c29585e5f0e3a06fd0.jpg'),
(83685, 5825, 'O Chefinho: De Volta ao Berço S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212130.mp4', 'http://timg.bdta.pro/images/c84e2010488ad18180aae95f22b3b644.jpg'),
(83686, 5825, 'O Chefinho: De Volta ao Berço S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212131.mp4', 'http://timg.bdta.pro/images/4e2773b436215907352ff0ee42c14848.jpg'),
(83687, 5825, 'O Chefinho: De Volta ao Berço S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212132.mp4', 'http://timg.bdta.pro/images/bae697d3ff8ac73176074609fded0970.jpg'),
(83688, 5825, 'O Chefinho: De Volta ao Berço S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212133.mp4', 'http://timg.bdta.pro/images/109797df7bef3637cdde0be65c2493c7.jpg'),
(83689, 5825, 'O Chefinho: De Volta ao Berço S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212134.mp4', 'http://timg.bdta.pro/images/8ccd4d9a31d5ddfc0e370a1865feb5d3.jpg'),
(83690, 5825, 'O Chefinho: De Volta ao Berço S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212135.mp4', 'http://timg.bdta.pro/images/1f75bc0790ccd858f5db7f72b677e74a.jpg'),
(83691, 5825, 'O Chefinho: De Volta ao Berço S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212136.mp4', 'http://timg.bdta.pro/images/f413f045c52e8a01515566aa87fa2ba8.jpg'),
(83692, 5825, 'O Chefinho: De Volta ao Berço S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212137.mp4', 'http://timg.bdta.pro/images/841b51d4ceccc1489033f5e4eebd8c67.jpg'),
(83693, 5825, 'O Chefinho: De Volta ao Berço S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212138.mp4', 'http://timg.bdta.pro/images/9c703364cd1683db6ab4453a714d83c9.jpg'),
(83694, 5825, 'O Chefinho: De Volta ao Berço S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212139.mp4', 'http://timg.bdta.pro/images/0b3cd378b97cdd24f00bbb88fa0e67c1.jpg'),
(83695, 5825, 'O Chefinho: De Volta ao Berço S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212140.mp4', 'http://timg.bdta.pro/images/b7da1a16caba8cff0f55d2e2cdee0865.jpg'),
(83696, 5825, 'O Chefinho: De Volta ao Berço S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212141.mp4', 'http://timg.bdta.pro/images/c84e2010488ad18180aae95f22b3b644.jpg'),
(83697, 5826, 'O Chefinho: De Volta ao Berço S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s6ikuqIY7UzL5L5xzO1Ep1fdKgo.jpg'),
(83698, 5826, 'O Chefinho: De Volta ao Berço S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rc4qlwjiEzmcckHBdJODLsTlSck.jpg'),
(83699, 5826, 'O Chefinho: De Volta ao Berço S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gftbUvX5picMvsOAHZSKe211Sio.jpg'),
(83700, 5826, 'O Chefinho: De Volta ao Berço S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yW2m4nWuOP39NkfjFOAcxryZMve.jpg'),
(83701, 5826, 'O Chefinho: De Volta ao Berço S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/45YjDbrbucrzm0jK0VC4z7syopl.jpg'),
(83702, 5826, 'O Chefinho: De Volta ao Berço S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c3UxWILdZs6Ghp6oGPneCbVI4rM.jpg'),
(83703, 5826, 'O Chefinho: De Volta ao Berço S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kHauapIvXstfvXVay6CXFGFSLxu.jpg'),
(83704, 5826, 'O Chefinho: De Volta ao Berço S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lajjAnsoX3iA5dcWXf0TUgJDzXe.jpg'),
(83705, 5826, 'O Chefinho: De Volta ao Berço S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fbOwC3beTWv0fEJnxGPqpcL1t8m.jpg'),
(83706, 5826, 'O Chefinho: De Volta ao Berço S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3N5XG7o0XlGEdkgHk0QUXgMPBJ8.jpg'),
(83707, 5826, 'O Chefinho: De Volta ao Berço S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gSCBHNIsAeftgIRqoLJUhqTpr89.jpg'),
(83708, 5826, 'O Chefinho: De Volta ao Berço S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sN7XphyPDpIa3iIHhdigBtcUe3R.jpg'),
(83709, 5826, 'O Chefinho: De Volta ao Berço S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AtpOvthbUDPWa793tKkZ7kkYZMh.jpg'),
(83710, 5826, 'O Chefinho: De Volta ao Berço S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cpOTeA6mmYYLBrr03EBPHsmHAEa.jpg'),
(83711, 5826, 'O Chefinho: De Volta ao Berço S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bYtJFq6vrVXT5gj4WnI927VIfGI.jpg'),
(83712, 5826, 'O Chefinho: De Volta ao Berço S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wYLZ1bJ5TxCShHCit3tP7Eku3Wd.jpg'),
(83713, 5827, 'O Sabor do Destino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181129.mp4', 'http://timg.bdta.pro/images/f84cec03447a0b51f0917d4610063617.jpg'),
(83714, 5827, 'O Sabor do Destino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181130.mp4', 'http://timg.bdta.pro/images/ed0218eb3ad56a71d5e2d3a161a16408.jpg'),
(83715, 5827, 'O Sabor do Destino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181131.mp4', 'http://timg.bdta.pro/images/e99679ae98f8462b7cacf569229c8d89.jpg'),
(83716, 5827, 'O Sabor do Destino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181132.mp4', 'http://gstaticontent.com/images/b6a7e18a217fb7abbc455630c0fa8252.jpg'),
(83717, 5827, 'O Sabor do Destino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181133.mp4', 'http://gstaticontent.com/images/b6a7e18a217fb7abbc455630c0fa8252.jpg'),
(83718, 5827, 'O Sabor do Destino S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181134.mp4', 'http://gstaticontent.com/images/b6a7e18a217fb7abbc455630c0fa8252.jpg'),
(83719, 5827, 'O Sabor do Destino S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181135.mp4', 'http://gstaticontent.com/images/b6a7e18a217fb7abbc455630c0fa8252.jpg'),
(83720, 5827, 'O Sabor do Destino S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181136.mp4', 'http://gstaticontent.com/images/b6a7e18a217fb7abbc455630c0fa8252.jpg'),
(83721, 5827, 'O Sabor do Destino S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181137.mp4', 'http://gstaticontent.com/images/b6a7e18a217fb7abbc455630c0fa8252.jpg'),
(83722, 5827, 'O Sabor do Destino S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181138.mp4', 'http://gstaticontent.com/images/b6a7e18a217fb7abbc455630c0fa8252.jpg'),
(83723, 5827, 'O Sabor do Destino S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/181139.mp4', 'http://gstaticontent.com/images/b6a7e18a217fb7abbc455630c0fa8252.jpg'),
(83724, 5827, 'O Sabor do Destino S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/181140.mp4', 'http://gstaticontent.com/images/b6a7e18a217fb7abbc455630c0fa8252.jpg'),
(83725, 5827, 'O Sabor do Destino S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/181141.mp4', 'http://gstaticontent.com/images/b6a7e18a217fb7abbc455630c0fa8252.jpg'),
(83726, 5827, 'O Sabor do Destino S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/181142.mp4', 'http://gstaticontent.com/images/b6a7e18a217fb7abbc455630c0fa8252.jpg'),
(83727, 5827, 'O Sabor do Destino S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/181143.mp4', 'http://gstaticontent.com/images/b6a7e18a217fb7abbc455630c0fa8252.jpg'),
(83728, 5827, 'O Sabor do Destino S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/181144.mp4', 'http://gstaticontent.com/images/b6a7e18a217fb7abbc455630c0fa8252.jpg'),
(83729, 5827, 'O Sabor do Destino S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/181145.mp4', 'http://gstaticontent.com/images/b6a7e18a217fb7abbc455630c0fa8252.jpg'),
(83730, 5828, 'Promised Land S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181119.mp4', 'http://timg.bdta.pro/images/fa452a7b0dc8b79685864440fa3c3ac1.jpg'),
(83731, 5828, 'Promised Land S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181120.mp4', 'http://timg.bdta.pro/images/7b96bbaeb08190a8bf28932d53d8156a.jpg'),
(83732, 5828, 'Promised Land S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181121.mp4', 'http://timg.bdta.pro/images/830dfb3704c1eac85623df451929834b.jpg'),
(83733, 5828, 'Promised Land S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181122.mp4', 'http://timg.bdta.pro/images/1b3b3b8cb4d15df8412997043c68b3ec.jpg'),
(83734, 5828, 'Promised Land S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181123.mp4', 'http://timg.bdta.pro/images/254dff577bc3146f494640fd858c75b1.jpg'),
(83735, 5828, 'Promised Land S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181124.mp4', 'http://timg.bdta.pro/images/0ab26450fec3b9b42f6bb5680eff2c30.jpg'),
(83736, 5828, 'Promised Land S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181125.mp4', 'http://timg.bdta.pro/images/61a46f289bcc9acb6b60a915e93631a3.jpg'),
(83737, 5828, 'Promised Land S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181126.mp4', 'http://timg.bdta.pro/images/2d8887248ed1e4f92b1bc5bf4de9edee.jpg'),
(83738, 5828, 'Promised Land S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181127.mp4', 'http://timg.bdta.pro/images/a90761d0db14ec2b904bd387b8841afa.jpg'),
(83739, 5828, 'Promised Land S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181128.mp4', 'http://gstaticontent.com/images/bfc874ddba5a81a4613fd7d75b9be36c.jpg'),
(83740, 5829, 'Sou Luna S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180819.mp4', 'http://timg.bdta.pro/images/9ec57a185cb0b3e05f1d84dab269b555.jpg'),
(83741, 5829, 'Sou Luna S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180820.mp4', 'http://timg.bdta.pro/images/630325b816be43765416fc8d4e75a760.jpg'),
(83742, 5829, 'Sou Luna S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180821.mp4', 'http://timg.bdta.pro/images/be5b5733633ad7de1d8113f012fbe30b.jpg'),
(83743, 5829, 'Sou Luna S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180822.mp4', 'http://timg.bdta.pro/images/4cdf035ef42ea6f6456d77ad96446345.jpg'),
(83744, 5829, 'Sou Luna S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180823.mp4', 'http://timg.bdta.pro/images/f68e8dba7e62ab5b34001711922d1551.jpg'),
(83745, 5829, 'Sou Luna S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180824.mp4', 'http://timg.bdta.pro/images/f324424ebb968a1b8d34fb411a3f3691.jpg'),
(83746, 5829, 'Sou Luna S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180825.mp4', 'http://timg.bdta.pro/images/8efca01563747f6bfcad7107a30f6c0a.jpg'),
(83747, 5829, 'Sou Luna S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180826.mp4', 'http://timg.bdta.pro/images/e9a9214e7c00e5b285b0bc47675daad9.jpg'),
(83748, 5829, 'Sou Luna S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180827.mp4', 'http://timg.bdta.pro/images/6802c48119446929bee26c7cda437225.jpg'),
(83749, 5829, 'Sou Luna S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180828.mp4', 'http://timg.bdta.pro/images/381e42372e18b623854e95293b40eab7.jpg'),
(83750, 5829, 'Sou Luna S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/180829.mp4', 'http://timg.bdta.pro/images/22a2198d6baa1baf616ddfd99e25199c.jpg'),
(83751, 5829, 'Sou Luna S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/180830.mp4', 'http://timg.bdta.pro/images/1a635e118e18d9e402aca9bb3c16a23e.jpg'),
(83752, 5829, 'Sou Luna S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/180831.mp4', 'http://timg.bdta.pro/images/f64278925128abfb0bd6cb9fcb45cd34.jpg'),
(83753, 5829, 'Sou Luna S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/180832.mp4', 'http://timg.bdta.pro/images/5fc913f9d9e812a50abbd2c134168e70.jpg'),
(83754, 5829, 'Sou Luna S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/180833.mp4', 'http://timg.bdta.pro/images/0d34ed36db71ded385c7290105360f0e.jpg'),
(83755, 5829, 'Sou Luna S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/180834.mp4', 'http://timg.bdta.pro/images/8d948c6e847c03ffd0d8382ddfba71d3.jpg'),
(83756, 5829, 'Sou Luna S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/180835.mp4', 'http://timg.bdta.pro/images/55592b3d2fb14ee9f95ec68d147b9ec0.jpg'),
(83757, 5829, 'Sou Luna S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/180836.mp4', 'http://timg.bdta.pro/images/7435d74f5a665d58be3fdbfb63810445.jpg'),
(83758, 5829, 'Sou Luna S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/180837.mp4', 'http://timg.bdta.pro/images/4be1f8291a77ad6aafdd7b77e1e50637.jpg'),
(83759, 5829, 'Sou Luna S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/180838.mp4', 'http://timg.bdta.pro/images/72f80130231742eb5f44a457340ef11a.jpg'),
(83760, 5829, 'Sou Luna S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/180839.mp4', 'http://timg.bdta.pro/images/311612336f58db6f206cde1d606ac148.jpg'),
(83761, 5829, 'Sou Luna S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/180840.mp4', 'http://timg.bdta.pro/images/e8180292f6f27f6293c2ac22b253503f.jpg'),
(83762, 5829, 'Sou Luna S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/180841.mp4', 'http://timg.bdta.pro/images/eb72c897954eef228bfde9a53b4dc455.jpg'),
(83763, 5829, 'Sou Luna S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/180842.mp4', 'http://timg.bdta.pro/images/e4c3e709dcfd2dcf934f9490e8f6cc65.jpg'),
(83764, 5829, 'Sou Luna S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/180843.mp4', 'http://timg.bdta.pro/images/8191db0a411fc4ed695d66f4fe4bc940.jpg'),
(83765, 5829, 'Sou Luna S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/180844.mp4', 'http://timg.bdta.pro/images/1c81036b658dab79ae4d1260c1e373be.jpg'),
(83766, 5829, 'Sou Luna S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/180845.mp4', 'http://timg.bdta.pro/images/c19fa0263fa2a12431bb2bd6418dbe9d.jpg'),
(83767, 5829, 'Sou Luna S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/180846.mp4', 'http://timg.bdta.pro/images/50f56626066dbfe07b09a4e4471f87eb.jpg'),
(83768, 5829, 'Sou Luna S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/180847.mp4', 'http://timg.bdta.pro/images/070aacd71bd01ed16b134d070b4f89ce.jpg'),
(83769, 5829, 'Sou Luna S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/180848.mp4', 'http://timg.bdta.pro/images/f720709495c632ae6bbf8891ce6fccd9.jpg'),
(83770, 5829, 'Sou Luna S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/180849.mp4', 'http://timg.bdta.pro/images/5db6ee04bb9acc0b774622ea966b6f11.jpg'),
(83771, 5829, 'Sou Luna S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/180850.mp4', 'http://timg.bdta.pro/images/87da17d2a66fae1bfb1c08fb59b762f8.jpg'),
(83772, 5829, 'Sou Luna S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/180851.mp4', 'http://timg.bdta.pro/images/1d48620c6073b1dce67f9d0dff21f83f.jpg'),
(83773, 5829, 'Sou Luna S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/180852.mp4', 'http://timg.bdta.pro/images/aa7c619f5b7b6afbee551c82788c7f35.jpg'),
(83774, 5829, 'Sou Luna S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/180853.mp4', 'http://timg.bdta.pro/images/01cc3981c09f1e09e28d460b02bdbafe.jpg'),
(83775, 5829, 'Sou Luna S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/180854.mp4', 'http://timg.bdta.pro/images/f2ad39a7deb004a342558ff0d47b2736.jpg'),
(83776, 5829, 'Sou Luna S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/180855.mp4', 'http://timg.bdta.pro/images/ec54ad2afb30ae55fe2d1539d9e04b03.jpg'),
(83777, 5829, 'Sou Luna S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/180856.mp4', 'http://timg.bdta.pro/images/4b1104a8d5cb6f845fa089f755220c28.jpg'),
(83778, 5829, 'Sou Luna S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/180857.mp4', 'http://timg.bdta.pro/images/f3d2a510993c4926a68514c40dc1a98f.jpg'),
(83779, 5829, 'Sou Luna S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/180858.mp4', 'http://timg.bdta.pro/images/66bd110d7a128d1ab1e6fbe5cf7cb95f.jpg'),
(83780, 5829, 'Sou Luna S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/180859.mp4', 'http://timg.bdta.pro/images/ec8e74412f5d2dca9b02067635175fea.jpg'),
(83781, 5829, 'Sou Luna S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/180860.mp4', 'http://timg.bdta.pro/images/97c56988fa6020e2f2d1849f41ba63d4.jpg'),
(83782, 5829, 'Sou Luna S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/180861.mp4', 'http://timg.bdta.pro/images/f40cf4dbb039243c9197050e28582da7.jpg'),
(83783, 5829, 'Sou Luna S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/180862.mp4', 'http://timg.bdta.pro/images/acc727112ceb58d838f1678a78c7bc4f.jpg'),
(83784, 5829, 'Sou Luna S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/180863.mp4', 'http://timg.bdta.pro/images/875d422d0cd9e7dc477c2b63555def93.jpg'),
(83785, 5829, 'Sou Luna S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/180864.mp4', 'http://timg.bdta.pro/images/a5a1a260e69d7e612af0ab53d5e581f1.jpg'),
(83786, 5829, 'Sou Luna S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/180865.mp4', 'http://timg.bdta.pro/images/031c639cbc79854b9159c42db8579311.jpg'),
(83787, 5829, 'Sou Luna S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/180866.mp4', 'http://timg.bdta.pro/images/6438160f609a858b812d8bee6b42ec21.jpg'),
(83788, 5829, 'Sou Luna S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/180867.mp4', 'http://timg.bdta.pro/images/d9c7c590629d2e5a6a715a5312e3932b.jpg'),
(83789, 5829, 'Sou Luna S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/180868.mp4', 'http://timg.bdta.pro/images/29d82ec031e313c8684dafe9f7898993.jpg'),
(83790, 5829, 'Sou Luna S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/180869.mp4', 'http://timg.bdta.pro/images/9b1719d92b3b516480ef4916b33e52bf.jpg'),
(83791, 5829, 'Sou Luna S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/180870.mp4', 'http://timg.bdta.pro/images/3abadd920c708c7493767c5acdba4c69.jpg'),
(83792, 5829, 'Sou Luna S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/180871.mp4', 'http://timg.bdta.pro/images/c23ab18c5ddd061e5a6903675b5eb039.jpg'),
(83793, 5829, 'Sou Luna S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/180872.mp4', 'http://timg.bdta.pro/images/ac3c0721889713ed9761577bdcd2676d.jpg'),
(83794, 5829, 'Sou Luna S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/180873.mp4', 'http://timg.bdta.pro/images/a024f165c60fb2cac4f3c8c7eca05070.jpg'),
(83795, 5829, 'Sou Luna S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/180874.mp4', 'http://timg.bdta.pro/images/5030bc8f77053fdabb131f28a3f7351d.jpg'),
(83796, 5829, 'Sou Luna S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/180875.mp4', 'http://timg.bdta.pro/images/3abadd920c708c7493767c5acdba4c69.jpg'),
(83797, 5829, 'Sou Luna S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/180876.mp4', 'http://timg.bdta.pro/images/f797d951651086c186775473e347a3ea.jpg'),
(83798, 5829, 'Sou Luna S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/180877.mp4', 'http://timg.bdta.pro/images/75a628bdaf66e47a99b55749f53b6c2e.jpg'),
(83799, 5829, 'Sou Luna S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/180878.mp4', 'http://timg.bdta.pro/images/2b8b87fdec710b8291f2a2951403c758.jpg'),
(83800, 5829, 'Sou Luna S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/180879.mp4', 'http://timg.bdta.pro/images/dc26444c63c88866cb5e3f114fb71ce5.jpg'),
(83801, 5829, 'Sou Luna S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/180880.mp4', 'http://timg.bdta.pro/images/40b8b3cd3ccf27fc678339fb10b6d351.jpg'),
(83802, 5829, 'Sou Luna S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/180881.mp4', 'http://timg.bdta.pro/images/c12104c25fc53e1e7a31b14175d42f50.jpg'),
(83803, 5829, 'Sou Luna S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/180882.mp4', 'http://timg.bdta.pro/images/6280a728933f98db97b886be77ef85b0.jpg'),
(83804, 5829, 'Sou Luna S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/180883.mp4', 'http://timg.bdta.pro/images/9ba6a4b970ae6d1afd0e231660e9ba3d.jpg'),
(83805, 5829, 'Sou Luna S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/180884.mp4', 'http://timg.bdta.pro/images/1bfeb49a6dc511cf21b0b5c9aedea730.jpg'),
(83806, 5829, 'Sou Luna S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/180885.mp4', 'http://timg.bdta.pro/images/ab916cb97d9dd52a174a45bc26919dca.jpg'),
(83807, 5829, 'Sou Luna S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/180886.mp4', 'http://timg.bdta.pro/images/8e3d39c4d6a4d36df7e2feaee0f05258.jpg'),
(83808, 5829, 'Sou Luna S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/180887.mp4', 'http://timg.bdta.pro/images/bb23009b2627654799699c2c569f4a0f.jpg'),
(83809, 5829, 'Sou Luna S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/180888.mp4', 'http://timg.bdta.pro/images/56b27ada0fbce0892ebc508504957906.jpg'),
(83810, 5829, 'Sou Luna S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/180889.mp4', 'http://timg.bdta.pro/images/a597d136c5df147ce6d843c07cca8eb1.jpg'),
(83811, 5829, 'Sou Luna S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/180890.mp4', 'http://timg.bdta.pro/images/892ee36aecb72eae3734a48556d1b620.jpg'),
(83812, 5829, 'Sou Luna S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/180891.mp4', 'http://timg.bdta.pro/images/aed0d6d8d81ebfb11283366f5da27d1c.jpg'),
(83813, 5829, 'Sou Luna S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/180892.mp4', 'http://timg.bdta.pro/images/18251680215d17258191c4af9b274aa5.jpg'),
(83814, 5829, 'Sou Luna S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/180893.mp4', 'http://timg.bdta.pro/images/d7af9224a1c88c7cfd326c5f6a2b3dbe.jpg'),
(83815, 5829, 'Sou Luna S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/180894.mp4', 'http://timg.bdta.pro/images/10115a2f7686b74fe2cb7c5b336066de.jpg'),
(83816, 5829, 'Sou Luna S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/180895.mp4', 'http://timg.bdta.pro/images/62eb29e2189342d4f42e83e508018c8b.jpg'),
(83817, 5829, 'Sou Luna S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/180896.mp4', 'http://timg.bdta.pro/images/437d58ecfefb09073eae67e179095234.jpg'),
(83818, 5829, 'Sou Luna S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/180897.mp4', 'http://timg.bdta.pro/images/28378fdfd6cc63d882a85a2095963a6c.jpg'),
(83819, 5829, 'Sou Luna S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/180898.mp4', 'http://timg.bdta.pro/images/e3c572c050880bed708223233963e713.jpg'),
(83820, 5830, 'Sou Luna S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180899.mp4', 'http://timg.bdta.pro/images/3dedd3eb1cabd053ca0f62dcf99206fc.jpg'),
(83821, 5830, 'Sou Luna S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180900.mp4', 'http://timg.bdta.pro/images/d0fc0f847d7c89344b342fe6d5cdea23.jpg'),
(83822, 5830, 'Sou Luna S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180901.mp4', 'http://timg.bdta.pro/images/3e4ddd0c52bad2cf5f0bca7bab346fb2.jpg'),
(83823, 5830, 'Sou Luna S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180902.mp4', 'http://timg.bdta.pro/images/6a58c4cb1e0962250251f82181b7af19.jpg'),
(83824, 5830, 'Sou Luna S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180903.mp4', 'http://timg.bdta.pro/images/5410aec2896e390bd304b134d7e26d6b.jpg'),
(83825, 5830, 'Sou Luna S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180904.mp4', 'http://timg.bdta.pro/images/48460f82df0aa19cf06a38e2a01cc2ea.jpg'),
(83826, 5830, 'Sou Luna S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180905.mp4', 'http://timg.bdta.pro/images/97759e837c4825367818fde287664055.jpg'),
(83827, 5830, 'Sou Luna S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180906.mp4', 'http://timg.bdta.pro/images/b67fc05ae645d2bad48cda61aede47a2.jpg'),
(83828, 5830, 'Sou Luna S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180907.mp4', 'http://timg.bdta.pro/images/bbe909df5d2be7b19e2a711fec75941b.jpg'),
(83829, 5830, 'Sou Luna S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180908.mp4', 'http://timg.bdta.pro/images/51c1690ab0f4c2a1feb0f8cb29b8d27a.jpg'),
(83830, 5830, 'Sou Luna S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/180909.mp4', 'http://timg.bdta.pro/images/3499d4cec7946cd267627eabff995c12.jpg'),
(83831, 5830, 'Sou Luna S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/180910.mp4', 'http://timg.bdta.pro/images/b4bdaf273ca208dc2ee4c9f2c2415200.jpg'),
(83832, 5830, 'Sou Luna S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/180911.mp4', 'http://timg.bdta.pro/images/43216868e6c54bc54581983a52516046.jpg'),
(83833, 5830, 'Sou Luna S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/180912.mp4', 'http://timg.bdta.pro/images/6e98d1716654d31d349b7d482f66291a.jpg'),
(83834, 5830, 'Sou Luna S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/180913.mp4', 'http://timg.bdta.pro/images/ed3b9d6d8dfbfc4acff4df36df41a3bf.jpg'),
(83835, 5830, 'Sou Luna S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/180914.mp4', 'http://timg.bdta.pro/images/a2f733381ccb798df680b6061d2eb202.jpg'),
(83836, 5830, 'Sou Luna S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/180915.mp4', 'http://timg.bdta.pro/images/3b98f88849b8bc06af534c1b509ddd1a.jpg'),
(83837, 5830, 'Sou Luna S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/180916.mp4', 'http://timg.bdta.pro/images/91421e11997cf8bc7371e63ead8f3558.jpg'),
(83838, 5830, 'Sou Luna S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/180917.mp4', 'http://timg.bdta.pro/images/75c34cb80284a0ef892a2e63ba227a23.jpg'),
(83839, 5830, 'Sou Luna S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/180918.mp4', 'http://timg.bdta.pro/images/49c868dc2a7293cad23bc5cad7f0e405.jpg'),
(83840, 5830, 'Sou Luna S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/180919.mp4', 'http://timg.bdta.pro/images/01d68afa3a3155a89bd1dcd446427c8e.jpg'),
(83841, 5830, 'Sou Luna S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/180920.mp4', 'http://timg.bdta.pro/images/df7442e47141d156646096665e2df13c.jpg'),
(83842, 5830, 'Sou Luna S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/180921.mp4', 'http://timg.bdta.pro/images/1e637acf8da71a6c91e9c96e5fbdfef0.jpg'),
(83843, 5830, 'Sou Luna S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/180922.mp4', 'http://timg.bdta.pro/images/3526c7206e0532c97d01341bbf5ca368.jpg'),
(83844, 5830, 'Sou Luna S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/180923.mp4', 'http://timg.bdta.pro/images/363aaa7eb84e7c56703a4e09b89d6e51.jpg'),
(83845, 5830, 'Sou Luna S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/180924.mp4', 'http://timg.bdta.pro/images/0385c54bdc2358a4efebca6a552517f4.jpg'),
(83846, 5830, 'Sou Luna S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/180925.mp4', 'http://timg.bdta.pro/images/08d8c79a69e8473de391a7eb78aed14e.jpg'),
(83847, 5830, 'Sou Luna S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/180926.mp4', 'http://timg.bdta.pro/images/e76e2d86c1dd67d04c9fbaef4d2a680b.jpg'),
(83848, 5830, 'Sou Luna S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/180927.mp4', 'http://timg.bdta.pro/images/3b205041e3037ddc5e9460297aec3221.jpg'),
(83849, 5830, 'Sou Luna S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/180928.mp4', 'http://timg.bdta.pro/images/0ba0cba7c39788b47dd0c6486f99ac8d.jpg'),
(83850, 5830, 'Sou Luna S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/180929.mp4', 'http://timg.bdta.pro/images/4daf076a4a73159755e9e89e98536650.jpg'),
(83851, 5830, 'Sou Luna S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/180930.mp4', 'http://timg.bdta.pro/images/bd79822ff5bc733bdffbfa22e21f529c.jpg'),
(83852, 5830, 'Sou Luna S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/180931.mp4', 'http://timg.bdta.pro/images/a5f9b466d0add18a7d8cd85eee10eeb4.jpg'),
(83853, 5830, 'Sou Luna S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/180932.mp4', 'http://timg.bdta.pro/images/9fdf3eb59243706ff95d408e1af08064.jpg'),
(83854, 5830, 'Sou Luna S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/180933.mp4', 'http://timg.bdta.pro/images/019c7558e360cae178ac7beace7c2499.jpg'),
(83855, 5830, 'Sou Luna S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/180934.mp4', 'http://timg.bdta.pro/images/4b73d59c8f440ffcf1df7d5b8da473bb.jpg'),
(83856, 5830, 'Sou Luna S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/180935.mp4', 'http://timg.bdta.pro/images/c721c7427d141d84f80b310179bce2f5.jpg'),
(83857, 5830, 'Sou Luna S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/180936.mp4', 'http://timg.bdta.pro/images/0743a19a0767df38ea5e11d7384c71d4.jpg'),
(83858, 5830, 'Sou Luna S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/180937.mp4', 'http://timg.bdta.pro/images/6b447076e81ef9be963580c9a09541ee.jpg'),
(83859, 5830, 'Sou Luna S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/180938.mp4', 'http://timg.bdta.pro/images/a5f4ebc4a4db94ec2f9b2f69904cef8d.jpg'),
(83860, 5830, 'Sou Luna S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/180939.mp4', 'http://timg.bdta.pro/images/af80713033e7d40cfc080a31dccac0f7.jpg'),
(83861, 5830, 'Sou Luna S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/180940.mp4', 'http://timg.bdta.pro/images/29d081f1f130c3ea4c244b3dc9aceadc.jpg'),
(83862, 5830, 'Sou Luna S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/180941.mp4', 'http://timg.bdta.pro/images/462372704c3806c2528c97c5b159ba49.jpg'),
(83863, 5830, 'Sou Luna S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/180942.mp4', 'http://timg.bdta.pro/images/7422bd412c7bd1e472b07e2a7365f61b.jpg'),
(83864, 5830, 'Sou Luna S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/180943.mp4', 'http://timg.bdta.pro/images/7c196a65962286c13dcf4297cc4dbbf0.jpg'),
(83865, 5830, 'Sou Luna S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/180944.mp4', 'http://timg.bdta.pro/images/2726bfddac1426873914abfba6c3f2e5.jpg'),
(83866, 5830, 'Sou Luna S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/180945.mp4', 'http://timg.bdta.pro/images/b048d6c68177a3d9983e80fe15ad0f48.jpg'),
(83867, 5830, 'Sou Luna S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/180946.mp4', 'http://timg.bdta.pro/images/9fc6bd2bbe41149365ecded8200fb0c6.jpg'),
(83868, 5830, 'Sou Luna S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/180947.mp4', 'http://timg.bdta.pro/images/2c968a4a19baaccfa6a956ef8b833355.jpg'),
(83869, 5830, 'Sou Luna S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/180948.mp4', 'http://timg.bdta.pro/images/d97b6f0f799e6d315a6589fc3199150c.jpg'),
(83870, 5830, 'Sou Luna S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/180949.mp4', 'http://timg.bdta.pro/images/77a16a677ad492de8be59f42283a5a60.jpg'),
(83871, 5830, 'Sou Luna S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/180950.mp4', 'http://timg.bdta.pro/images/96fbdf02e918556b485cdabc636eac36.jpg'),
(83872, 5830, 'Sou Luna S02 E53', 'http://sinalprivado.info:80/series/1533784/1533784/180951.mp4', 'http://timg.bdta.pro/images/4ad75c75c51cc41ab05952221b2c00b3.jpg'),
(83873, 5830, 'Sou Luna S02 E54', 'http://sinalprivado.info:80/series/1533784/1533784/180952.mp4', 'http://timg.bdta.pro/images/97547bdbe19e7e1eef7fd2cc42274c21.jpg'),
(83874, 5830, 'Sou Luna S02 E55', 'http://sinalprivado.info:80/series/1533784/1533784/180953.mp4', 'http://timg.bdta.pro/images/65dd2c198473a4aab17f820e23900a48.jpg'),
(83875, 5830, 'Sou Luna S02 E56', 'http://sinalprivado.info:80/series/1533784/1533784/180954.mp4', 'http://timg.bdta.pro/images/597480be8c207fd60337df7c5079d56e.jpg'),
(83876, 5830, 'Sou Luna S02 E57', 'http://sinalprivado.info:80/series/1533784/1533784/180955.mp4', 'http://timg.bdta.pro/images/0af1aafa58ee82186bd38fbdff7b094c.jpg'),
(83877, 5830, 'Sou Luna S02 E58', 'http://sinalprivado.info:80/series/1533784/1533784/562454.mp4', 'http://gstaticontent.com/images/73b958ee71c0201ff998dc18c1dc312c.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(83878, 5830, 'Sou Luna S02 E59', 'http://sinalprivado.info:80/series/1533784/1533784/180957.mp4', 'http://timg.bdta.pro/images/ab066a17c5b77b1600a885bdc4aaaf85.jpg'),
(83879, 5830, 'Sou Luna S02 E60', 'http://sinalprivado.info:80/series/1533784/1533784/180958.mp4', 'http://timg.bdta.pro/images/ad5eb1b548ff276e5a39a9fa9e3f80e9.jpg'),
(83880, 5830, 'Sou Luna S02 E61', 'http://sinalprivado.info:80/series/1533784/1533784/180959.mp4', 'http://timg.bdta.pro/images/130453e4ca2e58e4aeb3874eb4fcde08.jpg'),
(83881, 5830, 'Sou Luna S02 E62', 'http://sinalprivado.info:80/series/1533784/1533784/180960.mp4', 'http://timg.bdta.pro/images/b39d790d85d9accbe8d9492b7599f992.jpg'),
(83882, 5830, 'Sou Luna S02 E63', 'http://sinalprivado.info:80/series/1533784/1533784/180961.mp4', 'http://timg.bdta.pro/images/2ed4f2ef64bac5c86b26a999a3ebbe35.jpg'),
(83883, 5830, 'Sou Luna S02 E64', 'http://sinalprivado.info:80/series/1533784/1533784/180962.mp4', 'http://timg.bdta.pro/images/3c2d4b6d9e84d4d17bc5bd188a9b79da.jpg'),
(83884, 5830, 'Sou Luna S02 E65', 'http://sinalprivado.info:80/series/1533784/1533784/180963.mp4', 'http://timg.bdta.pro/images/e2ac6c5076d4c945af3b9ffc822d545e.jpg'),
(83885, 5830, 'Sou Luna S02 E66', 'http://sinalprivado.info:80/series/1533784/1533784/180964.mp4', 'http://timg.bdta.pro/images/a852beba3df3206707ef0fe05c23d123.jpg'),
(83886, 5830, 'Sou Luna S02 E67', 'http://sinalprivado.info:80/series/1533784/1533784/180965.mp4', 'http://timg.bdta.pro/images/397048619502a06243a67ccd7589a128.jpg'),
(83887, 5830, 'Sou Luna S02 E68', 'http://sinalprivado.info:80/series/1533784/1533784/180966.mp4', 'http://timg.bdta.pro/images/bc901fe82004e2bfeec78e72f21d3e67.jpg'),
(83888, 5830, 'Sou Luna S02 E69', 'http://sinalprivado.info:80/series/1533784/1533784/180967.mp4', 'http://timg.bdta.pro/images/4e3141dd53937bd824ce6411fe415d4c.jpg'),
(83889, 5830, 'Sou Luna S02 E70', 'http://sinalprivado.info:80/series/1533784/1533784/180968.mp4', 'http://timg.bdta.pro/images/4e3141dd53937bd824ce6411fe415d4c.jpg'),
(83890, 5830, 'Sou Luna S02 E71', 'http://sinalprivado.info:80/series/1533784/1533784/180969.mp4', 'http://timg.bdta.pro/images/933af91207c9916da72bdc84e31761de.jpg'),
(83891, 5830, 'Sou Luna S02 E72', 'http://sinalprivado.info:80/series/1533784/1533784/180970.mp4', 'http://timg.bdta.pro/images/5938b254ac756ee568977aa5a483d134.jpg'),
(83892, 5830, 'Sou Luna S02 E73', 'http://sinalprivado.info:80/series/1533784/1533784/180971.mp4', 'http://timg.bdta.pro/images/a2872e99696fd2e3b76bb3b5efdaa725.jpg'),
(83893, 5830, 'Sou Luna S02 E74', 'http://sinalprivado.info:80/series/1533784/1533784/180972.mp4', 'http://timg.bdta.pro/images/ba3fccd91d08a1c8c4e0f342ca5dbf31.jpg'),
(83894, 5830, 'Sou Luna S02 E75', 'http://sinalprivado.info:80/series/1533784/1533784/180973.mp4', 'http://timg.bdta.pro/images/cdf1227682c1297fd4199ed786643071.jpg'),
(83895, 5830, 'Sou Luna S02 E76', 'http://sinalprivado.info:80/series/1533784/1533784/180974.mp4', 'http://timg.bdta.pro/images/8a21aba2b4b5e4612c2b5ac652ddade0.jpg'),
(83896, 5830, 'Sou Luna S02 E77', 'http://sinalprivado.info:80/series/1533784/1533784/180975.mp4', 'http://timg.bdta.pro/images/6eb626fe056bb5800ffd2d0a48bf3190.jpg'),
(83897, 5830, 'Sou Luna S02 E78', 'http://sinalprivado.info:80/series/1533784/1533784/180976.mp4', 'http://timg.bdta.pro/images/a846288d251f723d3fab7bc909ac9b77.jpg'),
(83898, 5830, 'Sou Luna S02 E79', 'http://sinalprivado.info:80/series/1533784/1533784/180977.mp4', 'http://timg.bdta.pro/images/26f3dda5bfe877186804454b75ebfaa5.jpg'),
(83899, 5830, 'Sou Luna S02 E80', 'http://sinalprivado.info:80/series/1533784/1533784/180978.mp4', 'http://timg.bdta.pro/images/0905cbd46f3504c5db6d07412057e33f.jpg'),
(83900, 5831, 'Sou Luna S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180979.mp4', 'http://timg.bdta.pro/images/c477d9ed666e230ebcb5bb0c11667470.jpg'),
(83901, 5831, 'Sou Luna S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180980.mp4', 'http://timg.bdta.pro/images/90fdf9a31008ad4d513e79dd953a639f.jpg'),
(83902, 5831, 'Sou Luna S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180981.mp4', 'http://timg.bdta.pro/images/b6e1aebfe8335affd6809c1dfb3af17c.jpg'),
(83903, 5831, 'Sou Luna S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180982.mp4', 'http://timg.bdta.pro/images/944a8b6094ddadb82f7f258b3e6c4f2f.jpg'),
(83904, 5831, 'Sou Luna S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180983.mp4', 'http://timg.bdta.pro/images/886e89360565f6166ebdeaa36eb21467.jpg'),
(83905, 5831, 'Sou Luna S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180984.mp4', 'http://timg.bdta.pro/images/5ea763f7e108e2a7b9d21accacb8bda3.jpg'),
(83906, 5831, 'Sou Luna S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180985.mp4', 'http://timg.bdta.pro/images/d2e80028b0e93b4eb4436cbcd3b75088.jpg'),
(83907, 5831, 'Sou Luna S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180986.mp4', 'http://timg.bdta.pro/images/96f3905af0a8b589b3e0b232ca8f44eb.jpg'),
(83908, 5831, 'Sou Luna S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180987.mp4', 'http://timg.bdta.pro/images/80df2e08eed801bf7e604eb4b5b7b40c.jpg'),
(83909, 5831, 'Sou Luna S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180988.mp4', 'http://timg.bdta.pro/images/4b771cdf41ae0f13f83ff2d21cafca8e.jpg'),
(83910, 5831, 'Sou Luna S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/180989.mp4', 'http://timg.bdta.pro/images/0817897a0f3eba84af01ef74d92fff83.jpg'),
(83911, 5831, 'Sou Luna S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/180990.mp4', 'http://timg.bdta.pro/images/c176f264b424c944de75454afcf75e26.jpg'),
(83912, 5831, 'Sou Luna S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/180991.mp4', 'http://timg.bdta.pro/images/eb5914eac2d3cc384b329bde3b8e8b60.jpg'),
(83913, 5831, 'Sou Luna S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/180992.mp4', 'http://timg.bdta.pro/images/5a0ea5f00908c92cfe40278f86809ae3.jpg'),
(83914, 5831, 'Sou Luna S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/180993.mp4', 'http://timg.bdta.pro/images/172860eb494ba1f3b79845b6f86af273.jpg'),
(83915, 5831, 'Sou Luna S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/180994.mp4', 'http://timg.bdta.pro/images/4c72724d24a388474494ea3ae46401e8.jpg'),
(83916, 5831, 'Sou Luna S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/180995.mp4', 'http://timg.bdta.pro/images/bffa9a4e23d035f875c1adff8689c939.jpg'),
(83917, 5831, 'Sou Luna S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/180996.mp4', 'http://timg.bdta.pro/images/ed8a64090bce5747b2e3a5f187fbdc44.jpg'),
(83918, 5831, 'Sou Luna S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/180997.mp4', 'http://timg.bdta.pro/images/68a4188fc4a0a151f1da884e0b5b8825.jpg'),
(83919, 5831, 'Sou Luna S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/180998.mp4', 'http://timg.bdta.pro/images/1b36773a03a0275f5638cd9ef7f7aee6.jpg'),
(83920, 5831, 'Sou Luna S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/180999.mp4', 'http://timg.bdta.pro/images/3bda1fe1118585c3f5ae8ef104199d80.jpg'),
(83921, 5831, 'Sou Luna S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/181000.mp4', 'http://timg.bdta.pro/images/38693b88527eee1fbed32536fbfb7100.jpg'),
(83922, 5831, 'Sou Luna S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/181001.mp4', 'http://timg.bdta.pro/images/7cd4b3ccaf93d018afaea58a954088d4.jpg'),
(83923, 5831, 'Sou Luna S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/181002.mp4', 'http://timg.bdta.pro/images/d604540598e012d95173e215d9081b67.jpg'),
(83924, 5831, 'Sou Luna S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/181003.mp4', 'http://timg.bdta.pro/images/4a0cc3bd03ae8855926b82988e44cfe5.jpg'),
(83925, 5831, 'Sou Luna S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/181004.mp4', 'http://timg.bdta.pro/images/c056e8f292052edcffaa2e1c6eac45aa.jpg'),
(83926, 5831, 'Sou Luna S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/181005.mp4', 'http://timg.bdta.pro/images/80e4bfdbdddc63e7185c6eca255eabdd.jpg'),
(83927, 5831, 'Sou Luna S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/181006.mp4', 'http://timg.bdta.pro/images/301e33a542d0b141b135eae3831e000a.jpg'),
(83928, 5831, 'Sou Luna S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/181007.mp4', 'http://timg.bdta.pro/images/5f70e412bbf33e5b35778293532a7a53.jpg'),
(83929, 5831, 'Sou Luna S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/181008.mp4', 'http://timg.bdta.pro/images/2e207a0b8e5a9e9e01192d61a5552c8c.jpg'),
(83930, 5831, 'Sou Luna S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/181009.mp4', 'http://timg.bdta.pro/images/9d1275a20fa056d3017099c31126a15b.jpg'),
(83931, 5831, 'Sou Luna S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/181010.mp4', 'http://timg.bdta.pro/images/c8d8507d83a16db5e730de2eaea5046f.jpg'),
(83932, 5831, 'Sou Luna S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/181011.mp4', 'http://timg.bdta.pro/images/9a3c10c2d8d4c94807c8eb9b0ec7f3a6.jpg'),
(83933, 5831, 'Sou Luna S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/181012.mp4', 'http://timg.bdta.pro/images/36c73c3e6e2de934f7b9542f6f946a5a.jpg'),
(83934, 5831, 'Sou Luna S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/181013.mp4', 'http://timg.bdta.pro/images/8255873c85bc935f76a1c6268256c4d1.jpg'),
(83935, 5831, 'Sou Luna S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/181014.mp4', 'http://timg.bdta.pro/images/bb9390afcfee70e38bb66fe18875bb93.jpg'),
(83936, 5831, 'Sou Luna S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/181015.mp4', 'http://timg.bdta.pro/images/2feb8ac192599d02392a66a2fecd92b6.jpg'),
(83937, 5831, 'Sou Luna S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/181016.mp4', 'http://timg.bdta.pro/images/622f2eafd967a13fe5bb60425238f05c.jpg'),
(83938, 5831, 'Sou Luna S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/181017.mp4', 'http://timg.bdta.pro/images/d7fc91b0e2753bb616afe82fe61f2ce3.jpg'),
(83939, 5831, 'Sou Luna S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/181018.mp4', 'http://timg.bdta.pro/images/083a3598480815bf55accd9cb3c4afb1.jpg'),
(83940, 5831, 'Sou Luna S03 E41', 'http://sinalprivado.info:80/series/1533784/1533784/181019.mp4', 'http://timg.bdta.pro/images/7b07f151aef4b5632a2abf1f9587b3e9.jpg'),
(83941, 5831, 'Sou Luna S03 E42', 'http://sinalprivado.info:80/series/1533784/1533784/181020.mp4', 'http://timg.bdta.pro/images/416f6cf5cdafed9d4bd248a8c2c5d662.jpg'),
(83942, 5831, 'Sou Luna S03 E43', 'http://sinalprivado.info:80/series/1533784/1533784/181021.mp4', 'http://timg.bdta.pro/images/2213748071f3ed8f444a9873ec7007c1.jpg'),
(83943, 5831, 'Sou Luna S03 E44', 'http://sinalprivado.info:80/series/1533784/1533784/181022.mp4', 'http://timg.bdta.pro/images/2213748071f3ed8f444a9873ec7007c1.jpg'),
(83944, 5831, 'Sou Luna S03 E45', 'http://sinalprivado.info:80/series/1533784/1533784/181023.mp4', 'http://timg.bdta.pro/images/2272fc732056e80098a280e7de5e8843.jpg'),
(83945, 5831, 'Sou Luna S03 E46', 'http://sinalprivado.info:80/series/1533784/1533784/181024.mp4', 'http://timg.bdta.pro/images/49ad06d8184c823aaec02e8b870b5e38.jpg'),
(83946, 5831, 'Sou Luna S03 E47', 'http://sinalprivado.info:80/series/1533784/1533784/181025.mp4', 'http://timg.bdta.pro/images/00fc7e0e6213c3f840e45740fee766a3.jpg'),
(83947, 5831, 'Sou Luna S03 E48', 'http://sinalprivado.info:80/series/1533784/1533784/181026.mp4', 'http://timg.bdta.pro/images/37ce6de292b0a25380c7663ad7121a26.jpg'),
(83948, 5831, 'Sou Luna S03 E49', 'http://sinalprivado.info:80/series/1533784/1533784/181027.mp4', 'http://timg.bdta.pro/images/6531e25ea3a7e1ab2a30d85768258074.jpg'),
(83949, 5831, 'Sou Luna S03 E50', 'http://sinalprivado.info:80/series/1533784/1533784/181028.mp4', 'http://timg.bdta.pro/images/40c6a740980963e9a1aa9e64bbcecb48.jpg'),
(83950, 5831, 'Sou Luna S03 E51', 'http://sinalprivado.info:80/series/1533784/1533784/181029.mp4', 'http://timg.bdta.pro/images/d85baab2bd66417d971dcfd79d33759f.jpg'),
(83951, 5831, 'Sou Luna S03 E52', 'http://sinalprivado.info:80/series/1533784/1533784/181030.mp4', 'http://timg.bdta.pro/images/c4b81508ffb7a664037b2005741cee08.jpg'),
(83952, 5831, 'Sou Luna S03 E53', 'http://sinalprivado.info:80/series/1533784/1533784/181031.mp4', 'http://timg.bdta.pro/images/5560482443190152f7e08ef37d05445b.jpg'),
(83953, 5831, 'Sou Luna S03 E54', 'http://sinalprivado.info:80/series/1533784/1533784/181032.mp4', 'http://timg.bdta.pro/images/f0c516b76d43bcd64997aeffacb898e2.jpg'),
(83954, 5831, 'Sou Luna S03 E55', 'http://sinalprivado.info:80/series/1533784/1533784/181033.mp4', 'http://timg.bdta.pro/images/783b09c93f47b5b359e1346827cc7d52.jpg'),
(83955, 5831, 'Sou Luna S03 E56', 'http://sinalprivado.info:80/series/1533784/1533784/181034.mp4', 'http://timg.bdta.pro/images/d50aeba137a06bbba73db0715b0dc364.jpg'),
(83956, 5831, 'Sou Luna S03 E57', 'http://sinalprivado.info:80/series/1533784/1533784/181035.mp4', 'http://timg.bdta.pro/images/ddd9566970828aa501532213b84784a0.jpg'),
(83957, 5831, 'Sou Luna S03 E58', 'http://sinalprivado.info:80/series/1533784/1533784/181036.mp4', 'http://timg.bdta.pro/images/fe21c40d90e9cce35d4bf74b84535d11.jpg'),
(83958, 5831, 'Sou Luna S03 E59', 'http://sinalprivado.info:80/series/1533784/1533784/181037.mp4', 'http://timg.bdta.pro/images/62fe16feec6008faaf81d29f7239b980.jpg'),
(83959, 5831, 'Sou Luna S03 E60', 'http://sinalprivado.info:80/series/1533784/1533784/181038.mp4', 'http://timg.bdta.pro/images/ee3c11faa1c13eae8df164aeadb06409.jpg'),
(83960, 5832, 'Galera do Barulho S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181087.mp4', 'http://timg.bdta.pro/images/cc1bf5f710fd5b79485de2339f5bbe29.jpg'),
(83961, 5832, 'Galera do Barulho S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181088.mp4', 'http://timg.bdta.pro/images/2878a462baf4de00fa4e45c2c29030d2.jpg'),
(83962, 5832, 'Galera do Barulho S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181089.mp4', 'http://timg.bdta.pro/images/c5851d59cd2d1992f49b9d30888c3787.jpg'),
(83963, 5832, 'Galera do Barulho S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181090.mp4', 'http://timg.bdta.pro/images/67da5292b101d90466baf3398a6614d1.jpg'),
(83964, 5832, 'Galera do Barulho S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181091.mp4', 'http://timg.bdta.pro/images/417dd39301f6674dc2b66afa6b533458.jpg'),
(83965, 5832, 'Galera do Barulho S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181092.mp4', 'http://timg.bdta.pro/images/9b2c1019b67f0a1419f323544db5251f.jpg'),
(83966, 5832, 'Galera do Barulho S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181093.mp4', 'http://timg.bdta.pro/images/c1adb37e5e6735e94fb19b8adae5e811.jpg'),
(83967, 5832, 'Galera do Barulho S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181094.mp4', 'http://timg.bdta.pro/images/54d4d5a49913c126a32d96041d02633b.jpg'),
(83968, 5832, 'Galera do Barulho S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181095.mp4', 'http://timg.bdta.pro/images/ca34f393009f811db3410a72537e237e.jpg'),
(83969, 5832, 'Galera do Barulho S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181096.mp4', 'http://timg.bdta.pro/images/3f4da0ec903d8ffc51a67a016d6513bd.jpg'),
(83970, 5833, 'Galera do Barulho S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181097.mp4', 'http://timg.bdta.pro/images/b53c2447fbfa86e20d1eda1c2370f53b.jpg'),
(83971, 5833, 'Galera do Barulho S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181098.mp4', 'http://timg.bdta.pro/images/1e0d1a11fba2e0dd3114dc057e90788a.jpg'),
(83972, 5833, 'Galera do Barulho S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181099.mp4', 'http://timg.bdta.pro/images/c03f2eefe0aad8269b9a1abd9f8bab61.jpg'),
(83973, 5833, 'Galera do Barulho S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181100.mp4', 'http://timg.bdta.pro/images/89fd68ec020401e3a85b4ce5a3ec4c76.jpg'),
(83974, 5833, 'Galera do Barulho S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181101.mp4', 'http://timg.bdta.pro/images/000388b6923816322792f96d5b9149f8.jpg'),
(83975, 5833, 'Galera do Barulho S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181102.mp4', 'http://timg.bdta.pro/images/9a24a4bc950dae9dada684587395accd.jpg'),
(83976, 5833, 'Galera do Barulho S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181103.mp4', 'http://timg.bdta.pro/images/5563c87612998b934bd9622cff6a074d.jpg'),
(83977, 5833, 'Galera do Barulho S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181104.mp4', 'http://timg.bdta.pro/images/d9d048ce5f5eb8103956b3c1dbebfdc0.jpg'),
(83978, 5833, 'Galera do Barulho S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181105.mp4', 'http://timg.bdta.pro/images/4a4c730f5a854cc946776f9a7995b477.jpg'),
(83979, 5833, 'Galera do Barulho S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181106.mp4', 'http://timg.bdta.pro/images/acbb461b645db0dffc5236b32fabe52a.jpg'),
(83980, 5834, 'Casão: Num Jogo Sem Regras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180815.mp4', 'http://gstaticontent.com/images/70b252a7e3b734b8c32094eaa8c495cd.jpg'),
(83981, 5834, 'Casão: Num Jogo Sem Regras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180816.mp4', 'http://gstaticontent.com/images/70b252a7e3b734b8c32094eaa8c495cd.jpg'),
(83982, 5834, 'Casão: Num Jogo Sem Regras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180817.mp4', 'http://gstaticontent.com/images/70b252a7e3b734b8c32094eaa8c495cd.jpg'),
(83983, 5834, 'Casão: Num Jogo Sem Regras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180818.mp4', 'http://gstaticontent.com/images/70b252a7e3b734b8c32094eaa8c495cd.jpg'),
(83984, 5835, 'Damnation S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180805.mp4', 'http://timg.bdta.pro/images/97f9dbe6c4294b780b68e23602f0fb22.jpg'),
(83985, 5835, 'Damnation S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180806.mp4', 'http://timg.bdta.pro/images/e19c22c30eea150dd3173a379cff0e2f.jpg'),
(83986, 5835, 'Damnation S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180807.mp4', 'http://timg.bdta.pro/images/69cbac9bf5b895a5102ca71be35808f0.jpg'),
(83987, 5835, 'Damnation S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180808.mp4', 'http://timg.bdta.pro/images/6eb760e6ecc84c9bf8fb4dd22265f8e0.jpg'),
(83988, 5835, 'Damnation S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180809.mp4', 'http://timg.bdta.pro/images/bfe49cb63d0fb5f7cffc0a79e466b98f.jpg'),
(83989, 5835, 'Damnation S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180810.mp4', 'http://timg.bdta.pro/images/8c310a27ed6522b50de1d8681910dc61.jpg'),
(83990, 5835, 'Damnation S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180811.mp4', 'http://timg.bdta.pro/images/9ae9871c7e19f43a4325052864aa1c56.jpg'),
(83991, 5835, 'Damnation S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180812.mp4', 'http://timg.bdta.pro/images/c61eee33fec6ce74ad34620640c005c6.jpg'),
(83992, 5835, 'Damnation S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180813.mp4', 'http://timg.bdta.pro/images/b099bba47ad32de55de77bd9122cbbe5.jpg'),
(83993, 5835, 'Damnation S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180814.mp4', 'http://timg.bdta.pro/images/1a408ced2e780706442e8493775e08c0.jpg'),
(83994, 5836, 'Dossiê Chapecó: O Jogo por Trás da Tragédia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180801.mp4', 'http://gstaticontent.com/images/44de46bb53ad94f277a4b38f29488f03.jpg'),
(83995, 5836, 'Dossiê Chapecó: O Jogo por Trás da Tragédia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180802.mp4', 'http://gstaticontent.com/images/44de46bb53ad94f277a4b38f29488f03.jpg'),
(83996, 5836, 'Dossiê Chapecó: O Jogo por Trás da Tragédia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180803.mp4', 'http://gstaticontent.com/images/44de46bb53ad94f277a4b38f29488f03.jpg'),
(83997, 5836, 'Dossiê Chapecó: O Jogo por Trás da Tragédia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180804.mp4', 'http://gstaticontent.com/images/44de46bb53ad94f277a4b38f29488f03.jpg'),
(83998, 5837, 'Eizouken ni wa Te wo Dasu na! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180789.mp4', 'http://timg.bdta.pro/images/3e411e92465cc20157fb7b0f7ae942a1.jpg'),
(83999, 5837, 'Eizouken ni wa Te wo Dasu na! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180790.mp4', 'http://timg.bdta.pro/images/ac132ed6e5fdaa770aff133580042bc6.jpg'),
(84000, 5837, 'Eizouken ni wa Te wo Dasu na! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180791.mp4', 'http://timg.bdta.pro/images/5138c92249c54c6c00f221c520cc27db.jpg'),
(84001, 5837, 'Eizouken ni wa Te wo Dasu na! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180792.mp4', 'http://timg.bdta.pro/images/5d8972adb5b6dc30e2d8985fbb2e3691.jpg'),
(84002, 5837, 'Eizouken ni wa Te wo Dasu na! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180793.mp4', 'http://timg.bdta.pro/images/5b5bf6f05c30e51b7ab72db7074c4291.jpg'),
(84003, 5837, 'Eizouken ni wa Te wo Dasu na! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180794.mp4', 'http://timg.bdta.pro/images/10a0ff7a197e34397e3e3e8c413c1927.jpg'),
(84004, 5837, 'Eizouken ni wa Te wo Dasu na! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180795.mp4', 'http://timg.bdta.pro/images/be8a612fb8b3f0ccf3afa5fa84623096.jpg'),
(84005, 5837, 'Eizouken ni wa Te wo Dasu na! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180796.mp4', 'http://timg.bdta.pro/images/d8a64a8fe5b5ab4af5bc04b16748207e.jpg'),
(84006, 5837, 'Eizouken ni wa Te wo Dasu na! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180797.mp4', 'http://timg.bdta.pro/images/8cbd4e26227fd6fdb2fca62ed8208bbd.jpg'),
(84007, 5837, 'Eizouken ni wa Te wo Dasu na! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180798.mp4', 'http://timg.bdta.pro/images/1ba9c0987a0ead0c183c15657e37b29c.jpg'),
(84008, 5837, 'Eizouken ni wa Te wo Dasu na! S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/180799.mp4', 'http://timg.bdta.pro/images/0386a2a7e0efe44b9a46213bb2165b0f.jpg'),
(84009, 5837, 'Eizouken ni wa Te wo Dasu na! S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/180800.mp4', 'http://timg.bdta.pro/images/caf5d42240fb6bcc64805576cbf7a481.jpg'),
(84010, 5838, 'Genius S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180761.mp4', 'http://timg.bdta.pro/images/ca4faed8bcbe8b0b3fe0535182cd97c8.jpg'),
(84011, 5838, 'Genius S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180762.mp4', 'http://timg.bdta.pro/images/c98065e9b249f7555b82619c97b33eb6.jpg'),
(84012, 5838, 'Genius S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180763.mp4', 'http://timg.bdta.pro/images/36b6539ef797a6ee305f61e24d81c7c0.jpg'),
(84013, 5838, 'Genius S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180764.mp4', 'http://timg.bdta.pro/images/eb8328ecb1987b2630f31d8017358245.jpg'),
(84014, 5838, 'Genius S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180765.mp4', 'http://timg.bdta.pro/images/9415d5a36414bd53499ea2ce4a120f60.jpg'),
(84015, 5838, 'Genius S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180766.mp4', 'http://timg.bdta.pro/images/8b46c50c0a8e0f3e9f6c144048f85fbc.jpg'),
(84016, 5838, 'Genius S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180767.mp4', 'http://timg.bdta.pro/images/87aaa0c0896631c46d8fcb00e45a6767.jpg'),
(84017, 5838, 'Genius S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180768.mp4', 'http://timg.bdta.pro/images/c8d8ab6a8bf7a152af2d596f54510b75.jpg'),
(84018, 5838, 'Genius S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180769.mp4', 'http://timg.bdta.pro/images/dd20a8b0d32f42a9712694ee317d6b2d.jpg'),
(84019, 5838, 'Genius S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180770.mp4', 'http://timg.bdta.pro/images/8d8271284309eb5c2d576a29a26764de.jpg'),
(84020, 5839, 'Genius S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180771.mp4', 'http://timg.bdta.pro/images/8cc4261d0798797abee9da9cdd3caa43.jpg'),
(84021, 5839, 'Genius S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180772.mp4', 'http://timg.bdta.pro/images/c39c6c1745bbc1fed573d9287ad613f8.jpg'),
(84022, 5839, 'Genius S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180773.mp4', 'http://timg.bdta.pro/images/761c91fc9f54670d6d799c9fc68a30d4.jpg'),
(84023, 5839, 'Genius S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180774.mp4', 'http://timg.bdta.pro/images/09fefd4bc896ed0153c9999b46597556.jpg'),
(84024, 5839, 'Genius S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180775.mp4', 'http://timg.bdta.pro/images/bb97e3a96be9825772ca1134498c7b55.jpg'),
(84025, 5839, 'Genius S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180776.mp4', 'http://timg.bdta.pro/images/9de2836ed10fc6356c329d50dab2bcf5.jpg'),
(84026, 5839, 'Genius S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180777.mp4', 'http://timg.bdta.pro/images/600879b85455bd4809845f5cba85c6c6.jpg'),
(84027, 5839, 'Genius S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180778.mp4', 'http://timg.bdta.pro/images/40475fc12e8a9070db27892aeaf42dc4.jpg'),
(84028, 5839, 'Genius S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180779.mp4', 'http://timg.bdta.pro/images/c44dfee8220792cf50fad7278ab6f4a8.jpg'),
(84029, 5839, 'Genius S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180780.mp4', 'http://timg.bdta.pro/images/57c96f5b43ebabcaf2b66fcbf1a72c58.jpg'),
(84030, 5840, 'Genius S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180781.mp4', 'http://timg.bdta.pro/images/079a0cbb12d6262326d8c72abdec65ca.jpg'),
(84031, 5840, 'Genius S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180782.mp4', 'http://timg.bdta.pro/images/d57e64d763450cb4c52cf43ef97b70c9.jpg'),
(84032, 5840, 'Genius S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180783.mp4', 'http://timg.bdta.pro/images/b0fc9e023d9cd919995f98fbec905576.jpg'),
(84033, 5840, 'Genius S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180784.mp4', 'http://timg.bdta.pro/images/0850bccf655d3ad99ab317d50d5019cd.jpg'),
(84034, 5840, 'Genius S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180785.mp4', 'http://timg.bdta.pro/images/3a6f29cdb54664eba2b987b8a1985fe3.jpg'),
(84035, 5840, 'Genius S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180786.mp4', 'http://timg.bdta.pro/images/238e319312caf535759e16a3e3ea94e4.jpg'),
(84036, 5840, 'Genius S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180787.mp4', 'http://timg.bdta.pro/images/b92f91c1d1a209b1f5b8b3e1a2efae09.jpg'),
(84037, 5840, 'Genius S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180788.mp4', 'http://timg.bdta.pro/images/ddbef7f2b40c14759248fd80a39229df.jpg'),
(84038, 5841, 'Genius S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/271207.mp4', 'http://gstaticontent.com/images/2887b53c054671571a27f38b9f729586.jpg'),
(84039, 5841, 'Genius S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/271208.mp4', 'http://gstaticontent.com/images/2887b53c054671571a27f38b9f729586.jpg'),
(84040, 5841, 'Genius S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/271209.mp4', 'http://gstaticontent.com/images/2887b53c054671571a27f38b9f729586.jpg'),
(84041, 5841, 'Genius S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/271210.mp4', 'http://gstaticontent.com/images/2887b53c054671571a27f38b9f729586.jpg'),
(84042, 5841, 'Genius S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/276537.mp4', 'http://gstaticontent.com/images/2887b53c054671571a27f38b9f729586.jpg'),
(84043, 5841, 'Genius S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/276538.mp4', 'http://gstaticontent.com/images/2887b53c054671571a27f38b9f729586.jpg'),
(84044, 5841, 'Genius S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/280907.mp4', 'http://gstaticontent.com/images/2887b53c054671571a27f38b9f729586.jpg'),
(84045, 5841, 'Genius S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/280908.mp4', 'http://gstaticontent.com/images/2887b53c054671571a27f38b9f729586.jpg'),
(84046, 5842, 'Justiça S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180741.mp4', 'http://timg.bdta.pro/images/3cf3b46d1ff4dd48f63675008376c915.jpg'),
(84047, 5842, 'Justiça S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180742.mp4', 'http://timg.bdta.pro/images/9b197a5ac262030433d9540f23a4a3d0.jpg'),
(84048, 5842, 'Justiça S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180743.mp4', 'http://timg.bdta.pro/images/4402ff40e491ac4bcf8a14dc3b93c785.jpg'),
(84049, 5842, 'Justiça S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180744.mp4', 'http://timg.bdta.pro/images/1d539399ba2b3da7de44a82ecd213900.jpg'),
(84050, 5842, 'Justiça S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180745.mp4', 'http://timg.bdta.pro/images/a5c3db933dd2a33c2ef5fc4c471baede.jpg'),
(84051, 5842, 'Justiça S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180746.mp4', 'http://timg.bdta.pro/images/d8f12cb967d3ce3c68b2314055806bad.jpg'),
(84052, 5842, 'Justiça S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180747.mp4', 'http://timg.bdta.pro/images/ddd7c769b692a266fb3bf8b9b05b1eee.jpg'),
(84053, 5842, 'Justiça S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180748.mp4', 'http://timg.bdta.pro/images/c9ed691317a9663ca5d3f2565476f61c.jpg'),
(84054, 5842, 'Justiça S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180749.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84055, 5842, 'Justiça S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180750.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84056, 5842, 'Justiça S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/180751.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84057, 5842, 'Justiça S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/180752.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84058, 5842, 'Justiça S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/180753.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84059, 5842, 'Justiça S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/180754.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84060, 5842, 'Justiça S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/180755.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84061, 5842, 'Justiça S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/180756.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84062, 5842, 'Justiça S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/180757.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84063, 5842, 'Justiça S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/180758.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84064, 5842, 'Justiça S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/180759.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84065, 5842, 'Justiça S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/180760.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84066, 5843, 'Justiça S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/330590.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84067, 5843, 'Justiça S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/330591.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84068, 5843, 'Justiça S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/330592.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84069, 5843, 'Justiça S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/330593.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84070, 5843, 'Justiça S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/330594.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84071, 5843, 'Justiça S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/330595.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84072, 5843, 'Justiça S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/330596.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84073, 5843, 'Justiça S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/330597.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84074, 5843, 'Justiça S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/332595.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84075, 5843, 'Justiça S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/332596.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84076, 5843, 'Justiça S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/332597.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84077, 5843, 'Justiça S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/332598.mp4', 'http://gstaticontent.com/images/58da671255845a24e5c5b4841b778aa3.jpg'),
(84078, 5844, 'Onde Nascem os Fortes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180688.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84079, 5844, 'Onde Nascem os Fortes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180689.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84080, 5844, 'Onde Nascem os Fortes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180690.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84081, 5844, 'Onde Nascem os Fortes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180691.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84082, 5844, 'Onde Nascem os Fortes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180692.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84083, 5844, 'Onde Nascem os Fortes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180693.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84084, 5844, 'Onde Nascem os Fortes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180694.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84085, 5844, 'Onde Nascem os Fortes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180695.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84086, 5844, 'Onde Nascem os Fortes S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180696.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84087, 5844, 'Onde Nascem os Fortes S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180697.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84088, 5844, 'Onde Nascem os Fortes S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/180698.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84089, 5844, 'Onde Nascem os Fortes S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/180699.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84090, 5844, 'Onde Nascem os Fortes S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/180700.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84091, 5844, 'Onde Nascem os Fortes S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/180701.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84092, 5844, 'Onde Nascem os Fortes S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/180702.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84093, 5844, 'Onde Nascem os Fortes S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/180703.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84094, 5844, 'Onde Nascem os Fortes S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/180704.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84095, 5844, 'Onde Nascem os Fortes S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/180705.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84096, 5844, 'Onde Nascem os Fortes S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/180706.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84097, 5844, 'Onde Nascem os Fortes S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/180707.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84098, 5844, 'Onde Nascem os Fortes S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/180708.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84099, 5844, 'Onde Nascem os Fortes S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/180709.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84100, 5844, 'Onde Nascem os Fortes S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/180710.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84101, 5844, 'Onde Nascem os Fortes S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/180711.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84102, 5844, 'Onde Nascem os Fortes S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/180712.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84103, 5844, 'Onde Nascem os Fortes S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/180713.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84104, 5844, 'Onde Nascem os Fortes S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/180714.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84105, 5844, 'Onde Nascem os Fortes S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/180715.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84106, 5844, 'Onde Nascem os Fortes S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/180716.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84107, 5844, 'Onde Nascem os Fortes S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/180717.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84108, 5844, 'Onde Nascem os Fortes S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/180718.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84109, 5844, 'Onde Nascem os Fortes S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/180719.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84110, 5844, 'Onde Nascem os Fortes S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/180720.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84111, 5844, 'Onde Nascem os Fortes S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/180721.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84112, 5844, 'Onde Nascem os Fortes S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/180722.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84113, 5844, 'Onde Nascem os Fortes S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/180723.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84114, 5844, 'Onde Nascem os Fortes S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/180724.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84115, 5844, 'Onde Nascem os Fortes S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/180725.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84116, 5844, 'Onde Nascem os Fortes S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/180726.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84117, 5844, 'Onde Nascem os Fortes S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/180727.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84118, 5844, 'Onde Nascem os Fortes S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/180728.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84119, 5844, 'Onde Nascem os Fortes S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/180729.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84120, 5844, 'Onde Nascem os Fortes S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/180730.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84121, 5844, 'Onde Nascem os Fortes S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/180731.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84122, 5844, 'Onde Nascem os Fortes S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/180732.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84123, 5844, 'Onde Nascem os Fortes S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/180733.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84124, 5844, 'Onde Nascem os Fortes S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/180734.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84125, 5844, 'Onde Nascem os Fortes S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/180735.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84126, 5844, 'Onde Nascem os Fortes S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/180736.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84127, 5844, 'Onde Nascem os Fortes S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/180737.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84128, 5844, 'Onde Nascem os Fortes S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/180738.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84129, 5844, 'Onde Nascem os Fortes S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/180739.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84130, 5844, 'Onde Nascem os Fortes S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/180740.mp4', 'http://gstaticontent.com/images/8f507cd868e172cfd4119bb1b5bdd10c.jpg'),
(84131, 5845, 'One Piece S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257778.mp4', 'http://timg.bdta.pro/images/69fc19187e24cf22300a525a2a186664.jpg'),
(84132, 5845, 'One Piece S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257779.mp4', 'http://timg.bdta.pro/images/96da101520508b1d64f878a8a127e1b3.jpg'),
(84133, 5845, 'One Piece S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257780.mp4', 'http://timg.bdta.pro/images/950ce995199b0135f6ba9f676993aa85.jpg'),
(84134, 5845, 'One Piece S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257781.mp4', 'http://timg.bdta.pro/images/e9008616d5a5d1baa53e2fe3ecd9ec9e.jpg'),
(84135, 5845, 'One Piece S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257782.mp4', 'http://timg.bdta.pro/images/74c8ce48a9cc739d7d6f1425d12d87df.jpg'),
(84136, 5845, 'One Piece S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257783.mp4', 'http://timg.bdta.pro/images/7e044e1ff01d3b8fddd5508a2ff5a314.jpg'),
(84137, 5845, 'One Piece S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257784.mp4', 'http://timg.bdta.pro/images/417145e473d70268223a2e21653913e8.jpg'),
(84138, 5845, 'One Piece S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257785.mp4', 'http://timg.bdta.pro/images/788d7cbd6b6468212a938e6083b67f06.jpg'),
(84139, 5845, 'One Piece S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257786.mp4', 'http://timg.bdta.pro/images/2395ea1084ffce9fa5dfadb6a8d4742f.jpg'),
(84140, 5845, 'One Piece S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257787.mp4', 'http://timg.bdta.pro/images/b1cf733441b6e4d9737538755ff16b4a.jpg'),
(84141, 5845, 'One Piece S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257788.mp4', 'http://timg.bdta.pro/images/fcc9a83f7562aed0682e04c04acff955.jpg'),
(84142, 5845, 'One Piece S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257789.mp4', 'http://timg.bdta.pro/images/6e79d1d41046ae92a6bc06dcdf14ea62.jpg'),
(84143, 5845, 'One Piece S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257790.mp4', 'http://timg.bdta.pro/images/befa695879374d3968fbc7f794a331ca.jpg'),
(84144, 5845, 'One Piece S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/257791.mp4', 'http://timg.bdta.pro/images/86493d4c8345970c3cd25517dbba1c7a.jpg'),
(84145, 5845, 'One Piece S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/257792.mp4', 'http://timg.bdta.pro/images/709a111dfc9d702d4dcdaf85f65a5675.jpg'),
(84146, 5845, 'One Piece S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/257793.mp4', 'http://timg.bdta.pro/images/e1257340d06abbfc0bfceeb644a60c6b.jpg'),
(84147, 5845, 'One Piece S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/257794.mp4', 'http://timg.bdta.pro/images/03973fa62172b11d0aaa9df9b05a242e.jpg'),
(84148, 5845, 'One Piece S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/257795.mp4', 'http://timg.bdta.pro/images/e3186ae5a4968f1dc1e682b4e9dc4146.jpg'),
(84149, 5845, 'One Piece S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/257796.mp4', 'http://timg.bdta.pro/images/fd3d8b3d141ce9fde25ee0b07f347c54.jpg'),
(84150, 5845, 'One Piece S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/257797.mp4', 'http://timg.bdta.pro/images/734506099aa6c51ce7db2f1801750d18.jpg'),
(84151, 5845, 'One Piece S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/257798.mp4', 'http://timg.bdta.pro/images/b0c93af8e95d8c1e9e1085f7fd008669.jpg'),
(84152, 5845, 'One Piece S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/257799.mp4', 'http://timg.bdta.pro/images/45376d3419aa935fc014e916405682bd.jpg'),
(84153, 5845, 'One Piece S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/257800.mp4', 'http://timg.bdta.pro/images/6baf4dd9f2bb8e1123749546595516a7.jpg'),
(84154, 5845, 'One Piece S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/257801.mp4', 'http://timg.bdta.pro/images/9fe604536ad3e3f945da1c4c4ab79bf9.jpg'),
(84155, 5845, 'One Piece S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/257802.mp4', 'http://timg.bdta.pro/images/464da7addeb1c48125ea7f50b8fe7bb6.jpg'),
(84156, 5845, 'One Piece S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/257803.mp4', 'http://timg.bdta.pro/images/9217bb4947bcad61e7c813ac09f55591.jpg'),
(84157, 5845, 'One Piece S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/257804.mp4', 'http://timg.bdta.pro/images/4ef06e091393c53a43e650b0ddffb200.jpg'),
(84158, 5845, 'One Piece S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/257805.mp4', 'http://timg.bdta.pro/images/8891917a02cccb2664fa4a2f78d7437c.jpg'),
(84159, 5845, 'One Piece S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/257806.mp4', 'http://timg.bdta.pro/images/a18c869062cb2419f0f250939885af3c.jpg'),
(84160, 5845, 'One Piece S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/257807.mp4', 'http://timg.bdta.pro/images/14bd3641b8a79503234d377e94946df1.jpg'),
(84161, 5845, 'One Piece S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/257808.mp4', 'http://timg.bdta.pro/images/0cfb51fca58a4645e2195ed2bd5929d8.jpg'),
(84162, 5845, 'One Piece S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/257809.mp4', 'http://timg.bdta.pro/images/5c11ee0ef6f5e53a483628c45d9be434.jpg'),
(84163, 5845, 'One Piece S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/257810.mp4', 'http://timg.bdta.pro/images/ad49bbd1409d1e5cf18a718c4f203120.jpg'),
(84164, 5845, 'One Piece S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/257811.mp4', 'http://timg.bdta.pro/images/84fde64e34554f1525539ecd02e784b1.jpg'),
(84165, 5845, 'One Piece S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/257812.mp4', 'http://timg.bdta.pro/images/50fb7918f59904e6562df6dd4fe2876b.jpg'),
(84166, 5845, 'One Piece S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/257813.mp4', 'http://timg.bdta.pro/images/08591c0786711541ad4dfd34da54433d.jpg'),
(84167, 5845, 'One Piece S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/257814.mp4', 'http://timg.bdta.pro/images/509ab5877b9a94cc2186ba2e31685abc.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(84168, 5845, 'One Piece S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/257815.mp4', 'http://timg.bdta.pro/images/8f3202e47dd35ea6462b7ee770037eb7.jpg'),
(84169, 5845, 'One Piece S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/257816.mp4', 'http://timg.bdta.pro/images/d131e95893deee45fb637548e93573e0.jpg'),
(84170, 5845, 'One Piece S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/257817.mp4', 'http://timg.bdta.pro/images/d5f0f7865e9133e5132eeab223253335.jpg'),
(84171, 5845, 'One Piece S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/257818.mp4', 'http://timg.bdta.pro/images/1ff084bea19609dee257d806b8f25233.jpg'),
(84172, 5845, 'One Piece S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/257819.mp4', 'http://timg.bdta.pro/images/ab7f8c838cf92060746c17e28e8f8bc3.jpg'),
(84173, 5845, 'One Piece S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/257820.mp4', 'http://timg.bdta.pro/images/14a5c232aea5709581ae7edc6f063a1b.jpg'),
(84174, 5845, 'One Piece S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/257821.mp4', 'http://timg.bdta.pro/images/e10b3e3c98931eca2401c5c44e20788f.jpg'),
(84175, 5845, 'One Piece S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/257822.mp4', 'http://timg.bdta.pro/images/968f6bd3a8f7d3b577a895aa3a8a2211.jpg'),
(84176, 5845, 'One Piece S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/257823.mp4', 'http://timg.bdta.pro/images/9900cb7b51ff2204764376d68212027f.jpg'),
(84177, 5845, 'One Piece S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/257824.mp4', 'http://timg.bdta.pro/images/df85bd41a6c7f91267d05c61ae223b22.jpg'),
(84178, 5845, 'One Piece S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/257825.mp4', 'http://timg.bdta.pro/images/960617fc34bac09245e2090ba2ede890.jpg'),
(84179, 5845, 'One Piece S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/257826.mp4', 'http://timg.bdta.pro/images/7db66e07dcf122171bb0706acaafeff6.jpg'),
(84180, 5845, 'One Piece S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/257827.mp4', 'http://timg.bdta.pro/images/bcfbfaf0719a4ab30210262e2190e69c.jpg'),
(84181, 5845, 'One Piece S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/257828.mp4', 'http://timg.bdta.pro/images/90d9c9ce1e8d8f0d3c0a7c896c302044.jpg'),
(84182, 5845, 'One Piece S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/257829.mp4', 'http://timg.bdta.pro/images/aaab9b2073950d2569805c22d305f248.jpg'),
(84183, 5845, 'One Piece S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/257830.mp4', 'http://timg.bdta.pro/images/ef9ed199723fe7c53d1d4a62c8422d0d.jpg'),
(84184, 5845, 'One Piece S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/257831.mp4', 'http://timg.bdta.pro/images/3bbe332068c8653413e249ba53beecaf.jpg'),
(84185, 5845, 'One Piece S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/257832.mp4', 'http://timg.bdta.pro/images/5aa2f263264ec230b441dbf1270ee76f.jpg'),
(84186, 5845, 'One Piece S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/257833.mp4', 'http://timg.bdta.pro/images/464fa4d190dda58928477e04ccbae570.jpg'),
(84187, 5845, 'One Piece S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/257834.mp4', 'http://timg.bdta.pro/images/afe6821525ae134458ca7572e7064bf9.jpg'),
(84188, 5845, 'One Piece S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/257835.mp4', 'http://timg.bdta.pro/images/f7383ba35564306799f475313f50d76f.jpg'),
(84189, 5845, 'One Piece S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/257836.mp4', 'http://timg.bdta.pro/images/d564bb8d9541929333325e75cb3c8661.jpg'),
(84190, 5845, 'One Piece S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/257837.mp4', 'http://timg.bdta.pro/images/544efc51a75b010044ca542f120d8504.jpg'),
(84191, 5845, 'One Piece S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/257838.mp4', 'http://timg.bdta.pro/images/9438ab085fade406501c78d792db38f6.jpg'),
(84192, 5846, 'One Piece S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257839.mp4', 'http://timg.bdta.pro/images/f75e337c574dec4d5499cb1d305512c2.jpg'),
(84193, 5846, 'One Piece S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257840.mp4', 'http://timg.bdta.pro/images/5a1adc40cf61416b50beba11dd2c9067.jpg'),
(84194, 5846, 'One Piece S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257841.mp4', 'http://timg.bdta.pro/images/03fb84e031622fd5d250bd504b187204.jpg'),
(84195, 5846, 'One Piece S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257842.mp4', 'http://timg.bdta.pro/images/0cf90729a7d3fccd497ab28c567090a4.jpg'),
(84196, 5846, 'One Piece S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257843.mp4', 'http://timg.bdta.pro/images/6ecc007fa1395aec956f252b6f37b98d.jpg'),
(84197, 5846, 'One Piece S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257844.mp4', 'http://timg.bdta.pro/images/0affa464996760492b940c691de106a3.jpg'),
(84198, 5846, 'One Piece S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257845.mp4', 'http://timg.bdta.pro/images/8d7e725b3492895a9043925753608427.jpg'),
(84199, 5846, 'One Piece S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257846.mp4', 'http://timg.bdta.pro/images/4ce24ef5763bd9fdd2cc51374fa94ab7.jpg'),
(84200, 5846, 'One Piece S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257847.mp4', 'http://timg.bdta.pro/images/0ea7cce66761d199965fe1f246754086.jpg'),
(84201, 5846, 'One Piece S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257848.mp4', 'http://timg.bdta.pro/images/1a80d9e5404811e6179b661c776e5189.jpg'),
(84202, 5846, 'One Piece S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257849.mp4', 'http://timg.bdta.pro/images/4591b4a324f06b3513c5c6c157888daa.jpg'),
(84203, 5846, 'One Piece S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257850.mp4', 'http://timg.bdta.pro/images/124f2fe36fe2a55ca79f88d76bade9df.jpg'),
(84204, 5846, 'One Piece S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257851.mp4', 'http://timg.bdta.pro/images/b348d8b8a9bd1cca689b5bc6a01e937a.jpg'),
(84205, 5846, 'One Piece S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/257852.mp4', 'http://timg.bdta.pro/images/a1d3f7b7bbab4b1094074feb2d9dda90.jpg'),
(84206, 5846, 'One Piece S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/257853.mp4', 'http://timg.bdta.pro/images/9e8cfa3a22becf081b75e51b6be5f98d.jpg'),
(84207, 5846, 'One Piece S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/257854.mp4', 'http://timg.bdta.pro/images/30f238ee13f581f3808baac59e5ebc51.jpg'),
(84208, 5847, 'One Piece S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257855.mp4', 'http://timg.bdta.pro/images/52d34adb5cd8598070cac304ea00135e.jpg'),
(84209, 5847, 'One Piece S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257856.mp4', 'http://timg.bdta.pro/images/81f1b4424db0e6c1ce35fd19abbd086d.jpg'),
(84210, 5847, 'One Piece S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257857.mp4', 'http://timg.bdta.pro/images/97013553b30aa4b2e08540c421c578be.jpg'),
(84211, 5847, 'One Piece S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257858.mp4', 'http://timg.bdta.pro/images/a2abe98f12cf2d99408fe54c0447f370.jpg'),
(84212, 5847, 'One Piece S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257859.mp4', 'http://timg.bdta.pro/images/28af40f50fe7976d57f80ec4a17b5398.jpg'),
(84213, 5847, 'One Piece S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257860.mp4', 'http://timg.bdta.pro/images/f6786163b0be5d885720bd7e79218cbd.jpg'),
(84214, 5847, 'One Piece S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257861.mp4', 'http://timg.bdta.pro/images/3c55883e57105887a3a3181922b1895b.jpg'),
(84215, 5847, 'One Piece S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257862.mp4', 'http://timg.bdta.pro/images/0d104733373d6c972f88b53ebd820770.jpg'),
(84216, 5847, 'One Piece S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257863.mp4', 'http://timg.bdta.pro/images/90f7c32e15f62fc86cda490d42e38d2a.jpg'),
(84217, 5847, 'One Piece S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257864.mp4', 'http://timg.bdta.pro/images/15dc2de0018b16d659e80205b29c6d3a.jpg'),
(84218, 5847, 'One Piece S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257865.mp4', 'http://timg.bdta.pro/images/2636e1963afa1c06b675a1e488d36f2c.jpg'),
(84219, 5847, 'One Piece S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257866.mp4', 'http://timg.bdta.pro/images/406190b7c31728f68bc3e4c1d0b28c01.jpg'),
(84220, 5847, 'One Piece S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257867.mp4', 'http://timg.bdta.pro/images/67541fe821991af99e209289924a1d3b.jpg'),
(84221, 5847, 'One Piece S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/257868.mp4', 'http://timg.bdta.pro/images/9428f0d8aaa90eafe745c37e07a1a05e.jpg'),
(84222, 5848, 'One Piece S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257869.mp4', 'http://timg.bdta.pro/images/3121aa6ad73d601b5268df6e49bae668.jpg'),
(84223, 5848, 'One Piece S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257870.mp4', 'http://timg.bdta.pro/images/33f8dd351fb704c9ee6c693ff3c2fdc3.jpg'),
(84224, 5848, 'One Piece S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257871.mp4', 'http://timg.bdta.pro/images/7ab5e7b8c34653b098e7ac43d36786d0.jpg'),
(84225, 5848, 'One Piece S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257872.mp4', 'http://timg.bdta.pro/images/c7fca7609690a64c3804e56c6eefd05e.jpg'),
(84226, 5848, 'One Piece S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257873.mp4', 'http://timg.bdta.pro/images/0ebaf254008cc5543200da11aae12c6a.jpg'),
(84227, 5848, 'One Piece S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257874.mp4', 'http://timg.bdta.pro/images/0a48281df1ef0e17ed3b643cc2c8168a.jpg'),
(84228, 5848, 'One Piece S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257875.mp4', 'http://timg.bdta.pro/images/ba6eaa71289d7bd060a7eaca319f85bb.jpg'),
(84229, 5848, 'One Piece S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257876.mp4', 'http://timg.bdta.pro/images/562a79ac381cce2e43a1d52f61143380.jpg'),
(84230, 5848, 'One Piece S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257877.mp4', 'http://timg.bdta.pro/images/2c013f0faca965cfb67214d2cb5882c3.jpg'),
(84231, 5848, 'One Piece S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257878.mp4', 'http://timg.bdta.pro/images/b06d71d29c80ca0b7517bae3c51044ce.jpg'),
(84232, 5848, 'One Piece S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257879.mp4', 'http://timg.bdta.pro/images/cb5fd26f9631cf045fae13085237ce1d.jpg'),
(84233, 5848, 'One Piece S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257880.mp4', 'http://timg.bdta.pro/images/9ca7b5abaf93394791fcaac91b61612c.jpg'),
(84234, 5848, 'One Piece S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257881.mp4', 'http://timg.bdta.pro/images/e85465646c8af974c1f0708e8d539efd.jpg'),
(84235, 5848, 'One Piece S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/257882.mp4', 'http://timg.bdta.pro/images/2b94e38760dee319026decba8c6cc1b9.jpg'),
(84236, 5848, 'One Piece S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/257883.mp4', 'http://timg.bdta.pro/images/ec03a0724a3d54500b733488152677de.jpg'),
(84237, 5848, 'One Piece S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/257884.mp4', 'http://timg.bdta.pro/images/b8658433962a1aea3adf384273e0dfd8.jpg'),
(84238, 5848, 'One Piece S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/257885.mp4', 'http://timg.bdta.pro/images/7faaf559d4e160c3f73fbca46745c3fc.jpg'),
(84239, 5848, 'One Piece S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/257886.mp4', 'http://timg.bdta.pro/images/3798c14e345b8c683af649e4ab13fd84.jpg'),
(84240, 5848, 'One Piece S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/257887.mp4', 'http://timg.bdta.pro/images/599642eda8294342184eda690126eba5.jpg'),
(84241, 5848, 'One Piece S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/257888.mp4', 'http://timg.bdta.pro/images/a1893dab9e85bf15709cda9637dd883b.jpg'),
(84242, 5848, 'One Piece S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/257889.mp4', 'http://timg.bdta.pro/images/1a0d0dc6f06af4d067cebeee42b89db5.jpg'),
(84243, 5848, 'One Piece S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/257890.mp4', 'http://timg.bdta.pro/images/d7db77dc884c325853b871789d74b560.jpg'),
(84244, 5848, 'One Piece S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/257891.mp4', 'http://timg.bdta.pro/images/04759530ad9912cf36965b93d82a3391.jpg'),
(84245, 5848, 'One Piece S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/257892.mp4', 'http://timg.bdta.pro/images/6126c83accff289d773f7e1123679f15.jpg'),
(84246, 5848, 'One Piece S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/257893.mp4', 'http://timg.bdta.pro/images/98acfc571c578c08d779d5d387278e4e.jpg'),
(84247, 5848, 'One Piece S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/257894.mp4', 'http://timg.bdta.pro/images/cf6171a2c69127c224b2c28dd63bb002.jpg'),
(84248, 5848, 'One Piece S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/257895.mp4', 'http://timg.bdta.pro/images/eb227181175f12a94d2cb43c75b98de1.jpg'),
(84249, 5848, 'One Piece S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/257896.mp4', 'http://timg.bdta.pro/images/6c8dfbc3eb86127693d39d8c718e4b5f.jpg'),
(84250, 5848, 'One Piece S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/257897.mp4', 'http://timg.bdta.pro/images/adac37b0510a24ef59e0fdab92ace62a.jpg'),
(84251, 5848, 'One Piece S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/257898.mp4', 'http://timg.bdta.pro/images/48c977e67843e02d77a6a7c345b517d1.jpg'),
(84252, 5848, 'One Piece S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/257899.mp4', 'http://timg.bdta.pro/images/d2a8b7ed7c5558ce61734ee15d5d9b16.jpg'),
(84253, 5848, 'One Piece S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/257900.mp4', 'http://timg.bdta.pro/images/35bd621c0a35958c25721cbef5138ade.jpg'),
(84254, 5848, 'One Piece S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/257901.mp4', 'http://timg.bdta.pro/images/5599801bb75949c8c1526146a8afdab2.jpg'),
(84255, 5848, 'One Piece S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/257902.mp4', 'http://timg.bdta.pro/images/a81eacec2067ed5c166a32675d152985.jpg'),
(84256, 5848, 'One Piece S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/257903.mp4', 'http://timg.bdta.pro/images/40b434033280fcba4979d49814ecc23b.jpg'),
(84257, 5848, 'One Piece S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/257904.mp4', 'http://timg.bdta.pro/images/186b0e0e4e20bec72fca153cd7d2b750.jpg'),
(84258, 5848, 'One Piece S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/257905.mp4', 'http://timg.bdta.pro/images/991de22e8de927a1074ca9313f515b72.jpg'),
(84259, 5848, 'One Piece S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/257906.mp4', 'http://timg.bdta.pro/images/2273f479341cbb14ae749301d1553adc.jpg'),
(84260, 5848, 'One Piece S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/257907.mp4', 'http://timg.bdta.pro/images/d0b3f8261db45de73c64fc6ccbdf75fd.jpg'),
(84261, 5849, 'One Piece S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257908.mp4', 'http://timg.bdta.pro/images/0c326e2390ca3ecfe157206f79046d55.jpg'),
(84262, 5849, 'One Piece S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257909.mp4', 'http://timg.bdta.pro/images/422dd80f82dc0bef9838db20d5e01a0d.jpg'),
(84263, 5849, 'One Piece S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257910.mp4', 'http://timg.bdta.pro/images/f88d46d3325c46aef6a2f43115036537.jpg'),
(84264, 5849, 'One Piece S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257911.mp4', 'http://timg.bdta.pro/images/20d0b4e7ed890b1f1654b6f5c05568c0.jpg'),
(84265, 5849, 'One Piece S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257912.mp4', 'http://timg.bdta.pro/images/8533613559ab57025f0968bc65b45e3a.jpg'),
(84266, 5849, 'One Piece S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257913.mp4', 'http://timg.bdta.pro/images/ec3598472b62e6525c989979d0aa7c71.jpg'),
(84267, 5849, 'One Piece S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257914.mp4', 'http://timg.bdta.pro/images/4c6d8ddb0df1ce970be9070abfd27437.jpg'),
(84268, 5849, 'One Piece S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257915.mp4', 'http://timg.bdta.pro/images/38318071e47f886d425482a42758df31.jpg'),
(84269, 5849, 'One Piece S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257916.mp4', 'http://timg.bdta.pro/images/72e75d75c37c8666fd1b4e27daa58944.jpg'),
(84270, 5849, 'One Piece S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257917.mp4', 'http://timg.bdta.pro/images/35ae4ab5ce91653475219c3953eeb6d2.jpg'),
(84271, 5849, 'One Piece S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257918.mp4', 'http://timg.bdta.pro/images/8be2c3e8407bea6ef5e2ddf555eb6d44.jpg'),
(84272, 5849, 'One Piece S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257919.mp4', 'http://timg.bdta.pro/images/92c0f81e95621ff583bdd60a01d93d7e.jpg'),
(84273, 5849, 'One Piece S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257920.mp4', 'http://timg.bdta.pro/images/eaa891e7e0111873c0397e80b7543ae2.jpg'),
(84274, 5850, 'One Piece S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257921.mp4', 'http://timg.bdta.pro/images/408c62ad822ee5ea8f98a1b479eddd80.jpg'),
(84275, 5850, 'One Piece S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257922.mp4', 'http://timg.bdta.pro/images/194b2153c87c47b44fd2e028561a0470.jpg'),
(84276, 5850, 'One Piece S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257923.mp4', 'http://timg.bdta.pro/images/8ef3e2408536fdb9782715416e5e7ba8.jpg'),
(84277, 5850, 'One Piece S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257924.mp4', 'http://timg.bdta.pro/images/12aefd33b700440e228baeb2f94ae22f.jpg'),
(84278, 5850, 'One Piece S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257925.mp4', 'http://timg.bdta.pro/images/c66b9e29fbe4bf649a1c79854962cdca.jpg'),
(84279, 5850, 'One Piece S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257926.mp4', 'http://timg.bdta.pro/images/affbe467f2d4365bbf6ab024256deabb.jpg'),
(84280, 5850, 'One Piece S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257927.mp4', 'http://timg.bdta.pro/images/1ba233974024dcdc44fd896daf724cac.jpg'),
(84281, 5850, 'One Piece S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257928.mp4', 'http://timg.bdta.pro/images/2d09d0d123f8fa020a141485684e4573.jpg'),
(84282, 5850, 'One Piece S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257929.mp4', 'http://timg.bdta.pro/images/df9ebdfd416a59f87b5b739dd1119e5f.jpg'),
(84283, 5850, 'One Piece S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257930.mp4', 'http://timg.bdta.pro/images/5be973188cb54c6c5ba1705879a8fe3c.jpg'),
(84284, 5850, 'One Piece S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257931.mp4', 'http://timg.bdta.pro/images/5628606340c082ea691a624ef4793f2e.jpg'),
(84285, 5850, 'One Piece S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257932.mp4', 'http://timg.bdta.pro/images/c72a7b1ead604cdbb83df068836ae1ce.jpg'),
(84286, 5850, 'One Piece S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257933.mp4', 'http://timg.bdta.pro/images/7c38945951d771995d2598bf3a58d878.jpg'),
(84287, 5850, 'One Piece S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/257934.mp4', 'http://timg.bdta.pro/images/52c838b12c50c1497902eb17a6d0c51e.jpg'),
(84288, 5850, 'One Piece S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/257935.mp4', 'http://timg.bdta.pro/images/d040da11746ed51484e0ed7c4c27c89d.jpg'),
(84289, 5850, 'One Piece S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/257936.mp4', 'http://timg.bdta.pro/images/4911e42cd7892c1bf3d03ce2cc02ccb6.jpg'),
(84290, 5850, 'One Piece S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/257937.mp4', 'http://timg.bdta.pro/images/a5bf31729e530e6a8119e026f22da15a.jpg'),
(84291, 5850, 'One Piece S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/257938.mp4', 'http://timg.bdta.pro/images/85a641af94a70c98c2959f05f68d60a9.jpg'),
(84292, 5850, 'One Piece S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/257939.mp4', 'http://timg.bdta.pro/images/d8362f9f01b2348163c298cfe92de4f9.jpg'),
(84293, 5850, 'One Piece S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/257940.mp4', 'http://timg.bdta.pro/images/4241b1e05436ffbc1a2ecc5b354c3594.jpg'),
(84294, 5850, 'One Piece S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/257941.mp4', 'http://timg.bdta.pro/images/a4de50804ab0e2e7bf6a6a926046fc36.jpg'),
(84295, 5850, 'One Piece S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/257942.mp4', 'http://timg.bdta.pro/images/d50f12dec55f7fd55f2f2e2fa2d0bbe2.jpg'),
(84296, 5850, 'One Piece S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/257943.mp4', 'http://timg.bdta.pro/images/334ffab73063b49e260e5f90a01455da.jpg'),
(84297, 5850, 'One Piece S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/257944.mp4', 'http://timg.bdta.pro/images/e9615b762b5d2fa082ac55b08a3dfe24.jpg'),
(84298, 5850, 'One Piece S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/257945.mp4', 'http://timg.bdta.pro/images/435d44e1dde0b5ba20278c60bfcf7efa.jpg'),
(84299, 5850, 'One Piece S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/257946.mp4', 'http://timg.bdta.pro/images/13dc6dfe61d64571796c7b5ee4e7bad5.jpg'),
(84300, 5850, 'One Piece S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/257947.mp4', 'http://timg.bdta.pro/images/2bee342ba77d7614e3d8116d65c20c58.jpg'),
(84301, 5850, 'One Piece S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/257948.mp4', 'http://timg.bdta.pro/images/1b9971acab42a0bc1e5f7c312115fa6c.jpg'),
(84302, 5850, 'One Piece S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/257949.mp4', 'http://timg.bdta.pro/images/1e6aa37b5300d73ffc5cc4236ec328bf.jpg'),
(84303, 5850, 'One Piece S06 E30', 'http://sinalprivado.info:80/series/1533784/1533784/257950.mp4', 'http://timg.bdta.pro/images/8b90fe8f7cc1fff82cd8fff3340f646e.jpg'),
(84304, 5850, 'One Piece S06 E31', 'http://sinalprivado.info:80/series/1533784/1533784/257951.mp4', 'http://timg.bdta.pro/images/be2ede4055828f738e2249c6a8b82275.jpg'),
(84305, 5850, 'One Piece S06 E32', 'http://sinalprivado.info:80/series/1533784/1533784/257952.mp4', 'http://timg.bdta.pro/images/9826c069f70e3b0b37c5ae68db51cc80.jpg'),
(84306, 5850, 'One Piece S06 E33', 'http://sinalprivado.info:80/series/1533784/1533784/257953.mp4', 'http://timg.bdta.pro/images/68f2c29df588b10671861e7a64d6bf3d.jpg'),
(84307, 5850, 'One Piece S06 E34', 'http://sinalprivado.info:80/series/1533784/1533784/257954.mp4', 'http://timg.bdta.pro/images/323b08b379f8d32d14ba5eafaf26beee.jpg'),
(84308, 5850, 'One Piece S06 E35', 'http://sinalprivado.info:80/series/1533784/1533784/257955.mp4', 'http://timg.bdta.pro/images/0885a8932cb2e237b7d90aecd8853050.jpg'),
(84309, 5850, 'One Piece S06 E36', 'http://sinalprivado.info:80/series/1533784/1533784/257956.mp4', 'http://timg.bdta.pro/images/ef0637448d5f2a29b299c0e3966d01b5.jpg'),
(84310, 5850, 'One Piece S06 E37', 'http://sinalprivado.info:80/series/1533784/1533784/257957.mp4', 'http://timg.bdta.pro/images/e45c1947ba6706103ee42d14084526d8.jpg'),
(84311, 5850, 'One Piece S06 E38', 'http://sinalprivado.info:80/series/1533784/1533784/257958.mp4', 'http://timg.bdta.pro/images/ebc9983df24b9d5de52fc0aa9a281269.jpg'),
(84312, 5850, 'One Piece S06 E39', 'http://sinalprivado.info:80/series/1533784/1533784/257959.mp4', 'http://timg.bdta.pro/images/b0d5fc724682fa7f75e4c706f6fb2744.jpg'),
(84313, 5850, 'One Piece S06 E40', 'http://sinalprivado.info:80/series/1533784/1533784/257960.mp4', 'http://timg.bdta.pro/images/9aa5dc9c0541f2ac97dac75f1575460c.jpg'),
(84314, 5850, 'One Piece S06 E41', 'http://sinalprivado.info:80/series/1533784/1533784/257961.mp4', 'http://timg.bdta.pro/images/156f82fc79d7806007bc5cb814cdc470.jpg'),
(84315, 5850, 'One Piece S06 E42', 'http://sinalprivado.info:80/series/1533784/1533784/257962.mp4', 'http://timg.bdta.pro/images/fe8ff6ad368ace5b1e1a7f236c113a28.jpg'),
(84316, 5850, 'One Piece S06 E43', 'http://sinalprivado.info:80/series/1533784/1533784/257963.mp4', 'http://timg.bdta.pro/images/e2a8a266711cb0c1935f84178e7e1638.jpg'),
(84317, 5850, 'One Piece S06 E44', 'http://sinalprivado.info:80/series/1533784/1533784/257964.mp4', 'http://timg.bdta.pro/images/70d7d94945259bac4330942c157165af.jpg'),
(84318, 5850, 'One Piece S06 E45', 'http://sinalprivado.info:80/series/1533784/1533784/257965.mp4', 'http://timg.bdta.pro/images/832f7ae1596406d771f4ebd97a39e909.jpg'),
(84319, 5850, 'One Piece S06 E46', 'http://sinalprivado.info:80/series/1533784/1533784/257966.mp4', 'http://timg.bdta.pro/images/1b2b40b6f397a59cf4d632e153b0f350.jpg'),
(84320, 5850, 'One Piece S06 E47', 'http://sinalprivado.info:80/series/1533784/1533784/257967.mp4', 'http://timg.bdta.pro/images/692b82e1f918e5d00356be6929c2b08e.jpg'),
(84321, 5850, 'One Piece S06 E48', 'http://sinalprivado.info:80/series/1533784/1533784/257968.mp4', 'http://timg.bdta.pro/images/7747e7b983b67be71a6551bdfd95c8a6.jpg'),
(84322, 5850, 'One Piece S06 E49', 'http://sinalprivado.info:80/series/1533784/1533784/257969.mp4', 'http://timg.bdta.pro/images/357ca2c312521d1658ac627714a87e66.jpg'),
(84323, 5850, 'One Piece S06 E50', 'http://sinalprivado.info:80/series/1533784/1533784/257970.mp4', 'http://timg.bdta.pro/images/008044998938bdb82e159d981ba3b7f3.jpg'),
(84324, 5850, 'One Piece S06 E51', 'http://sinalprivado.info:80/series/1533784/1533784/257971.mp4', 'http://timg.bdta.pro/images/9706055377b0068dfd42ba405e9867e6.jpg'),
(84325, 5850, 'One Piece S06 E52', 'http://sinalprivado.info:80/series/1533784/1533784/257972.mp4', 'http://timg.bdta.pro/images/93e6eaaa8bf8dca70f123e52dbf447c7.jpg'),
(84326, 5851, 'One Piece S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257973.mp4', 'http://timg.bdta.pro/images/bfed9061e9acfbfec911251c1510f34a.jpg'),
(84327, 5851, 'One Piece S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257974.mp4', 'http://timg.bdta.pro/images/2bac745d6c87c34d842acf0e75e67c8d.jpg'),
(84328, 5851, 'One Piece S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257975.mp4', 'http://timg.bdta.pro/images/78e1f33b85f3d59d172aaff68f4525a9.jpg'),
(84329, 5851, 'One Piece S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257976.mp4', 'http://timg.bdta.pro/images/1e8ebccc1a3bb5f4390e802207d3594e.jpg'),
(84330, 5851, 'One Piece S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257977.mp4', 'http://timg.bdta.pro/images/6eee86b948cfa593b4a44557ff81d60f.jpg'),
(84331, 5851, 'One Piece S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257978.mp4', 'http://timg.bdta.pro/images/d8c262d0189b8d96e9fd1a747004dc11.jpg'),
(84332, 5851, 'One Piece S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257979.mp4', 'http://timg.bdta.pro/images/ecb6469b76320fa341d9dfb290b149da.jpg'),
(84333, 5851, 'One Piece S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257980.mp4', 'http://timg.bdta.pro/images/0991191a0942fe59d3391c1d04afc25c.jpg'),
(84334, 5851, 'One Piece S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257981.mp4', 'http://timg.bdta.pro/images/0d98b48d21c14812387636dbd35b17b3.jpg'),
(84335, 5851, 'One Piece S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257982.mp4', 'http://timg.bdta.pro/images/e044878e64b938e988c7f7ec38e55b79.jpg'),
(84336, 5851, 'One Piece S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257983.mp4', 'http://timg.bdta.pro/images/b8c3cf18f3bbc1b9cf19038390cbd53b.jpg'),
(84337, 5851, 'One Piece S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257984.mp4', 'http://timg.bdta.pro/images/bdcc1c47bed503c90d05207c6899d1ff.jpg'),
(84338, 5851, 'One Piece S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257985.mp4', 'http://timg.bdta.pro/images/e8917ccb9f7d0e958b4878cd9a143d1b.jpg'),
(84339, 5851, 'One Piece S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/257986.mp4', 'http://timg.bdta.pro/images/fe0efdc6f091708540e24e286ff9e0d8.jpg'),
(84340, 5851, 'One Piece S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/257987.mp4', 'http://timg.bdta.pro/images/7dbdd37933d81f65fd816be16bbfd7a1.jpg'),
(84341, 5851, 'One Piece S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/257988.mp4', 'http://timg.bdta.pro/images/9a1e9b83dc16971c87a277f9aa2201d9.jpg'),
(84342, 5851, 'One Piece S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/257989.mp4', 'http://timg.bdta.pro/images/beba252c9a3ae706f4b318d68bc219cf.jpg'),
(84343, 5851, 'One Piece S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/257990.mp4', 'http://timg.bdta.pro/images/0570dda725cfd18b41ffea8ad624a10d.jpg'),
(84344, 5851, 'One Piece S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/257991.mp4', 'http://timg.bdta.pro/images/14cb4a3755688b2f4cb20c594b7e5aec.jpg'),
(84345, 5851, 'One Piece S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/257992.mp4', 'http://timg.bdta.pro/images/e01c1ed69fe67af09a64539c96747369.jpg'),
(84346, 5851, 'One Piece S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/257993.mp4', 'http://timg.bdta.pro/images/fcc5e582cab5bb9d489e86721598803b.jpg'),
(84347, 5851, 'One Piece S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/257994.mp4', 'http://timg.bdta.pro/images/0324ab664e0124f03a7f8e0fff483889.jpg'),
(84348, 5851, 'One Piece S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/257995.mp4', 'http://timg.bdta.pro/images/b01d08708febabd23161757321ce9f98.jpg'),
(84349, 5851, 'One Piece S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/257996.mp4', 'http://timg.bdta.pro/images/cbe19906e82671fa4f460af3edc0b230.jpg'),
(84350, 5851, 'One Piece S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/257997.mp4', 'http://timg.bdta.pro/images/f0ef658531c9e8246266293a461a6dd4.jpg'),
(84351, 5851, 'One Piece S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/257998.mp4', 'http://timg.bdta.pro/images/e1d6860d9b2a84415bb3a770f000cae3.jpg'),
(84352, 5851, 'One Piece S07 E27', 'http://sinalprivado.info:80/series/1533784/1533784/257999.mp4', 'http://timg.bdta.pro/images/f5b9c8204250b4165c7e236f3a95a999.jpg'),
(84353, 5851, 'One Piece S07 E28', 'http://sinalprivado.info:80/series/1533784/1533784/258000.mp4', 'http://timg.bdta.pro/images/9784580601dc6e7e3f4d6900d4414c6f.jpg'),
(84354, 5851, 'One Piece S07 E29', 'http://sinalprivado.info:80/series/1533784/1533784/258001.mp4', 'http://timg.bdta.pro/images/91158397dde3fae8932fb4adce15f2da.jpg'),
(84355, 5851, 'One Piece S07 E30', 'http://sinalprivado.info:80/series/1533784/1533784/258002.mp4', 'http://timg.bdta.pro/images/ee135d51735fcc4a317c2988171e39d5.jpg'),
(84356, 5851, 'One Piece S07 E31', 'http://sinalprivado.info:80/series/1533784/1533784/258003.mp4', 'http://timg.bdta.pro/images/3713a0e174d8afbf31655c70d50450d1.jpg'),
(84357, 5851, 'One Piece S07 E32', 'http://sinalprivado.info:80/series/1533784/1533784/258004.mp4', 'http://timg.bdta.pro/images/900b72161fd2120f2b8710d272ee976e.jpg'),
(84358, 5851, 'One Piece S07 E33', 'http://sinalprivado.info:80/series/1533784/1533784/258005.mp4', 'http://timg.bdta.pro/images/3f7ba1832ceab90b28876e8f5ed4078f.jpg'),
(84359, 5852, 'One Piece S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258006.mp4', 'http://timg.bdta.pro/images/570fa2af036529fa4bd65f4403bb3a85.jpg'),
(84360, 5852, 'One Piece S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258007.mp4', 'http://timg.bdta.pro/images/7b72163aa4d1fcb68a582b15ae9a27d0.jpg'),
(84361, 5852, 'One Piece S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258008.mp4', 'http://timg.bdta.pro/images/f839ffea39486b4a51814915d737ff80.jpg'),
(84362, 5852, 'One Piece S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258009.mp4', 'http://timg.bdta.pro/images/80a19d851146a653909f30e731c23452.jpg'),
(84363, 5852, 'One Piece S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258010.mp4', 'http://timg.bdta.pro/images/546ff7ad2649617215dac654f5ee5914.jpg'),
(84364, 5852, 'One Piece S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258011.mp4', 'http://timg.bdta.pro/images/ac2b854091b5fde79c304367f8834f08.jpg'),
(84365, 5852, 'One Piece S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258012.mp4', 'http://timg.bdta.pro/images/94194a04d02c7d6ad8a6b4abbb20a0df.jpg'),
(84366, 5852, 'One Piece S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258013.mp4', 'http://timg.bdta.pro/images/b02070590b9947a9771562fe78a226a6.jpg'),
(84367, 5852, 'One Piece S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258014.mp4', 'http://timg.bdta.pro/images/3ac96bbcc0da3dd111e6c61c40727512.jpg'),
(84368, 5852, 'One Piece S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258015.mp4', 'http://timg.bdta.pro/images/faf3f11eb6d644ed6ba9fb067b709f65.jpg'),
(84369, 5852, 'One Piece S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/258016.mp4', 'http://timg.bdta.pro/images/36c94f81456e709b627f621da9f899c9.jpg'),
(84370, 5852, 'One Piece S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/258017.mp4', 'http://timg.bdta.pro/images/950f9d64b1d995f6271a99045ef89cd4.jpg'),
(84371, 5852, 'One Piece S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/258018.mp4', 'http://timg.bdta.pro/images/42a114c68bf9367f95734ab671529bd6.jpg'),
(84372, 5852, 'One Piece S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/258019.mp4', 'http://timg.bdta.pro/images/7b441f53389947625fd0f90223f11dbc.jpg'),
(84373, 5852, 'One Piece S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/258020.mp4', 'http://timg.bdta.pro/images/3882cababf124925049d485fbd1d30ca.jpg'),
(84374, 5852, 'One Piece S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/258021.mp4', 'http://timg.bdta.pro/images/60aa517fab964c01374332b8db8b5051.jpg'),
(84375, 5852, 'One Piece S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/258022.mp4', 'http://timg.bdta.pro/images/d1f2b8e83dfbdf0194b97aa9ab3bd5f0.jpg'),
(84376, 5852, 'One Piece S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/258023.mp4', 'http://timg.bdta.pro/images/0b04e7e518ba0040269ad9a2b749ef14.jpg'),
(84377, 5852, 'One Piece S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/258024.mp4', 'http://timg.bdta.pro/images/641f06dbb8c5c4d20e246f1a0790c236.jpg'),
(84378, 5852, 'One Piece S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/258025.mp4', 'http://timg.bdta.pro/images/492b183565b582447bd96f78ba9e29e6.jpg'),
(84379, 5852, 'One Piece S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/258026.mp4', 'http://timg.bdta.pro/images/949656ded40ebb7e9998d6e650ab3a8b.jpg'),
(84380, 5852, 'One Piece S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/258027.mp4', 'http://timg.bdta.pro/images/53e0130fd2156ef0f831ae33c724b3a4.jpg'),
(84381, 5852, 'One Piece S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/258028.mp4', 'http://timg.bdta.pro/images/b53971efb891ac356d6e266e751d3bac.jpg'),
(84382, 5852, 'One Piece S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/258029.mp4', 'http://timg.bdta.pro/images/4584a21a73cfd3007bc3218f731ae270.jpg'),
(84383, 5852, 'One Piece S08 E25', 'http://sinalprivado.info:80/series/1533784/1533784/258030.mp4', 'http://timg.bdta.pro/images/dab5198c62164a01d3c7d5563c271bc0.jpg'),
(84384, 5852, 'One Piece S08 E26', 'http://sinalprivado.info:80/series/1533784/1533784/258031.mp4', 'http://timg.bdta.pro/images/24016cdc818fedcdbe62d38235293a27.jpg'),
(84385, 5852, 'One Piece S08 E27', 'http://sinalprivado.info:80/series/1533784/1533784/258032.mp4', 'http://timg.bdta.pro/images/e45830d73d9c1726555c041310f49095.jpg'),
(84386, 5852, 'One Piece S08 E28', 'http://sinalprivado.info:80/series/1533784/1533784/258033.mp4', 'http://timg.bdta.pro/images/9f789af61fc55107883c069ed332fd1a.jpg'),
(84387, 5852, 'One Piece S08 E29', 'http://sinalprivado.info:80/series/1533784/1533784/258034.mp4', 'http://timg.bdta.pro/images/5aa73f573efc6f2d330d48bf951076c0.jpg'),
(84388, 5852, 'One Piece S08 E30', 'http://sinalprivado.info:80/series/1533784/1533784/258035.mp4', 'http://timg.bdta.pro/images/8cc2e60bfc6509b37aaf6751771595cb.jpg'),
(84389, 5852, 'One Piece S08 E31', 'http://sinalprivado.info:80/series/1533784/1533784/258036.mp4', 'http://timg.bdta.pro/images/e0492e925e853e8475dc971470082c64.jpg'),
(84390, 5852, 'One Piece S08 E32', 'http://sinalprivado.info:80/series/1533784/1533784/258037.mp4', 'http://timg.bdta.pro/images/b669e1c9b177d1871e9757732b20c701.jpg'),
(84391, 5852, 'One Piece S08 E33', 'http://sinalprivado.info:80/series/1533784/1533784/258038.mp4', 'http://timg.bdta.pro/images/3b3c9bf7507f986846cedb21ef67eb08.jpg'),
(84392, 5852, 'One Piece S08 E34', 'http://sinalprivado.info:80/series/1533784/1533784/258039.mp4', 'http://timg.bdta.pro/images/eca76c2b4ed4b41964d7b20f3f3c1d33.jpg'),
(84393, 5852, 'One Piece S08 E35', 'http://sinalprivado.info:80/series/1533784/1533784/258040.mp4', 'http://timg.bdta.pro/images/f0a676515c97c992d80e03edc0029b4e.jpg'),
(84394, 5853, 'One Piece S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258041.mp4', 'http://timg.bdta.pro/images/484e6d9b47b18b83a20e3622f1e4d50c.jpg'),
(84395, 5853, 'One Piece S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258042.mp4', 'http://timg.bdta.pro/images/307c97822cf232c9e8f0db2c9d9cceee.jpg'),
(84396, 5853, 'One Piece S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258043.mp4', 'http://timg.bdta.pro/images/cc256904c997ffce5f3c39f683413699.jpg'),
(84397, 5853, 'One Piece S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258044.mp4', 'http://timg.bdta.pro/images/c8733808bbe0d1c22c0067f73ed03e2e.jpg'),
(84398, 5853, 'One Piece S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258045.mp4', 'http://timg.bdta.pro/images/5b9b95950daf58f69bb8499be2ff7f7f.jpg'),
(84399, 5853, 'One Piece S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258046.mp4', 'http://timg.bdta.pro/images/8bf57eef903aba1e624bc2e77e3304f9.jpg'),
(84400, 5853, 'One Piece S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258047.mp4', 'http://timg.bdta.pro/images/876d366eddbda1be756aa76dc46e7dee.jpg'),
(84401, 5853, 'One Piece S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258048.mp4', 'http://timg.bdta.pro/images/39e96b19a500316fe788b159ee3b4069.jpg'),
(84402, 5853, 'One Piece S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258049.mp4', 'http://timg.bdta.pro/images/224d3a7c36113c06dd2d4f14b2d50edd.jpg'),
(84403, 5853, 'One Piece S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258050.mp4', 'http://timg.bdta.pro/images/6e9cb1095dadc0b71d57a967d3c1b113.jpg'),
(84404, 5853, 'One Piece S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/258051.mp4', 'http://timg.bdta.pro/images/98a9d05813d75cdb4055793bc1fff954.jpg'),
(84405, 5853, 'One Piece S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/258052.mp4', 'http://timg.bdta.pro/images/f5dc994f7f266f6f5aef44c7a221a117.jpg'),
(84406, 5853, 'One Piece S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/258053.mp4', 'http://timg.bdta.pro/images/fa43e8803f63ada929a587a050d252e1.jpg'),
(84407, 5853, 'One Piece S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/258054.mp4', 'http://timg.bdta.pro/images/f7a1690a42b6d73e64d0d62f389262ab.jpg'),
(84408, 5853, 'One Piece S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/258055.mp4', 'http://timg.bdta.pro/images/6c702f0ffc91cb8e5572067c972b038f.jpg'),
(84409, 5853, 'One Piece S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/258056.mp4', 'http://timg.bdta.pro/images/9e141855368b7bb7f6aa64c7c4743186.jpg'),
(84410, 5853, 'One Piece S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/258057.mp4', 'http://timg.bdta.pro/images/47e0265102fc25c730a240ac0ef99256.jpg'),
(84411, 5853, 'One Piece S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/258058.mp4', 'http://timg.bdta.pro/images/2f0d86ed838647fb0ff06c3ee15a8648.jpg'),
(84412, 5853, 'One Piece S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/258059.mp4', 'http://timg.bdta.pro/images/607079f8ad14a390a78628ce3b679a22.jpg'),
(84413, 5853, 'One Piece S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/258060.mp4', 'http://timg.bdta.pro/images/827b1f9d9024a516eff858b726d1d8b7.jpg'),
(84414, 5853, 'One Piece S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/258061.mp4', 'http://timg.bdta.pro/images/44c1076c090d9217f3fa001c4b1780db.jpg'),
(84415, 5853, 'One Piece S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/258062.mp4', 'http://timg.bdta.pro/images/61e82a76e0f4a2e6080fdc65bb58b91a.jpg'),
(84416, 5853, 'One Piece S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/258063.mp4', 'http://timg.bdta.pro/images/a574e50dadfe4d02311f78c9ecee6de6.jpg'),
(84417, 5853, 'One Piece S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/258064.mp4', 'http://timg.bdta.pro/images/b984e0d959511670bbd4a42bfd933ab7.jpg'),
(84418, 5853, 'One Piece S09 E25', 'http://sinalprivado.info:80/series/1533784/1533784/258065.mp4', 'http://timg.bdta.pro/images/915c5a2c70ea8e62b2cf87738b8ce658.jpg'),
(84419, 5853, 'One Piece S09 E26', 'http://sinalprivado.info:80/series/1533784/1533784/258066.mp4', 'http://timg.bdta.pro/images/5d717851da5e8ae1d5c81cebbbeb0a0f.jpg'),
(84420, 5853, 'One Piece S09 E27', 'http://sinalprivado.info:80/series/1533784/1533784/258067.mp4', 'http://timg.bdta.pro/images/8ea31cf90848f87a3d84d17472b77cbf.jpg'),
(84421, 5853, 'One Piece S09 E28', 'http://sinalprivado.info:80/series/1533784/1533784/258068.mp4', 'http://timg.bdta.pro/images/92986c6b958fd8f69f956521340581ee.jpg'),
(84422, 5853, 'One Piece S09 E29', 'http://sinalprivado.info:80/series/1533784/1533784/258069.mp4', 'http://timg.bdta.pro/images/544b83e9cef2cfc86b210aa4918426b3.jpg'),
(84423, 5853, 'One Piece S09 E30', 'http://sinalprivado.info:80/series/1533784/1533784/258070.mp4', 'http://timg.bdta.pro/images/0026456ee7bd8ebdd9dd109ac73fff96.jpg'),
(84424, 5853, 'One Piece S09 E31', 'http://sinalprivado.info:80/series/1533784/1533784/258071.mp4', 'http://timg.bdta.pro/images/05393a467bbd4c8e1c4a828525ff4517.jpg'),
(84425, 5853, 'One Piece S09 E32', 'http://sinalprivado.info:80/series/1533784/1533784/258072.mp4', 'http://timg.bdta.pro/images/668d406a22186273fc9f26c65bc508fc.jpg'),
(84426, 5853, 'One Piece S09 E33', 'http://sinalprivado.info:80/series/1533784/1533784/258073.mp4', 'http://timg.bdta.pro/images/2e42572ef524d812b8a3d614d221abd7.jpg'),
(84427, 5853, 'One Piece S09 E34', 'http://sinalprivado.info:80/series/1533784/1533784/258074.mp4', 'http://timg.bdta.pro/images/fbea22e84af1e204f110cf189c6baa15.jpg'),
(84428, 5853, 'One Piece S09 E35', 'http://sinalprivado.info:80/series/1533784/1533784/258075.mp4', 'http://timg.bdta.pro/images/660a28f53b29f2a13fef5d34df0f0f9f.jpg'),
(84429, 5853, 'One Piece S09 E36', 'http://sinalprivado.info:80/series/1533784/1533784/258076.mp4', 'http://timg.bdta.pro/images/e4e2b3783df2b6c2f5352009588a1248.jpg'),
(84430, 5853, 'One Piece S09 E37', 'http://sinalprivado.info:80/series/1533784/1533784/258077.mp4', 'http://timg.bdta.pro/images/4d121c4d2325bffb3147f11009e48161.jpg'),
(84431, 5853, 'One Piece S09 E38', 'http://sinalprivado.info:80/series/1533784/1533784/258078.mp4', 'http://timg.bdta.pro/images/21a7e338f66f9e506e804d5fa653ab1c.jpg'),
(84432, 5853, 'One Piece S09 E39', 'http://sinalprivado.info:80/series/1533784/1533784/258079.mp4', 'http://timg.bdta.pro/images/86b9d2fcf2a1e2521837e1b1c6de45b1.jpg'),
(84433, 5853, 'One Piece S09 E40', 'http://sinalprivado.info:80/series/1533784/1533784/258080.mp4', 'http://timg.bdta.pro/images/ffcc0bea374eed6e31af9f54cb7109f9.jpg'),
(84434, 5853, 'One Piece S09 E41', 'http://sinalprivado.info:80/series/1533784/1533784/258081.mp4', 'http://timg.bdta.pro/images/fe03168f23c357d609d046690480cf5a.jpg'),
(84435, 5853, 'One Piece S09 E42', 'http://sinalprivado.info:80/series/1533784/1533784/258082.mp4', 'http://timg.bdta.pro/images/e2c92bd111f2e05942e904434f4e476e.jpg'),
(84436, 5853, 'One Piece S09 E43', 'http://sinalprivado.info:80/series/1533784/1533784/258083.mp4', 'http://timg.bdta.pro/images/4d5ef1806bd38823c1f473f1bdb8ff9c.jpg'),
(84437, 5853, 'One Piece S09 E44', 'http://sinalprivado.info:80/series/1533784/1533784/258084.mp4', 'http://timg.bdta.pro/images/15d8bcc785b721d77d271c8b70c6241a.jpg'),
(84438, 5853, 'One Piece S09 E45', 'http://sinalprivado.info:80/series/1533784/1533784/258085.mp4', 'http://timg.bdta.pro/images/e17577c50b69d3415d90270661b40063.jpg'),
(84439, 5853, 'One Piece S09 E46', 'http://sinalprivado.info:80/series/1533784/1533784/258086.mp4', 'http://timg.bdta.pro/images/63551d67229a07c3df93cb842171fb00.jpg'),
(84440, 5853, 'One Piece S09 E47', 'http://sinalprivado.info:80/series/1533784/1533784/258087.mp4', 'http://timg.bdta.pro/images/71bfe48188bc0e2d802b656753abe507.jpg'),
(84441, 5853, 'One Piece S09 E48', 'http://sinalprivado.info:80/series/1533784/1533784/258088.mp4', 'http://timg.bdta.pro/images/352f302ac0d4b26c7c00717436900041.jpg'),
(84442, 5853, 'One Piece S09 E49', 'http://sinalprivado.info:80/series/1533784/1533784/258089.mp4', 'http://timg.bdta.pro/images/463011ab16baaf44d012d7c6e67fb849.jpg'),
(84443, 5853, 'One Piece S09 E50', 'http://sinalprivado.info:80/series/1533784/1533784/258090.mp4', 'http://timg.bdta.pro/images/5849395a413acba61a7637e3265057b7.jpg'),
(84444, 5853, 'One Piece S09 E51', 'http://sinalprivado.info:80/series/1533784/1533784/258091.mp4', 'http://timg.bdta.pro/images/70c77eb9246387113ea8c990fbbcb9d0.jpg'),
(84445, 5853, 'One Piece S09 E52', 'http://sinalprivado.info:80/series/1533784/1533784/258092.mp4', 'http://timg.bdta.pro/images/0c2c67023592f50e6297653b99c24bce.jpg'),
(84446, 5853, 'One Piece S09 E53', 'http://sinalprivado.info:80/series/1533784/1533784/258093.mp4', 'http://timg.bdta.pro/images/083a9cb34d6fb83702447285e7764487.jpg'),
(84447, 5853, 'One Piece S09 E54', 'http://sinalprivado.info:80/series/1533784/1533784/258094.mp4', 'http://timg.bdta.pro/images/2cbd14112ff9d24aa0ce39cde02a4f63.jpg'),
(84448, 5853, 'One Piece S09 E55', 'http://sinalprivado.info:80/series/1533784/1533784/258095.mp4', 'http://timg.bdta.pro/images/71824f017b954fb89f82782739ce6c5e.jpg'),
(84449, 5853, 'One Piece S09 E56', 'http://sinalprivado.info:80/series/1533784/1533784/258096.mp4', 'http://timg.bdta.pro/images/a2d21ccd6efef15378d4480a01922bea.jpg'),
(84450, 5853, 'One Piece S09 E57', 'http://sinalprivado.info:80/series/1533784/1533784/258097.mp4', 'http://timg.bdta.pro/images/e8db7811a7fcb1a7c27d5c4c9b68cebd.jpg'),
(84451, 5853, 'One Piece S09 E58', 'http://sinalprivado.info:80/series/1533784/1533784/258098.mp4', 'http://timg.bdta.pro/images/60b54a74ecd6174fe934bb04e009a5bc.jpg'),
(84452, 5853, 'One Piece S09 E59', 'http://sinalprivado.info:80/series/1533784/1533784/258099.mp4', 'http://timg.bdta.pro/images/4ec040cbd662bf67b940dad37b0709b9.jpg'),
(84453, 5853, 'One Piece S09 E60', 'http://sinalprivado.info:80/series/1533784/1533784/258100.mp4', 'http://timg.bdta.pro/images/eb58003805e7614c9a1ec4900411e702.jpg'),
(84454, 5853, 'One Piece S09 E61', 'http://sinalprivado.info:80/series/1533784/1533784/258101.mp4', 'http://timg.bdta.pro/images/aace0f1667d3d36f7b21c0ee76a797b8.jpg'),
(84455, 5853, 'One Piece S09 E62', 'http://sinalprivado.info:80/series/1533784/1533784/258102.mp4', 'http://timg.bdta.pro/images/1ddeea6bd19d71f999aa69c9b7d361c5.jpg'),
(84456, 5853, 'One Piece S09 E63', 'http://sinalprivado.info:80/series/1533784/1533784/258103.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84457, 5853, 'One Piece S09 E64', 'http://sinalprivado.info:80/series/1533784/1533784/258104.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84458, 5853, 'One Piece S09 E65', 'http://sinalprivado.info:80/series/1533784/1533784/258105.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84459, 5853, 'One Piece S09 E66', 'http://sinalprivado.info:80/series/1533784/1533784/258106.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84460, 5853, 'One Piece S09 E67', 'http://sinalprivado.info:80/series/1533784/1533784/258107.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84461, 5853, 'One Piece S09 E68', 'http://sinalprivado.info:80/series/1533784/1533784/258108.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84462, 5853, 'One Piece S09 E69', 'http://sinalprivado.info:80/series/1533784/1533784/258109.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84463, 5853, 'One Piece S09 E70', 'http://sinalprivado.info:80/series/1533784/1533784/258110.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84464, 5853, 'One Piece S09 E71', 'http://sinalprivado.info:80/series/1533784/1533784/258111.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84465, 5853, 'One Piece S09 E72', 'http://sinalprivado.info:80/series/1533784/1533784/258112.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(84466, 5853, 'One Piece S09 E73', 'http://sinalprivado.info:80/series/1533784/1533784/258113.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84467, 5854, 'One Piece S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258114.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84468, 5854, 'One Piece S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258115.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84469, 5854, 'One Piece S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258116.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84470, 5854, 'One Piece S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258117.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84471, 5854, 'One Piece S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258118.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84472, 5854, 'One Piece S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258119.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84473, 5854, 'One Piece S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258120.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84474, 5854, 'One Piece S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258121.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84475, 5854, 'One Piece S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258122.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84476, 5854, 'One Piece S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258123.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84477, 5854, 'One Piece S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/258124.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84478, 5854, 'One Piece S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/258125.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84479, 5854, 'One Piece S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/258126.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84480, 5854, 'One Piece S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/258127.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84481, 5854, 'One Piece S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/258128.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84482, 5854, 'One Piece S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/258129.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84483, 5854, 'One Piece S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/258130.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84484, 5854, 'One Piece S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/258131.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84485, 5854, 'One Piece S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/258132.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84486, 5854, 'One Piece S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/258133.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84487, 5854, 'One Piece S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/258134.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84488, 5854, 'One Piece S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/258135.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84489, 5854, 'One Piece S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/258136.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84490, 5854, 'One Piece S10 E24', 'http://sinalprivado.info:80/series/1533784/1533784/258137.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84491, 5854, 'One Piece S10 E25', 'http://sinalprivado.info:80/series/1533784/1533784/258138.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84492, 5854, 'One Piece S10 E26', 'http://sinalprivado.info:80/series/1533784/1533784/258139.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84493, 5854, 'One Piece S10 E27', 'http://sinalprivado.info:80/series/1533784/1533784/258140.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84494, 5854, 'One Piece S10 E28', 'http://sinalprivado.info:80/series/1533784/1533784/258141.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84495, 5854, 'One Piece S10 E29', 'http://sinalprivado.info:80/series/1533784/1533784/258142.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84496, 5854, 'One Piece S10 E30', 'http://sinalprivado.info:80/series/1533784/1533784/258143.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84497, 5854, 'One Piece S10 E31', 'http://sinalprivado.info:80/series/1533784/1533784/258144.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84498, 5854, 'One Piece S10 E32', 'http://sinalprivado.info:80/series/1533784/1533784/258145.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84499, 5854, 'One Piece S10 E33', 'http://sinalprivado.info:80/series/1533784/1533784/258146.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84500, 5854, 'One Piece S10 E34', 'http://sinalprivado.info:80/series/1533784/1533784/258147.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84501, 5854, 'One Piece S10 E35', 'http://sinalprivado.info:80/series/1533784/1533784/258148.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84502, 5854, 'One Piece S10 E36', 'http://sinalprivado.info:80/series/1533784/1533784/258149.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84503, 5854, 'One Piece S10 E37', 'http://sinalprivado.info:80/series/1533784/1533784/258150.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84504, 5854, 'One Piece S10 E38', 'http://sinalprivado.info:80/series/1533784/1533784/258151.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84505, 5854, 'One Piece S10 E39', 'http://sinalprivado.info:80/series/1533784/1533784/258152.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84506, 5854, 'One Piece S10 E40', 'http://sinalprivado.info:80/series/1533784/1533784/258153.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84507, 5854, 'One Piece S10 E41', 'http://sinalprivado.info:80/series/1533784/1533784/258154.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84508, 5854, 'One Piece S10 E42', 'http://sinalprivado.info:80/series/1533784/1533784/258155.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84509, 5854, 'One Piece S10 E43', 'http://sinalprivado.info:80/series/1533784/1533784/258156.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84510, 5854, 'One Piece S10 E44', 'http://sinalprivado.info:80/series/1533784/1533784/258157.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84511, 5854, 'One Piece S10 E45', 'http://sinalprivado.info:80/series/1533784/1533784/258158.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84512, 5855, 'One Piece S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/678821.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84513, 5855, 'One Piece S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/678822.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84514, 5855, 'One Piece S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/678823.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84515, 5855, 'One Piece S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/678824.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84516, 5855, 'One Piece S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/678825.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84517, 5855, 'One Piece S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/678826.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84518, 5855, 'One Piece S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/678827.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84519, 5855, 'One Piece S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/678828.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84520, 5855, 'One Piece S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/678829.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84521, 5855, 'One Piece S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/678830.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84522, 5855, 'One Piece S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/678831.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84523, 5855, 'One Piece S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/678832.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84524, 5855, 'One Piece S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/678833.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84525, 5855, 'One Piece S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/678834.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84526, 5855, 'One Piece S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/678835.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84527, 5855, 'One Piece S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/678836.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84528, 5855, 'One Piece S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/678837.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84529, 5855, 'One Piece S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/678838.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84530, 5855, 'One Piece S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/678839.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84531, 5855, 'One Piece S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/678840.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84532, 5855, 'One Piece S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/678841.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84533, 5855, 'One Piece S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/678842.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84534, 5855, 'One Piece S11 E23', 'http://sinalprivado.info:80/series/1533784/1533784/678843.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84535, 5855, 'One Piece S11 E24', 'http://sinalprivado.info:80/series/1533784/1533784/678844.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84536, 5855, 'One Piece S11 E25', 'http://sinalprivado.info:80/series/1533784/1533784/678845.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84537, 5855, 'One Piece S11 E26', 'http://sinalprivado.info:80/series/1533784/1533784/678846.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84538, 5856, 'One Piece S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/678847.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84539, 5856, 'One Piece S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/678848.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84540, 5856, 'One Piece S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/678849.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84541, 5856, 'One Piece S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/678850.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84542, 5856, 'One Piece S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/678851.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84543, 5856, 'One Piece S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/678852.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84544, 5856, 'One Piece S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/678853.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84545, 5856, 'One Piece S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/678854.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84546, 5856, 'One Piece S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/678855.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84547, 5856, 'One Piece S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/678856.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84548, 5856, 'One Piece S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/678857.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84549, 5856, 'One Piece S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/678858.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84550, 5856, 'One Piece S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/678859.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84551, 5856, 'One Piece S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/678860.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84552, 5857, 'One Piece S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/678861.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84553, 5857, 'One Piece S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/678862.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84554, 5857, 'One Piece S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/678863.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84555, 5857, 'One Piece S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/678864.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84556, 5857, 'One Piece S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/678865.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84557, 5857, 'One Piece S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/678866.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84558, 5857, 'One Piece S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/678867.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84559, 5857, 'One Piece S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/678868.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84560, 5857, 'One Piece S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/678869.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84561, 5857, 'One Piece S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/678870.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84562, 5857, 'One Piece S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/678871.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84563, 5857, 'One Piece S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/678872.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84564, 5857, 'One Piece S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/678873.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84565, 5857, 'One Piece S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/678874.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84566, 5857, 'One Piece S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/678875.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84567, 5857, 'One Piece S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/678876.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84568, 5857, 'One Piece S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/678877.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84569, 5857, 'One Piece S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/678878.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84570, 5857, 'One Piece S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/678879.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84571, 5857, 'One Piece S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/678880.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84572, 5857, 'One Piece S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/678881.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84573, 5857, 'One Piece S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/678882.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84574, 5857, 'One Piece S13 E23', 'http://sinalprivado.info:80/series/1533784/1533784/678883.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84575, 5857, 'One Piece S13 E24', 'http://sinalprivado.info:80/series/1533784/1533784/678884.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84576, 5857, 'One Piece S13 E25', 'http://sinalprivado.info:80/series/1533784/1533784/678885.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84577, 5857, 'One Piece S13 E26', 'http://sinalprivado.info:80/series/1533784/1533784/678886.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84578, 5857, 'One Piece S13 E27', 'http://sinalprivado.info:80/series/1533784/1533784/678887.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84579, 5857, 'One Piece S13 E28', 'http://sinalprivado.info:80/series/1533784/1533784/678888.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84580, 5857, 'One Piece S13 E29', 'http://sinalprivado.info:80/series/1533784/1533784/678889.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84581, 5857, 'One Piece S13 E30', 'http://sinalprivado.info:80/series/1533784/1533784/678890.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84582, 5857, 'One Piece S13 E31', 'http://sinalprivado.info:80/series/1533784/1533784/678891.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84583, 5857, 'One Piece S13 E32', 'http://sinalprivado.info:80/series/1533784/1533784/678892.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84584, 5857, 'One Piece S13 E33', 'http://sinalprivado.info:80/series/1533784/1533784/678893.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84585, 5857, 'One Piece S13 E34', 'http://sinalprivado.info:80/series/1533784/1533784/678894.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84586, 5857, 'One Piece S13 E35', 'http://sinalprivado.info:80/series/1533784/1533784/678895.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84587, 5857, 'One Piece S13 E36', 'http://sinalprivado.info:80/series/1533784/1533784/678896.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84588, 5857, 'One Piece S13 E37', 'http://sinalprivado.info:80/series/1533784/1533784/678897.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84589, 5857, 'One Piece S13 E38', 'http://sinalprivado.info:80/series/1533784/1533784/678898.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84590, 5857, 'One Piece S13 E39', 'http://sinalprivado.info:80/series/1533784/1533784/678899.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84591, 5857, 'One Piece S13 E40', 'http://sinalprivado.info:80/series/1533784/1533784/678900.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84592, 5857, 'One Piece S13 E41', 'http://sinalprivado.info:80/series/1533784/1533784/678901.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84593, 5857, 'One Piece S13 E42', 'http://sinalprivado.info:80/series/1533784/1533784/678902.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84594, 5857, 'One Piece S13 E43', 'http://sinalprivado.info:80/series/1533784/1533784/678903.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84595, 5857, 'One Piece S13 E44', 'http://sinalprivado.info:80/series/1533784/1533784/678904.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84596, 5857, 'One Piece S13 E45', 'http://sinalprivado.info:80/series/1533784/1533784/678905.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84597, 5857, 'One Piece S13 E46', 'http://sinalprivado.info:80/series/1533784/1533784/678906.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84598, 5857, 'One Piece S13 E47', 'http://sinalprivado.info:80/series/1533784/1533784/678907.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84599, 5857, 'One Piece S13 E48', 'http://sinalprivado.info:80/series/1533784/1533784/678908.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84600, 5857, 'One Piece S13 E49', 'http://sinalprivado.info:80/series/1533784/1533784/678909.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84601, 5857, 'One Piece S13 E50', 'http://sinalprivado.info:80/series/1533784/1533784/678910.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84602, 5857, 'One Piece S13 E51', 'http://sinalprivado.info:80/series/1533784/1533784/678911.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84603, 5857, 'One Piece S13 E52', 'http://sinalprivado.info:80/series/1533784/1533784/678912.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84604, 5857, 'One Piece S13 E53', 'http://sinalprivado.info:80/series/1533784/1533784/678913.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84605, 5857, 'One Piece S13 E54', 'http://sinalprivado.info:80/series/1533784/1533784/678914.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84606, 5857, 'One Piece S13 E55', 'http://sinalprivado.info:80/series/1533784/1533784/678915.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84607, 5857, 'One Piece S13 E56', 'http://sinalprivado.info:80/series/1533784/1533784/678916.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84608, 5857, 'One Piece S13 E57', 'http://sinalprivado.info:80/series/1533784/1533784/678917.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84609, 5857, 'One Piece S13 E58', 'http://sinalprivado.info:80/series/1533784/1533784/678918.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84610, 5857, 'One Piece S13 E59', 'http://sinalprivado.info:80/series/1533784/1533784/678919.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84611, 5857, 'One Piece S13 E60', 'http://sinalprivado.info:80/series/1533784/1533784/678920.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84612, 5857, 'One Piece S13 E61', 'http://sinalprivado.info:80/series/1533784/1533784/678921.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84613, 5857, 'One Piece S13 E62', 'http://sinalprivado.info:80/series/1533784/1533784/678922.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84614, 5857, 'One Piece S13 E63', 'http://sinalprivado.info:80/series/1533784/1533784/678923.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84615, 5857, 'One Piece S13 E64', 'http://sinalprivado.info:80/series/1533784/1533784/678924.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84616, 5857, 'One Piece S13 E65', 'http://sinalprivado.info:80/series/1533784/1533784/678925.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84617, 5857, 'One Piece S13 E66', 'http://sinalprivado.info:80/series/1533784/1533784/678926.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84618, 5857, 'One Piece S13 E67', 'http://sinalprivado.info:80/series/1533784/1533784/678927.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84619, 5857, 'One Piece S13 E68', 'http://sinalprivado.info:80/series/1533784/1533784/678928.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84620, 5857, 'One Piece S13 E69', 'http://sinalprivado.info:80/series/1533784/1533784/678929.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84621, 5857, 'One Piece S13 E70', 'http://sinalprivado.info:80/series/1533784/1533784/678930.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84622, 5857, 'One Piece S13 E71', 'http://sinalprivado.info:80/series/1533784/1533784/678931.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84623, 5857, 'One Piece S13 E72', 'http://sinalprivado.info:80/series/1533784/1533784/678932.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84624, 5857, 'One Piece S13 E73', 'http://sinalprivado.info:80/series/1533784/1533784/678933.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84625, 5857, 'One Piece S13 E74', 'http://sinalprivado.info:80/series/1533784/1533784/678934.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84626, 5857, 'One Piece S13 E75', 'http://sinalprivado.info:80/series/1533784/1533784/678935.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84627, 5857, 'One Piece S13 E76', 'http://sinalprivado.info:80/series/1533784/1533784/678936.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84628, 5857, 'One Piece S13 E77', 'http://sinalprivado.info:80/series/1533784/1533784/678937.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84629, 5857, 'One Piece S13 E78', 'http://sinalprivado.info:80/series/1533784/1533784/678938.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84630, 5857, 'One Piece S13 E79', 'http://sinalprivado.info:80/series/1533784/1533784/678939.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84631, 5857, 'One Piece S13 E80', 'http://sinalprivado.info:80/series/1533784/1533784/678940.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84632, 5857, 'One Piece S13 E81', 'http://sinalprivado.info:80/series/1533784/1533784/678941.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84633, 5857, 'One Piece S13 E82', 'http://sinalprivado.info:80/series/1533784/1533784/678942.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84634, 5857, 'One Piece S13 E83', 'http://sinalprivado.info:80/series/1533784/1533784/678943.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84635, 5857, 'One Piece S13 E84', 'http://sinalprivado.info:80/series/1533784/1533784/678944.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84636, 5857, 'One Piece S13 E85', 'http://sinalprivado.info:80/series/1533784/1533784/678945.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84637, 5857, 'One Piece S13 E86', 'http://sinalprivado.info:80/series/1533784/1533784/678946.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84638, 5857, 'One Piece S13 E87', 'http://sinalprivado.info:80/series/1533784/1533784/678947.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84639, 5857, 'One Piece S13 E88', 'http://sinalprivado.info:80/series/1533784/1533784/678948.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84640, 5857, 'One Piece S13 E89', 'http://sinalprivado.info:80/series/1533784/1533784/678949.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84641, 5857, 'One Piece S13 E90', 'http://sinalprivado.info:80/series/1533784/1533784/678950.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84642, 5857, 'One Piece S13 E91', 'http://sinalprivado.info:80/series/1533784/1533784/678951.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84643, 5857, 'One Piece S13 E92', 'http://sinalprivado.info:80/series/1533784/1533784/678952.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84644, 5857, 'One Piece S13 E93', 'http://sinalprivado.info:80/series/1533784/1533784/678953.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84645, 5857, 'One Piece S13 E94', 'http://sinalprivado.info:80/series/1533784/1533784/678954.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84646, 5857, 'One Piece S13 E95', 'http://sinalprivado.info:80/series/1533784/1533784/678955.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84647, 5857, 'One Piece S13 E96', 'http://sinalprivado.info:80/series/1533784/1533784/678956.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84648, 5857, 'One Piece S13 E97', 'http://sinalprivado.info:80/series/1533784/1533784/678957.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84649, 5857, 'One Piece S13 E98', 'http://sinalprivado.info:80/series/1533784/1533784/678958.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84650, 5857, 'One Piece S13 E99', 'http://sinalprivado.info:80/series/1533784/1533784/678959.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84651, 5857, 'One Piece S13 E100', 'http://sinalprivado.info:80/series/1533784/1533784/678960.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84652, 5857, 'One Piece S13 E101', 'http://sinalprivado.info:80/series/1533784/1533784/678961.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84653, 5858, 'One Piece S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/678962.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84654, 5858, 'One Piece S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/678963.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84655, 5858, 'One Piece S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/678964.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84656, 5858, 'One Piece S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/678965.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84657, 5858, 'One Piece S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/678966.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84658, 5858, 'One Piece S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/678967.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84659, 5858, 'One Piece S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/678968.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84660, 5858, 'One Piece S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/678969.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84661, 5858, 'One Piece S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/678970.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84662, 5858, 'One Piece S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/678971.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84663, 5858, 'One Piece S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/678972.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84664, 5858, 'One Piece S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/678973.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84665, 5858, 'One Piece S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/678974.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84666, 5858, 'One Piece S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/678975.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84667, 5858, 'One Piece S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/678976.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84668, 5858, 'One Piece S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/678977.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84669, 5858, 'One Piece S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/678978.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84670, 5858, 'One Piece S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/678979.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84671, 5858, 'One Piece S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/678980.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84672, 5858, 'One Piece S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/678981.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84673, 5858, 'One Piece S14 E21', 'http://sinalprivado.info:80/series/1533784/1533784/678982.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84674, 5858, 'One Piece S14 E22', 'http://sinalprivado.info:80/series/1533784/1533784/678983.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84675, 5858, 'One Piece S14 E23', 'http://sinalprivado.info:80/series/1533784/1533784/678984.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84676, 5858, 'One Piece S14 E24', 'http://sinalprivado.info:80/series/1533784/1533784/678985.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84677, 5858, 'One Piece S14 E25', 'http://sinalprivado.info:80/series/1533784/1533784/678986.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84678, 5858, 'One Piece S14 E26', 'http://sinalprivado.info:80/series/1533784/1533784/678987.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84679, 5858, 'One Piece S14 E27', 'http://sinalprivado.info:80/series/1533784/1533784/678988.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84680, 5858, 'One Piece S14 E28', 'http://sinalprivado.info:80/series/1533784/1533784/678989.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84681, 5858, 'One Piece S14 E29', 'http://sinalprivado.info:80/series/1533784/1533784/678990.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84682, 5858, 'One Piece S14 E30', 'http://sinalprivado.info:80/series/1533784/1533784/678991.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84683, 5858, 'One Piece S14 E31', 'http://sinalprivado.info:80/series/1533784/1533784/678992.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84684, 5858, 'One Piece S14 E32', 'http://sinalprivado.info:80/series/1533784/1533784/678993.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84685, 5858, 'One Piece S14 E33', 'http://sinalprivado.info:80/series/1533784/1533784/678994.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84686, 5858, 'One Piece S14 E34', 'http://sinalprivado.info:80/series/1533784/1533784/678995.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84687, 5858, 'One Piece S14 E35', 'http://sinalprivado.info:80/series/1533784/1533784/678996.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84688, 5858, 'One Piece S14 E36', 'http://sinalprivado.info:80/series/1533784/1533784/678997.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84689, 5858, 'One Piece S14 E37', 'http://sinalprivado.info:80/series/1533784/1533784/678998.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84690, 5858, 'One Piece S14 E38', 'http://sinalprivado.info:80/series/1533784/1533784/678999.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84691, 5858, 'One Piece S14 E39', 'http://sinalprivado.info:80/series/1533784/1533784/679000.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84692, 5858, 'One Piece S14 E40', 'http://sinalprivado.info:80/series/1533784/1533784/679001.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84693, 5858, 'One Piece S14 E41', 'http://sinalprivado.info:80/series/1533784/1533784/679002.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84694, 5858, 'One Piece S14 E42', 'http://sinalprivado.info:80/series/1533784/1533784/679003.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84695, 5858, 'One Piece S14 E43', 'http://sinalprivado.info:80/series/1533784/1533784/679004.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84696, 5858, 'One Piece S14 E44', 'http://sinalprivado.info:80/series/1533784/1533784/679005.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84697, 5858, 'One Piece S14 E45', 'http://sinalprivado.info:80/series/1533784/1533784/679006.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84698, 5858, 'One Piece S14 E46', 'http://sinalprivado.info:80/series/1533784/1533784/679007.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84699, 5858, 'One Piece S14 E47', 'http://sinalprivado.info:80/series/1533784/1533784/679008.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84700, 5858, 'One Piece S14 E48', 'http://sinalprivado.info:80/series/1533784/1533784/679009.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84701, 5858, 'One Piece S14 E49', 'http://sinalprivado.info:80/series/1533784/1533784/679010.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84702, 5858, 'One Piece S14 E50', 'http://sinalprivado.info:80/series/1533784/1533784/679011.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84703, 5858, 'One Piece S14 E51', 'http://sinalprivado.info:80/series/1533784/1533784/679012.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84704, 5858, 'One Piece S14 E52', 'http://sinalprivado.info:80/series/1533784/1533784/679013.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84705, 5858, 'One Piece S14 E53', 'http://sinalprivado.info:80/series/1533784/1533784/679014.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84706, 5858, 'One Piece S14 E54', 'http://sinalprivado.info:80/series/1533784/1533784/679015.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84707, 5858, 'One Piece S14 E55', 'http://sinalprivado.info:80/series/1533784/1533784/679016.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84708, 5858, 'One Piece S14 E56', 'http://sinalprivado.info:80/series/1533784/1533784/679017.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84709, 5858, 'One Piece S14 E57', 'http://sinalprivado.info:80/series/1533784/1533784/679018.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84710, 5858, 'One Piece S14 E58', 'http://sinalprivado.info:80/series/1533784/1533784/679019.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84711, 5859, 'One Piece S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/679020.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84712, 5859, 'One Piece S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/679021.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84713, 5859, 'One Piece S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/679022.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84714, 5859, 'One Piece S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/679023.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84715, 5859, 'One Piece S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/679024.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84716, 5859, 'One Piece S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/679025.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84717, 5859, 'One Piece S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/679026.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84718, 5859, 'One Piece S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/679027.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84719, 5859, 'One Piece S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/679028.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84720, 5859, 'One Piece S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/679029.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84721, 5859, 'One Piece S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/679030.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84722, 5859, 'One Piece S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/679031.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84723, 5859, 'One Piece S15 E13', 'http://sinalprivado.info:80/series/1533784/1533784/679032.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84724, 5859, 'One Piece S15 E14', 'http://sinalprivado.info:80/series/1533784/1533784/679033.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84725, 5859, 'One Piece S15 E15', 'http://sinalprivado.info:80/series/1533784/1533784/679034.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84726, 5859, 'One Piece S15 E16', 'http://sinalprivado.info:80/series/1533784/1533784/679035.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84727, 5859, 'One Piece S15 E17', 'http://sinalprivado.info:80/series/1533784/1533784/679036.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84728, 5859, 'One Piece S15 E18', 'http://sinalprivado.info:80/series/1533784/1533784/679037.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84729, 5859, 'One Piece S15 E19', 'http://sinalprivado.info:80/series/1533784/1533784/679038.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84730, 5859, 'One Piece S15 E20', 'http://sinalprivado.info:80/series/1533784/1533784/679039.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84731, 5859, 'One Piece S15 E21', 'http://sinalprivado.info:80/series/1533784/1533784/679040.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84732, 5859, 'One Piece S15 E22', 'http://sinalprivado.info:80/series/1533784/1533784/679041.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84733, 5859, 'One Piece S15 E23', 'http://sinalprivado.info:80/series/1533784/1533784/679042.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84734, 5859, 'One Piece S15 E24', 'http://sinalprivado.info:80/series/1533784/1533784/679043.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84735, 5859, 'One Piece S15 E25', 'http://sinalprivado.info:80/series/1533784/1533784/679044.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84736, 5859, 'One Piece S15 E26', 'http://sinalprivado.info:80/series/1533784/1533784/679045.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84737, 5859, 'One Piece S15 E27', 'http://sinalprivado.info:80/series/1533784/1533784/679046.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84738, 5859, 'One Piece S15 E28', 'http://sinalprivado.info:80/series/1533784/1533784/679047.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84739, 5859, 'One Piece S15 E29', 'http://sinalprivado.info:80/series/1533784/1533784/679048.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84740, 5859, 'One Piece S15 E30', 'http://sinalprivado.info:80/series/1533784/1533784/679049.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84741, 5859, 'One Piece S15 E31', 'http://sinalprivado.info:80/series/1533784/1533784/679050.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84742, 5859, 'One Piece S15 E32', 'http://sinalprivado.info:80/series/1533784/1533784/679051.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84743, 5859, 'One Piece S15 E33', 'http://sinalprivado.info:80/series/1533784/1533784/679052.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84744, 5859, 'One Piece S15 E34', 'http://sinalprivado.info:80/series/1533784/1533784/679053.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84745, 5859, 'One Piece S15 E35', 'http://sinalprivado.info:80/series/1533784/1533784/679054.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84746, 5859, 'One Piece S15 E36', 'http://sinalprivado.info:80/series/1533784/1533784/679055.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84747, 5859, 'One Piece S15 E37', 'http://sinalprivado.info:80/series/1533784/1533784/679056.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84748, 5859, 'One Piece S15 E38', 'http://sinalprivado.info:80/series/1533784/1533784/679057.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84749, 5859, 'One Piece S15 E39', 'http://sinalprivado.info:80/series/1533784/1533784/679058.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84750, 5859, 'One Piece S15 E40', 'http://sinalprivado.info:80/series/1533784/1533784/679059.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84751, 5859, 'One Piece S15 E41', 'http://sinalprivado.info:80/series/1533784/1533784/679060.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84752, 5859, 'One Piece S15 E42', 'http://sinalprivado.info:80/series/1533784/1533784/679061.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84753, 5859, 'One Piece S15 E43', 'http://sinalprivado.info:80/series/1533784/1533784/679062.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84754, 5859, 'One Piece S15 E44', 'http://sinalprivado.info:80/series/1533784/1533784/679063.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84755, 5859, 'One Piece S15 E45', 'http://sinalprivado.info:80/series/1533784/1533784/679064.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84756, 5859, 'One Piece S15 E46', 'http://sinalprivado.info:80/series/1533784/1533784/679065.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(84757, 5859, 'One Piece S15 E47', 'http://sinalprivado.info:80/series/1533784/1533784/679066.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84758, 5859, 'One Piece S15 E48', 'http://sinalprivado.info:80/series/1533784/1533784/679067.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84759, 5859, 'One Piece S15 E49', 'http://sinalprivado.info:80/series/1533784/1533784/871667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tX4vIqBExWl7fM1jvfexyE835oI.jpg'),
(84760, 5859, 'One Piece S15 E50', 'http://sinalprivado.info:80/series/1533784/1533784/871668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8raIWYHCYlx178y88kySGBDTfgy.jpg'),
(84761, 5859, 'One Piece S15 E51', 'http://sinalprivado.info:80/series/1533784/1533784/871669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aoQpajMh56vmr3PaskNVdUtBNtc.jpg'),
(84762, 5859, 'One Piece S15 E52', 'http://sinalprivado.info:80/series/1533784/1533784/871670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ydQLEQpKjhgzTwRMfKpKEBBgUD6.jpg'),
(84763, 5859, 'One Piece S15 E53', 'http://sinalprivado.info:80/series/1533784/1533784/871671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8YPW7p4dPqHyqD2ICxONz6z62s1.jpg'),
(84764, 5859, 'One Piece S15 E54', 'http://sinalprivado.info:80/series/1533784/1533784/871672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8iAnHcFt3iquY2MadeMs5qZ2HRM.jpg'),
(84765, 5859, 'One Piece S15 E55', 'http://sinalprivado.info:80/series/1533784/1533784/871673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hBctyh71iwkMDYP1WRX3UHoK80E.jpg'),
(84766, 5859, 'One Piece S15 E56', 'http://sinalprivado.info:80/series/1533784/1533784/871674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dD6GasNhmU4Q2uyBqCsF6aBPOKm.jpg'),
(84767, 5859, 'One Piece S15 E57', 'http://sinalprivado.info:80/series/1533784/1533784/871675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qtRWNhHVy4CrMBeU3PmwltEtQkz.jpg'),
(84768, 5859, 'One Piece S15 E58', 'http://sinalprivado.info:80/series/1533784/1533784/871676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srw6pXn35dzehSKrE08n2j2RiUL.jpg'),
(84769, 5859, 'One Piece S15 E59', 'http://sinalprivado.info:80/series/1533784/1533784/871677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/reKkdFcbTAuaVyD573RM36EmJP1.jpg'),
(84770, 5859, 'One Piece S15 E60', 'http://sinalprivado.info:80/series/1533784/1533784/871678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hauwq6Af3ZkNNhF9fA9OlYn0QPI.jpg'),
(84771, 5859, 'One Piece S15 E61', 'http://sinalprivado.info:80/series/1533784/1533784/871679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/59PaRXYwCEPxmmiL6RoaoPdj4PF.jpg'),
(84772, 5859, 'One Piece S15 E62', 'http://sinalprivado.info:80/series/1533784/1533784/871680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Xc3m0VG2Wph4jr6QdxCz0OrPAe.jpg'),
(84773, 5860, 'One Piece S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/871681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pCs1F84f9LZRlUONcL0CIdMHWdb.jpg'),
(84774, 5860, 'One Piece S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/871682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jbkvQvujXcTTx87qLaWyfh0mU0y.jpg'),
(84775, 5860, 'One Piece S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/871683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lPs6REXSA1V9OvUJQqAKVzsXjyP.jpg'),
(84776, 5860, 'One Piece S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/871684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xOy2KihnDsc2zfT8ZZxcK1lesWD.jpg'),
(84777, 5860, 'One Piece S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/871685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9zOXXgTqclLAKgWvzmtumqV2xQs.jpg'),
(84778, 5860, 'One Piece S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/871686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sGOYZfnDwWhHkTpAOkB8itH5gQi.jpg'),
(84779, 5860, 'One Piece S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/871687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWQtlELnIjT76ZAp4k6Dxl4YUFD.jpg'),
(84780, 5860, 'One Piece S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/871688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7qSs6LDq1eXJBaNGAvyLUfWSq9.jpg'),
(84781, 5860, 'One Piece S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/871689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aa7N6yQxprg7cpZ29iTkmAQ0mTm.jpg'),
(84782, 5860, 'One Piece S16 E10', 'http://sinalprivado.info:80/series/1533784/1533784/871690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v561FnZc1OM7YddZddf1RmImopb.jpg'),
(84783, 5860, 'One Piece S16 E11', 'http://sinalprivado.info:80/series/1533784/1533784/871691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9AIYStGarz6Rk3hWiYLKb3PwD2u.jpg'),
(84784, 5860, 'One Piece S16 E12', 'http://sinalprivado.info:80/series/1533784/1533784/871692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j0X1jX5Y60MN5K1LuzVtPZ6Di0q.jpg'),
(84785, 5860, 'One Piece S16 E13', 'http://sinalprivado.info:80/series/1533784/1533784/871693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/svGhxbFn2eLyFfH0qmJqP8hJ1rI.jpg'),
(84786, 5860, 'One Piece S16 E14', 'http://sinalprivado.info:80/series/1533784/1533784/871694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5tix6fMo9bsGVrHDqXJX9koPt7A.jpg'),
(84787, 5860, 'One Piece S16 E15', 'http://sinalprivado.info:80/series/1533784/1533784/871695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r2FK6yXCd8RktmSryC8lMuJsqEe.jpg'),
(84788, 5860, 'One Piece S16 E16', 'http://sinalprivado.info:80/series/1533784/1533784/871696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AqSZUYSNvF1ttaH9vBnRizWjxOn.jpg'),
(84789, 5860, 'One Piece S16 E17', 'http://sinalprivado.info:80/series/1533784/1533784/871697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/epTYcQmbBNtqpwb5HBoFzjmwgnK.jpg'),
(84790, 5860, 'One Piece S16 E18', 'http://sinalprivado.info:80/series/1533784/1533784/871698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m4wiOUYlYj5IP5f5Ws2o8vYVfRc.jpg'),
(84791, 5860, 'One Piece S16 E19', 'http://sinalprivado.info:80/series/1533784/1533784/871699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDKQeJvxPldR6jr9viKu9n9gyGz.jpg'),
(84792, 5860, 'One Piece S16 E20', 'http://sinalprivado.info:80/series/1533784/1533784/871700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cdlvWfDLisx8Y65ccHUqbzBIwjL.jpg'),
(84793, 5860, 'One Piece S16 E21', 'http://sinalprivado.info:80/series/1533784/1533784/871701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yd0RMAfww7fKAxAjzl2QLiHHwe.jpg'),
(84794, 5860, 'One Piece S16 E22', 'http://sinalprivado.info:80/series/1533784/1533784/871702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ikOwgFjpoEl5HZn2kqI8NMWxPdq.jpg'),
(84795, 5860, 'One Piece S16 E23', 'http://sinalprivado.info:80/series/1533784/1533784/871703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qRirwE1BTSvlI5umN6sr62Bq46.jpg'),
(84796, 5860, 'One Piece S16 E24', 'http://sinalprivado.info:80/series/1533784/1533784/871704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9expdd4ZoaPs8ulw9atigrXB8me.jpg'),
(84797, 5860, 'One Piece S16 E25', 'http://sinalprivado.info:80/series/1533784/1533784/871705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Rt93xWPmV7iupVVsNmqRbjKsTa.jpg'),
(84798, 5860, 'One Piece S16 E26', 'http://sinalprivado.info:80/series/1533784/1533784/871706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wS4X1aEpDofEZHXBGmyGgxrAqIy.jpg'),
(84799, 5860, 'One Piece S16 E27', 'http://sinalprivado.info:80/series/1533784/1533784/871707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aFyK4YIrVB8OQTQP9H2rWmTZqvi.jpg'),
(84800, 5860, 'One Piece S16 E28', 'http://sinalprivado.info:80/series/1533784/1533784/871708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zjk5VUzTqmzO4YDm7goA7lS7YWF.jpg'),
(84801, 5860, 'One Piece S16 E29', 'http://sinalprivado.info:80/series/1533784/1533784/871709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bw8r9YnwpxrbEIXBqE7J55d7jkn.jpg'),
(84802, 5860, 'One Piece S16 E30', 'http://sinalprivado.info:80/series/1533784/1533784/871710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ea82NcArsTHjIB4mHzjpNwQJhHq.jpg'),
(84803, 5860, 'One Piece S16 E31', 'http://sinalprivado.info:80/series/1533784/1533784/871711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ef8gwdjaxVJDZC196ZTEntlWJD.jpg'),
(84804, 5860, 'One Piece S16 E32', 'http://sinalprivado.info:80/series/1533784/1533784/871712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uZBg7K6deUhNKdnuTK4EVfvZvRQ.jpg'),
(84805, 5860, 'One Piece S16 E33', 'http://sinalprivado.info:80/series/1533784/1533784/871713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tZCTp23ODIKJu2h5MYX4alN9iN8.jpg'),
(84806, 5860, 'One Piece S16 E34', 'http://sinalprivado.info:80/series/1533784/1533784/871714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6GnSS3UhLbuXbBaRqnCoGLUck4N.jpg'),
(84807, 5860, 'One Piece S16 E35', 'http://sinalprivado.info:80/series/1533784/1533784/871715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wmPT4j8KRmDeVcpB6McG9hwwV1l.jpg'),
(84808, 5860, 'One Piece S16 E36', 'http://sinalprivado.info:80/series/1533784/1533784/871716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/isMryLy7wGIAzWCVYOOwz1kTfbv.jpg'),
(84809, 5860, 'One Piece S16 E37', 'http://sinalprivado.info:80/series/1533784/1533784/871717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xGY9pmRrxUlVeoHvAtT5Q4tTH2P.jpg'),
(84810, 5860, 'One Piece S16 E38', 'http://sinalprivado.info:80/series/1533784/1533784/871718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v4nCym2io4PFgpZudAAr5bkzAp4.jpg'),
(84811, 5860, 'One Piece S16 E39', 'http://sinalprivado.info:80/series/1533784/1533784/871719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xeOkWn6aYj4oQtSe3fe1UytMpbj.jpg'),
(84812, 5860, 'One Piece S16 E40', 'http://sinalprivado.info:80/series/1533784/1533784/871720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UCYURI8pzzGDuifyVVaqo89kql.jpg'),
(84813, 5860, 'One Piece S16 E41', 'http://sinalprivado.info:80/series/1533784/1533784/871721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kG3FeNr8bnSk644SPoBMlm1A6hQ.jpg'),
(84814, 5860, 'One Piece S16 E42', 'http://sinalprivado.info:80/series/1533784/1533784/871722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtufudNXPcBNMa8f3G9IK07PUsv.jpg'),
(84815, 5860, 'One Piece S16 E43', 'http://sinalprivado.info:80/series/1533784/1533784/871723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tm4LmKrGtpFFswx0XaAcvDUd0u3.jpg'),
(84816, 5860, 'One Piece S16 E44', 'http://sinalprivado.info:80/series/1533784/1533784/871724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eIBaJmzjxYW7HEUsFtoHnK071YH.jpg'),
(84817, 5860, 'One Piece S16 E45', 'http://sinalprivado.info:80/series/1533784/1533784/871725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/839Z2IUoi20BMu61AlhFrO4lJZ4.jpg'),
(84818, 5860, 'One Piece S16 E46', 'http://sinalprivado.info:80/series/1533784/1533784/871726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4c0ehJs17RWFIkVtL0VMAnrVqQD.jpg'),
(84819, 5860, 'One Piece S16 E47', 'http://sinalprivado.info:80/series/1533784/1533784/871727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lctAuWrjjUeGht9IZPcyXPYalrc.jpg'),
(84820, 5860, 'One Piece S16 E48', 'http://sinalprivado.info:80/series/1533784/1533784/871728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2OJGML9YMWv6jfIxLhTfOCZjIQd.jpg'),
(84821, 5860, 'One Piece S16 E49', 'http://sinalprivado.info:80/series/1533784/1533784/871729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vC9FAN2Q9nb0EmuPprUvSm58Bkl.jpg'),
(84822, 5860, 'One Piece S16 E50', 'http://sinalprivado.info:80/series/1533784/1533784/871730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u1rNKbd6YtOxfHfAgeyHklBizR2.jpg'),
(84823, 5861, 'One Piece S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/871731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vZ8I4AxV9B2zRzQnete5VkPGi3v.jpg'),
(84824, 5861, 'One Piece S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/871732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hOeTg3WLfz8qLc57ZKdB6DO5spu.jpg'),
(84825, 5861, 'One Piece S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/871733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2SHSbf4Z6lIQOQlmL8loREqbc1A.jpg'),
(84826, 5861, 'One Piece S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/871734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7DF1eOmvxTajUNPx1LUSCbLespc.jpg'),
(84827, 5861, 'One Piece S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/871735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ps6gVyIY0AcdnLGKXbAxxW7Ezvr.jpg'),
(84828, 5861, 'One Piece S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/871736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j2o63mqWwrT5s7CIb7cjgEQBClG.jpg'),
(84829, 5861, 'One Piece S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/871737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/riJJZ4AuElaJK27mCDJFjR4w59s.jpg'),
(84830, 5861, 'One Piece S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/871738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwMcjMHF5LCFpGvqcyueoWS2uF.jpg'),
(84831, 5861, 'One Piece S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/871739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ysHwBDruIOfx2DC0YTvrcAWO9RH.jpg'),
(84832, 5861, 'One Piece S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/871740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/odcW3iOV6TdiaObYlHUAjOHsNFh.jpg'),
(84833, 5861, 'One Piece S17 E11', 'http://sinalprivado.info:80/series/1533784/1533784/871741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4fOZpX6XoQUYDQzrrVd6OByE7WO.jpg'),
(84834, 5861, 'One Piece S17 E12', 'http://sinalprivado.info:80/series/1533784/1533784/871742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y4y98nrs5tNJsiE5xQ14wFvgELf.jpg'),
(84835, 5861, 'One Piece S17 E13', 'http://sinalprivado.info:80/series/1533784/1533784/871743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gcSnTQuhExhQmkeouUSW4hVbg0O.jpg'),
(84836, 5861, 'One Piece S17 E14', 'http://sinalprivado.info:80/series/1533784/1533784/871744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lrwyep7rvMV3cI85OPi6cSnj0MU.jpg'),
(84837, 5861, 'One Piece S17 E15', 'http://sinalprivado.info:80/series/1533784/1533784/871745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xBy2tkLmpcM5J3z5zJ9KXqlDFGL.jpg'),
(84838, 5861, 'One Piece S17 E16', 'http://sinalprivado.info:80/series/1533784/1533784/871746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5cdVq5XrYreJfoWKqCQNR8ZCtyK.jpg'),
(84839, 5861, 'One Piece S17 E17', 'http://sinalprivado.info:80/series/1533784/1533784/871747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cSg4z1xQzRJAoIhzXBCP07KEQYN.jpg'),
(84840, 5861, 'One Piece S17 E18', 'http://sinalprivado.info:80/series/1533784/1533784/871748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oVLXOA4JxoMDwWLOqyD0YlarA2H.jpg'),
(84841, 5861, 'One Piece S17 E19', 'http://sinalprivado.info:80/series/1533784/1533784/871749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1zdq1OgscMziy89DlbzNaDNVJ4a.jpg'),
(84842, 5861, 'One Piece S17 E20', 'http://sinalprivado.info:80/series/1533784/1533784/871750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uWyIGm20QU65JLJrDEg5qAwgkuY.jpg'),
(84843, 5861, 'One Piece S17 E21', 'http://sinalprivado.info:80/series/1533784/1533784/871751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a1YlQfM6CEZ1YorBog3EWGush4M.jpg'),
(84844, 5861, 'One Piece S17 E22', 'http://sinalprivado.info:80/series/1533784/1533784/871752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kRoCNjAOFShqdsDGNuAaBvnbE5r.jpg'),
(84845, 5861, 'One Piece S17 E23', 'http://sinalprivado.info:80/series/1533784/1533784/871753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sBPJv8NsrauzZJLojyRxWDOl0tk.jpg'),
(84846, 5861, 'One Piece S17 E24', 'http://sinalprivado.info:80/series/1533784/1533784/871754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gl43zNbtFnFhJQ8emCV5IoG5BHX.jpg'),
(84847, 5861, 'One Piece S17 E25', 'http://sinalprivado.info:80/series/1533784/1533784/871755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ojJZIPlI4QCFD3Rs7wVkUZuqjtV.jpg'),
(84848, 5861, 'One Piece S17 E26', 'http://sinalprivado.info:80/series/1533784/1533784/871756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQMYnnqbFQhUfARrt5dyRLDgeyd.jpg'),
(84849, 5861, 'One Piece S17 E27', 'http://sinalprivado.info:80/series/1533784/1533784/871757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h4a2JbmNRf4GKvr0GNPJimOgSlS.jpg'),
(84850, 5861, 'One Piece S17 E28', 'http://sinalprivado.info:80/series/1533784/1533784/871758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8sxsLUEVwpOlvLz9IPrnUmoXQ3w.jpg'),
(84851, 5861, 'One Piece S17 E29', 'http://sinalprivado.info:80/series/1533784/1533784/871759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cLSZo0YlG6kUjGm3z7oe7Mixy1m.jpg'),
(84852, 5861, 'One Piece S17 E30', 'http://sinalprivado.info:80/series/1533784/1533784/871760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/izf44Cn379t1LCePNz0UZMin3dD.jpg'),
(84853, 5861, 'One Piece S17 E31', 'http://sinalprivado.info:80/series/1533784/1533784/871761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/itBtHiee2bAfLWajHOrYVMxjpnV.jpg'),
(84854, 5861, 'One Piece S17 E32', 'http://sinalprivado.info:80/series/1533784/1533784/871762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iQTy2Xiuzb6UmSt0v43cIBzTAgC.jpg'),
(84855, 5861, 'One Piece S17 E33', 'http://sinalprivado.info:80/series/1533784/1533784/871763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jYu6z3u8gEkdlDfSnD8tPZCVCK8.jpg'),
(84856, 5861, 'One Piece S17 E34', 'http://sinalprivado.info:80/series/1533784/1533784/871764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/noxwpaUzZiTMV8FqGn1khuq7a7D.jpg'),
(84857, 5861, 'One Piece S17 E35', 'http://sinalprivado.info:80/series/1533784/1533784/871765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5kx65bhNde8DIxAcx5D3YQDzAKj.jpg'),
(84858, 5861, 'One Piece S17 E36', 'http://sinalprivado.info:80/series/1533784/1533784/871766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8IrAkM4z709YHsSgBYpI54cfrEt.jpg'),
(84859, 5861, 'One Piece S17 E37', 'http://sinalprivado.info:80/series/1533784/1533784/871767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iI4C58LdCdGvrPHofVUtpSOXq7j.jpg'),
(84860, 5861, 'One Piece S17 E38', 'http://sinalprivado.info:80/series/1533784/1533784/871768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/28uKohySdovKdNvkhgGQsYLkG3z.jpg'),
(84861, 5861, 'One Piece S17 E39', 'http://sinalprivado.info:80/series/1533784/1533784/871769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gK4WhzBjpmKv9vd1qIHjXE6mKUu.jpg'),
(84862, 5861, 'One Piece S17 E40', 'http://sinalprivado.info:80/series/1533784/1533784/871770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xvRWXHIfa83IBNcPmDJsaDStTuI.jpg'),
(84863, 5861, 'One Piece S17 E41', 'http://sinalprivado.info:80/series/1533784/1533784/871771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nF6TAODxdNsuIviC7BIoLD6k0Km.jpg'),
(84864, 5861, 'One Piece S17 E42', 'http://sinalprivado.info:80/series/1533784/1533784/871772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lJq3XhjW7A2aUxvmPkg0ckAxMrD.jpg'),
(84865, 5861, 'One Piece S17 E43', 'http://sinalprivado.info:80/series/1533784/1533784/871773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/80h8b8TN6skllRlhLrhERjqeTOn.jpg'),
(84866, 5861, 'One Piece S17 E44', 'http://sinalprivado.info:80/series/1533784/1533784/871774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x5RvAPN2sf8dOx62IekRlsdAonz.jpg'),
(84867, 5861, 'One Piece S17 E45', 'http://sinalprivado.info:80/series/1533784/1533784/871775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pI4geLPo3oHlyvE24HkHi5mamQM.jpg'),
(84868, 5861, 'One Piece S17 E46', 'http://sinalprivado.info:80/series/1533784/1533784/871776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gYZGqnWsWsmp7FoyxguwkZ97CFB.jpg'),
(84869, 5861, 'One Piece S17 E47', 'http://sinalprivado.info:80/series/1533784/1533784/871777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c4hVyV9R0XRZwTy6fDVo1LpfdP4.jpg'),
(84870, 5861, 'One Piece S17 E48', 'http://sinalprivado.info:80/series/1533784/1533784/871778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rWPKiNmEulv7T2oE0zrYBKVmwrb.jpg'),
(84871, 5861, 'One Piece S17 E49', 'http://sinalprivado.info:80/series/1533784/1533784/871779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9vg1KXCLHrh1LvdfN6BZcSqyo4k.jpg'),
(84872, 5861, 'One Piece S17 E50', 'http://sinalprivado.info:80/series/1533784/1533784/871780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3ojqqHNs4qShHbqCD2WQu50LuTS.jpg'),
(84873, 5861, 'One Piece S17 E51', 'http://sinalprivado.info:80/series/1533784/1533784/871781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n10tb531wsHz6vJvZxkwooDIRC1.jpg'),
(84874, 5861, 'One Piece S17 E52', 'http://sinalprivado.info:80/series/1533784/1533784/871782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ssLv19r7GwdG7vV16Pt5qO5nvb2.jpg'),
(84875, 5861, 'One Piece S17 E53', 'http://sinalprivado.info:80/series/1533784/1533784/871783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpwABixmP4RgyuMjaK4xmRJgoe8.jpg'),
(84876, 5861, 'One Piece S17 E54', 'http://sinalprivado.info:80/series/1533784/1533784/871784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qrXVRFRdqm167dFYtfQX9IWA8o9.jpg'),
(84877, 5861, 'One Piece S17 E55', 'http://sinalprivado.info:80/series/1533784/1533784/871785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ofXRq5F6EuJzyMkN7YK2Ce9JYOn.jpg'),
(84878, 5861, 'One Piece S17 E56', 'http://sinalprivado.info:80/series/1533784/1533784/871786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/miIjcQboK2JbVdUmLTGh136Z9MC.jpg'),
(84879, 5862, 'One Piece S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/871787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xWeYx1SBVkvM1D2Uv4k2pbU3jLh.jpg'),
(84880, 5862, 'One Piece S18 E02', 'http://sinalprivado.info:80/series/1533784/1533784/871788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xnynWG3nCJvRZphqsXY1htammfd.jpg'),
(84881, 5862, 'One Piece S18 E03', 'http://sinalprivado.info:80/series/1533784/1533784/896396.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84882, 5862, 'One Piece S18 E04', 'http://sinalprivado.info:80/series/1533784/1533784/896397.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84883, 5862, 'One Piece S18 E05', 'http://sinalprivado.info:80/series/1533784/1533784/896398.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84884, 5862, 'One Piece S18 E06', 'http://sinalprivado.info:80/series/1533784/1533784/896399.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84885, 5862, 'One Piece S18 E07', 'http://sinalprivado.info:80/series/1533784/1533784/896400.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84886, 5862, 'One Piece S18 E08', 'http://sinalprivado.info:80/series/1533784/1533784/896401.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84887, 5862, 'One Piece S18 E09', 'http://sinalprivado.info:80/series/1533784/1533784/896402.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84888, 5862, 'One Piece S18 E10', 'http://sinalprivado.info:80/series/1533784/1533784/896403.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84889, 5862, 'One Piece S18 E11', 'http://sinalprivado.info:80/series/1533784/1533784/896404.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84890, 5862, 'One Piece S18 E12', 'http://sinalprivado.info:80/series/1533784/1533784/896405.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84891, 5862, 'One Piece S18 E13', 'http://sinalprivado.info:80/series/1533784/1533784/896406.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84892, 5862, 'One Piece S18 E14', 'http://sinalprivado.info:80/series/1533784/1533784/896407.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84893, 5862, 'One Piece S18 E15', 'http://sinalprivado.info:80/series/1533784/1533784/896408.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84894, 5862, 'One Piece S18 E16', 'http://sinalprivado.info:80/series/1533784/1533784/896409.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84895, 5862, 'One Piece S18 E17', 'http://sinalprivado.info:80/series/1533784/1533784/896410.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84896, 5862, 'One Piece S18 E18', 'http://sinalprivado.info:80/series/1533784/1533784/896411.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84897, 5862, 'One Piece S18 E19', 'http://sinalprivado.info:80/series/1533784/1533784/896412.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84898, 5862, 'One Piece S18 E20', 'http://sinalprivado.info:80/series/1533784/1533784/896413.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84899, 5862, 'One Piece S18 E21', 'http://sinalprivado.info:80/series/1533784/1533784/896414.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84900, 5862, 'One Piece S18 E22', 'http://sinalprivado.info:80/series/1533784/1533784/896415.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84901, 5862, 'One Piece S18 E23', 'http://sinalprivado.info:80/series/1533784/1533784/896416.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84902, 5862, 'One Piece S18 E24', 'http://sinalprivado.info:80/series/1533784/1533784/896417.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84903, 5862, 'One Piece S18 E25', 'http://sinalprivado.info:80/series/1533784/1533784/896418.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84904, 5862, 'One Piece S18 E26', 'http://sinalprivado.info:80/series/1533784/1533784/896419.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84905, 5862, 'One Piece S18 E27', 'http://sinalprivado.info:80/series/1533784/1533784/896420.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84906, 5862, 'One Piece S18 E28', 'http://sinalprivado.info:80/series/1533784/1533784/896421.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84907, 5862, 'One Piece S18 E29', 'http://sinalprivado.info:80/series/1533784/1533784/896422.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84908, 5862, 'One Piece S18 E30', 'http://sinalprivado.info:80/series/1533784/1533784/896423.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84909, 5862, 'One Piece S18 E31', 'http://sinalprivado.info:80/series/1533784/1533784/896424.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84910, 5862, 'One Piece S18 E32', 'http://sinalprivado.info:80/series/1533784/1533784/896425.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84911, 5862, 'One Piece S18 E33', 'http://sinalprivado.info:80/series/1533784/1533784/896426.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84912, 5862, 'One Piece S18 E34', 'http://sinalprivado.info:80/series/1533784/1533784/896427.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84913, 5862, 'One Piece S18 E35', 'http://sinalprivado.info:80/series/1533784/1533784/896428.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84914, 5862, 'One Piece S18 E36', 'http://sinalprivado.info:80/series/1533784/1533784/896429.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84915, 5862, 'One Piece S18 E37', 'http://sinalprivado.info:80/series/1533784/1533784/896430.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84916, 5862, 'One Piece S18 E38', 'http://sinalprivado.info:80/series/1533784/1533784/896431.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84917, 5862, 'One Piece S18 E39', 'http://sinalprivado.info:80/series/1533784/1533784/896432.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84918, 5862, 'One Piece S18 E40', 'http://sinalprivado.info:80/series/1533784/1533784/896433.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84919, 5862, 'One Piece S18 E41', 'http://sinalprivado.info:80/series/1533784/1533784/896434.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84920, 5862, 'One Piece S18 E42', 'http://sinalprivado.info:80/series/1533784/1533784/896435.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84921, 5862, 'One Piece S18 E43', 'http://sinalprivado.info:80/series/1533784/1533784/896436.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84922, 5862, 'One Piece S18 E44', 'http://sinalprivado.info:80/series/1533784/1533784/896437.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84923, 5862, 'One Piece S18 E45', 'http://sinalprivado.info:80/series/1533784/1533784/896438.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84924, 5862, 'One Piece S18 E46', 'http://sinalprivado.info:80/series/1533784/1533784/896439.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84925, 5862, 'One Piece S18 E47', 'http://sinalprivado.info:80/series/1533784/1533784/896440.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84926, 5862, 'One Piece S18 E48', 'http://sinalprivado.info:80/series/1533784/1533784/896441.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84927, 5862, 'One Piece S18 E49', 'http://sinalprivado.info:80/series/1533784/1533784/896442.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84928, 5862, 'One Piece S18 E50', 'http://sinalprivado.info:80/series/1533784/1533784/896443.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84929, 5862, 'One Piece S18 E51', 'http://sinalprivado.info:80/series/1533784/1533784/896444.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84930, 5862, 'One Piece S18 E52', 'http://sinalprivado.info:80/series/1533784/1533784/896445.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84931, 5862, 'One Piece S18 E53', 'http://sinalprivado.info:80/series/1533784/1533784/896446.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84932, 5862, 'One Piece S18 E54', 'http://sinalprivado.info:80/series/1533784/1533784/896447.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84933, 5862, 'One Piece S18 E55', 'http://sinalprivado.info:80/series/1533784/1533784/896448.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84934, 5863, 'One Piece S19 E01', 'http://sinalprivado.info:80/series/1533784/1533784/896449.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84935, 5863, 'One Piece S19 E02', 'http://sinalprivado.info:80/series/1533784/1533784/896450.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84936, 5863, 'One Piece S19 E03', 'http://sinalprivado.info:80/series/1533784/1533784/896451.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84937, 5863, 'One Piece S19 E04', 'http://sinalprivado.info:80/series/1533784/1533784/896452.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84938, 5863, 'One Piece S19 E05', 'http://sinalprivado.info:80/series/1533784/1533784/896453.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84939, 5863, 'One Piece S19 E06', 'http://sinalprivado.info:80/series/1533784/1533784/896454.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84940, 5863, 'One Piece S19 E07', 'http://sinalprivado.info:80/series/1533784/1533784/896455.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84941, 5863, 'One Piece S19 E08', 'http://sinalprivado.info:80/series/1533784/1533784/896456.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84942, 5863, 'One Piece S19 E09', 'http://sinalprivado.info:80/series/1533784/1533784/896457.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84943, 5863, 'One Piece S19 E10', 'http://sinalprivado.info:80/series/1533784/1533784/896458.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84944, 5863, 'One Piece S19 E11', 'http://sinalprivado.info:80/series/1533784/1533784/896459.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84945, 5863, 'One Piece S19 E12', 'http://sinalprivado.info:80/series/1533784/1533784/896460.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84946, 5863, 'One Piece S19 E13', 'http://sinalprivado.info:80/series/1533784/1533784/896461.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84947, 5863, 'One Piece S19 E14', 'http://sinalprivado.info:80/series/1533784/1533784/896462.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84948, 5863, 'One Piece S19 E15', 'http://sinalprivado.info:80/series/1533784/1533784/896463.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84949, 5863, 'One Piece S19 E16', 'http://sinalprivado.info:80/series/1533784/1533784/896464.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84950, 5863, 'One Piece S19 E17', 'http://sinalprivado.info:80/series/1533784/1533784/896465.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84951, 5863, 'One Piece S19 E18', 'http://sinalprivado.info:80/series/1533784/1533784/896466.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84952, 5863, 'One Piece S19 E19', 'http://sinalprivado.info:80/series/1533784/1533784/896467.mp4', 'http://gstaticontent.com/images/471540363f0c7d476e446a5bfdacba78.jpg'),
(84953, 5864, 'Orient S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199711.mp4', 'http://timg.bdta.pro/images/fc7d4e971606435152e7f181adc1659e.jpg'),
(84954, 5864, 'Orient S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199712.mp4', 'http://timg.bdta.pro/images/aeda1fb7ef61c80425dae1e29378e29f.jpg'),
(84955, 5864, 'Orient S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199713.mp4', 'http://timg.bdta.pro/images/8d4b1d972c6f36e804b06f7cff955dac.jpg'),
(84956, 5864, 'Orient S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199714.mp4', 'http://timg.bdta.pro/images/862eda4d72fe998b07fcf1db9933a501.jpg'),
(84957, 5864, 'Orient S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199715.mp4', 'http://timg.bdta.pro/images/207b235831a69e176db96c0207ee3886.jpg'),
(84958, 5864, 'Orient S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199716.mp4', 'http://timg.bdta.pro/images/152b1be62cb83650e7bea33e4495acc2.jpg'),
(84959, 5864, 'Orient S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199717.mp4', 'http://timg.bdta.pro/images/356717c584345ced5b78e57544dc4f17.jpg'),
(84960, 5864, 'Orient S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199718.mp4', 'http://timg.bdta.pro/images/5fcb5db720720e304ffa3796eb5c6e0e.jpg'),
(84961, 5864, 'Orient S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199719.mp4', 'http://timg.bdta.pro/images/285d1f002b104d9b544d223b8149a0ef.jpg'),
(84962, 5864, 'Orient S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199720.mp4', 'http://timg.bdta.pro/images/b28b6fedbbccbe85f6c61f09d92566a4.jpg'),
(84963, 5864, 'Orient S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199721.mp4', 'http://timg.bdta.pro/images/4114eedbf792b45b5da86e99b8685b8e.jpg'),
(84964, 5864, 'Orient S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199722.mp4', 'http://timg.bdta.pro/images/8566ba76fbcd32b8286443cbe2f1420f.jpg'),
(84965, 5864, 'Orient S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/199723.mp4', 'http://timg.bdta.pro/images/d7d33ce90408a277635494d3f82abc6a.jpg'),
(84966, 5864, 'Orient S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/199724.mp4', 'http://timg.bdta.pro/images/62e95b4c6db411754986ed306ff045c5.jpg'),
(84967, 5864, 'Orient S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/199725.mp4', 'http://timg.bdta.pro/images/5d250f3a8c23d746e0de1a17dfff76e1.jpg'),
(84968, 5864, 'Orient S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/199726.mp4', 'http://timg.bdta.pro/images/aae3f0a0e4b4734039abc834099bbdb4.jpg'),
(84969, 5864, 'Orient S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/199727.mp4', 'http://timg.bdta.pro/images/2ea44806547a604086c0fb28bf0f3756.jpg'),
(84970, 5864, 'Orient S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/199728.mp4', 'http://timg.bdta.pro/images/70aba00a528d82a93348399ff941b443.jpg'),
(84971, 5864, 'Orient S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/199729.mp4', 'http://timg.bdta.pro/images/17f21531ddbd84c5b0c19a9f75374444.jpg'),
(84972, 5864, 'Orient S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/199730.mp4', 'http://timg.bdta.pro/images/913fdcb26d2a068557ececd975ff8aa9.jpg'),
(84973, 5864, 'Orient S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/199731.mp4', 'http://timg.bdta.pro/images/008d4a79705d7206c16b04ec8e8eebbd.jpg'),
(84974, 5864, 'Orient S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/199732.mp4', 'http://timg.bdta.pro/images/d3a0b2e7939b06a1edebdacc723fea95.jpg'),
(84975, 5864, 'Orient S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/199733.mp4', 'http://timg.bdta.pro/images/6dc6ee254ba82137c9ebbed4a09859e4.jpg'),
(84976, 5864, 'Orient S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/199734.mp4', 'http://timg.bdta.pro/images/b929ad4b57db3e2612268f3ba69ae2a6.jpg'),
(84977, 5865, 'Amanhã S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180511.mp4', 'http://timg.bdta.pro/images/7eaeb9bf6ddda6efbfa3ba82dd526a19.jpg'),
(84978, 5865, 'Amanhã S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180512.mp4', 'http://timg.bdta.pro/images/aeb1322e25bec5e0d3b13eea920c1afc.jpg'),
(84979, 5865, 'Amanhã S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180513.mp4', 'http://timg.bdta.pro/images/ecd0b3bed5e3976052e7e004f216aa1f.jpg'),
(84980, 5865, 'Amanhã S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180514.mp4', 'http://timg.bdta.pro/images/1a0fe81a14dbf074f07f2390a56f89a8.jpg'),
(84981, 5865, 'Amanhã S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180515.mp4', 'http://timg.bdta.pro/images/033109d0a13742894e6baaec6fd364ae.jpg'),
(84982, 5865, 'Amanhã S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180516.mp4', 'http://timg.bdta.pro/images/f3be4747906614bb5b62c580edc814e0.jpg'),
(84983, 5865, 'Amanhã S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180517.mp4', 'http://timg.bdta.pro/images/c0f7460361c598f979b7bd9cb5e97d10.jpg'),
(84984, 5865, 'Amanhã S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180518.mp4', 'http://timg.bdta.pro/images/806a14c428cb0b2d3a0e9039b99d4ee8.jpg'),
(84985, 5865, 'Amanhã S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180519.mp4', 'http://timg.bdta.pro/images/d01b28610fb742c6def600c47c42a20c.jpg'),
(84986, 5865, 'Amanhã S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180520.mp4', 'http://timg.bdta.pro/images/40399fb9823f74a1dd4dfde9bfe68a70.jpg'),
(84987, 5865, 'Amanhã S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/180521.mp4', 'http://timg.bdta.pro/images/058649031f904d00e7aca5c38fa0fa51.jpg'),
(84988, 5865, 'Amanhã S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/180522.mp4', 'http://timg.bdta.pro/images/b40f43665e6808106d5a6c0897cbdb53.jpg'),
(84989, 5865, 'Amanhã S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/180523.mp4', 'http://timg.bdta.pro/images/57347d740307e000c2584af71ff5ad6f.jpg'),
(84990, 5865, 'Amanhã S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/180524.mp4', 'http://timg.bdta.pro/images/3c87896e3d83841e6e3fb990b2048b87.jpg'),
(84991, 5865, 'Amanhã S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/180525.mp4', 'http://timg.bdta.pro/images/46e0c1995017da0569e26635be47a77d.jpg'),
(84992, 5865, 'Amanhã S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/180526.mp4', 'http://timg.bdta.pro/images/ffa46b6b05b31a14c890e8c5b57ad340.jpg'),
(84993, 5866, 'Bang Bang Baby S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180501.mp4', 'http://timg.bdta.pro/images/b123e60a15983f6b121b54582c11589b.jpg'),
(84994, 5866, 'Bang Bang Baby S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180502.mp4', 'http://timg.bdta.pro/images/6b6d4e27a63f23b182e4ce5bea1c2a0b.jpg'),
(84995, 5866, 'Bang Bang Baby S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180503.mp4', 'http://timg.bdta.pro/images/aeeb73def736970602a5146fbb8c03ff.jpg'),
(84996, 5866, 'Bang Bang Baby S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180504.mp4', 'http://timg.bdta.pro/images/757fa897ebc2b035e97d89988c69d213.jpg'),
(84997, 5866, 'Bang Bang Baby S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180505.mp4', 'http://timg.bdta.pro/images/419672985162d95fc21633900a8f4bce.jpg'),
(84998, 5866, 'Bang Bang Baby S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180506.mp4', 'http://gstaticontent.com/images/1d296f72878287e4bc425a020bb88db0.jpg'),
(84999, 5866, 'Bang Bang Baby S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180507.mp4', 'http://gstaticontent.com/images/1d296f72878287e4bc425a020bb88db0.jpg'),
(85000, 5866, 'Bang Bang Baby S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180508.mp4', 'http://gstaticontent.com/images/1d296f72878287e4bc425a020bb88db0.jpg'),
(85001, 5866, 'Bang Bang Baby S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180509.mp4', 'http://gstaticontent.com/images/1d296f72878287e4bc425a020bb88db0.jpg'),
(85002, 5866, 'Bang Bang Baby S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180510.mp4', 'http://gstaticontent.com/images/1d296f72878287e4bc425a020bb88db0.jpg'),
(85003, 5867, 'O Mistério de Chapelwaite S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180491.mp4', 'http://timg.bdta.pro/images/6798a4bc5b62c1d61f8b8d90271edb39.jpg'),
(85004, 5867, 'O Mistério de Chapelwaite S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180492.mp4', 'http://timg.bdta.pro/images/0efa17e72ff7b94f010a125a4ddeaa1f.jpg'),
(85005, 5867, 'O Mistério de Chapelwaite S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180493.mp4', 'http://timg.bdta.pro/images/1eef2dee40b29f45be8efe3bec808738.jpg'),
(85006, 5867, 'O Mistério de Chapelwaite S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180494.mp4', 'http://timg.bdta.pro/images/0c7d5d994d72318307693c6589948bba.jpg'),
(85007, 5867, 'O Mistério de Chapelwaite S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180495.mp4', 'http://timg.bdta.pro/images/1a99058f602a6b98ad030b018241e3b2.jpg'),
(85008, 5867, 'O Mistério de Chapelwaite S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180496.mp4', 'http://timg.bdta.pro/images/75221ce960af2332a93a833750a3c0cc.jpg'),
(85009, 5867, 'O Mistério de Chapelwaite S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180497.mp4', 'http://timg.bdta.pro/images/7405f7e320d753f52664989bb4044b6a.jpg'),
(85010, 5867, 'O Mistério de Chapelwaite S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180498.mp4', 'http://timg.bdta.pro/images/fd1853f40a854d00ea458150aaa524b6.jpg'),
(85011, 5867, 'O Mistério de Chapelwaite S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180499.mp4', 'http://timg.bdta.pro/images/ea0e646cab2e7d8e4fb5d9006590fc80.jpg'),
(85012, 5867, 'O Mistério de Chapelwaite S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180500.mp4', 'http://timg.bdta.pro/images/0d0f0a2cc4899443c54795f6d0f134ee.jpg'),
(85013, 5868, 'Dragões: Os Nove Reinos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238883.mp4', 'http://timg.bdta.pro/images/8acddcf73bd503cc098d37cbf7d511de.jpg'),
(85014, 5868, 'Dragões: Os Nove Reinos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238884.mp4', 'http://timg.bdta.pro/images/e126685f57205b1281f06c8f22662c28.jpg'),
(85015, 5868, 'Dragões: Os Nove Reinos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238885.mp4', 'http://timg.bdta.pro/images/dcd39c8f6d4b4b33d0a402c5d9988ab6.jpg'),
(85016, 5868, 'Dragões: Os Nove Reinos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238886.mp4', 'http://timg.bdta.pro/images/6dcf3218f3f252491f9bcdb6511c7b9e.jpg'),
(85017, 5868, 'Dragões: Os Nove Reinos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238887.mp4', 'http://timg.bdta.pro/images/475c458f2c46655f778e2d94601534ef.jpg'),
(85018, 5868, 'Dragões: Os Nove Reinos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238888.mp4', 'http://timg.bdta.pro/images/fb25d88354c87f86384932e66ecd18de.jpg'),
(85019, 5869, 'Dragões: Os Nove Reinos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238889.mp4', 'http://gstaticontent.com/images/a7c79ddb46fb60993a3ce87b21d763d8.jpg'),
(85020, 5869, 'Dragões: Os Nove Reinos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238890.mp4', 'http://gstaticontent.com/images/a7c79ddb46fb60993a3ce87b21d763d8.jpg'),
(85021, 5869, 'Dragões: Os Nove Reinos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238891.mp4', 'http://gstaticontent.com/images/a7c79ddb46fb60993a3ce87b21d763d8.jpg'),
(85022, 5869, 'Dragões: Os Nove Reinos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238892.mp4', 'http://gstaticontent.com/images/a7c79ddb46fb60993a3ce87b21d763d8.jpg'),
(85023, 5869, 'Dragões: Os Nove Reinos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238893.mp4', 'http://gstaticontent.com/images/a7c79ddb46fb60993a3ce87b21d763d8.jpg'),
(85024, 5869, 'Dragões: Os Nove Reinos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238894.mp4', 'http://gstaticontent.com/images/a7c79ddb46fb60993a3ce87b21d763d8.jpg'),
(85025, 5869, 'Dragões: Os Nove Reinos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238895.mp4', 'http://gstaticontent.com/images/a7c79ddb46fb60993a3ce87b21d763d8.jpg'),
(85026, 5870, 'Dragões: Os Nove Reinos S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cT1CfziRmBZ6VI2yubFL3WcowRp.jpg'),
(85027, 5870, 'Dragões: Os Nove Reinos S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t1RfWLuqAsPZPfsbJNKvXpP4k8D.jpg'),
(85028, 5870, 'Dragões: Os Nove Reinos S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5gWiGx2Bs1aXksfSklAI8DIIQM5.jpg'),
(85029, 5870, 'Dragões: Os Nove Reinos S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bIhWFanq4kNHDpbWdn6hRYgCIMF.jpg'),
(85030, 5870, 'Dragões: Os Nove Reinos S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aad01aWoiB1JK3QfSjcQhPyj6a8.jpg'),
(85031, 5870, 'Dragões: Os Nove Reinos S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2wKERgsu69xaJuz0QVpvtqnVFs.jpg'),
(85032, 5870, 'Dragões: Os Nove Reinos S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zlTfBijj0UFS12KpHviOFaIN5BO.jpg'),
(85033, 5871, 'Dragões: Os Nove Reinos S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbp4zETJGxIusPVnlqvwcd2EEvl.jpg'),
(85034, 5871, 'Dragões: Os Nove Reinos S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wswAjgdvSw3IdGfhn8VCfemAFJj.jpg'),
(85035, 5871, 'Dragões: Os Nove Reinos S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vckDJb53AxAk6mCWDPX4a2da7aO.jpg'),
(85036, 5871, 'Dragões: Os Nove Reinos S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oJjCEvDuRq4C3GECSBzn7ni8f3O.jpg'),
(85037, 5871, 'Dragões: Os Nove Reinos S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v17KiFokSkGFLeDpthOmtnMrsbZ.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(85038, 5871, 'Dragões: Os Nove Reinos S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kl1gYr1Y4YW3qcMlFyqhxlew8rm.jpg'),
(85039, 5872, 'Dragões: Os Nove Reinos S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b3jZQUjIMnEsjiSLdurtrG6hPpR.jpg'),
(85040, 5872, 'Dragões: Os Nove Reinos S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mPeIevShiDoL0mzWafZqro39fra.jpg'),
(85041, 5872, 'Dragões: Os Nove Reinos S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xWW5rMhoWwU1y4iItJfuqdGbAKr.jpg'),
(85042, 5872, 'Dragões: Os Nove Reinos S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mqp5hEoQCESjgJdkUAJlk8lmPGD.jpg'),
(85043, 5872, 'Dragões: Os Nove Reinos S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lF0ELMg110oZCky713jGkWBW2fA.jpg'),
(85044, 5872, 'Dragões: Os Nove Reinos S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hTQTsAmyjE16E2dfy1B8kXrGlwO.jpg'),
(85045, 5873, 'Dragões: Os Nove Reinos S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZ1UZMU5VBCjn0y0GHoHnjSTqwa.jpg'),
(85046, 5873, 'Dragões: Os Nove Reinos S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4XiKRFc9vCiq6xK56BRVOgUMqtE.jpg'),
(85047, 5873, 'Dragões: Os Nove Reinos S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fYf9xfSWMikuq7FbfarnnaEQmNz.jpg'),
(85048, 5873, 'Dragões: Os Nove Reinos S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vSWLaCmtA2AH1MIuRZJrAnnyt1n.jpg'),
(85049, 5873, 'Dragões: Os Nove Reinos S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Ryip0j8irW0e7YUzYr3JIomKjv.jpg'),
(85050, 5873, 'Dragões: Os Nove Reinos S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDaK3CWXw5clyMrd07bS3BN7987.jpg'),
(85051, 5873, 'Dragões: Os Nove Reinos S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mTwSG2NwZQxppASTnFzLUY8eQEc.jpg'),
(85052, 5874, 'Dragões: Os Nove Reinos S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238922.mp4', 'http://gstaticontent.com/images/a7c79ddb46fb60993a3ce87b21d763d8.jpg'),
(85053, 5874, 'Dragões: Os Nove Reinos S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238923.mp4', 'http://gstaticontent.com/images/a7c79ddb46fb60993a3ce87b21d763d8.jpg'),
(85054, 5874, 'Dragões: Os Nove Reinos S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238924.mp4', 'http://gstaticontent.com/images/a7c79ddb46fb60993a3ce87b21d763d8.jpg'),
(85055, 5874, 'Dragões: Os Nove Reinos S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238925.mp4', 'http://gstaticontent.com/images/a7c79ddb46fb60993a3ce87b21d763d8.jpg'),
(85056, 5874, 'Dragões: Os Nove Reinos S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238926.mp4', 'http://gstaticontent.com/images/a7c79ddb46fb60993a3ce87b21d763d8.jpg'),
(85057, 5874, 'Dragões: Os Nove Reinos S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238927.mp4', 'http://gstaticontent.com/images/a7c79ddb46fb60993a3ce87b21d763d8.jpg'),
(85058, 5874, 'Dragões: Os Nove Reinos S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/326170.mp4', 'http://gstaticontent.com/images/a7c79ddb46fb60993a3ce87b21d763d8.jpg'),
(85059, 5875, 'Dragões: Os Nove Reinos S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326171.mp4', 'http://gstaticontent.com/images/a7c79ddb46fb60993a3ce87b21d763d8.jpg'),
(85060, 5875, 'Dragões: Os Nove Reinos S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326172.mp4', 'http://gstaticontent.com/images/a7c79ddb46fb60993a3ce87b21d763d8.jpg'),
(85061, 5875, 'Dragões: Os Nove Reinos S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326173.mp4', 'http://gstaticontent.com/images/a7c79ddb46fb60993a3ce87b21d763d8.jpg'),
(85062, 5875, 'Dragões: Os Nove Reinos S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/326174.mp4', 'http://gstaticontent.com/images/a7c79ddb46fb60993a3ce87b21d763d8.jpg'),
(85063, 5875, 'Dragões: Os Nove Reinos S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/326175.mp4', 'http://gstaticontent.com/images/a7c79ddb46fb60993a3ce87b21d763d8.jpg'),
(85064, 5875, 'Dragões: Os Nove Reinos S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/326176.mp4', 'http://gstaticontent.com/images/a7c79ddb46fb60993a3ce87b21d763d8.jpg'),
(85065, 5876, 'Ghost in the Shell: SAC_2045 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180467.mp4', 'http://timg.bdta.pro/images/3a758d706c87cfd9767843baeb9a2a57.jpg'),
(85066, 5876, 'Ghost in the Shell: SAC_2045 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180468.mp4', 'http://timg.bdta.pro/images/3220c276071686de6085ec27e7d137b2.jpg'),
(85067, 5876, 'Ghost in the Shell: SAC_2045 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180469.mp4', 'http://timg.bdta.pro/images/6c442085a5c7fc5ad2cec4653939e800.jpg'),
(85068, 5876, 'Ghost in the Shell: SAC_2045 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180470.mp4', 'http://timg.bdta.pro/images/fe157d492f38fcc6fd1ff0c2b37d9c9b.jpg'),
(85069, 5876, 'Ghost in the Shell: SAC_2045 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180471.mp4', 'http://timg.bdta.pro/images/8976c142f2321d46edf968f2fad51789.jpg'),
(85070, 5876, 'Ghost in the Shell: SAC_2045 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180472.mp4', 'http://timg.bdta.pro/images/c9ce4de379422b7538c9b974f014d30b.jpg'),
(85071, 5876, 'Ghost in the Shell: SAC_2045 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180473.mp4', 'http://timg.bdta.pro/images/19a2a9126ca0110eda9b2c18350987ca.jpg'),
(85072, 5876, 'Ghost in the Shell: SAC_2045 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180474.mp4', 'http://timg.bdta.pro/images/123c8f089eff0a6853b7922be4389d3f.jpg'),
(85073, 5876, 'Ghost in the Shell: SAC_2045 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180475.mp4', 'http://timg.bdta.pro/images/48e5ee29125ae6cba00147702318fdea.jpg'),
(85074, 5876, 'Ghost in the Shell: SAC_2045 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180476.mp4', 'http://timg.bdta.pro/images/0bb38ba7c97f25cc947b4ecc8a1aa8f1.jpg'),
(85075, 5876, 'Ghost in the Shell: SAC_2045 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/180477.mp4', 'http://timg.bdta.pro/images/8d32232979c0df579d05232a575dd0c4.jpg'),
(85076, 5876, 'Ghost in the Shell: SAC_2045 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/180478.mp4', 'http://timg.bdta.pro/images/13dba80f12c9d87be32c1cdca055035d.jpg'),
(85077, 5877, 'Ghost in the Shell: SAC_2045 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180479.mp4', 'http://timg.bdta.pro/images/5b546a272a78a165297d049b4b653dc6.jpg'),
(85078, 5877, 'Ghost in the Shell: SAC_2045 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180480.mp4', 'http://timg.bdta.pro/images/a66e34a9fe585ded781bf3a8f8494a82.jpg'),
(85079, 5877, 'Ghost in the Shell: SAC_2045 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180481.mp4', 'http://timg.bdta.pro/images/6df5937a348efc0c7eba54d1523ef130.jpg'),
(85080, 5877, 'Ghost in the Shell: SAC_2045 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180482.mp4', 'http://timg.bdta.pro/images/3ce9f5e061cc6a151f9aa6ffa91e8578.jpg'),
(85081, 5877, 'Ghost in the Shell: SAC_2045 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180483.mp4', 'http://timg.bdta.pro/images/5aacebbb94029d4e7f95bc7b54154857.jpg'),
(85082, 5877, 'Ghost in the Shell: SAC_2045 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180484.mp4', 'http://timg.bdta.pro/images/4c6af675daff5b3d8aef2895b49282a5.jpg'),
(85083, 5877, 'Ghost in the Shell: SAC_2045 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180485.mp4', 'http://timg.bdta.pro/images/d0cfdf760594e9db4a494ad228ed4b64.jpg'),
(85084, 5877, 'Ghost in the Shell: SAC_2045 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180486.mp4', 'http://timg.bdta.pro/images/9c727c937403f0ca8d672cb84e36296f.jpg'),
(85085, 5877, 'Ghost in the Shell: SAC_2045 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180487.mp4', 'http://timg.bdta.pro/images/6e06b54d2d614541ee796f7c0c273a0d.jpg'),
(85086, 5877, 'Ghost in the Shell: SAC_2045 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180488.mp4', 'http://timg.bdta.pro/images/5b7fbf0b88ef118c80377e860cc0a4b5.jpg'),
(85087, 5877, 'Ghost in the Shell: SAC_2045 S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/180489.mp4', 'http://timg.bdta.pro/images/d2f6100f729c85a2387d747668cfd8f8.jpg'),
(85088, 5877, 'Ghost in the Shell: SAC_2045 S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/180490.mp4', 'http://timg.bdta.pro/images/725a3314e9365915b4c43fa5d533121b.jpg'),
(85089, 5878, 'Grandes Fugas com Morgan Freeman S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179683.mp4', 'http://timg.bdta.pro/images/673409aee6a3501858bc79892aef2336.jpg'),
(85090, 5878, 'Grandes Fugas com Morgan Freeman S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179684.mp4', 'http://timg.bdta.pro/images/8b46dc50c29c745c1e5ede1634751a3e.jpg'),
(85091, 5878, 'Grandes Fugas com Morgan Freeman S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179685.mp4', 'http://timg.bdta.pro/images/e3e9612f2e3e4b99e17bb412feb619e7.jpg'),
(85092, 5878, 'Grandes Fugas com Morgan Freeman S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179686.mp4', 'http://timg.bdta.pro/images/56b6f6d80685e1640ea1534b9be933f7.jpg'),
(85093, 5878, 'Grandes Fugas com Morgan Freeman S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179687.mp4', 'http://timg.bdta.pro/images/1ed6371cb553b01446fdd4d714235130.jpg'),
(85094, 5878, 'Grandes Fugas com Morgan Freeman S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179688.mp4', 'http://timg.bdta.pro/images/66a60ba900a00e86421f02bbf2ea3b73.jpg'),
(85095, 5878, 'Grandes Fugas com Morgan Freeman S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179689.mp4', 'http://timg.bdta.pro/images/afddcff136515d9233dadb2b5f71dc16.jpg'),
(85096, 5878, 'Grandes Fugas com Morgan Freeman S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179690.mp4', 'http://timg.bdta.pro/images/91d8c040aa6e20aa5ead68a30681490f.jpg'),
(85097, 5879, 'Ken e Barbie: O Casal Assassino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180463.mp4', 'http://timg.bdta.pro/images/a736df0bc4dea43f12e60eb2efb9de47.jpg'),
(85098, 5879, 'Ken e Barbie: O Casal Assassino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180464.mp4', 'http://timg.bdta.pro/images/a7a3afdc731780db84b8d19c4d562990.jpg'),
(85099, 5879, 'Ken e Barbie: O Casal Assassino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180465.mp4', 'http://timg.bdta.pro/images/4e17513a5c5ec229456a229b6ac0782c.jpg'),
(85100, 5879, 'Ken e Barbie: O Casal Assassino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180466.mp4', 'http://timg.bdta.pro/images/84253b447fd5dbc324b9dd6c3d7b9987.jpg'),
(85101, 5880, 'Las Bravas FC S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180455.mp4', 'http://timg.bdta.pro/images/138df9c658ef1014894777551ab7a933.jpg'),
(85102, 5880, 'Las Bravas FC S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180456.mp4', 'http://timg.bdta.pro/images/413b7d2aa595106e74bd3fed127cbd98.jpg'),
(85103, 5880, 'Las Bravas FC S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180457.mp4', 'http://timg.bdta.pro/images/a0d34a64bf434a767da4091545981f86.jpg'),
(85104, 5880, 'Las Bravas FC S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180458.mp4', 'http://timg.bdta.pro/images/93b99b8c8a88b13cfa338df72b45ac47.jpg'),
(85105, 5880, 'Las Bravas FC S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180459.mp4', 'http://timg.bdta.pro/images/da784382871710592a972ab52f2df610.jpg'),
(85106, 5880, 'Las Bravas FC S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180460.mp4', 'http://timg.bdta.pro/images/a3e2b36e2c81e16e0093c91213101ab2.jpg'),
(85107, 5880, 'Las Bravas FC S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180461.mp4', 'http://timg.bdta.pro/images/1d02f4399132a5cb24523c3e47746db3.jpg'),
(85108, 5880, 'Las Bravas FC S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180462.mp4', 'http://timg.bdta.pro/images/fcca0c03696956cba32ef648c47356ca.jpg'),
(85109, 5881, 'Now and Then: O Segredo que Nos Une S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183795.mp4', 'http://timg.bdta.pro/images/33aa14787061f7db88ad79d921313842.jpg'),
(85110, 5881, 'Now and Then: O Segredo que Nos Une S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183796.mp4', 'http://timg.bdta.pro/images/1dd1ebcb6e5f4ed173b30d1b6094476f.jpg'),
(85111, 5881, 'Now and Then: O Segredo que Nos Une S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183797.mp4', 'http://timg.bdta.pro/images/8ac61825a47c2fe35f0a3493f127ed2d.jpg'),
(85112, 5881, 'Now and Then: O Segredo que Nos Une S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183798.mp4', 'http://timg.bdta.pro/images/c0c0fb9789f24c811c8c02b445a4974b.jpg'),
(85113, 5881, 'Now and Then: O Segredo que Nos Une S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183799.mp4', 'http://timg.bdta.pro/images/5888df0865687eed8185aed5bef8e9c4.jpg'),
(85114, 5881, 'Now and Then: O Segredo que Nos Une S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183800.mp4', 'http://timg.bdta.pro/images/b97cf2ae196e7169db15ecd502dbb050.jpg'),
(85115, 5881, 'Now and Then: O Segredo que Nos Une S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183801.mp4', 'http://timg.bdta.pro/images/2bfbf83a6cf9686c8bc45e6527bab17e.jpg'),
(85116, 5881, 'Now and Then: O Segredo que Nos Une S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183802.mp4', 'http://timg.bdta.pro/images/02fde5aa9fcf3a8b356d1f015376976d.jpg'),
(85117, 5882, 'O Que Você Não Sabia Sobre o Humor Brasileiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180449.mp4', 'http://timg.bdta.pro/images/79dde9d12c15d42bf8fb79c6f7a2a75c.jpg'),
(85118, 5882, 'O Que Você Não Sabia Sobre o Humor Brasileiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180450.mp4', 'http://timg.bdta.pro/images/d5a3749a9ee9bc3d3895b471e803c7ec.jpg'),
(85119, 5882, 'O Que Você Não Sabia Sobre o Humor Brasileiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180451.mp4', 'http://timg.bdta.pro/images/0544c5f77cd2213436a3e26bad916892.jpg'),
(85120, 5882, 'O Que Você Não Sabia Sobre o Humor Brasileiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180452.mp4', 'http://timg.bdta.pro/images/43350199ae38f83f541e6e2303caf1d8.jpg'),
(85121, 5882, 'O Que Você Não Sabia Sobre o Humor Brasileiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180453.mp4', 'http://timg.bdta.pro/images/298f17e0d0114665e0bb21b0874d8c54.jpg'),
(85122, 5882, 'O Que Você Não Sabia Sobre o Humor Brasileiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180454.mp4', 'http://timg.bdta.pro/images/02682f37772596405369799e14537c7a.jpg'),
(85123, 5883, 'Os Apuros de Penélope Charmosa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180432.mp4', 'http://timg.bdta.pro/images/7b16a0b73d7c5ea149b577a95b181a0d.jpg'),
(85124, 5883, 'Os Apuros de Penélope Charmosa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180433.mp4', 'http://timg.bdta.pro/images/468f5c85155f0e1458e4b7e2dc60c8e5.jpg'),
(85125, 5883, 'Os Apuros de Penélope Charmosa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180434.mp4', 'http://timg.bdta.pro/images/11e685a89e5e7b39f92a91f5b3085b02.jpg'),
(85126, 5883, 'Os Apuros de Penélope Charmosa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180435.mp4', 'http://timg.bdta.pro/images/a8f7e7bae8eafdc411b42b5c6b248f7f.jpg'),
(85127, 5883, 'Os Apuros de Penélope Charmosa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180436.mp4', 'http://timg.bdta.pro/images/a58675c09f987988580671b989e5990d.jpg'),
(85128, 5883, 'Os Apuros de Penélope Charmosa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180437.mp4', 'http://timg.bdta.pro/images/97e3be79505615a5cc798b8b7bd5d38d.jpg'),
(85129, 5883, 'Os Apuros de Penélope Charmosa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180438.mp4', 'http://timg.bdta.pro/images/7533913502fa6e16b48ae791ae5b9308.jpg'),
(85130, 5883, 'Os Apuros de Penélope Charmosa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180439.mp4', 'http://timg.bdta.pro/images/5dcb314bf3a593de67079e06670ca6d2.jpg'),
(85131, 5883, 'Os Apuros de Penélope Charmosa S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180440.mp4', 'http://timg.bdta.pro/images/da3d57ce51aebcef34f719772de96f6a.jpg'),
(85132, 5883, 'Os Apuros de Penélope Charmosa S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180441.mp4', 'http://timg.bdta.pro/images/038549204a5808508c1f470311de9639.jpg'),
(85133, 5883, 'Os Apuros de Penélope Charmosa S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/180442.mp4', 'http://timg.bdta.pro/images/2ec4c5b19840921e33ebed442291564b.jpg'),
(85134, 5883, 'Os Apuros de Penélope Charmosa S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/180443.mp4', 'http://timg.bdta.pro/images/822ad3047afbd0a05cd23a689d27c923.jpg'),
(85135, 5883, 'Os Apuros de Penélope Charmosa S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/180444.mp4', 'http://timg.bdta.pro/images/4beaf2acf33ad7190c94e664e09f787e.jpg'),
(85136, 5883, 'Os Apuros de Penélope Charmosa S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/180445.mp4', 'http://timg.bdta.pro/images/1a31ab1b1bb4c5ecb7f9d21e51017ab0.jpg'),
(85137, 5883, 'Os Apuros de Penélope Charmosa S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/180446.mp4', 'http://timg.bdta.pro/images/dc5a60454c33c33b20dbd111b131f137.jpg'),
(85138, 5883, 'Os Apuros de Penélope Charmosa S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/180447.mp4', 'http://timg.bdta.pro/images/cee83f712c790c85f172a02eefc8ef55.jpg'),
(85139, 5883, 'Os Apuros de Penélope Charmosa S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/180448.mp4', 'http://timg.bdta.pro/images/6d9b188c5d74094039ef5afb12440e36.jpg'),
(85140, 5884, 'PCC: Poder Secreto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180428.mp4', 'http://timg.bdta.pro/images/277b52739d14fdde5bedfc46ed63a553.jpg'),
(85141, 5884, 'PCC: Poder Secreto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180429.mp4', 'http://timg.bdta.pro/images/2b1c629c452da4a80984fa2eb8f817bf.jpg'),
(85142, 5884, 'PCC: Poder Secreto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180430.mp4', 'http://timg.bdta.pro/images/6b7414a6dbfd4bcdc3b7bffd46eb5e1a.jpg'),
(85143, 5884, 'PCC: Poder Secreto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180431.mp4', 'http://timg.bdta.pro/images/b7300924e62f99cbb00d29cd01a5275a.jpg'),
(85144, 5885, 'Planeta Pré-Histórico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217423.mp4', 'http://timg.bdta.pro/images/6b8302dd49ee52dfc64563ff60102f1a.jpg'),
(85145, 5885, 'Planeta Pré-Histórico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217424.mp4', 'http://timg.bdta.pro/images/4c1b15c131e6ae8fe1079ba82e450337.jpg'),
(85146, 5885, 'Planeta Pré-Histórico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217425.mp4', 'http://timg.bdta.pro/images/a4850e95774047bf2a19718be4dabf94.jpg'),
(85147, 5885, 'Planeta Pré-Histórico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217426.mp4', 'http://timg.bdta.pro/images/939b332a4007a9589c4017cf732f5895.jpg'),
(85148, 5885, 'Planeta Pré-Histórico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217427.mp4', 'http://timg.bdta.pro/images/1250f19062b3f1af4e8feb87922cced1.jpg'),
(85149, 5886, 'Planeta Pré-Histórico S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217428.mp4', 'http://image.tmdb.org/t/p/w1280/7vK38gc1Hxpuw0omgR4EW64n6gT.jpg'),
(85150, 5886, 'Planeta Pré-Histórico S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kx72xr6EFg03u0q3Tsb2BhllEW2.jpg'),
(85151, 5886, 'Planeta Pré-Histórico S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ocDS8tCsp7p1XRPwtl6lZtlAnSr.jpg'),
(85152, 5886, 'Planeta Pré-Histórico S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ZcyuOBY8k1GVaJDrtB6ex8uG2k.jpg'),
(85153, 5886, 'Planeta Pré-Histórico S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d5wq6gBAyuXOFDQVKzxhTtVqTGZ.jpg'),
(85154, 5887, 'Planeta Pré-Histórico S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/893456.mp4', 'http://gstaticontent.com/images/b461142189b3ff4cc79421553835a76a.jpg'),
(85155, 5887, 'Planeta Pré-Histórico S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/893457.mp4', 'http://gstaticontent.com/images/b461142189b3ff4cc79421553835a76a.jpg'),
(85156, 5887, 'Planeta Pré-Histórico S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/893458.mp4', 'http://gstaticontent.com/images/b461142189b3ff4cc79421553835a76a.jpg'),
(85157, 5887, 'Planeta Pré-Histórico S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/893459.mp4', 'http://gstaticontent.com/images/b461142189b3ff4cc79421553835a76a.jpg'),
(85158, 5887, 'Planeta Pré-Histórico S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/893460.mp4', 'http://gstaticontent.com/images/b461142189b3ff4cc79421553835a76a.jpg'),
(85159, 5888, 'The Thing About Pam S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180422.mp4', 'http://timg.bdta.pro/images/b3c58fcdd14d52cd52c6322bbda9c305.jpg'),
(85160, 5888, 'The Thing About Pam S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180423.mp4', 'http://timg.bdta.pro/images/bcbdc243bcf05f6b91dd54c2a23de5df.jpg'),
(85161, 5888, 'The Thing About Pam S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180424.mp4', 'http://timg.bdta.pro/images/38b1cc1670c93cb69cae20f60cd173ed.jpg'),
(85162, 5888, 'The Thing About Pam S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180425.mp4', 'http://timg.bdta.pro/images/9fc20e1ef83763c0386d9fd87b8b3fd9.jpg'),
(85163, 5888, 'The Thing About Pam S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180426.mp4', 'http://timg.bdta.pro/images/cf97c14da034f9e705ddad3e9c8bdc6c.jpg'),
(85164, 5888, 'The Thing About Pam S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180427.mp4', 'http://gstaticontent.com/images/3cad025ad501e27437c9c5492e4f44a2.jpg'),
(85165, 5889, 'Tudo Igual… SQN S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234612.mp4', 'http://timg.bdta.pro/images/42baaa04eeedb19f3ea7bd2d1d9f58b7.jpg'),
(85166, 5889, 'Tudo Igual… SQN S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234613.mp4', 'http://timg.bdta.pro/images/ab1c7b85a9597b9a3f03b1ef330bc3a6.jpg'),
(85167, 5889, 'Tudo Igual… SQN S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234614.mp4', 'http://timg.bdta.pro/images/46ed2823a1860d9891c466609393d48a.jpg'),
(85168, 5889, 'Tudo Igual… SQN S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234615.mp4', 'http://timg.bdta.pro/images/5022fd4ea7fb119860e33e23e538aed6.jpg'),
(85169, 5889, 'Tudo Igual… SQN S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234616.mp4', 'http://timg.bdta.pro/images/68f8443b6fbf44204c7cf2342f57a09c.jpg'),
(85170, 5889, 'Tudo Igual… SQN S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234617.mp4', 'http://timg.bdta.pro/images/a27a535973bf1d4f294537a70e0838da.jpg'),
(85171, 5889, 'Tudo Igual… SQN S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234618.mp4', 'http://timg.bdta.pro/images/c9aad102fcf23f8682a67eb29087ced8.jpg'),
(85172, 5889, 'Tudo Igual… SQN S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234619.mp4', 'http://timg.bdta.pro/images/74c9caafd6baa384caa2dbe2bd0528d5.jpg'),
(85173, 5889, 'Tudo Igual… SQN S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234620.mp4', 'http://timg.bdta.pro/images/0e22e2ce2761490ab9312ede1c50737a.jpg'),
(85174, 5889, 'Tudo Igual… SQN S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234621.mp4', 'http://timg.bdta.pro/images/b64c6bf0b5a4ef1433a6076f00fa9bc5.jpg'),
(85175, 5890, 'Tudo Igual… SQN S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234622.mp4', 'http://gstaticontent.com/images/db9285f26e4e69dff6c38b5a35c34942.jpg'),
(85176, 5890, 'Tudo Igual… SQN S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234623.mp4', 'http://gstaticontent.com/images/db9285f26e4e69dff6c38b5a35c34942.jpg'),
(85177, 5890, 'Tudo Igual… SQN S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234624.mp4', 'http://gstaticontent.com/images/db9285f26e4e69dff6c38b5a35c34942.jpg'),
(85178, 5890, 'Tudo Igual… SQN S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234625.mp4', 'http://gstaticontent.com/images/db9285f26e4e69dff6c38b5a35c34942.jpg'),
(85179, 5890, 'Tudo Igual… SQN S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234626.mp4', 'http://gstaticontent.com/images/db9285f26e4e69dff6c38b5a35c34942.jpg'),
(85180, 5890, 'Tudo Igual… SQN S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234627.mp4', 'http://gstaticontent.com/images/db9285f26e4e69dff6c38b5a35c34942.jpg'),
(85181, 5890, 'Tudo Igual… SQN S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234628.mp4', 'http://gstaticontent.com/images/db9285f26e4e69dff6c38b5a35c34942.jpg'),
(85182, 5890, 'Tudo Igual… SQN S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234629.mp4', 'http://gstaticontent.com/images/db9285f26e4e69dff6c38b5a35c34942.jpg'),
(85183, 5891, 'A Cidade É Nossa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i5Y2H5C30MEnnAHt25jadT9J1Nw.jpg'),
(85184, 5891, 'A Cidade É Nossa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180417.mp4', 'http://timg.bdta.pro/images/15e4635a50b5b97118ae50282b42844c.jpg'),
(85185, 5891, 'A Cidade É Nossa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180418.mp4', 'http://timg.bdta.pro/images/c117b71c414b8f8aa444864551347b0b.jpg'),
(85186, 5891, 'A Cidade É Nossa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180419.mp4', 'http://timg.bdta.pro/images/e9887dc1aabaa1cf96d4e25514072e13.jpg'),
(85187, 5891, 'A Cidade É Nossa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180420.mp4', 'http://timg.bdta.pro/images/5ac8fd2062da689cff02f6b5180c0a85.jpg'),
(85188, 5891, 'A Cidade É Nossa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180421.mp4', 'http://timg.bdta.pro/images/341586d3550ace4587b4193de5a93f68.jpg'),
(85189, 5892, 'Asas da Ambição S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248116.mp4', 'http://timg.bdta.pro/images/547885cbe458f28726c981e0e41540b3.jpg'),
(85190, 5892, 'Asas da Ambição S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248117.mp4', 'http://timg.bdta.pro/images/b9dc6504efefeb5b476ee78dce722a7f.jpg'),
(85191, 5892, 'Asas da Ambição S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248118.mp4', 'http://timg.bdta.pro/images/633197b5af08ab277a4782ef526d829a.jpg'),
(85192, 5892, 'Asas da Ambição S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248119.mp4', 'http://timg.bdta.pro/images/91b3932ac2d23d81929fb765c960b439.jpg'),
(85193, 5892, 'Asas da Ambição S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248120.mp4', 'http://timg.bdta.pro/images/3580d1a5d182f7103665a772afe21165.jpg'),
(85194, 5892, 'Asas da Ambição S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248121.mp4', 'http://timg.bdta.pro/images/0c0a6e25cff197f335afc7c0b0ef9e62.jpg'),
(85195, 5892, 'Asas da Ambição S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248122.mp4', 'http://timg.bdta.pro/images/f08b3e1dfa612ee282f67316da8f6c57.jpg'),
(85196, 5892, 'Asas da Ambição S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248123.mp4', 'http://timg.bdta.pro/images/c021b0c38f9fe5b9fbef3ed6cfd1d42e.jpg'),
(85197, 5893, 'Asas da Ambição S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248124.mp4', 'http://gstaticontent.com/images/9d49883ec393fbd06e9f11c98e69b393.jpg'),
(85198, 5893, 'Asas da Ambição S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248125.mp4', 'http://gstaticontent.com/images/9d49883ec393fbd06e9f11c98e69b393.jpg'),
(85199, 5893, 'Asas da Ambição S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248126.mp4', 'http://gstaticontent.com/images/9d49883ec393fbd06e9f11c98e69b393.jpg'),
(85200, 5893, 'Asas da Ambição S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248127.mp4', 'http://gstaticontent.com/images/9d49883ec393fbd06e9f11c98e69b393.jpg'),
(85201, 5893, 'Asas da Ambição S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248128.mp4', 'http://gstaticontent.com/images/9d49883ec393fbd06e9f11c98e69b393.jpg'),
(85202, 5893, 'Asas da Ambição S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248129.mp4', 'http://gstaticontent.com/images/9d49883ec393fbd06e9f11c98e69b393.jpg'),
(85203, 5893, 'Asas da Ambição S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248130.mp4', 'http://gstaticontent.com/images/9d49883ec393fbd06e9f11c98e69b393.jpg'),
(85204, 5893, 'Asas da Ambição S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248131.mp4', 'http://gstaticontent.com/images/9d49883ec393fbd06e9f11c98e69b393.jpg'),
(85205, 5894, 'Asas da Ambição S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/329079.mp4', 'http://gstaticontent.com/images/9d49883ec393fbd06e9f11c98e69b393.jpg'),
(85206, 5894, 'Asas da Ambição S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/329080.mp4', 'http://gstaticontent.com/images/9d49883ec393fbd06e9f11c98e69b393.jpg'),
(85207, 5894, 'Asas da Ambição S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/329081.mp4', 'http://gstaticontent.com/images/9d49883ec393fbd06e9f11c98e69b393.jpg'),
(85208, 5894, 'Asas da Ambição S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/329082.mp4', 'http://gstaticontent.com/images/9d49883ec393fbd06e9f11c98e69b393.jpg'),
(85209, 5894, 'Asas da Ambição S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/329083.mp4', 'http://gstaticontent.com/images/9d49883ec393fbd06e9f11c98e69b393.jpg'),
(85210, 5894, 'Asas da Ambição S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/329084.mp4', 'http://gstaticontent.com/images/9d49883ec393fbd06e9f11c98e69b393.jpg'),
(85211, 5894, 'Asas da Ambição S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/329085.mp4', 'http://gstaticontent.com/images/9d49883ec393fbd06e9f11c98e69b393.jpg'),
(85212, 5894, 'Asas da Ambição S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/329086.mp4', 'http://gstaticontent.com/images/9d49883ec393fbd06e9f11c98e69b393.jpg'),
(85213, 5895, 'Dois Verões S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180410.mp4', 'http://timg.bdta.pro/images/14c07c5b96e7ef6d853872becae61fcc.jpg'),
(85214, 5895, 'Dois Verões S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180411.mp4', 'http://timg.bdta.pro/images/b221540cd3269b572ac55d0e05761699.jpg'),
(85215, 5895, 'Dois Verões S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180412.mp4', 'http://timg.bdta.pro/images/e116c95eb401a82b4648ebebfa09837f.jpg'),
(85216, 5895, 'Dois Verões S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180413.mp4', 'http://timg.bdta.pro/images/bc83c04292e3fc83575e92e1eeb58093.jpg'),
(85217, 5895, 'Dois Verões S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180414.mp4', 'http://timg.bdta.pro/images/dd2ea11b41f2cf87fda1720f7f5f3fab.jpg'),
(85218, 5895, 'Dois Verões S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180415.mp4', 'http://timg.bdta.pro/images/10716ec5508dec491c09d1508c8911aa.jpg'),
(85219, 5896, 'Freakazoid: Alto Forte e Maluco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/561215.mp4', 'http://gstaticontent.com/images/353f5417ca1705afffdbe22d97719294.jpg'),
(85220, 5896, 'Freakazoid: Alto Forte e Maluco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/561217.mp4', 'http://gstaticontent.com/images/2db4154d2f739e72a214c41a9194969c.jpg'),
(85221, 5896, 'Freakazoid: Alto Forte e Maluco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/561219.mp4', 'http://gstaticontent.com/images/52870c2ec929048fc0d0ed947def6456.jpg'),
(85222, 5896, 'Freakazoid: Alto Forte e Maluco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/561221.mp4', 'http://gstaticontent.com/images/c805f5f0b11e1d9d83b51d60adae319c.jpg'),
(85223, 5896, 'Freakazoid: Alto Forte e Maluco S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/561223.mp4', 'http://gstaticontent.com/images/a33fc4dfa0da78f910c07ea127e10c13.jpg'),
(85224, 5896, 'Freakazoid: Alto Forte e Maluco S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/561225.mp4', 'http://gstaticontent.com/images/a7077334e54521cdbc43a23446df4b78.jpg'),
(85225, 5896, 'Freakazoid: Alto Forte e Maluco S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/561227.mp4', 'http://gstaticontent.com/images/238c9e96be99ddfb55207b1c5387ce4a.jpg'),
(85226, 5896, 'Freakazoid: Alto Forte e Maluco S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/561229.mp4', 'http://gstaticontent.com/images/eb294d618387f4e146ce5dcfc831a76b.jpg'),
(85227, 5896, 'Freakazoid: Alto Forte e Maluco S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/561231.mp4', 'http://gstaticontent.com/images/898bc2a52f550667733cc2759790ee0a.jpg'),
(85228, 5896, 'Freakazoid: Alto Forte e Maluco S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/561233.mp4', 'http://gstaticontent.com/images/85ca31c07c2c55e2efcc8ec97f42a5c7.jpg'),
(85229, 5896, 'Freakazoid: Alto Forte e Maluco S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/561235.mp4', 'http://gstaticontent.com/images/5753cfd96c669761e87db44e252793d2.jpg'),
(85230, 5896, 'Freakazoid: Alto Forte e Maluco S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/561237.mp4', 'http://gstaticontent.com/images/3464524f821d16656405bcf5607467fe.jpg'),
(85231, 5896, 'Freakazoid: Alto Forte e Maluco S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/561239.mp4', 'http://gstaticontent.com/images/04d9ee5e7051a1bd760115086a4bad8c.jpg'),
(85232, 5897, 'Freakazoid: Alto Forte e Maluco S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/561241.mp4', 'http://gstaticontent.com/images/a3e76afa4c221d28877a08c4f9644e02.jpg'),
(85233, 5897, 'Freakazoid: Alto Forte e Maluco S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/561243.mp4', 'http://gstaticontent.com/images/2d30642ccf3cc2751b6b6f7a61452e44.jpg'),
(85234, 5897, 'Freakazoid: Alto Forte e Maluco S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/561245.mp4', 'http://gstaticontent.com/images/3635469c2757eb2ec8268c91f5e81915.jpg'),
(85235, 5897, 'Freakazoid: Alto Forte e Maluco S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/561247.mp4', 'http://gstaticontent.com/images/c23b36bce347910b29c14fd4135c2034.jpg'),
(85236, 5897, 'Freakazoid: Alto Forte e Maluco S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/561249.mp4', 'http://gstaticontent.com/images/a8627d34046f1c4e538aadc8bdc4dfe9.jpg'),
(85237, 5897, 'Freakazoid: Alto Forte e Maluco S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/561251.mp4', 'http://gstaticontent.com/images/50678170b173a862fc1d0bfb8274c666.jpg'),
(85238, 5897, 'Freakazoid: Alto Forte e Maluco S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/561253.mp4', 'http://gstaticontent.com/images/6dfb9c9aadcc071bd680932f501fa87f.jpg'),
(85239, 5897, 'Freakazoid: Alto Forte e Maluco S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/561255.mp4', 'http://gstaticontent.com/images/b94931458706dc1ef29e7c7ecc368a3f.jpg'),
(85240, 5897, 'Freakazoid: Alto Forte e Maluco S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/561257.mp4', 'http://gstaticontent.com/images/d857cd691d6c3775440a173235c0263f.jpg'),
(85241, 5897, 'Freakazoid: Alto Forte e Maluco S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/561259.mp4', 'http://gstaticontent.com/images/c1deae95ad0d6592376d9caa06c5da08.jpg'),
(85242, 5897, 'Freakazoid: Alto Forte e Maluco S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/561261.mp4', 'http://gstaticontent.com/images/1b5d997fb7864902eb9799cadcef427d.jpg'),
(85243, 5898, 'Jogo da Lava S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196866.mp4', 'http://gstaticontent.com/images/6911f9c4d605f70bf74475fda6ef591b.jpg'),
(85244, 5898, 'Jogo da Lava S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196867.mp4', 'http://gstaticontent.com/images/6911f9c4d605f70bf74475fda6ef591b.jpg'),
(85245, 5898, 'Jogo da Lava S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196868.mp4', 'http://timg.bdta.pro/images/a35a475ca8bec02c38bc45f65116f4dd.jpg'),
(85246, 5898, 'Jogo da Lava S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196869.mp4', 'http://timg.bdta.pro/images/abed6dc88cb421a929fce77c34677e7c.jpg'),
(85247, 5898, 'Jogo da Lava S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196870.mp4', 'http://timg.bdta.pro/images/0e83832f7d01763febfa6c8d940c30d7.jpg'),
(85248, 5898, 'Jogo da Lava S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196871.mp4', 'http://timg.bdta.pro/images/405fdc63f407eba8646258bf8935fd03.jpg'),
(85249, 5898, 'Jogo da Lava S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196872.mp4', 'http://timg.bdta.pro/images/0ba5ce33c9deca9a551593e378d1a01c.jpg'),
(85250, 5898, 'Jogo da Lava S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196873.mp4', 'http://timg.bdta.pro/images/baa9d730bbfc6dddf3582f2c7f0db5a0.jpg'),
(85251, 5898, 'Jogo da Lava S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196874.mp4', 'http://timg.bdta.pro/images/f2d628af835c2d1fd326c3e641baaa21.jpg'),
(85252, 5898, 'Jogo da Lava S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196875.mp4', 'http://timg.bdta.pro/images/8b4797763c9343decb256b90ef87f23a.jpg'),
(85253, 5899, 'Jogo da Lava S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196876.mp4', 'http://timg.bdta.pro/images/0125c0c4bfadcbb4fcf227160311ef27.jpg'),
(85254, 5899, 'Jogo da Lava S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196877.mp4', 'http://timg.bdta.pro/images/5d3e51edf910b82fc0f53461acbd66bd.jpg'),
(85255, 5899, 'Jogo da Lava S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196878.mp4', 'http://timg.bdta.pro/images/4e7393d6ba922a5780100a543c16352d.jpg'),
(85256, 5899, 'Jogo da Lava S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196879.mp4', 'http://timg.bdta.pro/images/6bea9aa58e3ea49156945eed5b37d136.jpg'),
(85257, 5899, 'Jogo da Lava S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196880.mp4', 'http://timg.bdta.pro/images/78380a2b81729812b8f51fbd602960f3.jpg'),
(85258, 5900, 'Jogo da Lava S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196881.mp4', 'http://gstaticontent.com/images/6911f9c4d605f70bf74475fda6ef591b.jpg'),
(85259, 5900, 'Jogo da Lava S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196882.mp4', 'http://gstaticontent.com/images/6911f9c4d605f70bf74475fda6ef591b.jpg'),
(85260, 5900, 'Jogo da Lava S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196883.mp4', 'http://gstaticontent.com/images/6911f9c4d605f70bf74475fda6ef591b.jpg'),
(85261, 5900, 'Jogo da Lava S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196884.mp4', 'http://gstaticontent.com/images/6911f9c4d605f70bf74475fda6ef591b.jpg'),
(85262, 5900, 'Jogo da Lava S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196885.mp4', 'http://gstaticontent.com/images/6911f9c4d605f70bf74475fda6ef591b.jpg'),
(85263, 5901, 'Obi-Wan Kenobi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183789.mp4', 'http://timg.bdta.pro/images/b18a89a7019385a2da873aa0885d8057.jpg'),
(85264, 5901, 'Obi-Wan Kenobi S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183790.mp4', 'http://timg.bdta.pro/images/d2029bec6ba9784ed749a990f0a806db.jpg'),
(85265, 5901, 'Obi-Wan Kenobi S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183791.mp4', 'http://timg.bdta.pro/images/bafeaa29a12d13f333930f11e43c1964.jpg'),
(85266, 5901, 'Obi-Wan Kenobi S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183792.mp4', 'http://timg.bdta.pro/images/b1e2066440553bcb4b9734872de8a3c4.jpg'),
(85267, 5901, 'Obi-Wan Kenobi S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183793.mp4', 'http://timg.bdta.pro/images/946915bb3c3781cb5fc068bd18a31f46.jpg'),
(85268, 5901, 'Obi-Wan Kenobi S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183794.mp4', 'http://timg.bdta.pro/images/c800806f47c77409753667596337979c.jpg'),
(85269, 5902, 'Policial ou Bandido: O Enigma de Eirik Jensen S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180406.mp4', 'http://timg.bdta.pro/images/f1ef65789f3681162626c279baf8699f.jpg'),
(85270, 5902, 'Policial ou Bandido: O Enigma de Eirik Jensen S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180407.mp4', 'http://timg.bdta.pro/images/f1485e54fab4d58a0799bebb7ae0d83b.jpg'),
(85271, 5902, 'Policial ou Bandido: O Enigma de Eirik Jensen S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180408.mp4', 'http://timg.bdta.pro/images/978f2f60bb0ebe9c5dce7a72cd9c96ce.jpg'),
(85272, 5902, 'Policial ou Bandido: O Enigma de Eirik Jensen S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180409.mp4', 'http://timg.bdta.pro/images/6bbeb910ce60de205aba9ddff7fa276f.jpg'),
(85273, 5903, 'Relatos do Front A Outra Face do Cartao Postal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180402.mp4', 'http://gstaticontent.com/images/03e59de0fd4bbab1fec5ce3f5e50a9e1.jpg'),
(85274, 5903, 'Relatos do Front A Outra Face do Cartao Postal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180403.mp4', 'http://gstaticontent.com/images/03e59de0fd4bbab1fec5ce3f5e50a9e1.jpg'),
(85275, 5903, 'Relatos do Front A Outra Face do Cartao Postal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180404.mp4', 'http://gstaticontent.com/images/03e59de0fd4bbab1fec5ce3f5e50a9e1.jpg'),
(85276, 5903, 'Relatos do Front A Outra Face do Cartao Postal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180405.mp4', 'http://gstaticontent.com/images/03e59de0fd4bbab1fec5ce3f5e50a9e1.jpg'),
(85277, 5904, 'Shaman King S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180350.mp4', 'http://timg.bdta.pro/images/5043f88215fd21f8097f58854adb766e.jpg'),
(85278, 5904, 'Shaman King S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180351.mp4', 'http://timg.bdta.pro/images/0c0b8e8134df0d03258fe22f14247c4d.jpg'),
(85279, 5904, 'Shaman King S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180352.mp4', 'http://timg.bdta.pro/images/53edac9db5376535bf80a49056827fb4.jpg'),
(85280, 5904, 'Shaman King S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180353.mp4', 'http://timg.bdta.pro/images/7970f1f767af0a52bd844907174042e8.jpg'),
(85281, 5904, 'Shaman King S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180354.mp4', 'http://timg.bdta.pro/images/78ea49bd562c54233f5b5704faa8adc1.jpg'),
(85282, 5904, 'Shaman King S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180355.mp4', 'http://timg.bdta.pro/images/bd2910b23c1c78d8e83cc5e508d46f92.jpg'),
(85283, 5904, 'Shaman King S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180356.mp4', 'http://timg.bdta.pro/images/1d3aedfa3789ce4edac637af82f5f1fc.jpg'),
(85284, 5904, 'Shaman King S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180357.mp4', 'http://timg.bdta.pro/images/0da9d5ee0ffbf058210cbd58de6aaecb.jpg'),
(85285, 5904, 'Shaman King S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180358.mp4', 'http://timg.bdta.pro/images/9d2612eabf007985dc95938142d16c8d.jpg'),
(85286, 5904, 'Shaman King S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180359.mp4', 'http://timg.bdta.pro/images/ab700a99a2e8bc53723c72a58c2aa8e3.jpg'),
(85287, 5904, 'Shaman King S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/180360.mp4', 'http://timg.bdta.pro/images/4c9dcefb8022a7e04afc134a4bff48ea.jpg'),
(85288, 5904, 'Shaman King S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/180361.mp4', 'http://timg.bdta.pro/images/b9d641c1a314ce17b9b2cf3af6e0c24d.jpg'),
(85289, 5904, 'Shaman King S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/180362.mp4', 'http://timg.bdta.pro/images/4c08223792e1f76bb04dc58abda90a3c.jpg'),
(85290, 5904, 'Shaman King S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/180363.mp4', 'http://timg.bdta.pro/images/b615c0505322a24cd8c52f5559edb917.jpg'),
(85291, 5904, 'Shaman King S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/180364.mp4', 'http://timg.bdta.pro/images/24f2b34f6b17faa586d63cf2b67cab98.jpg'),
(85292, 5904, 'Shaman King S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/180365.mp4', 'http://timg.bdta.pro/images/1b1794c112868ec8855974f180aedc29.jpg'),
(85293, 5904, 'Shaman King S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/180366.mp4', 'http://timg.bdta.pro/images/b363c10fe0045f3aac7669a492bca451.jpg'),
(85294, 5904, 'Shaman King S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/180367.mp4', 'http://timg.bdta.pro/images/723a21ea79ea2157a2a77b8c96838e40.jpg'),
(85295, 5904, 'Shaman King S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/180368.mp4', 'http://timg.bdta.pro/images/ae7a42016c1b12bdd309bcf723eced3a.jpg'),
(85296, 5904, 'Shaman King S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/180369.mp4', 'http://timg.bdta.pro/images/2b7040b1583d23c5f034820d95577fc2.jpg'),
(85297, 5904, 'Shaman King S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/180370.mp4', 'http://timg.bdta.pro/images/4f3b16a395f3938e916753eb2dadb3e6.jpg'),
(85298, 5904, 'Shaman King S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/180371.mp4', 'http://timg.bdta.pro/images/82b7987d658edd1fb1a2350c57df0d83.jpg'),
(85299, 5904, 'Shaman King S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/180372.mp4', 'http://timg.bdta.pro/images/8d84a169bad83fdd97729db0ff22c65a.jpg'),
(85300, 5904, 'Shaman King S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/180373.mp4', 'http://timg.bdta.pro/images/ffb68262cde80e8693cb31e8470c89ae.jpg'),
(85301, 5904, 'Shaman King S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/180374.mp4', 'http://timg.bdta.pro/images/59e19017b8d0ed53bfcb5f462bc444da.jpg'),
(85302, 5904, 'Shaman King S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/180375.mp4', 'http://timg.bdta.pro/images/c41bef0c7eaa85ca6bd4b8f57b81ae5b.jpg'),
(85303, 5904, 'Shaman King S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/180376.mp4', 'http://timg.bdta.pro/images/a94eda737252283cae284926f3577f90.jpg'),
(85304, 5904, 'Shaman King S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/180377.mp4', 'http://timg.bdta.pro/images/2da2ba68b6f4fe4088930dbb50f9d771.jpg'),
(85305, 5904, 'Shaman King S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/180378.mp4', 'http://timg.bdta.pro/images/f4e795b2a81c7a8ff250fcc3a8ab246e.jpg'),
(85306, 5904, 'Shaman King S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/180379.mp4', 'http://timg.bdta.pro/images/eba271bde0a48a8a533d9a3c55710a74.jpg'),
(85307, 5904, 'Shaman King S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/180380.mp4', 'http://timg.bdta.pro/images/4aaac37b7950814b8ddefb00b88a355e.jpg'),
(85308, 5904, 'Shaman King S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/180381.mp4', 'http://timg.bdta.pro/images/3845d7d9e8dba311e031720d64653efa.jpg'),
(85309, 5904, 'Shaman King S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/180382.mp4', 'http://timg.bdta.pro/images/7312e5fcca9b43b49530fe4de2be66cf.jpg'),
(85310, 5904, 'Shaman King S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/180383.mp4', 'http://timg.bdta.pro/images/217c8e17ef5bf9160eeb295779f719e7.jpg'),
(85311, 5904, 'Shaman King S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/180384.mp4', 'http://timg.bdta.pro/images/d3a052baf37b65031cd190678d9f9d81.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(85312, 5904, 'Shaman King S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/180385.mp4', 'http://timg.bdta.pro/images/c62160c1bf71b8161122cfed3657bb64.jpg'),
(85313, 5904, 'Shaman King S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/180386.mp4', 'http://timg.bdta.pro/images/182623f661c73c3d5e97af3c86265f5a.jpg'),
(85314, 5904, 'Shaman King S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/180387.mp4', 'http://timg.bdta.pro/images/2fe3cc10123d7869b5f17955e014fe3b.jpg'),
(85315, 5904, 'Shaman King S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/180388.mp4', 'http://timg.bdta.pro/images/f6b9cb1f3de2c48cdfee4484c3e1c23b.jpg'),
(85316, 5904, 'Shaman King S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/180389.mp4', 'http://timg.bdta.pro/images/8e9f5f0a15f62ef27a26fd99466a5134.jpg'),
(85317, 5904, 'Shaman King S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/180390.mp4', 'http://timg.bdta.pro/images/b02bdf216663fede7fba3ed02befe347.jpg'),
(85318, 5904, 'Shaman King S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/180391.mp4', 'http://timg.bdta.pro/images/4d1ccbadd4d0d2e15770caeb407ae051.jpg'),
(85319, 5904, 'Shaman King S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/180392.mp4', 'http://timg.bdta.pro/images/7f24a0a41f2aee60a26b864ba62c1aa7.jpg'),
(85320, 5904, 'Shaman King S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/180393.mp4', 'http://timg.bdta.pro/images/72020277f4f2ee475233e84274fc1b30.jpg'),
(85321, 5904, 'Shaman King S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/180394.mp4', 'http://timg.bdta.pro/images/0a82bcb0158ed6e427eb060908e4343f.jpg'),
(85322, 5904, 'Shaman King S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/180395.mp4', 'http://timg.bdta.pro/images/322b4eff8b309269eacf27c52c7c26ee.jpg'),
(85323, 5904, 'Shaman King S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/180396.mp4', 'http://timg.bdta.pro/images/e5bad0f347f98ef33a06b6ab547424c2.jpg'),
(85324, 5904, 'Shaman King S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/180397.mp4', 'http://timg.bdta.pro/images/39e127b9874f557f47d34cb83063ee23.jpg'),
(85325, 5904, 'Shaman King S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/180398.mp4', 'http://timg.bdta.pro/images/086817dc780bf958ca81d4768dd13373.jpg'),
(85326, 5904, 'Shaman King S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/180399.mp4', 'http://timg.bdta.pro/images/5284e2db08d13c410a881d757223b2bb.jpg'),
(85327, 5904, 'Shaman King S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/180400.mp4', 'http://timg.bdta.pro/images/60a52134bb28ce4f2de28308ba4dcc7a.jpg'),
(85328, 5904, 'Shaman King S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/180401.mp4', 'http://timg.bdta.pro/images/db81b87527a04bc1302e36c40c6e5083.jpg'),
(85329, 5905, 'Star Trek: Strange New Worlds S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230518.mp4', 'http://timg.bdta.pro/images/5f5184c15726c1b4030f19fb9d1204dd.jpg'),
(85330, 5905, 'Star Trek: Strange New Worlds S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230519.mp4', 'http://timg.bdta.pro/images/e683f9738f92fdb1b46719cb5e4c76c7.jpg'),
(85331, 5905, 'Star Trek: Strange New Worlds S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230520.mp4', 'http://timg.bdta.pro/images/94b5b312e6b00e532f8fb035ddf6897f.jpg'),
(85332, 5905, 'Star Trek: Strange New Worlds S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230521.mp4', 'http://timg.bdta.pro/images/8a2233156baab49fba1116844485c871.jpg'),
(85333, 5905, 'Star Trek: Strange New Worlds S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230522.mp4', 'http://timg.bdta.pro/images/b51069d5d2354164d4c3eb31f7059ed6.jpg'),
(85334, 5905, 'Star Trek: Strange New Worlds S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230523.mp4', 'http://timg.bdta.pro/images/2fa935fcc1b498ab802e58c7fa6bd939.jpg'),
(85335, 5905, 'Star Trek: Strange New Worlds S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230524.mp4', 'http://timg.bdta.pro/images/8015d6a84abe3a75ccddf9590fa4f184.jpg'),
(85336, 5905, 'Star Trek: Strange New Worlds S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230525.mp4', 'http://timg.bdta.pro/images/1a331c70ad408623f169b8f0f87fd1ff.jpg'),
(85337, 5905, 'Star Trek: Strange New Worlds S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230526.mp4', 'http://timg.bdta.pro/images/3aa78f353ce2b0ea302bda7d16511644.jpg'),
(85338, 5905, 'Star Trek: Strange New Worlds S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230527.mp4', 'http://timg.bdta.pro/images/1d34527c7779b728b7254575f495979d.jpg'),
(85339, 5906, 'Star Trek: Strange New Worlds S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230528.mp4', 'http://gstaticontent.com/images/7938d527a19cfee6c536616a453ade3b.jpg'),
(85340, 5906, 'Star Trek: Strange New Worlds S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230529.mp4', 'http://image.tmdb.org/t/p/w1280/xmDChudvEB7eq7DlKlljjrqUiFg.jpg'),
(85341, 5906, 'Star Trek: Strange New Worlds S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230530.mp4', 'http://image.tmdb.org/t/p/w1280/f4FRVjwKKwM37g55Y32ule1wvIh.jpg'),
(85342, 5906, 'Star Trek: Strange New Worlds S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230531.mp4', 'http://image.tmdb.org/t/p/w1280/jJi2VGuS0tyXKtuqgCjsNIOztUY.jpg'),
(85343, 5906, 'Star Trek: Strange New Worlds S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230532.mp4', 'http://image.tmdb.org/t/p/w1280/epj3AGjYIvkpC3DYunSHOGlxqjt.jpg'),
(85344, 5906, 'Star Trek: Strange New Worlds S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230533.mp4', 'http://image.tmdb.org/t/p/w1280/wvAbW0YLMeOHjUIdd7N8euPBc4f.jpg'),
(85345, 5906, 'Star Trek: Strange New Worlds S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230534.mp4', 'http://image.tmdb.org/t/p/w1280/cUXmAvXYhi7zBIzoFgIzbxmf6QI.jpg'),
(85346, 5906, 'Star Trek: Strange New Worlds S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230535.mp4', 'http://image.tmdb.org/t/p/w1280/6UHcQZJjC5StPGkzq6sZAsBLGqx.jpg'),
(85347, 5906, 'Star Trek: Strange New Worlds S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230536.mp4', 'http://image.tmdb.org/t/p/w1280/silXyPIJc5DeTLDEAdgfhHAjAOS.jpg'),
(85348, 5906, 'Star Trek: Strange New Worlds S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230537.mp4', 'http://image.tmdb.org/t/p/w1280/rwqAAZjadCcmzfpLFvScBmzl274.jpg'),
(85349, 5907, 'Star Trek: Strange New Worlds S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/869626.mp4', 'http://gstaticontent.com/images/7938d527a19cfee6c536616a453ade3b.jpg'),
(85350, 5907, 'Star Trek: Strange New Worlds S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/869627.mp4', 'http://gstaticontent.com/images/7938d527a19cfee6c536616a453ade3b.jpg'),
(85351, 5907, 'Star Trek: Strange New Worlds S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/873396.mp4', 'http://gstaticontent.com/images/7938d527a19cfee6c536616a453ade3b.jpg'),
(85352, 5907, 'Star Trek: Strange New Worlds S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/879403.mp4', 'http://gstaticontent.com/images/7938d527a19cfee6c536616a453ade3b.jpg'),
(85353, 5907, 'Star Trek: Strange New Worlds S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/879880.mp4', 'http://gstaticontent.com/images/7938d527a19cfee6c536616a453ade3b.jpg'),
(85354, 5907, 'Star Trek: Strange New Worlds S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/880566.mp4', 'http://gstaticontent.com/images/7938d527a19cfee6c536616a453ade3b.jpg'),
(85355, 5907, 'Star Trek: Strange New Worlds S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/881158.mp4', 'http://gstaticontent.com/images/7938d527a19cfee6c536616a453ade3b.jpg'),
(85356, 5907, 'Star Trek: Strange New Worlds S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/881274.mp4', 'http://gstaticontent.com/images/7938d527a19cfee6c536616a453ade3b.jpg'),
(85357, 5907, 'Star Trek: Strange New Worlds S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/883021.mp4', 'http://gstaticontent.com/images/7938d527a19cfee6c536616a453ade3b.jpg'),
(85358, 5907, 'Star Trek: Strange New Worlds S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/883777.mp4', 'http://gstaticontent.com/images/7938d527a19cfee6c536616a453ade3b.jpg'),
(85359, 5908, 'The Man Who Fell to Earth S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183317.mp4', 'http://timg.bdta.pro/images/5ad0c35a3b83807e76a0f0f19087b991.jpg'),
(85360, 5908, 'The Man Who Fell to Earth S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183318.mp4', 'http://timg.bdta.pro/images/d6939b735c674b1d3e8bc8fae75da6da.jpg'),
(85361, 5908, 'The Man Who Fell to Earth S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183319.mp4', 'http://timg.bdta.pro/images/5a6134de292f48d8c00057e926f0a926.jpg'),
(85362, 5908, 'The Man Who Fell to Earth S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183320.mp4', 'http://timg.bdta.pro/images/7fd7dc18bd0989056a5de3348710f227.jpg'),
(85363, 5908, 'The Man Who Fell to Earth S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183321.mp4', 'http://timg.bdta.pro/images/ca87100d7a198862b59c8557a6ff6b35.jpg'),
(85364, 5908, 'The Man Who Fell to Earth S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183322.mp4', 'http://timg.bdta.pro/images/68d1ed8869531ec5b2b25a535e705219.jpg'),
(85365, 5908, 'The Man Who Fell to Earth S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183323.mp4', 'http://timg.bdta.pro/images/a9fb2e7c0cb20402cdc1c0de159ed55e.jpg'),
(85366, 5908, 'The Man Who Fell to Earth S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183324.mp4', 'http://timg.bdta.pro/images/88025af178192d92256b1e1bfb1c57ff.jpg'),
(85367, 5908, 'The Man Who Fell to Earth S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183325.mp4', 'http://timg.bdta.pro/images/b761f2cfb37da53668ffd14c6107bf83.jpg'),
(85368, 5908, 'The Man Who Fell to Earth S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183326.mp4', 'http://timg.bdta.pro/images/c8a19a492af9859a978a064f6618e81d.jpg'),
(85369, 5909, 'Three Busy Debras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180334.mp4', 'http://timg.bdta.pro/images/d251ea87938a57610680229d103b97b2.jpg'),
(85370, 5909, 'Three Busy Debras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180335.mp4', 'http://timg.bdta.pro/images/11308533987c1da31e424c7344b9d57b.jpg'),
(85371, 5909, 'Three Busy Debras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180336.mp4', 'http://timg.bdta.pro/images/27ae8b221ca781bfe2c99bc2a80824cb.jpg'),
(85372, 5909, 'Three Busy Debras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180337.mp4', 'http://timg.bdta.pro/images/112104efb7b4d4cb0046cd62b4334575.jpg'),
(85373, 5909, 'Three Busy Debras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180338.mp4', 'http://timg.bdta.pro/images/2e300e2a3ea60481722a624e39aec728.jpg'),
(85374, 5909, 'Three Busy Debras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180339.mp4', 'http://timg.bdta.pro/images/ddbad9cc7b20101cc64cb8cb60b75719.jpg'),
(85375, 5910, 'Three Busy Debras S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180340.mp4', 'http://timg.bdta.pro/images/be81ea9ed9e9c07a92275c56adfa94af.jpg'),
(85376, 5910, 'Three Busy Debras S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180341.mp4', 'http://timg.bdta.pro/images/9c8f6b90b68bad9d6fe272cc1d8bafda.jpg'),
(85377, 5910, 'Three Busy Debras S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180342.mp4', 'http://timg.bdta.pro/images/4fad4eebe051f3a028761512d34145f6.jpg'),
(85378, 5910, 'Three Busy Debras S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180343.mp4', 'http://timg.bdta.pro/images/622463440a7b3b680292481a4fa72ff0.jpg'),
(85379, 5910, 'Three Busy Debras S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180344.mp4', 'http://timg.bdta.pro/images/cf2d0726ddf89eda3d3ed1232ae97076.jpg'),
(85380, 5910, 'Three Busy Debras S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180345.mp4', 'http://timg.bdta.pro/images/fbe3191b52a0e4209f51ece43feb1625.jpg'),
(85381, 5910, 'Three Busy Debras S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180346.mp4', 'http://timg.bdta.pro/images/71d6488ff792bc974231b351ef42ab8c.jpg'),
(85382, 5910, 'Three Busy Debras S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180347.mp4', 'http://timg.bdta.pro/images/28acb6a78e31e1ecade49c7f2d4e005e.jpg'),
(85383, 5910, 'Three Busy Debras S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180348.mp4', 'http://timg.bdta.pro/images/ffa0d863d71068038cf35a35c4a05d36.jpg'),
(85384, 5910, 'Three Busy Debras S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180349.mp4', 'http://timg.bdta.pro/images/96415eb67241ec3663c214ca0246dedd.jpg'),
(85385, 5911, 'Túnel do Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217355.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85386, 5911, 'Túnel do Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217356.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85387, 5911, 'Túnel do Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217357.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85388, 5911, 'Túnel do Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217358.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85389, 5911, 'Túnel do Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217359.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85390, 5911, 'Túnel do Amor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217360.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85391, 5911, 'Túnel do Amor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217361.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85392, 5911, 'Túnel do Amor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217362.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85393, 5911, 'Túnel do Amor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217363.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85394, 5911, 'Túnel do Amor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217364.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85395, 5911, 'Túnel do Amor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217365.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85396, 5911, 'Túnel do Amor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217366.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85397, 5911, 'Túnel do Amor S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217367.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85398, 5911, 'Túnel do Amor S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/217368.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85399, 5911, 'Túnel do Amor S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/217369.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85400, 5911, 'Túnel do Amor S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/217370.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85401, 5911, 'Túnel do Amor S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/217371.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85402, 5911, 'Túnel do Amor S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/217372.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85403, 5912, 'Túnel do Amor S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qsHZNueAMygH0wqYxE4LD4I4hlv.jpg'),
(85404, 5912, 'Túnel do Amor S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p43UA2i8SUs1QY025Vssw4EJfbd.jpg'),
(85405, 5912, 'Túnel do Amor S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217375.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85406, 5912, 'Túnel do Amor S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uHonrQN4cDXCdKL0k6bAvpvkIf4.jpg'),
(85407, 5912, 'Túnel do Amor S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWt0jS0czQ9t4QNitOcZKfbcAAj.jpg'),
(85408, 5912, 'Túnel do Amor S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217378.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85409, 5912, 'Túnel do Amor S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217379.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85410, 5912, 'Túnel do Amor S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217380.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85411, 5912, 'Túnel do Amor S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217381.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85412, 5912, 'Túnel do Amor S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217382.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85413, 5912, 'Túnel do Amor S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217383.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85414, 5912, 'Túnel do Amor S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217384.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85415, 5912, 'Túnel do Amor S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217385.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85416, 5912, 'Túnel do Amor S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/217386.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85417, 5912, 'Túnel do Amor S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/217387.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85418, 5912, 'Túnel do Amor S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/217388.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85419, 5912, 'Túnel do Amor S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/217389.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85420, 5912, 'Túnel do Amor S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/217390.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85421, 5912, 'Túnel do Amor S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/217391.mp4', 'http://image.tmdb.org/t/p/w1280/ghdI63gcRTMso1Yjgcyl3GDABnP.jpg'),
(85422, 5912, 'Túnel do Amor S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/217392.mp4', 'http://image.tmdb.org/t/p/w1280/yXRT24glCfpzNuaHmO2sV4jmR8r.jpg'),
(85423, 5913, 'Túnel do Amor S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/335660.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85424, 5913, 'Túnel do Amor S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/335661.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85425, 5913, 'Túnel do Amor S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/335662.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85426, 5913, 'Túnel do Amor S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/335663.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85427, 5913, 'Túnel do Amor S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/335664.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85428, 5913, 'Túnel do Amor S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/339845.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85429, 5913, 'Túnel do Amor S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/339846.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85430, 5913, 'Túnel do Amor S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/339847.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85431, 5913, 'Túnel do Amor S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/339848.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85432, 5913, 'Túnel do Amor S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/339849.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85433, 5913, 'Túnel do Amor S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/350978.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85434, 5913, 'Túnel do Amor S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/350979.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85435, 5913, 'Túnel do Amor S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/350980.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85436, 5913, 'Túnel do Amor S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/350981.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85437, 5913, 'Túnel do Amor S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/350982.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85438, 5913, 'Túnel do Amor S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/350983.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85439, 5913, 'Túnel do Amor S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/350984.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85440, 5913, 'Túnel do Amor S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/350985.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85441, 5913, 'Túnel do Amor S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/350986.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85442, 5913, 'Túnel do Amor S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/350987.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85443, 5914, 'Túnel do Amor S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/893051.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85444, 5914, 'Túnel do Amor S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/893052.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85445, 5914, 'Túnel do Amor S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/893053.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85446, 5914, 'Túnel do Amor S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/893054.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85447, 5914, 'Túnel do Amor S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/893055.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85448, 5914, 'Túnel do Amor S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/893441.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85449, 5914, 'Túnel do Amor S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/893442.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85450, 5914, 'Túnel do Amor S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/893443.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85451, 5914, 'Túnel do Amor S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/893444.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85452, 5914, 'Túnel do Amor S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/893445.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85453, 5914, 'Túnel do Amor S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/894186.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85454, 5914, 'Túnel do Amor S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/894187.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85455, 5914, 'Túnel do Amor S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/894188.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85456, 5914, 'Túnel do Amor S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/894189.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85457, 5914, 'Túnel do Amor S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/894190.mp4', 'http://gstaticontent.com/images/5dda3f140f4183093799a9f70004c93d.jpg'),
(85458, 5915, 'Turbulências de Verão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236614.mp4', 'http://timg.bdta.pro/images/63c29fef1c36c361aa2a0123f6c764bb.jpg'),
(85459, 5915, 'Turbulências de Verão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236615.mp4', 'http://timg.bdta.pro/images/6450088f10e3f6e39ab8f52dc7aa48ce.jpg'),
(85460, 5915, 'Turbulências de Verão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236616.mp4', 'http://timg.bdta.pro/images/9232ae2ac9c04cf13d1366f87ccb2915.jpg'),
(85461, 5915, 'Turbulências de Verão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236617.mp4', 'http://timg.bdta.pro/images/0982596247fd36ceab7839e836adee98.jpg'),
(85462, 5915, 'Turbulências de Verão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236618.mp4', 'http://timg.bdta.pro/images/f8e72a79db292d3759d4057e42b2df0e.jpg'),
(85463, 5915, 'Turbulências de Verão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236619.mp4', 'http://timg.bdta.pro/images/eef40c0ec2e9bc7471e815f7a3b18a15.jpg'),
(85464, 5915, 'Turbulências de Verão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236620.mp4', 'http://timg.bdta.pro/images/350f52c1b6e3a5ff65929efdbd6fb75f.jpg'),
(85465, 5915, 'Turbulências de Verão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236621.mp4', 'http://timg.bdta.pro/images/f17f67efa74061b5cc94a2cee4e8b07a.jpg'),
(85466, 5915, 'Turbulências de Verão S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236622.mp4', 'http://timg.bdta.pro/images/d065d718c3d3c6c593530681869befd9.jpg'),
(85467, 5915, 'Turbulências de Verão S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236623.mp4', 'http://timg.bdta.pro/images/55e50375ef57b6abd2e5fbe662f1f6ca.jpg'),
(85468, 5916, 'Turbulências de Verão S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236624.mp4', 'http://gstaticontent.com/images/bcae4565d458bfd9cf9d9d580158ba1d.jpg'),
(85469, 5916, 'Turbulências de Verão S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236625.mp4', 'http://gstaticontent.com/images/bcae4565d458bfd9cf9d9d580158ba1d.jpg'),
(85470, 5916, 'Turbulências de Verão S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236626.mp4', 'http://gstaticontent.com/images/bcae4565d458bfd9cf9d9d580158ba1d.jpg'),
(85471, 5916, 'Turbulências de Verão S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236627.mp4', 'http://gstaticontent.com/images/bcae4565d458bfd9cf9d9d580158ba1d.jpg'),
(85472, 5916, 'Turbulências de Verão S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236628.mp4', 'http://gstaticontent.com/images/bcae4565d458bfd9cf9d9d580158ba1d.jpg'),
(85473, 5916, 'Turbulências de Verão S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236629.mp4', 'http://gstaticontent.com/images/bcae4565d458bfd9cf9d9d580158ba1d.jpg'),
(85474, 5916, 'Turbulências de Verão S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236630.mp4', 'http://gstaticontent.com/images/bcae4565d458bfd9cf9d9d580158ba1d.jpg'),
(85475, 5916, 'Turbulências de Verão S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236631.mp4', 'http://gstaticontent.com/images/bcae4565d458bfd9cf9d9d580158ba1d.jpg'),
(85476, 5917, 'Tyler Perry\'s Assisted Living S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180309.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85477, 5917, 'Tyler Perry\'s Assisted Living S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180310.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85478, 5917, 'Tyler Perry\'s Assisted Living S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180311.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85479, 5917, 'Tyler Perry\'s Assisted Living S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180312.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85480, 5917, 'Tyler Perry\'s Assisted Living S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/180313.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85481, 5917, 'Tyler Perry\'s Assisted Living S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/180314.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85482, 5917, 'Tyler Perry\'s Assisted Living S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/180315.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85483, 5917, 'Tyler Perry\'s Assisted Living S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/180316.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85484, 5917, 'Tyler Perry\'s Assisted Living S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/180317.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85485, 5917, 'Tyler Perry\'s Assisted Living S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/180318.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85486, 5917, 'Tyler Perry\'s Assisted Living S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/180319.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85487, 5917, 'Tyler Perry\'s Assisted Living S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/180320.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85488, 5917, 'Tyler Perry\'s Assisted Living S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/180321.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85489, 5917, 'Tyler Perry\'s Assisted Living S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/180322.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85490, 5917, 'Tyler Perry\'s Assisted Living S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/180323.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85491, 5917, 'Tyler Perry\'s Assisted Living S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/180324.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85492, 5917, 'Tyler Perry\'s Assisted Living S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/180325.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85493, 5917, 'Tyler Perry\'s Assisted Living S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/180326.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85494, 5917, 'Tyler Perry\'s Assisted Living S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/180327.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85495, 5917, 'Tyler Perry\'s Assisted Living S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/180328.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85496, 5917, 'Tyler Perry\'s Assisted Living S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/180329.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85497, 5917, 'Tyler Perry\'s Assisted Living S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/180330.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85498, 5917, 'Tyler Perry\'s Assisted Living S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/180331.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85499, 5917, 'Tyler Perry\'s Assisted Living S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/180332.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85500, 5917, 'Tyler Perry\'s Assisted Living S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/180333.mp4', 'http://gstaticontent.com/images/734f53f5ffe0ed56d23bd63fdcb3ad3a.jpg'),
(85501, 5918, 'Uma Mãe Perfeita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/180305.mp4', 'http://timg.bdta.pro/images/9e64207f7626fa5c97fc9efa8b7ddce0.jpg'),
(85502, 5918, 'Uma Mãe Perfeita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/180306.mp4', 'http://timg.bdta.pro/images/df2658319af7ef4b1f330c628e1d7e32.jpg'),
(85503, 5918, 'Uma Mãe Perfeita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/180307.mp4', 'http://timg.bdta.pro/images/5d5a01d9f86fdc01f3a5a2574b9b88e0.jpg'),
(85504, 5918, 'Uma Mãe Perfeita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/180308.mp4', 'http://timg.bdta.pro/images/ada61a9d429e700ccd15e32349bec586.jpg'),
(85505, 5919, 'All American: Novos Começos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213258.mp4', 'http://timg.bdta.pro/images/b4fd9d671eebc42d6eb5e81cfc150fdd.jpg'),
(85506, 5919, 'All American: Novos Começos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213259.mp4', 'http://timg.bdta.pro/images/175c0784bf173d5bd705625b7d6d9119.jpg'),
(85507, 5919, 'All American: Novos Começos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213260.mp4', 'http://timg.bdta.pro/images/b6335028972a11d3563f56bab3df8dd1.jpg'),
(85508, 5919, 'All American: Novos Começos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213261.mp4', 'http://timg.bdta.pro/images/e663a83b5acff8c33d6ce668ef1472e1.jpg'),
(85509, 5919, 'All American: Novos Começos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213262.mp4', 'http://timg.bdta.pro/images/6664850cc74b7aefa6958312f79bd063.jpg'),
(85510, 5919, 'All American: Novos Começos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213263.mp4', 'http://timg.bdta.pro/images/4f97031b3133ddb34db64767cb825b95.jpg'),
(85511, 5919, 'All American: Novos Começos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213264.mp4', 'http://timg.bdta.pro/images/62159adf698ac9ba68b2c88fe71c653e.jpg'),
(85512, 5919, 'All American: Novos Começos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213265.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85513, 5919, 'All American: Novos Começos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213266.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85514, 5919, 'All American: Novos Começos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213267.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85515, 5919, 'All American: Novos Começos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/213268.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85516, 5919, 'All American: Novos Começos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/213269.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85517, 5919, 'All American: Novos Começos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/213270.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85518, 5920, 'All American: Novos Começos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k71tKiO23BTHhVO0ySwFNuBq7b7.jpg'),
(85519, 5920, 'All American: Novos Começos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cCXg982VbBTk7yFN6rbGHYL7TjI.jpg'),
(85520, 5920, 'All American: Novos Começos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213273.mp4', 'http://image.tmdb.org/t/p/w1280/ffM6e1deaxlGbqmeDqZGkBzBB7s.jpg'),
(85521, 5920, 'All American: Novos Começos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213274.mp4', 'http://image.tmdb.org/t/p/w1280/tC4nMkBOx3uyCK6GMO1DKKIFozF.jpg'),
(85522, 5920, 'All American: Novos Começos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213275.mp4', 'http://image.tmdb.org/t/p/w1280/r23B07ZXEiJDkgEY5EprobITyjZ.jpg'),
(85523, 5920, 'All American: Novos Começos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213276.mp4', 'http://image.tmdb.org/t/p/w1280/eTLbHeC1QSBJRBCZx6cgs4xHS5z.jpg'),
(85524, 5920, 'All American: Novos Começos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213277.mp4', 'http://image.tmdb.org/t/p/w1280/5txH2dP6vYukyZKINYFizndt1ef.jpg'),
(85525, 5920, 'All American: Novos Começos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213278.mp4', 'http://image.tmdb.org/t/p/w1280/wR8sKndfNieaTlH70GLbJJpZYQ1.jpg'),
(85526, 5920, 'All American: Novos Começos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213279.mp4', 'http://image.tmdb.org/t/p/w1280/p3xq1EjNftyXR9uoSSe2Bg5VDf0.jpg'),
(85527, 5920, 'All American: Novos Começos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213280.mp4', 'http://image.tmdb.org/t/p/w1280/AdvcutrpORzIoYtn4k7fOtuvoIN.jpg'),
(85528, 5920, 'All American: Novos Começos S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/213281.mp4', 'http://image.tmdb.org/t/p/w1280/i04JU0MYCdJQqOdGdz1GKLnPKvQ.jpg'),
(85529, 5920, 'All American: Novos Começos S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/213282.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85530, 5920, 'All American: Novos Começos S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/213283.mp4', 'http://image.tmdb.org/t/p/w1280/1TQd7tNpoIhowFT8sjbaiovIGdW.jpg'),
(85531, 5920, 'All American: Novos Começos S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/213284.mp4', 'http://image.tmdb.org/t/p/w1280/uTLcVunKvaX7W8zOvV3yna4JxKu.jpg'),
(85532, 5920, 'All American: Novos Começos S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/213285.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85533, 5921, 'All American: Novos Começos S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/415101.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85534, 5921, 'All American: Novos Começos S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/415102.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85535, 5921, 'All American: Novos Começos S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425577.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85536, 5921, 'All American: Novos Começos S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/430005.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85537, 5921, 'All American: Novos Começos S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/430006.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85538, 5921, 'All American: Novos Começos S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/437675.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85539, 5921, 'All American: Novos Começos S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/442993.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85540, 5921, 'All American: Novos Começos S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/448869.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85541, 5921, 'All American: Novos Começos S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/452981.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85542, 5921, 'All American: Novos Começos S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462087.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85543, 5921, 'All American: Novos Começos S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/479135.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85544, 5921, 'All American: Novos Começos S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/479136.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85545, 5921, 'All American: Novos Começos S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/479137.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85546, 5921, 'All American: Novos Começos S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/761839.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85547, 5921, 'All American: Novos Começos S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/761840.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85548, 5921, 'All American: Novos Começos S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/761841.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85549, 5921, 'All American: Novos Começos S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/761842.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85550, 5921, 'All American: Novos Começos S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/761843.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85551, 5921, 'All American: Novos Começos S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/761844.mp4', 'http://gstaticontent.com/images/9f62776ccb96e8dde0eaa03a50ac4839.jpg'),
(85552, 5922, 'Cook Island: Ilha do Sabor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179752.mp4', 'http://gstaticontent.com/images/26353cdeec9363daa1e08fa2f194a74a.jpg'),
(85553, 5922, 'Cook Island: Ilha do Sabor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179753.mp4', 'http://gstaticontent.com/images/26353cdeec9363daa1e08fa2f194a74a.jpg'),
(85554, 5922, 'Cook Island: Ilha do Sabor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179754.mp4', 'http://gstaticontent.com/images/26353cdeec9363daa1e08fa2f194a74a.jpg'),
(85555, 5922, 'Cook Island: Ilha do Sabor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179755.mp4', 'http://gstaticontent.com/images/26353cdeec9363daa1e08fa2f194a74a.jpg'),
(85556, 5922, 'Cook Island: Ilha do Sabor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179756.mp4', 'http://gstaticontent.com/images/26353cdeec9363daa1e08fa2f194a74a.jpg'),
(85557, 5922, 'Cook Island: Ilha do Sabor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179757.mp4', 'http://gstaticontent.com/images/26353cdeec9363daa1e08fa2f194a74a.jpg'),
(85558, 5922, 'Cook Island: Ilha do Sabor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179758.mp4', 'http://gstaticontent.com/images/26353cdeec9363daa1e08fa2f194a74a.jpg'),
(85559, 5922, 'Cook Island: Ilha do Sabor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179759.mp4', 'http://gstaticontent.com/images/26353cdeec9363daa1e08fa2f194a74a.jpg'),
(85560, 5922, 'Cook Island: Ilha do Sabor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179760.mp4', 'http://gstaticontent.com/images/26353cdeec9363daa1e08fa2f194a74a.jpg'),
(85561, 5922, 'Cook Island: Ilha do Sabor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179761.mp4', 'http://gstaticontent.com/images/26353cdeec9363daa1e08fa2f194a74a.jpg'),
(85562, 5923, 'Desventuras em Série S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179727.mp4', 'http://timg.bdta.pro/images/6412c176ce69f795ce2f063ed3acf173.jpg'),
(85563, 5923, 'Desventuras em Série S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179728.mp4', 'http://timg.bdta.pro/images/4a33bb3d5d9296003ce33243c841f9fc.jpg'),
(85564, 5923, 'Desventuras em Série S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179729.mp4', 'http://timg.bdta.pro/images/5261a2208d0841b76b3468099cf8431f.jpg'),
(85565, 5923, 'Desventuras em Série S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179730.mp4', 'http://timg.bdta.pro/images/8987ee9294c1854fc6bd6e568154ffaa.jpg'),
(85566, 5923, 'Desventuras em Série S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179731.mp4', 'http://timg.bdta.pro/images/dc5534bca2fe145eca7657b2b9bc706e.jpg'),
(85567, 5923, 'Desventuras em Série S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179732.mp4', 'http://timg.bdta.pro/images/cfb1d2ddc5d28a5ac17d356469c89cf9.jpg'),
(85568, 5923, 'Desventuras em Série S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179733.mp4', 'http://timg.bdta.pro/images/7864efb588c60b918baa92efa0ca05af.jpg'),
(85569, 5923, 'Desventuras em Série S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179734.mp4', 'http://timg.bdta.pro/images/912f4b488c12a3d52cd12dc7ed23cbea.jpg'),
(85570, 5924, 'Desventuras em Série S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179735.mp4', 'http://timg.bdta.pro/images/cb8e1b1c2395e8d3ea4ffeb0c585878e.jpg'),
(85571, 5924, 'Desventuras em Série S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179736.mp4', 'http://timg.bdta.pro/images/c13dfd7ea9bbe6f201176117636fd645.jpg'),
(85572, 5924, 'Desventuras em Série S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179737.mp4', 'http://timg.bdta.pro/images/7c354769e8faf7f2b3d0fb06810dcfaa.jpg'),
(85573, 5924, 'Desventuras em Série S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179738.mp4', 'http://timg.bdta.pro/images/c38ba187294985e7d74510cfad79271f.jpg'),
(85574, 5924, 'Desventuras em Série S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179739.mp4', 'http://timg.bdta.pro/images/966e9d8e3a1437e00767431a2dbaad86.jpg'),
(85575, 5924, 'Desventuras em Série S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179740.mp4', 'http://timg.bdta.pro/images/4cd07d18e98c605e8941a9e19cbed108.jpg'),
(85576, 5924, 'Desventuras em Série S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179741.mp4', 'http://timg.bdta.pro/images/5db2a9e3205f3372acef0a52198f5f30.jpg'),
(85577, 5924, 'Desventuras em Série S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179742.mp4', 'http://timg.bdta.pro/images/9699c3a081adf6f16873bbe4eba68d19.jpg'),
(85578, 5924, 'Desventuras em Série S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179743.mp4', 'http://timg.bdta.pro/images/1f526980c3273ebb6be8dbdba437b13f.jpg'),
(85579, 5924, 'Desventuras em Série S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179744.mp4', 'http://timg.bdta.pro/images/2cb24d9058230b4ff89e4e211dc0347e.jpg'),
(85580, 5925, 'Desventuras em Série S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179745.mp4', 'http://timg.bdta.pro/images/bd5a8b1cf47ca27e9ae98f6900ef498e.jpg'),
(85581, 5925, 'Desventuras em Série S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179746.mp4', 'http://timg.bdta.pro/images/0c0a4143638e32adb6317d736d34756a.jpg'),
(85582, 5925, 'Desventuras em Série S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179747.mp4', 'http://timg.bdta.pro/images/4ef786b09749ee3b723296729806deca.jpg'),
(85583, 5925, 'Desventuras em Série S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179748.mp4', 'http://timg.bdta.pro/images/5bc361ee81884921771f28dcc0478db3.jpg'),
(85584, 5925, 'Desventuras em Série S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179749.mp4', 'http://timg.bdta.pro/images/b50b8edcc74c716358e21becf879e757.jpg'),
(85585, 5925, 'Desventuras em Série S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179750.mp4', 'http://timg.bdta.pro/images/1ffa29a51af2cad5ea0b4155f5084121.jpg'),
(85586, 5925, 'Desventuras em Série S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179751.mp4', 'http://timg.bdta.pro/images/6a76c72b4c4ad496a715ef7372b0d71b.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(85587, 5926, 'Grávida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179721.mp4', 'http://gstaticontent.com/images/300b7ea6a8bf37526f4d4b7b69471ea3.jpg'),
(85588, 5926, 'Grávida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179722.mp4', 'http://gstaticontent.com/images/300b7ea6a8bf37526f4d4b7b69471ea3.jpg'),
(85589, 5926, 'Grávida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179723.mp4', 'http://gstaticontent.com/images/300b7ea6a8bf37526f4d4b7b69471ea3.jpg'),
(85590, 5926, 'Grávida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179724.mp4', 'http://gstaticontent.com/images/300b7ea6a8bf37526f4d4b7b69471ea3.jpg'),
(85591, 5926, 'Grávida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179725.mp4', 'http://gstaticontent.com/images/300b7ea6a8bf37526f4d4b7b69471ea3.jpg'),
(85592, 5926, 'Grávida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179726.mp4', 'http://gstaticontent.com/images/300b7ea6a8bf37526f4d4b7b69471ea3.jpg'),
(85593, 5927, 'Ed Kemper: A Mente de um Monstro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179718.mp4', 'http://gstaticontent.com/images/a4d55219c5460de678f7e6e62c107e59.jpg'),
(85594, 5927, 'Ed Kemper: A Mente de um Monstro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179719.mp4', 'http://gstaticontent.com/images/a4d55219c5460de678f7e6e62c107e59.jpg'),
(85595, 5927, 'Ed Kemper: A Mente de um Monstro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179720.mp4', 'http://gstaticontent.com/images/a4d55219c5460de678f7e6e62c107e59.jpg'),
(85596, 5928, 'Gaslit S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179714.mp4', 'http://timg.bdta.pro/images/a02b90516f654da92ca6bfec9b1fbac2.jpg'),
(85597, 5928, 'Gaslit S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179715.mp4', 'http://timg.bdta.pro/images/f84e0e02a9b53177a9912541d0beda90.jpg'),
(85598, 5928, 'Gaslit S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179716.mp4', 'http://timg.bdta.pro/images/ce0db7cb3edfb24777387721b24c39ae.jpg'),
(85599, 5928, 'Gaslit S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179717.mp4', 'http://timg.bdta.pro/images/e1bd3c429bfdd6a81b4dd9991e25b202.jpg'),
(85600, 5929, 'Gentleman Jack S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179699.mp4', 'http://timg.bdta.pro/images/b946c1642f43ad9f255ca5b40aa70a14.jpg'),
(85601, 5929, 'Gentleman Jack S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179700.mp4', 'http://timg.bdta.pro/images/d17586ce1563a643fdc44ca05f00f27a.jpg'),
(85602, 5929, 'Gentleman Jack S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179701.mp4', 'http://timg.bdta.pro/images/3dee682661a0ed3af44b2c8cb3b96c1c.jpg'),
(85603, 5929, 'Gentleman Jack S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179702.mp4', 'http://timg.bdta.pro/images/9f3bd95c4196ce3403d7ca7415c8ab21.jpg'),
(85604, 5929, 'Gentleman Jack S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179703.mp4', 'http://timg.bdta.pro/images/23886e33db04db00564c4714db6f7c87.jpg'),
(85605, 5929, 'Gentleman Jack S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179704.mp4', 'http://timg.bdta.pro/images/99921714e841a4eb04c37407c3e251ac.jpg'),
(85606, 5929, 'Gentleman Jack S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179705.mp4', 'http://timg.bdta.pro/images/b169a35eadff61f162d4669c71241b20.jpg'),
(85607, 5929, 'Gentleman Jack S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179706.mp4', 'http://timg.bdta.pro/images/3fa5d46acca1a30c173f8ff781d36632.jpg'),
(85608, 5930, 'Gentleman Jack S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179707.mp4', 'http://timg.bdta.pro/images/0b180ad5c85415bba40a604099b34902.jpg'),
(85609, 5930, 'Gentleman Jack S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179708.mp4', 'http://timg.bdta.pro/images/27130e97d40048828fac474f808326e5.jpg'),
(85610, 5930, 'Gentleman Jack S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179709.mp4', 'http://timg.bdta.pro/images/a9b90babec6b545a8bb3016ef38cddbe.jpg'),
(85611, 5930, 'Gentleman Jack S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179710.mp4', 'http://timg.bdta.pro/images/9f47cca434e294f1ba49889385622c21.jpg'),
(85612, 5930, 'Gentleman Jack S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179711.mp4', 'http://timg.bdta.pro/images/81344aefb93b8a970af749028dde82c7.jpg'),
(85613, 5930, 'Gentleman Jack S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179712.mp4', 'http://timg.bdta.pro/images/6b0a52a6533105c4d0ed04018bc28a6e.jpg'),
(85614, 5930, 'Gentleman Jack S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179713.mp4', 'http://timg.bdta.pro/images/4963d954ada4024749ec0a9de5eb0f91.jpg'),
(85615, 5931, 'Intimidade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179691.mp4', 'http://timg.bdta.pro/images/c12b955aa692ac9a9cf6806b605736be.jpg'),
(85616, 5931, 'Intimidade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179692.mp4', 'http://timg.bdta.pro/images/d79be1f6c54e5aec32a42597627877cb.jpg'),
(85617, 5931, 'Intimidade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179693.mp4', 'http://timg.bdta.pro/images/98b579e15bf0b2b8ddd8084a61140afc.jpg'),
(85618, 5931, 'Intimidade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179694.mp4', 'http://timg.bdta.pro/images/80f4dfa6956319b2d11b3ac838edccad.jpg'),
(85619, 5931, 'Intimidade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179695.mp4', 'http://timg.bdta.pro/images/f823af5ad5d942047cd2ddcb058af58e.jpg'),
(85620, 5931, 'Intimidade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179696.mp4', 'http://timg.bdta.pro/images/3534f935b53f091a5a44bae552db5d4e.jpg'),
(85621, 5931, 'Intimidade S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179697.mp4', 'http://timg.bdta.pro/images/88fa20affb519a87f23f6173c45f237c.jpg'),
(85622, 5931, 'Intimidade S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179698.mp4', 'http://timg.bdta.pro/images/7dbbec1cfe04aa9375b13e1bb12966ff.jpg'),
(85623, 5932, 'Irma Vep S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191083.mp4', 'http://timg.bdta.pro/images/37e806e0d0c4a86eb90f2f1046ae44f6.jpg'),
(85624, 5932, 'Irma Vep S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191084.mp4', 'http://timg.bdta.pro/images/b848435e96d30c18d5a081b7423107b7.jpg'),
(85625, 5932, 'Irma Vep S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191085.mp4', 'http://timg.bdta.pro/images/a5fcc5114170cea193d17f5c6c9f24cf.jpg'),
(85626, 5932, 'Irma Vep S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191086.mp4', 'http://timg.bdta.pro/images/bf9c147f32cd606a2c9129fb193bde06.jpg'),
(85627, 5932, 'Irma Vep S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191087.mp4', 'http://timg.bdta.pro/images/5ca4fefe4c38a439390b031b6e2a1ee5.jpg'),
(85628, 5932, 'Irma Vep S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191088.mp4', 'http://timg.bdta.pro/images/38e352fe2945c2a1c63d5dd83f2bfe02.jpg'),
(85629, 5932, 'Irma Vep S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191089.mp4', 'http://timg.bdta.pro/images/7d5195903c8d11c206f98877e679c3c0.jpg'),
(85630, 5932, 'Irma Vep S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191090.mp4', 'http://timg.bdta.pro/images/c3f169054906816f9ef51decd608fc99.jpg'),
(85631, 5933, 'Lovely Little Farm S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179676.mp4', 'http://timg.bdta.pro/images/cd78e06ed9e5b2076ee3b6dd452df256.jpg'),
(85632, 5933, 'Lovely Little Farm S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179677.mp4', 'http://timg.bdta.pro/images/744547cd1ec9d782dcc39763d35a91c8.jpg'),
(85633, 5933, 'Lovely Little Farm S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179678.mp4', 'http://timg.bdta.pro/images/94668a900864336466ddde7d8f9c6327.jpg'),
(85634, 5933, 'Lovely Little Farm S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179679.mp4', 'http://timg.bdta.pro/images/8c4acb7ef4735ce50e521eaed98c0180.jpg'),
(85635, 5933, 'Lovely Little Farm S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179680.mp4', 'http://timg.bdta.pro/images/b18ac6d9c28c649d0e93260cfd96480e.jpg'),
(85636, 5933, 'Lovely Little Farm S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179681.mp4', 'http://timg.bdta.pro/images/f9e0d8bf0bcf79eac154bc1ddb028bd3.jpg'),
(85637, 5933, 'Lovely Little Farm S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179682.mp4', 'http://timg.bdta.pro/images/874b8f04d7ec8ca2e1262eb7ae5c063c.jpg'),
(85638, 5934, 'Manayek S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204229.mp4', 'http://timg.bdta.pro/images/b2072a28a8d928674d5ebdf406ba60f7.jpg'),
(85639, 5934, 'Manayek S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204230.mp4', 'http://timg.bdta.pro/images/c43e80c5f79e4ec98b4b6dbcf42eba2c.jpg'),
(85640, 5934, 'Manayek S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204231.mp4', 'http://timg.bdta.pro/images/9f786598e4fdf49c43b4b344969e8c0b.jpg'),
(85641, 5934, 'Manayek S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204232.mp4', 'http://timg.bdta.pro/images/cffb4e92befb27c219d9c649a2aeec52.jpg'),
(85642, 5934, 'Manayek S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204233.mp4', 'http://timg.bdta.pro/images/be849b707495ea5ba5960d4ea32efcb6.jpg'),
(85643, 5934, 'Manayek S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204234.mp4', 'http://timg.bdta.pro/images/8bef18e67f3654063c6385a3b68d9d12.jpg'),
(85644, 5934, 'Manayek S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204235.mp4', 'http://timg.bdta.pro/images/a645a9de28600e375a26280c2d56cc58.jpg'),
(85645, 5934, 'Manayek S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204236.mp4', 'http://timg.bdta.pro/images/ca6332afe623880e675ff58bc54e5073.jpg'),
(85646, 5934, 'Manayek S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204237.mp4', 'http://timg.bdta.pro/images/9da95a9dc74d36f87eef971d38309d08.jpg'),
(85647, 5934, 'Manayek S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204238.mp4', 'http://timg.bdta.pro/images/6c24fc6ccea9a193f10683b1cf0043b6.jpg'),
(85648, 5935, 'Manayek S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e9jIphXQ0CBk4TVn92VA0vVBq0n.jpg'),
(85649, 5935, 'Manayek S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eZUUYqPuYTJs124R3AS5gYVAsiB.jpg'),
(85650, 5935, 'Manayek S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8rtlVyyZBd31mdBsE71LzF7lpin.jpg'),
(85651, 5935, 'Manayek S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dNXqVAby83lKlDRiTKgcT3TAivB.jpg'),
(85652, 5935, 'Manayek S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kaCwB4OQ5LkSJXMyopLIW6BR8zN.jpg'),
(85653, 5935, 'Manayek S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y3wzGTs3JJViIJsv07H73Xe4c8O.jpg'),
(85654, 5935, 'Manayek S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/luwLdLFemtWjzZEIfoqnWUt8eWI.jpg'),
(85655, 5935, 'Manayek S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBuOnM8pXzYScWw5RYJPqs7q886.jpg'),
(85656, 5935, 'Manayek S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fU2XWSG3ieXg2apPtlvmtjIV6hw.jpg'),
(85657, 5935, 'Manayek S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Jh5rnq9Nf27xXaGQFm1ZUUPG0c.jpg'),
(85658, 5936, 'O Bebê S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179668.mp4', 'http://timg.bdta.pro/images/f60fcaf44c55301819f3312981528b66.jpg'),
(85659, 5936, 'O Bebê S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179669.mp4', 'http://timg.bdta.pro/images/1f6de785562943a3b986e555b9a933e9.jpg'),
(85660, 5936, 'O Bebê S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179670.mp4', 'http://timg.bdta.pro/images/dfc2fc5dfecd6c0943a7f1f454406e44.jpg'),
(85661, 5936, 'O Bebê S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179671.mp4', 'http://timg.bdta.pro/images/ddc42e7e76e30dee828c8226da0a5eff.jpg'),
(85662, 5936, 'O Bebê S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179672.mp4', 'http://timg.bdta.pro/images/5658de021d8bb61cbffca7f757c62682.jpg'),
(85663, 5936, 'O Bebê S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179673.mp4', 'http://timg.bdta.pro/images/388f4d5798e859b309d0639d7b804e74.jpg'),
(85664, 5936, 'O Bebê S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179674.mp4', 'http://timg.bdta.pro/images/c6d4939db6ee3a64e241c10be207ecfe.jpg'),
(85665, 5936, 'O Bebê S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179675.mp4', 'http://timg.bdta.pro/images/54622fe41eb54338e20c562743677015.jpg'),
(85666, 5937, 'Ele Não S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179656.mp4', 'http://timg.bdta.pro/images/5fce5a9f251d1b99b584639331ee6a89.jpg'),
(85667, 5937, 'Ele Não S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179657.mp4', 'http://timg.bdta.pro/images/36f84f27b76b70e2305642edbb766035.jpg'),
(85668, 5937, 'Ele Não S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179658.mp4', 'http://timg.bdta.pro/images/2b54f0eca5b1394378206d6d975c30ea.jpg'),
(85669, 5937, 'Ele Não S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179659.mp4', 'http://timg.bdta.pro/images/21c8675a70f80ad274982c1393391c35.jpg'),
(85670, 5937, 'Ele Não S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179660.mp4', 'http://timg.bdta.pro/images/22973a8ec0cdd790c20927dfdf8344e4.jpg'),
(85671, 5937, 'Ele Não S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179661.mp4', 'http://timg.bdta.pro/images/5fc983feb5f5a6c0db75cf0017a58e8a.jpg'),
(85672, 5937, 'Ele Não S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179662.mp4', 'http://timg.bdta.pro/images/9869685b135ebe551eb0b6d22804f1a0.jpg'),
(85673, 5937, 'Ele Não S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179663.mp4', 'http://timg.bdta.pro/images/c0e845c7060efa96c4b194983e139474.jpg'),
(85674, 5937, 'Ele Não S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179664.mp4', 'http://timg.bdta.pro/images/364ebe9203d9076e3bc1980b7a578b7d.jpg'),
(85675, 5937, 'Ele Não S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179665.mp4', 'http://timg.bdta.pro/images/0c91c1e01028529340d68c446f43654f.jpg'),
(85676, 5937, 'Ele Não S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179666.mp4', 'http://timg.bdta.pro/images/3a2a8948bc3143379a382e1201281787.jpg'),
(85677, 5937, 'Ele Não S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179667.mp4', 'http://timg.bdta.pro/images/0b499de647de7bc483928dc90a6025d3.jpg'),
(85678, 5938, 'Pig Royalty S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190637.mp4', 'http://timg.bdta.pro/images/f4df2aae0a0f796e23e579ba984fa7e9.jpg'),
(85679, 5938, 'Pig Royalty S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190638.mp4', 'http://timg.bdta.pro/images/35379344b6da2f5c22b927e555799fe2.jpg'),
(85680, 5938, 'Pig Royalty S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190639.mp4', 'http://timg.bdta.pro/images/a947be8d2190145ad584b8647a75e3bd.jpg'),
(85681, 5938, 'Pig Royalty S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190640.mp4', 'http://timg.bdta.pro/images/c75128b675433eafe5e3a4629417ac1c.jpg'),
(85682, 5938, 'Pig Royalty S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190641.mp4', 'http://timg.bdta.pro/images/c62f280c7b6fd36624c818686fd49734.jpg'),
(85683, 5938, 'Pig Royalty S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190642.mp4', 'http://timg.bdta.pro/images/81f175163b7e0e288ec7c30a70069f22.jpg'),
(85684, 5938, 'Pig Royalty S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190643.mp4', 'http://timg.bdta.pro/images/97cdaf4d9c224e059882c8168de62dc2.jpg'),
(85685, 5938, 'Pig Royalty S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190644.mp4', 'http://timg.bdta.pro/images/3a9e856b89c4e46063f154233091af57.jpg'),
(85686, 5939, 'Primeira Morte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179648.mp4', 'http://timg.bdta.pro/images/d2e409031b20880ff78bd99709ee01cb.jpg'),
(85687, 5939, 'Primeira Morte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179649.mp4', 'http://timg.bdta.pro/images/57a02708daf882a560adb00ae40a497e.jpg'),
(85688, 5939, 'Primeira Morte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179650.mp4', 'http://timg.bdta.pro/images/762299054740095539c7b2ac6b2084ab.jpg'),
(85689, 5939, 'Primeira Morte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179651.mp4', 'http://timg.bdta.pro/images/6471e50203d4037c05f7b3caaf0b810b.jpg'),
(85690, 5939, 'Primeira Morte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179652.mp4', 'http://timg.bdta.pro/images/e9cdcd07144200c60c373db8274c6972.jpg'),
(85691, 5939, 'Primeira Morte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179653.mp4', 'http://timg.bdta.pro/images/5e03dd9f11c3c2c841921386e9963b52.jpg'),
(85692, 5939, 'Primeira Morte S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179654.mp4', 'http://timg.bdta.pro/images/7ca7c929c5b02f644af0ce375a7ab5d5.jpg'),
(85693, 5939, 'Primeira Morte S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179655.mp4', 'http://timg.bdta.pro/images/d36af5ec6f414c8b4864d1730ca2cf10.jpg'),
(85694, 5940, 'Ms. Marvel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191883.mp4', 'http://timg.bdta.pro/images/1a282b2e08fcb2816cd4258447bc8afd.jpg'),
(85695, 5940, 'Ms. Marvel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191884.mp4', 'http://timg.bdta.pro/images/6191477a17e210d9128d7d7820cdeef5.jpg'),
(85696, 5940, 'Ms. Marvel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191885.mp4', 'http://timg.bdta.pro/images/cb6ddc9adf0c1dec48f75b3f3b0f0115.jpg'),
(85697, 5940, 'Ms. Marvel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191886.mp4', 'http://timg.bdta.pro/images/57861139d7777d42198ba6d30d7341b8.jpg'),
(85698, 5940, 'Ms. Marvel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191887.mp4', 'http://timg.bdta.pro/images/4d560cc758f4c391d3cc7bb5c8513444.jpg'),
(85699, 5940, 'Ms. Marvel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191888.mp4', 'http://timg.bdta.pro/images/1332cef611833fa7f98a31eff6aff891.jpg'),
(85700, 5941, 'A Corrida Maluca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179456.mp4', 'http://timg.bdta.pro/images/fd89b6bf38be26759feee99349d9c6c6.jpg'),
(85701, 5941, 'A Corrida Maluca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179457.mp4', 'http://timg.bdta.pro/images/00648bd79c959c17cf9685fd6569c273.jpg'),
(85702, 5941, 'A Corrida Maluca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179458.mp4', 'http://timg.bdta.pro/images/a58d4ee8212d1a9265b50506a3aa23cf.jpg'),
(85703, 5941, 'A Corrida Maluca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179459.mp4', 'http://timg.bdta.pro/images/40cff83e76efa6080399c511d894a0b3.jpg'),
(85704, 5941, 'A Corrida Maluca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179460.mp4', 'http://timg.bdta.pro/images/ee1db427fb9b3720b4ba2b94fc5c6906.jpg'),
(85705, 5941, 'A Corrida Maluca S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179461.mp4', 'http://timg.bdta.pro/images/c4aee30785bb1b7311a96e3e8f37a087.jpg'),
(85706, 5941, 'A Corrida Maluca S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179462.mp4', 'http://timg.bdta.pro/images/9b95bf2270d88c5d1eda49928d65bca7.jpg'),
(85707, 5941, 'A Corrida Maluca S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179463.mp4', 'http://timg.bdta.pro/images/0c5c0c62132706aef6ef6702beece672.jpg'),
(85708, 5941, 'A Corrida Maluca S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179464.mp4', 'http://timg.bdta.pro/images/191dfdf84c5d8c7d8ba2f2af3558f1ec.jpg'),
(85709, 5941, 'A Corrida Maluca S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179465.mp4', 'http://timg.bdta.pro/images/4377cc71e02aa51e54a9193d2768d9ec.jpg'),
(85710, 5941, 'A Corrida Maluca S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179466.mp4', 'http://timg.bdta.pro/images/33ec5b04cd72e80d1fc2de3e21429ba7.jpg'),
(85711, 5941, 'A Corrida Maluca S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179467.mp4', 'http://timg.bdta.pro/images/00092024463a9600c86cc433d073df68.jpg'),
(85712, 5941, 'A Corrida Maluca S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/179468.mp4', 'http://timg.bdta.pro/images/9d669dde7c9da847c41eebcff47f72a4.jpg'),
(85713, 5941, 'A Corrida Maluca S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/179469.mp4', 'http://timg.bdta.pro/images/736907f3da61047f4c971b015cc62adf.jpg'),
(85714, 5941, 'A Corrida Maluca S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/179470.mp4', 'http://timg.bdta.pro/images/1fbb8b6492d7d7d931857ec0ed0a029e.jpg'),
(85715, 5941, 'A Corrida Maluca S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/179471.mp4', 'http://timg.bdta.pro/images/418c0ca4f45dfb1050859eb66887edef.jpg'),
(85716, 5941, 'A Corrida Maluca S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/179472.mp4', 'http://timg.bdta.pro/images/044ace9ea59eb5b8b33055c5c7047d62.jpg'),
(85717, 5941, 'A Corrida Maluca S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/179473.mp4', 'http://timg.bdta.pro/images/a23889f918dab3626bdddd043c255686.jpg'),
(85718, 5941, 'A Corrida Maluca S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/179474.mp4', 'http://timg.bdta.pro/images/c211e86de7cd3c06f4e420417682a003.jpg'),
(85719, 5941, 'A Corrida Maluca S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/179475.mp4', 'http://timg.bdta.pro/images/d83b5703156882d20fd31f3a04682243.jpg'),
(85720, 5941, 'A Corrida Maluca S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/179476.mp4', 'http://timg.bdta.pro/images/979bbfad0fc00fa02d54572abb3ccf13.jpg'),
(85721, 5941, 'A Corrida Maluca S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/179477.mp4', 'http://timg.bdta.pro/images/06089f2e9cb32efc146a691df0d70019.jpg'),
(85722, 5941, 'A Corrida Maluca S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/179478.mp4', 'http://timg.bdta.pro/images/70249b2b516cb2c9a8878b76c8323857.jpg'),
(85723, 5941, 'A Corrida Maluca S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/179479.mp4', 'http://timg.bdta.pro/images/50c4233d254bfb68c49a7d8a11d1a6f2.jpg'),
(85724, 5941, 'A Corrida Maluca S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/179480.mp4', 'http://timg.bdta.pro/images/30bdff605e849db611db9b126eb9a026.jpg'),
(85725, 5941, 'A Corrida Maluca S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/179481.mp4', 'http://timg.bdta.pro/images/26dddb58baf86a29dfb8c3941658e6a0.jpg'),
(85726, 5941, 'A Corrida Maluca S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/179482.mp4', 'http://timg.bdta.pro/images/08d987c809ddb69b23338e2e60eaf97e.jpg'),
(85727, 5941, 'A Corrida Maluca S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/179483.mp4', 'http://timg.bdta.pro/images/0ccaa579f836c47ad95dbbaccb498092.jpg'),
(85728, 5941, 'A Corrida Maluca S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/179484.mp4', 'http://timg.bdta.pro/images/5e95b1c6b1f43bf5ed02327f9f493650.jpg'),
(85729, 5941, 'A Corrida Maluca S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/179485.mp4', 'http://timg.bdta.pro/images/c67e9f29ab3012ddd0dd3ffcd0f20c49.jpg'),
(85730, 5941, 'A Corrida Maluca S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/179486.mp4', 'http://timg.bdta.pro/images/8216dfa8d637853336a1cf305ac11308.jpg'),
(85731, 5941, 'A Corrida Maluca S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/179487.mp4', 'http://timg.bdta.pro/images/11324986ddbb95893cc9d92d2a8cb928.jpg'),
(85732, 5941, 'A Corrida Maluca S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/179488.mp4', 'http://timg.bdta.pro/images/11324986ddbb95893cc9d92d2a8cb928.jpg'),
(85733, 5941, 'A Corrida Maluca S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/179489.mp4', 'http://timg.bdta.pro/images/f47817719a306d4efb738d3cef8ca6b7.jpg'),
(85734, 5941, 'A Corrida Maluca S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/179490.mp4', 'http://timg.bdta.pro/images/a5ff50d2734fe9c26f3c2e49b27e0e92.jpg'),
(85735, 5941, 'A Corrida Maluca S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/179491.mp4', 'http://timg.bdta.pro/images/f770ff695eea2cfd7b6663b99d66371c.jpg'),
(85736, 5941, 'A Corrida Maluca S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/179492.mp4', 'http://timg.bdta.pro/images/b5a0674de4c8bd49d83b5e5dfef6d864.jpg'),
(85737, 5941, 'A Corrida Maluca S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/179493.mp4', 'http://timg.bdta.pro/images/b62e1ba27fd4c78d56b10ecca615ae43.jpg'),
(85738, 5941, 'A Corrida Maluca S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/179494.mp4', 'http://timg.bdta.pro/images/0fe575157818f952a06de6bd6da801bb.jpg'),
(85739, 5941, 'A Corrida Maluca S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/179495.mp4', 'http://timg.bdta.pro/images/b037bee94d791866b140a99f988f2ef0.jpg'),
(85740, 5942, 'A Corrida Maluca S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179496.mp4', 'http://timg.bdta.pro/images/9ebaec18e78c78886bd4569b09b0d667.jpg'),
(85741, 5942, 'A Corrida Maluca S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179497.mp4', 'http://timg.bdta.pro/images/4dadc4feaa702c9798fe94cd9d51771c.jpg'),
(85742, 5942, 'A Corrida Maluca S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179498.mp4', 'http://timg.bdta.pro/images/b20f996b95633332330f5a8d98283a58.jpg'),
(85743, 5942, 'A Corrida Maluca S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179499.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85744, 5942, 'A Corrida Maluca S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179500.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85745, 5942, 'A Corrida Maluca S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179501.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85746, 5942, 'A Corrida Maluca S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179502.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85747, 5942, 'A Corrida Maluca S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179503.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85748, 5942, 'A Corrida Maluca S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179504.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85749, 5942, 'A Corrida Maluca S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179505.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85750, 5942, 'A Corrida Maluca S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/179506.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85751, 5942, 'A Corrida Maluca S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/179507.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85752, 5942, 'A Corrida Maluca S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/179508.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85753, 5942, 'A Corrida Maluca S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/179509.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85754, 5942, 'A Corrida Maluca S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/179510.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85755, 5942, 'A Corrida Maluca S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/179511.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85756, 5942, 'A Corrida Maluca S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/179512.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85757, 5942, 'A Corrida Maluca S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/179513.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85758, 5942, 'A Corrida Maluca S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/179514.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85759, 5942, 'A Corrida Maluca S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/179515.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85760, 5942, 'A Corrida Maluca S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/179516.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85761, 5942, 'A Corrida Maluca S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/179517.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85762, 5942, 'A Corrida Maluca S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/179518.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85763, 5942, 'A Corrida Maluca S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/179519.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85764, 5942, 'A Corrida Maluca S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/179520.mp4', 'http://gstaticontent.com/images/f3d08706857b985a2284039b6d33e7f4.jpg'),
(85765, 5942, 'A Corrida Maluca S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/179521.mp4', 'http://timg.bdta.pro/images/9ebaec18e78c78886bd4569b09b0d667.jpg'),
(85766, 5942, 'A Corrida Maluca S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/179522.mp4', 'http://timg.bdta.pro/images/4dadc4feaa702c9798fe94cd9d51771c.jpg'),
(85767, 5942, 'A Corrida Maluca S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/179523.mp4', 'http://timg.bdta.pro/images/b20f996b95633332330f5a8d98283a58.jpg'),
(85768, 5942, 'A Corrida Maluca S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/179524.mp4', 'http://timg.bdta.pro/images/76a99bd2e90d6c9fcf3829ade4ad281a.jpg'),
(85769, 5942, 'A Corrida Maluca S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/179525.mp4', 'http://timg.bdta.pro/images/f2a3841a610e51a8db612805f44a75fc.jpg'),
(85770, 5942, 'A Corrida Maluca S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/179526.mp4', 'http://timg.bdta.pro/images/12c7ec4a53cb94f4c035b62f6870d011.jpg'),
(85771, 5942, 'A Corrida Maluca S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/179527.mp4', 'http://timg.bdta.pro/images/15405e4b6cd59cb97d0b21fa987e5cb3.jpg'),
(85772, 5942, 'A Corrida Maluca S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/179528.mp4', 'http://timg.bdta.pro/images/bb7019667e3ac46e265c4d5880500c92.jpg'),
(85773, 5942, 'A Corrida Maluca S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/179529.mp4', 'http://timg.bdta.pro/images/12f92fe54b1441bb48037e4c6ea321be.jpg'),
(85774, 5942, 'A Corrida Maluca S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/179530.mp4', 'http://timg.bdta.pro/images/ede0caafb5cfa3f464e8b8bb057ca29f.jpg'),
(85775, 5942, 'A Corrida Maluca S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/179531.mp4', 'http://timg.bdta.pro/images/3ee905c6980523a4684a42a862be2ec0.jpg'),
(85776, 5942, 'A Corrida Maluca S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/179532.mp4', 'http://timg.bdta.pro/images/1c35c5e7db793baae777d9aec31744ae.jpg'),
(85777, 5942, 'A Corrida Maluca S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/179533.mp4', 'http://timg.bdta.pro/images/236076ee22eb98b66711d95c7c441b5c.jpg'),
(85778, 5943, 'Amor e Anarquia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179440.mp4', 'http://timg.bdta.pro/images/70f51093441c44705fbd3c24d99c4e4b.jpg'),
(85779, 5943, 'Amor e Anarquia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179441.mp4', 'http://timg.bdta.pro/images/ccc35848e3134e1bcffc02ab0d6c018a.jpg'),
(85780, 5943, 'Amor e Anarquia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179442.mp4', 'http://timg.bdta.pro/images/a8b73d0b8443d8ebfaafcf726eefa56c.jpg'),
(85781, 5943, 'Amor e Anarquia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179443.mp4', 'http://timg.bdta.pro/images/05bd37d855dedbdb81f5051282b3036f.jpg'),
(85782, 5943, 'Amor e Anarquia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179444.mp4', 'http://timg.bdta.pro/images/e2d858c214250dd6ddd3e0d365958160.jpg'),
(85783, 5943, 'Amor e Anarquia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179445.mp4', 'http://timg.bdta.pro/images/a97ba15a55dcdab0d4ba54555008b68d.jpg'),
(85784, 5943, 'Amor e Anarquia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179446.mp4', 'http://timg.bdta.pro/images/47661e7d74f0e1596d8e2b27f7cd5353.jpg'),
(85785, 5943, 'Amor e Anarquia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179447.mp4', 'http://timg.bdta.pro/images/744efad481ded51acfe484b950cf4c83.jpg'),
(85786, 5944, 'Amor e Anarquia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179448.mp4', 'http://timg.bdta.pro/images/637515c57e4663639564f7c0ab5ca033.jpg'),
(85787, 5944, 'Amor e Anarquia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179449.mp4', 'http://timg.bdta.pro/images/5dc83f616ad9e40a9e523faccd60f2af.jpg'),
(85788, 5944, 'Amor e Anarquia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179450.mp4', 'http://timg.bdta.pro/images/e9d30f4a35263129249a669b40b88f77.jpg'),
(85789, 5944, 'Amor e Anarquia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179451.mp4', 'http://timg.bdta.pro/images/f19d9717e26b1c3f53bdf79d54fba314.jpg'),
(85790, 5944, 'Amor e Anarquia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179452.mp4', 'http://timg.bdta.pro/images/45a542683898c72ed23796716e42d52a.jpg'),
(85791, 5944, 'Amor e Anarquia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179453.mp4', 'http://timg.bdta.pro/images/6a7c1aa70d9ebb0a59916435c0f41e3f.jpg'),
(85792, 5944, 'Amor e Anarquia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179454.mp4', 'http://timg.bdta.pro/images/ce810315c0056f9ad422823bbeaf4c9f.jpg'),
(85793, 5944, 'Amor e Anarquia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179455.mp4', 'http://timg.bdta.pro/images/0a74bea27de91912ccfd692727207980.jpg'),
(85794, 5945, 'Guardiões da Mansão do Terror S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195665.mp4', 'http://timg.bdta.pro/images/c179c7ecf2e0912b23364ddd90a4a2b1.jpg'),
(85795, 5945, 'Guardiões da Mansão do Terror S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195666.mp4', 'http://timg.bdta.pro/images/85e83d24722387ed6f3cade35863a1e6.jpg'),
(85796, 5945, 'Guardiões da Mansão do Terror S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195667.mp4', 'http://timg.bdta.pro/images/9d08d00d9c2c44dcfc6a730e60e99533.jpg'),
(85797, 5945, 'Guardiões da Mansão do Terror S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195668.mp4', 'http://timg.bdta.pro/images/9d08d00d9c2c44dcfc6a730e60e99533.jpg'),
(85798, 5945, 'Guardiões da Mansão do Terror S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195669.mp4', 'http://timg.bdta.pro/images/7577a0b7b5d22886e02c2f5906b90e67.jpg'),
(85799, 5945, 'Guardiões da Mansão do Terror S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195670.mp4', 'http://timg.bdta.pro/images/7fe8fdd026057a3a146bc5a21ba65f63.jpg'),
(85800, 5945, 'Guardiões da Mansão do Terror S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195671.mp4', 'http://timg.bdta.pro/images/ca59a6ab80482616c703f9172791047f.jpg'),
(85801, 5945, 'Guardiões da Mansão do Terror S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195672.mp4', 'http://timg.bdta.pro/images/4ed51b8d750b8b7ca296824320cc32ba.jpg'),
(85802, 5945, 'Guardiões da Mansão do Terror S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195673.mp4', 'http://timg.bdta.pro/images/d34cfb42f2e4bd758cb82776e3cf9bb3.jpg'),
(85803, 5945, 'Guardiões da Mansão do Terror S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195674.mp4', 'http://timg.bdta.pro/images/d698bfbbe1ea37413c9adfe36edf7c5a.jpg'),
(85804, 5946, 'Guardiões da Mansão do Terror S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195675.mp4', 'http://timg.bdta.pro/images/609f9d2cfff8f339928c02d4f2e0b941.jpg'),
(85805, 5946, 'Guardiões da Mansão do Terror S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195676.mp4', 'http://timg.bdta.pro/images/a1c21c0127360f139166ae6fafbe34a0.jpg'),
(85806, 5946, 'Guardiões da Mansão do Terror S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195677.mp4', 'http://timg.bdta.pro/images/e9de4f0f5f15ef0195e4d4885c92f741.jpg'),
(85807, 5946, 'Guardiões da Mansão do Terror S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195678.mp4', 'http://timg.bdta.pro/images/292e53e487eb69ceede080ada28d323d.jpg'),
(85808, 5946, 'Guardiões da Mansão do Terror S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195679.mp4', 'http://timg.bdta.pro/images/95c5d5e3163adec46c51da659dd4b58d.jpg'),
(85809, 5946, 'Guardiões da Mansão do Terror S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195680.mp4', 'http://timg.bdta.pro/images/48edc1227863860128cc216378a6d454.jpg'),
(85810, 5946, 'Guardiões da Mansão do Terror S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195681.mp4', 'http://timg.bdta.pro/images/6f037d9f620f49d037305d21eb01f0c1.jpg'),
(85811, 5946, 'Guardiões da Mansão do Terror S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195682.mp4', 'http://timg.bdta.pro/images/69edb850faff313d0ff49699f09d3cd9.jpg'),
(85812, 5946, 'Guardiões da Mansão do Terror S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195683.mp4', 'http://timg.bdta.pro/images/674f157bd68ef9b4a92f2d29593e64ab.jpg'),
(85813, 5946, 'Guardiões da Mansão do Terror S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195684.mp4', 'http://timg.bdta.pro/images/c190a0e9335bca39d97dc0384122e825.jpg'),
(85814, 5947, 'Maldivas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179433.mp4', 'http://timg.bdta.pro/images/bc505988e48971c2ddce154e581b904d.jpg'),
(85815, 5947, 'Maldivas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179434.mp4', 'http://timg.bdta.pro/images/56fffab84e0ad3f236a2a7235984bc24.jpg'),
(85816, 5947, 'Maldivas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179435.mp4', 'http://timg.bdta.pro/images/12e6aada4acc3d2780b72e102c18b390.jpg'),
(85817, 5947, 'Maldivas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179436.mp4', 'http://timg.bdta.pro/images/c202f2060eaece1d9ce2041a56d98133.jpg'),
(85818, 5947, 'Maldivas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179437.mp4', 'http://timg.bdta.pro/images/a3384eb14b300aa8740acb4befed3def.jpg'),
(85819, 5947, 'Maldivas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179438.mp4', 'http://timg.bdta.pro/images/545ee3ebd19ea9ca0978097c7b046289.jpg'),
(85820, 5947, 'Maldivas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179439.mp4', 'http://timg.bdta.pro/images/f38b1924c3c4746f6ab175cca37ad6fa.jpg'),
(85821, 5948, 'O Idiota Favorito de Deus S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179425.mp4', 'http://timg.bdta.pro/images/5c3b42eff2dbfd8e0dbecba92210021b.jpg'),
(85822, 5948, 'O Idiota Favorito de Deus S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179426.mp4', 'http://timg.bdta.pro/images/b3714a4febb38e55b7aa62ed6c853c3a.jpg'),
(85823, 5948, 'O Idiota Favorito de Deus S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179427.mp4', 'http://timg.bdta.pro/images/244619678f1bbe4e69adba89d5743ef6.jpg'),
(85824, 5948, 'O Idiota Favorito de Deus S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179428.mp4', 'http://timg.bdta.pro/images/da864631e827b4cb6cd01df4f20d388b.jpg'),
(85825, 5948, 'O Idiota Favorito de Deus S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179429.mp4', 'http://timg.bdta.pro/images/5e722da9e32864d61b7a7d7e31d0fda8.jpg'),
(85826, 5948, 'O Idiota Favorito de Deus S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179430.mp4', 'http://timg.bdta.pro/images/82b3c83df601d5cc2aff415433adc56e.jpg'),
(85827, 5948, 'O Idiota Favorito de Deus S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179431.mp4', 'http://timg.bdta.pro/images/5006e23eef747d59fa3b2dd8e34f1497.jpg'),
(85828, 5948, 'O Idiota Favorito de Deus S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179432.mp4', 'http://timg.bdta.pro/images/c6591985091589e11fdf288f56618bd3.jpg'),
(85829, 5949, 'O Lago S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215410.mp4', 'http://timg.bdta.pro/images/d56b9efb6e8ac91d591a343a51889b98.jpg'),
(85830, 5949, 'O Lago S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215411.mp4', 'http://timg.bdta.pro/images/123f5528f9f28bdadf3ca11909728a26.jpg'),
(85831, 5949, 'O Lago S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215412.mp4', 'http://timg.bdta.pro/images/df316c633c2a8d74bd003eabf5a7a451.jpg'),
(85832, 5949, 'O Lago S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215413.mp4', 'http://timg.bdta.pro/images/c64924958a507d5c8f5d2aa4b2e703e5.jpg'),
(85833, 5949, 'O Lago S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215414.mp4', 'http://timg.bdta.pro/images/513920bf529d1f58520f9bd10a6486c1.jpg'),
(85834, 5949, 'O Lago S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215415.mp4', 'http://timg.bdta.pro/images/a71783443914b72857025b937b160d86.jpg'),
(85835, 5949, 'O Lago S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215416.mp4', 'http://timg.bdta.pro/images/909fd641bed0260c56202a13cf2e40bc.jpg'),
(85836, 5949, 'O Lago S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215417.mp4', 'http://timg.bdta.pro/images/b239f749ddfb6c831814061e2ff7237b.jpg'),
(85837, 5950, 'O Lago S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6S1UtsrMPHFjuD0cYza2QwTVPC5.jpg'),
(85838, 5950, 'O Lago S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uHLe9nrghoWYiML13g2usQmOekQ.jpg'),
(85839, 5950, 'O Lago S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ddCV7xJAAnB3J0lD39jfsPDfHp2.jpg'),
(85840, 5950, 'O Lago S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yeN3ifQrlVUAHOsbIz7wQ0AOONw.jpg'),
(85841, 5950, 'O Lago S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sc4h78T7iohL2KMQe3UjEbuOKGh.jpg'),
(85842, 5950, 'O Lago S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o6L5ksMKvmkGHdOdHs9Jj1zcdTq.jpg'),
(85843, 5950, 'O Lago S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mFAopzwnUf1GNV69wGQ5WW8h8TL.jpg'),
(85844, 5950, 'O Lago S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qb7jGAx7N60xuv5wneuIY8e7kY5.jpg'),
(85845, 5951, 'O Verão Que Mudou Minha Vida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228842.mp4', 'http://timg.bdta.pro/images/8122611cf162741a072560c33fe683b4.jpg'),
(85846, 5951, 'O Verão Que Mudou Minha Vida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228843.mp4', 'http://timg.bdta.pro/images/c7baf57595a6e68ecf20784d787b6c98.jpg'),
(85847, 5951, 'O Verão Que Mudou Minha Vida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228844.mp4', 'http://timg.bdta.pro/images/499ea073da3b74cb32bb96470a009d7e.jpg'),
(85848, 5951, 'O Verão Que Mudou Minha Vida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228845.mp4', 'http://timg.bdta.pro/images/b9ada6f81522c9f06f80c612bef03ba6.jpg'),
(85849, 5951, 'O Verão Que Mudou Minha Vida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228846.mp4', 'http://timg.bdta.pro/images/c37a4804399f34ec9de3a3d8abaae5be.jpg'),
(85850, 5951, 'O Verão Que Mudou Minha Vida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228847.mp4', 'http://timg.bdta.pro/images/ab4e11f60c3d890c8f07e8fcb08b2818.jpg'),
(85851, 5951, 'O Verão Que Mudou Minha Vida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228848.mp4', 'http://timg.bdta.pro/images/479d63dff8c40f38b42d07264c961d7a.jpg'),
(85852, 5952, 'O Verão Que Mudou Minha Vida S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ceeiqNUDGFCO1Fjj5S3xe2q0f52.jpg'),
(85853, 5952, 'O Verão Que Mudou Minha Vida S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZ4cM5Q1C08uGNAiBnSms8iZ3Sh.jpg'),
(85854, 5952, 'O Verão Que Mudou Minha Vida S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f3G09f15JSWYBZ0KyaZkNSCYO7u.jpg'),
(85855, 5952, 'O Verão Que Mudou Minha Vida S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228852.mp4', 'http://image.tmdb.org/t/p/w1280/bI0s6ZZ7rEjWKTKM2oU3eAZobZp.jpg'),
(85856, 5952, 'O Verão Que Mudou Minha Vida S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228853.mp4', 'http://image.tmdb.org/t/p/w1280/cEEIw1H0Ta8d8gtJ8yOx5fx7DEs.jpg'),
(85857, 5952, 'O Verão Que Mudou Minha Vida S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228854.mp4', 'http://image.tmdb.org/t/p/w1280/3hwdw43vdOCarJ3bhpKteA65QFA.jpg'),
(85858, 5952, 'O Verão Que Mudou Minha Vida S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228855.mp4', 'http://image.tmdb.org/t/p/w1280/h7y6svGUAqq5y7hPZYvYqUbQf9K.jpg'),
(85859, 5952, 'O Verão Que Mudou Minha Vida S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228856.mp4', 'http://image.tmdb.org/t/p/w1280/dGTjnpcll0tvSrEP7wIPsqBbd34.jpg'),
(85860, 5953, 'O Verão Que Mudou Minha Vida S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/870338.mp4', 'http://gstaticontent.com/images/bbf3faf2a1709aa06ecf6d68fc16183c.jpg'),
(85861, 5953, 'O Verão Que Mudou Minha Vida S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/870339.mp4', 'http://gstaticontent.com/images/bbf3faf2a1709aa06ecf6d68fc16183c.jpg'),
(85862, 5953, 'O Verão Que Mudou Minha Vida S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/874191.mp4', 'http://gstaticontent.com/images/bbf3faf2a1709aa06ecf6d68fc16183c.jpg'),
(85863, 5953, 'O Verão Que Mudou Minha Vida S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/878868.mp4', 'http://gstaticontent.com/images/bbf3faf2a1709aa06ecf6d68fc16183c.jpg'),
(85864, 5953, 'O Verão Que Mudou Minha Vida S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/879978.mp4', 'http://gstaticontent.com/images/bbf3faf2a1709aa06ecf6d68fc16183c.jpg'),
(85865, 5953, 'O Verão Que Mudou Minha Vida S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/880381.mp4', 'http://gstaticontent.com/images/bbf3faf2a1709aa06ecf6d68fc16183c.jpg'),
(85866, 5953, 'O Verão Que Mudou Minha Vida S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/881197.mp4', 'http://gstaticontent.com/images/bbf3faf2a1709aa06ecf6d68fc16183c.jpg'),
(85867, 5953, 'O Verão Que Mudou Minha Vida S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/881311.mp4', 'http://gstaticontent.com/images/bbf3faf2a1709aa06ecf6d68fc16183c.jpg'),
(85868, 5953, 'O Verão Que Mudou Minha Vida S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/882204.mp4', 'http://gstaticontent.com/images/bbf3faf2a1709aa06ecf6d68fc16183c.jpg'),
(85869, 5953, 'O Verão Que Mudou Minha Vida S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/883789.mp4', 'http://gstaticontent.com/images/bbf3faf2a1709aa06ecf6d68fc16183c.jpg'),
(85870, 5953, 'O Verão Que Mudou Minha Vida S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/885313.mp4', 'http://gstaticontent.com/images/bbf3faf2a1709aa06ecf6d68fc16183c.jpg'),
(85871, 5954, 'Recomeço em Família S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179419.mp4', 'http://gstaticontent.com/images/d4fe4c1054b6d34a176b926455e272ed.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(85872, 5954, 'Recomeço em Família S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179420.mp4', 'http://gstaticontent.com/images/d4fe4c1054b6d34a176b926455e272ed.jpg'),
(85873, 5954, 'Recomeço em Família S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179421.mp4', 'http://gstaticontent.com/images/d4fe4c1054b6d34a176b926455e272ed.jpg'),
(85874, 5954, 'Recomeço em Família S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179422.mp4', 'http://gstaticontent.com/images/d4fe4c1054b6d34a176b926455e272ed.jpg'),
(85875, 5954, 'Recomeço em Família S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179423.mp4', 'http://gstaticontent.com/images/d4fe4c1054b6d34a176b926455e272ed.jpg'),
(85876, 5954, 'Recomeço em Família S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179424.mp4', 'http://gstaticontent.com/images/d4fe4c1054b6d34a176b926455e272ed.jpg'),
(85877, 5955, 'Sempre Fui Eu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179409.mp4', 'http://timg.bdta.pro/images/d8c09210db0bbbde4886137c45d49e7e.jpg'),
(85878, 5955, 'Sempre Fui Eu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179410.mp4', 'http://timg.bdta.pro/images/1cb44103c0f357317f62bab98e5f2dc4.jpg'),
(85879, 5955, 'Sempre Fui Eu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179411.mp4', 'http://timg.bdta.pro/images/7947eb1bdcc45d9a046960bcbd14f75f.jpg'),
(85880, 5955, 'Sempre Fui Eu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179412.mp4', 'http://timg.bdta.pro/images/51555c3c3c4652934b1cfd73bd0d6598.jpg'),
(85881, 5955, 'Sempre Fui Eu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179413.mp4', 'http://timg.bdta.pro/images/204757a0e3299dc4d3304c39e1861375.jpg'),
(85882, 5955, 'Sempre Fui Eu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179414.mp4', 'http://timg.bdta.pro/images/a1e130da16383cce78e528744f775692.jpg'),
(85883, 5955, 'Sempre Fui Eu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179415.mp4', 'http://timg.bdta.pro/images/2345ded61627341ee43bb59943eece66.jpg'),
(85884, 5955, 'Sempre Fui Eu S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179416.mp4', 'http://timg.bdta.pro/images/917e71af264c8762bab6c4e6bd895d6f.jpg'),
(85885, 5955, 'Sempre Fui Eu S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/179417.mp4', 'http://timg.bdta.pro/images/2d342206518c6c8d8215ea846979c4de.jpg'),
(85886, 5955, 'Sempre Fui Eu S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/179418.mp4', 'http://timg.bdta.pro/images/d09d4dd16240a04ceae6859d57ed73e0.jpg'),
(85887, 5956, 'Single Drunk Female S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213762.mp4', 'http://timg.bdta.pro/images/9de1ed9dfadac3664d182d546c59c672.jpg'),
(85888, 5956, 'Single Drunk Female S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213763.mp4', 'http://timg.bdta.pro/images/2e295ab2154b02edf4b0618d35da297b.jpg'),
(85889, 5956, 'Single Drunk Female S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213764.mp4', 'http://timg.bdta.pro/images/2140a2e80a8e4d1fb0170ede60cfcb90.jpg'),
(85890, 5956, 'Single Drunk Female S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213765.mp4', 'http://timg.bdta.pro/images/1b59f47ee650494f4079a1c071180d93.jpg'),
(85891, 5956, 'Single Drunk Female S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213766.mp4', 'http://timg.bdta.pro/images/902ceb30474f8e9f9a398b5ab68e6a32.jpg'),
(85892, 5956, 'Single Drunk Female S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213767.mp4', 'http://timg.bdta.pro/images/217fb83a02285eb8e09e053ac71bd7c4.jpg'),
(85893, 5956, 'Single Drunk Female S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213768.mp4', 'http://timg.bdta.pro/images/d65367ec758272a0b015bd0a17e169c4.jpg'),
(85894, 5956, 'Single Drunk Female S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213769.mp4', 'http://timg.bdta.pro/images/84d7f824a96463e5463ace403d075cba.jpg'),
(85895, 5956, 'Single Drunk Female S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213770.mp4', 'http://timg.bdta.pro/images/1f2764d484dd04ee281b7743a697b0e3.jpg'),
(85896, 5956, 'Single Drunk Female S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213771.mp4', 'http://timg.bdta.pro/images/4fe645be260e8dfe8d20f70300ec55cd.jpg'),
(85897, 5957, 'Single Drunk Female S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1c7OAhhnM4Sl9BklX7IMOFc5hE.jpg'),
(85898, 5957, 'Single Drunk Female S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/TqdolZIczMbqxxpGal6o5ByHjB.jpg'),
(85899, 5957, 'Single Drunk Female S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213774.mp4', 'http://image.tmdb.org/t/p/w1280/tOLL9Sl0pxYHFqbuNab4MNSRAKr.jpg'),
(85900, 5957, 'Single Drunk Female S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213775.mp4', 'http://image.tmdb.org/t/p/w1280/mGuvjBWtCJOYtyA4tIMJpryV1zh.jpg'),
(85901, 5957, 'Single Drunk Female S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213776.mp4', 'http://image.tmdb.org/t/p/w1280/vx2rRQ1Te27pRrghQoBOg5hIFGI.jpg'),
(85902, 5957, 'Single Drunk Female S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213777.mp4', 'http://image.tmdb.org/t/p/w1280/71OYYZtiQcIYz3f3T7WrSitRsQc.jpg'),
(85903, 5957, 'Single Drunk Female S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rjCmIuszl14t3vYZ8BuOu3NNZW4.jpg'),
(85904, 5957, 'Single Drunk Female S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/90KGLYmd4TIgGHkHOSykkql46og.jpg'),
(85905, 5957, 'Single Drunk Female S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c1ehr6BxG4Ysgs5XSjhdvhMGqY.jpg'),
(85906, 5957, 'Single Drunk Female S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cT9KNeafNmApCYWfEumhEWEDS5P.jpg'),
(85907, 5958, 'Suzhal: Vórtice S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179401.mp4', 'http://timg.bdta.pro/images/28493abdc2092242d5ff7a653281bbcf.jpg'),
(85908, 5958, 'Suzhal: Vórtice S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179402.mp4', 'http://timg.bdta.pro/images/1847215318af789fe998c95e78bc3092.jpg'),
(85909, 5958, 'Suzhal: Vórtice S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179403.mp4', 'http://timg.bdta.pro/images/c5e574347bf0a07af8dab7446603434b.jpg'),
(85910, 5958, 'Suzhal: Vórtice S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179404.mp4', 'http://timg.bdta.pro/images/82183069cad36bf90dcd1e02ec48f815.jpg'),
(85911, 5958, 'Suzhal: Vórtice S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179405.mp4', 'http://timg.bdta.pro/images/eda267d3539635de596f29ca749f137a.jpg'),
(85912, 5958, 'Suzhal: Vórtice S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179406.mp4', 'http://timg.bdta.pro/images/c025315a0b936fa5c19bd5f9f0bf3b29.jpg'),
(85913, 5958, 'Suzhal: Vórtice S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/179407.mp4', 'http://timg.bdta.pro/images/7269a27a2b8fc373d85c1750758f39e1.jpg'),
(85914, 5958, 'Suzhal: Vórtice S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/179408.mp4', 'http://timg.bdta.pro/images/cabeac23ee178f7a11bbce5a3385c928.jpg'),
(85915, 5959, 'Morte e Mentiras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179395.mp4', 'http://gstaticontent.com/images/7b687e54536542f4832b349b6b7c7f6f.jpg'),
(85916, 5959, 'Morte e Mentiras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179396.mp4', 'http://gstaticontent.com/images/7b687e54536542f4832b349b6b7c7f6f.jpg'),
(85917, 5959, 'Morte e Mentiras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179397.mp4', 'http://gstaticontent.com/images/7b687e54536542f4832b349b6b7c7f6f.jpg'),
(85918, 5959, 'Morte e Mentiras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179398.mp4', 'http://gstaticontent.com/images/7b687e54536542f4832b349b6b7c7f6f.jpg'),
(85919, 5959, 'Morte e Mentiras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/179399.mp4', 'http://gstaticontent.com/images/7b687e54536542f4832b349b6b7c7f6f.jpg'),
(85920, 5959, 'Morte e Mentiras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/179400.mp4', 'http://gstaticontent.com/images/7b687e54536542f4832b349b6b7c7f6f.jpg'),
(85921, 5960, 'Vocês Não Me Conhecem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/179391.mp4', 'http://timg.bdta.pro/images/8afbfa20591d74dee06a960b06dae650.jpg'),
(85922, 5960, 'Vocês Não Me Conhecem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/179392.mp4', 'http://timg.bdta.pro/images/54aea7e571c872b7e7c78e38d5c5543a.jpg'),
(85923, 5960, 'Vocês Não Me Conhecem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/179393.mp4', 'http://timg.bdta.pro/images/bfebb6adafaed4e0cfc9398575ace527.jpg'),
(85924, 5960, 'Vocês Não Me Conhecem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/179394.mp4', 'http://timg.bdta.pro/images/1a7e80e7524865f27042d75c84f01921.jpg'),
(85925, 5961, 'Mike & Molly S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215970.mp4', 'http://timg.bdta.pro/images/b77b38c0736702ef95bb0504a133356d.jpg'),
(85926, 5961, 'Mike & Molly S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215971.mp4', 'http://timg.bdta.pro/images/0dd75b0da30974f543c8f42f1cc738c9.jpg'),
(85927, 5961, 'Mike & Molly S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215972.mp4', 'http://timg.bdta.pro/images/f9848c100a7ee8744f9775745218f310.jpg'),
(85928, 5961, 'Mike & Molly S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215973.mp4', 'http://timg.bdta.pro/images/32bde7b291e8dcb72171fb42267d670b.jpg'),
(85929, 5961, 'Mike & Molly S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215974.mp4', 'http://timg.bdta.pro/images/85fcc714863e45ebd14efc0155a8da31.jpg'),
(85930, 5961, 'Mike & Molly S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215975.mp4', 'http://timg.bdta.pro/images/62f64bf427f447a90de8c1e1309bf2f4.jpg'),
(85931, 5961, 'Mike & Molly S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215976.mp4', 'http://timg.bdta.pro/images/a369a3f0a29a584d0058ce346eba4023.jpg'),
(85932, 5961, 'Mike & Molly S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215977.mp4', 'http://timg.bdta.pro/images/a369a3f0a29a584d0058ce346eba4023.jpg'),
(85933, 5961, 'Mike & Molly S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215978.mp4', 'http://timg.bdta.pro/images/74eada1b859cc0bdebcc4fbfc6e82d04.jpg'),
(85934, 5961, 'Mike & Molly S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215979.mp4', 'http://timg.bdta.pro/images/f05718546bb420952ad3713800dac4a8.jpg'),
(85935, 5961, 'Mike & Molly S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215980.mp4', 'http://timg.bdta.pro/images/e6d545cc7816cf5baa58e549dd7c30cc.jpg'),
(85936, 5961, 'Mike & Molly S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215981.mp4', 'http://timg.bdta.pro/images/0bfe6708cb33b3b75b99daefc28e155a.jpg'),
(85937, 5961, 'Mike & Molly S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215982.mp4', 'http://timg.bdta.pro/images/2d092ab85f5280b4915a1b594384fef1.jpg'),
(85938, 5961, 'Mike & Molly S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215983.mp4', 'http://timg.bdta.pro/images/6f74abb1941eae13418264186e8e1926.jpg'),
(85939, 5961, 'Mike & Molly S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215984.mp4', 'http://timg.bdta.pro/images/53f7ab443b21eeeab404a685dfbf8e85.jpg'),
(85940, 5961, 'Mike & Molly S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215985.mp4', 'http://timg.bdta.pro/images/b0e4f56f7d68ee0fcbd4167f596701fd.jpg'),
(85941, 5961, 'Mike & Molly S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/215986.mp4', 'http://timg.bdta.pro/images/17db086a8ac2c91e822f4f32104f435a.jpg'),
(85942, 5961, 'Mike & Molly S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/215987.mp4', 'http://timg.bdta.pro/images/97293093a385bde5c9b6a28881ab470a.jpg'),
(85943, 5961, 'Mike & Molly S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/215988.mp4', 'http://timg.bdta.pro/images/49d7e930d5cb2edfb2d911ce35becba1.jpg'),
(85944, 5961, 'Mike & Molly S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/215989.mp4', 'http://timg.bdta.pro/images/649eadc5cfcfb1c0f145194e974b5980.jpg'),
(85945, 5961, 'Mike & Molly S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/215990.mp4', 'http://timg.bdta.pro/images/68a2f717c597113de68a2526f4f5ee2f.jpg'),
(85946, 5961, 'Mike & Molly S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/215991.mp4', 'http://timg.bdta.pro/images/fb77db0f0e42e342d02abfe678358ec6.jpg'),
(85947, 5961, 'Mike & Molly S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/215992.mp4', 'http://timg.bdta.pro/images/649eadc5cfcfb1c0f145194e974b5980.jpg'),
(85948, 5961, 'Mike & Molly S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/215993.mp4', 'http://timg.bdta.pro/images/8255a3ddf8128e347b183f6d3aadd052.jpg'),
(85949, 5962, 'Mike & Molly S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215994.mp4', 'http://timg.bdta.pro/images/d2e1da89b9d19db1efc0a12abed54dad.jpg'),
(85950, 5962, 'Mike & Molly S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215995.mp4', 'http://timg.bdta.pro/images/86bacb840bedd8d5da050e39771528c4.jpg'),
(85951, 5962, 'Mike & Molly S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215996.mp4', 'http://timg.bdta.pro/images/86319ae069235913e2a238fb04cf1ebf.jpg'),
(85952, 5962, 'Mike & Molly S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215997.mp4', 'http://timg.bdta.pro/images/ad658af2e703c8d1b29c5384d93cf0a7.jpg'),
(85953, 5962, 'Mike & Molly S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215998.mp4', 'http://timg.bdta.pro/images/63f0c39ca46c838407ac07cac7dbab34.jpg'),
(85954, 5962, 'Mike & Molly S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215999.mp4', 'http://timg.bdta.pro/images/02091e9755d9266b314323196951b856.jpg'),
(85955, 5962, 'Mike & Molly S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216000.mp4', 'http://timg.bdta.pro/images/5017b09fd9df9e04258e8d084ce2184f.jpg'),
(85956, 5962, 'Mike & Molly S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216001.mp4', 'http://timg.bdta.pro/images/692750f600718e13f2a8ae1e7c20f905.jpg'),
(85957, 5962, 'Mike & Molly S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216002.mp4', 'http://timg.bdta.pro/images/31429ca5cd5c14c3e2d4c830a534ae4d.jpg'),
(85958, 5962, 'Mike & Molly S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216003.mp4', 'http://timg.bdta.pro/images/685ca4f60e5c431c758c78e648327527.jpg'),
(85959, 5962, 'Mike & Molly S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216004.mp4', 'http://timg.bdta.pro/images/30d8a95fbd54dba0bab90370354e20a3.jpg'),
(85960, 5962, 'Mike & Molly S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216005.mp4', 'http://timg.bdta.pro/images/4114c3398ae9f3aabb8e5db63c1e4631.jpg'),
(85961, 5962, 'Mike & Molly S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216006.mp4', 'http://timg.bdta.pro/images/ebc00aa0ba9e756be5e847bf22a5d167.jpg'),
(85962, 5962, 'Mike & Molly S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216007.mp4', 'http://timg.bdta.pro/images/4152d639d6e098af2f9e06b5740c9d4c.jpg'),
(85963, 5962, 'Mike & Molly S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/216008.mp4', 'http://timg.bdta.pro/images/fa872ab56009e6901d96c144dec8c923.jpg'),
(85964, 5962, 'Mike & Molly S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/216009.mp4', 'http://timg.bdta.pro/images/eb03069260c1c69ca1341fbb1d383eed.jpg'),
(85965, 5962, 'Mike & Molly S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/216010.mp4', 'http://timg.bdta.pro/images/9b00e5f32439bcb96f1822b5785d7191.jpg'),
(85966, 5962, 'Mike & Molly S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/216011.mp4', 'http://timg.bdta.pro/images/b39fa00a224915e01752620bd5370970.jpg'),
(85967, 5962, 'Mike & Molly S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/216012.mp4', 'http://timg.bdta.pro/images/552088320ab52cc5581d6e85c38002b7.jpg'),
(85968, 5962, 'Mike & Molly S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/216013.mp4', 'http://timg.bdta.pro/images/c0d0a383cee3023d49c1e9582df3721a.jpg'),
(85969, 5962, 'Mike & Molly S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/216014.mp4', 'http://timg.bdta.pro/images/3722b9913bb830a220f3967276ac7219.jpg'),
(85970, 5962, 'Mike & Molly S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/216015.mp4', 'http://timg.bdta.pro/images/0fa9d0b8272e8192f9abb2c4d4adc183.jpg'),
(85971, 5962, 'Mike & Molly S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/216016.mp4', 'http://timg.bdta.pro/images/02c02486466495c88548af53cead7bdd.jpg'),
(85972, 5963, 'Mike & Molly S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216017.mp4', 'http://timg.bdta.pro/images/f7df1315e6b436390f3f8ce1405e6633.jpg'),
(85973, 5963, 'Mike & Molly S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216018.mp4', 'http://timg.bdta.pro/images/bd054a08509a0b13ea2558f832c192b0.jpg'),
(85974, 5963, 'Mike & Molly S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216019.mp4', 'http://timg.bdta.pro/images/c91de3e84df9f041fe28459f36fefc29.jpg'),
(85975, 5963, 'Mike & Molly S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216020.mp4', 'http://timg.bdta.pro/images/2fc998f82e08969558632ea14f8c3372.jpg'),
(85976, 5963, 'Mike & Molly S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216021.mp4', 'http://timg.bdta.pro/images/e3386e52501638bf694e8b1e23cb588f.jpg'),
(85977, 5963, 'Mike & Molly S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216022.mp4', 'http://timg.bdta.pro/images/df2e7d55e83fdf234d9df07a4d5b0e53.jpg'),
(85978, 5963, 'Mike & Molly S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216023.mp4', 'http://timg.bdta.pro/images/a4e844eea2a163b079df3246dc3a2d20.jpg'),
(85979, 5963, 'Mike & Molly S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216024.mp4', 'http://timg.bdta.pro/images/b0cbfaf3f7e9a07c94eb6cc0cde1f8d5.jpg'),
(85980, 5963, 'Mike & Molly S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216025.mp4', 'http://timg.bdta.pro/images/b16cc5ad40ac35c615f6d3d6e3058bc5.jpg'),
(85981, 5963, 'Mike & Molly S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216026.mp4', 'http://timg.bdta.pro/images/bb904220f4e8e1e4780bd52c21fdf735.jpg'),
(85982, 5963, 'Mike & Molly S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216027.mp4', 'http://timg.bdta.pro/images/3ff4ae776c5f357d8b8719ad39da757e.jpg'),
(85983, 5963, 'Mike & Molly S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216028.mp4', 'http://timg.bdta.pro/images/44e07d855fab179b3d7704d447ae6f84.jpg'),
(85984, 5963, 'Mike & Molly S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216029.mp4', 'http://timg.bdta.pro/images/6e0dc343b30b1ec9f7397339ad0d27f5.jpg'),
(85985, 5963, 'Mike & Molly S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216030.mp4', 'http://timg.bdta.pro/images/5f3bef1e6a077c993b4d9952a9e500fd.jpg'),
(85986, 5963, 'Mike & Molly S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/216031.mp4', 'http://timg.bdta.pro/images/8525f17242cfea6ecfec65f8b1827db3.jpg'),
(85987, 5963, 'Mike & Molly S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/216032.mp4', 'http://timg.bdta.pro/images/60b5157cd99a9a4f71e83db4f27bc07e.jpg'),
(85988, 5963, 'Mike & Molly S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/216033.mp4', 'http://timg.bdta.pro/images/e61fb89ec8467dbf5d397f25f9a398b1.jpg'),
(85989, 5963, 'Mike & Molly S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/216034.mp4', 'http://timg.bdta.pro/images/1a51a17de721aeabb036daa42edf4581.jpg'),
(85990, 5963, 'Mike & Molly S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/216035.mp4', 'http://timg.bdta.pro/images/1aa5dd8d8d14d166ac81234a0845897a.jpg'),
(85991, 5963, 'Mike & Molly S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/216036.mp4', 'http://timg.bdta.pro/images/e6bda6dc52a75e1a8d9062544801643c.jpg'),
(85992, 5963, 'Mike & Molly S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/216037.mp4', 'http://timg.bdta.pro/images/a6ae16e65524ea769dac6ff3747ebbc0.jpg'),
(85993, 5963, 'Mike & Molly S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/216038.mp4', 'http://timg.bdta.pro/images/c66c2e3dfe10197b76098a6e3542ebf9.jpg'),
(85994, 5963, 'Mike & Molly S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/216039.mp4', 'http://timg.bdta.pro/images/73e5b528d0292d0e11e72312e8bd8daf.jpg'),
(85995, 5964, 'Mike & Molly S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216040.mp4', 'http://timg.bdta.pro/images/af6769cb57924074e248e6fa09699096.jpg'),
(85996, 5964, 'Mike & Molly S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216041.mp4', 'http://timg.bdta.pro/images/3911420a5222c7bddedac2a644b897f9.jpg'),
(85997, 5964, 'Mike & Molly S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216042.mp4', 'http://timg.bdta.pro/images/aaecce0e15d02b58e6d35379de6ed5a2.jpg'),
(85998, 5964, 'Mike & Molly S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216043.mp4', 'http://timg.bdta.pro/images/5c548dd1188649a2e43c3c138475fdc2.jpg'),
(85999, 5964, 'Mike & Molly S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216044.mp4', 'http://timg.bdta.pro/images/0a8dbd0008e4043de7475410ebe1018e.jpg'),
(86000, 5964, 'Mike & Molly S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216045.mp4', 'http://timg.bdta.pro/images/e7ccd87c3df1f7060b304d4248ec96a9.jpg'),
(86001, 5964, 'Mike & Molly S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216046.mp4', 'http://timg.bdta.pro/images/077dd4bb3d5a7cd5a5464d6f3aec84d8.jpg'),
(86002, 5964, 'Mike & Molly S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216047.mp4', 'http://timg.bdta.pro/images/fee45634d7c28c05bed501864ebf84a9.jpg'),
(86003, 5964, 'Mike & Molly S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216048.mp4', 'http://timg.bdta.pro/images/c9a7f9ce8b8b672bab141c278089d0aa.jpg'),
(86004, 5964, 'Mike & Molly S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216049.mp4', 'http://timg.bdta.pro/images/8dccb7b4decc32a508c29cf7fe0ed78f.jpg'),
(86005, 5964, 'Mike & Molly S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216050.mp4', 'http://timg.bdta.pro/images/09658f51077dc63bed75a3c287dc345c.jpg'),
(86006, 5964, 'Mike & Molly S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216051.mp4', 'http://timg.bdta.pro/images/10acb848acc8c9866279ce66130431b1.jpg'),
(86007, 5964, 'Mike & Molly S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216052.mp4', 'http://timg.bdta.pro/images/4c382284f3295622edc35c176ead240d.jpg'),
(86008, 5964, 'Mike & Molly S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216053.mp4', 'http://timg.bdta.pro/images/0da109804cdc127e2b0eab15ba3e4a1e.jpg'),
(86009, 5964, 'Mike & Molly S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/216054.mp4', 'http://timg.bdta.pro/images/74572053897d0f05cf53bd96f22c6a82.jpg'),
(86010, 5964, 'Mike & Molly S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/216055.mp4', 'http://timg.bdta.pro/images/ce4b8331e674dd105c2dc272d10b384b.jpg'),
(86011, 5964, 'Mike & Molly S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/216056.mp4', 'http://timg.bdta.pro/images/47b1f66e3081fba1ce9b29242226031a.jpg'),
(86012, 5964, 'Mike & Molly S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/216057.mp4', 'http://timg.bdta.pro/images/4e9bd28a05e07cba52ba8295a2a015f2.jpg'),
(86013, 5964, 'Mike & Molly S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/216058.mp4', 'http://timg.bdta.pro/images/958c3b103af058fdab9977c48e30dd42.jpg'),
(86014, 5964, 'Mike & Molly S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/216059.mp4', 'http://timg.bdta.pro/images/9e3f712e59bee05a8fabe1d324bcdd62.jpg'),
(86015, 5964, 'Mike & Molly S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/216060.mp4', 'http://timg.bdta.pro/images/2d98531f8a3f906006920903a7d6f078.jpg'),
(86016, 5964, 'Mike & Molly S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/216061.mp4', 'http://timg.bdta.pro/images/4471c85a7b2be6953c748ef74f543336.jpg'),
(86017, 5965, 'Mike & Molly S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4wUk76e7ITEnR232y9sZJyBar3X.jpg'),
(86018, 5965, 'Mike & Molly S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ggDevL56IMdOKgpfz6KfUVZd8K.jpg'),
(86019, 5965, 'Mike & Molly S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6f9hlEMuK2yqqW8xXEQAggFow6e.jpg'),
(86020, 5965, 'Mike & Molly S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vQEsswoCLbhiyslqhgvAXWxJ1kB.jpg'),
(86021, 5965, 'Mike & Molly S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/66ZrfOSw0GhWEuucCs030rABzeA.jpg'),
(86022, 5965, 'Mike & Molly S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iOBYsVXYHBDDu9MKJfzpFxPWSJp.jpg'),
(86023, 5965, 'Mike & Molly S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4GiXZpMijqO8LAtce9GdM8sU427.jpg'),
(86024, 5965, 'Mike & Molly S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yzAEvEOKvogZsiLz4Dia1LBMmIF.jpg'),
(86025, 5965, 'Mike & Molly S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4bAsJ6yfDpAemoQJ6aVsgTswQnm.jpg'),
(86026, 5965, 'Mike & Molly S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/parIjOb1Rekr9vpGQ0nSaXwN0j7.jpg'),
(86027, 5965, 'Mike & Molly S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qU3lg4WnPho9bpWsJYeChYCSN7p.jpg'),
(86028, 5965, 'Mike & Molly S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6AahztDdCdQVLDVcQyBhPpdF4IC.jpg'),
(86029, 5965, 'Mike & Molly S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3DafADcj6hyZRcxHJwc5cafgPO.jpg'),
(86030, 5965, 'Mike & Molly S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hroLDFQRRtCRCm9m9Fo4xTBpzAZ.jpg'),
(86031, 5965, 'Mike & Molly S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/216076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Oyp1dVeDCGOwkDR64HR2xIRml8.jpg'),
(86032, 5965, 'Mike & Molly S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/216077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPsmSDYGKPZf0K42q8eGnjq5P8u.jpg'),
(86033, 5965, 'Mike & Molly S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/216078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k2ARpyeNIcHewPY9KhvnMkiLZnw.jpg'),
(86034, 5965, 'Mike & Molly S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/216079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eKYORcDSa7CNMaNowWwdO7Q1lYs.jpg'),
(86035, 5965, 'Mike & Molly S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/216080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/euBAoptH1FWiVjZ7a8QFgqtkjcR.jpg'),
(86036, 5965, 'Mike & Molly S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/216081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hLFrfBymkkgLCWYlnUltrInJTGH.jpg'),
(86037, 5965, 'Mike & Molly S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/216082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5LwPuCvAhvbrqVmN2p7SnApnS0G.jpg'),
(86038, 5965, 'Mike & Molly S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/216083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9MyTdbqmqOl95swn9Z5oaTBXH7v.jpg'),
(86039, 5966, 'Mike & Molly S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l9fXyc3U1Jzg1ZYMaCDSLylyXUr.jpg'),
(86040, 5966, 'Mike & Molly S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fJx8XQUPiEXqHhCT5tmDp0jFq5p.jpg'),
(86041, 5966, 'Mike & Molly S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gw13FzaXEbTKRE95GPHE4CE4Me6.jpg'),
(86042, 5966, 'Mike & Molly S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jfzMNgp9UzeV1gl55bFnwO5Fpzl.jpg'),
(86043, 5966, 'Mike & Molly S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eFcyuFf40JO4B8Ms76cg2Sv3JqX.jpg'),
(86044, 5966, 'Mike & Molly S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1upZNhj4mKdZ9KbVaT8SWwYk0kr.jpg'),
(86045, 5966, 'Mike & Molly S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sszDieAz9TBgIBIiFGZ5o65B936.jpg'),
(86046, 5966, 'Mike & Molly S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1gdMlc9i4Qo5rHa7frL20whckEQ.jpg'),
(86047, 5966, 'Mike & Molly S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sLmIWSLBKDpmF3gJIZQBl2NAMmn.jpg'),
(86048, 5966, 'Mike & Molly S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zrWGoxln7nSUFJDzVrCeaiKe83t.jpg'),
(86049, 5966, 'Mike & Molly S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5EWVk3BptXoGPHjzm50isaQ6yOR.jpg'),
(86050, 5966, 'Mike & Molly S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/72T9BAMJkrgnHnvVBIlzThYlUuL.jpg'),
(86051, 5966, 'Mike & Molly S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJQrVpLlt70vfkJi7smTbNpEF5r.jpg'),
(86052, 5967, '2 Cachorros Bobos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/184088.mp4', 'http://timg.bdta.pro/images/a0fa0043851660c3a95c81314ff44654.jpg'),
(86053, 5967, '2 Cachorros Bobos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/184089.mp4', 'http://timg.bdta.pro/images/20e2693b9ae614ba92829c9e65ca40ce.jpg'),
(86054, 5967, '2 Cachorros Bobos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/184090.mp4', 'http://timg.bdta.pro/images/d2f0257fcee4e7392978c0e56be464b2.jpg'),
(86055, 5967, '2 Cachorros Bobos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/184091.mp4', 'http://timg.bdta.pro/images/dd4814a621115676b9548e6eab7d1b20.jpg'),
(86056, 5967, '2 Cachorros Bobos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/184092.mp4', 'http://timg.bdta.pro/images/87a910f5ed51e2d59d1ecaba5f942fe1.jpg'),
(86057, 5967, '2 Cachorros Bobos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/184093.mp4', 'http://timg.bdta.pro/images/346dedf89158903862da3e37366de195.jpg'),
(86058, 5967, '2 Cachorros Bobos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/184094.mp4', 'http://timg.bdta.pro/images/9c4a3e7b97a55ee3523cc546f57f7d40.jpg'),
(86059, 5967, '2 Cachorros Bobos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/184095.mp4', 'http://timg.bdta.pro/images/9cf157996fb1df4fc561f7126492fb1d.jpg'),
(86060, 5967, '2 Cachorros Bobos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/184096.mp4', 'http://timg.bdta.pro/images/3da7417680b0e7bcdee7ac0d1e3d8b05.jpg'),
(86061, 5967, '2 Cachorros Bobos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/184097.mp4', 'http://timg.bdta.pro/images/e609e7542f67d17d8ffaf953e26cde47.jpg'),
(86062, 5967, '2 Cachorros Bobos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/184098.mp4', 'http://timg.bdta.pro/images/7673fd6703d9ea10a364ba0f67139cad.jpg'),
(86063, 5967, '2 Cachorros Bobos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/184099.mp4', 'http://timg.bdta.pro/images/b8274c18dd2714c9153bb9386558375b.jpg'),
(86064, 5967, '2 Cachorros Bobos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/184100.mp4', 'http://timg.bdta.pro/images/01547e88c17e6c5c3b7094ff96faa3fd.jpg'),
(86065, 5968, '2 Cachorros Bobos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/184101.mp4', 'http://gstaticontent.com/images/a33580159171e671190b9da6d3d8d5d6.jpg'),
(86066, 5968, '2 Cachorros Bobos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/184102.mp4', 'http://gstaticontent.com/images/a33580159171e671190b9da6d3d8d5d6.jpg'),
(86067, 5968, '2 Cachorros Bobos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/184103.mp4', 'http://timg.bdta.pro/images/f93d603dee9a608a15890fce57e9216f.jpg'),
(86068, 5968, '2 Cachorros Bobos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/184104.mp4', 'http://timg.bdta.pro/images/6314efe9e5b0bcbaf1bb21daa4feac74.jpg'),
(86069, 5968, '2 Cachorros Bobos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/184105.mp4', 'http://gstaticontent.com/images/a33580159171e671190b9da6d3d8d5d6.jpg'),
(86070, 5968, '2 Cachorros Bobos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/184106.mp4', 'http://timg.bdta.pro/images/9d6e903ece90c151d5e1dc831d5ae30c.jpg'),
(86071, 5968, '2 Cachorros Bobos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/184107.mp4', 'http://gstaticontent.com/images/a33580159171e671190b9da6d3d8d5d6.jpg'),
(86072, 5968, '2 Cachorros Bobos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/184108.mp4', 'http://timg.bdta.pro/images/8e934aad5daab1616c38b61c3f7df6c0.jpg'),
(86073, 5968, '2 Cachorros Bobos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/184109.mp4', 'http://timg.bdta.pro/images/59f63fb8e2f57bc78e596797e46b2d33.jpg'),
(86074, 5968, '2 Cachorros Bobos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/184110.mp4', 'http://timg.bdta.pro/images/82cf1220e8a370f515765dc833f849be.jpg'),
(86075, 5968, '2 Cachorros Bobos S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/184111.mp4', 'http://timg.bdta.pro/images/4243919c032052ca9b94099a5ab73261.jpg'),
(86076, 5968, '2 Cachorros Bobos S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/184112.mp4', 'http://gstaticontent.com/images/a33580159171e671190b9da6d3d8d5d6.jpg'),
(86077, 5968, '2 Cachorros Bobos S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/184113.mp4', 'http://gstaticontent.com/images/a33580159171e671190b9da6d3d8d5d6.jpg'),
(86078, 5969, 'A Ilha da Fantasia (1978) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183960.mp4', 'http://timg.bdta.pro/images/0828487b5ca72a78753986343b82080f.jpg'),
(86079, 5969, 'A Ilha da Fantasia (1978) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183961.mp4', 'http://timg.bdta.pro/images/7be055ed633761764a897cd3cf1e3f46.jpg'),
(86080, 5969, 'A Ilha da Fantasia (1978) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183962.mp4', 'http://timg.bdta.pro/images/cc93d9462f23f929462872063f20746b.jpg'),
(86081, 5969, 'A Ilha da Fantasia (1978) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183963.mp4', 'http://timg.bdta.pro/images/c8253aac9e4889eb467a38056923096b.jpg'),
(86082, 5969, 'A Ilha da Fantasia (1978) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183964.mp4', 'http://timg.bdta.pro/images/717117a02ea2f990d096f0c8a1b898a5.jpg'),
(86083, 5969, 'A Ilha da Fantasia (1978) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183965.mp4', 'http://timg.bdta.pro/images/1508bb8ddf015ac7a799747ecc7efc68.jpg'),
(86084, 5969, 'A Ilha da Fantasia (1978) S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183966.mp4', 'http://timg.bdta.pro/images/c08f485ece8dce02c5e348579fda0234.jpg'),
(86085, 5969, 'A Ilha da Fantasia (1978) S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183967.mp4', 'http://timg.bdta.pro/images/8409d54da3c542e87beab00fc8bb9a8b.jpg'),
(86086, 5969, 'A Ilha da Fantasia (1978) S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183968.mp4', 'http://timg.bdta.pro/images/dd4ca4c05e66603eff325e45adb4edf4.jpg'),
(86087, 5969, 'A Ilha da Fantasia (1978) S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183969.mp4', 'http://timg.bdta.pro/images/e45d631946738142ba751602b44d0e24.jpg'),
(86088, 5969, 'A Ilha da Fantasia (1978) S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183970.mp4', 'http://timg.bdta.pro/images/67f6a856c654dc9b8439323e1d21adaf.jpg'),
(86089, 5969, 'A Ilha da Fantasia (1978) S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183971.mp4', 'http://timg.bdta.pro/images/9cedca73127b91222bc61af7f3819811.jpg'),
(86090, 5969, 'A Ilha da Fantasia (1978) S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/183972.mp4', 'http://timg.bdta.pro/images/0dba8c84c27eba325222dbd2be58dfe7.jpg'),
(86091, 5969, 'A Ilha da Fantasia (1978) S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/183973.mp4', 'http://timg.bdta.pro/images/647dc11003e7a28bfb06d85204d20e20.jpg'),
(86092, 5970, 'A Ilha da Fantasia (1978) S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183974.mp4', 'http://timg.bdta.pro/images/e7b47c72cbd7788abf8be662761d6817.jpg'),
(86093, 5970, 'A Ilha da Fantasia (1978) S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183975.mp4', 'http://timg.bdta.pro/images/48ad16865bd96b97ceb73de2bd0a8b9f.jpg'),
(86094, 5970, 'A Ilha da Fantasia (1978) S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183976.mp4', 'http://timg.bdta.pro/images/2c089a2ac16ba9c63e14846b2c7109c6.jpg'),
(86095, 5970, 'A Ilha da Fantasia (1978) S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183977.mp4', 'http://timg.bdta.pro/images/3f23b42487c19362dec10c53d762ec0e.jpg'),
(86096, 5970, 'A Ilha da Fantasia (1978) S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183978.mp4', 'http://timg.bdta.pro/images/e0efeb930c36a02315ea9b966ac0efc5.jpg'),
(86097, 5970, 'A Ilha da Fantasia (1978) S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183979.mp4', 'http://timg.bdta.pro/images/baa81718846a910b09270c80272ca4c1.jpg'),
(86098, 5970, 'A Ilha da Fantasia (1978) S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183980.mp4', 'http://timg.bdta.pro/images/926e0bfa886befecec7536c157f2dc26.jpg'),
(86099, 5970, 'A Ilha da Fantasia (1978) S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183981.mp4', 'http://timg.bdta.pro/images/bc68ca801b76c8ff5b80472c486239e3.jpg'),
(86100, 5970, 'A Ilha da Fantasia (1978) S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183982.mp4', 'http://timg.bdta.pro/images/2864192bf72d440524f7a739ac0dd21c.jpg'),
(86101, 5970, 'A Ilha da Fantasia (1978) S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183983.mp4', 'http://timg.bdta.pro/images/7800345b3993e3a82cc73984f122ec7f.jpg'),
(86102, 5970, 'A Ilha da Fantasia (1978) S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183984.mp4', 'http://timg.bdta.pro/images/9326c2dd53fc024493d99f74d1eaec32.jpg'),
(86103, 5970, 'A Ilha da Fantasia (1978) S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183985.mp4', 'http://timg.bdta.pro/images/fb497560906d2b3b425f51238ddc3a37.jpg'),
(86104, 5970, 'A Ilha da Fantasia (1978) S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/183986.mp4', 'http://timg.bdta.pro/images/deb2dd5307529b59a83d9676a19c32c1.jpg'),
(86105, 5970, 'A Ilha da Fantasia (1978) S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/183987.mp4', 'http://timg.bdta.pro/images/6722fd1e930fb5afca3d7c0440d7eef6.jpg'),
(86106, 5970, 'A Ilha da Fantasia (1978) S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/183988.mp4', 'http://timg.bdta.pro/images/2ee8301f2f01ebfd795956f1ebc75497.jpg'),
(86107, 5970, 'A Ilha da Fantasia (1978) S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/183989.mp4', 'http://timg.bdta.pro/images/5062695475e5865f7eec7cc9f912562a.jpg'),
(86108, 5970, 'A Ilha da Fantasia (1978) S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/183990.mp4', 'http://timg.bdta.pro/images/f0f316268e56b942ebdf3820bb3e78e7.jpg'),
(86109, 5970, 'A Ilha da Fantasia (1978) S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/183991.mp4', 'http://timg.bdta.pro/images/b46d61cf07a613de8bfc83df3f49093d.jpg'),
(86110, 5970, 'A Ilha da Fantasia (1978) S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/183992.mp4', 'http://timg.bdta.pro/images/89047d4d7aff4cee9a96bf77f3fc4366.jpg'),
(86111, 5970, 'A Ilha da Fantasia (1978) S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/183993.mp4', 'http://timg.bdta.pro/images/2fad0cfbdf3eb34a63167b864af00d32.jpg'),
(86112, 5970, 'A Ilha da Fantasia (1978) S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/183994.mp4', 'http://timg.bdta.pro/images/54e421535bd8e315d3c08175c714bb06.jpg'),
(86113, 5970, 'A Ilha da Fantasia (1978) S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/183995.mp4', 'http://timg.bdta.pro/images/6ee5ec637ac9724be222801be60f75eb.jpg'),
(86114, 5970, 'A Ilha da Fantasia (1978) S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/183996.mp4', 'http://timg.bdta.pro/images/6dd362179917610f43673ffd6d63503e.jpg'),
(86115, 5970, 'A Ilha da Fantasia (1978) S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/183997.mp4', 'http://timg.bdta.pro/images/d0e807c983c20b8102088627e74853c6.jpg'),
(86116, 5970, 'A Ilha da Fantasia (1978) S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/183998.mp4', 'http://timg.bdta.pro/images/14c6a6e04302b13448d1f387b52b6c49.jpg'),
(86117, 5971, 'A Ilha da Fantasia (1978) S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183999.mp4', 'http://timg.bdta.pro/images/de44fef3d0f839a886e75de0ca24eea2.jpg'),
(86118, 5971, 'A Ilha da Fantasia (1978) S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/184000.mp4', 'http://timg.bdta.pro/images/aa2efafe9bc902fa86001639fbe8c531.jpg'),
(86119, 5971, 'A Ilha da Fantasia (1978) S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/184001.mp4', 'http://timg.bdta.pro/images/2450badb0fbcdc345cf598020fc0fdc6.jpg'),
(86120, 5971, 'A Ilha da Fantasia (1978) S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/184002.mp4', 'http://timg.bdta.pro/images/c8775051767b427516d7e380ab296481.jpg'),
(86121, 5971, 'A Ilha da Fantasia (1978) S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/184003.mp4', 'http://timg.bdta.pro/images/e49fde35d949a4dfb7feb06ecb901f6e.jpg'),
(86122, 5971, 'A Ilha da Fantasia (1978) S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/184004.mp4', 'http://timg.bdta.pro/images/b41f994aba4cc3d6886a864aa7dbac65.jpg'),
(86123, 5971, 'A Ilha da Fantasia (1978) S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/184005.mp4', 'http://timg.bdta.pro/images/a836fa8c923cd05de5eee917d397e257.jpg'),
(86124, 5971, 'A Ilha da Fantasia (1978) S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/184006.mp4', 'http://timg.bdta.pro/images/882639a9831f8710d47b7d8637ee8069.jpg'),
(86125, 5971, 'A Ilha da Fantasia (1978) S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/184007.mp4', 'http://timg.bdta.pro/images/05fba775a77c5db61147ddefc44bfcd5.jpg'),
(86126, 5971, 'A Ilha da Fantasia (1978) S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/184008.mp4', 'http://timg.bdta.pro/images/597a2ab6eedd302f522ed72b0380f4ba.jpg'),
(86127, 5971, 'A Ilha da Fantasia (1978) S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/184009.mp4', 'http://timg.bdta.pro/images/1a3b0e79e8a0753254db11176ae57b26.jpg'),
(86128, 5971, 'A Ilha da Fantasia (1978) S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/184010.mp4', 'http://timg.bdta.pro/images/9720826d77c049620c72610f5475ae91.jpg'),
(86129, 5971, 'A Ilha da Fantasia (1978) S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/184011.mp4', 'http://timg.bdta.pro/images/aa0616c64e22bfdde06c5823f712a288.jpg'),
(86130, 5971, 'A Ilha da Fantasia (1978) S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/184012.mp4', 'http://timg.bdta.pro/images/a55fbe568e078da2cc6975c52da3c99c.jpg'),
(86131, 5971, 'A Ilha da Fantasia (1978) S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/184013.mp4', 'http://timg.bdta.pro/images/299906471570eef2af384dcc7e2f4253.jpg'),
(86132, 5971, 'A Ilha da Fantasia (1978) S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/184014.mp4', 'http://timg.bdta.pro/images/2ad2b17ee56436c90207ce5ffc9fc626.jpg'),
(86133, 5971, 'A Ilha da Fantasia (1978) S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/184015.mp4', 'http://timg.bdta.pro/images/b332b4281aa4c7db10ea9e6b39153b98.jpg'),
(86134, 5971, 'A Ilha da Fantasia (1978) S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/184016.mp4', 'http://timg.bdta.pro/images/b5b5d8454b41155ae62e1b9db1be3add.jpg'),
(86135, 5971, 'A Ilha da Fantasia (1978) S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/184017.mp4', 'http://timg.bdta.pro/images/2618349e2c46c3477f90cbd247c963ea.jpg'),
(86136, 5971, 'A Ilha da Fantasia (1978) S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/184018.mp4', 'http://timg.bdta.pro/images/89e4f5bc640c2e4e58dbcbcc32a25e0c.jpg'),
(86137, 5971, 'A Ilha da Fantasia (1978) S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/184019.mp4', 'http://timg.bdta.pro/images/71d00a9e43213ac124011104d7f69f3d.jpg'),
(86138, 5971, 'A Ilha da Fantasia (1978) S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/184020.mp4', 'http://timg.bdta.pro/images/c787c81550536b0079b0dbfc5f72fe5e.jpg'),
(86139, 5971, 'A Ilha da Fantasia (1978) S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/184021.mp4', 'http://timg.bdta.pro/images/316cdf8ad5146d542f32f29285e96add.jpg'),
(86140, 5972, 'A Ilha da Fantasia (1978) S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/184022.mp4', 'http://timg.bdta.pro/images/6880ec6dea30e6f35893c43a0f1a13db.jpg'),
(86141, 5972, 'A Ilha da Fantasia (1978) S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/184023.mp4', 'http://timg.bdta.pro/images/3b630184ff614df9f2a43a197235a7f8.jpg'),
(86142, 5972, 'A Ilha da Fantasia (1978) S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/184024.mp4', 'http://timg.bdta.pro/images/8efaa8580fe06bc982d05f1970249062.jpg'),
(86143, 5972, 'A Ilha da Fantasia (1978) S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/184025.mp4', 'http://timg.bdta.pro/images/95d29ecea9b6b505af4d5815af61800b.jpg'),
(86144, 5972, 'A Ilha da Fantasia (1978) S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/184026.mp4', 'http://timg.bdta.pro/images/17ac8c53c614ab41cfba283c9e122a7c.jpg'),
(86145, 5972, 'A Ilha da Fantasia (1978) S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/184027.mp4', 'http://timg.bdta.pro/images/d531fff582a49c81c836386f601ea8fe.jpg'),
(86146, 5972, 'A Ilha da Fantasia (1978) S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/184028.mp4', 'http://timg.bdta.pro/images/219caf94eb87a1cf34677fb016d44e4e.jpg'),
(86147, 5972, 'A Ilha da Fantasia (1978) S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/184029.mp4', 'http://timg.bdta.pro/images/69cd15c077fd16829912192e238648ce.jpg'),
(86148, 5972, 'A Ilha da Fantasia (1978) S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/184030.mp4', 'http://timg.bdta.pro/images/87ad721ea1d60eb5f02622758e22f84f.jpg'),
(86149, 5972, 'A Ilha da Fantasia (1978) S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/184031.mp4', 'http://timg.bdta.pro/images/486ba4f22f4c226bd6dd088897a21931.jpg'),
(86150, 5972, 'A Ilha da Fantasia (1978) S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/184032.mp4', 'http://timg.bdta.pro/images/bccf67a81775a723f04e03c7594544c8.jpg'),
(86151, 5972, 'A Ilha da Fantasia (1978) S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/184033.mp4', 'http://timg.bdta.pro/images/d170ff425737b85e73c7e01671b695b9.jpg'),
(86152, 5972, 'A Ilha da Fantasia (1978) S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/184034.mp4', 'http://timg.bdta.pro/images/55ed08715fcd3d2d57a4ae42a025c30f.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(86153, 5972, 'A Ilha da Fantasia (1978) S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/184035.mp4', 'http://timg.bdta.pro/images/ff4fb0d536e13ea8f3b8ac8361af9c09.jpg'),
(86154, 5972, 'A Ilha da Fantasia (1978) S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/184036.mp4', 'http://timg.bdta.pro/images/b3b3a5e6ba3d02d3d6b3219b1e808fe4.jpg'),
(86155, 5972, 'A Ilha da Fantasia (1978) S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/184037.mp4', 'http://timg.bdta.pro/images/7434ebf1a673bf50648d8473ee617db4.jpg'),
(86156, 5972, 'A Ilha da Fantasia (1978) S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/184038.mp4', 'http://timg.bdta.pro/images/cec6dda3e232e2b2311904e02d21340d.jpg'),
(86157, 5972, 'A Ilha da Fantasia (1978) S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/184039.mp4', 'http://timg.bdta.pro/images/ca32c4973c52b733bd7d8ff0867af08e.jpg'),
(86158, 5972, 'A Ilha da Fantasia (1978) S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/184040.mp4', 'http://timg.bdta.pro/images/5032a4b8ac52b402ef5df8e93a63d374.jpg'),
(86159, 5972, 'A Ilha da Fantasia (1978) S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/184041.mp4', 'http://timg.bdta.pro/images/fd84b648e459b84be0c2c5af7fb5b4f2.jpg'),
(86160, 5972, 'A Ilha da Fantasia (1978) S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/184042.mp4', 'http://timg.bdta.pro/images/466e2d1f49131da0c8371b7f6fcd83a9.jpg'),
(86161, 5972, 'A Ilha da Fantasia (1978) S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/184043.mp4', 'http://timg.bdta.pro/images/c38e5c5938dad8802b27015269697c78.jpg'),
(86162, 5973, 'A Ilha da Fantasia (1978) S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/184044.mp4', 'http://timg.bdta.pro/images/f942873819742c1bb5f472d7a6e8328f.jpg'),
(86163, 5973, 'A Ilha da Fantasia (1978) S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/184045.mp4', 'http://timg.bdta.pro/images/84b1e4e9a5339c4f4e71d549307bb8eb.jpg'),
(86164, 5973, 'A Ilha da Fantasia (1978) S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/184046.mp4', 'http://timg.bdta.pro/images/269f8286d4e3ad26b13f8d854c0d19cc.jpg'),
(86165, 5973, 'A Ilha da Fantasia (1978) S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/184047.mp4', 'http://timg.bdta.pro/images/64ce7102c2460d7c6c1f28a40e039dac.jpg'),
(86166, 5973, 'A Ilha da Fantasia (1978) S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/184048.mp4', 'http://timg.bdta.pro/images/de4909ff5cecadff4678a4192dd5f617.jpg'),
(86167, 5973, 'A Ilha da Fantasia (1978) S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/184049.mp4', 'http://timg.bdta.pro/images/aad8f2d65c0594b6dc638de96e119593.jpg'),
(86168, 5973, 'A Ilha da Fantasia (1978) S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/184050.mp4', 'http://timg.bdta.pro/images/2a501f817208754d4c94d79cb796b6c9.jpg'),
(86169, 5973, 'A Ilha da Fantasia (1978) S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/184051.mp4', 'http://timg.bdta.pro/images/ed79652426e6dae4db0b8e545c48070e.jpg'),
(86170, 5973, 'A Ilha da Fantasia (1978) S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/184052.mp4', 'http://timg.bdta.pro/images/04550b9c78a8b559fe549ed0685d22a7.jpg'),
(86171, 5973, 'A Ilha da Fantasia (1978) S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/184053.mp4', 'http://timg.bdta.pro/images/297f4559832f682cd941f318e1d62ea1.jpg'),
(86172, 5973, 'A Ilha da Fantasia (1978) S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/184054.mp4', 'http://timg.bdta.pro/images/85289030734dbcbb159985483e3d419d.jpg'),
(86173, 5973, 'A Ilha da Fantasia (1978) S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/184055.mp4', 'http://timg.bdta.pro/images/84b7ab1d4fe061992ce55c707bdd4c91.jpg'),
(86174, 5973, 'A Ilha da Fantasia (1978) S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/184056.mp4', 'http://timg.bdta.pro/images/6675117b0c60f34248d9ab07447ec3ba.jpg'),
(86175, 5973, 'A Ilha da Fantasia (1978) S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/184057.mp4', 'http://timg.bdta.pro/images/b9d62958283d2edc65026ff98f3003ff.jpg'),
(86176, 5973, 'A Ilha da Fantasia (1978) S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/184058.mp4', 'http://timg.bdta.pro/images/8ca51b8e79b74d39de56fb99c23a0a8d.jpg'),
(86177, 5973, 'A Ilha da Fantasia (1978) S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/184059.mp4', 'http://timg.bdta.pro/images/2f81f1fd9cf11cb1530a4427167e3687.jpg'),
(86178, 5973, 'A Ilha da Fantasia (1978) S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/184060.mp4', 'http://timg.bdta.pro/images/9f709282cb0be5c190c4a4352d48bdb7.jpg'),
(86179, 5973, 'A Ilha da Fantasia (1978) S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/184061.mp4', 'http://timg.bdta.pro/images/53b3d71ffe98fea0c1f81446d039dbe1.jpg'),
(86180, 5973, 'A Ilha da Fantasia (1978) S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/184062.mp4', 'http://timg.bdta.pro/images/c7e65ac7cd83766292f8fe275451c469.jpg'),
(86181, 5973, 'A Ilha da Fantasia (1978) S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/184063.mp4', 'http://timg.bdta.pro/images/2e33c893937d8ca82ba4f4b6684658c2.jpg'),
(86182, 5973, 'A Ilha da Fantasia (1978) S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/184064.mp4', 'http://timg.bdta.pro/images/5ceb27a8ca0121fd34928f2fa910d1cb.jpg'),
(86183, 5973, 'A Ilha da Fantasia (1978) S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/184065.mp4', 'http://timg.bdta.pro/images/c4e5f93804987a8e62b10e8a9ae483df.jpg'),
(86184, 5974, 'A Ilha da Fantasia (1978) S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/184066.mp4', 'http://timg.bdta.pro/images/4b056ab371521ae7649f8da560ed4fdc.jpg'),
(86185, 5974, 'A Ilha da Fantasia (1978) S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/184067.mp4', 'http://timg.bdta.pro/images/4244d5b8b08f4d0e80ad1ad2f0347250.jpg'),
(86186, 5974, 'A Ilha da Fantasia (1978) S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/184068.mp4', 'http://timg.bdta.pro/images/8311bdab3a6af027968f522cbf279891.jpg'),
(86187, 5974, 'A Ilha da Fantasia (1978) S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/184069.mp4', 'http://timg.bdta.pro/images/585b8eca928d4918e28163da34e32bd4.jpg'),
(86188, 5974, 'A Ilha da Fantasia (1978) S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/184070.mp4', 'http://timg.bdta.pro/images/9b9593d7517710de2e645262541545b1.jpg'),
(86189, 5974, 'A Ilha da Fantasia (1978) S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/184071.mp4', 'http://timg.bdta.pro/images/2b51897968cc75cadac59c21749845b8.jpg'),
(86190, 5974, 'A Ilha da Fantasia (1978) S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/184072.mp4', 'http://timg.bdta.pro/images/c65660050921864daa6fb39c69889320.jpg'),
(86191, 5974, 'A Ilha da Fantasia (1978) S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/184073.mp4', 'http://timg.bdta.pro/images/e2a0f72acb154341854ac2412fec97e7.jpg'),
(86192, 5974, 'A Ilha da Fantasia (1978) S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/184074.mp4', 'http://timg.bdta.pro/images/0b317a57719dc1eda770b0f5b705f31a.jpg'),
(86193, 5974, 'A Ilha da Fantasia (1978) S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/184075.mp4', 'http://timg.bdta.pro/images/9f8e86a5d2282ee0dbc70507330a5d47.jpg'),
(86194, 5974, 'A Ilha da Fantasia (1978) S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/184076.mp4', 'http://timg.bdta.pro/images/a24fdf12d637c6591009bbf76c6b76f7.jpg'),
(86195, 5974, 'A Ilha da Fantasia (1978) S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/184077.mp4', 'http://timg.bdta.pro/images/68d78f319ec66c9692fbd49ee5bcfbd0.jpg'),
(86196, 5974, 'A Ilha da Fantasia (1978) S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/184078.mp4', 'http://timg.bdta.pro/images/8fc53a2f1bb5bee583f738c5b5752abc.jpg'),
(86197, 5974, 'A Ilha da Fantasia (1978) S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/184079.mp4', 'http://timg.bdta.pro/images/425038113ed4d3b3af0dd06bdfefefdc.jpg'),
(86198, 5974, 'A Ilha da Fantasia (1978) S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/184080.mp4', 'http://timg.bdta.pro/images/1f43b795f1bdd0a72614ca2d3dfa399d.jpg'),
(86199, 5974, 'A Ilha da Fantasia (1978) S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/184081.mp4', 'http://timg.bdta.pro/images/a6ceb5661ca9f7be2cd49eb8ac977161.jpg'),
(86200, 5974, 'A Ilha da Fantasia (1978) S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/184082.mp4', 'http://timg.bdta.pro/images/9511504072a4c598f76647811588c6e6.jpg'),
(86201, 5974, 'A Ilha da Fantasia (1978) S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/184083.mp4', 'http://timg.bdta.pro/images/e4718ba26a75e0e7efaea3c1c96b4433.jpg'),
(86202, 5974, 'A Ilha da Fantasia (1978) S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/184084.mp4', 'http://timg.bdta.pro/images/5825be530ad0ede6424b053dd279c58d.jpg'),
(86203, 5974, 'A Ilha da Fantasia (1978) S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/184085.mp4', 'http://timg.bdta.pro/images/02d892d7a534c6f522fd39292b416f81.jpg'),
(86204, 5974, 'A Ilha da Fantasia (1978) S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/184086.mp4', 'http://timg.bdta.pro/images/3e269c10e7facc1673b70cc1b181adf0.jpg'),
(86205, 5974, 'A Ilha da Fantasia (1978) S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/184087.mp4', 'http://timg.bdta.pro/images/7aebe766ce8f1d9329b2714c8c93a979.jpg'),
(86206, 5975, 'A Mulher do Viajante no Tempo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183954.mp4', 'http://timg.bdta.pro/images/5fa8235cf2a9e43dcea8c4cddcce6a57.jpg'),
(86207, 5975, 'A Mulher do Viajante no Tempo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183955.mp4', 'http://timg.bdta.pro/images/b36c8694140dc3b4ed04d5bc3e1db7e2.jpg'),
(86208, 5975, 'A Mulher do Viajante no Tempo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183956.mp4', 'http://timg.bdta.pro/images/6586cc25e84d8e54ccd33c64ba6431f9.jpg'),
(86209, 5975, 'A Mulher do Viajante no Tempo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183957.mp4', 'http://timg.bdta.pro/images/c9826d9c953fbc8e9d32f1aff638a612.jpg'),
(86210, 5975, 'A Mulher do Viajante no Tempo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183958.mp4', 'http://timg.bdta.pro/images/a3af68cfdafa2f67ebadafadc2ee658c.jpg'),
(86211, 5975, 'A Mulher do Viajante no Tempo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183959.mp4', 'http://timg.bdta.pro/images/2406c2a4df511f37cc786f18597f3114.jpg'),
(86212, 5976, 'A Ponte: The Bridge Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183946.mp4', 'http://timg.bdta.pro/images/2e6d155c807079e211610eee9d5029df.jpg'),
(86213, 5976, 'A Ponte: The Bridge Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183947.mp4', 'http://timg.bdta.pro/images/0cd5ba35142521808c6151ddf0fe0e2f.jpg'),
(86214, 5976, 'A Ponte: The Bridge Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183948.mp4', 'http://timg.bdta.pro/images/29ab5b8a3b2e6527f2b9cf6a9ceaea45.jpg'),
(86215, 5976, 'A Ponte: The Bridge Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183949.mp4', 'http://timg.bdta.pro/images/e89196a9c4091c2b27dd3884d099f4b1.jpg'),
(86216, 5976, 'A Ponte: The Bridge Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183950.mp4', 'http://timg.bdta.pro/images/dd125fd5fd22ab3152f97ddd2f6be62f.jpg'),
(86217, 5976, 'A Ponte: The Bridge Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183951.mp4', 'http://timg.bdta.pro/images/4e0278acdeec4863f85bec7b24a2676c.jpg'),
(86218, 5976, 'A Ponte: The Bridge Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183952.mp4', 'http://timg.bdta.pro/images/38deabc078cb8ffba0666813546971a4.jpg'),
(86219, 5976, 'A Ponte: The Bridge Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183953.mp4', 'http://timg.bdta.pro/images/677a6759bb673834b9448008129b3dd8.jpg'),
(86220, 5977, 'Amazing Grace S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183938.mp4', 'http://timg.bdta.pro/images/2a7000f64a76ee133e129a2e501a219f.jpg'),
(86221, 5977, 'Amazing Grace S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183939.mp4', 'http://timg.bdta.pro/images/70b70fc9d864657270dcd34d8553062f.jpg'),
(86222, 5977, 'Amazing Grace S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183940.mp4', 'http://timg.bdta.pro/images/bb83f6e8ebf156bd1366f10f57573fa3.jpg'),
(86223, 5977, 'Amazing Grace S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183941.mp4', 'http://gstaticontent.com/images/cacc2d85ae9a0f50d36cd0c14cc25128.jpg'),
(86224, 5977, 'Amazing Grace S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183942.mp4', 'http://gstaticontent.com/images/cacc2d85ae9a0f50d36cd0c14cc25128.jpg'),
(86225, 5977, 'Amazing Grace S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183943.mp4', 'http://gstaticontent.com/images/cacc2d85ae9a0f50d36cd0c14cc25128.jpg'),
(86226, 5977, 'Amazing Grace S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183944.mp4', 'http://gstaticontent.com/images/cacc2d85ae9a0f50d36cd0c14cc25128.jpg'),
(86227, 5977, 'Amazing Grace S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183945.mp4', 'http://gstaticontent.com/images/cacc2d85ae9a0f50d36cd0c14cc25128.jpg'),
(86228, 5978, 'Amor na Selva S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183931.mp4', 'http://timg.bdta.pro/images/8231b19b0e118a2f0899df2ea4035600.jpg'),
(86229, 5978, 'Amor na Selva S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183932.mp4', 'http://timg.bdta.pro/images/ece568e9f9c8d0e9ac54bd6cb7a1abe6.jpg'),
(86230, 5978, 'Amor na Selva S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183933.mp4', 'http://timg.bdta.pro/images/8ce578fffc2ea2997b391bac353c7aab.jpg'),
(86231, 5978, 'Amor na Selva S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183934.mp4', 'http://timg.bdta.pro/images/37d9983ff3fe871cf717c533564571b0.jpg'),
(86232, 5978, 'Amor na Selva S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183935.mp4', 'http://timg.bdta.pro/images/b132ad8f2b49a4673023c4057886837c.jpg'),
(86233, 5978, 'Amor na Selva S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183936.mp4', 'http://timg.bdta.pro/images/cf3b8064cadb644f3d9ce9a10dd05dea.jpg'),
(86234, 5978, 'Amor na Selva S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183937.mp4', 'http://gstaticontent.com/images/751a526470551cf392d3888c96c64a3e.jpg'),
(86235, 5979, 'Chloe S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183925.mp4', 'http://timg.bdta.pro/images/297856eaf074e7a07ef0f2c0a6068623.jpg'),
(86236, 5979, 'Chloe S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183926.mp4', 'http://timg.bdta.pro/images/9fd94049c773c97a772552b456a97724.jpg'),
(86237, 5979, 'Chloe S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183927.mp4', 'http://timg.bdta.pro/images/8e8a72ac83fad757fcf5f793cf1d4cb3.jpg'),
(86238, 5979, 'Chloe S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183928.mp4', 'http://timg.bdta.pro/images/1873df0cb0bc0baa939547f84664035e.jpg'),
(86239, 5979, 'Chloe S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183929.mp4', 'http://timg.bdta.pro/images/5d0f3586e18bc7432711e0ddbc2a41ef.jpg'),
(86240, 5979, 'Chloe S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183930.mp4', 'http://timg.bdta.pro/images/a626ac2eac84178ac355799919b242a8.jpg'),
(86241, 5980, 'Família Gil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHvrIikxLHxgKN67JHOLRGeDEY7.jpg'),
(86242, 5980, 'Família Gil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHvrIikxLHxgKN67JHOLRGeDEY7.jpg'),
(86243, 5980, 'Família Gil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHvrIikxLHxgKN67JHOLRGeDEY7.jpg'),
(86244, 5980, 'Família Gil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHvrIikxLHxgKN67JHOLRGeDEY7.jpg'),
(86245, 5980, 'Família Gil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHvrIikxLHxgKN67JHOLRGeDEY7.jpg'),
(86246, 5981, 'Família Gil S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHvrIikxLHxgKN67JHOLRGeDEY7.jpg'),
(86247, 5981, 'Família Gil S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHvrIikxLHxgKN67JHOLRGeDEY7.jpg'),
(86248, 5981, 'Família Gil S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHvrIikxLHxgKN67JHOLRGeDEY7.jpg'),
(86249, 5981, 'Família Gil S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHvrIikxLHxgKN67JHOLRGeDEY7.jpg'),
(86250, 5981, 'Família Gil S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHvrIikxLHxgKN67JHOLRGeDEY7.jpg'),
(86251, 5981, 'Família Gil S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHvrIikxLHxgKN67JHOLRGeDEY7.jpg'),
(86252, 5982, 'Geração Z no Perrengue S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183914.mp4', 'http://gstaticontent.com/images/b938afefb8870f33a02f90e1a8241b81.jpg'),
(86253, 5982, 'Geração Z no Perrengue S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183915.mp4', 'http://gstaticontent.com/images/b938afefb8870f33a02f90e1a8241b81.jpg'),
(86254, 5982, 'Geração Z no Perrengue S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183916.mp4', 'http://gstaticontent.com/images/b938afefb8870f33a02f90e1a8241b81.jpg'),
(86255, 5982, 'Geração Z no Perrengue S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183917.mp4', 'http://gstaticontent.com/images/b938afefb8870f33a02f90e1a8241b81.jpg'),
(86256, 5982, 'Geração Z no Perrengue S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183918.mp4', 'http://gstaticontent.com/images/b938afefb8870f33a02f90e1a8241b81.jpg'),
(86257, 5982, 'Geração Z no Perrengue S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183919.mp4', 'http://gstaticontent.com/images/b938afefb8870f33a02f90e1a8241b81.jpg'),
(86258, 5982, 'Geração Z no Perrengue S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183920.mp4', 'http://gstaticontent.com/images/b938afefb8870f33a02f90e1a8241b81.jpg'),
(86259, 5982, 'Geração Z no Perrengue S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183921.mp4', 'http://gstaticontent.com/images/b938afefb8870f33a02f90e1a8241b81.jpg'),
(86260, 5983, 'Iron Chef: Em Busca de uma Lenda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183906.mp4', 'http://gstaticontent.com/images/9cdbb0a75dc08bcdb10a912e25a47d99.jpg'),
(86261, 5983, 'Iron Chef: Em Busca de uma Lenda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183907.mp4', 'http://gstaticontent.com/images/9cdbb0a75dc08bcdb10a912e25a47d99.jpg'),
(86262, 5983, 'Iron Chef: Em Busca de uma Lenda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183908.mp4', 'http://gstaticontent.com/images/9cdbb0a75dc08bcdb10a912e25a47d99.jpg'),
(86263, 5983, 'Iron Chef: Em Busca de uma Lenda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183909.mp4', 'http://gstaticontent.com/images/9cdbb0a75dc08bcdb10a912e25a47d99.jpg'),
(86264, 5983, 'Iron Chef: Em Busca de uma Lenda S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183910.mp4', 'http://gstaticontent.com/images/9cdbb0a75dc08bcdb10a912e25a47d99.jpg'),
(86265, 5983, 'Iron Chef: Em Busca de uma Lenda S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183911.mp4', 'http://gstaticontent.com/images/9cdbb0a75dc08bcdb10a912e25a47d99.jpg'),
(86266, 5983, 'Iron Chef: Em Busca de uma Lenda S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183912.mp4', 'http://gstaticontent.com/images/9cdbb0a75dc08bcdb10a912e25a47d99.jpg'),
(86267, 5983, 'Iron Chef: Em Busca de uma Lenda S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183913.mp4', 'http://gstaticontent.com/images/9cdbb0a75dc08bcdb10a912e25a47d99.jpg'),
(86268, 5984, 'Joao Rock (2022) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183899.mp4', 'http://gstaticontent.com/images/1c125a2cc93df0a46e7f6ca767d33d11.png'),
(86269, 5984, 'Joao Rock (2022) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183900.mp4', 'http://gstaticontent.com/images/1c125a2cc93df0a46e7f6ca767d33d11.png'),
(86270, 5984, 'Joao Rock (2022) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183901.mp4', 'http://gstaticontent.com/images/1c125a2cc93df0a46e7f6ca767d33d11.png'),
(86271, 5984, 'Joao Rock (2022) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183902.mp4', 'http://gstaticontent.com/images/1c125a2cc93df0a46e7f6ca767d33d11.png'),
(86272, 5984, 'Joao Rock (2022) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183903.mp4', 'http://gstaticontent.com/images/1c125a2cc93df0a46e7f6ca767d33d11.png'),
(86273, 5984, 'Joao Rock (2022) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183904.mp4', 'http://gstaticontent.com/images/1c125a2cc93df0a46e7f6ca767d33d11.png'),
(86274, 5984, 'Joao Rock (2022) S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183905.mp4', 'http://gstaticontent.com/images/1c125a2cc93df0a46e7f6ca767d33d11.png'),
(86275, 5985, 'La Casa de Papel: Coreia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203980.mp4', 'http://timg.bdta.pro/images/c17159614037b06820dd6fff4e12edc2.jpg'),
(86276, 5985, 'La Casa de Papel: Coreia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203981.mp4', 'http://timg.bdta.pro/images/07346fb149195a5a5242ceff0bf96165.jpg'),
(86277, 5985, 'La Casa de Papel: Coreia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203982.mp4', 'http://timg.bdta.pro/images/e8f7d7a53788c16a0dd375a4b801d98c.jpg'),
(86278, 5985, 'La Casa de Papel: Coreia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203983.mp4', 'http://timg.bdta.pro/images/57f2afd65b7038c18d1c1a1a169d0e0e.jpg'),
(86279, 5985, 'La Casa de Papel: Coreia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203984.mp4', 'http://timg.bdta.pro/images/c6c36db8aa5cdebd562c01ad85e7e4fe.jpg'),
(86280, 5985, 'La Casa de Papel: Coreia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203985.mp4', 'http://timg.bdta.pro/images/a5f5e75e50e73ec5c9d836a7927a05f3.jpg'),
(86281, 5985, 'La Casa de Papel: Coreia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ASJ3uxiDTeSY69CcCkUmWqwlON.jpg'),
(86282, 5985, 'La Casa de Papel: Coreia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xBJKNy84p75EP6Z76b1ST68o9rU.jpg'),
(86283, 5985, 'La Casa de Papel: Coreia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pDUZ0H3QAtpvNUGn6hdPXkCUTNE.jpg'),
(86284, 5985, 'La Casa de Papel: Coreia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mC6MrvMe6nSdDOBCUUtVipUWzXS.jpg'),
(86285, 5985, 'La Casa de Papel: Coreia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVJQkJyAVMpU4kSza7yHzhNTtEF.jpg'),
(86286, 5985, 'La Casa de Papel: Coreia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tAHbXTJNYZOAPGrQErNVii4w3Vn.jpg'),
(86287, 5986, 'Landscapers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183895.mp4', 'http://timg.bdta.pro/images/034eb7b810ee327600ceaf2ca9239627.jpg'),
(86288, 5986, 'Landscapers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183896.mp4', 'http://timg.bdta.pro/images/814712964c2c6c159886150c8ca162e6.jpg'),
(86289, 5986, 'Landscapers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183897.mp4', 'http://timg.bdta.pro/images/f7918c5a5b58de89ac226ad391c99642.jpg'),
(86290, 5986, 'Landscapers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183898.mp4', 'http://timg.bdta.pro/images/d0f70033df4196178e2892655fd7a568.jpg'),
(86291, 5987, 'Pinky e o Cérebro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193862.mp4', 'http://timg.bdta.pro/images/948d049ff774e582999356fbd5ce445e.jpg'),
(86292, 5987, 'Pinky e o Cérebro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193863.mp4', 'http://timg.bdta.pro/images/2f49091d2eba64f89527f570820a5274.jpg'),
(86293, 5987, 'Pinky e o Cérebro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193864.mp4', 'http://timg.bdta.pro/images/77aab20247dd554268e159001de683af.jpg'),
(86294, 5987, 'Pinky e o Cérebro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193865.mp4', 'http://timg.bdta.pro/images/09145dd9fa4870968f8fd2d74c0196a9.jpg'),
(86295, 5987, 'Pinky e o Cérebro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193866.mp4', 'http://timg.bdta.pro/images/ffa3faa2c585607fa457e1ee546901c3.jpg'),
(86296, 5987, 'Pinky e o Cérebro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193867.mp4', 'http://timg.bdta.pro/images/b3469d2a2dc5cbc2f5a45f38d4336692.jpg'),
(86297, 5987, 'Pinky e o Cérebro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193868.mp4', 'http://timg.bdta.pro/images/003641fe3f866574d823a372fe60d779.jpg'),
(86298, 5987, 'Pinky e o Cérebro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193869.mp4', 'http://timg.bdta.pro/images/13e7e4973c4c2c05d3bf56f1212354bd.jpg'),
(86299, 5987, 'Pinky e o Cérebro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193870.mp4', 'http://timg.bdta.pro/images/862c99b597041612d3cc54355adc64c6.jpg'),
(86300, 5987, 'Pinky e o Cérebro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193871.mp4', 'http://timg.bdta.pro/images/770a9cd0b39e1efa2b6578b13b51c28a.jpg'),
(86301, 5987, 'Pinky e o Cérebro S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193872.mp4', 'http://timg.bdta.pro/images/dbb0eb6b05bed7f49514fa41faf09a1c.jpg'),
(86302, 5987, 'Pinky e o Cérebro S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193873.mp4', 'http://timg.bdta.pro/images/94714f7cf41268ada4d0f57320ab52f6.jpg'),
(86303, 5987, 'Pinky e o Cérebro S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193874.mp4', 'http://timg.bdta.pro/images/128d2d14b5cd3c5301cc5cc9e46c2696.jpg'),
(86304, 5988, 'Pinky e o Cérebro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193875.mp4', 'http://timg.bdta.pro/images/d01d9da80da62d9879413ca3601e1aa7.jpg'),
(86305, 5988, 'Pinky e o Cérebro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193876.mp4', 'http://timg.bdta.pro/images/7219280e36a68cd1a3c4c316ce4a9f07.jpg'),
(86306, 5988, 'Pinky e o Cérebro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193877.mp4', 'http://timg.bdta.pro/images/eaa1fdd6f03e7956481a97ace5eb5cf2.jpg'),
(86307, 5988, 'Pinky e o Cérebro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193878.mp4', 'http://timg.bdta.pro/images/7a9e3639c61bdb8a00cc3ceff198ac28.jpg'),
(86308, 5988, 'Pinky e o Cérebro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193879.mp4', 'http://timg.bdta.pro/images/f15456c5b3a4fefb4c20f6761982a396.jpg'),
(86309, 5988, 'Pinky e o Cérebro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193880.mp4', 'http://timg.bdta.pro/images/c2d24b3a79e42b280113f8e703870e38.jpg'),
(86310, 5988, 'Pinky e o Cérebro S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193881.mp4', 'http://timg.bdta.pro/images/387d7b72357e609f7c6233032c8c7a9f.jpg'),
(86311, 5988, 'Pinky e o Cérebro S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193882.mp4', 'http://timg.bdta.pro/images/482ae3592f8951eed41414b5bf73c992.jpg'),
(86312, 5988, 'Pinky e o Cérebro S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193883.mp4', 'http://timg.bdta.pro/images/b7f6f283df06281ebb56d4c2a52e1d53.jpg'),
(86313, 5988, 'Pinky e o Cérebro S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193884.mp4', 'http://timg.bdta.pro/images/c33201e0d618d4b700d1568c9b439bae.jpg'),
(86314, 5988, 'Pinky e o Cérebro S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193885.mp4', 'http://timg.bdta.pro/images/c76dbe594048c64afcd7db664f7d78c4.jpg'),
(86315, 5988, 'Pinky e o Cérebro S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193886.mp4', 'http://timg.bdta.pro/images/4fc3c26e702dcdf807ab0ba2325e8996.jpg'),
(86316, 5989, 'Pinky e o Cérebro S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193887.mp4', 'http://timg.bdta.pro/images/094249e92c4e2bcbed7f6e77bbdde39c.jpg'),
(86317, 5989, 'Pinky e o Cérebro S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193888.mp4', 'http://timg.bdta.pro/images/fee49893c97d76c9b3f21c01eb116614.jpg'),
(86318, 5989, 'Pinky e o Cérebro S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193889.mp4', 'http://timg.bdta.pro/images/3557dfbebd06cac168efaf432deafc20.jpg'),
(86319, 5989, 'Pinky e o Cérebro S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193890.mp4', 'http://timg.bdta.pro/images/317050de5b50cca45c8c419fd95495f9.jpg'),
(86320, 5989, 'Pinky e o Cérebro S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193891.mp4', 'http://timg.bdta.pro/images/3d72b5fa957e24016cf5a8825e80e77e.jpg'),
(86321, 5989, 'Pinky e o Cérebro S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193892.mp4', 'http://timg.bdta.pro/images/a9805aefc60e3025f8e44ef44a6d94b3.jpg'),
(86322, 5989, 'Pinky e o Cérebro S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193893.mp4', 'http://timg.bdta.pro/images/a4d24d606e2ebf43ea4ae52c1478bbd3.jpg'),
(86323, 5989, 'Pinky e o Cérebro S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/193894.mp4', 'http://timg.bdta.pro/images/bee35315c423bf26354e82399e9a1a36.jpg'),
(86324, 5989, 'Pinky e o Cérebro S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/193895.mp4', 'http://timg.bdta.pro/images/cf35ff4a1f6a33b1a94e3166a5504f84.jpg'),
(86325, 5989, 'Pinky e o Cérebro S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/193896.mp4', 'http://timg.bdta.pro/images/dc4523b877bc1a75d85979716e5ed76b.jpg'),
(86326, 5989, 'Pinky e o Cérebro S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/193897.mp4', 'http://timg.bdta.pro/images/6717c33e274696242e2b6ab0b1d55cae.jpg'),
(86327, 5989, 'Pinky e o Cérebro S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/193898.mp4', 'http://timg.bdta.pro/images/40df83dd2e222d4969f6ed1183f4b040.jpg'),
(86328, 5989, 'Pinky e o Cérebro S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/193899.mp4', 'http://timg.bdta.pro/images/980c9ae18cb306df4f1666d4c55b95dc.jpg'),
(86329, 5989, 'Pinky e o Cérebro S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/193900.mp4', 'http://timg.bdta.pro/images/94e98ec85406a4b0b60116bbccad18bb.jpg'),
(86330, 5989, 'Pinky e o Cérebro S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/193901.mp4', 'http://timg.bdta.pro/images/5873b15e882eb4c6c4fb2a13c74089c2.jpg'),
(86331, 5989, 'Pinky e o Cérebro S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/193902.mp4', 'http://timg.bdta.pro/images/6cb9495ea96c9cbe2f7c393c7cc301fb.jpg'),
(86332, 5989, 'Pinky e o Cérebro S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/193903.mp4', 'http://timg.bdta.pro/images/abcdb307cf49bd90427413784a3349f9.jpg'),
(86333, 5989, 'Pinky e o Cérebro S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/193904.mp4', 'http://timg.bdta.pro/images/6611715f7cd310435909b8e83e512585.jpg'),
(86334, 5989, 'Pinky e o Cérebro S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/193905.mp4', 'http://timg.bdta.pro/images/df06dd138c95e60a6aa3f9a46c3f6e20.jpg'),
(86335, 5989, 'Pinky e o Cérebro S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/193906.mp4', 'http://timg.bdta.pro/images/576fb628330faed2850dfa31d6f88d81.jpg'),
(86336, 5989, 'Pinky e o Cérebro S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/193907.mp4', 'http://timg.bdta.pro/images/326ade3157781660cdd0eb0fe1acca2c.jpg'),
(86337, 5989, 'Pinky e o Cérebro S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/193908.mp4', 'http://timg.bdta.pro/images/bc94b306690c2409f55823077729cc16.jpg'),
(86338, 5989, 'Pinky e o Cérebro S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/193909.mp4', 'http://timg.bdta.pro/images/51576d46be56640858aea5d89c83d1ed.jpg'),
(86339, 5989, 'Pinky e o Cérebro S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/193910.mp4', 'http://timg.bdta.pro/images/916879352d456b5843da79ebc4bb3c75.jpg'),
(86340, 5989, 'Pinky e o Cérebro S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/193911.mp4', 'http://timg.bdta.pro/images/67d4286a54bbe61dd12b42f74980471f.jpg'),
(86341, 5989, 'Pinky e o Cérebro S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/193912.mp4', 'http://timg.bdta.pro/images/6ede11c8bf09bdd034e7aa8cf405276e.jpg'),
(86342, 5989, 'Pinky e o Cérebro S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/193913.mp4', 'http://timg.bdta.pro/images/9c824bc0a0fdd1e0a64e8935a4d6121b.jpg'),
(86343, 5989, 'Pinky e o Cérebro S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/193914.mp4', 'http://timg.bdta.pro/images/9c824bc0a0fdd1e0a64e8935a4d6121b.jpg'),
(86344, 5989, 'Pinky e o Cérebro S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/193915.mp4', 'http://timg.bdta.pro/images/2847ee14c5ecc1aa88085a81ca6ad3e6.jpg'),
(86345, 5989, 'Pinky e o Cérebro S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/193916.mp4', 'http://timg.bdta.pro/images/38c404ec0aeff5d4bbb9a762cf6e8eb8.jpg'),
(86346, 5989, 'Pinky e o Cérebro S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/193917.mp4', 'http://timg.bdta.pro/images/38c404ec0aeff5d4bbb9a762cf6e8eb8.jpg'),
(86347, 5989, 'Pinky e o Cérebro S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/193918.mp4', 'http://timg.bdta.pro/images/0d9717ef2952556eb5db766adb10647b.jpg'),
(86348, 5989, 'Pinky e o Cérebro S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/193919.mp4', 'http://timg.bdta.pro/images/0d9717ef2952556eb5db766adb10647b.jpg'),
(86349, 5990, 'Pinky e o Cérebro S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/193920.mp4', 'http://timg.bdta.pro/images/7b16f7d4aa0480bf5abdd1f67ab0b6e7.jpg'),
(86350, 5990, 'Pinky e o Cérebro S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/193921.mp4', 'http://timg.bdta.pro/images/8daf6304afff1cbb1bd5f44656d19234.jpg'),
(86351, 5990, 'Pinky e o Cérebro S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/193922.mp4', 'http://timg.bdta.pro/images/5c241201d256f17329d37446db22c086.jpg'),
(86352, 5990, 'Pinky e o Cérebro S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/193923.mp4', 'http://timg.bdta.pro/images/c27b2115f173f0de9b9b689b499dd377.jpg'),
(86353, 5990, 'Pinky e o Cérebro S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/193924.mp4', 'http://timg.bdta.pro/images/c27b2115f173f0de9b9b689b499dd377.jpg'),
(86354, 5990, 'Pinky e o Cérebro S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/193925.mp4', 'http://timg.bdta.pro/images/87da4a6910ca737995008343553b5939.jpg'),
(86355, 5990, 'Pinky e o Cérebro S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/193926.mp4', 'http://timg.bdta.pro/images/730c657aff74a98030af9b6e431cb493.jpg'),
(86356, 5991, 'Risco Iminente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183889.mp4', 'http://timg.bdta.pro/images/d260a8d75c5cc20def4ef119d3d8cc74.jpg'),
(86357, 5991, 'Risco Iminente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183890.mp4', 'http://timg.bdta.pro/images/3dea7933841b10388e53453ce42831e4.jpg'),
(86358, 5991, 'Risco Iminente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183891.mp4', 'http://timg.bdta.pro/images/795d80ea5fb1fc9cb1c3795004851f43.jpg'),
(86359, 5991, 'Risco Iminente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183892.mp4', 'http://timg.bdta.pro/images/5cde48ba192c927757f87a87049d1510.jpg'),
(86360, 5991, 'Risco Iminente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183893.mp4', 'http://timg.bdta.pro/images/9b550f7ae15487e979a14f3a35b34674.jpg'),
(86361, 5991, 'Risco Iminente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183894.mp4', 'http://gstaticontent.com/images/a252b86ee5055374b7076d79490e1750.jpg'),
(86362, 5992, 'Ritmo + Flow: França S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183881.mp4', 'http://timg.bdta.pro/images/1f93411b3b03f16d3b27c75d90d51bd1.jpg'),
(86363, 5992, 'Ritmo + Flow: França S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183882.mp4', 'http://timg.bdta.pro/images/f7f0feae8e403a4e13442fff87337fd5.jpg'),
(86364, 5992, 'Ritmo + Flow: França S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183883.mp4', 'http://timg.bdta.pro/images/7ed5c7d840b6c3f7929efe511cefd127.jpg'),
(86365, 5992, 'Ritmo + Flow: França S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183884.mp4', 'http://timg.bdta.pro/images/0e98a581f3cd2321eb70af8b6770c023.jpg'),
(86366, 5992, 'Ritmo + Flow: França S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183885.mp4', 'http://timg.bdta.pro/images/d90a2487e0414181a446e0d826bbcf8d.jpg'),
(86367, 5992, 'Ritmo + Flow: França S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183886.mp4', 'http://timg.bdta.pro/images/8ab89891cc342f01a0d174ddbc671afc.jpg'),
(86368, 5992, 'Ritmo + Flow: França S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183887.mp4', 'http://timg.bdta.pro/images/94adc55a828d8bdf44dc65a26ff1c2f4.jpg'),
(86369, 5992, 'Ritmo + Flow: França S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183888.mp4', 'http://timg.bdta.pro/images/cb392ec16cd1a6fda06e65bff9b2aafc.jpg'),
(86370, 5993, 'Entre Lobos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kXnLyY8ggBsfPyvoSb54fCpvZbm.jpg'),
(86371, 5993, 'Entre Lobos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kXnLyY8ggBsfPyvoSb54fCpvZbm.jpg'),
(86372, 5993, 'Entre Lobos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kXnLyY8ggBsfPyvoSb54fCpvZbm.jpg'),
(86373, 5994, 'Faking It S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183721.mp4', 'http://timg.bdta.pro/images/418e90ec449dedce48486b86d6398e5e.jpg'),
(86374, 5994, 'Faking It S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183722.mp4', 'http://timg.bdta.pro/images/589605496413f32caa773b76479f6e49.jpg'),
(86375, 5994, 'Faking It S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183723.mp4', 'http://timg.bdta.pro/images/d44140c2159848cc029a9702cb02e51a.jpg'),
(86376, 5994, 'Faking It S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183724.mp4', 'http://timg.bdta.pro/images/b71e78fcf684024688f0b730805ab410.jpg'),
(86377, 5994, 'Faking It S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183725.mp4', 'http://timg.bdta.pro/images/09aeddb381df0a5ae2fcec564969a7b3.jpg'),
(86378, 5994, 'Faking It S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183726.mp4', 'http://timg.bdta.pro/images/4082fbd995b888a3c07811a2bebe73de.jpg'),
(86379, 5994, 'Faking It S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183727.mp4', 'http://timg.bdta.pro/images/42773c595f9648c1e8c67fde43694c68.jpg'),
(86380, 5994, 'Faking It S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183728.mp4', 'http://timg.bdta.pro/images/3cc065778c9740fabb6393ac88db1f04.jpg'),
(86381, 5995, 'Faking It S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183729.mp4', 'http://timg.bdta.pro/images/661cb734df94a0e6779fa3509c1fc5aa.jpg'),
(86382, 5995, 'Faking It S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183730.mp4', 'http://timg.bdta.pro/images/6382023e673b281b6878a39b76123fc8.jpg'),
(86383, 5995, 'Faking It S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183731.mp4', 'http://timg.bdta.pro/images/1bd3fcbaf5a00f2686963a5a56eadd42.jpg'),
(86384, 5995, 'Faking It S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183732.mp4', 'http://timg.bdta.pro/images/a3d1a4d6cd827b05acc03ce8997e096e.jpg'),
(86385, 5995, 'Faking It S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183733.mp4', 'http://timg.bdta.pro/images/f9de45e7af9eadd49cb38e26c7fe6070.jpg'),
(86386, 5995, 'Faking It S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183734.mp4', 'http://timg.bdta.pro/images/ecccb4d83a6e71ece77693aabfe0f78b.jpg'),
(86387, 5995, 'Faking It S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183735.mp4', 'http://timg.bdta.pro/images/a43231901980fbf66e40cf0d64f905a8.jpg'),
(86388, 5995, 'Faking It S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183736.mp4', 'http://timg.bdta.pro/images/f91153f64afb2c445e9a220b55a8094a.jpg'),
(86389, 5995, 'Faking It S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183737.mp4', 'http://timg.bdta.pro/images/ab65801d03bef75be96e6e02f3c7252f.jpg'),
(86390, 5995, 'Faking It S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183738.mp4', 'http://timg.bdta.pro/images/89675e8fe30b621d1a1d3587466db2e0.jpg'),
(86391, 5995, 'Faking It S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183739.mp4', 'http://timg.bdta.pro/images/6827286b90c47ddf4fd8242513716721.jpg'),
(86392, 5995, 'Faking It S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183740.mp4', 'http://timg.bdta.pro/images/843737c2d6f3fb6355a7ed464e192d22.jpg'),
(86393, 5995, 'Faking It S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/183741.mp4', 'http://timg.bdta.pro/images/a0ec6a69d1fe95ef5e106813dae2ad90.jpg'),
(86394, 5995, 'Faking It S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/183742.mp4', 'http://timg.bdta.pro/images/0acb638137124f6b79800c82f796a5be.jpg'),
(86395, 5995, 'Faking It S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/183743.mp4', 'http://timg.bdta.pro/images/b13e88af27c44c0531c13813f7015ac0.jpg'),
(86396, 5995, 'Faking It S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/183744.mp4', 'http://timg.bdta.pro/images/ac48b5443dcc0e9a531ae776bb87de62.jpg'),
(86397, 5995, 'Faking It S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/183745.mp4', 'http://timg.bdta.pro/images/454e6f4bba5f59bf36c1dde5ad754a69.jpg'),
(86398, 5995, 'Faking It S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/183746.mp4', 'http://timg.bdta.pro/images/67564fa7f3b6608090e03858de5490e1.jpg'),
(86399, 5995, 'Faking It S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/183747.mp4', 'http://timg.bdta.pro/images/511d12c10f44106c6597551d3f8b74bd.jpg'),
(86400, 5995, 'Faking It S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/183748.mp4', 'http://timg.bdta.pro/images/0d770578f0bd5c26511bea313065eab9.jpg'),
(86401, 5996, 'Faking It S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183749.mp4', 'http://timg.bdta.pro/images/8c397aec6ae261a5531d4d6468aede32.jpg'),
(86402, 5996, 'Faking It S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183750.mp4', 'http://timg.bdta.pro/images/67ec0c9d8b6e336596b5943d165caa4c.jpg'),
(86403, 5996, 'Faking It S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183751.mp4', 'http://timg.bdta.pro/images/299b9c33734bf7b18ba66230c823a8bd.jpg'),
(86404, 5996, 'Faking It S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183752.mp4', 'http://timg.bdta.pro/images/316924c519c0ccfa6e33bd5ef753fb90.jpg'),
(86405, 5996, 'Faking It S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183753.mp4', 'http://timg.bdta.pro/images/cd543c657971f93d28a39d50aa98ad80.jpg'),
(86406, 5996, 'Faking It S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183754.mp4', 'http://timg.bdta.pro/images/2ba39234cf51f731d8c57c81fa47bc8a.jpg'),
(86407, 5996, 'Faking It S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183755.mp4', 'http://timg.bdta.pro/images/00951abbab782ec0bdc5c75c7aa9b62d.jpg'),
(86408, 5996, 'Faking It S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183756.mp4', 'http://timg.bdta.pro/images/78a492d4b5e433323d50a5f6b55a030d.jpg'),
(86409, 5996, 'Faking It S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183757.mp4', 'http://timg.bdta.pro/images/a21b9026bf157735c59bb1702be33d92.jpg'),
(86410, 5996, 'Faking It S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183758.mp4', 'http://timg.bdta.pro/images/2f9bd73886ce2ed83d873c8ee37b7a38.jpg'),
(86411, 5997, 'Victoria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183704.mp4', 'http://timg.bdta.pro/images/ae4d67a905555b3e0e7a29d0c045d12d.jpg'),
(86412, 5997, 'Victoria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183705.mp4', 'http://timg.bdta.pro/images/5b7735e14d050f0dcb5b76fd4858a960.jpg'),
(86413, 5997, 'Victoria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183706.mp4', 'http://timg.bdta.pro/images/22b0787b5158b68644bcd8975a50855c.jpg'),
(86414, 5997, 'Victoria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183707.mp4', 'http://timg.bdta.pro/images/fc0868d9c764b727e02af4893eed18ba.jpg'),
(86415, 5997, 'Victoria S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183708.mp4', 'http://timg.bdta.pro/images/d76f5a8217e1ed40a0e4b250a3ebfe07.jpg'),
(86416, 5997, 'Victoria S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183709.mp4', 'http://timg.bdta.pro/images/122823d52743ee50533d5b8ef38a3fdc.jpg'),
(86417, 5997, 'Victoria S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183710.mp4', 'http://timg.bdta.pro/images/cb45a7bd08658e0869216659783f65d7.jpg'),
(86418, 5997, 'Victoria S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183711.mp4', 'http://timg.bdta.pro/images/a706145099626146f61c5d199aa73f2e.jpg'),
(86419, 5998, 'Victoria S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183712.mp4', 'http://timg.bdta.pro/images/8db44f40b69631b6a30501bb8be9ebb9.jpg'),
(86420, 5998, 'Victoria S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183713.mp4', 'http://timg.bdta.pro/images/5155b93136ce47a49d36e849c9aa4811.jpg'),
(86421, 5998, 'Victoria S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183714.mp4', 'http://timg.bdta.pro/images/9913153c6eeeb560a92749efa5737d00.jpg'),
(86422, 5998, 'Victoria S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183715.mp4', 'http://timg.bdta.pro/images/a1e75bec93a736172d486d88c9f90df2.jpg'),
(86423, 5998, 'Victoria S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183716.mp4', 'http://timg.bdta.pro/images/5b15a8e3a199d53802422a8f8fef7210.jpg'),
(86424, 5998, 'Victoria S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183717.mp4', 'http://timg.bdta.pro/images/fe24d55bbf18b49a4013b63b5f097bc5.jpg'),
(86425, 5998, 'Victoria S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183718.mp4', 'http://timg.bdta.pro/images/7f44f6a661090064f44624678b429c17.jpg'),
(86426, 5998, 'Victoria S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183719.mp4', 'http://timg.bdta.pro/images/a4d4b8384d92ed1c1441d83eeb3ecbe9.jpg'),
(86427, 5998, 'Victoria S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183720.mp4', 'http://gstaticontent.com/images/e63c5afe57ed245ded4db338c6169ed6.jpg'),
(86428, 5999, 'Black Clover S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256569.mp4', 'http://timg.bdta.pro/images/752c876758b9ee608084b6b4fbca00cb.jpg'),
(86429, 5999, 'Black Clover S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256570.mp4', 'http://timg.bdta.pro/images/1b04d21234bc91f7d0f5fd0d722d933c.jpg'),
(86430, 5999, 'Black Clover S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256571.mp4', 'http://timg.bdta.pro/images/5f91d42a56181b31baba53c7ed328074.jpg'),
(86431, 5999, 'Black Clover S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256572.mp4', 'http://timg.bdta.pro/images/eba54102dcacf44f3a25e81242cf09cd.jpg'),
(86432, 5999, 'Black Clover S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256573.mp4', 'http://timg.bdta.pro/images/a92839c5b9979fa6a05c70b476d5c06d.jpg'),
(86433, 5999, 'Black Clover S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256574.mp4', 'http://timg.bdta.pro/images/8339bd4b8ae4ca7ba22078053980e764.jpg'),
(86434, 5999, 'Black Clover S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256575.mp4', 'http://timg.bdta.pro/images/d037c923abe5bb23ec5b069abf5885b8.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(86435, 5999, 'Black Clover S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256576.mp4', 'http://timg.bdta.pro/images/99a26000a891ac353aa3b76e0df7148c.jpg'),
(86436, 5999, 'Black Clover S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256577.mp4', 'http://timg.bdta.pro/images/f8ecf02d67f20a6906257cb06267a0ed.jpg'),
(86437, 5999, 'Black Clover S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256578.mp4', 'http://timg.bdta.pro/images/8e86c05d989e665a19729d7e01dfb350.jpg'),
(86438, 5999, 'Black Clover S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256579.mp4', 'http://timg.bdta.pro/images/1d5b2fb081be574523724c61e1baf745.jpg'),
(86439, 5999, 'Black Clover S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256580.mp4', 'http://timg.bdta.pro/images/c148b1a4473193e4f0d4228f02fcc9f0.jpg'),
(86440, 5999, 'Black Clover S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256581.mp4', 'http://timg.bdta.pro/images/cbbdfc7a29c094651f1fc2717fa1435d.jpg'),
(86441, 5999, 'Black Clover S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256582.mp4', 'http://timg.bdta.pro/images/9b3cab46866e2d7c26c2676341fb1a7c.jpg'),
(86442, 5999, 'Black Clover S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256583.mp4', 'http://timg.bdta.pro/images/9ef3327fb47a7291cae8e2a6dbf7c2b6.jpg'),
(86443, 5999, 'Black Clover S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256584.mp4', 'http://timg.bdta.pro/images/bd6e48ed43ee48aca89a5de52017957e.jpg'),
(86444, 5999, 'Black Clover S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/256585.mp4', 'http://timg.bdta.pro/images/b79acfb96d63c6a4c7df6f9987a17b5a.jpg'),
(86445, 5999, 'Black Clover S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/256586.mp4', 'http://timg.bdta.pro/images/b879f8e7ed5617d7ede36d1274b9cf49.jpg'),
(86446, 5999, 'Black Clover S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/256587.mp4', 'http://timg.bdta.pro/images/8d4939efdcdcc82ecbd49d80858da345.jpg'),
(86447, 5999, 'Black Clover S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/256588.mp4', 'http://timg.bdta.pro/images/9fa5309cb69aa9bf65946b055796dc86.jpg'),
(86448, 5999, 'Black Clover S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/256589.mp4', 'http://timg.bdta.pro/images/0bfb03d6fb191c0c96b5ea71a665aa77.jpg'),
(86449, 5999, 'Black Clover S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/256590.mp4', 'http://timg.bdta.pro/images/31159dc485b8a8940a912fb08b8b3e18.jpg'),
(86450, 5999, 'Black Clover S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/256591.mp4', 'http://timg.bdta.pro/images/ddce3a207998b3fe3d65e5635642e135.jpg'),
(86451, 5999, 'Black Clover S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/256592.mp4', 'http://timg.bdta.pro/images/1f99ebfa6c1b2342bbece1100714a442.jpg'),
(86452, 5999, 'Black Clover S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/256593.mp4', 'http://timg.bdta.pro/images/d1aae406df599d4aa2cd36271a9ecf78.jpg'),
(86453, 5999, 'Black Clover S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/256594.mp4', 'http://timg.bdta.pro/images/72782a75638d86970a2a252edc145716.jpg'),
(86454, 5999, 'Black Clover S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/256595.mp4', 'http://timg.bdta.pro/images/9cbb00eabd79e9107c300f82208d602e.jpg'),
(86455, 5999, 'Black Clover S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/256596.mp4', 'http://timg.bdta.pro/images/0a8160989ca0c61eef44c7714ea977ed.jpg'),
(86456, 5999, 'Black Clover S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/256597.mp4', 'http://timg.bdta.pro/images/8d8a3c00bb549f3238eff8f26bb542d1.jpg'),
(86457, 5999, 'Black Clover S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/256598.mp4', 'http://timg.bdta.pro/images/3aa37d4391ab3585fec456bfe8feaf70.jpg'),
(86458, 5999, 'Black Clover S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/256599.mp4', 'http://timg.bdta.pro/images/44a30417ccd8fdf72d4c743f5033b613.jpg'),
(86459, 5999, 'Black Clover S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/256600.mp4', 'http://timg.bdta.pro/images/5f1f7b04e5e56b21ed853933a95997bc.jpg'),
(86460, 5999, 'Black Clover S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/256601.mp4', 'http://timg.bdta.pro/images/5bab252489a038255db07c543bb25e52.jpg'),
(86461, 5999, 'Black Clover S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/256602.mp4', 'http://timg.bdta.pro/images/77b357b101aac988332924946daa6a1d.jpg'),
(86462, 5999, 'Black Clover S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/256603.mp4', 'http://timg.bdta.pro/images/fdb39f0f694264032dd419cd3c47733a.jpg'),
(86463, 5999, 'Black Clover S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/256604.mp4', 'http://timg.bdta.pro/images/7003eaf47822be878a617c46eea0b034.jpg'),
(86464, 5999, 'Black Clover S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/256605.mp4', 'http://timg.bdta.pro/images/bd1e459479b6e3aaf6efd0739230dbfa.jpg'),
(86465, 5999, 'Black Clover S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/256606.mp4', 'http://timg.bdta.pro/images/7fc84fe4f12a0aa873e34bbf7b4514e4.jpg'),
(86466, 5999, 'Black Clover S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/256607.mp4', 'http://timg.bdta.pro/images/32bf515f13fd6e68d255b2d70bd06bcf.jpg'),
(86467, 5999, 'Black Clover S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/256608.mp4', 'http://timg.bdta.pro/images/31848bcc63fc47313d4949047ea08cdc.jpg'),
(86468, 5999, 'Black Clover S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/256609.mp4', 'http://timg.bdta.pro/images/a0d75c3b9e231c87bf7c790c9140fbaa.jpg'),
(86469, 5999, 'Black Clover S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/256610.mp4', 'http://timg.bdta.pro/images/a40a4b06c2836b80d274125ecf762bad.jpg'),
(86470, 5999, 'Black Clover S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/256611.mp4', 'http://timg.bdta.pro/images/90fc80204413521137a6adc42851fd97.jpg'),
(86471, 5999, 'Black Clover S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/256612.mp4', 'http://timg.bdta.pro/images/4969dd1da2f93b57e244b7ba86a3aa0f.jpg'),
(86472, 5999, 'Black Clover S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/256613.mp4', 'http://timg.bdta.pro/images/9ae4c4f406e3a6faa2dd6317da8a4f99.jpg'),
(86473, 5999, 'Black Clover S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/256614.mp4', 'http://timg.bdta.pro/images/ec0fa1c8378c2c3029cb51c01111a985.jpg'),
(86474, 5999, 'Black Clover S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/256615.mp4', 'http://timg.bdta.pro/images/6685eca58b0845c04c79030723b77547.jpg'),
(86475, 5999, 'Black Clover S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/256616.mp4', 'http://timg.bdta.pro/images/5a1cb3ff7b020088eba8ae1c25443c71.jpg'),
(86476, 5999, 'Black Clover S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/256617.mp4', 'http://timg.bdta.pro/images/c27a243b9e77e73b5647b4eca5114f30.jpg'),
(86477, 5999, 'Black Clover S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/256618.mp4', 'http://timg.bdta.pro/images/13686336eeedd381fea899b0aefe5be0.jpg'),
(86478, 5999, 'Black Clover S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/256619.mp4', 'http://timg.bdta.pro/images/3d7b70184a94bfddbffba3b3008b6bbc.jpg'),
(86479, 6000, 'Black Clover S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256620.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86480, 6000, 'Black Clover S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256621.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86481, 6000, 'Black Clover S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256622.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86482, 6000, 'Black Clover S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256623.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86483, 6000, 'Black Clover S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256624.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86484, 6000, 'Black Clover S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256625.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86485, 6000, 'Black Clover S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256626.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86486, 6000, 'Black Clover S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256627.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86487, 6000, 'Black Clover S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256628.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86488, 6000, 'Black Clover S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256629.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86489, 6000, 'Black Clover S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256630.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86490, 6000, 'Black Clover S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256631.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86491, 6000, 'Black Clover S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256632.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86492, 6000, 'Black Clover S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256633.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86493, 6000, 'Black Clover S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256634.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86494, 6000, 'Black Clover S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256635.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86495, 6000, 'Black Clover S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/256636.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86496, 6000, 'Black Clover S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/256637.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86497, 6000, 'Black Clover S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/256638.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86498, 6000, 'Black Clover S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/256639.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86499, 6000, 'Black Clover S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/256640.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86500, 6000, 'Black Clover S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/256641.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86501, 6000, 'Black Clover S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/256642.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86502, 6000, 'Black Clover S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/256643.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86503, 6000, 'Black Clover S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/256644.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86504, 6000, 'Black Clover S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/256645.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86505, 6000, 'Black Clover S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/256646.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86506, 6000, 'Black Clover S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/256647.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86507, 6000, 'Black Clover S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/256648.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86508, 6000, 'Black Clover S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/256649.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86509, 6000, 'Black Clover S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/256650.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86510, 6000, 'Black Clover S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/256651.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86511, 6000, 'Black Clover S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/256652.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86512, 6000, 'Black Clover S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/256653.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86513, 6000, 'Black Clover S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/256654.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86514, 6000, 'Black Clover S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/256655.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86515, 6000, 'Black Clover S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/256656.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86516, 6000, 'Black Clover S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/256657.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86517, 6000, 'Black Clover S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/256658.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86518, 6000, 'Black Clover S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/256659.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86519, 6000, 'Black Clover S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/256660.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86520, 6000, 'Black Clover S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/256661.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86521, 6000, 'Black Clover S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/256662.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86522, 6000, 'Black Clover S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/256663.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86523, 6000, 'Black Clover S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/256664.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86524, 6000, 'Black Clover S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/256665.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86525, 6000, 'Black Clover S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/256666.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86526, 6000, 'Black Clover S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/256667.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86527, 6000, 'Black Clover S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/256668.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86528, 6000, 'Black Clover S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/256669.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86529, 6000, 'Black Clover S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/256670.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86530, 6001, 'Black Clover S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256671.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86531, 6001, 'Black Clover S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256672.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86532, 6001, 'Black Clover S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256673.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86533, 6001, 'Black Clover S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256674.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86534, 6001, 'Black Clover S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256675.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86535, 6001, 'Black Clover S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256676.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86536, 6001, 'Black Clover S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256677.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86537, 6001, 'Black Clover S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256678.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86538, 6001, 'Black Clover S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256679.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86539, 6001, 'Black Clover S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256680.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86540, 6001, 'Black Clover S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256681.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86541, 6001, 'Black Clover S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256682.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86542, 6001, 'Black Clover S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256683.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86543, 6001, 'Black Clover S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256684.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86544, 6001, 'Black Clover S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256685.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86545, 6001, 'Black Clover S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256686.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86546, 6001, 'Black Clover S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/256687.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86547, 6001, 'Black Clover S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/256688.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86548, 6001, 'Black Clover S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/256689.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86549, 6001, 'Black Clover S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/256690.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86550, 6001, 'Black Clover S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/256691.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86551, 6001, 'Black Clover S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/256692.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86552, 6001, 'Black Clover S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/256693.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86553, 6001, 'Black Clover S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/256694.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86554, 6001, 'Black Clover S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/256695.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86555, 6001, 'Black Clover S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/256696.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86556, 6001, 'Black Clover S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/256697.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86557, 6001, 'Black Clover S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/256698.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86558, 6001, 'Black Clover S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/256699.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86559, 6001, 'Black Clover S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/256700.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86560, 6001, 'Black Clover S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/256701.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86561, 6001, 'Black Clover S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/256702.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86562, 6001, 'Black Clover S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/256703.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86563, 6001, 'Black Clover S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/256704.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86564, 6001, 'Black Clover S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/256705.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86565, 6001, 'Black Clover S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/256706.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86566, 6001, 'Black Clover S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/256707.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86567, 6001, 'Black Clover S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/256708.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86568, 6001, 'Black Clover S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/256709.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86569, 6001, 'Black Clover S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/256710.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86570, 6001, 'Black Clover S03 E41', 'http://sinalprivado.info:80/series/1533784/1533784/256711.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86571, 6001, 'Black Clover S03 E42', 'http://sinalprivado.info:80/series/1533784/1533784/256712.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86572, 6001, 'Black Clover S03 E43', 'http://sinalprivado.info:80/series/1533784/1533784/256713.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86573, 6001, 'Black Clover S03 E44', 'http://sinalprivado.info:80/series/1533784/1533784/256714.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86574, 6001, 'Black Clover S03 E45', 'http://sinalprivado.info:80/series/1533784/1533784/256715.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86575, 6001, 'Black Clover S03 E46', 'http://sinalprivado.info:80/series/1533784/1533784/256716.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86576, 6001, 'Black Clover S03 E47', 'http://sinalprivado.info:80/series/1533784/1533784/256717.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86577, 6001, 'Black Clover S03 E48', 'http://sinalprivado.info:80/series/1533784/1533784/256718.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86578, 6001, 'Black Clover S03 E49', 'http://sinalprivado.info:80/series/1533784/1533784/256719.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86579, 6001, 'Black Clover S03 E50', 'http://sinalprivado.info:80/series/1533784/1533784/256720.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86580, 6001, 'Black Clover S03 E51', 'http://sinalprivado.info:80/series/1533784/1533784/256721.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86581, 6001, 'Black Clover S03 E52', 'http://sinalprivado.info:80/series/1533784/1533784/256722.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86582, 6002, 'Black Clover S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256723.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86583, 6002, 'Black Clover S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256724.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86584, 6002, 'Black Clover S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256725.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86585, 6002, 'Black Clover S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256726.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86586, 6002, 'Black Clover S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256727.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86587, 6002, 'Black Clover S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256728.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86588, 6002, 'Black Clover S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256729.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86589, 6002, 'Black Clover S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256730.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86590, 6002, 'Black Clover S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256731.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86591, 6002, 'Black Clover S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256732.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86592, 6002, 'Black Clover S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256733.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86593, 6002, 'Black Clover S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256734.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86594, 6002, 'Black Clover S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256735.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86595, 6002, 'Black Clover S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256736.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86596, 6002, 'Black Clover S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256737.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86597, 6002, 'Black Clover S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256738.mp4', 'http://gstaticontent.com/images/c4a1b551137026638924e4a7683e41cb.jpg'),
(86598, 6003, 'A Lista Terminal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183696.mp4', 'http://timg.bdta.pro/images/bf8d94842f7833006f021768cdfce3d3.jpg'),
(86599, 6003, 'A Lista Terminal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183697.mp4', 'http://timg.bdta.pro/images/9e57207e9af15124c4d177afa9ae8e87.jpg'),
(86600, 6003, 'A Lista Terminal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183698.mp4', 'http://timg.bdta.pro/images/f060e7800d942c0feb41bab031c4c6d1.jpg'),
(86601, 6003, 'A Lista Terminal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183699.mp4', 'http://timg.bdta.pro/images/4692a9e1d56724b32c7041d558bc6368.jpg'),
(86602, 6003, 'A Lista Terminal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183700.mp4', 'http://timg.bdta.pro/images/3c8e3488d1b7aa01cdaccf2577c99f32.jpg'),
(86603, 6003, 'A Lista Terminal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183701.mp4', 'http://timg.bdta.pro/images/07829f6685fa4468c5220b929b05da1a.jpg'),
(86604, 6003, 'A Lista Terminal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183702.mp4', 'http://timg.bdta.pro/images/9e6c6530a2968b6bd0baf30e306bdf37.jpg'),
(86605, 6003, 'A Lista Terminal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183703.mp4', 'http://timg.bdta.pro/images/9b3b20daaf39ad5176d609b469d2cf08.jpg'),
(86606, 6004, 'A Magia do Disney\'s Animal Kingdom S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183688.mp4', 'http://timg.bdta.pro/images/a02cff213ab7cb59d25c3e1d94e6bc39.jpg'),
(86607, 6004, 'A Magia do Disney\'s Animal Kingdom S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183689.mp4', 'http://timg.bdta.pro/images/1c5839072e3e6f9b2687107376c47390.jpg'),
(86608, 6004, 'A Magia do Disney\'s Animal Kingdom S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183690.mp4', 'http://timg.bdta.pro/images/90d0a1e77403abe5a73c45cb583e0a77.jpg'),
(86609, 6004, 'A Magia do Disney\'s Animal Kingdom S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183691.mp4', 'http://timg.bdta.pro/images/2db66805df44125b3fb3be62a059ca72.jpg'),
(86610, 6004, 'A Magia do Disney\'s Animal Kingdom S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183692.mp4', 'http://timg.bdta.pro/images/fb0b13d0759af8b4931f3a5cb56237af.jpg'),
(86611, 6004, 'A Magia do Disney\'s Animal Kingdom S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183693.mp4', 'http://timg.bdta.pro/images/53bddc8ce19d8afcf902a51d96df7300.jpg'),
(86612, 6004, 'A Magia do Disney\'s Animal Kingdom S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183694.mp4', 'http://timg.bdta.pro/images/d775369427eb1b78f6efd80ab779731b.jpg'),
(86613, 6004, 'A Magia do Disney\'s Animal Kingdom S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183695.mp4', 'http://timg.bdta.pro/images/898c657710e5f7cad2170e0811a954d1.jpg'),
(86614, 6005, 'Adak: Ilha do Tesouro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183680.mp4', 'http://timg.bdta.pro/images/edd4b36edd02e44d1878809c9c67bb20.jpg'),
(86615, 6005, 'Adak: Ilha do Tesouro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183681.mp4', 'http://timg.bdta.pro/images/105b3cafc3083e8077b3e425509abbdb.jpg'),
(86616, 6005, 'Adak: Ilha do Tesouro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183682.mp4', 'http://timg.bdta.pro/images/1399bc36c911cc34b306316c9a1e3f8e.jpg'),
(86617, 6005, 'Adak: Ilha do Tesouro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183683.mp4', 'http://timg.bdta.pro/images/585455af0da9d02af80084ab9d3fb34b.jpg'),
(86618, 6005, 'Adak: Ilha do Tesouro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183684.mp4', 'http://timg.bdta.pro/images/598492f63a196123dfbd46569e237552.jpg'),
(86619, 6005, 'Adak: Ilha do Tesouro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183685.mp4', 'http://timg.bdta.pro/images/2dab88bb54cc3aea79b4b82e1a10c084.jpg'),
(86620, 6005, 'Adak: Ilha do Tesouro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183686.mp4', 'http://timg.bdta.pro/images/649f0b133dc78aee578da3a9c52e44ac.jpg'),
(86621, 6005, 'Adak: Ilha do Tesouro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183687.mp4', 'http://timg.bdta.pro/images/16c36eed135003f7fe6d936dac350e8d.jpg'),
(86622, 6006, 'Amor no Espectro: EUA S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261533.mp4', 'http://timg.bdta.pro/images/40ee840647a80102659f02ed8b067925.jpg'),
(86623, 6006, 'Amor no Espectro: EUA S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261534.mp4', 'http://timg.bdta.pro/images/b9345167877edc8419a199baa546ee70.jpg'),
(86624, 6006, 'Amor no Espectro: EUA S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261535.mp4', 'http://timg.bdta.pro/images/fa9f0e4a33d4ffea0447954d3fb5dbf2.jpg'),
(86625, 6006, 'Amor no Espectro: EUA S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261536.mp4', 'http://timg.bdta.pro/images/18bff47bb68bb15f4d4c3eec8b541999.jpg'),
(86626, 6006, 'Amor no Espectro: EUA S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261537.mp4', 'http://timg.bdta.pro/images/2d5999246c4b53f5d712c138ebe87bd1.jpg'),
(86627, 6006, 'Amor no Espectro: EUA S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261538.mp4', 'http://timg.bdta.pro/images/b0db74d9fcb5e9ae362ff03277b0d58d.jpg'),
(86628, 6007, 'Amor no Espectro: EUA S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261539.mp4', 'http://gstaticontent.com/images/8aeecc492a045db2477b1514cb86268e.jpg'),
(86629, 6007, 'Amor no Espectro: EUA S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261540.mp4', 'http://gstaticontent.com/images/8aeecc492a045db2477b1514cb86268e.jpg'),
(86630, 6007, 'Amor no Espectro: EUA S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261541.mp4', 'http://gstaticontent.com/images/8aeecc492a045db2477b1514cb86268e.jpg'),
(86631, 6007, 'Amor no Espectro: EUA S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261542.mp4', 'http://gstaticontent.com/images/8aeecc492a045db2477b1514cb86268e.jpg'),
(86632, 6007, 'Amor no Espectro: EUA S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261543.mp4', 'http://gstaticontent.com/images/8aeecc492a045db2477b1514cb86268e.jpg'),
(86633, 6007, 'Amor no Espectro: EUA S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261544.mp4', 'http://gstaticontent.com/images/8aeecc492a045db2477b1514cb86268e.jpg'),
(86634, 6007, 'Amor no Espectro: EUA S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261545.mp4', 'http://gstaticontent.com/images/8aeecc492a045db2477b1514cb86268e.jpg'),
(86635, 4306, 'Animaniacs S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183582.mp4', 'http://timg.bdta.pro/images/ebc6f3a255fc6e366c8e5d229db8ebf1.jpg'),
(86636, 4306, 'Animaniacs S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183583.mp4', 'http://timg.bdta.pro/images/ebc6f3a255fc6e366c8e5d229db8ebf1.jpg'),
(86637, 4306, 'Animaniacs S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183584.mp4', 'http://timg.bdta.pro/images/ebc6f3a255fc6e366c8e5d229db8ebf1.jpg'),
(86638, 4306, 'Animaniacs S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183585.mp4', 'http://timg.bdta.pro/images/b3f378504e3d343a2d6aef39340608cf.jpg'),
(86639, 4306, 'Animaniacs S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183586.mp4', 'http://timg.bdta.pro/images/b3f378504e3d343a2d6aef39340608cf.jpg'),
(86640, 4306, 'Animaniacs S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183587.mp4', 'http://timg.bdta.pro/images/b3f378504e3d343a2d6aef39340608cf.jpg'),
(86641, 4306, 'Animaniacs S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183588.mp4', 'http://timg.bdta.pro/images/74fb7fb98ea0654ed8a36ca7625ef7f5.jpg'),
(86642, 4306, 'Animaniacs S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183589.mp4', 'http://timg.bdta.pro/images/74fb7fb98ea0654ed8a36ca7625ef7f5.jpg'),
(86643, 4306, 'Animaniacs S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183590.mp4', 'http://timg.bdta.pro/images/74fb7fb98ea0654ed8a36ca7625ef7f5.jpg'),
(86644, 4306, 'Animaniacs S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183591.mp4', 'http://timg.bdta.pro/images/6223c6a9087a7104ec2764e88fdb215b.jpg'),
(86645, 4306, 'Animaniacs S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183592.mp4', 'http://timg.bdta.pro/images/6223c6a9087a7104ec2764e88fdb215b.jpg'),
(86646, 4306, 'Animaniacs S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183593.mp4', 'http://timg.bdta.pro/images/5f51f5e7fc0157e20d1a41621a3e8668.jpg'),
(86647, 4306, 'Animaniacs S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/183594.mp4', 'http://timg.bdta.pro/images/fc2b33573c7652b2be5923822c671ada.jpg'),
(86648, 4306, 'Animaniacs S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/183595.mp4', 'http://timg.bdta.pro/images/fc2b33573c7652b2be5923822c671ada.jpg'),
(86649, 4306, 'Animaniacs S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/183596.mp4', 'http://timg.bdta.pro/images/fc2b33573c7652b2be5923822c671ada.jpg'),
(86650, 4306, 'Animaniacs S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/183597.mp4', 'http://timg.bdta.pro/images/ed1477a73467901a9c29f288a38b43a5.jpg'),
(86651, 4306, 'Animaniacs S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/183598.mp4', 'http://timg.bdta.pro/images/ed1477a73467901a9c29f288a38b43a5.jpg'),
(86652, 4306, 'Animaniacs S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/183599.mp4', 'http://timg.bdta.pro/images/cb092d682e2adac9f41e9446b941ead0.jpg'),
(86653, 4306, 'Animaniacs S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/183600.mp4', 'http://timg.bdta.pro/images/cb092d682e2adac9f41e9446b941ead0.jpg'),
(86654, 4306, 'Animaniacs S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/183601.mp4', 'http://timg.bdta.pro/images/4ab18eda755a6970dd3aa2fcfce84610.jpg'),
(86655, 4306, 'Animaniacs S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/183602.mp4', 'http://timg.bdta.pro/images/4ab18eda755a6970dd3aa2fcfce84610.jpg'),
(86656, 4306, 'Animaniacs S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/183603.mp4', 'http://timg.bdta.pro/images/2b49e18a5fde366dec8f8e9fd2e4212c.jpg'),
(86657, 4306, 'Animaniacs S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/183604.mp4', 'http://timg.bdta.pro/images/802eb96778815b34172eabf20cd47f71.jpg'),
(86658, 4306, 'Animaniacs S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/183605.mp4', 'http://timg.bdta.pro/images/802eb96778815b34172eabf20cd47f71.jpg'),
(86659, 4306, 'Animaniacs S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/183606.mp4', 'http://timg.bdta.pro/images/64d381acbe8579518ce533853e658fd6.jpg'),
(86660, 4306, 'Animaniacs S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/183607.mp4', 'http://timg.bdta.pro/images/64d381acbe8579518ce533853e658fd6.jpg'),
(86661, 4306, 'Animaniacs S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/183608.mp4', 'http://timg.bdta.pro/images/1ffa78eee1a3aa207522b8b6bd4b6bdc.jpg'),
(86662, 4306, 'Animaniacs S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/183609.mp4', 'http://timg.bdta.pro/images/1ffa78eee1a3aa207522b8b6bd4b6bdc.jpg'),
(86663, 4306, 'Animaniacs S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/183610.mp4', 'http://timg.bdta.pro/images/1ffa78eee1a3aa207522b8b6bd4b6bdc.jpg'),
(86664, 4306, 'Animaniacs S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/183612.mp4', 'http://timg.bdta.pro/images/b16037106dfc4a5f1a0b66016ac0e4ee.jpg'),
(86665, 4306, 'Animaniacs S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/183613.mp4', 'http://timg.bdta.pro/images/4547e68fe76d2be67e6cc657e27e59f2.jpg'),
(86666, 4306, 'Animaniacs S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/183614.mp4', 'http://timg.bdta.pro/images/4547e68fe76d2be67e6cc657e27e59f2.jpg'),
(86667, 4306, 'Animaniacs S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/183615.mp4', 'http://timg.bdta.pro/images/d66d1f0f7890065e2a72b672ec190985.jpg'),
(86668, 4306, 'Animaniacs S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/183616.mp4', 'http://timg.bdta.pro/images/d66d1f0f7890065e2a72b672ec190985.jpg'),
(86669, 4306, 'Animaniacs S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/183617.mp4', 'http://timg.bdta.pro/images/d66d1f0f7890065e2a72b672ec190985.jpg'),
(86670, 4306, 'Animaniacs S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/183618.mp4', 'http://timg.bdta.pro/images/e6a1860cb059477c9def0f1202f6e9fe.jpg'),
(86671, 4306, 'Animaniacs S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/183619.mp4', 'http://timg.bdta.pro/images/e6a1860cb059477c9def0f1202f6e9fe.jpg'),
(86672, 4306, 'Animaniacs S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/183620.mp4', 'http://timg.bdta.pro/images/3338dd24ae026b58ab2a7157e9f118a7.jpg'),
(86673, 4306, 'Animaniacs S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/183621.mp4', 'http://timg.bdta.pro/images/3338dd24ae026b58ab2a7157e9f118a7.jpg'),
(86674, 4306, 'Animaniacs S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/183622.mp4', 'http://timg.bdta.pro/images/3338dd24ae026b58ab2a7157e9f118a7.jpg'),
(86675, 4306, 'Animaniacs S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/183623.mp4', 'http://timg.bdta.pro/images/c182a9a7c194de8df21be6d15dbbaa72.jpg'),
(86676, 4306, 'Animaniacs S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/183624.mp4', 'http://timg.bdta.pro/images/c182a9a7c194de8df21be6d15dbbaa72.jpg'),
(86677, 4306, 'Animaniacs S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/183625.mp4', 'http://timg.bdta.pro/images/7ef305e55f34dce87d0ae2d9e4d82ece.jpg'),
(86678, 4306, 'Animaniacs S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/183627.mp4', 'http://timg.bdta.pro/images/7ef305e55f34dce87d0ae2d9e4d82ece.jpg'),
(86679, 4306, 'Animaniacs S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/183628.mp4', 'http://timg.bdta.pro/images/7ef305e55f34dce87d0ae2d9e4d82ece.jpg'),
(86680, 4306, 'Animaniacs S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/183630.mp4', 'http://timg.bdta.pro/images/797bcce7dd63bdda1c45e08bb7ed2fe7.jpg'),
(86681, 4306, 'Animaniacs S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/183631.mp4', 'http://timg.bdta.pro/images/72f4d421cb50a4d0ea7510a92d930ced.jpg'),
(86682, 4306, 'Animaniacs S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/183632.mp4', 'http://timg.bdta.pro/images/72f4d421cb50a4d0ea7510a92d930ced.jpg'),
(86683, 4306, 'Animaniacs S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/183633.mp4', 'http://timg.bdta.pro/images/f7b9530917a0170fb6e14daa37ffa186.jpg'),
(86684, 4306, 'Animaniacs S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/183634.mp4', 'http://timg.bdta.pro/images/f7b9530917a0170fb6e14daa37ffa186.jpg'),
(86685, 4306, 'Animaniacs S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/183635.mp4', 'http://timg.bdta.pro/images/f7b9530917a0170fb6e14daa37ffa186.jpg'),
(86686, 4306, 'Animaniacs S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/183636.mp4', 'http://timg.bdta.pro/images/8a289314edcfda792e502209bb9ac493.jpg'),
(86687, 4306, 'Animaniacs S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/183637.mp4', 'http://timg.bdta.pro/images/8a289314edcfda792e502209bb9ac493.jpg'),
(86688, 4306, 'Animaniacs S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/183638.mp4', 'http://timg.bdta.pro/images/fcfa632acff21a185af8b1af3bdf8e87.jpg'),
(86689, 4306, 'Animaniacs S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/183639.mp4', 'http://timg.bdta.pro/images/fcfa632acff21a185af8b1af3bdf8e87.jpg'),
(86690, 4306, 'Animaniacs S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/183640.mp4', 'http://timg.bdta.pro/images/fcfa632acff21a185af8b1af3bdf8e87.jpg'),
(86691, 4306, 'Animaniacs S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/183641.mp4', 'http://timg.bdta.pro/images/740c42e526a006208af41b68183a214f.jpg'),
(86692, 4306, 'Animaniacs S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/183643.mp4', 'http://timg.bdta.pro/images/740c42e526a006208af41b68183a214f.jpg'),
(86693, 4306, 'Animaniacs S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/183645.mp4', 'http://timg.bdta.pro/images/740c42e526a006208af41b68183a214f.jpg'),
(86694, 4307, 'Animaniacs S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183646.mp4', 'http://timg.bdta.pro/images/740c42e526a006208af41b68183a214f.jpg'),
(86695, 4307, 'Animaniacs S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183647.mp4', 'http://timg.bdta.pro/images/740c42e526a006208af41b68183a214f.jpg'),
(86696, 4307, 'Animaniacs S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183648.mp4', 'http://timg.bdta.pro/images/740c42e526a006208af41b68183a214f.jpg'),
(86697, 4307, 'Animaniacs S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183649.mp4', 'http://timg.bdta.pro/images/740c42e526a006208af41b68183a214f.jpg'),
(86698, 4307, 'Animaniacs S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183650.mp4', 'http://timg.bdta.pro/images/740c42e526a006208af41b68183a214f.jpg'),
(86699, 4307, 'Animaniacs S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183651.mp4', 'http://timg.bdta.pro/images/740c42e526a006208af41b68183a214f.jpg'),
(86700, 4307, 'Animaniacs S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183652.mp4', 'http://timg.bdta.pro/images/740c42e526a006208af41b68183a214f.jpg'),
(86701, 4307, 'Animaniacs S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183653.mp4', 'http://timg.bdta.pro/images/740c42e526a006208af41b68183a214f.jpg'),
(86702, 4307, 'Animaniacs S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183654.mp4', 'http://timg.bdta.pro/images/740c42e526a006208af41b68183a214f.jpg'),
(86703, 4307, 'Animaniacs S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183655.mp4', 'http://timg.bdta.pro/images/740c42e526a006208af41b68183a214f.jpg'),
(86704, 4307, 'Animaniacs S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183656.mp4', 'http://timg.bdta.pro/images/740c42e526a006208af41b68183a214f.jpg'),
(86705, 4307, 'Animaniacs S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183657.mp4', 'http://timg.bdta.pro/images/740c42e526a006208af41b68183a214f.jpg'),
(86706, 4307, 'Animaniacs S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/183658.mp4', 'http://gstaticontent.com/images/8b817abfed2e7f2b7733eb5f363e05a9.jpg'),
(86707, 4307, 'Animaniacs S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/183659.mp4', 'http://gstaticontent.com/images/8b817abfed2e7f2b7733eb5f363e05a9.jpg'),
(86708, 4307, 'Animaniacs S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/183660.mp4', 'http://gstaticontent.com/images/8b817abfed2e7f2b7733eb5f363e05a9.jpg'),
(86709, 4307, 'Animaniacs S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/183661.mp4', 'http://gstaticontent.com/images/8b817abfed2e7f2b7733eb5f363e05a9.jpg'),
(86710, 4307, 'Animaniacs S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/183662.mp4', 'http://gstaticontent.com/images/8b817abfed2e7f2b7733eb5f363e05a9.jpg'),
(86711, 4307, 'Animaniacs S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/183663.mp4', 'http://gstaticontent.com/images/8b817abfed2e7f2b7733eb5f363e05a9.jpg'),
(86712, 4308, 'Animaniacs S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183664.mp4', 'http://timg.bdta.pro/images/dbfeb6ae52b9d6752e0a9d826d41d007.jpg'),
(86713, 4308, 'Animaniacs S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183665.mp4', 'http://timg.bdta.pro/images/dbfeb6ae52b9d6752e0a9d826d41d007.jpg'),
(86714, 4308, 'Animaniacs S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183666.mp4', 'http://timg.bdta.pro/images/08b7f0dcd7e63840b132edd1135b8828.jpg'),
(86715, 4308, 'Animaniacs S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183667.mp4', 'http://timg.bdta.pro/images/08b7f0dcd7e63840b132edd1135b8828.jpg'),
(86716, 4308, 'Animaniacs S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183668.mp4', 'http://timg.bdta.pro/images/08b7f0dcd7e63840b132edd1135b8828.jpg'),
(86717, 4308, 'Animaniacs S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183669.mp4', 'http://timg.bdta.pro/images/08b7f0dcd7e63840b132edd1135b8828.jpg'),
(86718, 4308, 'Animaniacs S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183670.mp4', 'http://timg.bdta.pro/images/08b7f0dcd7e63840b132edd1135b8828.jpg'),
(86719, 6008, 'Animaniacs S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183671.mp4', 'http://timg.bdta.pro/images/cb28635d8b4c7ebc67783ec0e44d69bf.jpg'),
(86720, 6008, 'Animaniacs S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183672.mp4', 'http://timg.bdta.pro/images/0c83ba78ea09739a6fd564374fa50f09.jpg'),
(86721, 6008, 'Animaniacs S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183673.mp4', 'http://timg.bdta.pro/images/0c83ba78ea09739a6fd564374fa50f09.jpg'),
(86722, 6008, 'Animaniacs S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183674.mp4', 'http://timg.bdta.pro/images/0c83ba78ea09739a6fd564374fa50f09.jpg'),
(86723, 6008, 'Animaniacs S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183675.mp4', 'http://timg.bdta.pro/images/02833f96bcc5a092fb6407b8d5d18f33.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(86724, 6008, 'Animaniacs S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183676.mp4', 'http://timg.bdta.pro/images/02833f96bcc5a092fb6407b8d5d18f33.jpg'),
(86725, 6008, 'Animaniacs S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183677.mp4', 'http://timg.bdta.pro/images/02833f96bcc5a092fb6407b8d5d18f33.jpg'),
(86726, 6008, 'Animaniacs S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183678.mp4', 'http://timg.bdta.pro/images/02833f96bcc5a092fb6407b8d5d18f33.jpg'),
(86727, 6008, 'Animaniacs S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183679.mp4', 'http://timg.bdta.pro/images/02833f96bcc5a092fb6407b8d5d18f33.jpg'),
(86728, 6009, 'Dias Melhores S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183572.mp4', 'http://timg.bdta.pro/images/0e82fdeea3de15ef114701a0085f8639.jpg'),
(86729, 6009, 'Dias Melhores S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183573.mp4', 'http://timg.bdta.pro/images/0e82fdeea3de15ef114701a0085f8639.jpg'),
(86730, 6009, 'Dias Melhores S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183574.mp4', 'http://timg.bdta.pro/images/0e82fdeea3de15ef114701a0085f8639.jpg'),
(86731, 6009, 'Dias Melhores S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183575.mp4', 'http://timg.bdta.pro/images/0e82fdeea3de15ef114701a0085f8639.jpg'),
(86732, 6009, 'Dias Melhores S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183576.mp4', 'http://timg.bdta.pro/images/0e82fdeea3de15ef114701a0085f8639.jpg'),
(86733, 6009, 'Dias Melhores S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183577.mp4', 'http://timg.bdta.pro/images/0e82fdeea3de15ef114701a0085f8639.jpg'),
(86734, 6009, 'Dias Melhores S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183578.mp4', 'http://timg.bdta.pro/images/0e82fdeea3de15ef114701a0085f8639.jpg'),
(86735, 6009, 'Dias Melhores S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183579.mp4', 'http://timg.bdta.pro/images/0e82fdeea3de15ef114701a0085f8639.jpg'),
(86736, 6009, 'Dias Melhores S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183580.mp4', 'http://timg.bdta.pro/images/0e82fdeea3de15ef114701a0085f8639.jpg'),
(86737, 6009, 'Dias Melhores S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183581.mp4', 'http://timg.bdta.pro/images/0e82fdeea3de15ef114701a0085f8639.jpg'),
(86738, 6010, 'Família Paraíso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86739, 6010, 'Família Paraíso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86740, 6010, 'Família Paraíso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86741, 6010, 'Família Paraíso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86742, 6010, 'Família Paraíso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86743, 6010, 'Família Paraíso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86744, 6010, 'Família Paraíso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86745, 6010, 'Família Paraíso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86746, 6010, 'Família Paraíso S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86747, 6010, 'Família Paraíso S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86748, 6010, 'Família Paraíso S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86749, 6010, 'Família Paraíso S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86750, 6010, 'Família Paraíso S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86751, 6010, 'Família Paraíso S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86752, 6010, 'Família Paraíso S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86753, 6010, 'Família Paraíso S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86754, 6010, 'Família Paraíso S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/220061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86755, 6010, 'Família Paraíso S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/220062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86756, 6010, 'Família Paraíso S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/220063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86757, 6010, 'Família Paraíso S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/220064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86758, 6011, 'Família Paraíso S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86759, 6011, 'Família Paraíso S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86760, 6011, 'Família Paraíso S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86761, 6011, 'Família Paraíso S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86762, 6011, 'Família Paraíso S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86763, 6011, 'Família Paraíso S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86764, 6011, 'Família Paraíso S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86765, 6011, 'Família Paraíso S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86766, 6011, 'Família Paraíso S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86767, 6011, 'Família Paraíso S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86768, 6011, 'Família Paraíso S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86769, 6011, 'Família Paraíso S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86770, 6011, 'Família Paraíso S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86771, 6011, 'Família Paraíso S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86772, 6011, 'Família Paraíso S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/220079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86773, 6011, 'Família Paraíso S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/220080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86774, 6011, 'Família Paraíso S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/220081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86775, 6011, 'Família Paraíso S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/220082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86776, 6011, 'Família Paraíso S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/220083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86777, 6011, 'Família Paraíso S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/220084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXVfljVTgRwkWON4Mh4X4re3CSY.jpg'),
(86778, 6012, 'Gatos Selvagens da Índia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183570.mp4', 'http://timg.bdta.pro/images/dcc92299f81c9389f253f08001e25ab2.jpg'),
(86779, 6012, 'Gatos Selvagens da Índia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183571.mp4', 'http://timg.bdta.pro/images/ee5003f80db6735d5b1db91536772b52.jpg'),
(86780, 6013, 'Homem X Abelha: A Batalha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183561.mp4', 'http://timg.bdta.pro/images/9b255bbcf548cb53d7786b440d320a1f.jpg'),
(86781, 6013, 'Homem X Abelha: A Batalha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183562.mp4', 'http://timg.bdta.pro/images/95664d63cc2280fa929fa1a8ebdd9f14.jpg'),
(86782, 6013, 'Homem X Abelha: A Batalha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183563.mp4', 'http://timg.bdta.pro/images/70d1d75f3c9548e77f1941b5bc16bb5e.jpg'),
(86783, 6013, 'Homem X Abelha: A Batalha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183564.mp4', 'http://timg.bdta.pro/images/47b21e5002b88ee0418b357c531bc39b.jpg'),
(86784, 6013, 'Homem X Abelha: A Batalha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183565.mp4', 'http://timg.bdta.pro/images/84bf00d1c724151ff529822115a9edf7.jpg'),
(86785, 6013, 'Homem X Abelha: A Batalha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183566.mp4', 'http://timg.bdta.pro/images/ffc26c9ffcc1608b63f14df4564e2af0.jpg'),
(86786, 6013, 'Homem X Abelha: A Batalha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183567.mp4', 'http://timg.bdta.pro/images/81e0dc608974195e24c4d4c461f16ec0.jpg'),
(86787, 6013, 'Homem X Abelha: A Batalha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183568.mp4', 'http://timg.bdta.pro/images/67c43b167517f73a77821458921dfa83.jpg'),
(86788, 6013, 'Homem X Abelha: A Batalha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183569.mp4', 'http://timg.bdta.pro/images/ee4235cef3b1bb15dbd1f9f70cdd52f5.jpg'),
(86789, 6014, 'Jovem Solteiro à Procura S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183531.mp4', 'http://timg.bdta.pro/images/9327e2e309fa25c3d3e4c7139032a42e.jpg'),
(86790, 6014, 'Jovem Solteiro à Procura S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183532.mp4', 'http://timg.bdta.pro/images/a2e2281f27df8729d9b5ad97dd570b6a.jpg'),
(86791, 6014, 'Jovem Solteiro à Procura S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183533.mp4', 'http://timg.bdta.pro/images/dda8dfc03d3a90476a40e04601826949.jpg'),
(86792, 6014, 'Jovem Solteiro à Procura S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183534.mp4', 'http://timg.bdta.pro/images/9ad23b7cc6d9abdc598791dd57c4d034.jpg'),
(86793, 6014, 'Jovem Solteiro à Procura S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183535.mp4', 'http://timg.bdta.pro/images/c5d5ba6f2f5f8ed33c0d94f064307b9f.jpg'),
(86794, 6014, 'Jovem Solteiro à Procura S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183536.mp4', 'http://timg.bdta.pro/images/2ba6ebfa0c658994666e7c4b5ef89430.jpg'),
(86795, 6014, 'Jovem Solteiro à Procura S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183537.mp4', 'http://timg.bdta.pro/images/eb14dab79a1329fe5638e1b7a65f8c6f.jpg'),
(86796, 6014, 'Jovem Solteiro à Procura S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183538.mp4', 'http://timg.bdta.pro/images/602c4f50e86b2ffc24c6cd66235b02a8.jpg'),
(86797, 6014, 'Jovem Solteiro à Procura S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183539.mp4', 'http://timg.bdta.pro/images/8f2e41c2a9df1d1a77e4e4d05efd4d37.jpg'),
(86798, 6014, 'Jovem Solteiro à Procura S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183540.mp4', 'http://timg.bdta.pro/images/dac8db3c97a3fc54d390b176ec861679.jpg'),
(86799, 6015, 'Jovem Solteiro à Procura S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183541.mp4', 'http://timg.bdta.pro/images/7f77109a7486a73279555b5e3c47a562.jpg'),
(86800, 6015, 'Jovem Solteiro à Procura S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183542.mp4', 'http://timg.bdta.pro/images/f46e02e2116c37e577c2997361a9647f.jpg'),
(86801, 6015, 'Jovem Solteiro à Procura S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183543.mp4', 'http://timg.bdta.pro/images/5a26a339dfd0ec546dc1483a67162836.jpg'),
(86802, 6015, 'Jovem Solteiro à Procura S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183544.mp4', 'http://timg.bdta.pro/images/3c360645515e0bb73fc2eedb99dee9bc.jpg'),
(86803, 6015, 'Jovem Solteiro à Procura S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183545.mp4', 'http://timg.bdta.pro/images/361bab729334a04bba39f41c744c4d36.jpg'),
(86804, 6015, 'Jovem Solteiro à Procura S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183546.mp4', 'http://timg.bdta.pro/images/361bab729334a04bba39f41c744c4d36.jpg'),
(86805, 6015, 'Jovem Solteiro à Procura S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183547.mp4', 'http://timg.bdta.pro/images/361bab729334a04bba39f41c744c4d36.jpg'),
(86806, 6015, 'Jovem Solteiro à Procura S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183548.mp4', 'http://timg.bdta.pro/images/361bab729334a04bba39f41c744c4d36.jpg'),
(86807, 6015, 'Jovem Solteiro à Procura S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183549.mp4', 'http://timg.bdta.pro/images/361bab729334a04bba39f41c744c4d36.jpg'),
(86808, 6015, 'Jovem Solteiro à Procura S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183550.mp4', 'http://timg.bdta.pro/images/361bab729334a04bba39f41c744c4d36.jpg'),
(86809, 6016, 'Jovem Solteiro à Procura S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183551.mp4', 'http://timg.bdta.pro/images/0a48025047677a43898fcc4d0f00889c.jpg'),
(86810, 6016, 'Jovem Solteiro à Procura S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183552.mp4', 'http://timg.bdta.pro/images/d6d752f03ae5df6c4ad493089216a4bf.jpg'),
(86811, 6016, 'Jovem Solteiro à Procura S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183553.mp4', 'http://timg.bdta.pro/images/977d4bf42a79a40108d75d77ce734eff.jpg'),
(86812, 6016, 'Jovem Solteiro à Procura S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183554.mp4', 'http://timg.bdta.pro/images/9bb6369629a5f77a80b24a247ad3f323.jpg'),
(86813, 6016, 'Jovem Solteiro à Procura S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183555.mp4', 'http://timg.bdta.pro/images/2e915a06c0252843b8885689755e0bf7.jpg'),
(86814, 6016, 'Jovem Solteiro à Procura S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183556.mp4', 'http://timg.bdta.pro/images/a7609923087e7dee08122f6a021c148e.jpg'),
(86815, 6016, 'Jovem Solteiro à Procura S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183557.mp4', 'http://timg.bdta.pro/images/ea59a90f99d2e44d91d2295b9984c6e4.jpg'),
(86816, 6016, 'Jovem Solteiro à Procura S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183558.mp4', 'http://timg.bdta.pro/images/aa023737f9b7a43d457618011c08f2d8.jpg'),
(86817, 6016, 'Jovem Solteiro à Procura S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183559.mp4', 'http://timg.bdta.pro/images/e5ff8b1e0a121047f7e993fcfce40249.jpg'),
(86818, 6016, 'Jovem Solteiro à Procura S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183560.mp4', 'http://timg.bdta.pro/images/88200628537dd5ffc7f76573ee64bdb7.jpg'),
(86819, 6017, 'Meu Diário para a Liberdade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183515.mp4', 'http://timg.bdta.pro/images/e15b3ac4e7886fdc7b5939c4637d9f7d.jpg'),
(86820, 6017, 'Meu Diário para a Liberdade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183516.mp4', 'http://timg.bdta.pro/images/d6623a7c50192f40101170d734d279c6.jpg'),
(86821, 6017, 'Meu Diário para a Liberdade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183517.mp4', 'http://timg.bdta.pro/images/9c4e6ea3675a29fbc87aceba3e9ff507.jpg'),
(86822, 6017, 'Meu Diário para a Liberdade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183518.mp4', 'http://timg.bdta.pro/images/a6c3bf5feb99032a1d93ddd8fb55796b.jpg'),
(86823, 6017, 'Meu Diário para a Liberdade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183519.mp4', 'http://timg.bdta.pro/images/a2ae1cd8d44a43847514c40cea2dd73e.jpg'),
(86824, 6017, 'Meu Diário para a Liberdade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183520.mp4', 'http://timg.bdta.pro/images/9067bb2c956e0a0a930cd9c5a5333284.jpg'),
(86825, 6017, 'Meu Diário para a Liberdade S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183521.mp4', 'http://timg.bdta.pro/images/0c239f143c5d2c71d250824be4a4558a.jpg'),
(86826, 6017, 'Meu Diário para a Liberdade S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183522.mp4', 'http://timg.bdta.pro/images/9b70ee752fa3eaf25c85e0747c5d4252.jpg'),
(86827, 6017, 'Meu Diário para a Liberdade S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183523.mp4', 'http://timg.bdta.pro/images/fe80af3f7adeccb6169aaedc8d483e60.jpg'),
(86828, 6017, 'Meu Diário para a Liberdade S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183524.mp4', 'http://timg.bdta.pro/images/9939c80cf0bdeede7b2a61785f4ea1b8.jpg'),
(86829, 6017, 'Meu Diário para a Liberdade S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183525.mp4', 'http://timg.bdta.pro/images/b20409e85d9fd7e0ffc6a5fe031b8fdc.jpg'),
(86830, 6017, 'Meu Diário para a Liberdade S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183526.mp4', 'http://timg.bdta.pro/images/6040f087c5e73d85db73900bddd5aafb.jpg'),
(86831, 6017, 'Meu Diário para a Liberdade S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/183527.mp4', 'http://timg.bdta.pro/images/0810f6f63d1da6eeca28a24c6d25c800.jpg'),
(86832, 6017, 'Meu Diário para a Liberdade S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/183528.mp4', 'http://timg.bdta.pro/images/a9867b4c691c65841af338f86e1c06a0.jpg'),
(86833, 6017, 'Meu Diário para a Liberdade S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/183529.mp4', 'http://timg.bdta.pro/images/eeb8a1355b58d704b2e5d9fa2428904e.jpg'),
(86834, 6017, 'Meu Diário para a Liberdade S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/183530.mp4', 'http://timg.bdta.pro/images/ce71e5376a679f8c0234cc45f75e11cc.jpg'),
(86835, 6018, 'Os Flintstones S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183381.mp4', 'http://timg.bdta.pro/images/7a04e2fef5c29b2ea0c15b478413a831.jpg'),
(86836, 6018, 'Os Flintstones S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183382.mp4', 'http://timg.bdta.pro/images/a136de006b7be1aad57d09903f9f9a1b.jpg'),
(86837, 6018, 'Os Flintstones S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183383.mp4', 'http://timg.bdta.pro/images/6868f2fff5d63cb88b512be57319c482.jpg'),
(86838, 6018, 'Os Flintstones S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183384.mp4', 'http://timg.bdta.pro/images/7cfd2e6697d03d102c1df56f80959304.jpg'),
(86839, 6018, 'Os Flintstones S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183385.mp4', 'http://timg.bdta.pro/images/b55cd3d4c400eaba792794b91dbe8e9a.jpg'),
(86840, 6018, 'Os Flintstones S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183386.mp4', 'http://timg.bdta.pro/images/4242a8da4e415c51d80d4c36adcb4d87.jpg'),
(86841, 6018, 'Os Flintstones S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183387.mp4', 'http://timg.bdta.pro/images/4c34f6fc6af2d14c566a962411ef77b1.jpg'),
(86842, 6018, 'Os Flintstones S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183388.mp4', 'http://timg.bdta.pro/images/a28a23bfcccfc1625f7f1c4cbca6f005.jpg'),
(86843, 6018, 'Os Flintstones S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183389.mp4', 'http://timg.bdta.pro/images/ea8f7ca427e3c658a11b04864204d6b0.jpg'),
(86844, 6018, 'Os Flintstones S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183390.mp4', 'http://timg.bdta.pro/images/e2a5a710f87c167bdb9ab1c40625eed2.jpg'),
(86845, 6018, 'Os Flintstones S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183391.mp4', 'http://timg.bdta.pro/images/2eec606deb2d7d2548b377b2493d7aff.jpg'),
(86846, 6018, 'Os Flintstones S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183392.mp4', 'http://timg.bdta.pro/images/19dceb35f98e63a232101d3fe4501871.jpg'),
(86847, 6018, 'Os Flintstones S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/183393.mp4', 'http://timg.bdta.pro/images/2f6c43b1e86b85187a098a10211616d0.jpg'),
(86848, 6018, 'Os Flintstones S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/183394.mp4', 'http://timg.bdta.pro/images/fa520af4ea62c89debd89baff118174b.jpg'),
(86849, 6018, 'Os Flintstones S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/183395.mp4', 'http://timg.bdta.pro/images/2352f57f5a984e7928aa840955ff4f1c.jpg'),
(86850, 6018, 'Os Flintstones S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/183396.mp4', 'http://timg.bdta.pro/images/7c311e368b09993e340595afe9e5ac8b.jpg'),
(86851, 6018, 'Os Flintstones S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/183397.mp4', 'http://timg.bdta.pro/images/0dc4bc344e1b1689ff3b757a0108e04a.jpg'),
(86852, 6018, 'Os Flintstones S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/183398.mp4', 'http://timg.bdta.pro/images/c6d953715d4bd3fe63a49940e7a921ed.jpg'),
(86853, 6018, 'Os Flintstones S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/183399.mp4', 'http://timg.bdta.pro/images/6f13b26282a39b95646358cd4f21a6c7.jpg'),
(86854, 6018, 'Os Flintstones S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/183400.mp4', 'http://timg.bdta.pro/images/b72c0b444307ce4d723b2539476ec877.jpg'),
(86855, 6018, 'Os Flintstones S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/183401.mp4', 'http://timg.bdta.pro/images/4d73169af2b78a741bbc389513f3cae7.jpg'),
(86856, 6018, 'Os Flintstones S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/183402.mp4', 'http://timg.bdta.pro/images/70735ca44d2f690b237ec62cbc020bff.jpg'),
(86857, 6018, 'Os Flintstones S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/183403.mp4', 'http://timg.bdta.pro/images/ae50542ba3f07ac9e57d2d269b13337e.jpg'),
(86858, 6018, 'Os Flintstones S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/183404.mp4', 'http://timg.bdta.pro/images/43157be45597c42ba5e6083423b4b181.jpg'),
(86859, 6018, 'Os Flintstones S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/183405.mp4', 'http://timg.bdta.pro/images/79c4b72fa25d7103161c662ed5611cdf.jpg'),
(86860, 6018, 'Os Flintstones S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/183406.mp4', 'http://timg.bdta.pro/images/70551f6ef450c160a24d49e05615103d.jpg'),
(86861, 6018, 'Os Flintstones S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/183407.mp4', 'http://timg.bdta.pro/images/485e6e4b4b4c5f87592e8a128e8af965.jpg'),
(86862, 6018, 'Os Flintstones S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/183408.mp4', 'http://timg.bdta.pro/images/1161d3264b7fcf1f7b591161d8b8d84b.jpg'),
(86863, 6019, 'Os Flintstones S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183409.mp4', 'http://timg.bdta.pro/images/6c54a0d8b5e5d06d49ffc71d813de4db.jpg'),
(86864, 6019, 'Os Flintstones S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183410.mp4', 'http://timg.bdta.pro/images/0261bf10fa7a7839b61a30447a585fb8.jpg'),
(86865, 6019, 'Os Flintstones S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183411.mp4', 'http://timg.bdta.pro/images/42f0d3a594d798e5cba01e39e058f763.jpg'),
(86866, 6019, 'Os Flintstones S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183412.mp4', 'http://timg.bdta.pro/images/232efed7404d8a8b82b08e15161e3a1a.jpg'),
(86867, 6019, 'Os Flintstones S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183413.mp4', 'http://timg.bdta.pro/images/8861c34c1511ccfaafc83010788cb6b3.jpg'),
(86868, 6019, 'Os Flintstones S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183414.mp4', 'http://timg.bdta.pro/images/008d129f46888b728036af1a3eb98fe8.jpg'),
(86869, 6019, 'Os Flintstones S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183415.mp4', 'http://timg.bdta.pro/images/6c6d9116397c5bbfe847388531543551.jpg'),
(86870, 6019, 'Os Flintstones S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183416.mp4', 'http://timg.bdta.pro/images/fe5e62b74608009f78c6c525b8edbc4e.jpg'),
(86871, 6019, 'Os Flintstones S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183417.mp4', 'http://timg.bdta.pro/images/278034e53bc2245eeab5cd77b87878f7.jpg'),
(86872, 6019, 'Os Flintstones S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183418.mp4', 'http://timg.bdta.pro/images/3cb742df76c6685e4fe991755fcf7b34.jpg'),
(86873, 6019, 'Os Flintstones S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183419.mp4', 'http://timg.bdta.pro/images/a57673e73cb2ad6edf35b0345fdda977.jpg'),
(86874, 6019, 'Os Flintstones S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183420.mp4', 'http://timg.bdta.pro/images/6af900ddf8ab6bd996f20c0cda28cd72.jpg'),
(86875, 6019, 'Os Flintstones S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/183421.mp4', 'http://timg.bdta.pro/images/52e07f840fcb5979d5b0912542e8d543.jpg'),
(86876, 6019, 'Os Flintstones S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/183422.mp4', 'http://timg.bdta.pro/images/1875a98633ff2ca4e4e2933ed26c03e4.jpg'),
(86877, 6019, 'Os Flintstones S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/183423.mp4', 'http://timg.bdta.pro/images/81a0f435e3bfb8f2cc2aa1c80c9ce196.jpg'),
(86878, 6019, 'Os Flintstones S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/183424.mp4', 'http://timg.bdta.pro/images/95eab0f0f97208a009a9944a1932a1a2.jpg'),
(86879, 6019, 'Os Flintstones S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/183425.mp4', 'http://timg.bdta.pro/images/6eb215245a8b6556afdd1129b8e36b32.jpg'),
(86880, 6019, 'Os Flintstones S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/183426.mp4', 'http://timg.bdta.pro/images/1db1f0fe45ec43fbdb1a3440f582fc52.jpg'),
(86881, 6019, 'Os Flintstones S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/183427.mp4', 'http://timg.bdta.pro/images/380501fc83602bdfa74d14eaa77046db.jpg'),
(86882, 6019, 'Os Flintstones S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/183428.mp4', 'http://timg.bdta.pro/images/0229a2a992b3ac1fc3d42b71ce8d2556.jpg'),
(86883, 6019, 'Os Flintstones S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/183429.mp4', 'http://timg.bdta.pro/images/0f7480f0270c058167adc903d893d9e6.jpg'),
(86884, 6019, 'Os Flintstones S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/183430.mp4', 'http://timg.bdta.pro/images/6fbc3d2e4a9b379674b92e66f684c5eb.jpg'),
(86885, 6019, 'Os Flintstones S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/183431.mp4', 'http://timg.bdta.pro/images/9b83220a4ec94d7aa0ddec193957f0a0.jpg'),
(86886, 6019, 'Os Flintstones S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/183432.mp4', 'http://timg.bdta.pro/images/dfabb1c07de5e0cbb856a91712bc9574.jpg'),
(86887, 6019, 'Os Flintstones S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/183433.mp4', 'http://timg.bdta.pro/images/4d74d01bf7248a3430c7f82ed5879bd0.jpg'),
(86888, 6019, 'Os Flintstones S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/183434.mp4', 'http://timg.bdta.pro/images/11623d6310211ed92b3d9c0481a08b44.jpg'),
(86889, 6019, 'Os Flintstones S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/183435.mp4', 'http://timg.bdta.pro/images/15bcce75fdb6fe2ecad2d7c50c5a79f6.jpg'),
(86890, 6019, 'Os Flintstones S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/183436.mp4', 'http://timg.bdta.pro/images/e03f6f3990d31040abcf8206ccf61740.jpg'),
(86891, 6019, 'Os Flintstones S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/183437.mp4', 'http://timg.bdta.pro/images/9ba3bea5a959baa43048b3f5f411a978.jpg'),
(86892, 6019, 'Os Flintstones S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/183438.mp4', 'http://timg.bdta.pro/images/7b98f7b936d324b04c4f4d23e9058b21.jpg'),
(86893, 6019, 'Os Flintstones S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/183439.mp4', 'http://timg.bdta.pro/images/f4d19067bb083f17bc268dd52124323a.jpg'),
(86894, 6019, 'Os Flintstones S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/183440.mp4', 'http://timg.bdta.pro/images/78e946512b32b0feee3f352a4a63d253.jpg'),
(86895, 6020, 'Os Flintstones S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183441.mp4', 'http://timg.bdta.pro/images/c6015c929a6cf118686e33b04f7d38bb.jpg'),
(86896, 6020, 'Os Flintstones S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183442.mp4', 'http://timg.bdta.pro/images/7e8fc306c1ee37e1543f6d6bc2298b9d.jpg'),
(86897, 6020, 'Os Flintstones S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183443.mp4', 'http://timg.bdta.pro/images/5c633ed2054693f440c1e995136cbf6e.jpg'),
(86898, 6020, 'Os Flintstones S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183444.mp4', 'http://timg.bdta.pro/images/2dc1d592b9540492b5efb5267d9d39e2.jpg'),
(86899, 6020, 'Os Flintstones S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183445.mp4', 'http://timg.bdta.pro/images/5e628a42b91b4f35ee40e5b4a698e377.jpg'),
(86900, 6020, 'Os Flintstones S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183446.mp4', 'http://timg.bdta.pro/images/65c0f6341260e7ed3ee7fb6dec737da7.jpg'),
(86901, 6020, 'Os Flintstones S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183447.mp4', 'http://timg.bdta.pro/images/2d5536a675432ceddb5aa6a750f4acd8.jpg'),
(86902, 6020, 'Os Flintstones S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183448.mp4', 'http://timg.bdta.pro/images/d4f3d7143af5fb3c96a303e916b76dcf.jpg'),
(86903, 6020, 'Os Flintstones S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183449.mp4', 'http://timg.bdta.pro/images/21de7eb0c4d98311f1df2005c8d852d5.jpg'),
(86904, 6020, 'Os Flintstones S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183450.mp4', 'http://timg.bdta.pro/images/482547e8e129be7f73c6aedb6ea7d491.jpg'),
(86905, 6020, 'Os Flintstones S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183451.mp4', 'http://timg.bdta.pro/images/8a88bf1d634c15447546565b93921add.jpg'),
(86906, 6020, 'Os Flintstones S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183452.mp4', 'http://timg.bdta.pro/images/6ca51ab2147e2d4ec30313f38f216405.jpg'),
(86907, 6020, 'Os Flintstones S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/183453.mp4', 'http://timg.bdta.pro/images/ec4c4f3493554857fd893f285dc3b10b.jpg'),
(86908, 6020, 'Os Flintstones S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/183454.mp4', 'http://timg.bdta.pro/images/82d2ecb9fbc52831d0f4d180ead83263.jpg'),
(86909, 6020, 'Os Flintstones S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/183455.mp4', 'http://timg.bdta.pro/images/b4c9dc4cf1876e639bbc80d2d8d98273.jpg'),
(86910, 6020, 'Os Flintstones S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/183456.mp4', 'http://timg.bdta.pro/images/92a434a1aa14913c2a98fc1c93c92e66.jpg'),
(86911, 6020, 'Os Flintstones S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/183457.mp4', 'http://timg.bdta.pro/images/6b35b6d066a97ff339771d195438fe5f.jpg'),
(86912, 6020, 'Os Flintstones S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/183458.mp4', 'http://timg.bdta.pro/images/dd79a5a2ea99a8efb99729f7407c5ecd.jpg'),
(86913, 6020, 'Os Flintstones S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/183459.mp4', 'http://timg.bdta.pro/images/6b0519cb92941b3a0ea1bd8398b10fc3.jpg'),
(86914, 6020, 'Os Flintstones S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/183460.mp4', 'http://timg.bdta.pro/images/7af6283e4076a8d15f213bf27f501247.jpg'),
(86915, 6020, 'Os Flintstones S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/183461.mp4', 'http://timg.bdta.pro/images/0826d5fbdd48ff723b90afc24677f210.jpg'),
(86916, 6020, 'Os Flintstones S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/183462.mp4', 'http://timg.bdta.pro/images/f522d3b9445cbd1e4d1fcfdc14bf0384.jpg'),
(86917, 6020, 'Os Flintstones S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/183463.mp4', 'http://timg.bdta.pro/images/4da9b41bc9da581cce258fbe70f72421.jpg'),
(86918, 6020, 'Os Flintstones S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/183464.mp4', 'http://timg.bdta.pro/images/ee9d55a9be762e9becf6f043041f7b0f.jpg'),
(86919, 6020, 'Os Flintstones S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/183465.mp4', 'http://timg.bdta.pro/images/1e2c1694ca277991dce9b305fb694c2a.jpg'),
(86920, 6020, 'Os Flintstones S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/183466.mp4', 'http://timg.bdta.pro/images/6f1b6e160bcf77c0b20c8e1b97b6145a.jpg'),
(86921, 6020, 'Os Flintstones S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/183467.mp4', 'http://timg.bdta.pro/images/c6cb546666318aa1840e9c9611c94b04.jpg'),
(86922, 6020, 'Os Flintstones S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/183468.mp4', 'http://timg.bdta.pro/images/105c0bbe20932195e3390179d76d790a.jpg'),
(86923, 6021, 'Os Flintstones S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183469.mp4', 'http://timg.bdta.pro/images/f1f7f6f43918c90a248698399e6179b9.jpg'),
(86924, 6021, 'Os Flintstones S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183470.mp4', 'http://timg.bdta.pro/images/b274a68b12f74c572573b355879a8584.jpg'),
(86925, 6021, 'Os Flintstones S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183471.mp4', 'http://timg.bdta.pro/images/9cad9d467294da6d9220977a1d9850ee.jpg'),
(86926, 6021, 'Os Flintstones S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183472.mp4', 'http://timg.bdta.pro/images/1735cfdde5149c6433fbe42b2dba64f7.jpg'),
(86927, 6021, 'Os Flintstones S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183473.mp4', 'http://timg.bdta.pro/images/014e2b8adcdd8b1b32beb08fe293e4f5.jpg'),
(86928, 6021, 'Os Flintstones S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183474.mp4', 'http://timg.bdta.pro/images/827763d0302b3d726a881f94c50d1fc7.jpg'),
(86929, 6021, 'Os Flintstones S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183475.mp4', 'http://timg.bdta.pro/images/ae3afd8e37597c322e73c244beac984f.jpg'),
(86930, 6021, 'Os Flintstones S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183476.mp4', 'http://timg.bdta.pro/images/7395d7fb853b12319d433159d77881e6.jpg'),
(86931, 6021, 'Os Flintstones S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183477.mp4', 'http://timg.bdta.pro/images/be67bdab29490956b8d5445bcd12dd6a.jpg'),
(86932, 6021, 'Os Flintstones S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183478.mp4', 'http://timg.bdta.pro/images/465e66958cabc9c46cc8a1cbd08ac34b.jpg'),
(86933, 6021, 'Os Flintstones S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183479.mp4', 'http://timg.bdta.pro/images/a7d710e412d7f656b1d4a11f7d0719e9.jpg'),
(86934, 6021, 'Os Flintstones S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183480.mp4', 'http://timg.bdta.pro/images/db99fb7c292ef12f8313e789edfd0e3f.jpg'),
(86935, 6021, 'Os Flintstones S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/183481.mp4', 'http://timg.bdta.pro/images/68ba6add4673f26eddb820c81aeb181b.jpg'),
(86936, 6021, 'Os Flintstones S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/183482.mp4', 'http://timg.bdta.pro/images/2a896e2f916d481bc5ac94a660601623.jpg'),
(86937, 6021, 'Os Flintstones S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/183483.mp4', 'http://timg.bdta.pro/images/26413e7681679d28cef0e57d95dabf68.jpg'),
(86938, 6021, 'Os Flintstones S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/183484.mp4', 'http://timg.bdta.pro/images/797864943798652807815dbca77a8558.jpg'),
(86939, 6021, 'Os Flintstones S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/183485.mp4', 'http://timg.bdta.pro/images/4f6def507b00299ded32315431b09eb8.jpg'),
(86940, 6021, 'Os Flintstones S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/183486.mp4', 'http://timg.bdta.pro/images/a8b62e9f247e3780ef9df5d9b2532691.jpg'),
(86941, 6021, 'Os Flintstones S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/183487.mp4', 'http://timg.bdta.pro/images/dba24b6c69724ea0ba35c944b8df669b.jpg'),
(86942, 6021, 'Os Flintstones S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/183488.mp4', 'http://timg.bdta.pro/images/acb0a77831010fa554c6cd89b407032e.jpg'),
(86943, 6021, 'Os Flintstones S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/183489.mp4', 'http://timg.bdta.pro/images/5500fb16bf69fb9600940c40d73489f6.jpg'),
(86944, 6022, 'Os Flintstones S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183490.mp4', 'http://timg.bdta.pro/images/0e1279ab8b3215d4b399d03db9be1f4b.jpg'),
(86945, 6022, 'Os Flintstones S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183491.mp4', 'http://timg.bdta.pro/images/a88a8bfa41fefc17c0409893ea980a05.jpg'),
(86946, 6022, 'Os Flintstones S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183492.mp4', 'http://timg.bdta.pro/images/06d4c73b4db1465475ed27e4b5350e36.jpg'),
(86947, 6022, 'Os Flintstones S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183493.mp4', 'http://timg.bdta.pro/images/cf15ee2f85a1797930ea1b678d294472.jpg'),
(86948, 6022, 'Os Flintstones S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183494.mp4', 'http://timg.bdta.pro/images/f7a39f4bc64d533268aa09462af67431.jpg'),
(86949, 6022, 'Os Flintstones S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183495.mp4', 'http://timg.bdta.pro/images/d1d37755b98586d68531c4731bf1e15a.jpg'),
(86950, 6022, 'Os Flintstones S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183496.mp4', 'http://timg.bdta.pro/images/c4d7cac78adeadbdd4d646ac3eb0a666.jpg'),
(86951, 6022, 'Os Flintstones S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183497.mp4', 'http://timg.bdta.pro/images/82654e348819ff5747f2f157a8b25cf1.jpg'),
(86952, 6022, 'Os Flintstones S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183498.mp4', 'http://timg.bdta.pro/images/3d70780c16f83be897e6b3b005a6de5f.jpg'),
(86953, 6022, 'Os Flintstones S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183499.mp4', 'http://timg.bdta.pro/images/5a71301f137e013354c42abae7c9a7e5.jpg'),
(86954, 6022, 'Os Flintstones S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183500.mp4', 'http://timg.bdta.pro/images/c0958bbe330ba59cb1fc01aaf4546326.jpg'),
(86955, 6022, 'Os Flintstones S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183501.mp4', 'http://timg.bdta.pro/images/e97c0ec073592b52ff252a7b50f0b9fc.jpg'),
(86956, 6022, 'Os Flintstones S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/183502.mp4', 'http://timg.bdta.pro/images/c595245bdcc02612c4e511062b5a9a39.jpg'),
(86957, 6022, 'Os Flintstones S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/183503.mp4', 'http://timg.bdta.pro/images/ec6595eaf575c2c2ec9beb684554e863.jpg'),
(86958, 6022, 'Os Flintstones S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/183504.mp4', 'http://timg.bdta.pro/images/50d65bcce41a759a77ac8c8d655f4d32.jpg'),
(86959, 6022, 'Os Flintstones S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/183505.mp4', 'http://timg.bdta.pro/images/01931e286ac010c796b082a7fb497703.jpg'),
(86960, 6022, 'Os Flintstones S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/183506.mp4', 'http://timg.bdta.pro/images/8835cbac132b9222a4296d0a66cb4e47.jpg'),
(86961, 6022, 'Os Flintstones S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/183507.mp4', 'http://timg.bdta.pro/images/6747e3968395d9d65bd73679f9af6ff5.jpg'),
(86962, 6022, 'Os Flintstones S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/183508.mp4', 'http://timg.bdta.pro/images/089809ff32ff097370f4c7dc84f89a26.jpg'),
(86963, 6022, 'Os Flintstones S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/183509.mp4', 'http://timg.bdta.pro/images/5a5b1958f2edbc2565bb97a4cc5c8295.jpg'),
(86964, 6022, 'Os Flintstones S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/183510.mp4', 'http://timg.bdta.pro/images/c7e7b7fbb058e5cf2086bf7e14334ad2.jpg'),
(86965, 6022, 'Os Flintstones S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/183511.mp4', 'http://timg.bdta.pro/images/f40748c10a559c63ab6437e74923b8b6.jpg'),
(86966, 6022, 'Os Flintstones S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/183512.mp4', 'http://timg.bdta.pro/images/5a10381be94a80bd2aff792aad7d9c6f.jpg'),
(86967, 6022, 'Os Flintstones S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/183513.mp4', 'http://timg.bdta.pro/images/43befc2ebf2a19ca87ea1260b837b6fd.jpg'),
(86968, 6022, 'Os Flintstones S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/183514.mp4', 'http://timg.bdta.pro/images/a903183e77f04e2edadc69862a1f34ec.jpg'),
(86969, 6023, 'Os Padrinhos Mágicos: Mais Mágicos Que Nunca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183369.mp4', 'http://timg.bdta.pro/images/ff12a77fc2ef9ee717fa79a93c2565ea.jpg'),
(86970, 6023, 'Os Padrinhos Mágicos: Mais Mágicos Que Nunca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183370.mp4', 'http://timg.bdta.pro/images/813cd41d2e7e65cb6d73c0db03ea97d8.jpg'),
(86971, 6023, 'Os Padrinhos Mágicos: Mais Mágicos Que Nunca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183371.mp4', 'http://timg.bdta.pro/images/1bb8b118d90f2c7d5161e6a367bcde5d.jpg'),
(86972, 6023, 'Os Padrinhos Mágicos: Mais Mágicos Que Nunca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183372.mp4', 'http://timg.bdta.pro/images/6a5c2e9bf50a7daabe7337e636aef139.jpg'),
(86973, 6023, 'Os Padrinhos Mágicos: Mais Mágicos Que Nunca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183373.mp4', 'http://timg.bdta.pro/images/ab711f55da33c712e67b59514ef9068e.jpg'),
(86974, 6023, 'Os Padrinhos Mágicos: Mais Mágicos Que Nunca S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183374.mp4', 'http://timg.bdta.pro/images/224a90aa1e2d76333b250536d8136235.jpg'),
(86975, 6023, 'Os Padrinhos Mágicos: Mais Mágicos Que Nunca S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183375.mp4', 'http://timg.bdta.pro/images/79f45e8f9642b5298b1b477a9da1ede4.jpg'),
(86976, 6023, 'Os Padrinhos Mágicos: Mais Mágicos Que Nunca S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183376.mp4', 'http://timg.bdta.pro/images/4e36a39c5490d5ec451e50445763e1ba.jpg'),
(86977, 6023, 'Os Padrinhos Mágicos: Mais Mágicos Que Nunca S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183377.mp4', 'http://timg.bdta.pro/images/1ccec3cd23e0c449ee8b75f33dda0447.jpg'),
(86978, 6023, 'Os Padrinhos Mágicos: Mais Mágicos Que Nunca S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183378.mp4', 'http://timg.bdta.pro/images/ee95a75ba7447a75bf78e5c8fa1106c4.jpg'),
(86979, 6023, 'Os Padrinhos Mágicos: Mais Mágicos Que Nunca S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183379.mp4', 'http://timg.bdta.pro/images/35a979396c91b7c4f3665dbebd1a6d97.jpg'),
(86980, 6023, 'Os Padrinhos Mágicos: Mais Mágicos Que Nunca S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183380.mp4', 'http://timg.bdta.pro/images/8b1c4c7411868b0c98fe3120c4090d96.jpg'),
(86981, 6024, 'Os Top Dez dos Anos 80 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183363.mp4', 'http://timg.bdta.pro/images/4c25d290d10f248ec304b824acba181f.jpg'),
(86982, 6024, 'Os Top Dez dos Anos 80 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183364.mp4', 'http://timg.bdta.pro/images/f6b8464ce30ab222d30c7255785d6fdf.jpg'),
(86983, 6024, 'Os Top Dez dos Anos 80 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183365.mp4', 'http://timg.bdta.pro/images/b9cefed6e5caaf8fc07744dcbd33c8cd.jpg'),
(86984, 6024, 'Os Top Dez dos Anos 80 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183366.mp4', 'http://timg.bdta.pro/images/05e71335dad89173286d24b19a9fde1b.jpg'),
(86985, 6024, 'Os Top Dez dos Anos 80 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183367.mp4', 'http://timg.bdta.pro/images/e0c64d3c371de03fdbe54c32ae6f149e.jpg'),
(86986, 6024, 'Os Top Dez dos Anos 80 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183368.mp4', 'http://timg.bdta.pro/images/8b097515adc1ad1d08fd2b7579ac495a.jpg'),
(86987, 6025, 'Queen Loretta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183359.mp4', 'http://timg.bdta.pro/images/f1e17849bd98eceb41edd58b5c1e99ea.jpg'),
(86988, 6025, 'Queen Loretta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183360.mp4', 'http://timg.bdta.pro/images/481a2c6b3db43943b8307896fa14e93c.jpg'),
(86989, 6025, 'Queen Loretta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183361.mp4', 'http://timg.bdta.pro/images/59a681fa7e658e90d609bbc6ff079125.jpg'),
(86990, 6025, 'Queen Loretta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183362.mp4', 'http://timg.bdta.pro/images/72f3f7e8ab29625b050fe4c20ee58777.jpg'),
(86991, 3080, 'Sem Limites S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183353.mp4', 'http://timg.bdta.pro/images/58ec7356e4b3ee9c9a9ae399089f7170.jpg'),
(86992, 3080, 'Sem Limites S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183354.mp4', 'http://timg.bdta.pro/images/22ccde6f61b214836b69b9d3c15126bb.jpg'),
(86993, 3080, 'Sem Limites S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183355.mp4', 'http://timg.bdta.pro/images/1576cb9f8a97a7f7c2553631e6f547c6.jpg'),
(86994, 3080, 'Sem Limites S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183356.mp4', 'http://timg.bdta.pro/images/06f6554c7c7962e0f6c985033c647c56.jpg'),
(86995, 3080, 'Sem Limites S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183357.mp4', 'http://timg.bdta.pro/images/898a6f5ae99fdba3536c083c6b70add1.jpg'),
(86996, 3080, 'Sem Limites S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183358.mp4', 'http://timg.bdta.pro/images/c0725590890a15463ed9726dea6d04cb.jpg'),
(86997, 6026, 'Takt Op. Destiny S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183341.mp4', 'http://timg.bdta.pro/images/ab5c4098cda06ba62821039891722f5f.jpg'),
(86998, 6026, 'Takt Op. Destiny S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183342.mp4', 'http://timg.bdta.pro/images/d0391d1f72f77475117ddb979271fae7.jpg'),
(86999, 6026, 'Takt Op. Destiny S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183343.mp4', 'http://timg.bdta.pro/images/533b6026acee0000b13367a79f8cc140.jpg'),
(87000, 6026, 'Takt Op. Destiny S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183344.mp4', 'http://timg.bdta.pro/images/c09666bd5cc033b65248160bc3325dfe.jpg'),
(87001, 6026, 'Takt Op. Destiny S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183345.mp4', 'http://timg.bdta.pro/images/751f15e98360aa8a964625148410d228.jpg'),
(87002, 6026, 'Takt Op. Destiny S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183346.mp4', 'http://timg.bdta.pro/images/887e92c717627647ee5c122e0a3b3e11.jpg'),
(87003, 6026, 'Takt Op. Destiny S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183347.mp4', 'http://timg.bdta.pro/images/6163d4ef57a9313033399b770d32accc.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(87004, 6026, 'Takt Op. Destiny S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183348.mp4', 'http://timg.bdta.pro/images/ca514bd011a9c9e6a35a676735186b7d.jpg'),
(87005, 6026, 'Takt Op. Destiny S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183349.mp4', 'http://timg.bdta.pro/images/3b090580e2363ce36cc34f41433ade83.jpg'),
(87006, 6026, 'Takt Op. Destiny S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183350.mp4', 'http://timg.bdta.pro/images/d8f4d6ae7498db603d5277b120380410.jpg'),
(87007, 6026, 'Takt Op. Destiny S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183351.mp4', 'http://timg.bdta.pro/images/02b55cd4e4d151df3a06db224bdc3c43.jpg'),
(87008, 6026, 'Takt Op. Destiny S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183352.mp4', 'http://timg.bdta.pro/images/c78d661ffb9e1305422138c0c6218cbe.jpg'),
(87009, 6027, 'That Damn Michael Che S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183335.mp4', 'http://timg.bdta.pro/images/8f204918152183d00a48568aaab0be8d.jpg'),
(87010, 6027, 'That Damn Michael Che S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183336.mp4', 'http://timg.bdta.pro/images/0b66ce7b5117318247cad141a49b2a20.jpg'),
(87011, 6027, 'That Damn Michael Che S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183337.mp4', 'http://timg.bdta.pro/images/b8152b7be4ef1afdd9093d1b0b3c92b1.jpg'),
(87012, 6027, 'That Damn Michael Che S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183338.mp4', 'http://timg.bdta.pro/images/50e3ccc68628d55d50217c034b983696.jpg'),
(87013, 6027, 'That Damn Michael Che S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183339.mp4', 'http://timg.bdta.pro/images/7dde91e95c06e2774ccfc94150c8bf4f.jpg'),
(87014, 6027, 'That Damn Michael Che S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183340.mp4', 'http://timg.bdta.pro/images/d7f48d6ad39bf06393e9dc8cb3ea2024.jpg'),
(87015, 6028, 'The Dropout S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183327.mp4', 'http://timg.bdta.pro/images/4ece4ad6ef6dfc53fd01a1134a58aab1.jpg'),
(87016, 6028, 'The Dropout S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183328.mp4', 'http://timg.bdta.pro/images/f61b45fcfbe86164bafa4d9b77c14619.jpg'),
(87017, 6028, 'The Dropout S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183329.mp4', 'http://timg.bdta.pro/images/1ebf16333e73880c40d84ce0577b913c.jpg'),
(87018, 6028, 'The Dropout S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183330.mp4', 'http://timg.bdta.pro/images/0e975e05100fef938d344f54a952d17f.jpg'),
(87019, 6028, 'The Dropout S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183331.mp4', 'http://timg.bdta.pro/images/36d7d24920acba0a4d77dc48d1f10767.jpg'),
(87020, 6028, 'The Dropout S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183332.mp4', 'http://timg.bdta.pro/images/4dadbc4f1d014b7682bb880a65ab2344.jpg'),
(87021, 6028, 'The Dropout S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183333.mp4', 'http://timg.bdta.pro/images/cb5079eb80bed9f21f118b45a7fee3da.jpg'),
(87022, 6028, 'The Dropout S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183334.mp4', 'http://timg.bdta.pro/images/48e4e9d666be73251b4fcafe30fc3cdd.jpg'),
(87023, 6029, '190: Inteligência Contra o Crime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183310.mp4', 'http://gstaticontent.com/images/58662b3fe927309ff87a76b95cce6d49.jpg'),
(87024, 6029, '190: Inteligência Contra o Crime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183311.mp4', 'http://gstaticontent.com/images/58662b3fe927309ff87a76b95cce6d49.jpg'),
(87025, 6029, '190: Inteligência Contra o Crime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183312.mp4', 'http://gstaticontent.com/images/58662b3fe927309ff87a76b95cce6d49.jpg'),
(87026, 6029, '190: Inteligência Contra o Crime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183313.mp4', 'http://gstaticontent.com/images/58662b3fe927309ff87a76b95cce6d49.jpg'),
(87027, 6029, '190: Inteligência Contra o Crime S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183314.mp4', 'http://gstaticontent.com/images/58662b3fe927309ff87a76b95cce6d49.jpg'),
(87028, 6029, '190: Inteligência Contra o Crime S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183315.mp4', 'http://gstaticontent.com/images/58662b3fe927309ff87a76b95cce6d49.jpg'),
(87029, 6029, '190: Inteligência Contra o Crime S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183316.mp4', 'http://gstaticontent.com/images/58662b3fe927309ff87a76b95cce6d49.jpg'),
(87030, 6030, 'Avisa Lá Que Eu Vou S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219053.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87031, 6030, 'Avisa Lá Que Eu Vou S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219054.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87032, 6030, 'Avisa Lá Que Eu Vou S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219055.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87033, 6030, 'Avisa Lá Que Eu Vou S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219056.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87034, 6030, 'Avisa Lá Que Eu Vou S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219057.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87035, 6030, 'Avisa Lá Que Eu Vou S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219058.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87036, 6030, 'Avisa Lá Que Eu Vou S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219059.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87037, 6030, 'Avisa Lá Que Eu Vou S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219060.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87038, 6030, 'Avisa Lá Que Eu Vou S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219061.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87039, 6030, 'Avisa Lá Que Eu Vou S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219062.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87040, 6031, 'Avisa Lá Que Eu Vou S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219063.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87041, 6031, 'Avisa Lá Que Eu Vou S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219064.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87042, 6031, 'Avisa Lá Que Eu Vou S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219065.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87043, 6031, 'Avisa Lá Que Eu Vou S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219066.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87044, 6031, 'Avisa Lá Que Eu Vou S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219067.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87045, 6031, 'Avisa Lá Que Eu Vou S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219068.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87046, 6031, 'Avisa Lá Que Eu Vou S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219069.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87047, 6031, 'Avisa Lá Que Eu Vou S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219070.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87048, 6031, 'Avisa Lá Que Eu Vou S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219071.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87049, 6031, 'Avisa Lá Que Eu Vou S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219072.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87050, 6032, 'Avisa Lá Que Eu Vou S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353312.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87051, 6032, 'Avisa Lá Que Eu Vou S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353313.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87052, 6032, 'Avisa Lá Que Eu Vou S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/360394.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87053, 6032, 'Avisa Lá Que Eu Vou S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/369714.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87054, 6032, 'Avisa Lá Que Eu Vou S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/375457.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87055, 6032, 'Avisa Lá Que Eu Vou S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/383375.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87056, 6032, 'Avisa Lá Que Eu Vou S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/385117.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87057, 6032, 'Avisa Lá Que Eu Vou S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/399933.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87058, 6032, 'Avisa Lá Que Eu Vou S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/399934.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87059, 6032, 'Avisa Lá Que Eu Vou S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/406471.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87060, 6033, 'Avisa Lá Que Eu Vou S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/847757.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87061, 6033, 'Avisa Lá Que Eu Vou S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/852042.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87062, 6033, 'Avisa Lá Que Eu Vou S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/857551.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87063, 6033, 'Avisa Lá Que Eu Vou S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/864861.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87064, 6033, 'Avisa Lá Que Eu Vou S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/870938.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87065, 6033, 'Avisa Lá Que Eu Vou S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/874754.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87066, 6033, 'Avisa Lá Que Eu Vou S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/879438.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87067, 6033, 'Avisa Lá Que Eu Vou S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/879894.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87068, 6033, 'Avisa Lá Que Eu Vou S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/880415.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87069, 6033, 'Avisa Lá Que Eu Vou S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/881256.mp4', 'http://gstaticontent.com/images/264452e7d4028382ee1891555656ba81.jpg'),
(87070, 6034, 'Black Bird S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190345.mp4', 'http://timg.bdta.pro/images/91311f835596b07f37340a2b022aa02f.jpg'),
(87071, 6034, 'Black Bird S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190346.mp4', 'http://timg.bdta.pro/images/822d5e99129cea8b053dacb5d59f3690.jpg'),
(87072, 6034, 'Black Bird S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190347.mp4', 'http://timg.bdta.pro/images/531d2043b7bff70d283f4328f2dec0c9.jpg'),
(87073, 6034, 'Black Bird S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190348.mp4', 'http://timg.bdta.pro/images/cdfc5b404ddb1e85e0d1b18ab5f30780.jpg'),
(87074, 6034, 'Black Bird S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190349.mp4', 'http://timg.bdta.pro/images/afe1c5180c8aed59137b307b515950c0.jpg'),
(87075, 6034, 'Black Bird S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190350.mp4', 'http://timg.bdta.pro/images/815bc007676921bceb4bc4d44981e52b.jpg'),
(87076, 6035, 'Bitch S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183301.mp4', 'http://timg.bdta.pro/images/664cea07bbaa01c56d8fe2112addf119.jpg'),
(87077, 6035, 'Bitch S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183302.mp4', 'http://timg.bdta.pro/images/11459dfe9d36cc0ed3d1377244fea31b.jpg'),
(87078, 6035, 'Bitch S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183303.mp4', 'http://timg.bdta.pro/images/cdf25ea9853351a92e4b21e7cd7e24b2.jpg'),
(87079, 6035, 'Bitch S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183304.mp4', 'http://timg.bdta.pro/images/7d6a9c4bf3e8462e3ad1520e54368bca.jpg'),
(87080, 6035, 'Bitch S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183305.mp4', 'http://timg.bdta.pro/images/b63042f49839be382e7c6b2327b65f01.jpg'),
(87081, 6035, 'Bitch S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183306.mp4', 'http://timg.bdta.pro/images/6a9049b87456d0fbaf193fd2cdb153c1.jpg'),
(87082, 6035, 'Bitch S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183307.mp4', 'http://timg.bdta.pro/images/e00887698d361beac60fcf52bf01416d.jpg'),
(87083, 6035, 'Bitch S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183308.mp4', 'http://timg.bdta.pro/images/9c92741c9fd0fb1f24bc98b23e339905.jpg'),
(87084, 6036, 'Desapegue Se For Capaz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224402.mp4', 'http://gstaticontent.com/images/afcf9d9228ccbca242706eeccc30fad0.jpg'),
(87085, 6036, 'Desapegue Se For Capaz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224403.mp4', 'http://gstaticontent.com/images/afcf9d9228ccbca242706eeccc30fad0.jpg'),
(87086, 6036, 'Desapegue Se For Capaz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224404.mp4', 'http://gstaticontent.com/images/afcf9d9228ccbca242706eeccc30fad0.jpg'),
(87087, 6036, 'Desapegue Se For Capaz S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224405.mp4', 'http://gstaticontent.com/images/afcf9d9228ccbca242706eeccc30fad0.jpg'),
(87088, 6036, 'Desapegue Se For Capaz S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224406.mp4', 'http://gstaticontent.com/images/afcf9d9228ccbca242706eeccc30fad0.jpg'),
(87089, 6036, 'Desapegue Se For Capaz S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224407.mp4', 'http://gstaticontent.com/images/afcf9d9228ccbca242706eeccc30fad0.jpg'),
(87090, 6036, 'Desapegue Se For Capaz S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224408.mp4', 'http://gstaticontent.com/images/afcf9d9228ccbca242706eeccc30fad0.jpg'),
(87091, 6036, 'Desapegue Se For Capaz S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224409.mp4', 'http://gstaticontent.com/images/afcf9d9228ccbca242706eeccc30fad0.jpg'),
(87092, 6036, 'Desapegue Se For Capaz S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224410.mp4', 'http://gstaticontent.com/images/afcf9d9228ccbca242706eeccc30fad0.jpg'),
(87093, 6036, 'Desapegue Se For Capaz S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224411.mp4', 'http://gstaticontent.com/images/afcf9d9228ccbca242706eeccc30fad0.jpg'),
(87094, 6037, 'Desapegue Se For Capaz S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224412.mp4', 'http://gstaticontent.com/images/afcf9d9228ccbca242706eeccc30fad0.jpg'),
(87095, 6037, 'Desapegue Se For Capaz S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224413.mp4', 'http://gstaticontent.com/images/afcf9d9228ccbca242706eeccc30fad0.jpg'),
(87096, 6037, 'Desapegue Se For Capaz S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224414.mp4', 'http://gstaticontent.com/images/afcf9d9228ccbca242706eeccc30fad0.jpg'),
(87097, 6037, 'Desapegue Se For Capaz S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224415.mp4', 'http://gstaticontent.com/images/afcf9d9228ccbca242706eeccc30fad0.jpg'),
(87098, 6037, 'Desapegue Se For Capaz S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224416.mp4', 'http://gstaticontent.com/images/afcf9d9228ccbca242706eeccc30fad0.jpg'),
(87099, 6037, 'Desapegue Se For Capaz S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224417.mp4', 'http://gstaticontent.com/images/afcf9d9228ccbca242706eeccc30fad0.jpg'),
(87100, 6037, 'Desapegue Se For Capaz S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224418.mp4', 'http://gstaticontent.com/images/afcf9d9228ccbca242706eeccc30fad0.jpg'),
(87101, 6037, 'Desapegue Se For Capaz S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224419.mp4', 'http://gstaticontent.com/images/afcf9d9228ccbca242706eeccc30fad0.jpg'),
(87102, 6037, 'Desapegue Se For Capaz S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224420.mp4', 'http://gstaticontent.com/images/afcf9d9228ccbca242706eeccc30fad0.jpg'),
(87103, 6037, 'Desapegue Se For Capaz S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224421.mp4', 'http://gstaticontent.com/images/afcf9d9228ccbca242706eeccc30fad0.jpg'),
(87104, 6038, 'Designers So Que Nao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183286.mp4', 'http://gstaticontent.com/images/48afdb34fea26ab4d582f07302619809.jpg'),
(87105, 6038, 'Designers So Que Nao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183287.mp4', 'http://gstaticontent.com/images/48afdb34fea26ab4d582f07302619809.jpg'),
(87106, 6038, 'Designers So Que Nao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183288.mp4', 'http://gstaticontent.com/images/48afdb34fea26ab4d582f07302619809.jpg'),
(87107, 6038, 'Designers So Que Nao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183289.mp4', 'http://gstaticontent.com/images/48afdb34fea26ab4d582f07302619809.jpg'),
(87108, 6038, 'Designers So Que Nao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183290.mp4', 'http://gstaticontent.com/images/48afdb34fea26ab4d582f07302619809.jpg'),
(87109, 6038, 'Designers So Que Nao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183291.mp4', 'http://gstaticontent.com/images/48afdb34fea26ab4d582f07302619809.jpg'),
(87110, 6038, 'Designers So Que Nao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183292.mp4', 'http://gstaticontent.com/images/48afdb34fea26ab4d582f07302619809.jpg'),
(87111, 6038, 'Designers So Que Nao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183293.mp4', 'http://gstaticontent.com/images/48afdb34fea26ab4d582f07302619809.jpg'),
(87112, 6039, 'Designers So Que Nao S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183294.mp4', 'http://gstaticontent.com/images/48afdb34fea26ab4d582f07302619809.jpg'),
(87113, 6039, 'Designers So Que Nao S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183295.mp4', 'http://gstaticontent.com/images/48afdb34fea26ab4d582f07302619809.jpg'),
(87114, 6039, 'Designers So Que Nao S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183296.mp4', 'http://gstaticontent.com/images/48afdb34fea26ab4d582f07302619809.jpg'),
(87115, 6039, 'Designers So Que Nao S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183297.mp4', 'http://gstaticontent.com/images/48afdb34fea26ab4d582f07302619809.jpg'),
(87116, 6039, 'Designers So Que Nao S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183298.mp4', 'http://gstaticontent.com/images/48afdb34fea26ab4d582f07302619809.jpg'),
(87117, 6039, 'Designers So Que Nao S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183299.mp4', 'http://gstaticontent.com/images/48afdb34fea26ab4d582f07302619809.jpg'),
(87118, 6039, 'Designers So Que Nao S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183300.mp4', 'http://gstaticontent.com/images/48afdb34fea26ab4d582f07302619809.jpg'),
(87119, 6040, 'Duelo de Restaurantes Irvine vs. Taffer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191938.mp4', 'http://gstaticontent.com/images/bb40c539f5c50d4f7e507c6c138d5505.jpg'),
(87120, 6040, 'Duelo de Restaurantes Irvine vs. Taffer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191939.mp4', 'http://gstaticontent.com/images/bb40c539f5c50d4f7e507c6c138d5505.jpg'),
(87121, 6040, 'Duelo de Restaurantes Irvine vs. Taffer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191940.mp4', 'http://gstaticontent.com/images/bb40c539f5c50d4f7e507c6c138d5505.jpg'),
(87122, 6041, 'Encontro Selvagem com Coyote Peterson S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183268.mp4', 'http://gstaticontent.com/images/bf9944bd5a96324937e57d8226d0e327.jpg'),
(87123, 6041, 'Encontro Selvagem com Coyote Peterson S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183269.mp4', 'http://gstaticontent.com/images/bf9944bd5a96324937e57d8226d0e327.jpg'),
(87124, 6041, 'Encontro Selvagem com Coyote Peterson S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183270.mp4', 'http://gstaticontent.com/images/bf9944bd5a96324937e57d8226d0e327.jpg'),
(87125, 6041, 'Encontro Selvagem com Coyote Peterson S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183271.mp4', 'http://gstaticontent.com/images/bf9944bd5a96324937e57d8226d0e327.jpg'),
(87126, 6041, 'Encontro Selvagem com Coyote Peterson S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183272.mp4', 'http://gstaticontent.com/images/bf9944bd5a96324937e57d8226d0e327.jpg'),
(87127, 6041, 'Encontro Selvagem com Coyote Peterson S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183273.mp4', 'http://gstaticontent.com/images/bf9944bd5a96324937e57d8226d0e327.jpg'),
(87128, 6041, 'Encontro Selvagem com Coyote Peterson S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183274.mp4', 'http://gstaticontent.com/images/bf9944bd5a96324937e57d8226d0e327.jpg'),
(87129, 6041, 'Encontro Selvagem com Coyote Peterson S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183275.mp4', 'http://gstaticontent.com/images/bf9944bd5a96324937e57d8226d0e327.jpg'),
(87130, 6041, 'Encontro Selvagem com Coyote Peterson S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183276.mp4', 'http://gstaticontent.com/images/bf9944bd5a96324937e57d8226d0e327.jpg'),
(87131, 6041, 'Encontro Selvagem com Coyote Peterson S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183277.mp4', 'http://gstaticontent.com/images/bf9944bd5a96324937e57d8226d0e327.jpg'),
(87132, 6041, 'Encontro Selvagem com Coyote Peterson S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183278.mp4', 'http://gstaticontent.com/images/bf9944bd5a96324937e57d8226d0e327.jpg'),
(87133, 6041, 'Encontro Selvagem com Coyote Peterson S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183279.mp4', 'http://gstaticontent.com/images/bf9944bd5a96324937e57d8226d0e327.jpg'),
(87134, 6041, 'Encontro Selvagem com Coyote Peterson S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/183280.mp4', 'http://gstaticontent.com/images/bf9944bd5a96324937e57d8226d0e327.jpg'),
(87135, 6041, 'Encontro Selvagem com Coyote Peterson S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/183281.mp4', 'http://gstaticontent.com/images/bf9944bd5a96324937e57d8226d0e327.jpg'),
(87136, 6041, 'Encontro Selvagem com Coyote Peterson S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/183282.mp4', 'http://gstaticontent.com/images/bf9944bd5a96324937e57d8226d0e327.jpg'),
(87137, 6041, 'Encontro Selvagem com Coyote Peterson S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/183283.mp4', 'http://gstaticontent.com/images/bf9944bd5a96324937e57d8226d0e327.jpg'),
(87138, 6041, 'Encontro Selvagem com Coyote Peterson S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/183284.mp4', 'http://gstaticontent.com/images/bf9944bd5a96324937e57d8226d0e327.jpg'),
(87139, 6041, 'Encontro Selvagem com Coyote Peterson S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/183285.mp4', 'http://gstaticontent.com/images/bf9944bd5a96324937e57d8226d0e327.jpg'),
(87140, 6042, 'Operação Naufrágios S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183258.mp4', 'http://gstaticontent.com/images/f5c523e4831af632ef4ca85d311bf148.jpg'),
(87141, 6042, 'Operação Naufrágios S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183259.mp4', 'http://gstaticontent.com/images/f5c523e4831af632ef4ca85d311bf148.jpg'),
(87142, 6042, 'Operação Naufrágios S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183260.mp4', 'http://gstaticontent.com/images/f5c523e4831af632ef4ca85d311bf148.jpg'),
(87143, 6042, 'Operação Naufrágios S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183261.mp4', 'http://gstaticontent.com/images/f5c523e4831af632ef4ca85d311bf148.jpg'),
(87144, 6042, 'Operação Naufrágios S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183262.mp4', 'http://gstaticontent.com/images/f5c523e4831af632ef4ca85d311bf148.jpg'),
(87145, 6042, 'Operação Naufrágios S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183263.mp4', 'http://gstaticontent.com/images/f5c523e4831af632ef4ca85d311bf148.jpg'),
(87146, 6042, 'Operação Naufrágios S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183264.mp4', 'http://gstaticontent.com/images/f5c523e4831af632ef4ca85d311bf148.jpg'),
(87147, 6042, 'Operação Naufrágios S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183265.mp4', 'http://gstaticontent.com/images/f5c523e4831af632ef4ca85d311bf148.jpg'),
(87148, 6042, 'Operação Naufrágios S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183266.mp4', 'http://gstaticontent.com/images/f5c523e4831af632ef4ca85d311bf148.jpg'),
(87149, 6042, 'Operação Naufrágios S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183267.mp4', 'http://gstaticontent.com/images/f5c523e4831af632ef4ca85d311bf148.jpg'),
(87150, 6043, 'Grandes Sonhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183250.mp4', 'http://timg.bdta.pro/images/24a67c55969161a18ad96440faabd35d.jpg'),
(87151, 6043, 'Grandes Sonhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183251.mp4', 'http://timg.bdta.pro/images/b33d02815072c59f522d8be562127590.jpg'),
(87152, 6043, 'Grandes Sonhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183252.mp4', 'http://timg.bdta.pro/images/a357680889b764b27236da69fffb0c38.jpg'),
(87153, 6043, 'Grandes Sonhos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183253.mp4', 'http://timg.bdta.pro/images/6811aef235a1bf59e496b270d014aa05.jpg'),
(87154, 6043, 'Grandes Sonhos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183254.mp4', 'http://timg.bdta.pro/images/fa9246d72c58097de8fe92ae7ff97a8b.jpg'),
(87155, 6043, 'Grandes Sonhos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183255.mp4', 'http://timg.bdta.pro/images/bcd72e98e3452fa79e72a37d04e6db50.jpg'),
(87156, 6043, 'Grandes Sonhos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183256.mp4', 'http://timg.bdta.pro/images/c029757af476ba80e3271c4edc505c87.jpg'),
(87157, 6043, 'Grandes Sonhos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183257.mp4', 'http://timg.bdta.pro/images/1ee3442cf601ab9798df7eae8e603913.jpg'),
(87158, 6044, 'Peter Nygard Alem da Moda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183246.mp4', 'http://gstaticontent.com/images/46a670cce60a54efd34b9e969d3bf93e.jpg'),
(87159, 6044, 'Peter Nygard Alem da Moda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183247.mp4', 'http://gstaticontent.com/images/46a670cce60a54efd34b9e969d3bf93e.jpg'),
(87160, 6044, 'Peter Nygard Alem da Moda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183248.mp4', 'http://gstaticontent.com/images/46a670cce60a54efd34b9e969d3bf93e.jpg'),
(87161, 6044, 'Peter Nygard Alem da Moda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183249.mp4', 'http://gstaticontent.com/images/46a670cce60a54efd34b9e969d3bf93e.jpg'),
(87162, 6045, 'Prisioneiro da Madrugada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183240.mp4', 'http://timg.bdta.pro/images/c4553a98695c4e23628dbbe0f12a9a19.jpg'),
(87163, 6045, 'Prisioneiro da Madrugada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183241.mp4', 'http://timg.bdta.pro/images/89fb70675fb4237be463c008ec58b702.jpg'),
(87164, 6045, 'Prisioneiro da Madrugada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183242.mp4', 'http://timg.bdta.pro/images/f1713dc60365394afdbb47e5fcc2782b.jpg'),
(87165, 6045, 'Prisioneiro da Madrugada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183243.mp4', 'http://timg.bdta.pro/images/5f4c2e4801d00d86176629b2f80ec208.jpg'),
(87166, 6045, 'Prisioneiro da Madrugada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183244.mp4', 'http://timg.bdta.pro/images/ef7adad706008110320dec75a97857d8.jpg'),
(87167, 6045, 'Prisioneiro da Madrugada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183245.mp4', 'http://timg.bdta.pro/images/bd62f03c38cf84653872c695efd0e36b.jpg'),
(87168, 6046, 'Ragdoll S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183234.mp4', 'http://timg.bdta.pro/images/e1dc395173d16a973944f671e1d338db.jpg'),
(87169, 6046, 'Ragdoll S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183235.mp4', 'http://timg.bdta.pro/images/940117d6d905ec9ba2b8a64d26d7a8d2.jpg'),
(87170, 6046, 'Ragdoll S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183236.mp4', 'http://timg.bdta.pro/images/ada5da1618ccb754983e03be22f339a7.jpg'),
(87171, 6046, 'Ragdoll S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183237.mp4', 'http://timg.bdta.pro/images/ea30b7bbf055c6f28e578b0ecb6bf237.jpg'),
(87172, 6046, 'Ragdoll S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183238.mp4', 'http://timg.bdta.pro/images/bca3002061931f1923b7e713c3081a7b.jpg'),
(87173, 6046, 'Ragdoll S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183239.mp4', 'http://timg.bdta.pro/images/5f6ce47eb3c2e8a84f6fdf390a5347f9.jpg'),
(87174, 6047, 'Rei dos Stonks S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183228.mp4', 'http://timg.bdta.pro/images/2238b20f3a9165addbe62e7141e18774.jpg'),
(87175, 6047, 'Rei dos Stonks S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183229.mp4', 'http://timg.bdta.pro/images/a850190e5a92d7f1c3a414e8156f2580.jpg'),
(87176, 6047, 'Rei dos Stonks S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183230.mp4', 'http://timg.bdta.pro/images/0872a7fb1f1f09c1ff659b5156333e82.jpg'),
(87177, 6047, 'Rei dos Stonks S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183231.mp4', 'http://timg.bdta.pro/images/02b503ff5a223aa78875143017cd16f9.jpg'),
(87178, 6047, 'Rei dos Stonks S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183232.mp4', 'http://timg.bdta.pro/images/a3143d0de854eb5736aa2d19b177fd26.jpg'),
(87179, 6047, 'Rei dos Stonks S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183233.mp4', 'http://timg.bdta.pro/images/a3681cce2105d45d70e52fa911e0a34b.jpg'),
(87180, 6048, 'Rikei ga Koi ni Ochita no de Shoumei shitemita. S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183216.mp4', 'http://timg.bdta.pro/images/e9fdcbf7472858740115b6500b8b599b.jpg'),
(87181, 6048, 'Rikei ga Koi ni Ochita no de Shoumei shitemita. S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183217.mp4', 'http://timg.bdta.pro/images/57045e231a57e2a32da6158c34c3bc51.jpg'),
(87182, 6048, 'Rikei ga Koi ni Ochita no de Shoumei shitemita. S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183218.mp4', 'http://timg.bdta.pro/images/ea6c5c1421b882d29d5e3d64ed017ab5.jpg'),
(87183, 6048, 'Rikei ga Koi ni Ochita no de Shoumei shitemita. S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183219.mp4', 'http://timg.bdta.pro/images/511ae3873deabc5c5e66dd592c451517.jpg'),
(87184, 6048, 'Rikei ga Koi ni Ochita no de Shoumei shitemita. S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183220.mp4', 'http://timg.bdta.pro/images/42af1d280c07b2b6f33428a95afe54f1.jpg'),
(87185, 6048, 'Rikei ga Koi ni Ochita no de Shoumei shitemita. S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183221.mp4', 'http://timg.bdta.pro/images/7ec49fde0bd1b6ba11fefa461cd9643d.jpg'),
(87186, 6048, 'Rikei ga Koi ni Ochita no de Shoumei shitemita. S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183222.mp4', 'http://timg.bdta.pro/images/880d3bfa85943921cc5543a45333dc7d.jpg'),
(87187, 6048, 'Rikei ga Koi ni Ochita no de Shoumei shitemita. S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183223.mp4', 'http://timg.bdta.pro/images/74b07475382fa17595665d6b3dac6a45.jpg'),
(87188, 6048, 'Rikei ga Koi ni Ochita no de Shoumei shitemita. S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183224.mp4', 'http://timg.bdta.pro/images/cf19c5013e55d73e7338697d5268eec3.jpg'),
(87189, 6048, 'Rikei ga Koi ni Ochita no de Shoumei shitemita. S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183225.mp4', 'http://timg.bdta.pro/images/88762118f37562558cd06ccdf45aa27e.jpg'),
(87190, 6048, 'Rikei ga Koi ni Ochita no de Shoumei shitemita. S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183226.mp4', 'http://timg.bdta.pro/images/aead4078a0461dee07ad0449778a915b.jpg'),
(87191, 6048, 'Rikei ga Koi ni Ochita no de Shoumei shitemita. S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183227.mp4', 'http://timg.bdta.pro/images/a7d0484561fa0c54929804f987e7e516.jpg'),
(87192, 6049, 'Spy x Family S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261668.mp4', 'http://timg.bdta.pro/images/2fe6d2c4fc0aba20161fb40bca8e766e.jpg'),
(87193, 6049, 'Spy x Family S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261669.mp4', 'http://timg.bdta.pro/images/d1b82a541dfeb75b5e2c9eedeb4f2aa3.jpg'),
(87194, 6049, 'Spy x Family S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261670.mp4', 'http://timg.bdta.pro/images/ae0527da82462359e2d235efb94c9883.jpg'),
(87195, 6049, 'Spy x Family S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261671.mp4', 'http://timg.bdta.pro/images/44dc6f92b035b7e231f6d55e4b47f0c4.jpg'),
(87196, 6049, 'Spy x Family S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261672.mp4', 'http://timg.bdta.pro/images/d6ba57e23055e3563e789b67b306462a.jpg'),
(87197, 6049, 'Spy x Family S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261673.mp4', 'http://timg.bdta.pro/images/6e09bcbaa7486ec3182483e168299396.jpg'),
(87198, 6049, 'Spy x Family S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261674.mp4', 'http://timg.bdta.pro/images/bdf73242a0fcf87e71a0d9c17fc45068.jpg'),
(87199, 6049, 'Spy x Family S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261675.mp4', 'http://timg.bdta.pro/images/8405e8c30537b3053fa29584a92009e3.jpg'),
(87200, 6049, 'Spy x Family S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261676.mp4', 'http://timg.bdta.pro/images/813eb653c525efaa20ea59821d6a3cf7.jpg'),
(87201, 6049, 'Spy x Family S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261677.mp4', 'http://timg.bdta.pro/images/c8e6be7dd6e1a858226897a13d1a5bba.jpg'),
(87202, 6049, 'Spy x Family S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/261678.mp4', 'http://timg.bdta.pro/images/d0326d0678bbd6e58c30d820acc8b1d0.jpg'),
(87203, 6049, 'Spy x Family S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/261679.mp4', 'http://timg.bdta.pro/images/a87a42be6168dccbc2fbcd77162e036e.jpg'),
(87204, 6049, 'Spy x Family S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/261680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ptqj33RZtS4GYiLlI2Upr7vdpU.jpg'),
(87205, 6049, 'Spy x Family S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/261681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q3tcwPTNPfBMWGNqU5pL6EhyhrW.jpg'),
(87206, 6049, 'Spy x Family S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/261682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/coHlfqor3MWQ2lG0zE88cRuKxrT.jpg'),
(87207, 6049, 'Spy x Family S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/261683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5sa2wrA0XxIqERnQtV9zZW63RLk.jpg'),
(87208, 6049, 'Spy x Family S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/261684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8fflXUjj7MiuUvcKI29UzqGrtDf.jpg'),
(87209, 6049, 'Spy x Family S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/261685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhx4wzKNip6UbB1Of1N1B6z9U6G.jpg'),
(87210, 6049, 'Spy x Family S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/261686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpgG3QfrtPX1PtbSbRYbPQJnX58.jpg'),
(87211, 6049, 'Spy x Family S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/261687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/twVq0DcTQldwfhLWMwDhdpEyb5.jpg'),
(87212, 6049, 'Spy x Family S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/261688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnylapvm3ybxtnPKha63C38Q5cT.jpg'),
(87213, 6049, 'Spy x Family S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/261689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVndtOTTDvMPLROzseVpwhfQr0v.jpg'),
(87214, 6049, 'Spy x Family S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/261690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6f933w3jEMxmbShxJan9QEfAxF.jpg'),
(87215, 6049, 'Spy x Family S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/261691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3akst9vMYjZ3bXLZxaUE456V2uX.jpg'),
(87216, 6049, 'Spy x Family S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/261692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Nj6rwQKCqC51eOJmQlPxHApCC2.jpg'),
(87217, 6050, 'Spy x Family S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261693.mp4', 'http://gstaticontent.com/images/5fdf4c34cc97557355b857df1b28b6d5.jpg'),
(87218, 6050, 'Spy x Family S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261694.mp4', 'http://gstaticontent.com/images/5fdf4c34cc97557355b857df1b28b6d5.jpg'),
(87219, 6050, 'Spy x Family S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261695.mp4', 'http://gstaticontent.com/images/5fdf4c34cc97557355b857df1b28b6d5.jpg'),
(87220, 6050, 'Spy x Family S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261696.mp4', 'http://gstaticontent.com/images/5fdf4c34cc97557355b857df1b28b6d5.jpg'),
(87221, 6050, 'Spy x Family S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261697.mp4', 'http://gstaticontent.com/images/5fdf4c34cc97557355b857df1b28b6d5.jpg'),
(87222, 6050, 'Spy x Family S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261698.mp4', 'http://gstaticontent.com/images/5fdf4c34cc97557355b857df1b28b6d5.jpg'),
(87223, 6050, 'Spy x Family S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261699.mp4', 'http://gstaticontent.com/images/5fdf4c34cc97557355b857df1b28b6d5.jpg'),
(87224, 6050, 'Spy x Family S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261700.mp4', 'http://gstaticontent.com/images/5fdf4c34cc97557355b857df1b28b6d5.jpg'),
(87225, 6050, 'Spy x Family S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261701.mp4', 'http://gstaticontent.com/images/5fdf4c34cc97557355b857df1b28b6d5.jpg'),
(87226, 6050, 'Spy x Family S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261702.mp4', 'http://gstaticontent.com/images/5fdf4c34cc97557355b857df1b28b6d5.jpg'),
(87227, 6050, 'Spy x Family S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/261703.mp4', 'http://gstaticontent.com/images/5fdf4c34cc97557355b857df1b28b6d5.jpg'),
(87228, 6050, 'Spy x Family S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/261704.mp4', 'http://gstaticontent.com/images/5fdf4c34cc97557355b857df1b28b6d5.jpg'),
(87229, 6051, 'Supernova S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183212.mp4', 'http://gstaticontent.com/images/7e09f6b91574647f558e0555ee098d57.jpg'),
(87230, 6051, 'Supernova S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183213.mp4', 'http://gstaticontent.com/images/7e09f6b91574647f558e0555ee098d57.jpg'),
(87231, 6051, 'Supernova S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183214.mp4', 'http://gstaticontent.com/images/7e09f6b91574647f558e0555ee098d57.jpg'),
(87232, 6051, 'Supernova S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183215.mp4', 'http://gstaticontent.com/images/7e09f6b91574647f558e0555ee098d57.jpg'),
(87233, 6052, 'The Great Grape Ape Show S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183196.mp4', 'http://timg.bdta.pro/images/a3841ce128812197e1b1085ade573f19.jpg'),
(87234, 6052, 'The Great Grape Ape Show S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183197.mp4', 'http://timg.bdta.pro/images/69cf83a7e28919932af21eb4d25c5f7e.jpg'),
(87235, 6052, 'The Great Grape Ape Show S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183198.mp4', 'http://timg.bdta.pro/images/9ee36b5f3cb37b2e91f37c321c83a9ec.jpg'),
(87236, 6052, 'The Great Grape Ape Show S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183199.mp4', 'http://timg.bdta.pro/images/9ee732cdfdea64ad46b851c272a12189.jpg'),
(87237, 6052, 'The Great Grape Ape Show S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183200.mp4', 'http://timg.bdta.pro/images/b9f74276e5e6c2396768b5ba78c03edb.jpg'),
(87238, 6052, 'The Great Grape Ape Show S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183201.mp4', 'http://timg.bdta.pro/images/115afb49813f7ad8df8eddf51d2ec680.jpg'),
(87239, 6052, 'The Great Grape Ape Show S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/183202.mp4', 'http://timg.bdta.pro/images/8d059626fa66f45e5fbf6672e39fbbab.jpg'),
(87240, 6052, 'The Great Grape Ape Show S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/183203.mp4', 'http://timg.bdta.pro/images/3d09d24aa8accd2806d5e819221ce2f7.jpg'),
(87241, 6052, 'The Great Grape Ape Show S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/183204.mp4', 'http://timg.bdta.pro/images/75d6a9a9140ae2124e058e3bfb32650d.jpg'),
(87242, 6052, 'The Great Grape Ape Show S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/183205.mp4', 'http://timg.bdta.pro/images/94f425111d47d63c35bf250f5d044800.jpg'),
(87243, 6052, 'The Great Grape Ape Show S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/183206.mp4', 'http://timg.bdta.pro/images/2a1440b71802db41061698ceff0e274e.jpg'),
(87244, 6052, 'The Great Grape Ape Show S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/183207.mp4', 'http://timg.bdta.pro/images/1e0eaa772e17651eccea5aa448f1fb30.jpg'),
(87245, 6052, 'The Great Grape Ape Show S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/183208.mp4', 'http://timg.bdta.pro/images/35dfabe3935171eca5d74454ab692710.jpg'),
(87246, 6052, 'The Great Grape Ape Show S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/183209.mp4', 'http://timg.bdta.pro/images/061962ecf9ce88a101abefa0270399ae.jpg'),
(87247, 6052, 'The Great Grape Ape Show S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/183210.mp4', 'http://timg.bdta.pro/images/e9519c109e75ebebe019af3d146137a7.jpg'),
(87248, 6052, 'The Great Grape Ape Show S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/183211.mp4', 'http://timg.bdta.pro/images/c8a7e6348d84bae6531c41674f0fd0bc.jpg'),
(87249, 6053, 'Tom Tem Dez Anos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219389.mp4', 'http://gstaticontent.com/images/fb6c3471558fa1c16dd9377776da581c.jpg'),
(87250, 6053, 'Tom Tem Dez Anos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219390.mp4', 'http://gstaticontent.com/images/fb6c3471558fa1c16dd9377776da581c.jpg'),
(87251, 6053, 'Tom Tem Dez Anos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219391.mp4', 'http://gstaticontent.com/images/fb6c3471558fa1c16dd9377776da581c.jpg'),
(87252, 6053, 'Tom Tem Dez Anos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219392.mp4', 'http://gstaticontent.com/images/fb6c3471558fa1c16dd9377776da581c.jpg'),
(87253, 6053, 'Tom Tem Dez Anos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219393.mp4', 'http://gstaticontent.com/images/fb6c3471558fa1c16dd9377776da581c.jpg'),
(87254, 6053, 'Tom Tem Dez Anos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219394.mp4', 'http://gstaticontent.com/images/fb6c3471558fa1c16dd9377776da581c.jpg'),
(87255, 6053, 'Tom Tem Dez Anos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219395.mp4', 'http://gstaticontent.com/images/fb6c3471558fa1c16dd9377776da581c.jpg'),
(87256, 6053, 'Tom Tem Dez Anos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219396.mp4', 'http://gstaticontent.com/images/fb6c3471558fa1c16dd9377776da581c.jpg'),
(87257, 6053, 'Tom Tem Dez Anos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219397.mp4', 'http://gstaticontent.com/images/fb6c3471558fa1c16dd9377776da581c.jpg'),
(87258, 6053, 'Tom Tem Dez Anos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219398.mp4', 'http://gstaticontent.com/images/fb6c3471558fa1c16dd9377776da581c.jpg'),
(87259, 6054, 'Tom Tem Dez Anos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219399.mp4', 'http://gstaticontent.com/images/fb6c3471558fa1c16dd9377776da581c.jpg'),
(87260, 6054, 'Tom Tem Dez Anos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219400.mp4', 'http://gstaticontent.com/images/fb6c3471558fa1c16dd9377776da581c.jpg'),
(87261, 6054, 'Tom Tem Dez Anos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219401.mp4', 'http://gstaticontent.com/images/fb6c3471558fa1c16dd9377776da581c.jpg'),
(87262, 6054, 'Tom Tem Dez Anos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219402.mp4', 'http://gstaticontent.com/images/fb6c3471558fa1c16dd9377776da581c.jpg'),
(87263, 6054, 'Tom Tem Dez Anos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219403.mp4', 'http://gstaticontent.com/images/fb6c3471558fa1c16dd9377776da581c.jpg'),
(87264, 6054, 'Tom Tem Dez Anos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219404.mp4', 'http://gstaticontent.com/images/fb6c3471558fa1c16dd9377776da581c.jpg'),
(87265, 6054, 'Tom Tem Dez Anos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219405.mp4', 'http://gstaticontent.com/images/fb6c3471558fa1c16dd9377776da581c.jpg'),
(87266, 6054, 'Tom Tem Dez Anos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219406.mp4', 'http://gstaticontent.com/images/fb6c3471558fa1c16dd9377776da581c.jpg'),
(87267, 6054, 'Tom Tem Dez Anos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219407.mp4', 'http://gstaticontent.com/images/fb6c3471558fa1c16dd9377776da581c.jpg'),
(87268, 6054, 'Tom Tem Dez Anos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219408.mp4', 'http://gstaticontent.com/images/fb6c3471558fa1c16dd9377776da581c.jpg'),
(87269, 6055, 'Transamazônica: Uma Estrada para o Passado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/183190.mp4', 'http://timg.bdta.pro/images/59cd676f1b8e594193319819bbbe4a9a.jpg'),
(87270, 6055, 'Transamazônica: Uma Estrada para o Passado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/183191.mp4', 'http://gstaticontent.com/images/62c7857202b49e9e0075a5f56a7792ea.jpg'),
(87271, 6055, 'Transamazônica: Uma Estrada para o Passado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/183192.mp4', 'http://gstaticontent.com/images/62c7857202b49e9e0075a5f56a7792ea.jpg'),
(87272, 6055, 'Transamazônica: Uma Estrada para o Passado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/183193.mp4', 'http://gstaticontent.com/images/62c7857202b49e9e0075a5f56a7792ea.jpg'),
(87273, 6055, 'Transamazônica: Uma Estrada para o Passado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/183194.mp4', 'http://gstaticontent.com/images/62c7857202b49e9e0075a5f56a7792ea.jpg'),
(87274, 6055, 'Transamazônica: Uma Estrada para o Passado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/183195.mp4', 'http://gstaticontent.com/images/62c7857202b49e9e0075a5f56a7792ea.jpg'),
(87275, 6056, 'Angry Birds: Summer Madness S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194712.mp4', 'http://timg.bdta.pro/images/df4092ead0933cbd2d584e46bb9b0708.jpg'),
(87276, 6056, 'Angry Birds: Summer Madness S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194713.mp4', 'http://timg.bdta.pro/images/552328eb6f6f00c6bfed6474718619d6.jpg'),
(87277, 6056, 'Angry Birds: Summer Madness S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194714.mp4', 'http://timg.bdta.pro/images/f632638e47da4632b64b16b263674e54.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(87278, 6056, 'Angry Birds: Summer Madness S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194715.mp4', 'http://timg.bdta.pro/images/3cf56ac15e56bf5019ccbf5b0bf11da4.jpg'),
(87279, 6056, 'Angry Birds: Summer Madness S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194716.mp4', 'http://timg.bdta.pro/images/06a90ddd23237ca4360e09252cebbdab.jpg'),
(87280, 6056, 'Angry Birds: Summer Madness S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194717.mp4', 'http://timg.bdta.pro/images/66e34cc9884b34f6ae93b22ceec053af.jpg'),
(87281, 6056, 'Angry Birds: Summer Madness S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194718.mp4', 'http://timg.bdta.pro/images/fb6760cd09877bc4f05996d4baa24751.jpg'),
(87282, 6056, 'Angry Birds: Summer Madness S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194719.mp4', 'http://timg.bdta.pro/images/f66a915cc561629d276cb971d54b0b44.jpg'),
(87283, 6056, 'Angry Birds: Summer Madness S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194720.mp4', 'http://timg.bdta.pro/images/7e29d8a94872b906f7fcbd06ea9af239.jpg'),
(87284, 6056, 'Angry Birds: Summer Madness S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194721.mp4', 'http://timg.bdta.pro/images/ee302ee6a885d881b1cd82d95abec805.jpg'),
(87285, 6056, 'Angry Birds: Summer Madness S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194722.mp4', 'http://timg.bdta.pro/images/424bc13236710bdb260439c8b3237dee.jpg'),
(87286, 6056, 'Angry Birds: Summer Madness S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194723.mp4', 'http://timg.bdta.pro/images/26d6b4cd52dcb589c17b0ef829b1f4a7.jpg'),
(87287, 6056, 'Angry Birds: Summer Madness S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/194724.mp4', 'http://timg.bdta.pro/images/295114524cb6f2afaa9aab00b162ce04.jpg'),
(87288, 6056, 'Angry Birds: Summer Madness S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/194725.mp4', 'http://timg.bdta.pro/images/2409511d9d2f2bb4a7f1febc7204b100.jpg'),
(87289, 6056, 'Angry Birds: Summer Madness S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/194726.mp4', 'http://timg.bdta.pro/images/544705f7b4390e8c545d11e369e0dfca.jpg'),
(87290, 6056, 'Angry Birds: Summer Madness S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/194727.mp4', 'http://timg.bdta.pro/images/ff4bb8162aaf5c4aa4958335d8ee78fd.jpg'),
(87291, 6057, 'Angry Birds: Summer Madness S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194728.mp4', 'http://timg.bdta.pro/images/75b4c0fc1062005fff20d0c55eb2e50e.jpg'),
(87292, 6057, 'Angry Birds: Summer Madness S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194729.mp4', 'http://timg.bdta.pro/images/a40e43878248e99ca0b3619ff89b7af0.jpg'),
(87293, 6057, 'Angry Birds: Summer Madness S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194730.mp4', 'http://timg.bdta.pro/images/48a42fba15348563f7d9447336b1f318.jpg'),
(87294, 6057, 'Angry Birds: Summer Madness S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194731.mp4', 'http://timg.bdta.pro/images/a67595a2dad0c0937b682e2d47a1b71d.jpg'),
(87295, 6057, 'Angry Birds: Summer Madness S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194732.mp4', 'http://timg.bdta.pro/images/ee4b80e71a75a0ca24ed3659dca97f15.jpg'),
(87296, 6057, 'Angry Birds: Summer Madness S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194733.mp4', 'http://timg.bdta.pro/images/9544ab428d7cc9f105df06b777c28e09.jpg'),
(87297, 6057, 'Angry Birds: Summer Madness S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194734.mp4', 'http://timg.bdta.pro/images/deada05c59f81af30285f63aec6b065a.jpg'),
(87298, 6057, 'Angry Birds: Summer Madness S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194735.mp4', 'http://timg.bdta.pro/images/c24ce28dad1b4d155986228bc9c628d8.jpg'),
(87299, 6057, 'Angry Birds: Summer Madness S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194736.mp4', 'http://timg.bdta.pro/images/8d55155598d4a17c4a94540b3d8b333f.jpg'),
(87300, 6057, 'Angry Birds: Summer Madness S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194737.mp4', 'http://timg.bdta.pro/images/afe6b0c86bb089de9fb30c2d1d23fa6c.jpg'),
(87301, 6057, 'Angry Birds: Summer Madness S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194738.mp4', 'http://timg.bdta.pro/images/e912e90b1e47fc86f84611ba996b5742.jpg'),
(87302, 6057, 'Angry Birds: Summer Madness S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194739.mp4', 'http://timg.bdta.pro/images/a9401c655c3d3eafb8f06f25d5af9dfa.jpg'),
(87303, 6057, 'Angry Birds: Summer Madness S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/194740.mp4', 'http://timg.bdta.pro/images/346f92d8ac0db61d761b1224c0a82a1f.jpg'),
(87304, 6057, 'Angry Birds: Summer Madness S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/194741.mp4', 'http://timg.bdta.pro/images/d79cdd11e783dd3ee4737027e45a83f4.jpg'),
(87305, 6057, 'Angry Birds: Summer Madness S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/194742.mp4', 'http://timg.bdta.pro/images/4958d6ed159eb26867cf5a846fefe90a.jpg'),
(87306, 6057, 'Angry Birds: Summer Madness S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/194743.mp4', 'http://timg.bdta.pro/images/2da6f8d080c35cf89d811f3323a1d563.jpg'),
(87307, 6058, 'Angry Birds: Summer Madness S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194744.mp4', 'http://timg.bdta.pro/images/64f2b83e702a90b745e628049b13e316.jpg'),
(87308, 6058, 'Angry Birds: Summer Madness S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194745.mp4', 'http://timg.bdta.pro/images/4503c1b84f44755e6d23b0cfd7bbafbd.jpg'),
(87309, 6058, 'Angry Birds: Summer Madness S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194746.mp4', 'http://timg.bdta.pro/images/05bca1b54b91ea5c87c1d8eb34a71f9b.jpg'),
(87310, 6058, 'Angry Birds: Summer Madness S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194747.mp4', 'http://timg.bdta.pro/images/8815a75a6de5b24b11ec9d4be73c17d9.jpg'),
(87311, 6059, 'Buuu: Um Chamado para a Aventura S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182612.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87312, 6059, 'Buuu: Um Chamado para a Aventura S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182613.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87313, 6059, 'Buuu: Um Chamado para a Aventura S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182614.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87314, 6059, 'Buuu: Um Chamado para a Aventura S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182615.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87315, 6059, 'Buuu: Um Chamado para a Aventura S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182616.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87316, 6059, 'Buuu: Um Chamado para a Aventura S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182617.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87317, 6059, 'Buuu: Um Chamado para a Aventura S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182618.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87318, 6059, 'Buuu: Um Chamado para a Aventura S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182619.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87319, 6059, 'Buuu: Um Chamado para a Aventura S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/182620.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87320, 6059, 'Buuu: Um Chamado para a Aventura S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/182621.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87321, 6059, 'Buuu: Um Chamado para a Aventura S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/182622.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87322, 6059, 'Buuu: Um Chamado para a Aventura S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/182623.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87323, 6059, 'Buuu: Um Chamado para a Aventura S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/182624.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87324, 6059, 'Buuu: Um Chamado para a Aventura S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/182625.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87325, 6059, 'Buuu: Um Chamado para a Aventura S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/182626.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87326, 6059, 'Buuu: Um Chamado para a Aventura S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/182627.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87327, 6059, 'Buuu: Um Chamado para a Aventura S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/182628.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87328, 6059, 'Buuu: Um Chamado para a Aventura S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/182629.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87329, 6059, 'Buuu: Um Chamado para a Aventura S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/182630.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87330, 6059, 'Buuu: Um Chamado para a Aventura S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/182631.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87331, 6059, 'Buuu: Um Chamado para a Aventura S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/182632.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87332, 6059, 'Buuu: Um Chamado para a Aventura S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/182633.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87333, 6059, 'Buuu: Um Chamado para a Aventura S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/182634.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87334, 6059, 'Buuu: Um Chamado para a Aventura S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/182635.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87335, 6059, 'Buuu: Um Chamado para a Aventura S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/182636.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87336, 6059, 'Buuu: Um Chamado para a Aventura S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/182637.mp4', 'http://gstaticontent.com/images/6a6404c3194f0981b6fdee335ccc1f20.jpg'),
(87337, 6060, 'My Little Pony:  A Amizade é Mágica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218307.mp4', 'http://timg.bdta.pro/images/9b06d2b94d9678129ec9849e0cfbc4af.jpg'),
(87338, 6060, 'My Little Pony:  A Amizade é Mágica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218308.mp4', 'http://timg.bdta.pro/images/77b0b3355892dc52f15e4c3387ad14e7.jpg'),
(87339, 6060, 'My Little Pony:  A Amizade é Mágica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218309.mp4', 'http://timg.bdta.pro/images/e057de14eed860067670c15cc6a263e0.jpg'),
(87340, 6060, 'My Little Pony:  A Amizade é Mágica S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218310.mp4', 'http://timg.bdta.pro/images/32212a1d54a4bd2ae08c08763855eae2.jpg'),
(87341, 6060, 'My Little Pony:  A Amizade é Mágica S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218311.mp4', 'http://timg.bdta.pro/images/939c5006a8d69a5fb9e61ce36feb7ef2.jpg'),
(87342, 6060, 'My Little Pony:  A Amizade é Mágica S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218312.mp4', 'http://timg.bdta.pro/images/55e4182bb4fde06cd9083f96a0bc959e.jpg'),
(87343, 6060, 'My Little Pony:  A Amizade é Mágica S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218313.mp4', 'http://timg.bdta.pro/images/f2f6f035ae92b98347b28a26704026c3.jpg'),
(87344, 6060, 'My Little Pony:  A Amizade é Mágica S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218314.mp4', 'http://timg.bdta.pro/images/76fb275a8b6a49f35a3efafe3e900466.jpg'),
(87345, 6060, 'My Little Pony:  A Amizade é Mágica S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218315.mp4', 'http://timg.bdta.pro/images/aaf219eb8351e5b0f425363c565bacea.jpg'),
(87346, 6060, 'My Little Pony:  A Amizade é Mágica S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218316.mp4', 'http://timg.bdta.pro/images/e46d0db8428589ec44d53264c9deb610.jpg'),
(87347, 6060, 'My Little Pony:  A Amizade é Mágica S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218317.mp4', 'http://timg.bdta.pro/images/a496cc2a288d68598d8a8554df0b10c1.jpg'),
(87348, 6060, 'My Little Pony:  A Amizade é Mágica S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218318.mp4', 'http://timg.bdta.pro/images/bfb8bd33f08319a5e38a7ec84d0ef10d.jpg'),
(87349, 6060, 'My Little Pony:  A Amizade é Mágica S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218319.mp4', 'http://timg.bdta.pro/images/c78b04a9a7d696a542d350ec62049597.jpg'),
(87350, 6060, 'My Little Pony:  A Amizade é Mágica S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218320.mp4', 'http://timg.bdta.pro/images/117fff4efd1daabdd2ac0963b1e4ab7d.jpg'),
(87351, 6060, 'My Little Pony:  A Amizade é Mágica S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218321.mp4', 'http://timg.bdta.pro/images/3e9a0724415fd5f1862d311fd23959b5.jpg'),
(87352, 6060, 'My Little Pony:  A Amizade é Mágica S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218322.mp4', 'http://timg.bdta.pro/images/f2acc3f1d9073fbf3897329d54d520ef.jpg'),
(87353, 6060, 'My Little Pony:  A Amizade é Mágica S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218323.mp4', 'http://timg.bdta.pro/images/799d830618515335b697eea822532fd4.jpg'),
(87354, 6060, 'My Little Pony:  A Amizade é Mágica S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218324.mp4', 'http://timg.bdta.pro/images/87a97f94de3b6ccfc0af3ce44aada408.jpg'),
(87355, 6060, 'My Little Pony:  A Amizade é Mágica S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218325.mp4', 'http://timg.bdta.pro/images/e8f0c87ab5f6367e38eeef30af5a729c.jpg'),
(87356, 6060, 'My Little Pony:  A Amizade é Mágica S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218326.mp4', 'http://timg.bdta.pro/images/a19ae936cc61da647f59ec86634a8708.jpg'),
(87357, 6060, 'My Little Pony:  A Amizade é Mágica S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218327.mp4', 'http://timg.bdta.pro/images/94c78ef21ebb6fa583b9e538870aaf32.jpg'),
(87358, 6060, 'My Little Pony:  A Amizade é Mágica S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/218328.mp4', 'http://timg.bdta.pro/images/dca54d1d0833727ff53b4d3ae955f945.jpg'),
(87359, 6060, 'My Little Pony:  A Amizade é Mágica S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/218329.mp4', 'http://timg.bdta.pro/images/7f8199858508c01ce8725fcb275d7381.jpg'),
(87360, 6060, 'My Little Pony:  A Amizade é Mágica S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/218330.mp4', 'http://timg.bdta.pro/images/177122dc66e28e6443c02f5377270957.jpg'),
(87361, 6060, 'My Little Pony:  A Amizade é Mágica S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/218331.mp4', 'http://timg.bdta.pro/images/a21f0ef650cd53445ded55fe95cde02f.jpg'),
(87362, 6060, 'My Little Pony:  A Amizade é Mágica S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/218332.mp4', 'http://timg.bdta.pro/images/6e760180ee5d117ace0b611d44e4870f.jpg'),
(87363, 6061, 'My Little Pony:  A Amizade é Mágica S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218333.mp4', 'http://timg.bdta.pro/images/da9fa28a63c51d4ff315025ee437492c.jpg'),
(87364, 6061, 'My Little Pony:  A Amizade é Mágica S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218334.mp4', 'http://timg.bdta.pro/images/8bf374334d65d382a5d07cfa61527152.jpg'),
(87365, 6061, 'My Little Pony:  A Amizade é Mágica S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218335.mp4', 'http://timg.bdta.pro/images/32b7ef1d829adee2de735781b72623da.jpg'),
(87366, 6061, 'My Little Pony:  A Amizade é Mágica S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218336.mp4', 'http://timg.bdta.pro/images/4dcb605dd99fb19b2bc2b4290d8bf8d8.jpg'),
(87367, 6061, 'My Little Pony:  A Amizade é Mágica S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218337.mp4', 'http://timg.bdta.pro/images/d9ce15460d82c7c578ea06cb82b3c9dc.jpg'),
(87368, 6061, 'My Little Pony:  A Amizade é Mágica S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218338.mp4', 'http://timg.bdta.pro/images/d77eed31c99ff186afffb7d8438539dd.jpg'),
(87369, 6061, 'My Little Pony:  A Amizade é Mágica S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218339.mp4', 'http://timg.bdta.pro/images/efdf5b5819110e97552c982430d4c55a.jpg'),
(87370, 6061, 'My Little Pony:  A Amizade é Mágica S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218340.mp4', 'http://timg.bdta.pro/images/2f70b94030716fd1cae6d15a7a091a30.jpg'),
(87371, 6061, 'My Little Pony:  A Amizade é Mágica S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218341.mp4', 'http://timg.bdta.pro/images/93694ceb0b7700c6a40d134c20506a0b.jpg'),
(87372, 6061, 'My Little Pony:  A Amizade é Mágica S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218342.mp4', 'http://timg.bdta.pro/images/408a29f17b04e33d8850805dde9a1f95.jpg'),
(87373, 6061, 'My Little Pony:  A Amizade é Mágica S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218343.mp4', 'http://timg.bdta.pro/images/f73541aa11e4ef2dd372e1b9e600df6e.jpg'),
(87374, 6061, 'My Little Pony:  A Amizade é Mágica S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218344.mp4', 'http://timg.bdta.pro/images/98a27c95770d7ee3d0b17310a1ec8eae.jpg'),
(87375, 6061, 'My Little Pony:  A Amizade é Mágica S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218345.mp4', 'http://timg.bdta.pro/images/614fa16f63c901f50457a4311f23dd5f.jpg'),
(87376, 6061, 'My Little Pony:  A Amizade é Mágica S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218346.mp4', 'http://timg.bdta.pro/images/31a2d7a1b759d0f132c4cad539d3e026.jpg'),
(87377, 6061, 'My Little Pony:  A Amizade é Mágica S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218347.mp4', 'http://timg.bdta.pro/images/aad1e60bcf1564befd079138579f383b.jpg'),
(87378, 6061, 'My Little Pony:  A Amizade é Mágica S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218348.mp4', 'http://timg.bdta.pro/images/bf706458b3c588233b09a63baf9eae58.jpg'),
(87379, 6061, 'My Little Pony:  A Amizade é Mágica S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218349.mp4', 'http://timg.bdta.pro/images/dc3eafa5ba0a1a9bdbd30ef0cebc9b5f.jpg'),
(87380, 6061, 'My Little Pony:  A Amizade é Mágica S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218350.mp4', 'http://timg.bdta.pro/images/b5d8f459fbeee2542128f4741b05d5b7.jpg'),
(87381, 6061, 'My Little Pony:  A Amizade é Mágica S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218351.mp4', 'http://timg.bdta.pro/images/59657e58fcb21f970aaef142033d02c3.jpg'),
(87382, 6061, 'My Little Pony:  A Amizade é Mágica S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218352.mp4', 'http://timg.bdta.pro/images/4ba42dabb10da83c4d01596f2a2f8f7f.jpg'),
(87383, 6061, 'My Little Pony:  A Amizade é Mágica S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218353.mp4', 'http://timg.bdta.pro/images/3148d0cf9ca7b358926dad9a4f7958ab.jpg'),
(87384, 6061, 'My Little Pony:  A Amizade é Mágica S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/218354.mp4', 'http://timg.bdta.pro/images/7f76b353d1c6fcd63325708894fac3a6.jpg'),
(87385, 6061, 'My Little Pony:  A Amizade é Mágica S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/218355.mp4', 'http://timg.bdta.pro/images/3b2c235f8b53580cc279cdd907b7241e.jpg'),
(87386, 6061, 'My Little Pony:  A Amizade é Mágica S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/218356.mp4', 'http://timg.bdta.pro/images/0f267070b6524b14fc23e855bad18c79.jpg'),
(87387, 6061, 'My Little Pony:  A Amizade é Mágica S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/218357.mp4', 'http://timg.bdta.pro/images/b060f9042fff97cf54d9e5c4e0388be8.jpg'),
(87388, 6061, 'My Little Pony:  A Amizade é Mágica S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/218358.mp4', 'http://timg.bdta.pro/images/92552bd3509e6f4b56f62afaac0b8aec.jpg'),
(87389, 6062, 'My Little Pony:  A Amizade é Mágica S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218359.mp4', 'http://timg.bdta.pro/images/3b26a081b7aa30d7161c0e1f97d7f7e0.jpg'),
(87390, 6062, 'My Little Pony:  A Amizade é Mágica S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218360.mp4', 'http://timg.bdta.pro/images/301ba5f3ca159117bd218ba7a549c65a.jpg'),
(87391, 6062, 'My Little Pony:  A Amizade é Mágica S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218361.mp4', 'http://timg.bdta.pro/images/846d66d2f5b087f456606f08d1dfc6b1.jpg'),
(87392, 6062, 'My Little Pony:  A Amizade é Mágica S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218362.mp4', 'http://timg.bdta.pro/images/533008e6ab2a8ad05bfcf9c4fa7f515c.jpg'),
(87393, 6062, 'My Little Pony:  A Amizade é Mágica S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218363.mp4', 'http://timg.bdta.pro/images/370b5603dfbde2f457dd83e47c2f248c.jpg'),
(87394, 6062, 'My Little Pony:  A Amizade é Mágica S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218364.mp4', 'http://timg.bdta.pro/images/898b9f25a751168018b268799a771383.jpg'),
(87395, 6062, 'My Little Pony:  A Amizade é Mágica S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218365.mp4', 'http://timg.bdta.pro/images/12230a406bba7ba853b15aca64e45617.jpg'),
(87396, 6062, 'My Little Pony:  A Amizade é Mágica S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218366.mp4', 'http://timg.bdta.pro/images/fca3d0d7af247ea5a7943c5af2b58b0b.jpg'),
(87397, 6062, 'My Little Pony:  A Amizade é Mágica S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218367.mp4', 'http://timg.bdta.pro/images/ac6e8bf8fe0a8ee56caaac2eccbb3d12.jpg'),
(87398, 6062, 'My Little Pony:  A Amizade é Mágica S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218368.mp4', 'http://timg.bdta.pro/images/7d7dcf399889e1ccef88f416c020d36d.jpg'),
(87399, 6062, 'My Little Pony:  A Amizade é Mágica S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218369.mp4', 'http://timg.bdta.pro/images/fdef2dc612cfa8cf6651074a4c275ad4.jpg'),
(87400, 6062, 'My Little Pony:  A Amizade é Mágica S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218370.mp4', 'http://timg.bdta.pro/images/4d9ca5f97624df764750bdbe1710004e.jpg'),
(87401, 6062, 'My Little Pony:  A Amizade é Mágica S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218371.mp4', 'http://timg.bdta.pro/images/34313f56c19f340c7b22f44f33b7196f.jpg'),
(87402, 6063, 'My Little Pony:  A Amizade é Mágica S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218372.mp4', 'http://timg.bdta.pro/images/677cc42b820f317b7a2b336fc7fb55a5.jpg'),
(87403, 6063, 'My Little Pony:  A Amizade é Mágica S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218373.mp4', 'http://timg.bdta.pro/images/3b0b71806c14a52eea70123badab8efb.jpg'),
(87404, 6063, 'My Little Pony:  A Amizade é Mágica S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218374.mp4', 'http://timg.bdta.pro/images/0ccd0006a1b3b25b8345b91d927f88d3.jpg'),
(87405, 6063, 'My Little Pony:  A Amizade é Mágica S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218375.mp4', 'http://timg.bdta.pro/images/c06448e3175200cfc945c4a0120124ed.jpg'),
(87406, 6063, 'My Little Pony:  A Amizade é Mágica S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218376.mp4', 'http://timg.bdta.pro/images/787daf09fd7136f1ad12dde6da33cca0.jpg'),
(87407, 6063, 'My Little Pony:  A Amizade é Mágica S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218377.mp4', 'http://timg.bdta.pro/images/b4b8493bd30b509936e855a515b45aeb.jpg'),
(87408, 6063, 'My Little Pony:  A Amizade é Mágica S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218378.mp4', 'http://timg.bdta.pro/images/dd34ed57fb03729e1a91a5f3625bc9d2.jpg'),
(87409, 6063, 'My Little Pony:  A Amizade é Mágica S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218379.mp4', 'http://timg.bdta.pro/images/254868ceef0c9cc8f4ed837b30ac1e1b.jpg'),
(87410, 6063, 'My Little Pony:  A Amizade é Mágica S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218380.mp4', 'http://timg.bdta.pro/images/4406e5ba4b757b5b4f9f3118e10f63eb.jpg'),
(87411, 6063, 'My Little Pony:  A Amizade é Mágica S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218381.mp4', 'http://timg.bdta.pro/images/bc7d5b5fe9d57d05649333f88032e36c.jpg'),
(87412, 6063, 'My Little Pony:  A Amizade é Mágica S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218382.mp4', 'http://timg.bdta.pro/images/b07f01694f564aa009d5af1649f0d22b.jpg'),
(87413, 6063, 'My Little Pony:  A Amizade é Mágica S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218383.mp4', 'http://timg.bdta.pro/images/43ef7648631e565b8d64182410b45601.jpg'),
(87414, 6063, 'My Little Pony:  A Amizade é Mágica S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218384.mp4', 'http://timg.bdta.pro/images/ea7ef0d1ecd7289bb3fd7772657d7044.jpg'),
(87415, 6063, 'My Little Pony:  A Amizade é Mágica S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218385.mp4', 'http://timg.bdta.pro/images/97fb220c642d34e4a69ff23a7a2ae682.jpg'),
(87416, 6063, 'My Little Pony:  A Amizade é Mágica S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218386.mp4', 'http://timg.bdta.pro/images/2b21ce1cb3b3e98e887c430ac476821e.jpg'),
(87417, 6063, 'My Little Pony:  A Amizade é Mágica S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218387.mp4', 'http://timg.bdta.pro/images/463931f01610a6bef1cbfc58eae6064d.jpg'),
(87418, 6063, 'My Little Pony:  A Amizade é Mágica S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218388.mp4', 'http://timg.bdta.pro/images/91880e1864aa667584afb7228f4053ab.jpg'),
(87419, 6063, 'My Little Pony:  A Amizade é Mágica S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218389.mp4', 'http://timg.bdta.pro/images/a3df9d5555c6fa553a247f4d4b568fff.jpg'),
(87420, 6063, 'My Little Pony:  A Amizade é Mágica S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218390.mp4', 'http://timg.bdta.pro/images/366e50f627a5aff4224b9a0b0f1c0a63.jpg'),
(87421, 6063, 'My Little Pony:  A Amizade é Mágica S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218391.mp4', 'http://timg.bdta.pro/images/07759be5b837bed7f7b8d2820f037242.jpg'),
(87422, 6063, 'My Little Pony:  A Amizade é Mágica S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218392.mp4', 'http://timg.bdta.pro/images/e03d371f57d6da57c557f778879607de.jpg'),
(87423, 6063, 'My Little Pony:  A Amizade é Mágica S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/218393.mp4', 'http://timg.bdta.pro/images/1196a5f2bc30c5619c6a92f8a92a29b7.jpg'),
(87424, 6063, 'My Little Pony:  A Amizade é Mágica S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/218394.mp4', 'http://timg.bdta.pro/images/9e610d61cfab58fb3a559550f7bcf6ee.jpg'),
(87425, 6063, 'My Little Pony:  A Amizade é Mágica S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/218395.mp4', 'http://timg.bdta.pro/images/1964744c1ec49a68bff21410d8d1e8c0.jpg'),
(87426, 6063, 'My Little Pony:  A Amizade é Mágica S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/218396.mp4', 'http://timg.bdta.pro/images/30f2b77ea323e25305db5a71aa0c745b.jpg'),
(87427, 6063, 'My Little Pony:  A Amizade é Mágica S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/218397.mp4', 'http://timg.bdta.pro/images/e8147dd0a10095f332a0bd30f94d8be7.jpg'),
(87428, 6064, 'My Little Pony:  A Amizade é Mágica S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i2VD1oAJIXW8ygfoGwxGEhmadIz.jpg'),
(87429, 6064, 'My Little Pony:  A Amizade é Mágica S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dmkTBVgwIxXz33yPcfRDIondAts.jpg'),
(87430, 6064, 'My Little Pony:  A Amizade é Mágica S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pvK6ZZnriYRctT1pYPeyHUBCJsb.jpg'),
(87431, 6064, 'My Little Pony:  A Amizade é Mágica S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/isduh80cQqsTbnctzQA94NDZBDe.jpg'),
(87432, 6064, 'My Little Pony:  A Amizade é Mágica S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z3lcZlVg53CxBZV87kBrJ3Etpcu.jpg'),
(87433, 6064, 'My Little Pony:  A Amizade é Mágica S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJ7aWY0cTEJCBmK0d40hgscRwSA.jpg'),
(87434, 6064, 'My Little Pony:  A Amizade é Mágica S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6dJWyhliFhw474xPoFIzZeoEFGm.jpg'),
(87435, 6064, 'My Little Pony:  A Amizade é Mágica S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qGkJiiaUk2wWTsb6rtrrj51ZuJI.jpg'),
(87436, 6064, 'My Little Pony:  A Amizade é Mágica S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2tec2N8JNwZ6upACvHlzeNvb071.jpg'),
(87437, 6064, 'My Little Pony:  A Amizade é Mágica S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7yZb0CL6HSbwefUpKUbfTzC6AcY.jpg'),
(87438, 6064, 'My Little Pony:  A Amizade é Mágica S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g9KWYHA1aK3Fl830aLH6tqYB1iQ.jpg'),
(87439, 6064, 'My Little Pony:  A Amizade é Mágica S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vBqIJ4waXGT0oE8UD5VMzKH5byt.jpg'),
(87440, 6064, 'My Little Pony:  A Amizade é Mágica S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g9JP00BfPyd07tQor3Ku67T0jh0.jpg'),
(87441, 6064, 'My Little Pony:  A Amizade é Mágica S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gStKq1XeVNMMAzHAok13T5bjj5k.jpg'),
(87442, 6064, 'My Little Pony:  A Amizade é Mágica S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eX8ERai3f4k4N0nzCdICG1iosoh.jpg'),
(87443, 6064, 'My Little Pony:  A Amizade é Mágica S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hAQnrUfUIcv8kdqlLVfTAamcXMn.jpg'),
(87444, 6064, 'My Little Pony:  A Amizade é Mágica S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4DGIBbUxITtupLcuQLv73IpWbEi.jpg'),
(87445, 6064, 'My Little Pony:  A Amizade é Mágica S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3hjqhVP8WC82blvgL9sxYgAoO7U.jpg'),
(87446, 6064, 'My Little Pony:  A Amizade é Mágica S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uRslt3m1FKhKVe4xiEVJw4o0I8G.jpg'),
(87447, 6064, 'My Little Pony:  A Amizade é Mágica S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Atd1Niwa1bkdWrCWNnSvVSxPCi4.jpg'),
(87448, 6064, 'My Little Pony:  A Amizade é Mágica S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eTdVlFnO1hunNYlyM0xeKAUyqd9.jpg'),
(87449, 6064, 'My Little Pony:  A Amizade é Mágica S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/218419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHg1Zp4dGGjENE5QgpS6OG1AVes.jpg'),
(87450, 6064, 'My Little Pony:  A Amizade é Mágica S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/218420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgMs92axjvDuqo1MfmK4xuwRxHV.jpg'),
(87451, 6064, 'My Little Pony:  A Amizade é Mágica S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/218421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/weVER3aW4eP2tHWpjqI7Evtz1mK.jpg'),
(87452, 6064, 'My Little Pony:  A Amizade é Mágica S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/218422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c9Tv3Lu3WbOP7L2T00WvjfJiawo.jpg'),
(87453, 6064, 'My Little Pony:  A Amizade é Mágica S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/218423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gvjeNXkTTeSbE4DsZ7D38iUP3sC.jpg'),
(87454, 6065, 'Line of Duty [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191650.mp4', 'http://timg.bdta.pro/images/668335d7c71a02a6e9c6d40214d607a6.jpg'),
(87455, 6065, 'Line of Duty [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191651.mp4', 'http://timg.bdta.pro/images/16ef98befb3027bd61ddfdd39ad90ca9.jpg'),
(87456, 6065, 'Line of Duty [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191652.mp4', 'http://timg.bdta.pro/images/2d56e88a08be95cc6ebd1ce159a948ca.jpg'),
(87457, 6065, 'Line of Duty [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191653.mp4', 'http://timg.bdta.pro/images/927c89b2e688b5ea20d358f076b26daa.jpg'),
(87458, 6065, 'Line of Duty [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191654.mp4', 'http://timg.bdta.pro/images/d17c65aabc9420ba8942b245b2a52e06.jpg'),
(87459, 6066, 'Line of Duty [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191655.mp4', 'http://timg.bdta.pro/images/abc9980550da2b10ab79319fd30ad5eb.jpg'),
(87460, 6066, 'Line of Duty [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191656.mp4', 'http://timg.bdta.pro/images/a0725e757193e0d5cdc356c42fec3c48.jpg'),
(87461, 6066, 'Line of Duty [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191657.mp4', 'http://timg.bdta.pro/images/4c50acd37d6e92243035114200ea7532.jpg'),
(87462, 6066, 'Line of Duty [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191658.mp4', 'http://timg.bdta.pro/images/2da1acb339d688c556ca4d03d6853deb.jpg'),
(87463, 6066, 'Line of Duty [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191659.mp4', 'http://timg.bdta.pro/images/c794d13b5414b1d1eea0cd1a9584119e.jpg'),
(87464, 6066, 'Line of Duty [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191660.mp4', 'http://timg.bdta.pro/images/d281b958959928809f3c168e7da260de.jpg'),
(87465, 6067, 'Line of Duty [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191661.mp4', 'http://timg.bdta.pro/images/de9ba51de3a8b12431bc4ca586bd6cb2.jpg'),
(87466, 6067, 'Line of Duty [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191662.mp4', 'http://timg.bdta.pro/images/24caa48bfad30b7fa8884d938dad7f44.jpg'),
(87467, 6067, 'Line of Duty [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191663.mp4', 'http://timg.bdta.pro/images/e6f551eaed275665e6426c30e015188e.jpg'),
(87468, 6067, 'Line of Duty [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191664.mp4', 'http://timg.bdta.pro/images/dbba42045819f9dc913df725d681856b.jpg'),
(87469, 6067, 'Line of Duty [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191665.mp4', 'http://timg.bdta.pro/images/97cb91f3ca0b2a9ff11caf01bb69f412.jpg'),
(87470, 6067, 'Line of Duty [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191666.mp4', 'http://timg.bdta.pro/images/554a06f786ca197a2a6bc4dc28e3e73b.jpg'),
(87471, 6068, 'Line of Duty [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191667.mp4', 'http://timg.bdta.pro/images/5f3950171c6a686ef62a83f89183040a.jpg'),
(87472, 6068, 'Line of Duty [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191668.mp4', 'http://timg.bdta.pro/images/58c84268db4f77780f1e09ebbd9d5f59.jpg'),
(87473, 6068, 'Line of Duty [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191669.mp4', 'http://timg.bdta.pro/images/6708471b189e0c7830a4b8329cdb5fb9.jpg'),
(87474, 6068, 'Line of Duty [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191670.mp4', 'http://timg.bdta.pro/images/eaadbdf124e204df0950343e3059c6f3.jpg'),
(87475, 6068, 'Line of Duty [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191671.mp4', 'http://timg.bdta.pro/images/83413e896bac688b21a55c8502cd4ff2.jpg'),
(87476, 6068, 'Line of Duty [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191672.mp4', 'http://timg.bdta.pro/images/b0959b01df62cb5cc3bc992618ab8aec.jpg'),
(87477, 6069, 'Line of Duty [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191673.mp4', 'http://timg.bdta.pro/images/bdef45173a479fe439d04ed2e360d4e2.jpg'),
(87478, 6069, 'Line of Duty [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191674.mp4', 'http://timg.bdta.pro/images/2428a67b810f252f1070bdae24a7d613.jpg'),
(87479, 6069, 'Line of Duty [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191675.mp4', 'http://timg.bdta.pro/images/405d12a22a8c9e1832c08190e400133d.jpg'),
(87480, 6069, 'Line of Duty [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191676.mp4', 'http://timg.bdta.pro/images/02fbca36ff54cf0f2694d7ebb1babb63.jpg'),
(87481, 6069, 'Line of Duty [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191677.mp4', 'http://timg.bdta.pro/images/a367d57be3ae9168346b41227b23cc1c.jpg'),
(87482, 6069, 'Line of Duty [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191678.mp4', 'http://timg.bdta.pro/images/76425853c04abf2cc945c05e9a52e25f.jpg'),
(87483, 6070, 'Line of Duty [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191679.mp4', 'http://timg.bdta.pro/images/ddfbe073dc51b9bba03abfa280478cad.jpg'),
(87484, 6070, 'Line of Duty [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191680.mp4', 'http://timg.bdta.pro/images/33f821a7a551f18a51381d3ff50bcdef.jpg'),
(87485, 6070, 'Line of Duty [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191681.mp4', 'http://timg.bdta.pro/images/b471b4a8035f17ac8dc88032459cb49e.jpg'),
(87486, 6070, 'Line of Duty [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191682.mp4', 'http://timg.bdta.pro/images/cf95167a004757b810de73a7f51112d7.jpg'),
(87487, 6070, 'Line of Duty [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191683.mp4', 'http://timg.bdta.pro/images/55ed7dd11cd2ab62df9b9c3099d40c27.jpg'),
(87488, 6070, 'Line of Duty [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191684.mp4', 'http://timg.bdta.pro/images/0fcfdfd55f3a65b677c3d240f7061cac.jpg'),
(87489, 6070, 'Line of Duty [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191685.mp4', 'http://timg.bdta.pro/images/3d941f75e8e63376592e3ecedcad8a23.jpg'),
(87490, 6071, 'Em Nome do Céu [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182571.mp4', 'http://timg.bdta.pro/images/8ec3caa172212ca08fe69c61b0556ab2.jpg'),
(87491, 6071, 'Em Nome do Céu [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182572.mp4', 'http://timg.bdta.pro/images/e93cafe4ca82da7faabaa224c3208c82.jpg'),
(87492, 6071, 'Em Nome do Céu [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182573.mp4', 'http://timg.bdta.pro/images/a83672fd044a35719a68839609a34c54.jpg'),
(87493, 6071, 'Em Nome do Céu [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182574.mp4', 'http://timg.bdta.pro/images/b0a2cda88d22cdc65a87251c9f876870.jpg'),
(87494, 6071, 'Em Nome do Céu [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182575.mp4', 'http://timg.bdta.pro/images/7f8d65fa3762781bfa940f028e470236.jpg'),
(87495, 6071, 'Em Nome do Céu [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182576.mp4', 'http://timg.bdta.pro/images/468ebc10bf503d46a18d4394b6b0ef9d.jpg'),
(87496, 6071, 'Em Nome do Céu [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182577.mp4', 'http://timg.bdta.pro/images/e004e9fd434f6c89274f3175a2333c5e.jpg'),
(87497, 6072, 'Cinderella e os Quatro Cavaleiros [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182555.mp4', 'http://timg.bdta.pro/images/18849446077deef30e03886cedadc835.jpg'),
(87498, 6072, 'Cinderella e os Quatro Cavaleiros [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182556.mp4', 'http://timg.bdta.pro/images/495c2434fbef65ebe5150aa8d14c507d.jpg'),
(87499, 6072, 'Cinderella e os Quatro Cavaleiros [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182557.mp4', 'http://timg.bdta.pro/images/28f98f15a48fd80700ce53a6f9deea8c.jpg'),
(87500, 6072, 'Cinderella e os Quatro Cavaleiros [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182558.mp4', 'http://timg.bdta.pro/images/ba420e0e4157bcfe67eb01e3d7d65876.jpg'),
(87501, 6072, 'Cinderella e os Quatro Cavaleiros [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182559.mp4', 'http://timg.bdta.pro/images/67a877a813cad4353cbeb1802a359677.jpg'),
(87502, 6072, 'Cinderella e os Quatro Cavaleiros [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182560.mp4', 'http://timg.bdta.pro/images/1c9a76998bff8f39e11cc73fb82a982f.jpg'),
(87503, 6072, 'Cinderella e os Quatro Cavaleiros [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182561.mp4', 'http://timg.bdta.pro/images/757867f7bea6a628bae5727d31f79a24.jpg'),
(87504, 6072, 'Cinderella e os Quatro Cavaleiros [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182562.mp4', 'http://timg.bdta.pro/images/31aa7222b637af33474dfda71a4304ba.jpg'),
(87505, 6072, 'Cinderella e os Quatro Cavaleiros [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/182563.mp4', 'http://timg.bdta.pro/images/f78b94fbd2b746f153d8e24bf53e474f.jpg'),
(87506, 6072, 'Cinderella e os Quatro Cavaleiros [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/182564.mp4', 'http://timg.bdta.pro/images/f6d869e4668b4b37a58d5fe1a7db2f42.jpg'),
(87507, 6072, 'Cinderella e os Quatro Cavaleiros [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/182565.mp4', 'http://timg.bdta.pro/images/146630d723c1d7582af2ab140ba7e90c.jpg'),
(87508, 6072, 'Cinderella e os Quatro Cavaleiros [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/182566.mp4', 'http://timg.bdta.pro/images/7ad3b0dc1ef7b318be10cb8ca22e5e6a.jpg'),
(87509, 6072, 'Cinderella e os Quatro Cavaleiros [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/182567.mp4', 'http://timg.bdta.pro/images/3ed63801f0f3906f21ef335449fa072c.jpg'),
(87510, 6072, 'Cinderella e os Quatro Cavaleiros [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/182568.mp4', 'http://timg.bdta.pro/images/b37e008502d6beef946d9d7fdcee3c93.jpg'),
(87511, 6072, 'Cinderella e os Quatro Cavaleiros [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/182569.mp4', 'http://timg.bdta.pro/images/806a444003df134f59cf172b95860baa.jpg'),
(87512, 6072, 'Cinderella e os Quatro Cavaleiros [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/182570.mp4', 'http://timg.bdta.pro/images/e9a459df06db169d0b60cca6baa5deda.jpg'),
(87513, 6073, 'Chasing Monsters [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182543.mp4', 'http://gstaticontent.com/images/66fb4f1938436486485f51141c7fd1b2.jpg'),
(87514, 6073, 'Chasing Monsters [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182544.mp4', 'http://gstaticontent.com/images/66fb4f1938436486485f51141c7fd1b2.jpg'),
(87515, 6073, 'Chasing Monsters [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182545.mp4', 'http://gstaticontent.com/images/66fb4f1938436486485f51141c7fd1b2.jpg'),
(87516, 6073, 'Chasing Monsters [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182546.mp4', 'http://gstaticontent.com/images/66fb4f1938436486485f51141c7fd1b2.jpg'),
(87517, 6073, 'Chasing Monsters [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182547.mp4', 'http://gstaticontent.com/images/66fb4f1938436486485f51141c7fd1b2.jpg'),
(87518, 6073, 'Chasing Monsters [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182548.mp4', 'http://gstaticontent.com/images/66fb4f1938436486485f51141c7fd1b2.jpg'),
(87519, 6073, 'Chasing Monsters [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182549.mp4', 'http://gstaticontent.com/images/66fb4f1938436486485f51141c7fd1b2.jpg'),
(87520, 6073, 'Chasing Monsters [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182550.mp4', 'http://gstaticontent.com/images/66fb4f1938436486485f51141c7fd1b2.jpg'),
(87521, 6073, 'Chasing Monsters [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/182551.mp4', 'http://gstaticontent.com/images/66fb4f1938436486485f51141c7fd1b2.jpg'),
(87522, 6073, 'Chasing Monsters [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/182552.mp4', 'http://gstaticontent.com/images/66fb4f1938436486485f51141c7fd1b2.jpg'),
(87523, 6073, 'Chasing Monsters [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/182553.mp4', 'http://gstaticontent.com/images/66fb4f1938436486485f51141c7fd1b2.jpg'),
(87524, 6073, 'Chasing Monsters [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/182554.mp4', 'http://gstaticontent.com/images/66fb4f1938436486485f51141c7fd1b2.jpg'),
(87525, 6074, 'A Grande Família do Alasca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232754.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87526, 6074, 'A Grande Família do Alasca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232755.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87527, 6074, 'A Grande Família do Alasca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232756.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87528, 6074, 'A Grande Família do Alasca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232757.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87529, 6074, 'A Grande Família do Alasca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232758.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87530, 6075, 'A Grande Família do Alasca S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232759.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87531, 6075, 'A Grande Família do Alasca S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232760.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87532, 6075, 'A Grande Família do Alasca S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232761.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87533, 6075, 'A Grande Família do Alasca S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232762.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87534, 6075, 'A Grande Família do Alasca S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232763.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87535, 6075, 'A Grande Família do Alasca S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232764.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87536, 6075, 'A Grande Família do Alasca S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232765.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87537, 6075, 'A Grande Família do Alasca S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232766.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87538, 6075, 'A Grande Família do Alasca S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232767.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87539, 6076, 'A Grande Família do Alasca S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232768.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87540, 6076, 'A Grande Família do Alasca S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232769.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(87541, 6076, 'A Grande Família do Alasca S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232770.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87542, 6076, 'A Grande Família do Alasca S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232771.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87543, 6076, 'A Grande Família do Alasca S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232772.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87544, 6076, 'A Grande Família do Alasca S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232773.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87545, 6076, 'A Grande Família do Alasca S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232774.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87546, 6076, 'A Grande Família do Alasca S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232775.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87547, 6076, 'A Grande Família do Alasca S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232776.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87548, 6076, 'A Grande Família do Alasca S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232777.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87549, 6077, 'A Grande Família do Alasca S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232778.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87550, 6077, 'A Grande Família do Alasca S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232779.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87551, 6077, 'A Grande Família do Alasca S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232780.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87552, 6077, 'A Grande Família do Alasca S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232781.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87553, 6077, 'A Grande Família do Alasca S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232782.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87554, 6077, 'A Grande Família do Alasca S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232783.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87555, 6077, 'A Grande Família do Alasca S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232784.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87556, 6077, 'A Grande Família do Alasca S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232785.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87557, 6077, 'A Grande Família do Alasca S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232786.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87558, 6077, 'A Grande Família do Alasca S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232787.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87559, 6078, 'A Grande Família do Alasca S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232788.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87560, 6078, 'A Grande Família do Alasca S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232789.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87561, 6078, 'A Grande Família do Alasca S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232790.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87562, 6078, 'A Grande Família do Alasca S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232791.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87563, 6078, 'A Grande Família do Alasca S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232792.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87564, 6078, 'A Grande Família do Alasca S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232793.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87565, 6078, 'A Grande Família do Alasca S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232794.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87566, 6078, 'A Grande Família do Alasca S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232795.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87567, 6078, 'A Grande Família do Alasca S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232796.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87568, 6078, 'A Grande Família do Alasca S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232797.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87569, 6078, 'A Grande Família do Alasca S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232798.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87570, 6078, 'A Grande Família do Alasca S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232799.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87571, 6078, 'A Grande Família do Alasca S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/232800.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87572, 6079, 'A Grande Família do Alasca S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232801.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87573, 6079, 'A Grande Família do Alasca S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232802.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87574, 6079, 'A Grande Família do Alasca S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232803.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87575, 6079, 'A Grande Família do Alasca S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232804.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87576, 6079, 'A Grande Família do Alasca S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232805.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87577, 6079, 'A Grande Família do Alasca S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232806.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87578, 6079, 'A Grande Família do Alasca S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232807.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87579, 6079, 'A Grande Família do Alasca S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232808.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87580, 6079, 'A Grande Família do Alasca S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232809.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87581, 6079, 'A Grande Família do Alasca S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232810.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87582, 6079, 'A Grande Família do Alasca S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232811.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87583, 6079, 'A Grande Família do Alasca S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232812.mp4', 'http://gstaticontent.com/images/5b2540fc9eedac508d3ef8b64879c795.jpg'),
(87584, 6080, 'Alba S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182466.mp4', 'http://timg.bdta.pro/images/edb0ac33a19775fbd8dfefd506e0982a.jpg'),
(87585, 6080, 'Alba S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182467.mp4', 'http://timg.bdta.pro/images/0fd0ffe548dede36fb7bfecb169bda0a.jpg'),
(87586, 6080, 'Alba S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182468.mp4', 'http://timg.bdta.pro/images/df7ca6fd0ba11fbc09e81e6915fc48cd.jpg'),
(87587, 6080, 'Alba S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182469.mp4', 'http://timg.bdta.pro/images/8566643a9a99edf2b6e8369b5b6d179a.jpg'),
(87588, 6080, 'Alba S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182470.mp4', 'http://timg.bdta.pro/images/212ee2e551906cec283279ef9f9f5ca1.jpg'),
(87589, 6080, 'Alba S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182471.mp4', 'http://timg.bdta.pro/images/985ecfabef19693f0aca9c5a7894f6dc.jpg'),
(87590, 6080, 'Alba S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182472.mp4', 'http://timg.bdta.pro/images/d8898c0c22a5195ffcece56e1357698f.jpg'),
(87591, 6080, 'Alba S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182473.mp4', 'http://timg.bdta.pro/images/634435d154b4c56856b11e919c35b10d.jpg'),
(87592, 6080, 'Alba S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/182474.mp4', 'http://timg.bdta.pro/images/499b462712e033a51cc2e64ab17236f5.jpg'),
(87593, 6080, 'Alba S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/182475.mp4', 'http://timg.bdta.pro/images/dc42733587e0885f24aa3a8bf2b693ce.jpg'),
(87594, 6080, 'Alba S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/182476.mp4', 'http://timg.bdta.pro/images/b1f8db475bbdf627dbda0a831843d301.jpg'),
(87595, 6080, 'Alba S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/182477.mp4', 'http://timg.bdta.pro/images/f738d24fec202b741eadee111a9c9b83.jpg'),
(87596, 6080, 'Alba S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/182478.mp4', 'http://timg.bdta.pro/images/69eddb529c012df6399c1f376e77251f.jpg'),
(87597, 35, 'Anos Incríveis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182444.mp4', 'http://timg.bdta.pro/images/3636e6f269c902a1f2fc4da327d71714.jpg'),
(87598, 35, 'Anos Incríveis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182445.mp4', 'http://timg.bdta.pro/images/cc5216c538b028f44ae6c897a25898fe.jpg'),
(87599, 35, 'Anos Incríveis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182446.mp4', 'http://timg.bdta.pro/images/77ce1e7180e000704a86f439a3f677b5.jpg'),
(87600, 35, 'Anos Incríveis S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182447.mp4', 'http://timg.bdta.pro/images/e8adde55cf4746a3bd535b8847b6c203.jpg'),
(87601, 35, 'Anos Incríveis S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182448.mp4', 'http://timg.bdta.pro/images/e8a7284be8d39310d31ebe376479cbb5.jpg'),
(87602, 35, 'Anos Incríveis S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182449.mp4', 'http://timg.bdta.pro/images/cbf20eed12cec98415fb484e9ade75ab.jpg'),
(87603, 35, 'Anos Incríveis S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182450.mp4', 'http://timg.bdta.pro/images/542536d77abe3b8b480a3e8874953b73.jpg'),
(87604, 35, 'Anos Incríveis S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182451.mp4', 'http://timg.bdta.pro/images/5d46a2c43bf7e6f658457a019417b53b.jpg'),
(87605, 35, 'Anos Incríveis S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/182452.mp4', 'http://timg.bdta.pro/images/bc2b73f67ff131eba1b96b7b841071c3.jpg'),
(87606, 35, 'Anos Incríveis S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/182453.mp4', 'http://timg.bdta.pro/images/cc9c4304a3e01003f17713394a7f0ee2.jpg'),
(87607, 35, 'Anos Incríveis S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/182454.mp4', 'http://timg.bdta.pro/images/a20875d4273df1c002467906d52b541d.jpg'),
(87608, 35, 'Anos Incríveis S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/182455.mp4', 'http://timg.bdta.pro/images/4f3d07f143b3a683b7dc195d2ab68785.jpg'),
(87609, 35, 'Anos Incríveis S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/182456.mp4', 'http://timg.bdta.pro/images/50eb75018abe9202db788f5785e5a2de.jpg'),
(87610, 35, 'Anos Incríveis S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/182457.mp4', 'http://timg.bdta.pro/images/569bcb74b78472152c7d5b499c556710.jpg'),
(87611, 35, 'Anos Incríveis S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/182458.mp4', 'http://timg.bdta.pro/images/4a364a0355148a19b08ef141f0822ecd.jpg'),
(87612, 35, 'Anos Incríveis S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/182459.mp4', 'http://gstaticontent.com/images/be88d8d160c64f657531e075c3b99fc1.jpg'),
(87613, 35, 'Anos Incríveis S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/182460.mp4', 'http://gstaticontent.com/images/be88d8d160c64f657531e075c3b99fc1.jpg'),
(87614, 35, 'Anos Incríveis S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/182461.mp4', 'http://gstaticontent.com/images/be88d8d160c64f657531e075c3b99fc1.jpg'),
(87615, 35, 'Anos Incríveis S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/182462.mp4', 'http://gstaticontent.com/images/be88d8d160c64f657531e075c3b99fc1.jpg'),
(87616, 35, 'Anos Incríveis S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/182463.mp4', 'http://gstaticontent.com/images/be88d8d160c64f657531e075c3b99fc1.jpg'),
(87617, 35, 'Anos Incríveis S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/182464.mp4', 'http://gstaticontent.com/images/be88d8d160c64f657531e075c3b99fc1.jpg'),
(87618, 35, 'Anos Incríveis S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/182465.mp4', 'http://gstaticontent.com/images/be88d8d160c64f657531e075c3b99fc1.jpg'),
(87619, 6081, 'As Filhas da Seita Uma Historia de Abusos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182439.mp4', 'http://timg.bdta.pro/images/f26cdb88a405894d734b9de95cb1111d.jpg'),
(87620, 6081, 'As Filhas da Seita Uma Historia de Abusos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182440.mp4', 'http://timg.bdta.pro/images/83d0c3aa21f547a175545f156a11dad6.jpg'),
(87621, 6081, 'As Filhas da Seita Uma Historia de Abusos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182441.mp4', 'http://timg.bdta.pro/images/b046ca018a0a97edddf2fc06b103aca9.jpg'),
(87622, 6081, 'As Filhas da Seita Uma Historia de Abusos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182442.mp4', 'http://timg.bdta.pro/images/08e3e058554b03dbfb437dabe43e3129.jpg'),
(87623, 6081, 'As Filhas da Seita Uma Historia de Abusos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182443.mp4', 'http://timg.bdta.pro/images/ebdfa48fd373655b5da0814c8c3ff5f3.jpg'),
(87624, 6082, 'D.B. Cooper: Desaparecimento no Ar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182435.mp4', 'http://timg.bdta.pro/images/b4fcde3b27b6466665fe75fff1bfc6af.jpg'),
(87625, 6082, 'D.B. Cooper: Desaparecimento no Ar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182436.mp4', 'http://timg.bdta.pro/images/42f4bb562c2cd75dd9a120385d6a6ca3.jpg'),
(87626, 6082, 'D.B. Cooper: Desaparecimento no Ar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182437.mp4', 'http://timg.bdta.pro/images/795fae70cf6465aa4462ed61e6ec8f53.jpg'),
(87627, 6082, 'D.B. Cooper: Desaparecimento no Ar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182438.mp4', 'http://timg.bdta.pro/images/f785e9a4dd9399265182ca6a8ca3d16b.jpg'),
(87628, 6083, 'Farzar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182425.mp4', 'http://timg.bdta.pro/images/a8b97a97b25166c41bb743da47f13f45.jpg'),
(87629, 6083, 'Farzar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182426.mp4', 'http://timg.bdta.pro/images/eb04ea8ed621f692703abc5c3558fdeb.jpg'),
(87630, 6083, 'Farzar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182428.mp4', 'http://timg.bdta.pro/images/f7208b57ca760b6df3a4206b7fd73066.jpg'),
(87631, 6083, 'Farzar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182429.mp4', 'http://timg.bdta.pro/images/dc75cc436e0d919f92cb62f4e555118e.jpg'),
(87632, 6083, 'Farzar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182430.mp4', 'http://timg.bdta.pro/images/5981aabdab319c964bfbc6d03ee12df2.jpg'),
(87633, 6083, 'Farzar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182431.mp4', 'http://timg.bdta.pro/images/767e949574632641bb488001cae88a22.jpg'),
(87634, 6083, 'Farzar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182432.mp4', 'http://timg.bdta.pro/images/0ee1b2393cdb5c1941f25fb202f115a8.jpg'),
(87635, 6083, 'Farzar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182433.mp4', 'http://timg.bdta.pro/images/805603f236acb5df1f9d03f8bb156f50.jpg'),
(87636, 6083, 'Farzar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/182434.mp4', 'http://timg.bdta.pro/images/2fdb74570ecc756339d29abfa64ce0e7.jpg'),
(87637, 6084, '﻿Happy End: Por Trás da Webcam S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182417.mp4', 'http://timg.bdta.pro/images/8aa89c3d4706fafcbfedd391327fb27e.jpg'),
(87638, 6084, '﻿Happy End: Por Trás da Webcam S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182418.mp4', 'http://timg.bdta.pro/images/103dfd0321a001114bc736df68d51802.jpg'),
(87639, 6084, '﻿Happy End: Por Trás da Webcam S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182419.mp4', 'http://timg.bdta.pro/images/8bde22ba6378881a55307700128b2635.jpg'),
(87640, 6084, '﻿Happy End: Por Trás da Webcam S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182420.mp4', 'http://timg.bdta.pro/images/d77154520b3c2bdbe511ad5c87c23ac6.jpg'),
(87641, 6084, '﻿Happy End: Por Trás da Webcam S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182421.mp4', 'http://timg.bdta.pro/images/d43b69581b7b06ba965c8c1fd1f8f5e0.jpg'),
(87642, 6084, '﻿Happy End: Por Trás da Webcam S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182422.mp4', 'http://timg.bdta.pro/images/c885573c732e13370f10485a4bc055c2.jpg'),
(87643, 6084, '﻿Happy End: Por Trás da Webcam S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182423.mp4', 'http://timg.bdta.pro/images/e6c994255cfc8e6edf053773b1fa959d.jpg'),
(87644, 6084, '﻿Happy End: Por Trás da Webcam S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182424.mp4', 'http://timg.bdta.pro/images/1be48f7e80f20ee6d2b73e817959c0c8.jpg'),
(87645, 6085, 'Kung Fu Panda: O Cavaleiro Dragão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231914.mp4', 'http://timg.bdta.pro/images/9bb76b69dbc973b7ebaac7fcba43de92.jpg'),
(87646, 6085, 'Kung Fu Panda: O Cavaleiro Dragão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231915.mp4', 'http://timg.bdta.pro/images/62efe88869eceb00ed30e5da6218c382.jpg'),
(87647, 6085, 'Kung Fu Panda: O Cavaleiro Dragão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231916.mp4', 'http://timg.bdta.pro/images/c403617ea459fdc9f0fe1551028794a7.jpg'),
(87648, 6085, 'Kung Fu Panda: O Cavaleiro Dragão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231917.mp4', 'http://timg.bdta.pro/images/06121145903d0b6593d7c14b720f8b7e.jpg'),
(87649, 6085, 'Kung Fu Panda: O Cavaleiro Dragão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231918.mp4', 'http://timg.bdta.pro/images/c806c7175a59b22f16d4612272c7f00f.jpg'),
(87650, 6085, 'Kung Fu Panda: O Cavaleiro Dragão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231919.mp4', 'http://timg.bdta.pro/images/335547998ae2561d34f15e994acad57e.jpg'),
(87651, 6085, 'Kung Fu Panda: O Cavaleiro Dragão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231920.mp4', 'http://timg.bdta.pro/images/e96212f74278c08c18df036e9282e6c9.jpg'),
(87652, 6085, 'Kung Fu Panda: O Cavaleiro Dragão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231921.mp4', 'http://timg.bdta.pro/images/a973c369c0396eb7e8d47e693376b589.jpg'),
(87653, 6085, 'Kung Fu Panda: O Cavaleiro Dragão S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231922.mp4', 'http://timg.bdta.pro/images/272ea6d0cacb250e10d97e35492220bb.jpg'),
(87654, 6085, 'Kung Fu Panda: O Cavaleiro Dragão S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231923.mp4', 'http://timg.bdta.pro/images/d13808686824c3a9ef4d026cf02f3d4b.jpg'),
(87655, 6085, 'Kung Fu Panda: O Cavaleiro Dragão S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/231924.mp4', 'http://timg.bdta.pro/images/7dc7bd501e48ae2306300e10cc971c9d.jpg'),
(87656, 6086, 'Kung Fu Panda: O Cavaleiro Dragão S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vYODoN7fjSuvDGCJLrQeFSJzooq.jpg'),
(87657, 6086, 'Kung Fu Panda: O Cavaleiro Dragão S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8oaAMGtl49EOnTpmlWs70zPN04o.jpg'),
(87658, 6086, 'Kung Fu Panda: O Cavaleiro Dragão S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jMxD2qp9njYREPq958KgFJBaHkj.jpg'),
(87659, 6086, 'Kung Fu Panda: O Cavaleiro Dragão S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Rg3QTcci9XInEq5xKCzh3lFoBa.jpg'),
(87660, 6086, 'Kung Fu Panda: O Cavaleiro Dragão S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6RWXLQBaSCzOkrynonRj3U6taan.jpg'),
(87661, 6086, 'Kung Fu Panda: O Cavaleiro Dragão S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ilDOisGoHAomZTrMNPvu1mevVoe.jpg'),
(87662, 6086, 'Kung Fu Panda: O Cavaleiro Dragão S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/60uNPjn9Fr41l6gDXW8wM1fws05.jpg'),
(87663, 6086, 'Kung Fu Panda: O Cavaleiro Dragão S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/SUFA1gftZyoQynIXrCjmVozrUw.jpg'),
(87664, 6086, 'Kung Fu Panda: O Cavaleiro Dragão S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gjFBTGqXLfCt9b2BUsAQCoWYLG3.jpg'),
(87665, 6086, 'Kung Fu Panda: O Cavaleiro Dragão S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tyrctUa4ccvn637GUtmotMUm85t.jpg'),
(87666, 6086, 'Kung Fu Panda: O Cavaleiro Dragão S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/231935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mBOrkR2pq4o2GzH7wLMukVN43dU.jpg'),
(87667, 6086, 'Kung Fu Panda: O Cavaleiro Dragão S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/231936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xOPpsFr3h75Ngditi2cFVYIVL8t.jpg'),
(87668, 6087, 'Kung Fu Panda: O Cavaleiro Dragão S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yi144P3NzY9aGjImFHcNcOPyVEC.jpg'),
(87669, 6087, 'Kung Fu Panda: O Cavaleiro Dragão S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Zo6yPmbC0gw6UL4ifmJoZ9gwGy.jpg'),
(87670, 6087, 'Kung Fu Panda: O Cavaleiro Dragão S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iejm8xFDduW1PHemT2TVonE8S95.jpg'),
(87671, 6087, 'Kung Fu Panda: O Cavaleiro Dragão S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6VafSTjzAdNAetzYqCIe8UVqaFM.jpg'),
(87672, 6087, 'Kung Fu Panda: O Cavaleiro Dragão S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8kFn1Tzy5glgJCIEWCg3GajFdK4.jpg'),
(87673, 6087, 'Kung Fu Panda: O Cavaleiro Dragão S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZigUlLkAk7iCA3IFOjAyTEPKyW.jpg'),
(87674, 6087, 'Kung Fu Panda: O Cavaleiro Dragão S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sXB94RKprbgZAPVzWmuoevba4L0.jpg'),
(87675, 6087, 'Kung Fu Panda: O Cavaleiro Dragão S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0fbFKx75PaoHfshs2NxVV5z2w6.jpg'),
(87676, 6087, 'Kung Fu Panda: O Cavaleiro Dragão S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A7F4usFot9Jz1o7fETeDXzHoi0l.jpg'),
(87677, 6087, 'Kung Fu Panda: O Cavaleiro Dragão S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sybPiWW0jwZ0qmtLJPGfq5gxa7a.jpg'),
(87678, 6087, 'Kung Fu Panda: O Cavaleiro Dragão S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/231947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ecKql4SxzpYvOrtT7ENUczNIxKe.jpg'),
(87679, 6087, 'Kung Fu Panda: O Cavaleiro Dragão S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/231948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pOArhZ7xSXnUm5QrIDOvDCMWgF9.jpg'),
(87680, 6087, 'Kung Fu Panda: O Cavaleiro Dragão S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/231949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udMpsHh7l4DTlbdUq7Jj2fcgeIR.jpg'),
(87681, 6087, 'Kung Fu Panda: O Cavaleiro Dragão S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/231950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w1da7hbXRACWXCAn1XRq5Z6YnOw.jpg'),
(87682, 6087, 'Kung Fu Panda: O Cavaleiro Dragão S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/231951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xPM5NJDOsQWwqoSaH3wmRKkgEm1.jpg'),
(87683, 6087, 'Kung Fu Panda: O Cavaleiro Dragão S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/231952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3uUyszCsWyK8wl3On6XMmf7qZjv.jpg'),
(87684, 6087, 'Kung Fu Panda: O Cavaleiro Dragão S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/231953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ywRgU7qCrC4DUxD8K88Wuwp3Yhr.jpg'),
(87685, 6087, 'Kung Fu Panda: O Cavaleiro Dragão S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/231954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oymXR9OnoKn6tsCk9F3H9CvjFyC.jpg'),
(87686, 6087, 'Kung Fu Panda: O Cavaleiro Dragão S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/231955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Am9SsIuVgTSJWyuSx4P1WF33HHu.jpg'),
(87687, 6088, 'María Marta: O Assassinato no Country Clube S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182409.mp4', 'http://timg.bdta.pro/images/1a54b5e7788089859928a613c0c39331.jpg'),
(87688, 6088, 'María Marta: O Assassinato no Country Clube S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182410.mp4', 'http://timg.bdta.pro/images/61309e17b82d031fd4f7e108ed0165a0.jpg'),
(87689, 6088, 'María Marta: O Assassinato no Country Clube S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182411.mp4', 'http://timg.bdta.pro/images/08e557f5e11ba4a55f6075003d4096fc.jpg'),
(87690, 6088, 'María Marta: O Assassinato no Country Clube S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182412.mp4', 'http://timg.bdta.pro/images/da2afd01f4306d04bc676b9327eefabb.jpg'),
(87691, 6088, 'María Marta: O Assassinato no Country Clube S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182413.mp4', 'http://timg.bdta.pro/images/46295f27b5cb363d12eb43b6a2e17cc0.jpg'),
(87692, 6088, 'María Marta: O Assassinato no Country Clube S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182414.mp4', 'http://timg.bdta.pro/images/473674e9abb2c327a572ec68af0cd835.jpg'),
(87693, 6088, 'María Marta: O Assassinato no Country Clube S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182415.mp4', 'http://timg.bdta.pro/images/e1aca992def1320851b7565a365aae69.jpg'),
(87694, 6088, 'María Marta: O Assassinato no Country Clube S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182416.mp4', 'http://timg.bdta.pro/images/b6cab47af1e5d3e6113028aaf67324d1.jpg'),
(87695, 6089, 'Match VIP S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182401.mp4', 'http://timg.bdta.pro/images/16977c990ba457c4486b85de3ad084f8.jpg'),
(87696, 6089, 'Match VIP S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182402.mp4', 'http://timg.bdta.pro/images/8396f828aea6992486f90ba8b16d3a9e.jpg'),
(87697, 6089, 'Match VIP S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182403.mp4', 'http://timg.bdta.pro/images/0eaab6c1845ecd1ea6299c04f26d854d.jpg'),
(87698, 6089, 'Match VIP S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182404.mp4', 'http://timg.bdta.pro/images/0e3734dc26d547ee88e79f8245b70aab.jpg'),
(87699, 6089, 'Match VIP S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182405.mp4', 'http://timg.bdta.pro/images/7b6030b593101c05f41f1601fd0b53c0.jpg'),
(87700, 6089, 'Match VIP S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182406.mp4', 'http://timg.bdta.pro/images/69b5502111c4a7a4babb95b128d8a8ed.jpg'),
(87701, 6089, 'Match VIP S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182407.mp4', 'http://timg.bdta.pro/images/b7eb7e30a7e29a31a3ddced1fe98017b.jpg'),
(87702, 6089, 'Match VIP S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182408.mp4', 'http://timg.bdta.pro/images/69575899ae8d984676db08a79cea7d29.jpg'),
(87703, 6090, 'Os Mistérios de Frajola e Piu-Piu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182346.mp4', 'http://timg.bdta.pro/images/0eef97655ebed35772e0fb3ea791a861.jpg'),
(87704, 6090, 'Os Mistérios de Frajola e Piu-Piu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182347.mp4', 'http://timg.bdta.pro/images/70f5ae8d840880ee82f3a6470042e0b6.jpg'),
(87705, 6090, 'Os Mistérios de Frajola e Piu-Piu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182348.mp4', 'http://timg.bdta.pro/images/e240256df13369757a11d26a7f0d604d.jpg'),
(87706, 6090, 'Os Mistérios de Frajola e Piu-Piu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182349.mp4', 'http://timg.bdta.pro/images/f45806cfab530ec4cca5bf5a66790194.jpg'),
(87707, 6090, 'Os Mistérios de Frajola e Piu-Piu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182350.mp4', 'http://timg.bdta.pro/images/e849ac5a2d0fa7ddb7c318839bb37db7.jpg'),
(87708, 6090, 'Os Mistérios de Frajola e Piu-Piu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182351.mp4', 'http://timg.bdta.pro/images/75df47d13a4134e56e3d3ecfb41fe248.jpg'),
(87709, 6090, 'Os Mistérios de Frajola e Piu-Piu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182352.mp4', 'http://timg.bdta.pro/images/89f57f4b2695530b2dd6c92d91173997.jpg'),
(87710, 6090, 'Os Mistérios de Frajola e Piu-Piu S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182353.mp4', 'http://timg.bdta.pro/images/7e3ae8fd25d95d8c131c29efd01ed2f9.jpg'),
(87711, 6090, 'Os Mistérios de Frajola e Piu-Piu S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/182354.mp4', 'http://timg.bdta.pro/images/cc3046ef2d14740e10e6a9359d7e831d.jpg'),
(87712, 6090, 'Os Mistérios de Frajola e Piu-Piu S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/182355.mp4', 'http://timg.bdta.pro/images/b392de34e6af34aae6f2a84811072b66.jpg'),
(87713, 6090, 'Os Mistérios de Frajola e Piu-Piu S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/182356.mp4', 'http://timg.bdta.pro/images/57de44f1f09d94c47e6eb36d1f7aa20a.jpg'),
(87714, 6090, 'Os Mistérios de Frajola e Piu-Piu S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/182357.mp4', 'http://timg.bdta.pro/images/9748a44e8b10604eaf8f2732a26e1038.jpg'),
(87715, 6090, 'Os Mistérios de Frajola e Piu-Piu S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/182358.mp4', 'http://timg.bdta.pro/images/6eb78868bba35952dcac8d1086a88352.jpg'),
(87716, 6091, 'Os Mistérios de Frajola e Piu-Piu S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182359.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87717, 6091, 'Os Mistérios de Frajola e Piu-Piu S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182360.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87718, 6091, 'Os Mistérios de Frajola e Piu-Piu S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182361.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87719, 6091, 'Os Mistérios de Frajola e Piu-Piu S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182362.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87720, 6091, 'Os Mistérios de Frajola e Piu-Piu S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182363.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87721, 6091, 'Os Mistérios de Frajola e Piu-Piu S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182364.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87722, 6091, 'Os Mistérios de Frajola e Piu-Piu S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182365.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87723, 6091, 'Os Mistérios de Frajola e Piu-Piu S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182366.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87724, 6091, 'Os Mistérios de Frajola e Piu-Piu S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/182367.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87725, 6091, 'Os Mistérios de Frajola e Piu-Piu S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/182368.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87726, 6091, 'Os Mistérios de Frajola e Piu-Piu S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/182369.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87727, 6091, 'Os Mistérios de Frajola e Piu-Piu S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/182370.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87728, 6091, 'Os Mistérios de Frajola e Piu-Piu S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/182371.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87729, 6091, 'Os Mistérios de Frajola e Piu-Piu S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/182372.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87730, 6091, 'Os Mistérios de Frajola e Piu-Piu S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/182373.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87731, 6091, 'Os Mistérios de Frajola e Piu-Piu S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/182374.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87732, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182375.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87733, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182376.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87734, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182377.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87735, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182378.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87736, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182379.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87737, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182380.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87738, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182381.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87739, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182382.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87740, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/182383.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87741, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/182384.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87742, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/182385.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87743, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/182386.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87744, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/182387.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87745, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/182388.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87746, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/182389.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87747, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/182390.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87748, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/182391.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87749, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/182392.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87750, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/182393.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87751, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/182394.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87752, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/182395.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87753, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/182396.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87754, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/182397.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87755, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/182398.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87756, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/182399.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87757, 6092, 'Os Mistérios de Frajola e Piu-Piu S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/182400.mp4', 'http://gstaticontent.com/images/18af5c3b8bac33a7aaa8f562ffb5f7e4.jpg'),
(87758, 6093, 'Pegos na Rede S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182340.mp4', 'http://gstaticontent.com/images/c989b03a4203ce71e329ff6b3600d31d.jpg'),
(87759, 6093, 'Pegos na Rede S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182341.mp4', 'http://gstaticontent.com/images/c989b03a4203ce71e329ff6b3600d31d.jpg'),
(87760, 6093, 'Pegos na Rede S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182342.mp4', 'http://gstaticontent.com/images/c989b03a4203ce71e329ff6b3600d31d.jpg'),
(87761, 6093, 'Pegos na Rede S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182343.mp4', 'http://gstaticontent.com/images/c989b03a4203ce71e329ff6b3600d31d.jpg'),
(87762, 6093, 'Pegos na Rede S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182344.mp4', 'http://gstaticontent.com/images/c989b03a4203ce71e329ff6b3600d31d.jpg'),
(87763, 6093, 'Pegos na Rede S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182345.mp4', 'http://gstaticontent.com/images/c989b03a4203ce71e329ff6b3600d31d.jpg'),
(87764, 6094, 'Resident Evil: A Série S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182332.mp4', 'http://timg.bdta.pro/images/ade4f37ac2507c8a6e41b7fb15c5cf68.jpg'),
(87765, 6094, 'Resident Evil: A Série S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182333.mp4', 'http://timg.bdta.pro/images/eb183457f74fe443753ffbe437ac3a1d.jpg'),
(87766, 6094, 'Resident Evil: A Série S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182334.mp4', 'http://timg.bdta.pro/images/821eef065955bafa319b9a881437f21d.jpg'),
(87767, 6094, 'Resident Evil: A Série S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182335.mp4', 'http://timg.bdta.pro/images/38cb02b3f1410987fe801bd9c369a93b.jpg'),
(87768, 6094, 'Resident Evil: A Série S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182336.mp4', 'http://timg.bdta.pro/images/029ec93e8eda3ed6c758ec413c725658.jpg'),
(87769, 6094, 'Resident Evil: A Série S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182337.mp4', 'http://timg.bdta.pro/images/4c6015530bcad2ff9f93c49c7cad7bb0.jpg'),
(87770, 6094, 'Resident Evil: A Série S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182338.mp4', 'http://timg.bdta.pro/images/c25e9de3d3ff13b466b2b84c79bca66a.jpg'),
(87771, 6094, 'Resident Evil: A Série S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182339.mp4', 'http://timg.bdta.pro/images/9fa51dc0f3633e2440f33e4ff242e32f.jpg'),
(87772, 6095, 'Murabito A ni Tensei Suru S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182320.mp4', 'http://timg.bdta.pro/images/68af88fab17f5775cf3e1b04824bd2c5.jpg'),
(87773, 6095, 'Murabito A ni Tensei Suru S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182321.mp4', 'http://timg.bdta.pro/images/3b79b1f7b8dc843d90154c3b84bc1739.jpg'),
(87774, 6095, 'Murabito A ni Tensei Suru S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182322.mp4', 'http://timg.bdta.pro/images/f334a9dd8556de494da7585dc304f460.jpg'),
(87775, 6095, 'Murabito A ni Tensei Suru S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182323.mp4', 'http://timg.bdta.pro/images/8e734a406aae5288ca01dee02d18f6b0.jpg'),
(87776, 6095, 'Murabito A ni Tensei Suru S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182324.mp4', 'http://timg.bdta.pro/images/2f58aed6e07d6a945bddb7681b8365e2.jpg'),
(87777, 6095, 'Murabito A ni Tensei Suru S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182325.mp4', 'http://timg.bdta.pro/images/36a86008c15d5a6ddbe9181970a3ca40.jpg'),
(87778, 6095, 'Murabito A ni Tensei Suru S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182326.mp4', 'http://timg.bdta.pro/images/daeecb8d7486a5ea830d0d831b1b06b7.jpg'),
(87779, 6095, 'Murabito A ni Tensei Suru S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182327.mp4', 'http://timg.bdta.pro/images/5088420dcd26bf15c9707dcea12efa20.jpg'),
(87780, 6095, 'Murabito A ni Tensei Suru S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/182328.mp4', 'http://timg.bdta.pro/images/bb292a600f97e74ad1747ca0a33dd16d.jpg'),
(87781, 6095, 'Murabito A ni Tensei Suru S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/182329.mp4', 'http://timg.bdta.pro/images/3de251d1247c207788d1242255259d3c.jpg'),
(87782, 6095, 'Murabito A ni Tensei Suru S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/182330.mp4', 'http://timg.bdta.pro/images/5b939ec1568677fc55f1c7bfb907e692.jpg'),
(87783, 6095, 'Murabito A ni Tensei Suru S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/182331.mp4', 'http://timg.bdta.pro/images/9bd50a917d4481845117b3567dc3fae0.jpg'),
(87784, 6096, 'Soco no Estômago S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182316.mp4', 'http://timg.bdta.pro/images/f2b4fa77c1fb3a7705c3b140f7602529.jpg'),
(87785, 6096, 'Soco no Estômago S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182317.mp4', 'http://timg.bdta.pro/images/5310c883cfb7f7fb25b1891615a20cc5.jpg'),
(87786, 6096, 'Soco no Estômago S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182318.mp4', 'http://timg.bdta.pro/images/fca5af262002a8674956ed4f739d2d05.jpg'),
(87787, 6096, 'Soco no Estômago S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182319.mp4', 'http://timg.bdta.pro/images/17688b9ab8975dd2f3cde7fd324dff9b.jpg'),
(87788, 6097, 'Spidey e Seus Amigos Espetaculares S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224084.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87789, 6097, 'Spidey e Seus Amigos Espetaculares S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224085.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87790, 6097, 'Spidey e Seus Amigos Espetaculares S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224086.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87791, 6097, 'Spidey e Seus Amigos Espetaculares S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224087.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87792, 6097, 'Spidey e Seus Amigos Espetaculares S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224088.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87793, 6097, 'Spidey e Seus Amigos Espetaculares S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224089.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87794, 6097, 'Spidey e Seus Amigos Espetaculares S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224090.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87795, 6097, 'Spidey e Seus Amigos Espetaculares S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224091.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87796, 6097, 'Spidey e Seus Amigos Espetaculares S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224092.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87797, 6097, 'Spidey e Seus Amigos Espetaculares S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224093.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87798, 6097, 'Spidey e Seus Amigos Espetaculares S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224094.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87799, 6097, 'Spidey e Seus Amigos Espetaculares S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224095.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87800, 6097, 'Spidey e Seus Amigos Espetaculares S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224096.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87801, 6097, 'Spidey e Seus Amigos Espetaculares S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224097.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87802, 6097, 'Spidey e Seus Amigos Espetaculares S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224098.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87803, 6097, 'Spidey e Seus Amigos Espetaculares S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224099.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87804, 6097, 'Spidey e Seus Amigos Espetaculares S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224100.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87805, 6097, 'Spidey e Seus Amigos Espetaculares S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224101.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87806, 6097, 'Spidey e Seus Amigos Espetaculares S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224102.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(87807, 6097, 'Spidey e Seus Amigos Espetaculares S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224103.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87808, 6097, 'Spidey e Seus Amigos Espetaculares S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224104.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87809, 6097, 'Spidey e Seus Amigos Espetaculares S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224105.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87810, 6097, 'Spidey e Seus Amigos Espetaculares S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/224106.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87811, 6097, 'Spidey e Seus Amigos Espetaculares S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/224107.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87812, 6097, 'Spidey e Seus Amigos Espetaculares S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/224108.mp4', 'http://image.tmdb.org/t/p/w1280/c3Xj7DWnDrqVmOGa7oFYKN81Tea.jpg'),
(87813, 6098, 'Spidey e Seus Amigos Espetaculares S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/729570.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87814, 6098, 'Spidey e Seus Amigos Espetaculares S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/729571.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87815, 6098, 'Spidey e Seus Amigos Espetaculares S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/729572.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87816, 6098, 'Spidey e Seus Amigos Espetaculares S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/729573.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87817, 6098, 'Spidey e Seus Amigos Espetaculares S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/729574.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87818, 6098, 'Spidey e Seus Amigos Espetaculares S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/729575.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87819, 6098, 'Spidey e Seus Amigos Espetaculares S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/729576.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87820, 6098, 'Spidey e Seus Amigos Espetaculares S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/729577.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87821, 6098, 'Spidey e Seus Amigos Espetaculares S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/729578.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87822, 6098, 'Spidey e Seus Amigos Espetaculares S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/729579.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87823, 6098, 'Spidey e Seus Amigos Espetaculares S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/729580.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87824, 6098, 'Spidey e Seus Amigos Espetaculares S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/729581.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87825, 6098, 'Spidey e Seus Amigos Espetaculares S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/729582.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87826, 6098, 'Spidey e Seus Amigos Espetaculares S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/729583.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87827, 6098, 'Spidey e Seus Amigos Espetaculares S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/729584.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87828, 6098, 'Spidey e Seus Amigos Espetaculares S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/729585.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87829, 6098, 'Spidey e Seus Amigos Espetaculares S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/729586.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87830, 6098, 'Spidey e Seus Amigos Espetaculares S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/729587.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87831, 6098, 'Spidey e Seus Amigos Espetaculares S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/729588.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87832, 6098, 'Spidey e Seus Amigos Espetaculares S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/729589.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87833, 6098, 'Spidey e Seus Amigos Espetaculares S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/729590.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87834, 6098, 'Spidey e Seus Amigos Espetaculares S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/729591.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87835, 6098, 'Spidey e Seus Amigos Espetaculares S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/729592.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87836, 6098, 'Spidey e Seus Amigos Espetaculares S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/729593.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87837, 6098, 'Spidey e Seus Amigos Espetaculares S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/729594.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87838, 6098, 'Spidey e Seus Amigos Espetaculares S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/729595.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87839, 6098, 'Spidey e Seus Amigos Espetaculares S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/729596.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87840, 6098, 'Spidey e Seus Amigos Espetaculares S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/729597.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87841, 6098, 'Spidey e Seus Amigos Espetaculares S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/729598.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87842, 6099, 'Spidey e Seus Amigos Espetaculares S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/729599.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87843, 6099, 'Spidey e Seus Amigos Espetaculares S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/729600.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87844, 6099, 'Spidey e Seus Amigos Espetaculares S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/729601.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87845, 6099, 'Spidey e Seus Amigos Espetaculares S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/729602.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87846, 6099, 'Spidey e Seus Amigos Espetaculares S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/729603.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87847, 6099, 'Spidey e Seus Amigos Espetaculares S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/729604.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87848, 6099, 'Spidey e Seus Amigos Espetaculares S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/729605.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87849, 6099, 'Spidey e Seus Amigos Espetaculares S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/729606.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87850, 6099, 'Spidey e Seus Amigos Espetaculares S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/729607.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87851, 6099, 'Spidey e Seus Amigos Espetaculares S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/729608.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87852, 6099, 'Spidey e Seus Amigos Espetaculares S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/729609.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87853, 6099, 'Spidey e Seus Amigos Espetaculares S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/729610.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87854, 6099, 'Spidey e Seus Amigos Espetaculares S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/729611.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87855, 6099, 'Spidey e Seus Amigos Espetaculares S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/729612.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87856, 6099, 'Spidey e Seus Amigos Espetaculares S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/729613.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87857, 6099, 'Spidey e Seus Amigos Espetaculares S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/729614.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87858, 6099, 'Spidey e Seus Amigos Espetaculares S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/729615.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87859, 6099, 'Spidey e Seus Amigos Espetaculares S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/729616.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87860, 6099, 'Spidey e Seus Amigos Espetaculares S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/729617.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87861, 6099, 'Spidey e Seus Amigos Espetaculares S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/729618.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87862, 6099, 'Spidey e Seus Amigos Espetaculares S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/729619.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87863, 6099, 'Spidey e Seus Amigos Espetaculares S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/729620.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87864, 6099, 'Spidey e Seus Amigos Espetaculares S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/729621.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87865, 6099, 'Spidey e Seus Amigos Espetaculares S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/729622.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87866, 6099, 'Spidey e Seus Amigos Espetaculares S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/729623.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87867, 6099, 'Spidey e Seus Amigos Espetaculares S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/729624.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87868, 6099, 'Spidey e Seus Amigos Espetaculares S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/729625.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87869, 6099, 'Spidey e Seus Amigos Espetaculares S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/729626.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87870, 6099, 'Spidey e Seus Amigos Espetaculares S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/729627.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87871, 6099, 'Spidey e Seus Amigos Espetaculares S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/729628.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87872, 6100, 'Spidey e Seus Amigos Espetaculares S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/887726.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87873, 6100, 'Spidey e Seus Amigos Espetaculares S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/887727.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87874, 6100, 'Spidey e Seus Amigos Espetaculares S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/887728.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87875, 6100, 'Spidey e Seus Amigos Espetaculares S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/887729.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87876, 6100, 'Spidey e Seus Amigos Espetaculares S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/887730.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87877, 6100, 'Spidey e Seus Amigos Espetaculares S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/887731.mp4', 'http://gstaticontent.com/images/eabebd1a452be5e8e30fe6ee1d1c347d.jpg'),
(87878, 6101, 'Veleno: A Cidade das Crianças Perdidas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182229.mp4', 'http://timg.bdta.pro/images/6a91a3b40aeff707c770e16bace26322.jpg'),
(87879, 6101, 'Veleno: A Cidade das Crianças Perdidas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182230.mp4', 'http://timg.bdta.pro/images/20c3a2d5f4272b32bd146302ce827d8c.jpg'),
(87880, 6101, 'Veleno: A Cidade das Crianças Perdidas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182231.mp4', 'http://timg.bdta.pro/images/dda29ee021ca7f339598d820d1a3d5b2.jpg'),
(87881, 6101, 'Veleno: A Cidade das Crianças Perdidas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182232.mp4', 'http://timg.bdta.pro/images/09687d72540a7b47a4a4521e90a60a68.jpg'),
(87882, 6101, 'Veleno: A Cidade das Crianças Perdidas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182233.mp4', 'http://timg.bdta.pro/images/891782925a6c48d2e2ce898293f0a483.jpg'),
(87883, 6102, 'Construções Remotas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182222.mp4', 'http://timg.bdta.pro/images/aef39b98a8374cffe968a8bf4b28742d.jpg'),
(87884, 6102, 'Construções Remotas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182223.mp4', 'http://gstaticontent.com/images/def319d9c178397cdfdc918c8288b3f9.jpg'),
(87885, 6102, 'Construções Remotas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182224.mp4', 'http://gstaticontent.com/images/def319d9c178397cdfdc918c8288b3f9.jpg'),
(87886, 6102, 'Construções Remotas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182225.mp4', 'http://gstaticontent.com/images/def319d9c178397cdfdc918c8288b3f9.jpg'),
(87887, 6102, 'Construções Remotas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182226.mp4', 'http://gstaticontent.com/images/def319d9c178397cdfdc918c8288b3f9.jpg'),
(87888, 6102, 'Construções Remotas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182227.mp4', 'http://gstaticontent.com/images/def319d9c178397cdfdc918c8288b3f9.jpg'),
(87889, 6102, 'Construções Remotas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182228.mp4', 'http://gstaticontent.com/images/def319d9c178397cdfdc918c8288b3f9.jpg'),
(87890, 6103, 'Abdelmassih: Do Milagre ao Crime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182218.mp4', 'http://gstaticontent.com/images/3618de22476f64db98a018786269a205.jpg'),
(87891, 6103, 'Abdelmassih: Do Milagre ao Crime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182219.mp4', 'http://gstaticontent.com/images/3618de22476f64db98a018786269a205.jpg'),
(87892, 6103, 'Abdelmassih: Do Milagre ao Crime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182220.mp4', 'http://gstaticontent.com/images/3618de22476f64db98a018786269a205.jpg'),
(87893, 6103, 'Abdelmassih: Do Milagre ao Crime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182221.mp4', 'http://gstaticontent.com/images/3618de22476f64db98a018786269a205.jpg'),
(87894, 6104, 'The Loud House S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234630.mp4', 'http://timg.bdta.pro/images/5bd450c2214bd103dbca19464f5018e5.jpg'),
(87895, 6104, 'The Loud House S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234631.mp4', 'http://timg.bdta.pro/images/6672fcc42746e4320233aac56b00b409.jpg'),
(87896, 6104, 'The Loud House S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234632.mp4', 'http://timg.bdta.pro/images/a5fdfdf61d7ce2ff9dc3068579e0f16d.jpg'),
(87897, 6104, 'The Loud House S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234633.mp4', 'http://timg.bdta.pro/images/67b88c8eba18a41ccdca7d7642f088b0.jpg'),
(87898, 6104, 'The Loud House S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234634.mp4', 'http://timg.bdta.pro/images/0ae7346c5b51efd493300fae1fb8d6c1.jpg'),
(87899, 6104, 'The Loud House S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234635.mp4', 'http://timg.bdta.pro/images/679feeff6ba37fb052df466bc89d335f.jpg'),
(87900, 6104, 'The Loud House S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234636.mp4', 'http://timg.bdta.pro/images/15abf191df89cc5daec47b9410cb1784.jpg'),
(87901, 6104, 'The Loud House S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234637.mp4', 'http://timg.bdta.pro/images/621a7b59c1dcb801a34476088bdd677e.jpg'),
(87902, 6104, 'The Loud House S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234638.mp4', 'http://timg.bdta.pro/images/3d3f473df581750b915ebfa020ec0dcb.jpg'),
(87903, 6104, 'The Loud House S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234639.mp4', 'http://timg.bdta.pro/images/6c9984c66a32a6cc80cb81ad8676170e.jpg'),
(87904, 6104, 'The Loud House S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234640.mp4', 'http://timg.bdta.pro/images/6b12891da3147090fc3079bc23cb8a21.jpg'),
(87905, 6104, 'The Loud House S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234641.mp4', 'http://timg.bdta.pro/images/b960b3b5a93b9f0cccde315e073bc74d.jpg'),
(87906, 6104, 'The Loud House S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234642.mp4', 'http://timg.bdta.pro/images/10d9c48b3de9a8b603513c6fa184e0ec.jpg'),
(87907, 6104, 'The Loud House S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234643.mp4', 'http://timg.bdta.pro/images/ebd09c89722cb0b7b29ff6329a9ff849.jpg'),
(87908, 6104, 'The Loud House S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234644.mp4', 'http://timg.bdta.pro/images/da28dbb440dccfb2b836116fac3ed282.jpg'),
(87909, 6104, 'The Loud House S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234645.mp4', 'http://timg.bdta.pro/images/1cb7e619ecbe476b0feabb52d024610c.jpg'),
(87910, 6104, 'The Loud House S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234646.mp4', 'http://timg.bdta.pro/images/39dfc593a7e475f818afbe12ee43d037.jpg'),
(87911, 6104, 'The Loud House S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/234647.mp4', 'http://timg.bdta.pro/images/969e06567b122a9cb248ff3852e2792d.jpg'),
(87912, 6104, 'The Loud House S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/234648.mp4', 'http://timg.bdta.pro/images/d144f4cbd8a3b9b1ea893dad73a067ed.jpg'),
(87913, 6104, 'The Loud House S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/234649.mp4', 'http://timg.bdta.pro/images/4a36cfdc4e83e0f53f78388a28500200.jpg'),
(87914, 6104, 'The Loud House S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/234650.mp4', 'http://timg.bdta.pro/images/7588e942ba05324bcaa47c6a065c6a3d.jpg'),
(87915, 6104, 'The Loud House S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/234651.mp4', 'http://timg.bdta.pro/images/00754d895125d20a19bec0965bb941c1.jpg'),
(87916, 6104, 'The Loud House S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/234652.mp4', 'http://timg.bdta.pro/images/ba6bb4e1cc5d3c7a6bc668231f2e7412.jpg'),
(87917, 6104, 'The Loud House S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/234653.mp4', 'http://timg.bdta.pro/images/d188c7c4eabbe707552478371a60ef2c.jpg'),
(87918, 6104, 'The Loud House S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/234654.mp4', 'http://timg.bdta.pro/images/e9713f35687391f11a090dfa75f3cbba.jpg'),
(87919, 6104, 'The Loud House S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/234655.mp4', 'http://timg.bdta.pro/images/04ccad88a461321dddcfd6de5bcd2932.jpg'),
(87920, 6105, 'The Loud House S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234656.mp4', 'http://timg.bdta.pro/images/f7b2914332b9bda8589fe45b97100212.jpg'),
(87921, 6105, 'The Loud House S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234657.mp4', 'http://timg.bdta.pro/images/a5ce5db4beef5f92345d7493d3ec8f23.jpg'),
(87922, 6105, 'The Loud House S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234658.mp4', 'http://timg.bdta.pro/images/d9c571aecae20172247bd32aeb4d53b5.jpg'),
(87923, 6105, 'The Loud House S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234659.mp4', 'http://timg.bdta.pro/images/b233f7beb7978ad8d96f356ffeee145b.jpg'),
(87924, 6105, 'The Loud House S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234660.mp4', 'http://timg.bdta.pro/images/ea5a1bcb5a3e33f3e9495e0e139a2529.jpg'),
(87925, 6105, 'The Loud House S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234661.mp4', 'http://timg.bdta.pro/images/ebe4ebe6b3de1f64d285e799a68c9a7a.jpg'),
(87926, 6105, 'The Loud House S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234662.mp4', 'http://timg.bdta.pro/images/fec4078fb4681c9d2acda2dc7fd540b0.jpg'),
(87927, 6105, 'The Loud House S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234663.mp4', 'http://timg.bdta.pro/images/667e5a5c27996432a073b26538751ef0.jpg'),
(87928, 6105, 'The Loud House S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234664.mp4', 'http://timg.bdta.pro/images/082af38bfa7e5a492aa3bb69adc83048.jpg'),
(87929, 6105, 'The Loud House S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234665.mp4', 'http://timg.bdta.pro/images/d07229e7086dfd060e4388e55846d4e8.jpg'),
(87930, 6105, 'The Loud House S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234666.mp4', 'http://timg.bdta.pro/images/ef5f47c49fe79aae5518d40c99e0dd37.jpg'),
(87931, 6105, 'The Loud House S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234667.mp4', 'http://timg.bdta.pro/images/d30c52606c814f22cd8db7f7249e4fd6.jpg'),
(87932, 6105, 'The Loud House S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234668.mp4', 'http://timg.bdta.pro/images/757808b1569c42884155673b7fd7c693.jpg'),
(87933, 6105, 'The Loud House S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234669.mp4', 'http://timg.bdta.pro/images/05df7d13e06405b73a02bdd588ee72b8.jpg'),
(87934, 6105, 'The Loud House S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234670.mp4', 'http://timg.bdta.pro/images/24afa46717055ac023d114353f4ae94c.jpg'),
(87935, 6105, 'The Loud House S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234671.mp4', 'http://timg.bdta.pro/images/1ee115785b321d603177098cce6b4c5f.jpg'),
(87936, 6105, 'The Loud House S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234672.mp4', 'http://timg.bdta.pro/images/f3fbb9d67ea62259dae238666019e100.jpg'),
(87937, 6105, 'The Loud House S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/234673.mp4', 'http://timg.bdta.pro/images/a53755cbf75b1d64ac1aaacc21ed8f8d.jpg'),
(87938, 6105, 'The Loud House S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/234674.mp4', 'http://timg.bdta.pro/images/73430e9304273797fa79cc805bfeeb7c.jpg'),
(87939, 6105, 'The Loud House S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/234675.mp4', 'http://timg.bdta.pro/images/91445e0126d54c3cb7bf702b23a34e3b.jpg'),
(87940, 6105, 'The Loud House S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/234676.mp4', 'http://timg.bdta.pro/images/f9fad66a95cdf3587d88113ea70a047c.jpg'),
(87941, 6105, 'The Loud House S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/234677.mp4', 'http://timg.bdta.pro/images/29cef6d5535712a9e6de26dca6e9f13d.jpg'),
(87942, 6105, 'The Loud House S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/234678.mp4', 'http://timg.bdta.pro/images/d03d4ea6dbad31f48a7fb40967793b18.jpg'),
(87943, 6105, 'The Loud House S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/234679.mp4', 'http://timg.bdta.pro/images/2ff8b4e6f63ac99c436b72714a3b50af.jpg'),
(87944, 6105, 'The Loud House S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/234680.mp4', 'http://timg.bdta.pro/images/094aaf09ccba0ba9a43518e3d09a17c2.jpg'),
(87945, 6105, 'The Loud House S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/234681.mp4', 'http://timg.bdta.pro/images/276a0ea599cdba1aa857949e71a33a0a.jpg'),
(87946, 6106, 'The Loud House S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234682.mp4', 'http://timg.bdta.pro/images/ba78dd7678bdd41b7171e378b2108ef4.jpg'),
(87947, 6106, 'The Loud House S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234683.mp4', 'http://timg.bdta.pro/images/c7ff25071ee6f42039a9790a99eb6729.jpg'),
(87948, 6106, 'The Loud House S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234684.mp4', 'http://timg.bdta.pro/images/32411a049fa3fc71081b2782d8760490.jpg'),
(87949, 6106, 'The Loud House S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234685.mp4', 'http://timg.bdta.pro/images/859ccc2f11224a8975aeda5f07c5ec62.jpg'),
(87950, 6106, 'The Loud House S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234686.mp4', 'http://timg.bdta.pro/images/77c64e0229837bfdeb2fd3292eba6429.jpg'),
(87951, 6106, 'The Loud House S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234687.mp4', 'http://timg.bdta.pro/images/93131450af9cb693d82bf79171764ef0.jpg'),
(87952, 6106, 'The Loud House S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234688.mp4', 'http://timg.bdta.pro/images/6da1226f97e8ca29d3c5e6e791e44ef7.jpg'),
(87953, 6106, 'The Loud House S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234689.mp4', 'http://timg.bdta.pro/images/eb817e708ccba18d6e25bfd8909c6628.jpg'),
(87954, 6106, 'The Loud House S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234690.mp4', 'http://timg.bdta.pro/images/94c37774812f04fe7950ae46f9194394.jpg'),
(87955, 6106, 'The Loud House S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234691.mp4', 'http://timg.bdta.pro/images/eae74cc6f0d71201a63ba3d778019b4a.jpg'),
(87956, 6106, 'The Loud House S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234692.mp4', 'http://timg.bdta.pro/images/90ef5070bb69b1951369233a2953fb7c.jpg'),
(87957, 6106, 'The Loud House S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234693.mp4', 'http://timg.bdta.pro/images/d5d97c8d2f391127120e50e67f650691.jpg'),
(87958, 6106, 'The Loud House S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234694.mp4', 'http://timg.bdta.pro/images/eab6ee5a6da6915a1de35370af155dff.jpg'),
(87959, 6106, 'The Loud House S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234695.mp4', 'http://timg.bdta.pro/images/7d8c21c67219932177f52d676a461f7a.jpg'),
(87960, 6106, 'The Loud House S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234696.mp4', 'http://timg.bdta.pro/images/ab0b8c50f8696c38ff1da95ba6b77f88.jpg'),
(87961, 6106, 'The Loud House S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234697.mp4', 'http://timg.bdta.pro/images/36be91edbf6704552445520bad6f5d43.jpg'),
(87962, 6106, 'The Loud House S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234698.mp4', 'http://timg.bdta.pro/images/96f3139b4301c37ec8d889ef8416b8d6.jpg'),
(87963, 6106, 'The Loud House S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/234699.mp4', 'http://timg.bdta.pro/images/72d3c5657fbb5beb8221a17a9c28798a.jpg'),
(87964, 6106, 'The Loud House S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/234700.mp4', 'http://timg.bdta.pro/images/db2e54e136930142037cf7fc75fcb98d.jpg'),
(87965, 6106, 'The Loud House S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/234701.mp4', 'http://timg.bdta.pro/images/426af90390a00314a6f779f6b3f82e00.jpg'),
(87966, 6106, 'The Loud House S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/234702.mp4', 'http://timg.bdta.pro/images/77f67c83e6a5f6d2bb97d501098653fc.jpg'),
(87967, 6106, 'The Loud House S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/234703.mp4', 'http://timg.bdta.pro/images/41464075f074ef7073caa87b5502dc73.jpg'),
(87968, 6106, 'The Loud House S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/234704.mp4', 'http://timg.bdta.pro/images/b0ab8c81bd92aa32fa93cc9687fb210c.jpg'),
(87969, 6106, 'The Loud House S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/234705.mp4', 'http://timg.bdta.pro/images/4054de77422048ef96adf1d9ff126f56.jpg'),
(87970, 6106, 'The Loud House S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/234706.mp4', 'http://timg.bdta.pro/images/6729dafee934132bfac686303b20a130.jpg'),
(87971, 6106, 'The Loud House S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/234707.mp4', 'http://timg.bdta.pro/images/962065019cddb08183078091ce54ea07.jpg'),
(87972, 6107, 'The Loud House S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234708.mp4', 'http://timg.bdta.pro/images/7f88419847c6369ae85f9fba5b63e143.jpg'),
(87973, 6107, 'The Loud House S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234709.mp4', 'http://timg.bdta.pro/images/f67c9c6e8a8ce99fe01df53e1c964421.jpg'),
(87974, 6107, 'The Loud House S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234710.mp4', 'http://timg.bdta.pro/images/b376866fde0cfab8d60e1634686130f9.jpg'),
(87975, 6107, 'The Loud House S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234711.mp4', 'http://timg.bdta.pro/images/124edd097cd67319a02d8e579b58c342.jpg'),
(87976, 6107, 'The Loud House S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234712.mp4', 'http://timg.bdta.pro/images/5d3760c3691b27777fb6ffe4251577e6.jpg'),
(87977, 6107, 'The Loud House S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234713.mp4', 'http://timg.bdta.pro/images/2fdb3aad106e4c8e46d98c4998946a2b.jpg'),
(87978, 6107, 'The Loud House S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234714.mp4', 'http://timg.bdta.pro/images/3d4401ae7f56164f816b29a70bc67456.jpg'),
(87979, 6107, 'The Loud House S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234715.mp4', 'http://timg.bdta.pro/images/7aeb81a00897150701bdbfe8d728ae5b.jpg'),
(87980, 6107, 'The Loud House S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234716.mp4', 'http://timg.bdta.pro/images/9b85dc06194193278b526c03f9fdd601.jpg'),
(87981, 6107, 'The Loud House S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234717.mp4', 'http://timg.bdta.pro/images/4cd104895caa453a09ebc1a2bbf4b134.jpg'),
(87982, 6107, 'The Loud House S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234718.mp4', 'http://timg.bdta.pro/images/7972f02f62234f2e3d8aed737bdb5891.jpg'),
(87983, 6107, 'The Loud House S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234719.mp4', 'http://timg.bdta.pro/images/fdf6a43cbe56f319500c4e4c4987866b.jpg'),
(87984, 6107, 'The Loud House S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234720.mp4', 'http://timg.bdta.pro/images/3e98ce6bcfce575cbe45d66717fd27ae.jpg'),
(87985, 6107, 'The Loud House S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234721.mp4', 'http://timg.bdta.pro/images/d102263da4afce6ae855c5ba2666664d.jpg'),
(87986, 6107, 'The Loud House S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234722.mp4', 'http://timg.bdta.pro/images/516d5f4cf19f56e544cae3687ad8a61f.jpg'),
(87987, 6107, 'The Loud House S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234723.mp4', 'http://timg.bdta.pro/images/0e34be6d80be231a42c881baf8e91448.jpg'),
(87988, 6107, 'The Loud House S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234724.mp4', 'http://timg.bdta.pro/images/611e1d7730417c415c4253395d783f60.jpg'),
(87989, 6107, 'The Loud House S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/234725.mp4', 'http://timg.bdta.pro/images/244cd359ec782afdaa74f74d584f4bc3.jpg'),
(87990, 6107, 'The Loud House S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/234726.mp4', 'http://timg.bdta.pro/images/9b4d39a95b6606b71fb1c9e636b61ae3.jpg'),
(87991, 6107, 'The Loud House S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/234727.mp4', 'http://timg.bdta.pro/images/f0359787a7f360fc5b3d7e4d5ba14995.jpg'),
(87992, 6107, 'The Loud House S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/234728.mp4', 'http://timg.bdta.pro/images/578d7edee7a359bad2540e016b9d29c9.jpg'),
(87993, 6107, 'The Loud House S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/234729.mp4', 'http://timg.bdta.pro/images/ad2c472bcdc269792062ad33a2ef62d0.jpg'),
(87994, 6107, 'The Loud House S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/234730.mp4', 'http://timg.bdta.pro/images/31ee73316f925d50ee63174a5524bd1e.jpg'),
(87995, 6107, 'The Loud House S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/234731.mp4', 'http://timg.bdta.pro/images/152303466cbe54c20245866c68abd6ad.jpg'),
(87996, 6107, 'The Loud House S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/234732.mp4', 'http://timg.bdta.pro/images/d50d41465ddffa78dba880008f52ea6f.jpg'),
(87997, 6107, 'The Loud House S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/234733.mp4', 'http://timg.bdta.pro/images/c560fe9a2ae8bdc9245f5dce45607460.jpg'),
(87998, 6108, 'The Loud House S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234734.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(87999, 6108, 'The Loud House S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234735.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88000, 6108, 'The Loud House S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234736.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88001, 6108, 'The Loud House S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234737.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88002, 6108, 'The Loud House S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234738.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88003, 6108, 'The Loud House S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234739.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88004, 6108, 'The Loud House S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234740.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88005, 6108, 'The Loud House S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234741.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88006, 6108, 'The Loud House S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234742.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88007, 6108, 'The Loud House S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234743.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88008, 6108, 'The Loud House S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234744.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88009, 6108, 'The Loud House S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234745.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88010, 6108, 'The Loud House S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234746.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88011, 6108, 'The Loud House S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234747.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88012, 6108, 'The Loud House S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234748.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88013, 6108, 'The Loud House S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234749.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88014, 6108, 'The Loud House S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234750.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88015, 6108, 'The Loud House S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/234751.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88016, 6108, 'The Loud House S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/234752.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88017, 6108, 'The Loud House S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/234753.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88018, 6108, 'The Loud House S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/234754.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88019, 6108, 'The Loud House S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/234755.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88020, 6108, 'The Loud House S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/234756.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88021, 6108, 'The Loud House S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/234757.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88022, 6108, 'The Loud House S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/234758.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88023, 6108, 'The Loud House S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/234759.mp4', 'http://gstaticontent.com/images/40a1d7016d00b5d086667407299bd2f5.jpg'),
(88024, 6109, 'Vida Remota S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219465.mp4', 'http://timg.bdta.pro/images/787a1739be32bdde64c7df6ddfcfebb4.jpg'),
(88025, 6109, 'Vida Remota S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219466.mp4', 'http://timg.bdta.pro/images/eea135c1d37e6ca83df7ef66b8a1f4c3.jpg'),
(88026, 6109, 'Vida Remota S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219467.mp4', 'http://timg.bdta.pro/images/c5b57036666b34d0b5560e8f807858c9.jpg'),
(88027, 6109, 'Vida Remota S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219468.mp4', 'http://timg.bdta.pro/images/ab388d266e29abe256014917b2004c8c.jpg'),
(88028, 6109, 'Vida Remota S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219469.mp4', 'http://timg.bdta.pro/images/ea6a3cebb50ff19b50ba61253922dfcb.jpg'),
(88029, 6109, 'Vida Remota S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219470.mp4', 'http://timg.bdta.pro/images/8918d7491bc7b0892d30c593674fa899.jpg'),
(88030, 6109, 'Vida Remota S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219471.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88031, 6109, 'Vida Remota S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219472.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88032, 6109, 'Vida Remota S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219473.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88033, 6109, 'Vida Remota S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219474.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88034, 6109, 'Vida Remota S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219475.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88035, 6109, 'Vida Remota S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219476.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88036, 6109, 'Vida Remota S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219477.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88037, 6109, 'Vida Remota S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/219478.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88038, 6109, 'Vida Remota S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/219479.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88039, 6109, 'Vida Remota S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/219480.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88040, 6109, 'Vida Remota S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/219481.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88041, 6109, 'Vida Remota S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/219482.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88042, 6109, 'Vida Remota S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/219483.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88043, 6110, 'Vida Remota S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219484.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88044, 6110, 'Vida Remota S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219485.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88045, 6110, 'Vida Remota S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219486.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88046, 6110, 'Vida Remota S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219487.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88047, 6110, 'Vida Remota S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219488.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88048, 6110, 'Vida Remota S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219489.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88049, 6110, 'Vida Remota S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219490.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88050, 6110, 'Vida Remota S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219491.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88051, 6110, 'Vida Remota S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219492.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88052, 6110, 'Vida Remota S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219493.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88053, 6110, 'Vida Remota S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219494.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88054, 6110, 'Vida Remota S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219495.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88055, 6110, 'Vida Remota S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219496.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88056, 6111, 'Vida Remota S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219497.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88057, 6111, 'Vida Remota S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219498.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88058, 6111, 'Vida Remota S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219499.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88059, 6111, 'Vida Remota S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219500.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88060, 6111, 'Vida Remota S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219501.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88061, 6111, 'Vida Remota S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219502.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88062, 6111, 'Vida Remota S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219503.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88063, 6111, 'Vida Remota S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219504.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88064, 6111, 'Vida Remota S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219505.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88065, 6111, 'Vida Remota S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219506.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88066, 6111, 'Vida Remota S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219507.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88067, 6111, 'Vida Remota S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219508.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88068, 6111, 'Vida Remota S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219509.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88069, 6112, 'Vida Remota S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219510.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88070, 6112, 'Vida Remota S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219511.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88071, 6112, 'Vida Remota S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219512.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88072, 6112, 'Vida Remota S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219513.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88073, 6112, 'Vida Remota S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219514.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88074, 6112, 'Vida Remota S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219515.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88075, 6112, 'Vida Remota S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219516.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88076, 6112, 'Vida Remota S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219517.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88077, 6112, 'Vida Remota S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219518.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88078, 6113, 'Vida Remota S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219519.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88079, 6113, 'Vida Remota S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219520.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88080, 6113, 'Vida Remota S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219521.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88081, 6113, 'Vida Remota S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219522.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88082, 6113, 'Vida Remota S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219523.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88083, 6114, 'Vida Remota S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219524.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(88084, 6114, 'Vida Remota S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219525.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88085, 6114, 'Vida Remota S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219526.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88086, 6114, 'Vida Remota S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219527.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88087, 6114, 'Vida Remota S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219528.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88088, 6114, 'Vida Remota S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219529.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88089, 6114, 'Vida Remota S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219530.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88090, 6114, 'Vida Remota S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219531.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88091, 6114, 'Vida Remota S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219532.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88092, 6114, 'Vida Remota S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219533.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88093, 6114, 'Vida Remota S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219534.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88094, 6114, 'Vida Remota S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219535.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88095, 6114, 'Vida Remota S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219536.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88096, 6114, 'Vida Remota S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/219537.mp4', 'http://gstaticontent.com/images/74439bef02bca299ba31f8e4bad81008.jpg'),
(88097, 6115, 'The Kardashians S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249674.mp4', 'http://timg.bdta.pro/images/3f82bd6853a8a46a8197842f62d60a07.jpg'),
(88098, 6115, 'The Kardashians S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249675.mp4', 'http://timg.bdta.pro/images/dcb68aae0340becde785fbec230811dd.jpg'),
(88099, 6115, 'The Kardashians S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249676.mp4', 'http://timg.bdta.pro/images/c092143ce8deaa5b8df77c1b2c3bad6f.jpg'),
(88100, 6115, 'The Kardashians S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249677.mp4', 'http://timg.bdta.pro/images/f141a962ef3a799fe02dab97039f8642.jpg'),
(88101, 6115, 'The Kardashians S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249678.mp4', 'http://timg.bdta.pro/images/47d67799a1314c9244c350149c2dfd03.jpg'),
(88102, 6115, 'The Kardashians S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249679.mp4', 'http://timg.bdta.pro/images/c9a81efd635312ecd8ea699bc3ed74cf.jpg'),
(88103, 6115, 'The Kardashians S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249680.mp4', 'http://timg.bdta.pro/images/dc1fcd12fce12674cecd7b3dd5335294.jpg'),
(88104, 6115, 'The Kardashians S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249681.mp4', 'http://timg.bdta.pro/images/68c5b5aa74d9d9fe7591d89d8b2060d9.jpg'),
(88105, 6115, 'The Kardashians S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249682.mp4', 'http://timg.bdta.pro/images/2488365af7a48a285b1685c84b64fa43.jpg'),
(88106, 6115, 'The Kardashians S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249683.mp4', 'http://timg.bdta.pro/images/cbd44ab4bb27e33f144a35549ae15b59.jpg'),
(88107, 6116, 'The Kardashians S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249684.mp4', 'http://timg.bdta.pro/images/5b19ba5971c29b268bcb6e3d9f9b65d4.jpg'),
(88108, 6116, 'The Kardashians S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249685.mp4', 'http://timg.bdta.pro/images/6d8c7cac6f188ca586e9d3b7778ce032.jpg'),
(88109, 6116, 'The Kardashians S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t0IE5SqUjpIxfAJkU6BzKUOj5Qz.jpg'),
(88110, 6116, 'The Kardashians S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/76TXUmGq13zA9HD8Uo2L8O8B3nG.jpg'),
(88111, 6116, 'The Kardashians S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hrZ7QPr6IzXGlZaaUrk9nYWDnPz.jpg'),
(88112, 6116, 'The Kardashians S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNeF2O8uDpgpSO6s5ks8yqua32i.jpg'),
(88113, 6116, 'The Kardashians S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ycWDpF1qBiCraFqoiZa3oRAjNFo.jpg'),
(88114, 6116, 'The Kardashians S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wr5UixI6t5yxaCYZx2FqBkYFTlQ.jpg'),
(88115, 6116, 'The Kardashians S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249692.mp4', 'http://image.tmdb.org/t/p/w1280/5wUcbqGjFAHBXktYAcw3sirbC34.jpg'),
(88116, 6116, 'The Kardashians S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249693.mp4', 'http://image.tmdb.org/t/p/w1280/zuACjlO5Hl3B5clAZ0TKVlRxHnV.jpg'),
(88117, 6117, 'The Kardashians S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249694.mp4', 'http://image.tmdb.org/t/p/w1280/b6ghHPw2YCz2HWv5ddhKsjY81A6.jpg'),
(88118, 6117, 'The Kardashians S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249695.mp4', 'http://image.tmdb.org/t/p/w1280/au2QW6YwBft6VWisQTJp8Mj7obq.jpg'),
(88119, 6117, 'The Kardashians S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249696.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88120, 6117, 'The Kardashians S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249697.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88121, 6117, 'The Kardashians S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249698.mp4', 'http://image.tmdb.org/t/p/w1280/3AWE51Y61IdkwDD4NXNWxizOsQ5.jpg'),
(88122, 6117, 'The Kardashians S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249699.mp4', 'http://image.tmdb.org/t/p/w1280/31AExgjrXhhBb5ObW5RwAAusbvN.jpg'),
(88123, 6117, 'The Kardashians S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249700.mp4', 'http://image.tmdb.org/t/p/w1280/mrSis8TeGpGxpyg2z6QH9n0n3IR.jpg'),
(88124, 6117, 'The Kardashians S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249701.mp4', 'http://image.tmdb.org/t/p/w1280/oq0JvZGV8iVWAmIL6JU0Qcl4RNr.jpg'),
(88125, 6117, 'The Kardashians S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249702.mp4', 'http://image.tmdb.org/t/p/w1280/3gtLMUiAG3YmPanigrJeJd2ESUz.jpg'),
(88126, 6117, 'The Kardashians S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249703.mp4', 'http://image.tmdb.org/t/p/w1280/5BuRA05hwiGl4NuInsX0fHuWlZL.jpg'),
(88127, 6118, 'The Kardashians S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249704.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88128, 6118, 'The Kardashians S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249705.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88129, 6118, 'The Kardashians S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249706.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88130, 6118, 'The Kardashians S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249707.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88131, 6118, 'The Kardashians S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249708.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88132, 6118, 'The Kardashians S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249709.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88133, 6118, 'The Kardashians S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249710.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88134, 6118, 'The Kardashians S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249711.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88135, 6118, 'The Kardashians S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249712.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88136, 6118, 'The Kardashians S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249713.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88137, 6119, 'The Kardashians S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/358411.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88138, 6119, 'The Kardashians S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/422968.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c3VPeznTNtLRqCgUoXvii8FwRUr.jpg'),
(88139, 6119, 'The Kardashians S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/422969.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6kBPywZ00REtgKuFgZGLvJCIcCx.jpg'),
(88140, 6119, 'The Kardashians S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/413896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wCix8XOWG8N1j9rwQwUbzXZ4O6l.jpg'),
(88141, 6119, 'The Kardashians S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/422971.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/flWeslQkx65W3Id0VtwTLCTvDE7.jpg'),
(88142, 6119, 'The Kardashians S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/413898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kCNK2kjzsWNFFikSEGMlTf3u7A0.jpg'),
(88143, 6119, 'The Kardashians S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/422973.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88144, 6119, 'The Kardashians S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/422974.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88145, 6119, 'The Kardashians S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/422975.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88146, 6119, 'The Kardashians S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/426343.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88147, 6120, 'The Kardashians S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/726139.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88148, 6120, 'The Kardashians S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/697277.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88149, 6120, 'The Kardashians S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/726141.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88150, 6120, 'The Kardashians S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/799687.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88151, 6120, 'The Kardashians S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/808640.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88152, 6120, 'The Kardashians S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/808641.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88153, 6120, 'The Kardashians S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/808642.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88154, 6120, 'The Kardashians S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/808643.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88155, 6120, 'The Kardashians S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/808644.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88156, 6120, 'The Kardashians S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/808645.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88157, 6121, 'The Kardashians S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/891993.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88158, 6121, 'The Kardashians S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/891994.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88159, 6121, 'The Kardashians S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/892414.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88160, 6121, 'The Kardashians S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/893061.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88161, 6121, 'The Kardashians S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/893341.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88162, 6121, 'The Kardashians S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/895834.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88163, 6121, 'The Kardashians S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/896389.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88164, 6121, 'The Kardashians S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/896648.mp4', 'http://gstaticontent.com/images/52704a84e1ed36b91f65f549d8c00576.jpg'),
(88165, 6122, 'Paranormal Witness [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191686.mp4', 'http://timg.bdta.pro/images/d9e21b7178cded56b7f12bf8693a25e2.jpg'),
(88166, 6122, 'Paranormal Witness [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191687.mp4', 'http://timg.bdta.pro/images/2dbf225b7d5c0ea14c8c874e36623815.jpg'),
(88167, 6122, 'Paranormal Witness [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191688.mp4', 'http://gstaticontent.com/images/1111eaad6ce865d22a0e0763297cd271.jpg'),
(88168, 6122, 'Paranormal Witness [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191689.mp4', 'http://timg.bdta.pro/images/09466c1bfe64a8d5932a1f918c812f84.jpg'),
(88169, 6122, 'Paranormal Witness [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191690.mp4', 'http://timg.bdta.pro/images/c11cf3480d00389c39099951eb709fd2.jpg'),
(88170, 6122, 'Paranormal Witness [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191691.mp4', 'http://gstaticontent.com/images/1111eaad6ce865d22a0e0763297cd271.jpg'),
(88171, 6123, 'Paranormal Witness [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191692.mp4', 'http://gstaticontent.com/images/1111eaad6ce865d22a0e0763297cd271.jpg'),
(88172, 6123, 'Paranormal Witness [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191693.mp4', 'http://gstaticontent.com/images/1111eaad6ce865d22a0e0763297cd271.jpg'),
(88173, 6123, 'Paranormal Witness [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191694.mp4', 'http://gstaticontent.com/images/1111eaad6ce865d22a0e0763297cd271.jpg'),
(88174, 6123, 'Paranormal Witness [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191695.mp4', 'http://gstaticontent.com/images/1111eaad6ce865d22a0e0763297cd271.jpg'),
(88175, 6123, 'Paranormal Witness [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191696.mp4', 'http://gstaticontent.com/images/1111eaad6ce865d22a0e0763297cd271.jpg'),
(88176, 6123, 'Paranormal Witness [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191697.mp4', 'http://gstaticontent.com/images/1111eaad6ce865d22a0e0763297cd271.jpg'),
(88177, 6123, 'Paranormal Witness [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191698.mp4', 'http://gstaticontent.com/images/1111eaad6ce865d22a0e0763297cd271.jpg'),
(88178, 6123, 'Paranormal Witness [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191699.mp4', 'http://gstaticontent.com/images/1111eaad6ce865d22a0e0763297cd271.jpg'),
(88179, 6123, 'Paranormal Witness [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191700.mp4', 'http://gstaticontent.com/images/1111eaad6ce865d22a0e0763297cd271.jpg'),
(88180, 6123, 'Paranormal Witness [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191701.mp4', 'http://gstaticontent.com/images/1111eaad6ce865d22a0e0763297cd271.jpg'),
(88181, 6123, 'Paranormal Witness [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191702.mp4', 'http://gstaticontent.com/images/1111eaad6ce865d22a0e0763297cd271.jpg'),
(88182, 6123, 'Paranormal Witness [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/191703.mp4', 'http://gstaticontent.com/images/1111eaad6ce865d22a0e0763297cd271.jpg'),
(88183, 6124, 'Sem Medo da Verdade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182036.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88184, 6124, 'Sem Medo da Verdade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182037.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88185, 6124, 'Sem Medo da Verdade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182038.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88186, 6124, 'Sem Medo da Verdade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182039.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88187, 6124, 'Sem Medo da Verdade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182040.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88188, 6124, 'Sem Medo da Verdade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182041.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88189, 6124, 'Sem Medo da Verdade S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182042.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88190, 6124, 'Sem Medo da Verdade S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182043.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88191, 6124, 'Sem Medo da Verdade S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/182044.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88192, 6124, 'Sem Medo da Verdade S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/182045.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88193, 6124, 'Sem Medo da Verdade S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/182046.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88194, 6124, 'Sem Medo da Verdade S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/182047.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88195, 6124, 'Sem Medo da Verdade S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/182048.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88196, 6124, 'Sem Medo da Verdade S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/182049.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88197, 6124, 'Sem Medo da Verdade S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/182050.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88198, 6124, 'Sem Medo da Verdade S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/182051.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88199, 6124, 'Sem Medo da Verdade S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/182052.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88200, 6124, 'Sem Medo da Verdade S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/182053.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88201, 6124, 'Sem Medo da Verdade S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/182054.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88202, 6124, 'Sem Medo da Verdade S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/182055.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88203, 6124, 'Sem Medo da Verdade S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/182056.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88204, 6125, 'Sem Medo da Verdade S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182057.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88205, 6125, 'Sem Medo da Verdade S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182058.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88206, 6125, 'Sem Medo da Verdade S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182059.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88207, 6125, 'Sem Medo da Verdade S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182060.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88208, 6125, 'Sem Medo da Verdade S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182061.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88209, 6125, 'Sem Medo da Verdade S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182062.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88210, 6125, 'Sem Medo da Verdade S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182063.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88211, 6125, 'Sem Medo da Verdade S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182064.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88212, 6125, 'Sem Medo da Verdade S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/182065.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88213, 6125, 'Sem Medo da Verdade S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/182066.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88214, 6125, 'Sem Medo da Verdade S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/182067.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88215, 6125, 'Sem Medo da Verdade S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/182068.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88216, 6125, 'Sem Medo da Verdade S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/182069.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88217, 6125, 'Sem Medo da Verdade S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/182070.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88218, 6125, 'Sem Medo da Verdade S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/182071.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88219, 6125, 'Sem Medo da Verdade S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/182072.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88220, 6125, 'Sem Medo da Verdade S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/182073.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88221, 6125, 'Sem Medo da Verdade S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/182074.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88222, 6125, 'Sem Medo da Verdade S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/182075.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88223, 6125, 'Sem Medo da Verdade S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/182076.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88224, 6125, 'Sem Medo da Verdade S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/182077.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88225, 6125, 'Sem Medo da Verdade S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/182078.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88226, 6125, 'Sem Medo da Verdade S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/182079.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88227, 6125, 'Sem Medo da Verdade S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/182080.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88228, 6125, 'Sem Medo da Verdade S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/182081.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88229, 6126, 'Sem Medo da Verdade S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/182082.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88230, 6126, 'Sem Medo da Verdade S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/182083.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88231, 6126, 'Sem Medo da Verdade S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/182084.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88232, 6126, 'Sem Medo da Verdade S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/182085.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88233, 6126, 'Sem Medo da Verdade S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/182086.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88234, 6126, 'Sem Medo da Verdade S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/182087.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88235, 6126, 'Sem Medo da Verdade S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/182088.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88236, 6126, 'Sem Medo da Verdade S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/182089.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88237, 6126, 'Sem Medo da Verdade S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/182090.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88238, 6126, 'Sem Medo da Verdade S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/182091.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88239, 6126, 'Sem Medo da Verdade S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/182092.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88240, 6126, 'Sem Medo da Verdade S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/182093.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88241, 6126, 'Sem Medo da Verdade S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/182094.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88242, 6126, 'Sem Medo da Verdade S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/182095.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88243, 6126, 'Sem Medo da Verdade S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/182096.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88244, 6126, 'Sem Medo da Verdade S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/182097.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88245, 6126, 'Sem Medo da Verdade S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/182098.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88246, 6126, 'Sem Medo da Verdade S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/182099.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88247, 6126, 'Sem Medo da Verdade S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/182100.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88248, 6126, 'Sem Medo da Verdade S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/182101.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88249, 6126, 'Sem Medo da Verdade S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/182102.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88250, 6126, 'Sem Medo da Verdade S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/182103.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88251, 6126, 'Sem Medo da Verdade S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/182104.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88252, 6126, 'Sem Medo da Verdade S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/182105.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88253, 6126, 'Sem Medo da Verdade S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/182106.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88254, 6126, 'Sem Medo da Verdade S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/182107.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88255, 6126, 'Sem Medo da Verdade S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/182108.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88256, 6126, 'Sem Medo da Verdade S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/182109.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88257, 6126, 'Sem Medo da Verdade S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/182110.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88258, 6126, 'Sem Medo da Verdade S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/182111.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88259, 6126, 'Sem Medo da Verdade S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/182112.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88260, 6126, 'Sem Medo da Verdade S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/182113.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88261, 6126, 'Sem Medo da Verdade S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/182114.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88262, 6126, 'Sem Medo da Verdade S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/182115.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88263, 6126, 'Sem Medo da Verdade S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/182116.mp4', 'http://gstaticontent.com/images/e433084e60e46bda4c6890fd2b576643.jpg'),
(88264, 6127, 'Adriano Imperador S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181854.mp4', 'http://gstaticontent.com/images/c87338cb07fa20602ac3577c88d84fdc.jpg'),
(88265, 6127, 'Adriano Imperador S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181855.mp4', 'http://gstaticontent.com/images/c87338cb07fa20602ac3577c88d84fdc.jpg'),
(88266, 6127, 'Adriano Imperador S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181856.mp4', 'http://gstaticontent.com/images/c87338cb07fa20602ac3577c88d84fdc.jpg'),
(88267, 6128, 'Amor e Outros Dramas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181834.mp4', 'http://timg.bdta.pro/images/3b80a089fcb074772f3ca27607f640b8.jpg'),
(88268, 6128, 'Amor e Outros Dramas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181835.mp4', 'http://timg.bdta.pro/images/41558696a6825714dfd592fd0a926423.jpg'),
(88269, 6128, 'Amor e Outros Dramas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181836.mp4', 'http://timg.bdta.pro/images/6d3abdac095351240459b193331ae4d4.jpg'),
(88270, 6128, 'Amor e Outros Dramas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181837.mp4', 'http://timg.bdta.pro/images/812b2be9732779b5922b3b50f26488cf.jpg'),
(88271, 6128, 'Amor e Outros Dramas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181838.mp4', 'http://timg.bdta.pro/images/c1417ad92611950722238c25fdeae296.jpg'),
(88272, 6128, 'Amor e Outros Dramas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181839.mp4', 'http://timg.bdta.pro/images/c20d996df0319c91c3c2415404b5ddde.jpg'),
(88273, 6128, 'Amor e Outros Dramas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/181840.mp4', 'http://timg.bdta.pro/images/6296f26a0e9fc0fa7572d549b882cc08.jpg'),
(88274, 6128, 'Amor e Outros Dramas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/181841.mp4', 'http://timg.bdta.pro/images/4d980f8b292226f871b011f846ae236e.jpg'),
(88275, 6128, 'Amor e Outros Dramas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/181842.mp4', 'http://timg.bdta.pro/images/b43da24c1e107c02b3862332c02c4366.jpg'),
(88276, 6128, 'Amor e Outros Dramas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/181843.mp4', 'http://timg.bdta.pro/images/2006ef53103d364cf0499a48f187c004.jpg'),
(88277, 6128, 'Amor e Outros Dramas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/181845.mp4', 'http://timg.bdta.pro/images/84865ec324d276c747d41c6ab86bb6e7.jpg'),
(88278, 6128, 'Amor e Outros Dramas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/181846.mp4', 'http://timg.bdta.pro/images/02cb740eef2ffa8e2d3e24e842e7421f.jpg'),
(88279, 6128, 'Amor e Outros Dramas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/181847.mp4', 'http://timg.bdta.pro/images/b40cdf7566a4d9c3000db02057740aaa.jpg'),
(88280, 6128, 'Amor e Outros Dramas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/181848.mp4', 'http://timg.bdta.pro/images/3f1b2aff27c3af2ea7bd748db88a8eec.jpg'),
(88281, 6128, 'Amor e Outros Dramas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/181849.mp4', 'http://timg.bdta.pro/images/88ee5768040da14360613590a99cd668.jpg'),
(88282, 6128, 'Amor e Outros Dramas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/181850.mp4', 'http://timg.bdta.pro/images/ea546692d1d47ef8925c9993e7ebfae3.jpg'),
(88283, 6128, 'Amor e Outros Dramas S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/181851.mp4', 'http://timg.bdta.pro/images/46b541ab0b00ae2d3336234d7c7fe7a2.jpg'),
(88284, 6128, 'Amor e Outros Dramas S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/181852.mp4', 'http://timg.bdta.pro/images/231c5ea9e6caf61ddfacaa1393c590b4.jpg'),
(88285, 6128, 'Amor e Outros Dramas S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/181853.mp4', 'http://timg.bdta.pro/images/610693c4c2a4ebd61482959ad1359ed2.jpg'),
(88286, 6129, 'Anna S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181828.mp4', 'http://timg.bdta.pro/images/186d8ee907031e1d66a9618cb19ad984.jpg'),
(88287, 6129, 'Anna S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181829.mp4', 'http://timg.bdta.pro/images/43ecb5112616107325db61b4edd621c4.jpg'),
(88288, 6129, 'Anna S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181830.mp4', 'http://timg.bdta.pro/images/817fb5e5d6f2f26e8d065f734b432810.jpg'),
(88289, 6129, 'Anna S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181831.mp4', 'http://timg.bdta.pro/images/d33af3be12d9ae544efb45f81735a98f.jpg'),
(88290, 6129, 'Anna S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181832.mp4', 'http://timg.bdta.pro/images/b860d87c202c4bee67d82348d5736ea7.jpg'),
(88291, 6129, 'Anna S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181833.mp4', 'http://timg.bdta.pro/images/c899a6c12faebdd502084ca9a0f3731d.jpg'),
(88292, 6130, 'Assassinos Indianos: O Estripador de Déli S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181825.mp4', 'http://timg.bdta.pro/images/01080f3732d73940d2909b25620576bf.jpg'),
(88293, 6130, 'Assassinos Indianos: O Estripador de Déli S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181826.mp4', 'http://timg.bdta.pro/images/27e0dac7f9e9c6a36fde6d7683be0961.jpg'),
(88294, 6130, 'Assassinos Indianos: O Estripador de Déli S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181827.mp4', 'http://timg.bdta.pro/images/20b828f659e0baccaf3ad5219a8fdd68.jpg'),
(88295, 6131, 'Engenharia Extrema S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/181819.mp4', 'http://gstaticontent.com/images/1bbd1c2aaa69c7c494b431e09d954eab.jpg'),
(88296, 6131, 'Engenharia Extrema S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/181820.mp4', 'http://gstaticontent.com/images/1bbd1c2aaa69c7c494b431e09d954eab.jpg'),
(88297, 6131, 'Engenharia Extrema S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/181821.mp4', 'http://gstaticontent.com/images/1bbd1c2aaa69c7c494b431e09d954eab.jpg'),
(88298, 6131, 'Engenharia Extrema S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/181822.mp4', 'http://gstaticontent.com/images/1bbd1c2aaa69c7c494b431e09d954eab.jpg'),
(88299, 6131, 'Engenharia Extrema S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/181823.mp4', 'http://gstaticontent.com/images/1bbd1c2aaa69c7c494b431e09d954eab.jpg'),
(88300, 6131, 'Engenharia Extrema S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/181824.mp4', 'http://gstaticontent.com/images/1bbd1c2aaa69c7c494b431e09d954eab.jpg'),
(88301, 6132, 'High: Confissões de uma Traficante S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192040.mp4', 'http://gstaticontent.com/images/7c95bfc2a2e813d2925cb27250bdb91a.jpg'),
(88302, 6132, 'High: Confissões de uma Traficante S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192041.mp4', 'http://gstaticontent.com/images/7c95bfc2a2e813d2925cb27250bdb91a.jpg'),
(88303, 6132, 'High: Confissões de uma Traficante S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192042.mp4', 'http://gstaticontent.com/images/7c95bfc2a2e813d2925cb27250bdb91a.jpg'),
(88304, 6132, 'High: Confissões de uma Traficante S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192043.mp4', 'http://gstaticontent.com/images/7c95bfc2a2e813d2925cb27250bdb91a.jpg'),
(88305, 6133, 'I Love That for You S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192032.mp4', 'http://timg.bdta.pro/images/04e00032063eb7b095886e8644fd22bd.jpg'),
(88306, 6133, 'I Love That for You S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192033.mp4', 'http://timg.bdta.pro/images/ee6ce1349e37b2c6d57579a5518702af.jpg'),
(88307, 6133, 'I Love That for You S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192034.mp4', 'http://timg.bdta.pro/images/91cf1705426e6ce48fcabd41d51b48ac.jpg'),
(88308, 6133, 'I Love That for You S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192035.mp4', 'http://timg.bdta.pro/images/2d21e94fd9cbdad077adaa8f77f3b091.jpg'),
(88309, 6133, 'I Love That for You S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192036.mp4', 'http://timg.bdta.pro/images/5e205497da765ad7198b3d1464540110.jpg'),
(88310, 6133, 'I Love That for You S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192037.mp4', 'http://timg.bdta.pro/images/e04aa5d26b2dcc0391974aff463d36dc.jpg'),
(88311, 6133, 'I Love That for You S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192038.mp4', 'http://timg.bdta.pro/images/3ec9a15008364a2aac41fbcdab1d1b52.jpg'),
(88312, 6133, 'I Love That for You S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192039.mp4', 'http://timg.bdta.pro/images/2c940e40e1060c74b3ee0479e749f76b.jpg'),
(88313, 6134, 'Koi wa Sekai Seifuku no Ato de S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192020.mp4', 'http://timg.bdta.pro/images/6245ff31fc87d264a9a6f1f8fb2ad1f6.jpg'),
(88314, 6134, 'Koi wa Sekai Seifuku no Ato de S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192021.mp4', 'http://timg.bdta.pro/images/0f48ad57a48d1e53c41094d7073d3856.jpg'),
(88315, 6134, 'Koi wa Sekai Seifuku no Ato de S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192022.mp4', 'http://timg.bdta.pro/images/ea1e26afa15bd75bc3f4ad779facab65.jpg'),
(88316, 6134, 'Koi wa Sekai Seifuku no Ato de S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192023.mp4', 'http://timg.bdta.pro/images/7ab18dc37b8fac4bcbc7e69279f400bc.jpg'),
(88317, 6134, 'Koi wa Sekai Seifuku no Ato de S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192024.mp4', 'http://timg.bdta.pro/images/f9247db12c81a3f5fe22a986cb5ace4b.jpg'),
(88318, 6134, 'Koi wa Sekai Seifuku no Ato de S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192025.mp4', 'http://timg.bdta.pro/images/6b36e72dccd4ee2f5a414e25b770b55d.jpg'),
(88319, 6134, 'Koi wa Sekai Seifuku no Ato de S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192026.mp4', 'http://timg.bdta.pro/images/0f79392d1656fbbc0a07afe415743a13.jpg'),
(88320, 6134, 'Koi wa Sekai Seifuku no Ato de S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192027.mp4', 'http://timg.bdta.pro/images/2cedae249952123f2b2dfb5117443c91.jpg'),
(88321, 6134, 'Koi wa Sekai Seifuku no Ato de S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192028.mp4', 'http://timg.bdta.pro/images/4896fe8fce3efcb825fdd2f4dc590da1.jpg'),
(88322, 6134, 'Koi wa Sekai Seifuku no Ato de S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192029.mp4', 'http://timg.bdta.pro/images/783de413955f5ba6a148b24b2c9a3aa8.jpg'),
(88323, 6134, 'Koi wa Sekai Seifuku no Ato de S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192030.mp4', 'http://timg.bdta.pro/images/7f395823e7cce62d6ce37f529c7cc120.jpg'),
(88324, 6134, 'Koi wa Sekai Seifuku no Ato de S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192031.mp4', 'http://timg.bdta.pro/images/cb3eabc9bc726eda17e9d58eaa106572.jpg'),
(88325, 6135, 'Pelados e Apaixonados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204556.mp4', 'http://timg.bdta.pro/images/8a7278455ed0cfa1719cdb5136e71436.jpg'),
(88326, 6135, 'Pelados e Apaixonados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204557.mp4', 'http://timg.bdta.pro/images/e4e68eb436d37263af7edf221f719458.jpg'),
(88327, 6135, 'Pelados e Apaixonados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204558.mp4', 'http://timg.bdta.pro/images/64c74bec934fea2064c6355750140742.jpg'),
(88328, 6135, 'Pelados e Apaixonados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204559.mp4', 'http://timg.bdta.pro/images/f78e569b951e769feae3911f334cd694.jpg'),
(88329, 6135, 'Pelados e Apaixonados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204560.mp4', 'http://timg.bdta.pro/images/53897fd778fa7f37bb1e84a990bcd132.jpg'),
(88330, 6135, 'Pelados e Apaixonados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204561.mp4', 'http://timg.bdta.pro/images/f2a0cd92128a358ccc7af11bf3b54118.jpg'),
(88331, 6135, 'Pelados e Apaixonados S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204562.mp4', 'http://timg.bdta.pro/images/f324ccc9045ae704c66d6cbb0b816e75.jpg'),
(88332, 6135, 'Pelados e Apaixonados S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204563.mp4', 'http://timg.bdta.pro/images/23012c5028a5a99863426a09db96a6f8.jpg'),
(88333, 6135, 'Pelados e Apaixonados S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204564.mp4', 'http://timg.bdta.pro/images/537fa06263e1d33d4e88a5dac2fd9448.jpg'),
(88334, 6135, 'Pelados e Apaixonados S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204565.mp4', 'http://timg.bdta.pro/images/011fd65f0f6641a85f1f32043dfd6cfa.jpg'),
(88335, 6135, 'Pelados e Apaixonados S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204566.mp4', 'http://image.tmdb.org/t/p/w1280/6no8X5g2MBt3N0xEPO1IFWuTuyH.jpg'),
(88336, 6135, 'Pelados e Apaixonados S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204567.mp4', 'http://image.tmdb.org/t/p/w1280/fOiuSQ80FZRDXDF93qoMSvCA8e2.jpg'),
(88337, 6136, 'Mahoutsukai Reimeiki S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192008.mp4', 'http://timg.bdta.pro/images/512f78373cf34035dd345886a020ba4f.jpg'),
(88338, 6136, 'Mahoutsukai Reimeiki S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192009.mp4', 'http://timg.bdta.pro/images/34d317786cd7c18bc6fd39daf6ab9422.jpg'),
(88339, 6136, 'Mahoutsukai Reimeiki S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192010.mp4', 'http://timg.bdta.pro/images/2ecf38b98856a842aeca8413f18676b1.jpg'),
(88340, 6136, 'Mahoutsukai Reimeiki S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192011.mp4', 'http://timg.bdta.pro/images/ca78b40b493566b94f8ff4fda67686f1.jpg'),
(88341, 6136, 'Mahoutsukai Reimeiki S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192012.mp4', 'http://timg.bdta.pro/images/4e991867f3ea55b35cf0f7cf4d124fbc.jpg'),
(88342, 6136, 'Mahoutsukai Reimeiki S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192013.mp4', 'http://timg.bdta.pro/images/57fb155d08902e605257d564f17a4527.jpg'),
(88343, 6136, 'Mahoutsukai Reimeiki S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192014.mp4', 'http://timg.bdta.pro/images/7d8192daa203678eed47c7bd214d7192.jpg'),
(88344, 6136, 'Mahoutsukai Reimeiki S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192015.mp4', 'http://timg.bdta.pro/images/9d3c5ecf542e379ba7213274405b0522.jpg'),
(88345, 6136, 'Mahoutsukai Reimeiki S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192016.mp4', 'http://timg.bdta.pro/images/3b786e2606c9c202b04a53eaad23d660.jpg'),
(88346, 6136, 'Mahoutsukai Reimeiki S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192017.mp4', 'http://timg.bdta.pro/images/a4da0f8d56c3e4297df6b1f31991c614.jpg'),
(88347, 6136, 'Mahoutsukai Reimeiki S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192018.mp4', 'http://timg.bdta.pro/images/8dd1bc053a06bc5bc491a6338441d7e7.jpg'),
(88348, 6136, 'Mahoutsukai Reimeiki S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192019.mp4', 'http://timg.bdta.pro/images/d6a8a3df395f189643a9b7a59adb9f95.jpg'),
(88349, 6137, 'Meninas do Benfica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192000.mp4', 'http://timg.bdta.pro/images/5e26a4231e78f38a28a7d5e775eb8951.jpg'),
(88350, 6137, 'Meninas do Benfica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192001.mp4', 'http://timg.bdta.pro/images/2073cfdb1f6bba8eea511f0ca6988620.jpg'),
(88351, 6137, 'Meninas do Benfica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192002.mp4', 'http://timg.bdta.pro/images/07c20d9a4ae58fc9ec983ec8e0e575a4.jpg'),
(88352, 6137, 'Meninas do Benfica S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192003.mp4', 'http://timg.bdta.pro/images/e89da6fac1eb96f06b949f43c38fcaff.jpg'),
(88353, 6137, 'Meninas do Benfica S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192004.mp4', 'http://timg.bdta.pro/images/c6bf6710bd0cc506038ba45120890bc3.jpg'),
(88354, 6137, 'Meninas do Benfica S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192005.mp4', 'http://timg.bdta.pro/images/efe00561713d835b3339c69f0db360a7.jpg'),
(88355, 6137, 'Meninas do Benfica S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192006.mp4', 'http://timg.bdta.pro/images/54c400464fc142d041f6f6667d5aa027.jpg'),
(88356, 6137, 'Meninas do Benfica S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192007.mp4', 'http://timg.bdta.pro/images/23c701b7f6b4777c554fa9d2c49a150f.jpg'),
(88357, 6138, 'Mira: A Detetive do Reino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191975.mp4', 'http://timg.bdta.pro/images/498d2790b9e72e9fba339318ea73e650.jpg'),
(88358, 6138, 'Mira: A Detetive do Reino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191976.mp4', 'http://timg.bdta.pro/images/a086c111dc9aa4dc09891cb175f3a6c0.jpg'),
(88359, 6138, 'Mira: A Detetive do Reino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191977.mp4', 'http://timg.bdta.pro/images/a8d60a0aaed6ea3460855e5c53f7355d.jpg'),
(88360, 6138, 'Mira: A Detetive do Reino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191978.mp4', 'http://timg.bdta.pro/images/f78587bf1c58c4f363131a0e75f83b4f.jpg'),
(88361, 6138, 'Mira: A Detetive do Reino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191979.mp4', 'http://timg.bdta.pro/images/5749ff5f1dab8963dc3f9dad0b456ecd.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(88362, 6138, 'Mira: A Detetive do Reino S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191980.mp4', 'http://timg.bdta.pro/images/41f5a80beec07520cd36db5ce359335b.jpg'),
(88363, 6138, 'Mira: A Detetive do Reino S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191981.mp4', 'http://timg.bdta.pro/images/d5e1af5a6b4a15d8d60340a819fe0db2.jpg'),
(88364, 6138, 'Mira: A Detetive do Reino S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191982.mp4', 'http://timg.bdta.pro/images/7696df7b43be1507e44213c8a09acfc5.jpg'),
(88365, 6138, 'Mira: A Detetive do Reino S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191983.mp4', 'http://timg.bdta.pro/images/7264425574f8f1b3e4b43065bc1b21ea.jpg'),
(88366, 6138, 'Mira: A Detetive do Reino S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191984.mp4', 'http://timg.bdta.pro/images/6ee205fec19d9d781fb837607b5152bf.jpg'),
(88367, 6138, 'Mira: A Detetive do Reino S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191985.mp4', 'http://timg.bdta.pro/images/e9b489bf4c6669d4fef07115c03c2587.jpg'),
(88368, 6138, 'Mira: A Detetive do Reino S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/191986.mp4', 'http://timg.bdta.pro/images/b6e146b2868f92b985d6be3d42bae2d3.jpg'),
(88369, 6138, 'Mira: A Detetive do Reino S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/191987.mp4', 'http://timg.bdta.pro/images/51da6fd9a8784021ad8e3e5bac43906b.jpg'),
(88370, 6138, 'Mira: A Detetive do Reino S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/191988.mp4', 'http://timg.bdta.pro/images/9f6423e7a62252a18ffaad353c9c5238.jpg'),
(88371, 6138, 'Mira: A Detetive do Reino S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/191989.mp4', 'http://timg.bdta.pro/images/d3296d853289f5369d9d1b6876182361.jpg'),
(88372, 6138, 'Mira: A Detetive do Reino S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/191990.mp4', 'http://timg.bdta.pro/images/0ff2ee620cfae9b25b15e2db0b4f506a.jpg'),
(88373, 6138, 'Mira: A Detetive do Reino S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/191991.mp4', 'http://timg.bdta.pro/images/e2399bf4dbef24161198ce17e6bf9a0a.jpg'),
(88374, 6138, 'Mira: A Detetive do Reino S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/191992.mp4', 'http://timg.bdta.pro/images/9dc15138fa9c4479b2c8916b1ef2d4ea.jpg'),
(88375, 6138, 'Mira: A Detetive do Reino S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/191993.mp4', 'http://timg.bdta.pro/images/86625dc4df11db81a18971473eba241b.jpg'),
(88376, 6138, 'Mira: A Detetive do Reino S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/191994.mp4', 'http://timg.bdta.pro/images/b476e25b6b107ecbae9393aeba587c3a.jpg'),
(88377, 6138, 'Mira: A Detetive do Reino S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/191995.mp4', 'http://timg.bdta.pro/images/397b984b36f92aa419000b73c83d2e09.jpg'),
(88378, 6138, 'Mira: A Detetive do Reino S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/191996.mp4', 'http://timg.bdta.pro/images/bbdfe8e68936e8375fe7ff0def42c87d.jpg'),
(88379, 6138, 'Mira: A Detetive do Reino S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/191997.mp4', 'http://timg.bdta.pro/images/dbe786759c32e3f54cd22695a14c257a.jpg'),
(88380, 6138, 'Mira: A Detetive do Reino S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/191998.mp4', 'http://timg.bdta.pro/images/7a19364b08db18ca046ece183c305e94.jpg'),
(88381, 6138, 'Mira: A Detetive do Reino S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/191999.mp4', 'http://timg.bdta.pro/images/237ae9ca1c1a89857b3f8fbe9dfd1f88.jpg'),
(88382, 6139, 'Pacto Brutal: O Assassinato de Daniella Perez S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190645.mp4', 'http://timg.bdta.pro/images/e4130c7e12961e093c4f726f2d25cf56.jpg'),
(88383, 6139, 'Pacto Brutal: O Assassinato de Daniella Perez S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190646.mp4', 'http://timg.bdta.pro/images/c9bb6d92510c75418e9827a29f83413b.jpg'),
(88384, 6139, 'Pacto Brutal: O Assassinato de Daniella Perez S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190647.mp4', 'http://gstaticontent.com/images/b9db2215fc66aad284f36d5a80406d27.jpg'),
(88385, 6139, 'Pacto Brutal: O Assassinato de Daniella Perez S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190648.mp4', 'http://gstaticontent.com/images/b9db2215fc66aad284f36d5a80406d27.jpg'),
(88386, 6139, 'Pacto Brutal: O Assassinato de Daniella Perez S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190649.mp4', 'http://gstaticontent.com/images/b9db2215fc66aad284f36d5a80406d27.jpg'),
(88387, 6140, 'Rezar e Obedecer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191971.mp4', 'http://timg.bdta.pro/images/50cc8bc2a1a2a7f6c90c283f3aef893c.jpg'),
(88388, 6140, 'Rezar e Obedecer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191972.mp4', 'http://timg.bdta.pro/images/81b16bf2bef884780db8d8ff1d72425c.jpg'),
(88389, 6140, 'Rezar e Obedecer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191973.mp4', 'http://timg.bdta.pro/images/7e27488fdd62bec85d7d26f1432cfaf7.jpg'),
(88390, 6140, 'Rezar e Obedecer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191974.mp4', 'http://timg.bdta.pro/images/27bb7d455962c256f0330174c3a77130.jpg'),
(88391, 6141, 'Salve Meu Restaurante! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191961.mp4', 'http://gstaticontent.com/images/106c4a09bbcfc738e62bb761a4b60a4b.jpg'),
(88392, 6141, 'Salve Meu Restaurante! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191962.mp4', 'http://gstaticontent.com/images/106c4a09bbcfc738e62bb761a4b60a4b.jpg'),
(88393, 6141, 'Salve Meu Restaurante! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191963.mp4', 'http://gstaticontent.com/images/106c4a09bbcfc738e62bb761a4b60a4b.jpg'),
(88394, 6141, 'Salve Meu Restaurante! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191964.mp4', 'http://gstaticontent.com/images/106c4a09bbcfc738e62bb761a4b60a4b.jpg'),
(88395, 6141, 'Salve Meu Restaurante! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191965.mp4', 'http://gstaticontent.com/images/106c4a09bbcfc738e62bb761a4b60a4b.jpg'),
(88396, 6141, 'Salve Meu Restaurante! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191966.mp4', 'http://gstaticontent.com/images/106c4a09bbcfc738e62bb761a4b60a4b.jpg'),
(88397, 6141, 'Salve Meu Restaurante! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191967.mp4', 'http://gstaticontent.com/images/106c4a09bbcfc738e62bb761a4b60a4b.jpg'),
(88398, 6141, 'Salve Meu Restaurante! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191968.mp4', 'http://gstaticontent.com/images/106c4a09bbcfc738e62bb761a4b60a4b.jpg'),
(88399, 6141, 'Salve Meu Restaurante! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191969.mp4', 'http://gstaticontent.com/images/106c4a09bbcfc738e62bb761a4b60a4b.jpg'),
(88400, 6141, 'Salve Meu Restaurante! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191970.mp4', 'http://gstaticontent.com/images/106c4a09bbcfc738e62bb761a4b60a4b.jpg'),
(88401, 6142, 'Turma da Mônica - A Série S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191953.mp4', 'http://timg.bdta.pro/images/2370ed2a3d11ff6ddb13dd8101db9314.jpg'),
(88402, 6142, 'Turma da Mônica - A Série S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191954.mp4', 'http://timg.bdta.pro/images/f86cbd91ffe3a6c4e413fcbe4ed45356.jpg'),
(88403, 6142, 'Turma da Mônica - A Série S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191955.mp4', 'http://timg.bdta.pro/images/07180e5768cdc08afc8f106b6ebcadb2.jpg'),
(88404, 6142, 'Turma da Mônica - A Série S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191956.mp4', 'http://timg.bdta.pro/images/de006405786507a1ae3a8dd55d037504.jpg'),
(88405, 6142, 'Turma da Mônica - A Série S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191957.mp4', 'http://timg.bdta.pro/images/36e8d624f30f309d05ec3d1e94df5581.jpg'),
(88406, 6142, 'Turma da Mônica - A Série S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191958.mp4', 'http://timg.bdta.pro/images/f6d0dc34a8623e0e02571644fe823762.jpg'),
(88407, 6142, 'Turma da Mônica - A Série S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191959.mp4', 'http://timg.bdta.pro/images/e081f080d4bad898dce21fe5eb5289e4.jpg'),
(88408, 6142, 'Turma da Mônica - A Série S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191960.mp4', 'http://timg.bdta.pro/images/aef9390ec96723f20f1aaf7e1796ebb7.jpg'),
(88409, 6143, 'Um Passo de Cada Vez S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191943.mp4', 'http://timg.bdta.pro/images/b115c309d8369dc93f777944ff7fd4be.jpg'),
(88410, 6143, 'Um Passo de Cada Vez S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191944.mp4', 'http://timg.bdta.pro/images/5c44804a5aaebe058696a0342d5f7412.jpg'),
(88411, 6143, 'Um Passo de Cada Vez S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191945.mp4', 'http://timg.bdta.pro/images/f20f830a519c4f3892af38cff7099e3e.jpg'),
(88412, 6143, 'Um Passo de Cada Vez S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191946.mp4', 'http://timg.bdta.pro/images/252bfa91e303021e1937db87ce091cdd.jpg'),
(88413, 6143, 'Um Passo de Cada Vez S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191947.mp4', 'http://timg.bdta.pro/images/66805327ecea1d6526920f30c40722b2.jpg'),
(88414, 6143, 'Um Passo de Cada Vez S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191948.mp4', 'http://timg.bdta.pro/images/d6bc8cd33add2eea8e28a74e3e06eafd.jpg'),
(88415, 6143, 'Um Passo de Cada Vez S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191949.mp4', 'http://timg.bdta.pro/images/4c236282841c54d787fbf80dad5f1661.jpg'),
(88416, 6143, 'Um Passo de Cada Vez S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191950.mp4', 'http://timg.bdta.pro/images/2d45ef981b83b9240d62de3300eec378.jpg'),
(88417, 6143, 'Um Passo de Cada Vez S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191951.mp4', 'http://timg.bdta.pro/images/6606e88c3715a462f4a4b4d7661503a1.jpg'),
(88418, 6143, 'Um Passo de Cada Vez S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191952.mp4', 'http://timg.bdta.pro/images/055212bd09e11bf41073543d89b40b09.jpg'),
(88419, 6144, 'Desafio dos Cookies de Escoteiras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191941.mp4', 'http://timg.bdta.pro/images/15402c0c53cc9ed496e8c454ec938c78.jpg'),
(88420, 6144, 'Desafio dos Cookies de Escoteiras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191942.mp4', 'http://timg.bdta.pro/images/b0c4d266b87578e933d23aca0862f052.jpg'),
(88421, 6145, 'Truques da Mente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223569.mp4', 'http://timg.bdta.pro/images/277dd1451154a59e835b6ae83d6965f5.jpg'),
(88422, 6145, 'Truques da Mente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223570.mp4', 'http://timg.bdta.pro/images/f47fefd155625cb05c694f03e8e9531f.jpg'),
(88423, 6145, 'Truques da Mente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223571.mp4', 'http://timg.bdta.pro/images/0ec81348fbcd96a8d1d53056f6ed0e7f.jpg'),
(88424, 6146, 'Truques da Mente S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223572.mp4', 'http://timg.bdta.pro/images/437134bb82d826499ef641f0c0c9c68d.jpg'),
(88425, 6146, 'Truques da Mente S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223573.mp4', 'http://timg.bdta.pro/images/f0bcc2347f59cff0677d76be4e6b41c2.jpg'),
(88426, 6146, 'Truques da Mente S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223574.mp4', 'http://timg.bdta.pro/images/c3bbde0d4bf420b4179d278f7dcd3ef5.jpg'),
(88427, 6146, 'Truques da Mente S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223575.mp4', 'http://timg.bdta.pro/images/e73e0150504530ed110091a52574ef11.jpg'),
(88428, 6146, 'Truques da Mente S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223576.mp4', 'http://timg.bdta.pro/images/b7269475e3b7735ee94c6eeb968c3859.jpg'),
(88429, 6146, 'Truques da Mente S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223577.mp4', 'http://timg.bdta.pro/images/94836fa455e418c1842669c5785381d5.jpg'),
(88430, 6146, 'Truques da Mente S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223578.mp4', 'http://timg.bdta.pro/images/f26b23be181aa6bf7e9a6a7ffa621bdb.jpg'),
(88431, 6146, 'Truques da Mente S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223579.mp4', 'http://timg.bdta.pro/images/db4376c4028c923a2f7f19e75fc857e3.jpg'),
(88432, 6146, 'Truques da Mente S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223580.mp4', 'http://timg.bdta.pro/images/d21247d531bdc79eeb9bd3a650c26076.jpg'),
(88433, 6146, 'Truques da Mente S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223581.mp4', 'http://timg.bdta.pro/images/8b062e1fb577a916b3e8b3c65e53d495.jpg'),
(88434, 6146, 'Truques da Mente S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223582.mp4', 'http://timg.bdta.pro/images/3d639179951ac398afe804ca361e6115.jpg'),
(88435, 6146, 'Truques da Mente S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223583.mp4', 'http://timg.bdta.pro/images/2a3b1bd5f0b8484c982ea1b4e62db095.jpg'),
(88436, 6147, 'Truques da Mente S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i5sj3sT53OqdNdIWybvjni6p0ze.jpg'),
(88437, 6147, 'Truques da Mente S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kstTqHgWoeyu5HHcOGP5kGxUuc2.jpg'),
(88438, 6147, 'Truques da Mente S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tLSH24ZkdejSoAOUWmUXYsxcvsg.jpg'),
(88439, 6147, 'Truques da Mente S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rHMGihT5kP2v0GkcEgxurgTWCpf.jpg'),
(88440, 6147, 'Truques da Mente S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8y1c2gCAFXn1m5ek5gN8xerMMC.jpg'),
(88441, 6147, 'Truques da Mente S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9EcvL1ldzFqFeMHAZPkTGMWVQJt.jpg'),
(88442, 6147, 'Truques da Mente S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z4yb9dDqDTWTmzViAgRk86dfp1M.jpg'),
(88443, 6147, 'Truques da Mente S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/933r8RiG9U63IZtR09G5y8pDYHO.jpg'),
(88444, 6147, 'Truques da Mente S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1tVDcpyqa9c9PUYAHrCiMIgdcn2.jpg'),
(88445, 6147, 'Truques da Mente S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gruNFOViPN6NdX6aXx9kH6dTo3Y.jpg'),
(88446, 6148, 'Truques da Mente S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/HryFmCwqn86wK1ZgGvxi1gBdzO.jpg'),
(88447, 6148, 'Truques da Mente S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ym8yqoG8OPIIa0GTGwkgC2wfik9.jpg'),
(88448, 6148, 'Truques da Mente S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nRMVeP79baJQuywvJ2YaxiBNXwJ.jpg'),
(88449, 6148, 'Truques da Mente S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0anc0vFvzLxKhpnumLjZDDVHw8.jpg'),
(88450, 6148, 'Truques da Mente S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/byz2VMLxqU5OTGFgU2njM9XBGLl.jpg'),
(88451, 6148, 'Truques da Mente S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qhnSPYe0EMQfb3b2mfUy4LT1y1i.jpg'),
(88452, 6148, 'Truques da Mente S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13mmCp9nK1cTWpCjYKdGzTucclZ.jpg'),
(88453, 6148, 'Truques da Mente S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/beoFYouKsg1ERDqWF85v5jA0hpf.jpg'),
(88454, 6148, 'Truques da Mente S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/buyDznF6r8vB7aYURnlrIovWZKj.jpg'),
(88455, 6148, 'Truques da Mente S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4plBu5o329Oc3z1Y1iivHLn5zdY.jpg'),
(88456, 6149, 'Truques da Mente S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xUtV2yKjlMlMtT9hRAKXKilRjws.jpg'),
(88457, 6149, 'Truques da Mente S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l39xqqrW8LMmIHnqaQEfJwSg1e.jpg'),
(88458, 6149, 'Truques da Mente S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l39xqqrW8LMmIHnqaQEfJwSg1e.jpg'),
(88459, 6149, 'Truques da Mente S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rokYvyDR65Lm7YC0Fdshjdzaxmw.jpg'),
(88460, 6149, 'Truques da Mente S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A8iGvqod7Zl5oWF4PBWwf9fC1Ew.jpg'),
(88461, 6149, 'Truques da Mente S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCbWxtKegbHv81nLT5tWgnMiK7w.jpg'),
(88462, 6149, 'Truques da Mente S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/busKyG4pZdtsXGa7HbhHqqG4EW3.jpg'),
(88463, 6149, 'Truques da Mente S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7YJLej3m9bwGVDtvLAgjl7NuKXR.jpg'),
(88464, 6149, 'Truques da Mente S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yk2FaejJqxlN4Td48SbWslnpS8H.jpg'),
(88465, 6149, 'Truques da Mente S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mSVjijr5nDW9ZP7sgC5MjOlXB8O.jpg'),
(88466, 6150, 'Truques da Mente S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHdVub6sn48OikgfhkyHPVOeZR0.jpg'),
(88467, 6150, 'Truques da Mente S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/niydqcPqxxom8cBYEEwWfhjOJ6s.jpg'),
(88468, 6150, 'Truques da Mente S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBsh6yeGaVefZok3GLNs5mAlF7x.jpg'),
(88469, 6150, 'Truques da Mente S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Us9VVmNpMOeJWsCy2HObiLOSP5.jpg'),
(88470, 6150, 'Truques da Mente S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/75LkO1IVgfkibN3kwZVpqNJKy3e.jpg'),
(88471, 6150, 'Truques da Mente S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kForjSs4ngrBW2WE2cwtD62OR63.jpg'),
(88472, 6151, 'Truques da Mente S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ph8SoNRgpHcYmCbZhA8ouP7P4Nt.jpg'),
(88473, 6151, 'Truques da Mente S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b3RTEI0xi2kfyzWwv38gN7FnIVC.jpg'),
(88474, 6151, 'Truques da Mente S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cTCy8nX8FmqQK10MiTCdvB88UZM.jpg'),
(88475, 6151, 'Truques da Mente S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vo4e1dFlwdbUgYPolCRiVSuoNpq.jpg'),
(88476, 6151, 'Truques da Mente S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVn9qunOgAMshQeR8MX2n6nJNC8.jpg'),
(88477, 6151, 'Truques da Mente S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jbFZzB1vl5LK8uypK6HbzWuap6f.jpg'),
(88478, 6152, 'Em Nome do Céu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191316.mp4', 'http://timg.bdta.pro/images/8ec3caa172212ca08fe69c61b0556ab2.jpg'),
(88479, 6152, 'Em Nome do Céu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191317.mp4', 'http://timg.bdta.pro/images/e93cafe4ca82da7faabaa224c3208c82.jpg'),
(88480, 6152, 'Em Nome do Céu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191318.mp4', 'http://timg.bdta.pro/images/a83672fd044a35719a68839609a34c54.jpg'),
(88481, 6152, 'Em Nome do Céu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191319.mp4', 'http://timg.bdta.pro/images/b0a2cda88d22cdc65a87251c9f876870.jpg'),
(88482, 6152, 'Em Nome do Céu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191320.mp4', 'http://timg.bdta.pro/images/7f8d65fa3762781bfa940f028e470236.jpg'),
(88483, 6152, 'Em Nome do Céu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191321.mp4', 'http://timg.bdta.pro/images/468ebc10bf503d46a18d4394b6b0ef9d.jpg'),
(88484, 6152, 'Em Nome do Céu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191322.mp4', 'http://timg.bdta.pro/images/e004e9fd434f6c89274f3175a2333c5e.jpg'),
(88485, 6153, 'Perninha em Obras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191308.mp4', 'http://timg.bdta.pro/images/dfddc2ed3c76d9a4eb3bbc0b687bb5aa.jpg'),
(88486, 6153, 'Perninha em Obras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191309.mp4', 'http://timg.bdta.pro/images/c2bad1d204862c4fb9ad04c4ca970f8b.jpg'),
(88487, 6153, 'Perninha em Obras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191310.mp4', 'http://timg.bdta.pro/images/3190417c5fb5adf98928a40de7a16816.jpg'),
(88488, 6153, 'Perninha em Obras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191311.mp4', 'http://timg.bdta.pro/images/8f98c1b59af57a65d1518f9e9c298b1d.jpg'),
(88489, 6153, 'Perninha em Obras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191312.mp4', 'http://timg.bdta.pro/images/0f07688786356398047bd1a4f8c68df4.jpg'),
(88490, 6153, 'Perninha em Obras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191313.mp4', 'http://timg.bdta.pro/images/1540a6c8939a532c8e546a026e05ad80.jpg'),
(88491, 6153, 'Perninha em Obras S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191314.mp4', 'http://timg.bdta.pro/images/98a7e213e74bb8dcd2d5b3dc7a6f3a8b.jpg'),
(88492, 6153, 'Perninha em Obras S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191315.mp4', 'http://timg.bdta.pro/images/5f96247b5ce55dfc80df0f43f5fb2670.jpg'),
(88493, 6154, 'Santa Evita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191301.mp4', 'http://timg.bdta.pro/images/ee1de4bc519abc86d268592a1e6d64f3.jpg'),
(88494, 6154, 'Santa Evita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191302.mp4', 'http://timg.bdta.pro/images/ee1de4bc519abc86d268592a1e6d64f3.jpg'),
(88495, 6154, 'Santa Evita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191303.mp4', 'http://timg.bdta.pro/images/ee1de4bc519abc86d268592a1e6d64f3.jpg'),
(88496, 6154, 'Santa Evita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191304.mp4', 'http://timg.bdta.pro/images/ee1de4bc519abc86d268592a1e6d64f3.jpg'),
(88497, 6154, 'Santa Evita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191305.mp4', 'http://timg.bdta.pro/images/ee1de4bc519abc86d268592a1e6d64f3.jpg'),
(88498, 6154, 'Santa Evita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191306.mp4', 'http://timg.bdta.pro/images/ee1de4bc519abc86d268592a1e6d64f3.jpg'),
(88499, 6154, 'Santa Evita S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191307.mp4', 'http://timg.bdta.pro/images/ee1de4bc519abc86d268592a1e6d64f3.jpg'),
(88500, 6155, 'Segredos da Playboy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249744.mp4', 'http://gstaticontent.com/images/e9a49c8dcb3a7f4384633705b23de208.jpg'),
(88501, 6155, 'Segredos da Playboy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249745.mp4', 'http://gstaticontent.com/images/e9a49c8dcb3a7f4384633705b23de208.jpg'),
(88502, 6155, 'Segredos da Playboy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249746.mp4', 'http://gstaticontent.com/images/e9a49c8dcb3a7f4384633705b23de208.jpg'),
(88503, 6155, 'Segredos da Playboy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249747.mp4', 'http://timg.bdta.pro/images/bc0b27277c458ad327c15cbc3f4f4c9c.jpg'),
(88504, 6155, 'Segredos da Playboy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249748.mp4', 'http://gstaticontent.com/images/e9a49c8dcb3a7f4384633705b23de208.jpg'),
(88505, 6155, 'Segredos da Playboy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249749.mp4', 'http://gstaticontent.com/images/e9a49c8dcb3a7f4384633705b23de208.jpg'),
(88506, 6155, 'Segredos da Playboy S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249750.mp4', 'http://gstaticontent.com/images/e9a49c8dcb3a7f4384633705b23de208.jpg'),
(88507, 6155, 'Segredos da Playboy S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249751.mp4', 'http://gstaticontent.com/images/e9a49c8dcb3a7f4384633705b23de208.jpg'),
(88508, 6155, 'Segredos da Playboy S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249752.mp4', 'http://gstaticontent.com/images/e9a49c8dcb3a7f4384633705b23de208.jpg'),
(88509, 6155, 'Segredos da Playboy S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249753.mp4', 'http://gstaticontent.com/images/e9a49c8dcb3a7f4384633705b23de208.jpg'),
(88510, 6155, 'Segredos da Playboy S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249754.mp4', 'http://gstaticontent.com/images/e9a49c8dcb3a7f4384633705b23de208.jpg'),
(88511, 6155, 'Segredos da Playboy S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249755.mp4', 'http://gstaticontent.com/images/e9a49c8dcb3a7f4384633705b23de208.jpg'),
(88512, 6156, 'Segredos da Playboy S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249756.mp4', 'http://gstaticontent.com/images/e9a49c8dcb3a7f4384633705b23de208.jpg'),
(88513, 6156, 'Segredos da Playboy S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249757.mp4', 'http://gstaticontent.com/images/e9a49c8dcb3a7f4384633705b23de208.jpg'),
(88514, 6156, 'Segredos da Playboy S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249758.mp4', 'http://gstaticontent.com/images/e9a49c8dcb3a7f4384633705b23de208.jpg'),
(88515, 6156, 'Segredos da Playboy S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249759.mp4', 'http://gstaticontent.com/images/e9a49c8dcb3a7f4384633705b23de208.jpg'),
(88516, 6156, 'Segredos da Playboy S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249760.mp4', 'http://gstaticontent.com/images/e9a49c8dcb3a7f4384633705b23de208.jpg'),
(88517, 6156, 'Segredos da Playboy S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249761.mp4', 'http://gstaticontent.com/images/e9a49c8dcb3a7f4384633705b23de208.jpg'),
(88518, 6156, 'Segredos da Playboy S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249762.mp4', 'http://gstaticontent.com/images/e9a49c8dcb3a7f4384633705b23de208.jpg'),
(88519, 6156, 'Segredos da Playboy S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249763.mp4', 'http://gstaticontent.com/images/e9a49c8dcb3a7f4384633705b23de208.jpg'),
(88520, 6157, 'The Rising of the Shield Hero S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257718.mp4', 'http://timg.bdta.pro/images/2ae3c54e08482fbafd21cab0598c519e.jpg'),
(88521, 6157, 'The Rising of the Shield Hero S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257719.mp4', 'http://timg.bdta.pro/images/3cfeedb522af611ac1ca08e6aa813b32.jpg'),
(88522, 6157, 'The Rising of the Shield Hero S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257720.mp4', 'http://timg.bdta.pro/images/dc171ac804b294c5d7201daebcd7b30e.jpg'),
(88523, 6157, 'The Rising of the Shield Hero S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257721.mp4', 'http://timg.bdta.pro/images/b9cc0f12dfb37cf4016a650512c1ef10.jpg'),
(88524, 6157, 'The Rising of the Shield Hero S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257722.mp4', 'http://timg.bdta.pro/images/ed9bf9900a680353c1daf96b34ea1cf4.jpg'),
(88525, 6157, 'The Rising of the Shield Hero S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257723.mp4', 'http://timg.bdta.pro/images/3be1a31c38a640f5aba14cac9700a644.jpg'),
(88526, 6157, 'The Rising of the Shield Hero S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257724.mp4', 'http://timg.bdta.pro/images/144a2e0f1c68285363a305bcc20b4c6b.jpg'),
(88527, 6157, 'The Rising of the Shield Hero S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257725.mp4', 'http://timg.bdta.pro/images/2cf40b115477fdc816dad5b8a9a824d9.jpg'),
(88528, 6157, 'The Rising of the Shield Hero S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257726.mp4', 'http://timg.bdta.pro/images/6d70713d78fe884be195c3c8b0409702.jpg'),
(88529, 6157, 'The Rising of the Shield Hero S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257727.mp4', 'http://timg.bdta.pro/images/c6fb01e915920a7ead1f8614924ed0d8.jpg'),
(88530, 6157, 'The Rising of the Shield Hero S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257728.mp4', 'http://timg.bdta.pro/images/244ab621e85fb79808e9e8b8f7c01e76.jpg'),
(88531, 6157, 'The Rising of the Shield Hero S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257729.mp4', 'http://timg.bdta.pro/images/edf3a6adf8a2cf154f4c54b1cdfec2d8.jpg'),
(88532, 6157, 'The Rising of the Shield Hero S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257730.mp4', 'http://timg.bdta.pro/images/352364a5c51210c87514e186015b6874.jpg'),
(88533, 6157, 'The Rising of the Shield Hero S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/257731.mp4', 'http://timg.bdta.pro/images/d33eb7773062669a6bad33bfe6bd60a4.jpg'),
(88534, 6157, 'The Rising of the Shield Hero S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/257732.mp4', 'http://timg.bdta.pro/images/927c1c665be01df29a1317f9d279deb5.jpg'),
(88535, 6157, 'The Rising of the Shield Hero S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/257733.mp4', 'http://timg.bdta.pro/images/7cbc0e715b2ccc6043b6f37829f0a71a.jpg'),
(88536, 6157, 'The Rising of the Shield Hero S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/257734.mp4', 'http://timg.bdta.pro/images/b0d72d7a98dd6a37d9426b8c98863a12.jpg'),
(88537, 6157, 'The Rising of the Shield Hero S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/257735.mp4', 'http://timg.bdta.pro/images/5d0a25fd6f278bfcf50c4ea8faf55017.jpg'),
(88538, 6157, 'The Rising of the Shield Hero S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/257736.mp4', 'http://timg.bdta.pro/images/725ad2e63984e00aba00fd0e031a5a71.jpg'),
(88539, 6157, 'The Rising of the Shield Hero S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/257737.mp4', 'http://timg.bdta.pro/images/27e688cb8c1b34a311d4e4c4efeedbe2.jpg'),
(88540, 6157, 'The Rising of the Shield Hero S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/257738.mp4', 'http://timg.bdta.pro/images/3ad25e5572b132bf1eda89c61a841e1d.jpg'),
(88541, 6157, 'The Rising of the Shield Hero S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/257739.mp4', 'http://timg.bdta.pro/images/35a0edfcd858bb00cee08bf270247601.jpg'),
(88542, 6157, 'The Rising of the Shield Hero S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/257740.mp4', 'http://timg.bdta.pro/images/00d27641dbb302d400f19440065a87b2.jpg'),
(88543, 6157, 'The Rising of the Shield Hero S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/257741.mp4', 'http://timg.bdta.pro/images/d6c788ad0a936b5ab8fc94d89e961382.jpg'),
(88544, 6157, 'The Rising of the Shield Hero S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/257742.mp4', 'http://timg.bdta.pro/images/dbe0d4b3116b53de3dddd624822e9eda.jpg'),
(88545, 6158, 'The Rising of the Shield Hero S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257743.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88546, 6158, 'The Rising of the Shield Hero S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257744.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88547, 6158, 'The Rising of the Shield Hero S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257745.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88548, 6158, 'The Rising of the Shield Hero S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257746.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88549, 6158, 'The Rising of the Shield Hero S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257747.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88550, 6158, 'The Rising of the Shield Hero S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257748.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88551, 6158, 'The Rising of the Shield Hero S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257749.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88552, 6158, 'The Rising of the Shield Hero S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257750.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88553, 6158, 'The Rising of the Shield Hero S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257751.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88554, 6158, 'The Rising of the Shield Hero S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257752.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88555, 6158, 'The Rising of the Shield Hero S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257753.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88556, 6158, 'The Rising of the Shield Hero S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257754.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88557, 6158, 'The Rising of the Shield Hero S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257755.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88558, 6159, 'The Rising of the Shield Hero S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257756.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88559, 6159, 'The Rising of the Shield Hero S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257757.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88560, 6159, 'The Rising of the Shield Hero S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257758.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88561, 6159, 'The Rising of the Shield Hero S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257759.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88562, 6159, 'The Rising of the Shield Hero S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257760.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88563, 6159, 'The Rising of the Shield Hero S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257761.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88564, 6159, 'The Rising of the Shield Hero S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257762.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88565, 6159, 'The Rising of the Shield Hero S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257763.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88566, 6159, 'The Rising of the Shield Hero S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257764.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88567, 6159, 'The Rising of the Shield Hero S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257765.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88568, 6159, 'The Rising of the Shield Hero S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257766.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88569, 6159, 'The Rising of the Shield Hero S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257767.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88570, 6160, 'The Rising of the Shield Hero S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/869596.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88571, 6160, 'The Rising of the Shield Hero S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/878005.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88572, 6160, 'The Rising of the Shield Hero S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/879393.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88573, 6160, 'The Rising of the Shield Hero S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/879878.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88574, 6160, 'The Rising of the Shield Hero S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/880563.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88575, 6160, 'The Rising of the Shield Hero S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/881272.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88576, 6160, 'The Rising of the Shield Hero S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/881273.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88577, 6160, 'The Rising of the Shield Hero S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/882195.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88578, 6160, 'The Rising of the Shield Hero S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/883776.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88579, 6160, 'The Rising of the Shield Hero S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/885304.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88580, 6160, 'The Rising of the Shield Hero S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/886055.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88581, 6160, 'The Rising of the Shield Hero S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/887543.mp4', 'http://gstaticontent.com/images/8e51619d53c91caf5d13f850ca56ecce.jpg'),
(88582, 6161, 'Férias Mortais: O Assassinato Selvagem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191253.mp4', 'http://timg.bdta.pro/images/8565ec4254787ef8f39c785996102fa9.jpg'),
(88583, 6161, 'Férias Mortais: O Assassinato Selvagem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191254.mp4', 'http://timg.bdta.pro/images/31b66c594f4669d78a7cb6bb793eaf3b.jpg'),
(88584, 6161, 'Férias Mortais: O Assassinato Selvagem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191255.mp4', 'http://timg.bdta.pro/images/2daf61b07d8dfc0d49a66a3f01b6fec7.jpg'),
(88585, 6161, 'Férias Mortais: O Assassinato Selvagem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191256.mp4', 'http://timg.bdta.pro/images/e5e50bcbce47db06a26167e945d45aac.jpg'),
(88586, 6162, 'Maior de Idade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220485.mp4', 'http://gstaticontent.com/images/a0f47474f86a5ce2e31c9ac057b0b7c5.jpg'),
(88587, 6162, 'Maior de Idade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220486.mp4', 'http://gstaticontent.com/images/a0f47474f86a5ce2e31c9ac057b0b7c5.jpg'),
(88588, 6162, 'Maior de Idade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220487.mp4', 'http://gstaticontent.com/images/a0f47474f86a5ce2e31c9ac057b0b7c5.jpg'),
(88589, 6162, 'Maior de Idade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220488.mp4', 'http://gstaticontent.com/images/a0f47474f86a5ce2e31c9ac057b0b7c5.jpg'),
(88590, 6162, 'Maior de Idade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220489.mp4', 'http://gstaticontent.com/images/a0f47474f86a5ce2e31c9ac057b0b7c5.jpg'),
(88591, 6162, 'Maior de Idade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220490.mp4', 'http://gstaticontent.com/images/a0f47474f86a5ce2e31c9ac057b0b7c5.jpg'),
(88592, 6163, 'Maior de Idade S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220491.mp4', 'http://gstaticontent.com/images/a0f47474f86a5ce2e31c9ac057b0b7c5.jpg'),
(88593, 6163, 'Maior de Idade S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220492.mp4', 'http://gstaticontent.com/images/a0f47474f86a5ce2e31c9ac057b0b7c5.jpg'),
(88594, 6163, 'Maior de Idade S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220493.mp4', 'http://gstaticontent.com/images/a0f47474f86a5ce2e31c9ac057b0b7c5.jpg'),
(88595, 6163, 'Maior de Idade S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220494.mp4', 'http://gstaticontent.com/images/a0f47474f86a5ce2e31c9ac057b0b7c5.jpg'),
(88596, 6163, 'Maior de Idade S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220495.mp4', 'http://gstaticontent.com/images/a0f47474f86a5ce2e31c9ac057b0b7c5.jpg'),
(88597, 6163, 'Maior de Idade S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220496.mp4', 'http://gstaticontent.com/images/a0f47474f86a5ce2e31c9ac057b0b7c5.jpg'),
(88598, 6163, 'Maior de Idade S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220497.mp4', 'http://gstaticontent.com/images/a0f47474f86a5ce2e31c9ac057b0b7c5.jpg'),
(88599, 6163, 'Maior de Idade S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220498.mp4', 'http://gstaticontent.com/images/a0f47474f86a5ce2e31c9ac057b0b7c5.jpg'),
(88600, 6163, 'Maior de Idade S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220499.mp4', 'http://gstaticontent.com/images/a0f47474f86a5ce2e31c9ac057b0b7c5.jpg'),
(88601, 6163, 'Maior de Idade S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220500.mp4', 'http://gstaticontent.com/images/a0f47474f86a5ce2e31c9ac057b0b7c5.jpg'),
(88602, 6164, 'Kawaii dake ja Nai Shikimori-san S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191241.mp4', 'http://timg.bdta.pro/images/2d8ab5adcefe616b5d06ef89a9d175bf.jpg'),
(88603, 6164, 'Kawaii dake ja Nai Shikimori-san S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191242.mp4', 'http://timg.bdta.pro/images/26dadeb77653b77441acc4e6856ff0bb.jpg'),
(88604, 6164, 'Kawaii dake ja Nai Shikimori-san S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191243.mp4', 'http://timg.bdta.pro/images/3c872b4df7284f2f39a989ea31140bd6.jpg'),
(88605, 6164, 'Kawaii dake ja Nai Shikimori-san S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191244.mp4', 'http://timg.bdta.pro/images/a11d3093e1a7fd5ea70014d9173d8e0f.jpg'),
(88606, 6164, 'Kawaii dake ja Nai Shikimori-san S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191245.mp4', 'http://timg.bdta.pro/images/31d9fe1f801cb01e683193a3ce92fade.jpg'),
(88607, 6164, 'Kawaii dake ja Nai Shikimori-san S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191246.mp4', 'http://timg.bdta.pro/images/12179d9e3046b22d42a656d150184abe.jpg'),
(88608, 6164, 'Kawaii dake ja Nai Shikimori-san S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191247.mp4', 'http://timg.bdta.pro/images/e987f2ce8ef9bad2665d22b829f771a8.jpg'),
(88609, 6164, 'Kawaii dake ja Nai Shikimori-san S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191248.mp4', 'http://timg.bdta.pro/images/1d758a5c56aed3d54f48961c007d960a.jpg'),
(88610, 6164, 'Kawaii dake ja Nai Shikimori-san S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191249.mp4', 'http://timg.bdta.pro/images/ad3c97b7e07572645a00a8e4f566e2b0.jpg'),
(88611, 6164, 'Kawaii dake ja Nai Shikimori-san S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191250.mp4', 'http://timg.bdta.pro/images/2e82fa920566da805ccb75dc5e197f80.jpg'),
(88612, 6164, 'Kawaii dake ja Nai Shikimori-san S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191251.mp4', 'http://timg.bdta.pro/images/23d8fbe35b37f84fc637b0e05c503f31.jpg'),
(88613, 6164, 'Kawaii dake ja Nai Shikimori-san S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/191252.mp4', 'http://timg.bdta.pro/images/37ba74385de2d633dca74601e1ba321e.jpg'),
(88614, 6165, 'Light & Magic S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191235.mp4', 'http://timg.bdta.pro/images/f01888d8300e54d561f0946074dc6d83.jpg'),
(88615, 6165, 'Light & Magic S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191236.mp4', 'http://timg.bdta.pro/images/d80e72a81f99f18ff1624514737b949c.jpg'),
(88616, 6165, 'Light & Magic S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191237.mp4', 'http://timg.bdta.pro/images/febd76546fe8ff71cd7fbcc303bafe2f.jpg'),
(88617, 6165, 'Light & Magic S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191238.mp4', 'http://timg.bdta.pro/images/0d8e8beb71ccc1cbc14be9e9f8a51a32.jpg'),
(88618, 6165, 'Light & Magic S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191239.mp4', 'http://timg.bdta.pro/images/f41096054bd1e1b6b85dd0f7bd53d57c.jpg'),
(88619, 6165, 'Light & Magic S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191240.mp4', 'http://timg.bdta.pro/images/55a177261b38102f1e81269805a1e7b5.jpg'),
(88620, 6166, 'o Gorila S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191204.mp4', 'http://timg.bdta.pro/images/c68e33d65c269c3819988f1ddd1d26ea.jpg'),
(88621, 6166, 'o Gorila S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191205.mp4', 'http://timg.bdta.pro/images/e1adddb50c713688234e2254ef94a801.jpg'),
(88622, 6166, 'o Gorila S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191206.mp4', 'http://timg.bdta.pro/images/b483d4b6baeaa9560015351ccbd68565.jpg'),
(88623, 6166, 'o Gorila S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191207.mp4', 'http://timg.bdta.pro/images/f3d86506167f0752ab72d4e6cac7839c.jpg'),
(88624, 6166, 'o Gorila S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191208.mp4', 'http://timg.bdta.pro/images/83fb2c20e8f4bab0a8bd8929e72b30f8.jpg'),
(88625, 6166, 'o Gorila S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191209.mp4', 'http://timg.bdta.pro/images/136ea37b82046e7fba7c6fca75e82e1d.jpg'),
(88626, 6166, 'o Gorila S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191210.mp4', 'http://timg.bdta.pro/images/fe1a16d67f1bc20aeddfbc7fc9239b14.jpg'),
(88627, 6166, 'o Gorila S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191211.mp4', 'http://timg.bdta.pro/images/3625e1a11842ec2c8ca1b08fbddc89ad.jpg'),
(88628, 6166, 'o Gorila S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191212.mp4', 'http://timg.bdta.pro/images/16b1ce894863638911ad855fefb3fcdd.jpg'),
(88629, 6166, 'o Gorila S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191213.mp4', 'http://timg.bdta.pro/images/1c3c871560a6a52ca8b5ef91f080eda3.jpg'),
(88630, 6166, 'o Gorila S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191214.mp4', 'http://timg.bdta.pro/images/970796f0f27d6c1e794f56ba15cabe58.jpg'),
(88631, 6166, 'o Gorila S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/191215.mp4', 'http://timg.bdta.pro/images/dcbc06749231f9fa634ba86d3e0870dd.jpg'),
(88632, 6166, 'o Gorila S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/191216.mp4', 'http://timg.bdta.pro/images/17c1be326d3fc4ecb9e858e0e3648ae8.jpg'),
(88633, 6166, 'o Gorila S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/191217.mp4', 'http://timg.bdta.pro/images/d2184b785d918591be2a212abed35e68.jpg'),
(88634, 6166, 'o Gorila S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/191218.mp4', 'http://timg.bdta.pro/images/4b44e19b7084584f38b436813695dfe6.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(88635, 6166, 'o Gorila S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/191219.mp4', 'http://gstaticontent.com/images/7b7d378ebf64ea8cd3afeeb05663f4c9.jpg'),
(88636, 6166, 'o Gorila S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/191220.mp4', 'http://gstaticontent.com/images/7b7d378ebf64ea8cd3afeeb05663f4c9.jpg'),
(88637, 6166, 'o Gorila S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/191221.mp4', 'http://gstaticontent.com/images/7b7d378ebf64ea8cd3afeeb05663f4c9.jpg'),
(88638, 6166, 'o Gorila S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/191222.mp4', 'http://gstaticontent.com/images/7b7d378ebf64ea8cd3afeeb05663f4c9.jpg'),
(88639, 6166, 'o Gorila S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/191223.mp4', 'http://gstaticontent.com/images/7b7d378ebf64ea8cd3afeeb05663f4c9.jpg'),
(88640, 6166, 'o Gorila S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/191224.mp4', 'http://gstaticontent.com/images/7b7d378ebf64ea8cd3afeeb05663f4c9.jpg'),
(88641, 6166, 'o Gorila S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/191225.mp4', 'http://gstaticontent.com/images/7b7d378ebf64ea8cd3afeeb05663f4c9.jpg'),
(88642, 6166, 'o Gorila S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/191226.mp4', 'http://gstaticontent.com/images/7b7d378ebf64ea8cd3afeeb05663f4c9.jpg'),
(88643, 6166, 'o Gorila S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/191227.mp4', 'http://gstaticontent.com/images/7b7d378ebf64ea8cd3afeeb05663f4c9.jpg'),
(88644, 6166, 'o Gorila S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/191228.mp4', 'http://gstaticontent.com/images/7b7d378ebf64ea8cd3afeeb05663f4c9.jpg'),
(88645, 6166, 'o Gorila S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/191229.mp4', 'http://gstaticontent.com/images/7b7d378ebf64ea8cd3afeeb05663f4c9.jpg'),
(88646, 6166, 'o Gorila S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/191230.mp4', 'http://gstaticontent.com/images/7b7d378ebf64ea8cd3afeeb05663f4c9.jpg'),
(88647, 6166, 'o Gorila S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/191231.mp4', 'http://gstaticontent.com/images/7b7d378ebf64ea8cd3afeeb05663f4c9.jpg'),
(88648, 6166, 'o Gorila S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/191232.mp4', 'http://gstaticontent.com/images/7b7d378ebf64ea8cd3afeeb05663f4c9.jpg'),
(88649, 6166, 'o Gorila S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/191233.mp4', 'http://gstaticontent.com/images/7b7d378ebf64ea8cd3afeeb05663f4c9.jpg'),
(88650, 6166, 'o Gorila S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/191234.mp4', 'http://gstaticontent.com/images/7b7d378ebf64ea8cd3afeeb05663f4c9.jpg'),
(88651, 6167, 'Ninguém Mandou Se Meter com a Gente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191196.mp4', 'http://timg.bdta.pro/images/e3c699f498abc1c19b33f3a911a79527.jpg'),
(88652, 6167, 'Ninguém Mandou Se Meter com a Gente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191197.mp4', 'http://timg.bdta.pro/images/7a70bbfec7222a763e986d2889f96ebf.jpg'),
(88653, 6167, 'Ninguém Mandou Se Meter com a Gente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191198.mp4', 'http://timg.bdta.pro/images/7b5652c0e6d39dfccd8ccb9e0b37c783.jpg'),
(88654, 6167, 'Ninguém Mandou Se Meter com a Gente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191199.mp4', 'http://timg.bdta.pro/images/b4099977e25b5d270c8707ee5afab68a.jpg'),
(88655, 6167, 'Ninguém Mandou Se Meter com a Gente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191200.mp4', 'http://timg.bdta.pro/images/fd7a0506c09b952308b6c60df93a74e1.jpg'),
(88656, 6167, 'Ninguém Mandou Se Meter com a Gente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191201.mp4', 'http://timg.bdta.pro/images/5473329d5065ae7169a8205288a657d9.jpg'),
(88657, 6167, 'Ninguém Mandou Se Meter com a Gente S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191202.mp4', 'http://timg.bdta.pro/images/2daed91b4bfe79b7ec4c27e19746eba0.jpg'),
(88658, 6167, 'Ninguém Mandou Se Meter com a Gente S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191203.mp4', 'http://timg.bdta.pro/images/bf1ebd55c014c5acf5708839009b9947.jpg'),
(88659, 6168, 'O Refugio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191190.mp4', 'http://timg.bdta.pro/images/9c140a16e2221b224f250ac817d68ed5.jpg'),
(88660, 6168, 'O Refugio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191191.mp4', 'http://timg.bdta.pro/images/094b311cc7a3fdbe7fd0ea622a0662bb.jpg'),
(88661, 6168, 'O Refugio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191192.mp4', 'http://timg.bdta.pro/images/385c6a0b767997e7ff97b543cadc89b4.jpg'),
(88662, 6168, 'O Refugio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191193.mp4', 'http://timg.bdta.pro/images/c8e1793011b2cc90522746452d6c4d25.jpg'),
(88663, 6168, 'O Refugio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191194.mp4', 'http://timg.bdta.pro/images/6f0e7ec3ab7eba816f48758f0961e01c.jpg'),
(88664, 6168, 'O Refugio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191195.mp4', 'http://timg.bdta.pro/images/3964852df4063db25b00d51fef4046fb.jpg'),
(88665, 6169, 'Os Reis da Sucata S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191140.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88666, 6169, 'Os Reis da Sucata S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191141.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88667, 6169, 'Os Reis da Sucata S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191142.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88668, 6169, 'Os Reis da Sucata S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191143.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88669, 6169, 'Os Reis da Sucata S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191144.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88670, 6169, 'Os Reis da Sucata S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191145.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88671, 6170, 'Os Reis da Sucata S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191146.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88672, 6170, 'Os Reis da Sucata S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191147.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88673, 6170, 'Os Reis da Sucata S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191148.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88674, 6170, 'Os Reis da Sucata S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191149.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88675, 6170, 'Os Reis da Sucata S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191150.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88676, 6170, 'Os Reis da Sucata S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191151.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88677, 6170, 'Os Reis da Sucata S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191152.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88678, 6170, 'Os Reis da Sucata S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191153.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88679, 6171, 'Os Reis da Sucata S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191154.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88680, 6171, 'Os Reis da Sucata S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191155.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88681, 6171, 'Os Reis da Sucata S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191156.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88682, 6171, 'Os Reis da Sucata S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191157.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88683, 6171, 'Os Reis da Sucata S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191158.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88684, 6171, 'Os Reis da Sucata S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191159.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88685, 6171, 'Os Reis da Sucata S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191160.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88686, 6171, 'Os Reis da Sucata S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191161.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88687, 6171, 'Os Reis da Sucata S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191162.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88688, 6171, 'Os Reis da Sucata S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191163.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88689, 6171, 'Os Reis da Sucata S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191164.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88690, 6171, 'Os Reis da Sucata S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/191165.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88691, 6172, 'Os Reis da Sucata S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191166.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88692, 6172, 'Os Reis da Sucata S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191167.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88693, 6172, 'Os Reis da Sucata S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191168.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88694, 6172, 'Os Reis da Sucata S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191169.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88695, 6172, 'Os Reis da Sucata S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191170.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88696, 6172, 'Os Reis da Sucata S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191171.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88697, 6172, 'Os Reis da Sucata S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191172.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88698, 6172, 'Os Reis da Sucata S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191173.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88699, 6172, 'Os Reis da Sucata S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191174.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88700, 6172, 'Os Reis da Sucata S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191175.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88701, 6172, 'Os Reis da Sucata S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191176.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88702, 6172, 'Os Reis da Sucata S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/191177.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88703, 6173, 'Os Reis da Sucata S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191178.mp4', 'http://timg.bdta.pro/images/eda77a97fa107080a5d926988368ab58.jpg'),
(88704, 6173, 'Os Reis da Sucata S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191179.mp4', 'http://timg.bdta.pro/images/e6ff2d4505542b43bb19be4650fac091.jpg'),
(88705, 6173, 'Os Reis da Sucata S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191180.mp4', 'http://timg.bdta.pro/images/37e3eaaa17d168e47655745ca4e9a055.jpg'),
(88706, 6173, 'Os Reis da Sucata S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191181.mp4', 'http://timg.bdta.pro/images/aa081c826ee6b81b9a41f5ae06129917.jpg'),
(88707, 6173, 'Os Reis da Sucata S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191182.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88708, 6173, 'Os Reis da Sucata S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191183.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88709, 6173, 'Os Reis da Sucata S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191184.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88710, 6173, 'Os Reis da Sucata S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191185.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88711, 6173, 'Os Reis da Sucata S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191186.mp4', 'http://timg.bdta.pro/images/b6f1345181173681831210d71f1ba364.jpg'),
(88712, 6173, 'Os Reis da Sucata S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191187.mp4', 'http://timg.bdta.pro/images/3c58e9a8509240bb07088307972cea28.jpg'),
(88713, 6173, 'Os Reis da Sucata S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191188.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88714, 6173, 'Os Reis da Sucata S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/191189.mp4', 'http://gstaticontent.com/images/58e12d61f1495c1b1439d066e083ba1a.jpg'),
(88715, 6174, 'Paper Girls S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191132.mp4', 'http://timg.bdta.pro/images/3343482e3b1220a36fab2e94061effcd.jpg'),
(88716, 6174, 'Paper Girls S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191133.mp4', 'http://timg.bdta.pro/images/f6e0287d6ac5bb957bb18820a334e465.jpg'),
(88717, 6174, 'Paper Girls S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191134.mp4', 'http://timg.bdta.pro/images/d23741edce4ad439ea2a60ca44249f92.jpg'),
(88718, 6174, 'Paper Girls S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191135.mp4', 'http://timg.bdta.pro/images/4cc11dd58dfbd8c96ee63c30a3c0bdce.jpg'),
(88719, 6174, 'Paper Girls S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191136.mp4', 'http://timg.bdta.pro/images/3ac70f82587d5e67c4a8f60954e2eff5.jpg'),
(88720, 6174, 'Paper Girls S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191137.mp4', 'http://timg.bdta.pro/images/647dd35aee096139f895643c860d0ef0.jpg'),
(88721, 6174, 'Paper Girls S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191138.mp4', 'http://timg.bdta.pro/images/54162e172e32e77a70447104421648aa.jpg'),
(88722, 6174, 'Paper Girls S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191139.mp4', 'http://timg.bdta.pro/images/20f966ba7ccb3e234f3e524995898d68.jpg'),
(88723, 6175, 'Pinoquio e seus Amigos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191119.mp4', 'http://gstaticontent.com/images/0c64639ffdca67f46cf972c64eb3ebb6.jpg'),
(88724, 6175, 'Pinoquio e seus Amigos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191120.mp4', 'http://gstaticontent.com/images/0c64639ffdca67f46cf972c64eb3ebb6.jpg'),
(88725, 6175, 'Pinoquio e seus Amigos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191121.mp4', 'http://gstaticontent.com/images/0c64639ffdca67f46cf972c64eb3ebb6.jpg'),
(88726, 6175, 'Pinoquio e seus Amigos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191122.mp4', 'http://gstaticontent.com/images/0c64639ffdca67f46cf972c64eb3ebb6.jpg'),
(88727, 6175, 'Pinoquio e seus Amigos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191123.mp4', 'http://gstaticontent.com/images/0c64639ffdca67f46cf972c64eb3ebb6.jpg'),
(88728, 6175, 'Pinoquio e seus Amigos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191124.mp4', 'http://gstaticontent.com/images/0c64639ffdca67f46cf972c64eb3ebb6.jpg'),
(88729, 6175, 'Pinoquio e seus Amigos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191125.mp4', 'http://gstaticontent.com/images/0c64639ffdca67f46cf972c64eb3ebb6.jpg'),
(88730, 6175, 'Pinoquio e seus Amigos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191126.mp4', 'http://gstaticontent.com/images/0c64639ffdca67f46cf972c64eb3ebb6.jpg'),
(88731, 6175, 'Pinoquio e seus Amigos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/191127.mp4', 'http://gstaticontent.com/images/0c64639ffdca67f46cf972c64eb3ebb6.jpg'),
(88732, 6175, 'Pinoquio e seus Amigos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/191128.mp4', 'http://gstaticontent.com/images/0c64639ffdca67f46cf972c64eb3ebb6.jpg'),
(88733, 6175, 'Pinoquio e seus Amigos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/191129.mp4', 'http://gstaticontent.com/images/0c64639ffdca67f46cf972c64eb3ebb6.jpg'),
(88734, 6175, 'Pinoquio e seus Amigos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/191130.mp4', 'http://gstaticontent.com/images/0c64639ffdca67f46cf972c64eb3ebb6.jpg'),
(88735, 6175, 'Pinoquio e seus Amigos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/191131.mp4', 'http://gstaticontent.com/images/0c64639ffdca67f46cf972c64eb3ebb6.jpg'),
(88736, 6176, 'Pretty Little Liars: Um Novo Pecado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195343.mp4', 'http://timg.bdta.pro/images/e3cb594d70cc9544cc73e393897e30cd.jpg'),
(88737, 6176, 'Pretty Little Liars: Um Novo Pecado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195344.mp4', 'http://timg.bdta.pro/images/a56ee61bf5754ebbc3c66bce3d625261.jpg'),
(88738, 6176, 'Pretty Little Liars: Um Novo Pecado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195345.mp4', 'http://timg.bdta.pro/images/42cdd686bbd81f8be4abdde702343b3e.jpg'),
(88739, 6176, 'Pretty Little Liars: Um Novo Pecado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195346.mp4', 'http://timg.bdta.pro/images/8a7bbe96f8c28eff55286979a5ab2421.jpg'),
(88740, 6176, 'Pretty Little Liars: Um Novo Pecado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195347.mp4', 'http://timg.bdta.pro/images/211cadf647e440867971768dda2d7d93.jpg'),
(88741, 6176, 'Pretty Little Liars: Um Novo Pecado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195348.mp4', 'http://timg.bdta.pro/images/d193e337304ecaf1b81f235d6caab425.jpg'),
(88742, 6176, 'Pretty Little Liars: Um Novo Pecado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195349.mp4', 'http://timg.bdta.pro/images/f863eb25c497bb7fec7085296051b856.jpg'),
(88743, 6176, 'Pretty Little Liars: Um Novo Pecado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195350.mp4', 'http://timg.bdta.pro/images/0a3eb3646cc530632620ade7bf8132f5.jpg'),
(88744, 6176, 'Pretty Little Liars: Um Novo Pecado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195351.mp4', 'http://timg.bdta.pro/images/bd441a6fb8e8435448cad46adfe2fc22.jpg'),
(88745, 6176, 'Pretty Little Liars: Um Novo Pecado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195352.mp4', 'http://timg.bdta.pro/images/71a4cf1a61779399ff5ea586098a567f.jpg'),
(88746, 6177, 'Pretty Little Liars: Um Novo Pecado S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/351596.mp4', 'http://gstaticontent.com/images/6e346fe7682f4822852736c9abcd1cca.jpg'),
(88747, 6177, 'Pretty Little Liars: Um Novo Pecado S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/351597.mp4', 'http://gstaticontent.com/images/6e346fe7682f4822852736c9abcd1cca.jpg'),
(88748, 6177, 'Pretty Little Liars: Um Novo Pecado S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/351598.mp4', 'http://gstaticontent.com/images/6e346fe7682f4822852736c9abcd1cca.jpg'),
(88749, 6177, 'Pretty Little Liars: Um Novo Pecado S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/358918.mp4', 'http://gstaticontent.com/images/6e346fe7682f4822852736c9abcd1cca.jpg'),
(88750, 6177, 'Pretty Little Liars: Um Novo Pecado S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/365339.mp4', 'http://gstaticontent.com/images/6e346fe7682f4822852736c9abcd1cca.jpg'),
(88751, 6177, 'Pretty Little Liars: Um Novo Pecado S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/373357.mp4', 'http://gstaticontent.com/images/6e346fe7682f4822852736c9abcd1cca.jpg'),
(88752, 6177, 'Pretty Little Liars: Um Novo Pecado S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/381125.mp4', 'http://gstaticontent.com/images/6e346fe7682f4822852736c9abcd1cca.jpg'),
(88753, 6177, 'Pretty Little Liars: Um Novo Pecado S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/388901.mp4', 'http://gstaticontent.com/images/6e346fe7682f4822852736c9abcd1cca.jpg'),
(88754, 6178, 'Que a Justiça Seja Feita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191113.mp4', 'http://gstaticontent.com/images/093bdd24545f8cc6d63fae001957a49a.jpg'),
(88755, 6178, 'Que a Justiça Seja Feita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191114.mp4', 'http://gstaticontent.com/images/093bdd24545f8cc6d63fae001957a49a.jpg'),
(88756, 6178, 'Que a Justiça Seja Feita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191115.mp4', 'http://gstaticontent.com/images/093bdd24545f8cc6d63fae001957a49a.jpg'),
(88757, 6178, 'Que a Justiça Seja Feita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191116.mp4', 'http://gstaticontent.com/images/093bdd24545f8cc6d63fae001957a49a.jpg'),
(88758, 6178, 'Que a Justiça Seja Feita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191117.mp4', 'http://gstaticontent.com/images/093bdd24545f8cc6d63fae001957a49a.jpg'),
(88759, 6178, 'Que a Justiça Seja Feita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191118.mp4', 'http://gstaticontent.com/images/093bdd24545f8cc6d63fae001957a49a.jpg'),
(88760, 6179, 'Respire! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191107.mp4', 'http://timg.bdta.pro/images/cbb408ce6f33de9580dbb9667628e300.jpg'),
(88761, 6179, 'Respire! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191108.mp4', 'http://timg.bdta.pro/images/beb366e5803449030535d2fe16eee3e3.jpg'),
(88762, 6179, 'Respire! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191109.mp4', 'http://timg.bdta.pro/images/49b8e346961772544269ba252d717210.jpg'),
(88763, 6179, 'Respire! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191110.mp4', 'http://timg.bdta.pro/images/7876c683b82b367fa52de3fc014f9045.jpg'),
(88764, 6179, 'Respire! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191111.mp4', 'http://timg.bdta.pro/images/7c2e8aec0d4770b3e7557d81e56f812b.jpg'),
(88765, 6179, 'Respire! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191112.mp4', 'http://timg.bdta.pro/images/9595b7e3a9522d181a3d875fb3c2adc7.jpg'),
(88766, 6180, 'Superfície S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194547.mp4', 'http://timg.bdta.pro/images/f72599b02dfbc596850d1fd1656f7621.jpg'),
(88767, 6180, 'Superfície S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194548.mp4', 'http://timg.bdta.pro/images/5c65c1387696d3e691ccf5c61ac9a5d5.jpg'),
(88768, 6180, 'Superfície S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194549.mp4', 'http://timg.bdta.pro/images/a0f906ffeac343059080ce4c1c7114f3.jpg'),
(88769, 6180, 'Superfície S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194550.mp4', 'http://timg.bdta.pro/images/7237f79dac8f7353539df2684ad35743.jpg'),
(88770, 6180, 'Superfície S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194551.mp4', 'http://timg.bdta.pro/images/95c8d3e6bef6edfd13489602ad2f0da8.jpg'),
(88771, 6180, 'Superfície S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194552.mp4', 'http://timg.bdta.pro/images/36741fb84fb2e89221240258e2119665.jpg'),
(88772, 6180, 'Superfície S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194553.mp4', 'http://timg.bdta.pro/images/f01ad494f1297bf91323a9902fe5f25a.jpg'),
(88773, 6180, 'Superfície S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194554.mp4', 'http://timg.bdta.pro/images/f297218bd6cac7624fa12066c93fe80a.jpg'),
(88774, 6181, 'Superfície S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/703964.mp4', 'http://gstaticontent.com/images/231211c7d13257a4cfedc6422f2cdbe8.jpg'),
(88775, 6181, 'Superfície S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/713193.mp4', 'http://gstaticontent.com/images/231211c7d13257a4cfedc6422f2cdbe8.jpg'),
(88776, 6181, 'Superfície S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/716852.mp4', 'http://gstaticontent.com/images/231211c7d13257a4cfedc6422f2cdbe8.jpg'),
(88777, 6181, 'Superfície S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/723690.mp4', 'http://gstaticontent.com/images/231211c7d13257a4cfedc6422f2cdbe8.jpg'),
(88778, 6181, 'Superfície S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/730203.mp4', 'http://gstaticontent.com/images/231211c7d13257a4cfedc6422f2cdbe8.jpg'),
(88779, 6181, 'Superfície S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/750159.mp4', 'http://gstaticontent.com/images/231211c7d13257a4cfedc6422f2cdbe8.jpg'),
(88780, 6181, 'Superfície S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/889646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQ037ncngafl8oiH3AnEGHYgEud.jpg'),
(88781, 6181, 'Superfície S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/889647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cLZhsVauAihzRQZPgRr9mSl9mpc.jpg'),
(88782, 6182, 'Uma Nova Mulher S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191099.mp4', 'http://timg.bdta.pro/images/059a35abf2036a69185cc6d9fa33b11a.jpg'),
(88783, 6182, 'Uma Nova Mulher S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191100.mp4', 'http://timg.bdta.pro/images/e5fc3e946764bea39140444fef94f983.jpg'),
(88784, 6182, 'Uma Nova Mulher S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191101.mp4', 'http://timg.bdta.pro/images/7bf2fc44f5a009e77bbe6de25089dfe2.jpg'),
(88785, 6182, 'Uma Nova Mulher S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191102.mp4', 'http://timg.bdta.pro/images/f12c915bab6199da070b5b6779924416.jpg'),
(88786, 6182, 'Uma Nova Mulher S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191103.mp4', 'http://timg.bdta.pro/images/67d45213fae2c227daf56f6c46283655.jpg'),
(88787, 6182, 'Uma Nova Mulher S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191104.mp4', 'http://timg.bdta.pro/images/e607a37dc3b7c6458318cb71339899e0.jpg'),
(88788, 6182, 'Uma Nova Mulher S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191105.mp4', 'http://timg.bdta.pro/images/7bf2fc44f5a009e77bbe6de25089dfe2.jpg'),
(88789, 6182, 'Uma Nova Mulher S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191106.mp4', 'http://timg.bdta.pro/images/d0ffea8cf90bb217e9fb1aff71b9342a.jpg'),
(88790, 6183, 'Uma Nova Mulher S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/406142.mp4', 'http://gstaticontent.com/images/21853124e1a2850e9258161b7a02a600.jpg'),
(88791, 6183, 'Uma Nova Mulher S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/406143.mp4', 'http://gstaticontent.com/images/21853124e1a2850e9258161b7a02a600.jpg'),
(88792, 6183, 'Uma Nova Mulher S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/406144.mp4', 'http://gstaticontent.com/images/21853124e1a2850e9258161b7a02a600.jpg'),
(88793, 6183, 'Uma Nova Mulher S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/406145.mp4', 'http://gstaticontent.com/images/21853124e1a2850e9258161b7a02a600.jpg'),
(88794, 6183, 'Uma Nova Mulher S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/406146.mp4', 'http://gstaticontent.com/images/21853124e1a2850e9258161b7a02a600.jpg'),
(88795, 6183, 'Uma Nova Mulher S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/406147.mp4', 'http://gstaticontent.com/images/21853124e1a2850e9258161b7a02a600.jpg'),
(88796, 6183, 'Uma Nova Mulher S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/406148.mp4', 'http://gstaticontent.com/images/21853124e1a2850e9258161b7a02a600.jpg'),
(88797, 6183, 'Uma Nova Mulher S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/406149.mp4', 'http://gstaticontent.com/images/21853124e1a2850e9258161b7a02a600.jpg'),
(88798, 6184, 'Uncoupled S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/191091.mp4', 'http://timg.bdta.pro/images/4a9b9cb5db5561d9cbbbdee7fc2131c6.jpg'),
(88799, 6184, 'Uncoupled S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/191092.mp4', 'http://timg.bdta.pro/images/bf440b3fa8dc598e64c41364d370c7aa.jpg'),
(88800, 6184, 'Uncoupled S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/191093.mp4', 'http://timg.bdta.pro/images/cf42d023ab676854ee5a5613e9c9a3e7.jpg'),
(88801, 6184, 'Uncoupled S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/191094.mp4', 'http://timg.bdta.pro/images/802909508de54b608a0454a717c0d784.jpg'),
(88802, 6184, 'Uncoupled S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/191095.mp4', 'http://timg.bdta.pro/images/bbc2a58ab575a6d3951b41994b5b355f.jpg'),
(88803, 6184, 'Uncoupled S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/191096.mp4', 'http://timg.bdta.pro/images/5f963e6e616535e3f0970ed7a4dc5606.jpg'),
(88804, 6184, 'Uncoupled S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/191097.mp4', 'http://timg.bdta.pro/images/c207614e4e89ce6126e877d4bf3384b8.jpg'),
(88805, 6184, 'Uncoupled S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/191098.mp4', 'http://timg.bdta.pro/images/2f1acd1c2c5ef564677153e656545c6d.jpg'),
(88806, 6185, 'Oggy e as Baratas Tontas: E Piya! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190608.mp4', 'http://gstaticontent.com/images/e122cadaa7c5f53d360810713b087cca.jpg'),
(88807, 6185, 'Oggy e as Baratas Tontas: E Piya! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190609.mp4', 'http://timg.bdta.pro/images/35e6fb6057bbf57df77e6b50ac7e8e82.jpg'),
(88808, 6185, 'Oggy e as Baratas Tontas: E Piya! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190610.mp4', 'http://timg.bdta.pro/images/cde61748bf57737e98f7344c7ee2b9fa.jpg'),
(88809, 6185, 'Oggy e as Baratas Tontas: E Piya! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190611.mp4', 'http://timg.bdta.pro/images/1331123249dc73a43e34b1869458456d.jpg'),
(88810, 6185, 'Oggy e as Baratas Tontas: E Piya! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190612.mp4', 'http://timg.bdta.pro/images/41513fdfe08e867661e21c5020b64135.jpg'),
(88811, 6185, 'Oggy e as Baratas Tontas: E Piya! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190613.mp4', 'http://timg.bdta.pro/images/b6536c8f77e10c7ef281078f766263b0.jpg'),
(88812, 6185, 'Oggy e as Baratas Tontas: E Piya! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190614.mp4', 'http://timg.bdta.pro/images/2408bd5e1ff012eae882a4ad250ed076.jpg'),
(88813, 6185, 'Oggy e as Baratas Tontas: E Piya! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190615.mp4', 'http://gstaticontent.com/images/e122cadaa7c5f53d360810713b087cca.jpg'),
(88814, 6185, 'Oggy e as Baratas Tontas: E Piya! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190616.mp4', 'http://timg.bdta.pro/images/5dad7b838090039befb4708ecad86be9.jpg'),
(88815, 6185, 'Oggy e as Baratas Tontas: E Piya! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190617.mp4', 'http://timg.bdta.pro/images/7331a41195b0cbfc76df97a9b2d9a765.jpg'),
(88816, 6185, 'Oggy e as Baratas Tontas: E Piya! S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190618.mp4', 'http://timg.bdta.pro/images/de51870e975af3f7f0c2a185d03aec2c.jpg'),
(88817, 6185, 'Oggy e as Baratas Tontas: E Piya! S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190619.mp4', 'http://timg.bdta.pro/images/54b69ff1761411269e7effc5a15f2fa9.jpg'),
(88818, 6185, 'Oggy e as Baratas Tontas: E Piya! S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190620.mp4', 'http://timg.bdta.pro/images/bcc8a7c43d6f173961984d81d26ccdd4.jpg'),
(88819, 6186, 'Rock In Rio – A História S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190603.mp4', 'http://gstaticontent.com/images/cd75675b0fb21248addedc6856b978be.jpg'),
(88820, 6186, 'Rock In Rio – A História S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190604.mp4', 'http://gstaticontent.com/images/cd75675b0fb21248addedc6856b978be.jpg'),
(88821, 6186, 'Rock In Rio – A História S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190605.mp4', 'http://gstaticontent.com/images/cd75675b0fb21248addedc6856b978be.jpg'),
(88822, 6186, 'Rock In Rio – A História S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190606.mp4', 'http://gstaticontent.com/images/cd75675b0fb21248addedc6856b978be.jpg'),
(88823, 6186, 'Rock In Rio – A História S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190607.mp4', 'http://gstaticontent.com/images/cd75675b0fb21248addedc6856b978be.jpg'),
(88824, 6187, 'Um Pesadelo de Casamento S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190591.mp4', 'http://timg.bdta.pro/images/913d6434e33b799ff7f077ab7a23dbaf.jpg'),
(88825, 6187, 'Um Pesadelo de Casamento S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190592.mp4', 'http://timg.bdta.pro/images/2c8e6d854d13b8262edb9c745313a8f5.jpg'),
(88826, 6187, 'Um Pesadelo de Casamento S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190593.mp4', 'http://timg.bdta.pro/images/c047a02f445df4007765b5de39e34c40.jpg'),
(88827, 6187, 'Um Pesadelo de Casamento S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190594.mp4', 'http://timg.bdta.pro/images/5b345fdac4664e595fde01f2962e82b5.jpg'),
(88828, 6187, 'Um Pesadelo de Casamento S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190595.mp4', 'http://timg.bdta.pro/images/c262b3e8f284f4e5725563a6713e7440.jpg'),
(88829, 6187, 'Um Pesadelo de Casamento S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190596.mp4', 'http://timg.bdta.pro/images/3c72d491b2aa403800ca62bbed3df4e0.jpg'),
(88830, 6187, 'Um Pesadelo de Casamento S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190597.mp4', 'http://timg.bdta.pro/images/750e3258152be6214638f629e7eddf45.jpg'),
(88831, 6187, 'Um Pesadelo de Casamento S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190598.mp4', 'http://timg.bdta.pro/images/891e8944bc78e416dff22f994f39fb41.jpg'),
(88832, 6187, 'Um Pesadelo de Casamento S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190599.mp4', 'http://timg.bdta.pro/images/fc55f8718f828ab02b8eff424b83de0c.jpg'),
(88833, 6187, 'Um Pesadelo de Casamento S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190600.mp4', 'http://timg.bdta.pro/images/56a5ce0d6217fc5ff1e61a091f837af1.jpg'),
(88834, 6187, 'Um Pesadelo de Casamento S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190601.mp4', 'http://timg.bdta.pro/images/c0c513b0c164db07e6e40a16364110ec.jpg'),
(88835, 6187, 'Um Pesadelo de Casamento S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190602.mp4', 'http://timg.bdta.pro/images/92108c7137b63b28c11d34add5141285.jpg'),
(88836, 6188, 'Jovem e Gourmet [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190542.mp4', 'http://timg.bdta.pro/images/16d82c0aec1aaa58eabeaa40d3d759e0.jpg'),
(88837, 6188, 'Jovem e Gourmet [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190543.mp4', 'http://timg.bdta.pro/images/ae4a799efdfddc461d36c66d3ceb2f61.jpg'),
(88838, 6188, 'Jovem e Gourmet [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190544.mp4', 'http://timg.bdta.pro/images/b1e8ae96267ad17ebb845317f179812e.jpg'),
(88839, 6188, 'Jovem e Gourmet [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190545.mp4', 'http://timg.bdta.pro/images/1eb6f65c30f10cc7c13793c907bbc64e.jpg'),
(88840, 6188, 'Jovem e Gourmet [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190546.mp4', 'http://timg.bdta.pro/images/e8b673eb87856a1d478b01d295346f6b.jpg'),
(88841, 6188, 'Jovem e Gourmet [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190547.mp4', 'http://timg.bdta.pro/images/907038cdea9e68dd74bb2b45b13e2eaf.jpg'),
(88842, 6188, 'Jovem e Gourmet [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190548.mp4', 'http://timg.bdta.pro/images/14002b0210c943c12af8757ba331ab16.jpg'),
(88843, 6188, 'Jovem e Gourmet [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190549.mp4', 'http://timg.bdta.pro/images/d4d8ded2a37b4bea8ad6c87a792dba5a.jpg'),
(88844, 6188, 'Jovem e Gourmet [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190550.mp4', 'http://timg.bdta.pro/images/66e3afbc848155b9a13c603e706059f9.jpg'),
(88845, 6188, 'Jovem e Gourmet [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190551.mp4', 'http://timg.bdta.pro/images/53279163b85371778fd94ff6c4b545c7.jpg'),
(88846, 6189, 'Jovem e Gourmet [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190552.mp4', 'http://timg.bdta.pro/images/484cb832352175022d888fd5c1048846.jpg'),
(88847, 6189, 'Jovem e Gourmet [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190553.mp4', 'http://timg.bdta.pro/images/a7c7d4b35cb0bc273962bc6db4bf822a.jpg'),
(88848, 6189, 'Jovem e Gourmet [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190554.mp4', 'http://timg.bdta.pro/images/b7e327de2afb459a8aedfed2ee5c104e.jpg'),
(88849, 6189, 'Jovem e Gourmet [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190555.mp4', 'http://timg.bdta.pro/images/875407d9209f62845408f165a1ed2992.jpg'),
(88850, 6189, 'Jovem e Gourmet [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190556.mp4', 'http://timg.bdta.pro/images/92c3648026ac3347ac6fe1a759e49b6b.jpg'),
(88851, 6189, 'Jovem e Gourmet [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190557.mp4', 'http://timg.bdta.pro/images/60e777a0a7f94842c7f8240c408d24d5.jpg'),
(88852, 6189, 'Jovem e Gourmet [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190558.mp4', 'http://timg.bdta.pro/images/5cdb107cd864456ffcbb6c2d6721a73b.jpg'),
(88853, 6189, 'Jovem e Gourmet [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190559.mp4', 'http://timg.bdta.pro/images/580fc9a82774cbacabad3157a2ee52dd.jpg'),
(88854, 6189, 'Jovem e Gourmet [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190560.mp4', 'http://timg.bdta.pro/images/5872d4fcd28ccfa061cd14c763552ae3.jpg'),
(88855, 6189, 'Jovem e Gourmet [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190561.mp4', 'http://timg.bdta.pro/images/34e7352d261f18fb7a146f6dc4cbc513.jpg'),
(88856, 6189, 'Jovem e Gourmet [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/190562.mp4', 'http://timg.bdta.pro/images/d474e6872d12b7c298901f3077118501.jpg'),
(88857, 6189, 'Jovem e Gourmet [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/190563.mp4', 'http://timg.bdta.pro/images/c7d015cdc04c003ca96a2a1d36005c76.jpg'),
(88858, 6189, 'Jovem e Gourmet [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/190564.mp4', 'http://timg.bdta.pro/images/c8e572e6ee2acf4e4748c96cdc151d84.jpg'),
(88859, 6189, 'Jovem e Gourmet [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/190565.mp4', 'http://timg.bdta.pro/images/93317e6976edf2067326a85c55ac2180.jpg'),
(88860, 6189, 'Jovem e Gourmet [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/190566.mp4', 'http://timg.bdta.pro/images/10f37c156f40256e78f2bc42c596796e.jpg'),
(88861, 6189, 'Jovem e Gourmet [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/190567.mp4', 'http://timg.bdta.pro/images/0477be902fde1825ee95bb3251c13721.jpg'),
(88862, 6189, 'Jovem e Gourmet [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/190568.mp4', 'http://timg.bdta.pro/images/c7c91e79c3b6634cb13e23b4fa86cec1.jpg'),
(88863, 6189, 'Jovem e Gourmet [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/190569.mp4', 'http://timg.bdta.pro/images/25d9b7b9b900ab88b9122b3432c15671.jpg'),
(88864, 6189, 'Jovem e Gourmet [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/190570.mp4', 'http://timg.bdta.pro/images/b24a6db4e98b07e81ba1e0a71b758e29.jpg'),
(88865, 6189, 'Jovem e Gourmet [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/190571.mp4', 'http://timg.bdta.pro/images/8b949586f1d0a3ef3ffafdb90e97ded2.jpg'),
(88866, 6189, 'Jovem e Gourmet [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/190572.mp4', 'http://timg.bdta.pro/images/a099c92161a69763d5f4dbc2efbb90a7.jpg'),
(88867, 6190, 'Becoming Elizabeth S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190377.mp4', 'http://timg.bdta.pro/images/892f75458776395ed5778169b1924ce6.jpg'),
(88868, 6190, 'Becoming Elizabeth S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190378.mp4', 'http://timg.bdta.pro/images/660b0c10362d3e9d477a1dee9dd8cbe9.jpg'),
(88869, 6190, 'Becoming Elizabeth S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190379.mp4', 'http://timg.bdta.pro/images/a4d4eec36e20b70a6b8a5515e6c19ef8.jpg'),
(88870, 6190, 'Becoming Elizabeth S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190380.mp4', 'http://timg.bdta.pro/images/17d653b115ee84797a93e3ade54c0dbc.jpg'),
(88871, 6190, 'Becoming Elizabeth S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190381.mp4', 'http://timg.bdta.pro/images/0dca342bb103d5f08438e0a98997d217.jpg'),
(88872, 6190, 'Becoming Elizabeth S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190382.mp4', 'http://timg.bdta.pro/images/4f451d035de758c2022eebf165f57fad.jpg'),
(88873, 6190, 'Becoming Elizabeth S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190383.mp4', 'http://timg.bdta.pro/images/7a8ba132794fffb20212b8286ce397a4.jpg'),
(88874, 6190, 'Becoming Elizabeth S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190384.mp4', 'http://timg.bdta.pro/images/7d8bb516075b98021c5e1c465f37b996.jpg'),
(88875, 6191, 'Fortuna S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195407.mp4', 'http://timg.bdta.pro/images/7bc7750c61cecc12e6d62d154a78a255.jpg'),
(88876, 6191, 'Fortuna S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195408.mp4', 'http://timg.bdta.pro/images/01ce8d334169f7daeae1be4b10aa354b.jpg'),
(88877, 6191, 'Fortuna S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195409.mp4', 'http://timg.bdta.pro/images/a770eb56f53e834b4e272a7d92fa8254.jpg'),
(88878, 6191, 'Fortuna S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195410.mp4', 'http://timg.bdta.pro/images/21ea719e58583ac9f8311ac751f46380.jpg'),
(88879, 6191, 'Fortuna S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195411.mp4', 'http://timg.bdta.pro/images/0dbcad42b9ab56fc099b84b050eee1e4.jpg'),
(88880, 6191, 'Fortuna S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195412.mp4', 'http://timg.bdta.pro/images/50dfc0332e9b291ba1f653db45bb15b7.jpg'),
(88881, 6191, 'Fortuna S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195413.mp4', 'http://timg.bdta.pro/images/a272a18e7e15f050c460162de34f530f.jpg'),
(88882, 6191, 'Fortuna S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195414.mp4', 'http://timg.bdta.pro/images/652be2fedffa9f2c2fc235cbc161b878.jpg'),
(88883, 6191, 'Fortuna S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195415.mp4', 'http://timg.bdta.pro/images/d93b8bf4e9d46a2777326dc174ec549e.jpg'),
(88884, 6191, 'Fortuna S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195416.mp4', 'http://timg.bdta.pro/images/1904cf7308fc8d2208c7a7e4588957e9.jpg'),
(88885, 6192, 'Fortuna S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/317724.mp4', 'http://gstaticontent.com/images/3df2dde799870cdb12e8f7004423f98e.jpg'),
(88886, 6192, 'Fortuna S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/317725.mp4', 'http://gstaticontent.com/images/3df2dde799870cdb12e8f7004423f98e.jpg'),
(88887, 6192, 'Fortuna S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/323998.mp4', 'http://gstaticontent.com/images/3df2dde799870cdb12e8f7004423f98e.jpg'),
(88888, 6192, 'Fortuna S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/327868.mp4', 'http://gstaticontent.com/images/3df2dde799870cdb12e8f7004423f98e.jpg'),
(88889, 6192, 'Fortuna S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/332751.mp4', 'http://gstaticontent.com/images/3df2dde799870cdb12e8f7004423f98e.jpg'),
(88890, 6192, 'Fortuna S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/341059.mp4', 'http://gstaticontent.com/images/3df2dde799870cdb12e8f7004423f98e.jpg'),
(88891, 6192, 'Fortuna S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/352249.mp4', 'http://gstaticontent.com/images/3df2dde799870cdb12e8f7004423f98e.jpg'),
(88892, 6192, 'Fortuna S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/352250.mp4', 'http://gstaticontent.com/images/3df2dde799870cdb12e8f7004423f98e.jpg'),
(88893, 6192, 'Fortuna S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/359666.mp4', 'http://gstaticontent.com/images/3df2dde799870cdb12e8f7004423f98e.jpg'),
(88894, 6192, 'Fortuna S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/368425.mp4', 'http://gstaticontent.com/images/3df2dde799870cdb12e8f7004423f98e.jpg'),
(88895, 6193, 'Fortuna S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/889634.mp4', 'http://gstaticontent.com/images/3df2dde799870cdb12e8f7004423f98e.jpg'),
(88896, 6193, 'Fortuna S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/889635.mp4', 'http://gstaticontent.com/images/3df2dde799870cdb12e8f7004423f98e.jpg'),
(88897, 6193, 'Fortuna S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/890691.mp4', 'http://gstaticontent.com/images/3df2dde799870cdb12e8f7004423f98e.jpg'),
(88898, 6193, 'Fortuna S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/890692.mp4', 'http://gstaticontent.com/images/3df2dde799870cdb12e8f7004423f98e.jpg'),
(88899, 6193, 'Fortuna S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/891876.mp4', 'http://gstaticontent.com/images/3df2dde799870cdb12e8f7004423f98e.jpg'),
(88900, 6193, 'Fortuna S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/892462.mp4', 'http://gstaticontent.com/images/3df2dde799870cdb12e8f7004423f98e.jpg'),
(88901, 6193, 'Fortuna S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/893149.mp4', 'http://gstaticontent.com/images/3df2dde799870cdb12e8f7004423f98e.jpg'),
(88902, 6193, 'Fortuna S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/893472.mp4', 'http://gstaticontent.com/images/3df2dde799870cdb12e8f7004423f98e.jpg'),
(88903, 6193, 'Fortuna S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/894222.mp4', 'http://gstaticontent.com/images/3df2dde799870cdb12e8f7004423f98e.jpg'),
(88904, 6193, 'Fortuna S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/895891.mp4', 'http://gstaticontent.com/images/3df2dde799870cdb12e8f7004423f98e.jpg'),
(88905, 6194, 'Monsterland S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190369.mp4', 'http://timg.bdta.pro/images/64d8c1aecb129c6d64e00d9eface8652.jpg'),
(88906, 6194, 'Monsterland S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190370.mp4', 'http://timg.bdta.pro/images/b7da7ce63c43ff2aa587205f2102f50f.jpg'),
(88907, 6194, 'Monsterland S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190371.mp4', 'http://timg.bdta.pro/images/a4252dee8ac6211ba27f0a33ed460775.jpg'),
(88908, 6194, 'Monsterland S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190372.mp4', 'http://timg.bdta.pro/images/c2fe4c703b3ff026f611968f2b037077.jpg'),
(88909, 6194, 'Monsterland S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190373.mp4', 'http://timg.bdta.pro/images/e3404dda3bca3dc33b8479571083407b.jpg'),
(88910, 6194, 'Monsterland S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190374.mp4', 'http://timg.bdta.pro/images/02497adda940b6e9de6382c872bb5c08.jpg'),
(88911, 6194, 'Monsterland S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190375.mp4', 'http://timg.bdta.pro/images/b3477df1f76bafada7da02fc4eea13b3.jpg'),
(88912, 6194, 'Monsterland S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190376.mp4', 'http://timg.bdta.pro/images/c3b678d8d29fb7cefd8433e90be01ce0.jpg'),
(88913, 6195, 'Muppet Show S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203862.mp4', 'http://timg.bdta.pro/images/e25cc06fe6835f27e63474d2865e9ef1.jpg'),
(88914, 6195, 'Muppet Show S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203863.mp4', 'http://timg.bdta.pro/images/e1a20e81cbacbbbe352680abc35421fc.jpg'),
(88915, 6195, 'Muppet Show S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203864.mp4', 'http://timg.bdta.pro/images/94632612c0b0f863a7cad7f30fb39bb3.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(88916, 6195, 'Muppet Show S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203865.mp4', 'http://timg.bdta.pro/images/bb84ea30c5c2edb19eb962b498e2cf25.jpg'),
(88917, 6195, 'Muppet Show S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203866.mp4', 'http://timg.bdta.pro/images/bd8367c3f014fd10e65d68865f7d54bd.jpg'),
(88918, 6195, 'Muppet Show S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203867.mp4', 'http://timg.bdta.pro/images/5543c22b4b9d417b925220a110055cb8.jpg'),
(88919, 6195, 'Muppet Show S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203868.mp4', 'http://timg.bdta.pro/images/5d6c9c4286a203bca8072587b975826c.jpg'),
(88920, 6195, 'Muppet Show S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203869.mp4', 'http://timg.bdta.pro/images/15eb616fe74f3414024b87c1e46c9b57.jpg'),
(88921, 6195, 'Muppet Show S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203870.mp4', 'http://timg.bdta.pro/images/24965c7fdc9a3de3c303e33687293674.jpg'),
(88922, 6195, 'Muppet Show S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203871.mp4', 'http://timg.bdta.pro/images/c87812333f013795bfce4390d05d2371.jpg'),
(88923, 6195, 'Muppet Show S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203872.mp4', 'http://timg.bdta.pro/images/924144bc18fe46bea81ea5db9fe965f2.jpg'),
(88924, 6195, 'Muppet Show S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203873.mp4', 'http://timg.bdta.pro/images/fc8430e144ab11a97d927c22b73ce438.jpg'),
(88925, 6195, 'Muppet Show S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203874.mp4', 'http://timg.bdta.pro/images/38218e479c1c00e94ba00098e30ed00e.jpg'),
(88926, 6195, 'Muppet Show S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/203875.mp4', 'http://timg.bdta.pro/images/9d39587961680cb9d4dfc0d13883a605.jpg'),
(88927, 6195, 'Muppet Show S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/203876.mp4', 'http://timg.bdta.pro/images/669a6660d2ccea5017eab58cf12bccf1.jpg'),
(88928, 6195, 'Muppet Show S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/203877.mp4', 'http://timg.bdta.pro/images/497f67a4cffb4413684046093e025c69.jpg'),
(88929, 6195, 'Muppet Show S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/203878.mp4', 'http://timg.bdta.pro/images/e110b2593df1743ec9ab173f699e6b87.jpg'),
(88930, 6195, 'Muppet Show S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/203879.mp4', 'http://timg.bdta.pro/images/18c65031a493f2c9fd792547c9d8cce3.jpg'),
(88931, 6195, 'Muppet Show S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/203880.mp4', 'http://timg.bdta.pro/images/3de087c1f129f5c915527602e12ed658.jpg'),
(88932, 6195, 'Muppet Show S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/203881.mp4', 'http://timg.bdta.pro/images/d9663d5967ff8f9dcf5fe32e6970bb4b.jpg'),
(88933, 6195, 'Muppet Show S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/203882.mp4', 'http://timg.bdta.pro/images/b42d63bb2e4988a50381aa32af2110bb.jpg'),
(88934, 6195, 'Muppet Show S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/203883.mp4', 'http://timg.bdta.pro/images/ea5bd8adea21e7742603c29ad74752ea.jpg'),
(88935, 6195, 'Muppet Show S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/203884.mp4', 'http://timg.bdta.pro/images/a4410a53a6831afe32d875dfb8a99ef6.jpg'),
(88936, 6195, 'Muppet Show S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/203885.mp4', 'http://timg.bdta.pro/images/9350a780672ef8c9a1321f6f296f5b1b.jpg'),
(88937, 6196, 'Muppet Show S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203886.mp4', 'http://timg.bdta.pro/images/a8894642c5bd4a581a768463d711451a.jpg'),
(88938, 6196, 'Muppet Show S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203887.mp4', 'http://timg.bdta.pro/images/c323c30ae431cdb19476abf0c9c2df22.jpg'),
(88939, 6196, 'Muppet Show S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203888.mp4', 'http://timg.bdta.pro/images/8fc9117c280316335ba9d3df27204499.jpg'),
(88940, 6196, 'Muppet Show S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203889.mp4', 'http://timg.bdta.pro/images/737f6da2cadb1307c59eb119916cd718.jpg'),
(88941, 6196, 'Muppet Show S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203890.mp4', 'http://timg.bdta.pro/images/684a7cc7a695b88386e4b8465c60aae0.jpg'),
(88942, 6196, 'Muppet Show S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203891.mp4', 'http://timg.bdta.pro/images/7c45139a6f692c5d59450d86af513482.jpg'),
(88943, 6196, 'Muppet Show S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203892.mp4', 'http://timg.bdta.pro/images/12c2604313b1f9a4d970c1872f8518d5.jpg'),
(88944, 6196, 'Muppet Show S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203893.mp4', 'http://timg.bdta.pro/images/521b823c9e470914c3c23ae9dfbf53c9.jpg'),
(88945, 6196, 'Muppet Show S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203894.mp4', 'http://timg.bdta.pro/images/3c3d1007e045eb7e6368b5c7d6abb9ff.jpg'),
(88946, 6196, 'Muppet Show S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203895.mp4', 'http://timg.bdta.pro/images/4127bd32dc0e44d1f6e0515bb082247b.jpg'),
(88947, 6196, 'Muppet Show S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203896.mp4', 'http://timg.bdta.pro/images/a010f01d48a273864c700fae33523155.jpg'),
(88948, 6196, 'Muppet Show S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203897.mp4', 'http://timg.bdta.pro/images/4a2f85ebbb6b18e41897543213b442fe.jpg'),
(88949, 6196, 'Muppet Show S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203898.mp4', 'http://timg.bdta.pro/images/511bb04ce6e9409df4942ba6c3027f04.jpg'),
(88950, 6196, 'Muppet Show S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/203899.mp4', 'http://timg.bdta.pro/images/fe27d5d725e8880c589278ee0f124b5b.jpg'),
(88951, 6196, 'Muppet Show S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/203900.mp4', 'http://timg.bdta.pro/images/880df1b923a0a6d4c5f77854ba2ecd56.jpg'),
(88952, 6196, 'Muppet Show S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/203901.mp4', 'http://timg.bdta.pro/images/ed8814ac2715f8ba69f810ee500d0b57.jpg'),
(88953, 6196, 'Muppet Show S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/203902.mp4', 'http://timg.bdta.pro/images/d18243e5abdebb36a016a836ba4e759b.jpg'),
(88954, 6196, 'Muppet Show S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/203903.mp4', 'http://timg.bdta.pro/images/946c549518f5b1940f277aac3ab30668.jpg'),
(88955, 6196, 'Muppet Show S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/203904.mp4', 'http://timg.bdta.pro/images/abf757c5b5847601d859e2f6197a4850.jpg'),
(88956, 6196, 'Muppet Show S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/203905.mp4', 'http://timg.bdta.pro/images/d87a0e16c87219da9a773b9edf899eff.jpg'),
(88957, 6196, 'Muppet Show S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/203906.mp4', 'http://timg.bdta.pro/images/0f9ca657feb7667bebea092763b5e03d.jpg'),
(88958, 6196, 'Muppet Show S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/203907.mp4', 'http://timg.bdta.pro/images/40f299c2055e35e5ccc2c65738d367b4.jpg'),
(88959, 6196, 'Muppet Show S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/203908.mp4', 'http://timg.bdta.pro/images/672b2a8c844aef618a2e348d2c51666c.jpg'),
(88960, 6196, 'Muppet Show S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/203909.mp4', 'http://timg.bdta.pro/images/ab6a2372ad40845d7b0a44d66ca3284b.jpg'),
(88961, 6197, 'Muppet Show S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203910.mp4', 'http://timg.bdta.pro/images/61205415866ebe29a8b85d1ca32e35bc.jpg'),
(88962, 6197, 'Muppet Show S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203911.mp4', 'http://timg.bdta.pro/images/ab64cb132917da2eb122b7d0a5610311.jpg'),
(88963, 6197, 'Muppet Show S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203912.mp4', 'http://timg.bdta.pro/images/ed14856d0d1dde8334f310a27f37666c.jpg'),
(88964, 6197, 'Muppet Show S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203913.mp4', 'http://timg.bdta.pro/images/96ec9f9a482c1fdfed793db039eba47d.jpg'),
(88965, 6197, 'Muppet Show S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203914.mp4', 'http://timg.bdta.pro/images/0db76c575d238c78a027f0f6ff90ea9d.jpg'),
(88966, 6197, 'Muppet Show S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203915.mp4', 'http://timg.bdta.pro/images/b469dcad44cd7557a6a2f0f5f2a0ff23.jpg'),
(88967, 6197, 'Muppet Show S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203916.mp4', 'http://timg.bdta.pro/images/dc7cdca95b823baf017588dca67f1cc8.jpg'),
(88968, 6197, 'Muppet Show S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203917.mp4', 'http://timg.bdta.pro/images/11a5b77198292d3b6eddaab7275db0b5.jpg'),
(88969, 6197, 'Muppet Show S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203918.mp4', 'http://timg.bdta.pro/images/37ef68c8475abfc4d97e7996c6e021a0.jpg'),
(88970, 6197, 'Muppet Show S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203919.mp4', 'http://timg.bdta.pro/images/6982d410c8479f2f746ada0780d98b42.jpg'),
(88971, 6197, 'Muppet Show S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203920.mp4', 'http://timg.bdta.pro/images/3c46283f99e7d95c5cf84592ea29c378.jpg'),
(88972, 6197, 'Muppet Show S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203921.mp4', 'http://timg.bdta.pro/images/7c82be0e6f1a614aed690214f0ab9dfd.jpg'),
(88973, 6197, 'Muppet Show S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203922.mp4', 'http://timg.bdta.pro/images/f064a0264f10e18e79e787af4f315ccd.jpg'),
(88974, 6197, 'Muppet Show S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/203923.mp4', 'http://timg.bdta.pro/images/bf7a91557666eefd6ee46e4da024d911.jpg'),
(88975, 6197, 'Muppet Show S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/203924.mp4', 'http://timg.bdta.pro/images/6536f873b9ed12be4e68426b4e1d7475.jpg'),
(88976, 6197, 'Muppet Show S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/203925.mp4', 'http://timg.bdta.pro/images/14b8ec259771bb50ab08372205ae708b.jpg'),
(88977, 6197, 'Muppet Show S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/203926.mp4', 'http://timg.bdta.pro/images/cb7e09ad925ca1b8102407399cd5add8.jpg'),
(88978, 6197, 'Muppet Show S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/203927.mp4', 'http://timg.bdta.pro/images/89a6143e717cd7266116d0a234afc8a9.jpg'),
(88979, 6197, 'Muppet Show S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/203928.mp4', 'http://gstaticontent.com/images/4183cf11a906784fd2bd5d75fc284dda.jpg'),
(88980, 6197, 'Muppet Show S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/203929.mp4', 'http://gstaticontent.com/images/4183cf11a906784fd2bd5d75fc284dda.jpg'),
(88981, 6197, 'Muppet Show S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/203930.mp4', 'http://gstaticontent.com/images/4183cf11a906784fd2bd5d75fc284dda.jpg'),
(88982, 6197, 'Muppet Show S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/203931.mp4', 'http://gstaticontent.com/images/4183cf11a906784fd2bd5d75fc284dda.jpg'),
(88983, 6197, 'Muppet Show S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/203932.mp4', 'http://gstaticontent.com/images/4183cf11a906784fd2bd5d75fc284dda.jpg'),
(88984, 6197, 'Muppet Show S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/203933.mp4', 'http://gstaticontent.com/images/4183cf11a906784fd2bd5d75fc284dda.jpg'),
(88985, 6198, 'Muppet Show S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203934.mp4', 'http://timg.bdta.pro/images/0e2b243d81ad9166cbd84a8b0928c825.jpg'),
(88986, 6198, 'Muppet Show S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203935.mp4', 'http://timg.bdta.pro/images/1aaa8f363877214dd8ebdbd873aea09d.jpg'),
(88987, 6198, 'Muppet Show S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203936.mp4', 'http://timg.bdta.pro/images/558174a7380f0fca9105463a2985d5ad.jpg'),
(88988, 6198, 'Muppet Show S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203937.mp4', 'http://timg.bdta.pro/images/7ccb0ff7d9a105efb1f209b116051a5a.jpg'),
(88989, 6198, 'Muppet Show S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203938.mp4', 'http://timg.bdta.pro/images/4677e1cb4e9f08f593c4169d48fe8aec.jpg'),
(88990, 6198, 'Muppet Show S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203939.mp4', 'http://timg.bdta.pro/images/ff5959aeabd4699bc48f0412f612d9fd.jpg'),
(88991, 6198, 'Muppet Show S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203940.mp4', 'http://timg.bdta.pro/images/bfce6d7539992e58a3eb3759276e6c54.jpg'),
(88992, 6198, 'Muppet Show S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203941.mp4', 'http://timg.bdta.pro/images/5433d0a39357f49b796af2652b15262d.jpg'),
(88993, 6198, 'Muppet Show S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203942.mp4', 'http://timg.bdta.pro/images/f06a159f8be923c914e21bcda8883294.jpg'),
(88994, 6198, 'Muppet Show S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203943.mp4', 'http://timg.bdta.pro/images/5183b02efd9a399981ed38f8dbfe9614.jpg'),
(88995, 6198, 'Muppet Show S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203944.mp4', 'http://timg.bdta.pro/images/c23ebec9d690b0a307b49b5e87381cdb.jpg'),
(88996, 6198, 'Muppet Show S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203945.mp4', 'http://timg.bdta.pro/images/7ed28877977991b30192848165d0432b.jpg'),
(88997, 6198, 'Muppet Show S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203946.mp4', 'http://timg.bdta.pro/images/cd6a61e3d968f0a63399d23db8d27b4e.jpg'),
(88998, 6198, 'Muppet Show S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/203947.mp4', 'http://timg.bdta.pro/images/7b6f4ace8d45f36169d72e7d294f3df3.jpg'),
(88999, 6198, 'Muppet Show S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/203948.mp4', 'http://timg.bdta.pro/images/dda74443e41e9ef3e3502e0ea9b8001d.jpg'),
(89000, 6198, 'Muppet Show S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/203949.mp4', 'http://timg.bdta.pro/images/d6aecd12287896b480ddc63eba75ddc0.jpg'),
(89001, 6198, 'Muppet Show S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/203950.mp4', 'http://timg.bdta.pro/images/1e02cbe1ed09314e7459c35faa270923.jpg'),
(89002, 6198, 'Muppet Show S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/203951.mp4', 'http://timg.bdta.pro/images/39a8f06411a92318f9fabe76055c8439.jpg'),
(89003, 6198, 'Muppet Show S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/203952.mp4', 'http://timg.bdta.pro/images/d7ed94fff006974e3b1f4c5b291129a0.jpg'),
(89004, 6198, 'Muppet Show S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/203953.mp4', 'http://timg.bdta.pro/images/2bc9bb69fc0cc3fdec5125d43483a3a6.jpg'),
(89005, 6198, 'Muppet Show S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/203954.mp4', 'http://timg.bdta.pro/images/9e19c01680b98951fa39d5bd7980fe5c.jpg'),
(89006, 6198, 'Muppet Show S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/203955.mp4', 'http://timg.bdta.pro/images/1beeef471883ffa8434c6e4a5eb7f906.jpg'),
(89007, 6198, 'Muppet Show S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/203956.mp4', 'http://timg.bdta.pro/images/81dbb09343cee53b4724113fa42dc13a.jpg'),
(89008, 6198, 'Muppet Show S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/203957.mp4', 'http://timg.bdta.pro/images/f65463b0c032370301f7348f6254e84f.jpg'),
(89009, 6199, 'Muppet Show S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wkNkj0toZ5wKJae9ZuYIAqla2mG.jpg'),
(89010, 6199, 'Muppet Show S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2hbQGUDiYTQI5qua37rtzrJIFDF.jpg'),
(89011, 6199, 'Muppet Show S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLjszskI3ORvfreRKsYvq8qQS4o.jpg'),
(89012, 6199, 'Muppet Show S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ojU0Gwu0TtgXaZciE8BFRmrxACG.jpg'),
(89013, 6199, 'Muppet Show S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uGPz2a1Yjf5f6S16gP985UBx9ax.jpg'),
(89014, 6199, 'Muppet Show S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8T3PLBynL65hnVMlP2oACAAm7j8.jpg'),
(89015, 6199, 'Muppet Show S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nC7xoeE20UbQh27tyrqWhF7sMpD.jpg'),
(89016, 6199, 'Muppet Show S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/85Ebc912pjl8xc0YuNWTaM1qBbO.jpg'),
(89017, 6199, 'Muppet Show S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7A2e9wTYzTQLKmrbrziGSz3ZBGW.jpg'),
(89018, 6199, 'Muppet Show S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3t5addtR0rFGT3ZJD5sjPKeGZgt.jpg'),
(89019, 6199, 'Muppet Show S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZR8TZRYtk1Cur3rQP6s72zratB.jpg'),
(89020, 6199, 'Muppet Show S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2aWvCkprnRxfhJ07Q0q2eaKfJef.jpg'),
(89021, 6199, 'Muppet Show S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h9lRm9q0h1MZLs3TnSdL5cwZ2IA.jpg'),
(89022, 6199, 'Muppet Show S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/203971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fvOxr7dRstdyjDIytXpjde7kyd8.jpg'),
(89023, 6199, 'Muppet Show S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/203972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lOSVZLamcpNtRWReaChxAavZuoz.jpg'),
(89024, 6199, 'Muppet Show S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/203973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lOIuCbnJBDfFymsTTVgH1tWlQSl.jpg'),
(89025, 6199, 'Muppet Show S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/203974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lRV0xXV342nkHHhY24wnFsC6dhK.jpg'),
(89026, 6199, 'Muppet Show S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/203975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iDFFWy79q9vBMqRHmPVEgx6d9mF.jpg'),
(89027, 6199, 'Muppet Show S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/203976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ydEKFK5AkZNiwERX1uUNshjgBCD.jpg'),
(89028, 6199, 'Muppet Show S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/203977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vO2z1u2I6NBDMUXwa6QkwnBzm0J.jpg'),
(89029, 6199, 'Muppet Show S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/203978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ygGAAhp6dYN0ogRGCWtztPFU9ai.jpg'),
(89030, 6199, 'Muppet Show S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/203979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mhu0xlNII8ovVnbZ5Ylkkl7OUYH.jpg'),
(89031, 6200, 'Os Grandiosos Irmãos Robôs S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190359.mp4', 'http://timg.bdta.pro/images/3d51140dc10bb9c542c3c77e4c793116.jpg'),
(89032, 6200, 'Os Grandiosos Irmãos Robôs S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190360.mp4', 'http://timg.bdta.pro/images/508b238d7bc3de4ab8990602c2f1ee84.jpg'),
(89033, 6200, 'Os Grandiosos Irmãos Robôs S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190361.mp4', 'http://timg.bdta.pro/images/ca6f19c3b3336839ab6fa1fa0bb48872.jpg'),
(89034, 6200, 'Os Grandiosos Irmãos Robôs S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190362.mp4', 'http://timg.bdta.pro/images/5b667070df3a2263579c6c75a3911232.jpg'),
(89035, 6200, 'Os Grandiosos Irmãos Robôs S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190363.mp4', 'http://timg.bdta.pro/images/6460366e009fafefed377cc3a0cef221.jpg'),
(89036, 6200, 'Os Grandiosos Irmãos Robôs S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190364.mp4', 'http://timg.bdta.pro/images/354db52cf076b325b499807cd7674c3d.jpg'),
(89037, 6200, 'Os Grandiosos Irmãos Robôs S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190365.mp4', 'http://timg.bdta.pro/images/3bb8407c82f11b1ee8d71ca0ee382a5a.jpg'),
(89038, 6200, 'Os Grandiosos Irmãos Robôs S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190366.mp4', 'http://timg.bdta.pro/images/9534c5e1baf2d5c5bb8035d5d1866404.jpg'),
(89039, 6200, 'Os Grandiosos Irmãos Robôs S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/190367.mp4', 'http://timg.bdta.pro/images/28303d82400448b0e323e8e3ef887884.jpg'),
(89040, 6200, 'Os Grandiosos Irmãos Robôs S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/190368.mp4', 'http://timg.bdta.pro/images/8dedf7131663f2a4029a227da1def8e3.jpg'),
(89041, 6201, 'The Sandman S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195332.mp4', 'http://timg.bdta.pro/images/33e9aa121970c8a8c43094c7b90bae4f.jpg'),
(89042, 6201, 'The Sandman S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195333.mp4', 'http://timg.bdta.pro/images/99977654520c674bd4de6a80a558ab9d.jpg'),
(89043, 6201, 'The Sandman S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195334.mp4', 'http://timg.bdta.pro/images/adc89db2bee317bc989b45a51095017c.jpg'),
(89044, 6201, 'The Sandman S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195335.mp4', 'http://timg.bdta.pro/images/a1abede4c933c6ded819645e868baaac.jpg'),
(89045, 6201, 'The Sandman S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195336.mp4', 'http://timg.bdta.pro/images/56087a8f8784aab9e0dbf8d72599732e.jpg'),
(89046, 6201, 'The Sandman S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195337.mp4', 'http://timg.bdta.pro/images/5ca0382b7b48108d83229e474d017f68.jpg'),
(89047, 6201, 'The Sandman S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195338.mp4', 'http://timg.bdta.pro/images/38bb2a6058db844e055bd393f64eccdf.jpg'),
(89048, 6201, 'The Sandman S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195339.mp4', 'http://timg.bdta.pro/images/ef47dd34c7457cdadc223b029a0ef376.jpg'),
(89049, 6201, 'The Sandman S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195340.mp4', 'http://timg.bdta.pro/images/746551bb146ad7c0afb5cb9fba7c1b24.jpg'),
(89050, 6201, 'The Sandman S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195341.mp4', 'http://timg.bdta.pro/images/668e0644020e1d772449bdea2feae6fe.jpg'),
(89051, 6201, 'The Sandman S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/195342.mp4', 'http://timg.bdta.pro/images/c5fd96d106fcbcab76c4c2f573e95029.jpg'),
(89052, 6202, 'The Sandman S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/855545.mp4', 'http://gstaticontent.com/images/98fa4d7232da0cda58e3caa42bb47d8e.jpg'),
(89053, 6202, 'The Sandman S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/855546.mp4', 'http://gstaticontent.com/images/98fa4d7232da0cda58e3caa42bb47d8e.jpg'),
(89054, 6202, 'The Sandman S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/855547.mp4', 'http://gstaticontent.com/images/98fa4d7232da0cda58e3caa42bb47d8e.jpg'),
(89055, 6202, 'The Sandman S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/855548.mp4', 'http://gstaticontent.com/images/98fa4d7232da0cda58e3caa42bb47d8e.jpg'),
(89056, 6202, 'The Sandman S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/855549.mp4', 'http://gstaticontent.com/images/98fa4d7232da0cda58e3caa42bb47d8e.jpg'),
(89057, 6202, 'The Sandman S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/855550.mp4', 'http://gstaticontent.com/images/98fa4d7232da0cda58e3caa42bb47d8e.jpg'),
(89058, 6202, 'The Sandman S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/873447.mp4', 'http://gstaticontent.com/images/98fa4d7232da0cda58e3caa42bb47d8e.jpg'),
(89059, 6202, 'The Sandman S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/873448.mp4', 'http://gstaticontent.com/images/98fa4d7232da0cda58e3caa42bb47d8e.jpg'),
(89060, 6202, 'The Sandman S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/873449.mp4', 'http://gstaticontent.com/images/98fa4d7232da0cda58e3caa42bb47d8e.jpg'),
(89061, 6202, 'The Sandman S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/873450.mp4', 'http://gstaticontent.com/images/98fa4d7232da0cda58e3caa42bb47d8e.jpg'),
(89062, 6202, 'The Sandman S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/873451.mp4', 'http://gstaticontent.com/images/98fa4d7232da0cda58e3caa42bb47d8e.jpg'),
(89063, 6202, 'The Sandman S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/879404.mp4', 'http://gstaticontent.com/images/98fa4d7232da0cda58e3caa42bb47d8e.jpg'),
(89064, 6203, 'Valendo Ouro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/190351.mp4', 'http://gstaticontent.com/images/1113f0d888c4d72cc370797da967ae90.jpg'),
(89065, 6203, 'Valendo Ouro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/190352.mp4', 'http://gstaticontent.com/images/1113f0d888c4d72cc370797da967ae90.jpg'),
(89066, 6203, 'Valendo Ouro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/190353.mp4', 'http://gstaticontent.com/images/1113f0d888c4d72cc370797da967ae90.jpg'),
(89067, 6203, 'Valendo Ouro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/190354.mp4', 'http://gstaticontent.com/images/1113f0d888c4d72cc370797da967ae90.jpg'),
(89068, 6203, 'Valendo Ouro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/190355.mp4', 'http://gstaticontent.com/images/1113f0d888c4d72cc370797da967ae90.jpg'),
(89069, 6203, 'Valendo Ouro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/190356.mp4', 'http://gstaticontent.com/images/1113f0d888c4d72cc370797da967ae90.jpg'),
(89070, 6203, 'Valendo Ouro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/190357.mp4', 'http://gstaticontent.com/images/1113f0d888c4d72cc370797da967ae90.jpg'),
(89071, 6203, 'Valendo Ouro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/190358.mp4', 'http://gstaticontent.com/images/1113f0d888c4d72cc370797da967ae90.jpg'),
(89072, 6204, 'Bucky S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189962.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89073, 6204, 'Bucky S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189963.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89074, 6204, 'Bucky S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189964.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89075, 6204, 'Bucky S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189965.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89076, 6204, 'Bucky S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189966.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89077, 6204, 'Bucky S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189967.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89078, 6204, 'Bucky S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189968.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89079, 6204, 'Bucky S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189969.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89080, 6204, 'Bucky S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/189970.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89081, 6204, 'Bucky S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/189971.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89082, 6204, 'Bucky S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/189972.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89083, 6204, 'Bucky S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/189973.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89084, 6204, 'Bucky S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/189974.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89085, 6204, 'Bucky S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/189975.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89086, 6204, 'Bucky S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/189976.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89087, 6204, 'Bucky S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/189977.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89088, 6204, 'Bucky S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/189978.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89089, 6204, 'Bucky S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/189979.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89090, 6204, 'Bucky S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/189980.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89091, 6204, 'Bucky S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/189981.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89092, 6204, 'Bucky S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/189982.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89093, 6204, 'Bucky S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/189983.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89094, 6204, 'Bucky S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/189984.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89095, 6204, 'Bucky S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/189985.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89096, 6204, 'Bucky S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/189986.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89097, 6204, 'Bucky S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/189987.mp4', 'http://gstaticontent.com/images/1d5afc9bb325c23647213a63621ef398.jpg'),
(89098, 6205, 'A Casa do Dragao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199665.mp4', 'http://timg.bdta.pro/images/b48eb81bcab9081375fc747f1d4168b9.jpg'),
(89099, 6205, 'A Casa do Dragao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199666.mp4', 'http://timg.bdta.pro/images/66fcf8f7c5828e79b11e0eadb3632736.jpg'),
(89100, 6205, 'A Casa do Dragao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199667.mp4', 'http://timg.bdta.pro/images/34ba481edf8311003f8612ee0b040ad0.jpg'),
(89101, 6205, 'A Casa do Dragao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199668.mp4', 'http://timg.bdta.pro/images/18d06a3eb2afa514d4644288af58834d.jpg'),
(89102, 6205, 'A Casa do Dragao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199669.mp4', 'http://timg.bdta.pro/images/d2b7b32687a71275509c8492513309e3.jpg'),
(89103, 6205, 'A Casa do Dragao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199670.mp4', 'http://timg.bdta.pro/images/bbf4733ca70adc1cb255e6d9835a371f.jpg'),
(89104, 6205, 'A Casa do Dragao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199671.mp4', 'http://timg.bdta.pro/images/42735d67fc4297669acccd65b4dee27b.jpg'),
(89105, 6205, 'A Casa do Dragao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199672.mp4', 'http://timg.bdta.pro/images/7cf6433c6adcb1ae67124d028e09f011.jpg'),
(89106, 6205, 'A Casa do Dragao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199673.mp4', 'http://timg.bdta.pro/images/6433a97de919f23a118313f6b945c9f8.jpg'),
(89107, 6205, 'A Casa do Dragao S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199674.mp4', 'http://timg.bdta.pro/images/c3a159646ab04634f8886bc4e44dbde6.jpg'),
(89108, 6206, 'A Casa do Dragao S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/388216.mp4', 'http://gstaticontent.com/images/3e9472ac405c126b324e8d7d1ad58db5.jpg'),
(89109, 6206, 'A Casa do Dragao S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393014.mp4', 'http://gstaticontent.com/images/3e9472ac405c126b324e8d7d1ad58db5.jpg'),
(89110, 6206, 'A Casa do Dragao S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399148.mp4', 'http://gstaticontent.com/images/3e9472ac405c126b324e8d7d1ad58db5.jpg'),
(89111, 6206, 'A Casa do Dragao S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/403870.mp4', 'http://gstaticontent.com/images/3e9472ac405c126b324e8d7d1ad58db5.jpg'),
(89112, 6206, 'A Casa do Dragao S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/409896.mp4', 'http://gstaticontent.com/images/3e9472ac405c126b324e8d7d1ad58db5.jpg'),
(89113, 6206, 'A Casa do Dragao S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416228.mp4', 'http://gstaticontent.com/images/3e9472ac405c126b324e8d7d1ad58db5.jpg'),
(89114, 6206, 'A Casa do Dragao S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/417207.mp4', 'http://gstaticontent.com/images/3e9472ac405c126b324e8d7d1ad58db5.jpg'),
(89115, 6206, 'A Casa do Dragao S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/425622.mp4', 'http://gstaticontent.com/images/3e9472ac405c126b324e8d7d1ad58db5.jpg'),
(89116, 6207, 'A Casa do Dragão [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199655.mp4', 'http://timg.bdta.pro/images/b48eb81bcab9081375fc747f1d4168b9.jpg'),
(89117, 6207, 'A Casa do Dragão [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199656.mp4', 'http://timg.bdta.pro/images/66fcf8f7c5828e79b11e0eadb3632736.jpg'),
(89118, 6207, 'A Casa do Dragão [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199657.mp4', 'http://timg.bdta.pro/images/64ad2fce9fae3031189ffd78e761c2bd.jpg'),
(89119, 6207, 'A Casa do Dragão [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199658.mp4', 'http://timg.bdta.pro/images/18d06a3eb2afa514d4644288af58834d.jpg'),
(89120, 6207, 'A Casa do Dragão [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199659.mp4', 'http://timg.bdta.pro/images/d2b7b32687a71275509c8492513309e3.jpg'),
(89121, 6207, 'A Casa do Dragão [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199660.mp4', 'http://timg.bdta.pro/images/bbf4733ca70adc1cb255e6d9835a371f.jpg'),
(89122, 6207, 'A Casa do Dragão [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199661.mp4', 'http://timg.bdta.pro/images/42735d67fc4297669acccd65b4dee27b.jpg'),
(89123, 6207, 'A Casa do Dragão [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199662.mp4', 'http://timg.bdta.pro/images/7cf6433c6adcb1ae67124d028e09f011.jpg'),
(89124, 6207, 'A Casa do Dragão [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199663.mp4', 'http://timg.bdta.pro/images/6433a97de919f23a118313f6b945c9f8.jpg'),
(89125, 6207, 'A Casa do Dragão [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199664.mp4', 'http://timg.bdta.pro/images/c3a159646ab04634f8886bc4e44dbde6.jpg'),
(89126, 6208, 'A Escola Amaldiçoada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189954.mp4', 'http://timg.bdta.pro/images/7969871b5bdb7b4c4df792891a3a2ee8.jpg'),
(89127, 6208, 'A Escola Amaldiçoada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189955.mp4', 'http://timg.bdta.pro/images/6b87b3b70cc306d407c0cc15c44b5959.jpg'),
(89128, 6208, 'A Escola Amaldiçoada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189956.mp4', 'http://timg.bdta.pro/images/6ec420d46f72f7db4bd18492293627e8.jpg'),
(89129, 6208, 'A Escola Amaldiçoada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189957.mp4', 'http://timg.bdta.pro/images/3bc4211213e3e9f9585562653592e576.jpg'),
(89130, 6208, 'A Escola Amaldiçoada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189958.mp4', 'http://timg.bdta.pro/images/ee7b0e952a8983313234bd4dad7d80cd.jpg'),
(89131, 6208, 'A Escola Amaldiçoada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189959.mp4', 'http://timg.bdta.pro/images/9d08a8c8bbcb8c698d3dfdc72e790426.jpg'),
(89132, 6208, 'A Escola Amaldiçoada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189960.mp4', 'http://timg.bdta.pro/images/cf661912042129f5a5f61da0715281fe.jpg'),
(89133, 6208, 'A Escola Amaldiçoada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189961.mp4', 'http://timg.bdta.pro/images/b36109892baf9e0ade0a6d69e54e09e3.jpg'),
(89134, 6209, 'A Trama S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189948.mp4', 'http://gstaticontent.com/images/f619ede51a6dc237f2c5015c12b13301.jpg'),
(89135, 6209, 'A Trama S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189949.mp4', 'http://gstaticontent.com/images/f619ede51a6dc237f2c5015c12b13301.jpg'),
(89136, 6209, 'A Trama S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189950.mp4', 'http://gstaticontent.com/images/f619ede51a6dc237f2c5015c12b13301.jpg'),
(89137, 6209, 'A Trama S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189951.mp4', 'http://gstaticontent.com/images/f619ede51a6dc237f2c5015c12b13301.jpg'),
(89138, 6209, 'A Trama S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189952.mp4', 'http://gstaticontent.com/images/f619ede51a6dc237f2c5015c12b13301.jpg'),
(89139, 6209, 'A Trama S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189953.mp4', 'http://gstaticontent.com/images/f619ede51a6dc237f2c5015c12b13301.jpg'),
(89140, 6210, 'All Star Shore S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253725.mp4', 'http://timg.bdta.pro/images/af835efe9e5516182b3dbb5ff3466cfe.jpg'),
(89141, 6210, 'All Star Shore S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253726.mp4', 'http://timg.bdta.pro/images/da07a1fe41792ff4ce055cb923fd7411.jpg'),
(89142, 6210, 'All Star Shore S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253727.mp4', 'http://timg.bdta.pro/images/5f47e70a4f48711c7a3d2714bf09399a.jpg'),
(89143, 6210, 'All Star Shore S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253728.mp4', 'http://timg.bdta.pro/images/610f9069b1c181d6312663a85e82945c.jpg'),
(89144, 6210, 'All Star Shore S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253729.mp4', 'http://timg.bdta.pro/images/6735e5626f4fceeae84b40264323dbba.jpg'),
(89145, 6210, 'All Star Shore S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253730.mp4', 'http://timg.bdta.pro/images/1d57696d127c246357d228f60cf962dc.jpg'),
(89146, 6210, 'All Star Shore S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253731.mp4', 'http://timg.bdta.pro/images/2b69ef11be4821726089290013502b91.jpg'),
(89147, 6210, 'All Star Shore S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253732.mp4', 'http://timg.bdta.pro/images/9326834f56baad023eef681804ca1617.jpg'),
(89148, 6210, 'All Star Shore S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253733.mp4', 'http://timg.bdta.pro/images/f4de7dea4f345eecc4de16020dedebed.jpg'),
(89149, 6210, 'All Star Shore S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253734.mp4', 'http://gstaticontent.com/images/d6e47e11f26a5ae1dbda79d6a5cc35b3.jpg'),
(89150, 6210, 'All Star Shore S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253735.mp4', 'http://gstaticontent.com/images/d6e47e11f26a5ae1dbda79d6a5cc35b3.jpg'),
(89151, 6211, 'All Star Shore S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253736.mp4', 'http://gstaticontent.com/images/d6e47e11f26a5ae1dbda79d6a5cc35b3.jpg'),
(89152, 6211, 'All Star Shore S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253737.mp4', 'http://gstaticontent.com/images/d6e47e11f26a5ae1dbda79d6a5cc35b3.jpg'),
(89153, 6211, 'All Star Shore S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253738.mp4', 'http://gstaticontent.com/images/d6e47e11f26a5ae1dbda79d6a5cc35b3.jpg'),
(89154, 6211, 'All Star Shore S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253739.mp4', 'http://gstaticontent.com/images/d6e47e11f26a5ae1dbda79d6a5cc35b3.jpg'),
(89155, 6211, 'All Star Shore S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253740.mp4', 'http://gstaticontent.com/images/d6e47e11f26a5ae1dbda79d6a5cc35b3.jpg'),
(89156, 6211, 'All Star Shore S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253741.mp4', 'http://gstaticontent.com/images/d6e47e11f26a5ae1dbda79d6a5cc35b3.jpg'),
(89157, 6211, 'All Star Shore S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253742.mp4', 'http://gstaticontent.com/images/d6e47e11f26a5ae1dbda79d6a5cc35b3.jpg'),
(89158, 6211, 'All Star Shore S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253743.mp4', 'http://gstaticontent.com/images/d6e47e11f26a5ae1dbda79d6a5cc35b3.jpg'),
(89159, 6211, 'All Star Shore S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253744.mp4', 'http://gstaticontent.com/images/d6e47e11f26a5ae1dbda79d6a5cc35b3.jpg'),
(89160, 6211, 'All Star Shore S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253745.mp4', 'http://gstaticontent.com/images/d6e47e11f26a5ae1dbda79d6a5cc35b3.jpg'),
(89161, 6211, 'All Star Shore S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253746.mp4', 'http://gstaticontent.com/images/d6e47e11f26a5ae1dbda79d6a5cc35b3.jpg'),
(89162, 6211, 'All Star Shore S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253747.mp4', 'http://gstaticontent.com/images/d6e47e11f26a5ae1dbda79d6a5cc35b3.jpg'),
(89163, 6212, 'Alma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189939.mp4', 'http://timg.bdta.pro/images/a4f1a0fcd43b575d5ca963cfdabc4560.jpg'),
(89164, 6212, 'Alma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189940.mp4', 'http://timg.bdta.pro/images/43dd8a77557fbaf1cde08e74b7ea4d01.jpg'),
(89165, 6212, 'Alma S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189941.mp4', 'http://timg.bdta.pro/images/bb5037a4ce978bb2da829f16d03fc96f.jpg'),
(89166, 6212, 'Alma S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189942.mp4', 'http://timg.bdta.pro/images/4a13aea80ee865a824786432904ef473.jpg'),
(89167, 6212, 'Alma S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189943.mp4', 'http://timg.bdta.pro/images/ef9df215866ec48e4d7e127ad11b42c2.jpg'),
(89168, 6212, 'Alma S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189944.mp4', 'http://timg.bdta.pro/images/ee104442eeb603b958431988aeb0f5cb.jpg'),
(89169, 6212, 'Alma S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189945.mp4', 'http://timg.bdta.pro/images/6a15712fcb68c7dfc75d1c94ffefa6bf.jpg'),
(89170, 6212, 'Alma S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189946.mp4', 'http://timg.bdta.pro/images/f5a63fef8a1604a7efc928f57e79f4dc.jpg'),
(89171, 6212, 'Alma S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/189947.mp4', 'http://timg.bdta.pro/images/ae9825198587b6789d11e1bbf8a6a58e.jpg'),
(89172, 6213, 'Are You The One? UK S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195843.mp4', 'http://timg.bdta.pro/images/02b13d7bc7cb331a42e8377aaef9be8e.jpg'),
(89173, 6213, 'Are You The One? UK S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195844.mp4', 'http://gstaticontent.com/images/e88eafcd51d0d624f54f6e88022b1ec4.jpg'),
(89174, 6213, 'Are You The One? UK S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195845.mp4', 'http://gstaticontent.com/images/e88eafcd51d0d624f54f6e88022b1ec4.jpg'),
(89175, 6213, 'Are You The One? UK S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195846.mp4', 'http://gstaticontent.com/images/e88eafcd51d0d624f54f6e88022b1ec4.jpg'),
(89176, 6213, 'Are You The One? UK S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195847.mp4', 'http://gstaticontent.com/images/e88eafcd51d0d624f54f6e88022b1ec4.jpg'),
(89177, 6213, 'Are You The One? UK S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195848.mp4', 'http://gstaticontent.com/images/e88eafcd51d0d624f54f6e88022b1ec4.jpg'),
(89178, 6213, 'Are You The One? UK S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195849.mp4', 'http://gstaticontent.com/images/e88eafcd51d0d624f54f6e88022b1ec4.jpg'),
(89179, 6213, 'Are You The One? UK S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195850.mp4', 'http://gstaticontent.com/images/e88eafcd51d0d624f54f6e88022b1ec4.jpg'),
(89180, 6213, 'Are You The One? UK S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195851.mp4', 'http://gstaticontent.com/images/e88eafcd51d0d624f54f6e88022b1ec4.jpg'),
(89181, 6213, 'Are You The One? UK S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195852.mp4', 'http://gstaticontent.com/images/e88eafcd51d0d624f54f6e88022b1ec4.jpg'),
(89182, 6214, 'Black Rock Shooter: Amanhecer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189927.mp4', 'http://timg.bdta.pro/images/e25e82cf2a508cebc2ccd5491f760736.jpg'),
(89183, 6214, 'Black Rock Shooter: Amanhecer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189928.mp4', 'http://timg.bdta.pro/images/d5f7a1eadf6c5f156a3f9f3eee596815.jpg'),
(89184, 6214, 'Black Rock Shooter: Amanhecer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189929.mp4', 'http://timg.bdta.pro/images/fa10c71869e2d56e0682cf8c68de56c0.jpg'),
(89185, 6214, 'Black Rock Shooter: Amanhecer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189930.mp4', 'http://timg.bdta.pro/images/a290d1c2e14c619b52e3dae9d06b9e3b.jpg'),
(89186, 6214, 'Black Rock Shooter: Amanhecer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189931.mp4', 'http://timg.bdta.pro/images/08277cfbc42595567587515e88076639.jpg'),
(89187, 6214, 'Black Rock Shooter: Amanhecer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189932.mp4', 'http://timg.bdta.pro/images/fa4a636539d3278a29a8a8e7fe32bc2e.jpg'),
(89188, 6214, 'Black Rock Shooter: Amanhecer S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189933.mp4', 'http://timg.bdta.pro/images/a684ab35539cc3275315e507fd3538cb.jpg'),
(89189, 6214, 'Black Rock Shooter: Amanhecer S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189934.mp4', 'http://timg.bdta.pro/images/e422a6ea9bc4fee43c8322c4f7553925.jpg'),
(89190, 6214, 'Black Rock Shooter: Amanhecer S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/189935.mp4', 'http://timg.bdta.pro/images/0ae53d499decd6bd6b77bf07741c3e10.jpg'),
(89191, 6214, 'Black Rock Shooter: Amanhecer S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/189936.mp4', 'http://timg.bdta.pro/images/ea33098c480f82d92d294ddc1f3f99d1.jpg'),
(89192, 6214, 'Black Rock Shooter: Amanhecer S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/189937.mp4', 'http://timg.bdta.pro/images/9260c99e513c3d5ae684fe15cfea176e.jpg'),
(89193, 6214, 'Black Rock Shooter: Amanhecer S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/189938.mp4', 'http://timg.bdta.pro/images/4f39463525dc6023fb7bebb9cf755053.jpg'),
(89194, 6215, 'Bleach (2004) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251564.mp4', 'http://timg.bdta.pro/images/8567060a63af1ee6fce06f44563f4e3e.jpg'),
(89195, 6215, 'Bleach (2004) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251565.mp4', 'http://timg.bdta.pro/images/a780fce336e64d9e79e0de68b2674944.jpg'),
(89196, 6215, 'Bleach (2004) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251566.mp4', 'http://timg.bdta.pro/images/792546f75c02ce31af58b164416aa2e4.jpg'),
(89197, 6215, 'Bleach (2004) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251567.mp4', 'http://timg.bdta.pro/images/01adc29b373fd225aebaeb98aad47b08.jpg'),
(89198, 6215, 'Bleach (2004) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251568.mp4', 'http://timg.bdta.pro/images/f8ccd301f36218b0bdb9a9599a973ab1.jpg'),
(89199, 6215, 'Bleach (2004) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251569.mp4', 'http://timg.bdta.pro/images/1db224df25a3d6dc0cf86185acfe7076.jpg'),
(89200, 6215, 'Bleach (2004) S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251570.mp4', 'http://timg.bdta.pro/images/783eba52460ed9dbca61344a8b395abc.jpg'),
(89201, 6215, 'Bleach (2004) S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251571.mp4', 'http://timg.bdta.pro/images/cd7f622af5b40e2dd713302048da2a3c.jpg'),
(89202, 6215, 'Bleach (2004) S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251572.mp4', 'http://timg.bdta.pro/images/069575850df18459fbfa195b62b5a0a1.jpg'),
(89203, 6215, 'Bleach (2004) S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251573.mp4', 'http://timg.bdta.pro/images/d251c9c0ef73e51595749777bec6f1a9.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(89204, 6215, 'Bleach (2004) S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251574.mp4', 'http://timg.bdta.pro/images/82100130135c386709ace1b6ceb0f072.jpg'),
(89205, 6215, 'Bleach (2004) S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251575.mp4', 'http://timg.bdta.pro/images/f1d954948911306dfc5fdb5be0e29b75.jpg'),
(89206, 6215, 'Bleach (2004) S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251576.mp4', 'http://timg.bdta.pro/images/52ef7649e9a1eb9787915c148e9cc0d8.jpg'),
(89207, 6215, 'Bleach (2004) S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251577.mp4', 'http://timg.bdta.pro/images/932b5a7d8a6293bd3e8bd34d9daa20cd.jpg'),
(89208, 6215, 'Bleach (2004) S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251578.mp4', 'http://timg.bdta.pro/images/ff67e6772105af0a78ed8ec0505143ba.jpg'),
(89209, 6215, 'Bleach (2004) S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/251579.mp4', 'http://timg.bdta.pro/images/4fe9ce3468320d3836bfa433f50d3cd6.jpg'),
(89210, 6215, 'Bleach (2004) S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/251580.mp4', 'http://timg.bdta.pro/images/b3f0cfa7cadc5449994e930ff2c03240.jpg'),
(89211, 6215, 'Bleach (2004) S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/251581.mp4', 'http://timg.bdta.pro/images/1bc39cbd5e988c8a6b7d1a797ede2d60.jpg'),
(89212, 6215, 'Bleach (2004) S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/251582.mp4', 'http://timg.bdta.pro/images/de527eb4dbfbe39bd8db1d0aa36ee33a.jpg'),
(89213, 6215, 'Bleach (2004) S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/251583.mp4', 'http://timg.bdta.pro/images/6aa8a2a04a16115f9f058d9a203058ec.jpg'),
(89214, 6216, 'Bleach (2004) S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251584.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89215, 6216, 'Bleach (2004) S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251585.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89216, 6216, 'Bleach (2004) S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251586.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89217, 6216, 'Bleach (2004) S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251587.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89218, 6216, 'Bleach (2004) S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251588.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89219, 6216, 'Bleach (2004) S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251589.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89220, 6216, 'Bleach (2004) S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251590.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89221, 6216, 'Bleach (2004) S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251591.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89222, 6216, 'Bleach (2004) S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251592.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89223, 6216, 'Bleach (2004) S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251593.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89224, 6216, 'Bleach (2004) S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251594.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89225, 6216, 'Bleach (2004) S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251595.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89226, 6216, 'Bleach (2004) S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251596.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89227, 6216, 'Bleach (2004) S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251597.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89228, 6216, 'Bleach (2004) S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251598.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89229, 6216, 'Bleach (2004) S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/251599.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89230, 6216, 'Bleach (2004) S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/251600.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89231, 6216, 'Bleach (2004) S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/251601.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89232, 6216, 'Bleach (2004) S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/251602.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89233, 6216, 'Bleach (2004) S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/251603.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89234, 6216, 'Bleach (2004) S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/251604.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89235, 6217, 'Bleach (2004) S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251605.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89236, 6217, 'Bleach (2004) S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251606.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89237, 6217, 'Bleach (2004) S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251607.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89238, 6217, 'Bleach (2004) S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251608.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89239, 6217, 'Bleach (2004) S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251609.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89240, 6217, 'Bleach (2004) S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251610.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89241, 6217, 'Bleach (2004) S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251611.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89242, 6217, 'Bleach (2004) S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251612.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89243, 6217, 'Bleach (2004) S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251613.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89244, 6217, 'Bleach (2004) S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251614.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89245, 6217, 'Bleach (2004) S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251615.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89246, 6217, 'Bleach (2004) S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251616.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89247, 6217, 'Bleach (2004) S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251617.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89248, 6217, 'Bleach (2004) S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251618.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89249, 6217, 'Bleach (2004) S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251619.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89250, 6217, 'Bleach (2004) S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/251620.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89251, 6217, 'Bleach (2004) S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/251621.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89252, 6217, 'Bleach (2004) S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/251622.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89253, 6217, 'Bleach (2004) S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/251623.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89254, 6217, 'Bleach (2004) S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/251624.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89255, 6217, 'Bleach (2004) S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/251625.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89256, 6217, 'Bleach (2004) S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/251626.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89257, 6218, 'Bleach (2004) S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251627.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89258, 6218, 'Bleach (2004) S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251628.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89259, 6218, 'Bleach (2004) S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251629.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89260, 6218, 'Bleach (2004) S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251630.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89261, 6218, 'Bleach (2004) S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251631.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89262, 6218, 'Bleach (2004) S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251632.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89263, 6218, 'Bleach (2004) S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251633.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89264, 6218, 'Bleach (2004) S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251634.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89265, 6218, 'Bleach (2004) S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251635.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89266, 6218, 'Bleach (2004) S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251636.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89267, 6218, 'Bleach (2004) S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251637.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89268, 6218, 'Bleach (2004) S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251638.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89269, 6218, 'Bleach (2004) S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251639.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89270, 6218, 'Bleach (2004) S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251640.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89271, 6218, 'Bleach (2004) S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251641.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89272, 6218, 'Bleach (2004) S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/251642.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89273, 6218, 'Bleach (2004) S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/251643.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89274, 6218, 'Bleach (2004) S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/251644.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89275, 6218, 'Bleach (2004) S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/251645.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89276, 6218, 'Bleach (2004) S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/251646.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89277, 6218, 'Bleach (2004) S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/251647.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89278, 6218, 'Bleach (2004) S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/251648.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89279, 6218, 'Bleach (2004) S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/251649.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89280, 6218, 'Bleach (2004) S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/251650.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89281, 6218, 'Bleach (2004) S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/251651.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89282, 6218, 'Bleach (2004) S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/251652.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89283, 6218, 'Bleach (2004) S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/251653.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89284, 6218, 'Bleach (2004) S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/251654.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89285, 6219, 'Bleach (2004) S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251655.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89286, 6219, 'Bleach (2004) S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251656.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89287, 6219, 'Bleach (2004) S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251657.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89288, 6219, 'Bleach (2004) S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251658.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89289, 6219, 'Bleach (2004) S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251659.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89290, 6219, 'Bleach (2004) S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251660.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89291, 6219, 'Bleach (2004) S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251661.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89292, 6219, 'Bleach (2004) S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251662.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89293, 6219, 'Bleach (2004) S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251663.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89294, 6219, 'Bleach (2004) S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251664.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89295, 6219, 'Bleach (2004) S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251665.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89296, 6219, 'Bleach (2004) S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251666.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89297, 6219, 'Bleach (2004) S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251667.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89298, 6219, 'Bleach (2004) S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251668.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89299, 6219, 'Bleach (2004) S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251669.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89300, 6219, 'Bleach (2004) S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/251670.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89301, 6219, 'Bleach (2004) S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/251671.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89302, 6219, 'Bleach (2004) S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/251672.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89303, 6220, 'Bleach (2004) S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251673.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89304, 6220, 'Bleach (2004) S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251674.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89305, 6220, 'Bleach (2004) S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251675.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89306, 6220, 'Bleach (2004) S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251676.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89307, 6220, 'Bleach (2004) S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251677.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89308, 6220, 'Bleach (2004) S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251678.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89309, 6220, 'Bleach (2004) S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251679.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89310, 6220, 'Bleach (2004) S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251680.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89311, 6220, 'Bleach (2004) S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251681.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89312, 6220, 'Bleach (2004) S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251682.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89313, 6220, 'Bleach (2004) S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251683.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89314, 6220, 'Bleach (2004) S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251684.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89315, 6220, 'Bleach (2004) S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251685.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89316, 6220, 'Bleach (2004) S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251686.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89317, 6220, 'Bleach (2004) S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251687.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89318, 6220, 'Bleach (2004) S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/251688.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89319, 6220, 'Bleach (2004) S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/251689.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89320, 6220, 'Bleach (2004) S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/251690.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89321, 6220, 'Bleach (2004) S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/251691.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89322, 6220, 'Bleach (2004) S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/251692.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89323, 6220, 'Bleach (2004) S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/251693.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89324, 6220, 'Bleach (2004) S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/251694.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89325, 6221, 'Bleach (2004) S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251695.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89326, 6221, 'Bleach (2004) S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251696.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89327, 6221, 'Bleach (2004) S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251697.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89328, 6221, 'Bleach (2004) S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251698.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89329, 6221, 'Bleach (2004) S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251699.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89330, 6221, 'Bleach (2004) S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251700.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89331, 6221, 'Bleach (2004) S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251701.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89332, 6221, 'Bleach (2004) S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251702.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89333, 6221, 'Bleach (2004) S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251703.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89334, 6221, 'Bleach (2004) S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251704.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89335, 6221, 'Bleach (2004) S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251705.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89336, 6221, 'Bleach (2004) S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251706.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89337, 6221, 'Bleach (2004) S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251707.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89338, 6221, 'Bleach (2004) S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251708.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89339, 6221, 'Bleach (2004) S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251709.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89340, 6221, 'Bleach (2004) S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/251710.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89341, 6221, 'Bleach (2004) S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/251711.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89342, 6221, 'Bleach (2004) S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/251712.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89343, 6221, 'Bleach (2004) S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/251713.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89344, 6221, 'Bleach (2004) S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/251714.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89345, 6222, 'Bleach (2004) S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251715.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89346, 6222, 'Bleach (2004) S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251716.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89347, 6222, 'Bleach (2004) S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251717.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89348, 6222, 'Bleach (2004) S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251718.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89349, 6222, 'Bleach (2004) S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251719.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89350, 6222, 'Bleach (2004) S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251720.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89351, 6222, 'Bleach (2004) S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251721.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89352, 6222, 'Bleach (2004) S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251722.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89353, 6222, 'Bleach (2004) S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251723.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89354, 6222, 'Bleach (2004) S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251724.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89355, 6222, 'Bleach (2004) S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251725.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89356, 6222, 'Bleach (2004) S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251726.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89357, 6222, 'Bleach (2004) S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251727.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89358, 6222, 'Bleach (2004) S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251728.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89359, 6222, 'Bleach (2004) S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251729.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89360, 6222, 'Bleach (2004) S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/251730.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89361, 6223, 'Bleach (2004) S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251731.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89362, 6223, 'Bleach (2004) S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251732.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89363, 6223, 'Bleach (2004) S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251733.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89364, 6223, 'Bleach (2004) S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251734.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89365, 6223, 'Bleach (2004) S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251735.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89366, 6223, 'Bleach (2004) S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251736.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89367, 6223, 'Bleach (2004) S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251737.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89368, 6223, 'Bleach (2004) S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251738.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89369, 6223, 'Bleach (2004) S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251739.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89370, 6223, 'Bleach (2004) S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251740.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89371, 6223, 'Bleach (2004) S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251741.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89372, 6223, 'Bleach (2004) S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251742.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89373, 6223, 'Bleach (2004) S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251743.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89374, 6223, 'Bleach (2004) S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251744.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89375, 6223, 'Bleach (2004) S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251745.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89376, 6223, 'Bleach (2004) S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/251746.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89377, 6223, 'Bleach (2004) S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/251747.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89378, 6223, 'Bleach (2004) S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/251748.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89379, 6223, 'Bleach (2004) S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/251749.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89380, 6223, 'Bleach (2004) S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/251750.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89381, 6223, 'Bleach (2004) S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/251751.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89382, 6223, 'Bleach (2004) S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/251752.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89383, 6224, 'Bleach (2004) S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251753.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89384, 6224, 'Bleach (2004) S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251754.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89385, 6224, 'Bleach (2004) S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251755.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89386, 6224, 'Bleach (2004) S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251756.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89387, 6224, 'Bleach (2004) S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251757.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89388, 6224, 'Bleach (2004) S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251758.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89389, 6224, 'Bleach (2004) S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251759.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89390, 6224, 'Bleach (2004) S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251760.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89391, 6224, 'Bleach (2004) S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251761.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89392, 6224, 'Bleach (2004) S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251762.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89393, 6224, 'Bleach (2004) S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251763.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89394, 6224, 'Bleach (2004) S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251764.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89395, 6224, 'Bleach (2004) S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251765.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89396, 6224, 'Bleach (2004) S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251766.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89397, 6224, 'Bleach (2004) S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251767.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89398, 6224, 'Bleach (2004) S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/251768.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89399, 6225, 'Bleach (2004) S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251769.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89400, 6225, 'Bleach (2004) S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251770.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89401, 6225, 'Bleach (2004) S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251771.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89402, 6225, 'Bleach (2004) S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251772.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89403, 6225, 'Bleach (2004) S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251773.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89404, 6225, 'Bleach (2004) S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251774.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89405, 6225, 'Bleach (2004) S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251775.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89406, 6225, 'Bleach (2004) S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251776.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89407, 6225, 'Bleach (2004) S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251777.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89408, 6226, 'Bleach (2004) S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251778.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89409, 6226, 'Bleach (2004) S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251779.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89410, 6226, 'Bleach (2004) S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251780.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89411, 6226, 'Bleach (2004) S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251781.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89412, 6226, 'Bleach (2004) S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251782.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89413, 6226, 'Bleach (2004) S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251783.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89414, 6226, 'Bleach (2004) S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251784.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89415, 6226, 'Bleach (2004) S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251785.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89416, 6226, 'Bleach (2004) S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251786.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89417, 6226, 'Bleach (2004) S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251787.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89418, 6226, 'Bleach (2004) S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251788.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89419, 6226, 'Bleach (2004) S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251789.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89420, 6226, 'Bleach (2004) S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251790.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89421, 6226, 'Bleach (2004) S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251791.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89422, 6226, 'Bleach (2004) S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251792.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89423, 6227, 'Bleach (2004) S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251793.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89424, 6227, 'Bleach (2004) S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251794.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89425, 6227, 'Bleach (2004) S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251795.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89426, 6227, 'Bleach (2004) S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251796.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89427, 6227, 'Bleach (2004) S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251797.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89428, 6227, 'Bleach (2004) S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251798.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89429, 6227, 'Bleach (2004) S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251799.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89430, 6227, 'Bleach (2004) S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251800.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89431, 6227, 'Bleach (2004) S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251801.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89432, 6227, 'Bleach (2004) S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251802.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89433, 6227, 'Bleach (2004) S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251803.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89434, 6227, 'Bleach (2004) S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251804.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89435, 6227, 'Bleach (2004) S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251805.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89436, 6227, 'Bleach (2004) S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251806.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89437, 6227, 'Bleach (2004) S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251807.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89438, 6227, 'Bleach (2004) S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/251808.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89439, 6227, 'Bleach (2004) S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/251809.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89440, 6227, 'Bleach (2004) S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/251810.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89441, 6227, 'Bleach (2004) S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/251811.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89442, 6227, 'Bleach (2004) S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/251812.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89443, 6227, 'Bleach (2004) S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/251813.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89444, 6227, 'Bleach (2004) S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/251814.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89445, 6227, 'Bleach (2004) S13 E23', 'http://sinalprivado.info:80/series/1533784/1533784/251815.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89446, 6227, 'Bleach (2004) S13 E24', 'http://sinalprivado.info:80/series/1533784/1533784/251816.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89447, 6227, 'Bleach (2004) S13 E25', 'http://sinalprivado.info:80/series/1533784/1533784/251817.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89448, 6227, 'Bleach (2004) S13 E26', 'http://sinalprivado.info:80/series/1533784/1533784/251818.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89449, 6227, 'Bleach (2004) S13 E27', 'http://sinalprivado.info:80/series/1533784/1533784/251819.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89450, 6227, 'Bleach (2004) S13 E28', 'http://sinalprivado.info:80/series/1533784/1533784/251820.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89451, 6227, 'Bleach (2004) S13 E29', 'http://sinalprivado.info:80/series/1533784/1533784/251821.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89452, 6227, 'Bleach (2004) S13 E30', 'http://sinalprivado.info:80/series/1533784/1533784/251822.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89453, 6227, 'Bleach (2004) S13 E31', 'http://sinalprivado.info:80/series/1533784/1533784/251823.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89454, 6227, 'Bleach (2004) S13 E32', 'http://sinalprivado.info:80/series/1533784/1533784/251824.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89455, 6227, 'Bleach (2004) S13 E33', 'http://sinalprivado.info:80/series/1533784/1533784/251825.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89456, 6227, 'Bleach (2004) S13 E34', 'http://sinalprivado.info:80/series/1533784/1533784/251826.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89457, 6227, 'Bleach (2004) S13 E35', 'http://sinalprivado.info:80/series/1533784/1533784/251827.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89458, 6227, 'Bleach (2004) S13 E36', 'http://sinalprivado.info:80/series/1533784/1533784/251828.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89459, 6228, 'Bleach (2004) S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251829.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89460, 6228, 'Bleach (2004) S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251830.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89461, 6228, 'Bleach (2004) S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251831.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89462, 6228, 'Bleach (2004) S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251832.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89463, 6228, 'Bleach (2004) S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251833.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89464, 6228, 'Bleach (2004) S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251834.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89465, 6228, 'Bleach (2004) S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251835.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89466, 6228, 'Bleach (2004) S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251836.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89467, 6228, 'Bleach (2004) S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251837.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89468, 6228, 'Bleach (2004) S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251838.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89469, 6228, 'Bleach (2004) S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251839.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89470, 6228, 'Bleach (2004) S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251840.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89471, 6228, 'Bleach (2004) S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251841.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89472, 6228, 'Bleach (2004) S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251842.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89473, 6228, 'Bleach (2004) S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251843.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89474, 6228, 'Bleach (2004) S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/251844.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89475, 6228, 'Bleach (2004) S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/251845.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89476, 6228, 'Bleach (2004) S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/251846.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89477, 6228, 'Bleach (2004) S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/251847.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89478, 6228, 'Bleach (2004) S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/251848.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89479, 6228, 'Bleach (2004) S14 E21', 'http://sinalprivado.info:80/series/1533784/1533784/251849.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89480, 6228, 'Bleach (2004) S14 E22', 'http://sinalprivado.info:80/series/1533784/1533784/251850.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89481, 6228, 'Bleach (2004) S14 E23', 'http://sinalprivado.info:80/series/1533784/1533784/251851.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89482, 6228, 'Bleach (2004) S14 E24', 'http://sinalprivado.info:80/series/1533784/1533784/251852.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89483, 6228, 'Bleach (2004) S14 E25', 'http://sinalprivado.info:80/series/1533784/1533784/251853.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89484, 6228, 'Bleach (2004) S14 E26', 'http://sinalprivado.info:80/series/1533784/1533784/251854.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89485, 6228, 'Bleach (2004) S14 E27', 'http://sinalprivado.info:80/series/1533784/1533784/251855.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89486, 6228, 'Bleach (2004) S14 E28', 'http://sinalprivado.info:80/series/1533784/1533784/251856.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89487, 6228, 'Bleach (2004) S14 E29', 'http://sinalprivado.info:80/series/1533784/1533784/251857.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89488, 6228, 'Bleach (2004) S14 E30', 'http://sinalprivado.info:80/series/1533784/1533784/251858.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89489, 6228, 'Bleach (2004) S14 E31', 'http://sinalprivado.info:80/series/1533784/1533784/251859.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89490, 6228, 'Bleach (2004) S14 E32', 'http://sinalprivado.info:80/series/1533784/1533784/251860.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89491, 6228, 'Bleach (2004) S14 E33', 'http://sinalprivado.info:80/series/1533784/1533784/251861.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89492, 6228, 'Bleach (2004) S14 E34', 'http://sinalprivado.info:80/series/1533784/1533784/251862.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89493, 6228, 'Bleach (2004) S14 E35', 'http://sinalprivado.info:80/series/1533784/1533784/251863.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(89494, 6228, 'Bleach (2004) S14 E36', 'http://sinalprivado.info:80/series/1533784/1533784/251864.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89495, 6228, 'Bleach (2004) S14 E37', 'http://sinalprivado.info:80/series/1533784/1533784/251865.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89496, 6228, 'Bleach (2004) S14 E38', 'http://sinalprivado.info:80/series/1533784/1533784/251866.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89497, 6228, 'Bleach (2004) S14 E39', 'http://sinalprivado.info:80/series/1533784/1533784/251867.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89498, 6228, 'Bleach (2004) S14 E40', 'http://sinalprivado.info:80/series/1533784/1533784/251868.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89499, 6228, 'Bleach (2004) S14 E41', 'http://sinalprivado.info:80/series/1533784/1533784/251869.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89500, 6228, 'Bleach (2004) S14 E42', 'http://sinalprivado.info:80/series/1533784/1533784/251870.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89501, 6228, 'Bleach (2004) S14 E43', 'http://sinalprivado.info:80/series/1533784/1533784/251871.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89502, 6228, 'Bleach (2004) S14 E44', 'http://sinalprivado.info:80/series/1533784/1533784/251872.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89503, 6228, 'Bleach (2004) S14 E45', 'http://sinalprivado.info:80/series/1533784/1533784/251873.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89504, 6228, 'Bleach (2004) S14 E46', 'http://sinalprivado.info:80/series/1533784/1533784/251874.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89505, 6228, 'Bleach (2004) S14 E47', 'http://sinalprivado.info:80/series/1533784/1533784/251875.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89506, 6228, 'Bleach (2004) S14 E48', 'http://sinalprivado.info:80/series/1533784/1533784/251876.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89507, 6228, 'Bleach (2004) S14 E49', 'http://sinalprivado.info:80/series/1533784/1533784/251877.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89508, 6228, 'Bleach (2004) S14 E50', 'http://sinalprivado.info:80/series/1533784/1533784/251878.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89509, 6228, 'Bleach (2004) S14 E51', 'http://sinalprivado.info:80/series/1533784/1533784/251879.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89510, 6229, 'Bleach (2004) S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251880.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89511, 6229, 'Bleach (2004) S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251881.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89512, 6229, 'Bleach (2004) S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251882.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89513, 6229, 'Bleach (2004) S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251883.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89514, 6229, 'Bleach (2004) S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251884.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89515, 6229, 'Bleach (2004) S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251885.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89516, 6229, 'Bleach (2004) S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251886.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89517, 6229, 'Bleach (2004) S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251887.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89518, 6229, 'Bleach (2004) S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251888.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89519, 6229, 'Bleach (2004) S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251889.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89520, 6229, 'Bleach (2004) S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251890.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89521, 6229, 'Bleach (2004) S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251891.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89522, 6229, 'Bleach (2004) S15 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251892.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89523, 6229, 'Bleach (2004) S15 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251893.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89524, 6229, 'Bleach (2004) S15 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251894.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89525, 6229, 'Bleach (2004) S15 E16', 'http://sinalprivado.info:80/series/1533784/1533784/251895.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89526, 6229, 'Bleach (2004) S15 E17', 'http://sinalprivado.info:80/series/1533784/1533784/251896.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89527, 6229, 'Bleach (2004) S15 E18', 'http://sinalprivado.info:80/series/1533784/1533784/251897.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89528, 6229, 'Bleach (2004) S15 E19', 'http://sinalprivado.info:80/series/1533784/1533784/251898.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89529, 6229, 'Bleach (2004) S15 E20', 'http://sinalprivado.info:80/series/1533784/1533784/251899.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89530, 6229, 'Bleach (2004) S15 E21', 'http://sinalprivado.info:80/series/1533784/1533784/251900.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89531, 6229, 'Bleach (2004) S15 E22', 'http://sinalprivado.info:80/series/1533784/1533784/251901.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89532, 6229, 'Bleach (2004) S15 E23', 'http://sinalprivado.info:80/series/1533784/1533784/251902.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89533, 6229, 'Bleach (2004) S15 E24', 'http://sinalprivado.info:80/series/1533784/1533784/251903.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89534, 6229, 'Bleach (2004) S15 E25', 'http://sinalprivado.info:80/series/1533784/1533784/251904.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89535, 6229, 'Bleach (2004) S15 E26', 'http://sinalprivado.info:80/series/1533784/1533784/251905.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89536, 6230, 'Bleach (2004) S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251906.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89537, 6230, 'Bleach (2004) S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251907.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89538, 6230, 'Bleach (2004) S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251908.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89539, 6230, 'Bleach (2004) S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251909.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89540, 6230, 'Bleach (2004) S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251910.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89541, 6230, 'Bleach (2004) S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251911.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89542, 6230, 'Bleach (2004) S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251912.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89543, 6230, 'Bleach (2004) S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251913.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89544, 6230, 'Bleach (2004) S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251914.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89545, 6230, 'Bleach (2004) S16 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251915.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89546, 6230, 'Bleach (2004) S16 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251916.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89547, 6230, 'Bleach (2004) S16 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251917.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89548, 6230, 'Bleach (2004) S16 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251918.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89549, 6230, 'Bleach (2004) S16 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251919.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89550, 6230, 'Bleach (2004) S16 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251920.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89551, 6230, 'Bleach (2004) S16 E16', 'http://sinalprivado.info:80/series/1533784/1533784/251921.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89552, 6230, 'Bleach (2004) S16 E17', 'http://sinalprivado.info:80/series/1533784/1533784/251922.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89553, 6230, 'Bleach (2004) S16 E18', 'http://sinalprivado.info:80/series/1533784/1533784/251923.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89554, 6230, 'Bleach (2004) S16 E19', 'http://sinalprivado.info:80/series/1533784/1533784/251924.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89555, 6230, 'Bleach (2004) S16 E20', 'http://sinalprivado.info:80/series/1533784/1533784/251925.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89556, 6230, 'Bleach (2004) S16 E21', 'http://sinalprivado.info:80/series/1533784/1533784/251926.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89557, 6230, 'Bleach (2004) S16 E22', 'http://sinalprivado.info:80/series/1533784/1533784/251927.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89558, 6230, 'Bleach (2004) S16 E23', 'http://sinalprivado.info:80/series/1533784/1533784/251928.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89559, 6230, 'Bleach (2004) S16 E24', 'http://sinalprivado.info:80/series/1533784/1533784/251929.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89560, 6231, 'Bleach (2004) S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251930.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89561, 6231, 'Bleach (2004) S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251931.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89562, 6231, 'Bleach (2004) S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251932.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89563, 6231, 'Bleach (2004) S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251933.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89564, 6231, 'Bleach (2004) S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251934.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89565, 6231, 'Bleach (2004) S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251935.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89566, 6231, 'Bleach (2004) S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251936.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89567, 6231, 'Bleach (2004) S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251937.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89568, 6231, 'Bleach (2004) S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251938.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89569, 6231, 'Bleach (2004) S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251939.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89570, 6231, 'Bleach (2004) S17 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251940.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89571, 6231, 'Bleach (2004) S17 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251941.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89572, 6231, 'Bleach (2004) S17 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251942.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89573, 6231, 'Bleach (2004) S17 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251943.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89574, 6231, 'Bleach (2004) S17 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251944.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89575, 6231, 'Bleach (2004) S17 E16', 'http://sinalprivado.info:80/series/1533784/1533784/251945.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89576, 6231, 'Bleach (2004) S17 E17', 'http://sinalprivado.info:80/series/1533784/1533784/251946.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89577, 6231, 'Bleach (2004) S17 E18', 'http://sinalprivado.info:80/series/1533784/1533784/251947.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89578, 6231, 'Bleach (2004) S17 E19', 'http://sinalprivado.info:80/series/1533784/1533784/251948.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89579, 6231, 'Bleach (2004) S17 E20', 'http://sinalprivado.info:80/series/1533784/1533784/251949.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89580, 6231, 'Bleach (2004) S17 E21', 'http://sinalprivado.info:80/series/1533784/1533784/251950.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89581, 6231, 'Bleach (2004) S17 E22', 'http://sinalprivado.info:80/series/1533784/1533784/251951.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89582, 6231, 'Bleach (2004) S17 E23', 'http://sinalprivado.info:80/series/1533784/1533784/251952.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89583, 6231, 'Bleach (2004) S17 E24', 'http://sinalprivado.info:80/series/1533784/1533784/251953.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89584, 6231, 'Bleach (2004) S17 E25', 'http://sinalprivado.info:80/series/1533784/1533784/251954.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89585, 6231, 'Bleach (2004) S17 E26', 'http://sinalprivado.info:80/series/1533784/1533784/251955.mp4', 'http://image.tmdb.org/images/25c01132eadb051e942d2fd0a81f68b8.jpg'),
(89586, 6232, 'Cinco Dias no Hospital Memorial S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192311.mp4', 'http://timg.bdta.pro/images/3995b20506471c077fd89917ee875141.jpg'),
(89587, 6232, 'Cinco Dias no Hospital Memorial S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192312.mp4', 'http://timg.bdta.pro/images/2b44187a004fa593ea0c9242cae69272.jpg'),
(89588, 6232, 'Cinco Dias no Hospital Memorial S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192313.mp4', 'http://timg.bdta.pro/images/84dc0b1c41efaec7fa4138f46d97b8e8.jpg'),
(89589, 6232, 'Cinco Dias no Hospital Memorial S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192314.mp4', 'http://timg.bdta.pro/images/3afa06adc18791de947c985c347a4c7c.jpg'),
(89590, 6232, 'Cinco Dias no Hospital Memorial S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192315.mp4', 'http://timg.bdta.pro/images/12a50cd05d26ca4e1c5d2f0bf6c992a9.jpg'),
(89591, 6232, 'Cinco Dias no Hospital Memorial S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192316.mp4', 'http://timg.bdta.pro/images/db10e02a7806ae0fb02c3151f095f266.jpg'),
(89592, 6232, 'Cinco Dias no Hospital Memorial S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192317.mp4', 'http://timg.bdta.pro/images/8696e167c7f94ce0c711296c1e0e3b2f.jpg'),
(89593, 6232, 'Cinco Dias no Hospital Memorial S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192318.mp4', 'http://timg.bdta.pro/images/27f0c62bdca3ea7f40c541f5bef12793.jpg'),
(89594, 6233, 'Clarice S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189914.mp4', 'http://timg.bdta.pro/images/1acd8eb20d10c5918a3084d5954b8f57.jpg'),
(89595, 6233, 'Clarice S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189915.mp4', 'http://timg.bdta.pro/images/b421ed58a31c9fbedd9f374b8463345e.jpg'),
(89596, 6233, 'Clarice S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189916.mp4', 'http://timg.bdta.pro/images/b16c5d197900efb20e767b66a73cd4f8.jpg'),
(89597, 6233, 'Clarice S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189917.mp4', 'http://timg.bdta.pro/images/1468ee419120816c9655a8deb9e9c5be.jpg'),
(89598, 6233, 'Clarice S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189918.mp4', 'http://timg.bdta.pro/images/44385720e449dffd6207c4f380d3f44e.jpg'),
(89599, 6233, 'Clarice S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189919.mp4', 'http://timg.bdta.pro/images/00f2278132a38eb9301f2333d38c1518.jpg'),
(89600, 6233, 'Clarice S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189920.mp4', 'http://timg.bdta.pro/images/97032b8e23d5f47f976ee656e6d90662.jpg'),
(89601, 6233, 'Clarice S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189921.mp4', 'http://timg.bdta.pro/images/ca42b5500ac92dc7f9549ac400996eb7.jpg'),
(89602, 6233, 'Clarice S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/189922.mp4', 'http://timg.bdta.pro/images/4e213eb43e6bde0f474ba07fea1a7326.jpg'),
(89603, 6233, 'Clarice S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/189923.mp4', 'http://timg.bdta.pro/images/eae2798b63a00130dfeaea6ee5c33096.jpg'),
(89604, 6233, 'Clarice S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/189924.mp4', 'http://timg.bdta.pro/images/9894a7d56b3efd164384c0f95feb13cf.jpg'),
(89605, 6233, 'Clarice S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/189925.mp4', 'http://timg.bdta.pro/images/4fac6dc38114a655ad13cf4cbc210e04.jpg'),
(89606, 6233, 'Clarice S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/189926.mp4', 'http://timg.bdta.pro/images/9af36223cebee7e845c4d19accf86aa2.jpg'),
(89607, 6234, 'Compulsion S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189910.mp4', 'http://timg.bdta.pro/images/e9965a81168ec179d6148f3112f67df5.jpg'),
(89608, 6234, 'Compulsion S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189911.mp4', 'http://timg.bdta.pro/images/5d49c600ae5fdfcec16673a47feb3807.jpg'),
(89609, 6234, 'Compulsion S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189912.mp4', 'http://timg.bdta.pro/images/c998fad9a5f7ea8e50158e934d2949c7.jpg'),
(89610, 6234, 'Compulsion S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189913.mp4', 'http://timg.bdta.pro/images/11c2913cb8bd1aeeeb309834474456bb.jpg'),
(89611, 6235, 'Critter Fixers: Hospital Veterinário S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189890.mp4', 'http://gstaticontent.com/images/33dd7e9e0033da44616e495dd6ba3d3a.jpg'),
(89612, 6235, 'Critter Fixers: Hospital Veterinário S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189891.mp4', 'http://gstaticontent.com/images/33dd7e9e0033da44616e495dd6ba3d3a.jpg'),
(89613, 6235, 'Critter Fixers: Hospital Veterinário S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189892.mp4', 'http://gstaticontent.com/images/33dd7e9e0033da44616e495dd6ba3d3a.jpg'),
(89614, 6235, 'Critter Fixers: Hospital Veterinário S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189893.mp4', 'http://gstaticontent.com/images/33dd7e9e0033da44616e495dd6ba3d3a.jpg'),
(89615, 6235, 'Critter Fixers: Hospital Veterinário S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189894.mp4', 'http://gstaticontent.com/images/33dd7e9e0033da44616e495dd6ba3d3a.jpg'),
(89616, 6235, 'Critter Fixers: Hospital Veterinário S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189895.mp4', 'http://gstaticontent.com/images/33dd7e9e0033da44616e495dd6ba3d3a.jpg'),
(89617, 6235, 'Critter Fixers: Hospital Veterinário S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189896.mp4', 'http://gstaticontent.com/images/33dd7e9e0033da44616e495dd6ba3d3a.jpg'),
(89618, 6235, 'Critter Fixers: Hospital Veterinário S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189897.mp4', 'http://gstaticontent.com/images/33dd7e9e0033da44616e495dd6ba3d3a.jpg'),
(89619, 6236, 'Critter Fixers: Hospital Veterinário S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189898.mp4', 'http://gstaticontent.com/images/33dd7e9e0033da44616e495dd6ba3d3a.jpg'),
(89620, 6236, 'Critter Fixers: Hospital Veterinário S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189899.mp4', 'http://gstaticontent.com/images/33dd7e9e0033da44616e495dd6ba3d3a.jpg'),
(89621, 6236, 'Critter Fixers: Hospital Veterinário S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189900.mp4', 'http://gstaticontent.com/images/33dd7e9e0033da44616e495dd6ba3d3a.jpg'),
(89622, 6236, 'Critter Fixers: Hospital Veterinário S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189901.mp4', 'http://gstaticontent.com/images/33dd7e9e0033da44616e495dd6ba3d3a.jpg'),
(89623, 6236, 'Critter Fixers: Hospital Veterinário S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189902.mp4', 'http://gstaticontent.com/images/33dd7e9e0033da44616e495dd6ba3d3a.jpg'),
(89624, 6236, 'Critter Fixers: Hospital Veterinário S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189903.mp4', 'http://gstaticontent.com/images/33dd7e9e0033da44616e495dd6ba3d3a.jpg'),
(89625, 6236, 'Critter Fixers: Hospital Veterinário S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189904.mp4', 'http://gstaticontent.com/images/33dd7e9e0033da44616e495dd6ba3d3a.jpg'),
(89626, 6236, 'Critter Fixers: Hospital Veterinário S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189905.mp4', 'http://gstaticontent.com/images/33dd7e9e0033da44616e495dd6ba3d3a.jpg'),
(89627, 6236, 'Critter Fixers: Hospital Veterinário S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/189906.mp4', 'http://gstaticontent.com/images/33dd7e9e0033da44616e495dd6ba3d3a.jpg'),
(89628, 6236, 'Critter Fixers: Hospital Veterinário S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/189907.mp4', 'http://gstaticontent.com/images/33dd7e9e0033da44616e495dd6ba3d3a.jpg'),
(89629, 6236, 'Critter Fixers: Hospital Veterinário S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/189908.mp4', 'http://gstaticontent.com/images/33dd7e9e0033da44616e495dd6ba3d3a.jpg'),
(89630, 6236, 'Critter Fixers: Hospital Veterinário S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/189909.mp4', 'http://gstaticontent.com/images/33dd7e9e0033da44616e495dd6ba3d3a.jpg'),
(89631, 6237, 'Domina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189882.mp4', 'http://timg.bdta.pro/images/76a120bb1140c6cfc3e401ef61f8df8c.jpg'),
(89632, 6237, 'Domina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189883.mp4', 'http://timg.bdta.pro/images/5010b5536f77f3d72bd2fdfa01c77406.jpg'),
(89633, 6237, 'Domina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189884.mp4', 'http://timg.bdta.pro/images/99a0af6e19bd4ac8e5e5d92c4ba471a3.jpg'),
(89634, 6237, 'Domina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189885.mp4', 'http://timg.bdta.pro/images/4e699c3bd45c60591dd82e02211f6d09.jpg'),
(89635, 6237, 'Domina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189886.mp4', 'http://timg.bdta.pro/images/82d15c72f3dbd69dd826379c52e8cc45.jpg'),
(89636, 6237, 'Domina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189887.mp4', 'http://timg.bdta.pro/images/decaa970a6d4fb77f77766cea3d2b902.jpg'),
(89637, 6237, 'Domina S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189888.mp4', 'http://timg.bdta.pro/images/39cf6ef2e76f1461650ca3e247ccf865.jpg'),
(89638, 6237, 'Domina S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189889.mp4', 'http://timg.bdta.pro/images/968a80fa2b86e2b0a2ae8084f19fa9ba.jpg'),
(89639, 6238, 'Echoes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189875.mp4', 'http://timg.bdta.pro/images/10daaacc6dee14650136a5eca6b5d930.jpg'),
(89640, 6238, 'Echoes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189876.mp4', 'http://timg.bdta.pro/images/f0ec1f99612ce76eac09285ee5bdb4ee.jpg'),
(89641, 6238, 'Echoes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189877.mp4', 'http://timg.bdta.pro/images/6a0e09404f276e0e905f8c577b4ef131.jpg'),
(89642, 6238, 'Echoes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189878.mp4', 'http://timg.bdta.pro/images/811b5aac720f8c6916cb28c2ba31a359.jpg'),
(89643, 6238, 'Echoes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189879.mp4', 'http://timg.bdta.pro/images/52e9d0958a63a6faf3af9e2ccd37a882.jpg'),
(89644, 6238, 'Echoes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189880.mp4', 'http://timg.bdta.pro/images/f2abda93a26fdba5ba1b2933894f6a07.jpg'),
(89645, 6238, 'Echoes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189881.mp4', 'http://timg.bdta.pro/images/a49e5a6584376130cd2e8f8d5bd28ae3.jpg'),
(89646, 6239, 'Em Busca da Casa Perfeita: Comediantes Sem Filtro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189865.mp4', 'http://timg.bdta.pro/images/356e08179104212d9a7821884fdcdb7e.jpg'),
(89647, 6239, 'Em Busca da Casa Perfeita: Comediantes Sem Filtro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189866.mp4', 'http://timg.bdta.pro/images/66be1557a56eed65f47d19f262ee1bf0.jpg'),
(89648, 6239, 'Em Busca da Casa Perfeita: Comediantes Sem Filtro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189867.mp4', 'http://timg.bdta.pro/images/4b0adb9f51c8fa7f13ec98a1db2b0dd8.jpg'),
(89649, 6239, 'Em Busca da Casa Perfeita: Comediantes Sem Filtro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189868.mp4', 'http://timg.bdta.pro/images/f6a389a08e09005cbda12615f0524974.jpg'),
(89650, 6239, 'Em Busca da Casa Perfeita: Comediantes Sem Filtro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189869.mp4', 'http://timg.bdta.pro/images/f36525b926782a720f4b4edd072f0e27.jpg'),
(89651, 6239, 'Em Busca da Casa Perfeita: Comediantes Sem Filtro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189870.mp4', 'http://gstaticontent.com/images/1a386888ee0f9701415b839d1c98776e.jpg'),
(89652, 6239, 'Em Busca da Casa Perfeita: Comediantes Sem Filtro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189871.mp4', 'http://gstaticontent.com/images/1a386888ee0f9701415b839d1c98776e.jpg'),
(89653, 6239, 'Em Busca da Casa Perfeita: Comediantes Sem Filtro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189872.mp4', 'http://gstaticontent.com/images/1a386888ee0f9701415b839d1c98776e.jpg'),
(89654, 6239, 'Em Busca da Casa Perfeita: Comediantes Sem Filtro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/189873.mp4', 'http://gstaticontent.com/images/1a386888ee0f9701415b839d1c98776e.jpg'),
(89655, 6239, 'Em Busca da Casa Perfeita: Comediantes Sem Filtro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/189874.mp4', 'http://gstaticontent.com/images/1a386888ee0f9701415b839d1c98776e.jpg'),
(89656, 6240, 'Entre a Vida e a Morte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189859.mp4', 'http://timg.bdta.pro/images/f474d88ab1f2c20599fe030c21220d7b.jpg'),
(89657, 6240, 'Entre a Vida e a Morte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189860.mp4', 'http://timg.bdta.pro/images/6952ce2f0a8e1708f4432b46c50abe0c.jpg'),
(89658, 6240, 'Entre a Vida e a Morte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189861.mp4', 'http://timg.bdta.pro/images/890501fe65f84c191b1a30508699fb97.jpg'),
(89659, 6240, 'Entre a Vida e a Morte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189862.mp4', 'http://timg.bdta.pro/images/ece75d44b2ae34128911777e45fb3699.jpg'),
(89660, 6240, 'Entre a Vida e a Morte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189863.mp4', 'http://timg.bdta.pro/images/e145f4ad03f08eb1f913d7389d38c6a4.jpg'),
(89661, 6240, 'Entre a Vida e a Morte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189864.mp4', 'http://timg.bdta.pro/images/dcd70468d9e7b1b09b75ac5f47a4175c.jpg'),
(89662, 6241, 'Eu Matei Meu Pai S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189856.mp4', 'http://timg.bdta.pro/images/685ee4df5a6a06425c3449f8458eadaf.jpg'),
(89663, 6241, 'Eu Matei Meu Pai S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189857.mp4', 'http://timg.bdta.pro/images/f4925534b298a91ef72aeade201b5d7e.jpg'),
(89664, 6241, 'Eu Matei Meu Pai S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189858.mp4', 'http://timg.bdta.pro/images/88e9f81e9e5f400b401c5ace3d4aeed3.jpg'),
(89665, 6242, 'Eu Sou Groot S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189851.mp4', 'http://gstaticontent.com/images/18fc703509f8de0dc3be0243e137b172.jpg'),
(89666, 6242, 'Eu Sou Groot S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189852.mp4', 'http://gstaticontent.com/images/18fc703509f8de0dc3be0243e137b172.jpg'),
(89667, 6242, 'Eu Sou Groot S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189853.mp4', 'http://gstaticontent.com/images/18fc703509f8de0dc3be0243e137b172.jpg'),
(89668, 6242, 'Eu Sou Groot S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189854.mp4', 'http://gstaticontent.com/images/18fc703509f8de0dc3be0243e137b172.jpg'),
(89669, 6242, 'Eu Sou Groot S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189855.mp4', 'http://gstaticontent.com/images/18fc703509f8de0dc3be0243e137b172.jpg'),
(89670, 6243, 'Evil By Design: Surviving Nygård S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189848.mp4', 'http://timg.bdta.pro/images/4038e111681052153f1d2094fa265add.jpg'),
(89671, 6243, 'Evil By Design: Surviving Nygård S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189849.mp4', 'http://timg.bdta.pro/images/88301625fb0b04db5b53f4855a4fcd85.jpg'),
(89672, 6243, 'Evil By Design: Surviving Nygård S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189850.mp4', 'http://timg.bdta.pro/images/19c89eedc8170eab78f528428d2b5d54.jpg'),
(89673, 6244, 'Fair Trade: Jogo Sujo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189840.mp4', 'http://timg.bdta.pro/images/53c264b9fc9a98d18856f7b1b8af884c.jpg'),
(89674, 6244, 'Fair Trade: Jogo Sujo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189841.mp4', 'http://timg.bdta.pro/images/cfed4ad9174fc69300fffcbf4371977d.jpg'),
(89675, 6244, 'Fair Trade: Jogo Sujo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189842.mp4', 'http://timg.bdta.pro/images/4b055a90920d269b6734b080087be8ae.jpg'),
(89676, 6244, 'Fair Trade: Jogo Sujo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189843.mp4', 'http://timg.bdta.pro/images/b749e6ea72c4802f5a19d291a102b8f6.jpg'),
(89677, 6244, 'Fair Trade: Jogo Sujo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189844.mp4', 'http://timg.bdta.pro/images/d2d27bb96ef3b112055b218a071cf5cd.jpg'),
(89678, 6244, 'Fair Trade: Jogo Sujo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189845.mp4', 'http://timg.bdta.pro/images/5add334d9b9a9240dabb22200642cb5b.jpg'),
(89679, 6244, 'Fair Trade: Jogo Sujo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189846.mp4', 'http://timg.bdta.pro/images/d20f06d61bc12d3d9b98ab64c2350cec.jpg'),
(89680, 6244, 'Fair Trade: Jogo Sujo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189847.mp4', 'http://timg.bdta.pro/images/a1b9fca02c4fc7df9ce6557f09056fa8.jpg'),
(89681, 6245, 'FriendZSpace S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189827.mp4', 'http://timg.bdta.pro/images/1ebe8d5eff4a6f59b1deb1db738ff5a9.jpg'),
(89682, 6245, 'FriendZSpace S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189828.mp4', 'http://timg.bdta.pro/images/49d864c1f2314c209b759e0b7c436b35.jpg'),
(89683, 6245, 'FriendZSpace S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189829.mp4', 'http://timg.bdta.pro/images/e7db5665a9521b674bea460d35067868.jpg'),
(89684, 6245, 'FriendZSpace S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189830.mp4', 'http://timg.bdta.pro/images/3e3caf910e9b9eb6af4e35aec17fc10d.jpg'),
(89685, 6245, 'FriendZSpace S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189831.mp4', 'http://timg.bdta.pro/images/3b7bdf007a8bb2740abe60bfe3ecbafe.jpg'),
(89686, 6245, 'FriendZSpace S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189832.mp4', 'http://timg.bdta.pro/images/e928f356b6e65fb6a011612773cefbbd.jpg'),
(89687, 6245, 'FriendZSpace S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189833.mp4', 'http://timg.bdta.pro/images/45d4109e78c5258577c9c2decc88b1b4.jpg'),
(89688, 6245, 'FriendZSpace S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189834.mp4', 'http://timg.bdta.pro/images/93d4bbf7ca151c4afab861b29ad63cd7.jpg'),
(89689, 6245, 'FriendZSpace S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/189835.mp4', 'http://timg.bdta.pro/images/0446dd7fee0d4492f632b3b85d6bf026.jpg'),
(89690, 6245, 'FriendZSpace S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/189836.mp4', 'http://timg.bdta.pro/images/d4bcda91445ff0029acd88ed337a17ae.jpg'),
(89691, 6245, 'FriendZSpace S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/189837.mp4', 'http://timg.bdta.pro/images/31895a19e78fb1e01702425f561c511d.jpg'),
(89692, 6245, 'FriendZSpace S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/189838.mp4', 'http://timg.bdta.pro/images/c31df9c16ee942497b73fcc464bad9de.jpg'),
(89693, 6245, 'FriendZSpace S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/189839.mp4', 'http://timg.bdta.pro/images/459c0319186b30634f92ee4ef29325cf.jpg'),
(89694, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189801.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89695, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189802.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89696, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189803.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89697, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189804.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89698, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189805.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89699, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189806.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89700, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189807.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89701, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189808.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89702, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/189809.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89703, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/189810.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89704, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/189811.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89705, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/189812.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89706, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/189813.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89707, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/189814.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89708, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/189815.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89709, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/189816.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89710, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/189817.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89711, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/189818.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89712, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/189819.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89713, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/189820.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89714, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/189821.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89715, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/189822.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89716, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/189823.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89717, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/189824.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89718, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/189825.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89719, 6246, 'GloboNews: 25 Anos Em 25 Entrevistas S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/189826.mp4', 'http://gstaticontent.com/images/0fb151785160eda44ddbf7ae1a7c1f1b.jpg'),
(89720, 6247, 'Grid S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189793.mp4', 'http://timg.bdta.pro/images/97cbd7a4271abb2bf8ae3a44b87ff4f5.jpg'),
(89721, 6247, 'Grid S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189794.mp4', 'http://timg.bdta.pro/images/68e4e45465e0446d434f1791a8fb224b.jpg'),
(89722, 6247, 'Grid S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189795.mp4', 'http://timg.bdta.pro/images/16ce436d82c6ffcfc0817a4ec1f0e746.jpg'),
(89723, 6247, 'Grid S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189796.mp4', 'http://timg.bdta.pro/images/9b6103d30f98fe51cf7355e856d6b87a.jpg'),
(89724, 6247, 'Grid S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189797.mp4', 'http://timg.bdta.pro/images/317dd9ecc961f50bbba2f417cb53a908.jpg'),
(89725, 6247, 'Grid S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189798.mp4', 'http://timg.bdta.pro/images/d678ae9ed9e33cb17f014aea37637733.jpg'),
(89726, 6247, 'Grid S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189799.mp4', 'http://timg.bdta.pro/images/da8dd8f55ac43de605c30b8aadf76589.jpg'),
(89727, 6247, 'Grid S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189800.mp4', 'http://timg.bdta.pro/images/041e4c86d424ca82f469f06e27e93f73.jpg'),
(89728, 6248, 'Hierarquia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189783.mp4', 'http://timg.bdta.pro/images/c0d8cffa301cd78f8a49d7d768324c5c.jpg'),
(89729, 6248, 'Hierarquia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189784.mp4', 'http://timg.bdta.pro/images/5f94ba526bc6c2f88054cd15929542a2.jpg'),
(89730, 6248, 'Hierarquia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189785.mp4', 'http://timg.bdta.pro/images/ec06e26a9f2403b82096f383a15bc74f.jpg'),
(89731, 6248, 'Hierarquia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189786.mp4', 'http://timg.bdta.pro/images/e3d773110d3f9905630ac3c8e597b802.jpg'),
(89732, 6248, 'Hierarquia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189787.mp4', 'http://timg.bdta.pro/images/93c079dcef8f8b1a42b1d080ff0d4c62.jpg'),
(89733, 6248, 'Hierarquia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189788.mp4', 'http://timg.bdta.pro/images/f40dee8b5c3842cacdce09c4bab4e09d.jpg'),
(89734, 6248, 'Hierarquia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189789.mp4', 'http://timg.bdta.pro/images/f33719eeb3d0ff63bc4f36b4ff9945dc.jpg'),
(89735, 6248, 'Hierarquia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189790.mp4', 'http://timg.bdta.pro/images/f3962e1c688ea176610f5c8f647c082e.jpg'),
(89736, 6248, 'Hierarquia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/189791.mp4', 'http://timg.bdta.pro/images/cd4db6ef04bbbcf0c9bc2f9856b0ac79.jpg'),
(89737, 6248, 'Hierarquia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/189792.mp4', 'http://timg.bdta.pro/images/8fd00266a70f11c6e321f1feeffedf19.jpg'),
(89738, 6249, 'Infiniti S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196886.mp4', 'http://timg.bdta.pro/images/5c69231f1b6e4a013f0a01fc144bab11.jpg'),
(89739, 6249, 'Infiniti S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196887.mp4', 'http://timg.bdta.pro/images/9d1ee2058974ccd2a0255191e31df4a0.jpg'),
(89740, 6249, 'Infiniti S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196888.mp4', 'http://timg.bdta.pro/images/9efc36ff7e992a08796e4182caf4f1c8.jpg'),
(89741, 6249, 'Infiniti S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196889.mp4', 'http://timg.bdta.pro/images/d564d1d65676578dfe69b7bdd43a9500.jpg'),
(89742, 6249, 'Infiniti S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196890.mp4', 'http://timg.bdta.pro/images/b87bbc234e08955b8f9ee31d0ef2ea68.jpg'),
(89743, 6249, 'Infiniti S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196891.mp4', 'http://timg.bdta.pro/images/dc4e5fad1c104925c460b14e28d604af.jpg'),
(89744, 6250, 'Iron Chef: Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189775.mp4', 'http://gstaticontent.com/images/f5d78d339a2c86b0b348036da77af5e7.jpg'),
(89745, 6250, 'Iron Chef: Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189776.mp4', 'http://gstaticontent.com/images/f5d78d339a2c86b0b348036da77af5e7.jpg'),
(89746, 6250, 'Iron Chef: Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189777.mp4', 'http://gstaticontent.com/images/f5d78d339a2c86b0b348036da77af5e7.jpg'),
(89747, 6250, 'Iron Chef: Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189778.mp4', 'http://gstaticontent.com/images/f5d78d339a2c86b0b348036da77af5e7.jpg'),
(89748, 6250, 'Iron Chef: Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189779.mp4', 'http://gstaticontent.com/images/f5d78d339a2c86b0b348036da77af5e7.jpg'),
(89749, 6250, 'Iron Chef: Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189780.mp4', 'http://gstaticontent.com/images/f5d78d339a2c86b0b348036da77af5e7.jpg'),
(89750, 6250, 'Iron Chef: Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189781.mp4', 'http://gstaticontent.com/images/f5d78d339a2c86b0b348036da77af5e7.jpg'),
(89751, 6250, 'Iron Chef: Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189782.mp4', 'http://gstaticontent.com/images/f5d78d339a2c86b0b348036da77af5e7.jpg'),
(89752, 6251, 'Kleo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189767.mp4', 'http://timg.bdta.pro/images/3621d66d0c82372c42e9d04fab7cb821.jpg'),
(89753, 6251, 'Kleo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189768.mp4', 'http://timg.bdta.pro/images/0e2120b249a39e6292304034b798b0e1.jpg'),
(89754, 6251, 'Kleo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189769.mp4', 'http://timg.bdta.pro/images/76822283e1cf0b9f6b87c85d840430ea.jpg'),
(89755, 6251, 'Kleo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189770.mp4', 'http://timg.bdta.pro/images/b635ee598b5a7bcf18e9b09ddbde9a01.jpg'),
(89756, 6251, 'Kleo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189771.mp4', 'http://timg.bdta.pro/images/46a5f2c2a1bca11f71ecd6aedfe42ce6.jpg'),
(89757, 6251, 'Kleo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189772.mp4', 'http://timg.bdta.pro/images/7d0d1510b1386cbe2f6290c047691cbf.jpg'),
(89758, 6251, 'Kleo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189773.mp4', 'http://timg.bdta.pro/images/5b4dfa365cb62cb3b699c02afbd2268d.jpg'),
(89759, 6251, 'Kleo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189774.mp4', 'http://timg.bdta.pro/images/b09694dc3e4b2105b65de0ca5ffdb151.jpg'),
(89760, 6252, 'Kleo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/419498.mp4', 'http://gstaticontent.com/images/3754339a4ed17ee7bd6a8b2062e690de.jpg'),
(89761, 6252, 'Kleo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/419499.mp4', 'http://gstaticontent.com/images/3754339a4ed17ee7bd6a8b2062e690de.jpg'),
(89762, 6252, 'Kleo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/419500.mp4', 'http://gstaticontent.com/images/3754339a4ed17ee7bd6a8b2062e690de.jpg'),
(89763, 6252, 'Kleo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/419501.mp4', 'http://gstaticontent.com/images/3754339a4ed17ee7bd6a8b2062e690de.jpg'),
(89764, 6252, 'Kleo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/419502.mp4', 'http://gstaticontent.com/images/3754339a4ed17ee7bd6a8b2062e690de.jpg'),
(89765, 6252, 'Kleo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/419503.mp4', 'http://gstaticontent.com/images/3754339a4ed17ee7bd6a8b2062e690de.jpg'),
(89766, 6253, 'Ludik S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189761.mp4', 'http://timg.bdta.pro/images/30d864772d48b2145b100d75ddd834e4.jpg'),
(89767, 6253, 'Ludik S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189762.mp4', 'http://timg.bdta.pro/images/e154c301daf8404a94c2a02201692747.jpg'),
(89768, 6253, 'Ludik S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189763.mp4', 'http://timg.bdta.pro/images/2b4e8aaa5fa7e9067a98231eb8ff1831.jpg'),
(89769, 6253, 'Ludik S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189764.mp4', 'http://timg.bdta.pro/images/26d8250d69f149248035f917b598c275.jpg'),
(89770, 6253, 'Ludik S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189765.mp4', 'http://timg.bdta.pro/images/e88fecf9c724bf9df85a88e4e3800f01.jpg'),
(89771, 6253, 'Ludik S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189766.mp4', 'http://timg.bdta.pro/images/70dff8b458b78ee3a799ce9f6eefcf56.jpg'),
(89772, 6254, 'Mal de Família S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195655.mp4', 'http://timg.bdta.pro/images/6cecfde5e0a87f428975857e2f3c4191.jpg'),
(89773, 6254, 'Mal de Família S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195656.mp4', 'http://timg.bdta.pro/images/44648f359db49bfd41081a7553fc521e.jpg'),
(89774, 6254, 'Mal de Família S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195657.mp4', 'http://timg.bdta.pro/images/36bd20d3cdcf6edfaaea326e7b4c58e5.jpg'),
(89775, 6254, 'Mal de Família S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195658.mp4', 'http://timg.bdta.pro/images/08241dd5137af6a6c23993ef1f19802e.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(89776, 6254, 'Mal de Família S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195659.mp4', 'http://timg.bdta.pro/images/5a879850f2417d2cfc0dfc706079d8b0.jpg'),
(89777, 6254, 'Mal de Família S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195660.mp4', 'http://timg.bdta.pro/images/8ea0dec652aaca557285b29ee7a03e2e.jpg'),
(89778, 6254, 'Mal de Família S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195661.mp4', 'http://timg.bdta.pro/images/a15e43e582011ba3e2b805245d0b39ac.jpg'),
(89779, 6254, 'Mal de Família S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637115.mp4', 'http://gstaticontent.com/images/21ae2aaf198d57e8c66cb9a509060c7c.jpg'),
(89780, 6254, 'Mal de Família S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/656370.mp4', 'http://image.tmdb.org//t/p/w1280/qXhZA1k8hEcuQx4TCoruextKRnZ.jpg'),
(89781, 6254, 'Mal de Família S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195664.mp4', 'http://timg.bdta.pro/images/50e56c82274c1cfddab122f90b41a859.jpg'),
(89782, 6255, 'Mal de Família S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656372.mp4', 'http://image.tmdb.org//t/p/w1280/xeWgf2RagCCMdgXJwpDJc2DH8ZD.jpg'),
(89783, 6255, 'Mal de Família S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656373.mp4', 'http://image.tmdb.org//t/p/w1280/s8Wr5lko5PwXeOTfVbrHcA6v0if.jpg'),
(89784, 6255, 'Mal de Família S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637118.mp4', 'http://gstaticontent.com/images/8f2bd0746d6634165405c8192188c990.jpg'),
(89785, 6255, 'Mal de Família S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/515438.mp4', 'http://gstaticontent.com/images/8f2bd0746d6634165405c8192188c990.jpg'),
(89786, 6255, 'Mal de Família S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/523340.mp4', 'http://gstaticontent.com/images/8f2bd0746d6634165405c8192188c990.jpg'),
(89787, 6255, 'Mal de Família S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/523341.mp4', 'http://gstaticontent.com/images/8f2bd0746d6634165405c8192188c990.jpg'),
(89788, 6255, 'Mal de Família S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637122.mp4', 'http://gstaticontent.com/images/8f2bd0746d6634165405c8192188c990.jpg'),
(89789, 6255, 'Mal de Família S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/640964.mp4', 'http://gstaticontent.com/images/8f2bd0746d6634165405c8192188c990.jpg'),
(89790, 6256, 'Mo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189753.mp4', 'http://timg.bdta.pro/images/8f615d3a8bc6dad842cea7ab3593aad9.jpg'),
(89791, 6256, 'Mo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189754.mp4', 'http://timg.bdta.pro/images/2e12e1a112d918834e405d68a41218b9.jpg'),
(89792, 6256, 'Mo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189755.mp4', 'http://timg.bdta.pro/images/e80ec61def86f0a631a857905a1a2878.jpg'),
(89793, 6256, 'Mo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189756.mp4', 'http://timg.bdta.pro/images/d46929265176bbd412193df990345c4d.jpg'),
(89794, 6256, 'Mo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189757.mp4', 'http://timg.bdta.pro/images/14eeed7299d046d39770837f2d76ad48.jpg'),
(89795, 6256, 'Mo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189758.mp4', 'http://timg.bdta.pro/images/c50e676fffcde75d257318e1a08dd254.jpg'),
(89796, 6256, 'Mo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189759.mp4', 'http://gstaticontent.com/images/f9dca4b3d14e8c85e170e1b7598a09c0.jpg'),
(89797, 6256, 'Mo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189760.mp4', 'http://gstaticontent.com/images/f9dca4b3d14e8c85e170e1b7598a09c0.jpg'),
(89798, 6257, 'MS Estonia: Tragédia em Alto Mar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189748.mp4', 'http://timg.bdta.pro/images/26b8b407412521da910c9d65090d7087.jpg'),
(89799, 6257, 'MS Estonia: Tragédia em Alto Mar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189749.mp4', 'http://timg.bdta.pro/images/ea00972f978bf7e6fdb2cdf1cdd012cc.jpg'),
(89800, 6257, 'MS Estonia: Tragédia em Alto Mar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189750.mp4', 'http://timg.bdta.pro/images/aebfdcabeb7ea235efe1d1a0be82936e.jpg'),
(89801, 6257, 'MS Estonia: Tragédia em Alto Mar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189751.mp4', 'http://timg.bdta.pro/images/0730c64f54de71f81e47deac4b21e3d5.jpg'),
(89802, 6257, 'MS Estonia: Tragédia em Alto Mar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189752.mp4', 'http://timg.bdta.pro/images/458834d031520162a104cdb811b1ea2a.jpg'),
(89803, 6258, 'Mulher-Hulk: Defensora de Heróis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195630.mp4', 'http://timg.bdta.pro/images/62d0d12fa36c4c10c69fd30a0a162c10.jpg'),
(89804, 6258, 'Mulher-Hulk: Defensora de Heróis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195631.mp4', 'http://timg.bdta.pro/images/bb34438146920098b9eb3b5238cc6db2.jpg'),
(89805, 6258, 'Mulher-Hulk: Defensora de Heróis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195632.mp4', 'http://timg.bdta.pro/images/5f94cac3f08b59a46e421c984b04420c.jpg'),
(89806, 6258, 'Mulher-Hulk: Defensora de Heróis S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195633.mp4', 'http://timg.bdta.pro/images/6ec586edc1da0f508ce5ef8667bf5a63.jpg'),
(89807, 6258, 'Mulher-Hulk: Defensora de Heróis S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195634.mp4', 'http://timg.bdta.pro/images/09add443d2a10cefad7b87837cb15722.jpg'),
(89808, 6258, 'Mulher-Hulk: Defensora de Heróis S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195635.mp4', 'http://timg.bdta.pro/images/780d2bebab40fa9f3473d8cb8985056e.jpg'),
(89809, 6258, 'Mulher-Hulk: Defensora de Heróis S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195636.mp4', 'http://timg.bdta.pro/images/4ee11563948f14add4378e0443eef191.jpg'),
(89810, 6258, 'Mulher-Hulk: Defensora de Heróis S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195637.mp4', 'http://timg.bdta.pro/images/5628b6a4f7d465e4dd093f391e1622c8.jpg'),
(89811, 6258, 'Mulher-Hulk: Defensora de Heróis S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195638.mp4', 'http://timg.bdta.pro/images/d8f5179ce2819e4b8a6d99d7d83e8b3d.jpg'),
(89812, 6259, 'Nada Suspeitos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189739.mp4', 'http://gstaticontent.com/images/786be3968fe90ca50d86d495c9e0a8f6.jpg'),
(89813, 6259, 'Nada Suspeitos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189740.mp4', 'http://gstaticontent.com/images/786be3968fe90ca50d86d495c9e0a8f6.jpg'),
(89814, 6259, 'Nada Suspeitos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189741.mp4', 'http://gstaticontent.com/images/786be3968fe90ca50d86d495c9e0a8f6.jpg'),
(89815, 6259, 'Nada Suspeitos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189742.mp4', 'http://gstaticontent.com/images/786be3968fe90ca50d86d495c9e0a8f6.jpg'),
(89816, 6259, 'Nada Suspeitos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189743.mp4', 'http://gstaticontent.com/images/786be3968fe90ca50d86d495c9e0a8f6.jpg'),
(89817, 6259, 'Nada Suspeitos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189744.mp4', 'http://gstaticontent.com/images/786be3968fe90ca50d86d495c9e0a8f6.jpg'),
(89818, 6259, 'Nada Suspeitos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189745.mp4', 'http://gstaticontent.com/images/786be3968fe90ca50d86d495c9e0a8f6.jpg'),
(89819, 6259, 'Nada Suspeitos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189746.mp4', 'http://gstaticontent.com/images/786be3968fe90ca50d86d495c9e0a8f6.jpg'),
(89820, 6259, 'Nada Suspeitos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/189747.mp4', 'http://gstaticontent.com/images/786be3968fe90ca50d86d495c9e0a8f6.jpg'),
(89821, 6260, 'Não Foi Minha Culpa: Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189729.mp4', 'http://gstaticontent.com/images/367daacf9a20703091b51bff1b44a729.jpg'),
(89822, 6260, 'Não Foi Minha Culpa: Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189730.mp4', 'http://gstaticontent.com/images/367daacf9a20703091b51bff1b44a729.jpg'),
(89823, 6260, 'Não Foi Minha Culpa: Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189731.mp4', 'http://gstaticontent.com/images/367daacf9a20703091b51bff1b44a729.jpg'),
(89824, 6260, 'Não Foi Minha Culpa: Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189732.mp4', 'http://gstaticontent.com/images/367daacf9a20703091b51bff1b44a729.jpg'),
(89825, 6260, 'Não Foi Minha Culpa: Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189733.mp4', 'http://gstaticontent.com/images/367daacf9a20703091b51bff1b44a729.jpg'),
(89826, 6260, 'Não Foi Minha Culpa: Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189734.mp4', 'http://gstaticontent.com/images/367daacf9a20703091b51bff1b44a729.jpg'),
(89827, 6260, 'Não Foi Minha Culpa: Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189735.mp4', 'http://gstaticontent.com/images/367daacf9a20703091b51bff1b44a729.jpg'),
(89828, 6260, 'Não Foi Minha Culpa: Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189736.mp4', 'http://gstaticontent.com/images/367daacf9a20703091b51bff1b44a729.jpg'),
(89829, 6260, 'Não Foi Minha Culpa: Brasil S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/189737.mp4', 'http://gstaticontent.com/images/367daacf9a20703091b51bff1b44a729.jpg'),
(89830, 6260, 'Não Foi Minha Culpa: Brasil S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/189738.mp4', 'http://gstaticontent.com/images/367daacf9a20703091b51bff1b44a729.jpg'),
(89831, 6261, 'O Ensaio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189723.mp4', 'http://timg.bdta.pro/images/2216796d714f2e1e72b9e9a997897635.jpg'),
(89832, 6261, 'O Ensaio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189724.mp4', 'http://timg.bdta.pro/images/e72f1c49ffb7ab2a71310a43bebf7a50.jpg'),
(89833, 6261, 'O Ensaio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189725.mp4', 'http://timg.bdta.pro/images/806229235fc7aa5a4cf3dec2000a631b.jpg'),
(89834, 6261, 'O Ensaio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189726.mp4', 'http://timg.bdta.pro/images/b01e339aa66c206dce639ae7624cbd8a.jpg'),
(89835, 6261, 'O Ensaio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189727.mp4', 'http://timg.bdta.pro/images/9336b64f00d183fc6ff5384737413fca.jpg'),
(89836, 6261, 'O Ensaio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189728.mp4', 'http://timg.bdta.pro/images/43cd8fb3a21dfea0021a7e801cba6951.jpg'),
(89837, 6262, 'O Ensaio S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/809170.mp4', 'http://gstaticontent.com/images/44a5ce990039a0e75aebddd61e8cefb8.jpg'),
(89838, 6262, 'O Ensaio S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/809171.mp4', 'http://gstaticontent.com/images/44a5ce990039a0e75aebddd61e8cefb8.jpg'),
(89839, 6262, 'O Ensaio S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/809172.mp4', 'http://gstaticontent.com/images/44a5ce990039a0e75aebddd61e8cefb8.jpg'),
(89840, 6262, 'O Ensaio S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/809173.mp4', 'http://gstaticontent.com/images/44a5ce990039a0e75aebddd61e8cefb8.jpg'),
(89841, 6262, 'O Ensaio S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/809174.mp4', 'http://gstaticontent.com/images/44a5ce990039a0e75aebddd61e8cefb8.jpg'),
(89842, 6263, 'o Coelhinho Perdido S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189719.mp4', 'http://timg.bdta.pro/images/43678054900a5cb83e747de525f2b1b4.jpg'),
(89843, 6263, 'o Coelhinho Perdido S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189720.mp4', 'http://timg.bdta.pro/images/765b1e7e40e76b41e16f693236c6013b.jpg'),
(89844, 6263, 'o Coelhinho Perdido S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189721.mp4', 'http://timg.bdta.pro/images/78852ab84130af00ccf1d1e1b3f2c7b3.jpg'),
(89845, 6263, 'o Coelhinho Perdido S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189722.mp4', 'http://timg.bdta.pro/images/e2d35e89339e4f46ae8c287786e4c5ec.jpg'),
(89846, 6264, 'Orange County à Venda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231862.mp4', 'http://gstaticontent.com/images/b7a14064175c04e5049bc19a5a951c2b.jpg'),
(89847, 6264, 'Orange County à Venda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231863.mp4', 'http://gstaticontent.com/images/b7a14064175c04e5049bc19a5a951c2b.jpg'),
(89848, 6264, 'Orange County à Venda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231864.mp4', 'http://gstaticontent.com/images/b7a14064175c04e5049bc19a5a951c2b.jpg'),
(89849, 6264, 'Orange County à Venda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231865.mp4', 'http://gstaticontent.com/images/b7a14064175c04e5049bc19a5a951c2b.jpg'),
(89850, 6264, 'Orange County à Venda S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231866.mp4', 'http://gstaticontent.com/images/b7a14064175c04e5049bc19a5a951c2b.jpg'),
(89851, 6264, 'Orange County à Venda S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231867.mp4', 'http://gstaticontent.com/images/b7a14064175c04e5049bc19a5a951c2b.jpg'),
(89852, 6264, 'Orange County à Venda S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231868.mp4', 'http://gstaticontent.com/images/b7a14064175c04e5049bc19a5a951c2b.jpg'),
(89853, 6264, 'Orange County à Venda S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231869.mp4', 'http://gstaticontent.com/images/b7a14064175c04e5049bc19a5a951c2b.jpg'),
(89854, 6265, 'Orange County à Venda S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u9sFaikaxDIE5lALaPmPOuNGYlE.jpg'),
(89855, 6265, 'Orange County à Venda S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/denrFMYSAbj1SS7Ji7fCP49tdnY.jpg'),
(89856, 6265, 'Orange County à Venda S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/razlCsw6rNEhEBNrnTdbkeriVa9.jpg'),
(89857, 6265, 'Orange County à Venda S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3yPPRPukn5fL5mJqWW9wwb219P0.jpg'),
(89858, 6265, 'Orange County à Venda S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/33PsEVUVr9lQBN3yVCURYT2h7m5.jpg'),
(89859, 6265, 'Orange County à Venda S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/osdddru0MfrGgODFIb2yBrVpfSU.jpg'),
(89860, 6265, 'Orange County à Venda S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eCmxaV1R0zdkSEe0Y5rH8hGtsvJ.jpg'),
(89861, 6265, 'Orange County à Venda S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7MMZxgzXGTdnEAR5jDv8t7VVFLM.jpg'),
(89862, 6266, 'Os Segredos das Piramides S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189713.mp4', 'http://gstaticontent.com/images/89c0763c2a02a342d96c9cde43a382c0.jpg'),
(89863, 6266, 'Os Segredos das Piramides S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189714.mp4', 'http://gstaticontent.com/images/89c0763c2a02a342d96c9cde43a382c0.jpg'),
(89864, 6266, 'Os Segredos das Piramides S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189715.mp4', 'http://gstaticontent.com/images/89c0763c2a02a342d96c9cde43a382c0.jpg'),
(89865, 6266, 'Os Segredos das Piramides S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189716.mp4', 'http://gstaticontent.com/images/89c0763c2a02a342d96c9cde43a382c0.jpg'),
(89866, 6266, 'Os Segredos das Piramides S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189717.mp4', 'http://gstaticontent.com/images/89c0763c2a02a342d96c9cde43a382c0.jpg'),
(89867, 6266, 'Os Segredos das Piramides S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189718.mp4', 'http://gstaticontent.com/images/89c0763c2a02a342d96c9cde43a382c0.jpg'),
(89868, 6267, 'Os Segredos das Piramides S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/441612.mp4', 'http://gstaticontent.com/images/89c0763c2a02a342d96c9cde43a382c0.jpg'),
(89869, 6267, 'Os Segredos das Piramides S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/441613.mp4', 'http://gstaticontent.com/images/89c0763c2a02a342d96c9cde43a382c0.jpg'),
(89870, 6267, 'Os Segredos das Piramides S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/441614.mp4', 'http://gstaticontent.com/images/89c0763c2a02a342d96c9cde43a382c0.jpg'),
(89871, 6267, 'Os Segredos das Piramides S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/441615.mp4', 'http://gstaticontent.com/images/89c0763c2a02a342d96c9cde43a382c0.jpg'),
(89872, 6267, 'Os Segredos das Piramides S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/441616.mp4', 'http://gstaticontent.com/images/89c0763c2a02a342d96c9cde43a382c0.jpg'),
(89873, 6267, 'Os Segredos das Piramides S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/441617.mp4', 'http://gstaticontent.com/images/89c0763c2a02a342d96c9cde43a382c0.jpg'),
(89874, 6268, 'Pais Por Acidente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189703.mp4', 'http://timg.bdta.pro/images/8010ca649a1ac7bfa7bc422d96ee968c.jpg'),
(89875, 6268, 'Pais Por Acidente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189704.mp4', 'http://timg.bdta.pro/images/fd44ad93f360214606dde733aa729bd4.jpg'),
(89876, 6268, 'Pais Por Acidente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189705.mp4', 'http://timg.bdta.pro/images/a1ccc82c30ec1f29bca1396ded2f0ad7.jpg'),
(89877, 6268, 'Pais Por Acidente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189706.mp4', 'http://timg.bdta.pro/images/b23c070867299c7fa9ac12d880a9e2a1.jpg'),
(89878, 6268, 'Pais Por Acidente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189707.mp4', 'http://timg.bdta.pro/images/ba1b9852dadb0b6f9b8dfd4e61aabcf3.jpg'),
(89879, 6268, 'Pais Por Acidente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189708.mp4', 'http://timg.bdta.pro/images/490fc115798fffba1a49fcebb0f63d4a.jpg'),
(89880, 6268, 'Pais Por Acidente S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189709.mp4', 'http://timg.bdta.pro/images/e9f422308ed0e1177d86f67e656fa63f.jpg'),
(89881, 6268, 'Pais Por Acidente S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189710.mp4', 'http://timg.bdta.pro/images/96f337a6616286f0b55778ffaccda071.jpg'),
(89882, 6268, 'Pais Por Acidente S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/189711.mp4', 'http://timg.bdta.pro/images/480a82145c43ffb05a6024feed0b5ab1.jpg'),
(89883, 6268, 'Pais Por Acidente S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/189712.mp4', 'http://timg.bdta.pro/images/5a6219ab048363805594304b09bae493.jpg'),
(89884, 6269, 'Pistol S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189697.mp4', 'http://timg.bdta.pro/images/af69072329f99736d4854013d1401b2d.jpg'),
(89885, 6269, 'Pistol S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189698.mp4', 'http://timg.bdta.pro/images/1845390d0c6801395e21198e3060c3df.jpg'),
(89886, 6269, 'Pistol S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189699.mp4', 'http://timg.bdta.pro/images/cb1b6d769b8f1c8eb6a3b550687fa9a9.jpg'),
(89887, 6269, 'Pistol S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189700.mp4', 'http://timg.bdta.pro/images/d2c3b7ee42f8a582d5ac56c686f60532.jpg'),
(89888, 6269, 'Pistol S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189701.mp4', 'http://timg.bdta.pro/images/bba43509548d086653f5bddc91bd7e8c.jpg'),
(89889, 6269, 'Pistol S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189702.mp4', 'http://timg.bdta.pro/images/8960e002e1930c614acaf8faa9692f0f.jpg'),
(89890, 6270, 'Players S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189687.mp4', 'http://timg.bdta.pro/images/b266d194543922fb7859ec3e80d1be81.jpg'),
(89891, 6270, 'Players S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189688.mp4', 'http://timg.bdta.pro/images/6a59568dffd01ffefd9eb86bfbb19c2c.jpg'),
(89892, 6270, 'Players S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189689.mp4', 'http://timg.bdta.pro/images/f5beb2fde802d554c0bb99bd82f7c1ac.jpg'),
(89893, 6270, 'Players S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189690.mp4', 'http://timg.bdta.pro/images/c761d80efa26f1258e27e93e8538a620.jpg'),
(89894, 6270, 'Players S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189691.mp4', 'http://timg.bdta.pro/images/b9b0a34600adcda546c67d85979e8333.jpg'),
(89895, 6270, 'Players S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189692.mp4', 'http://timg.bdta.pro/images/67ce3228f884d2645e2d9b7362f17899.jpg'),
(89896, 6270, 'Players S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189693.mp4', 'http://timg.bdta.pro/images/0be441f0d792db851cc5868a39c1d32c.jpg'),
(89897, 6270, 'Players S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189694.mp4', 'http://timg.bdta.pro/images/88fcaa1a7b9cab9e72cb650b78fff57d.jpg'),
(89898, 6270, 'Players S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/189695.mp4', 'http://timg.bdta.pro/images/137760b34776f16345e744eeac7f1d7c.jpg'),
(89899, 6270, 'Players S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/189696.mp4', 'http://timg.bdta.pro/images/13494c1d3a053f79816fa9a88ade9f9f.jpg'),
(89900, 6271, 'Queer as Folk S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189679.mp4', 'http://timg.bdta.pro/images/6cab06da09fcd89fcfc9e07d0f479d39.jpg'),
(89901, 6271, 'Queer as Folk S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189680.mp4', 'http://timg.bdta.pro/images/65f0909db5783589d88cff127f374012.jpg'),
(89902, 6271, 'Queer as Folk S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189681.mp4', 'http://timg.bdta.pro/images/0b14d6c9977f0ec82628fadd033df08a.jpg'),
(89903, 6271, 'Queer as Folk S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189682.mp4', 'http://timg.bdta.pro/images/ba4005fa1e136df18646eea3db02017b.jpg'),
(89904, 6271, 'Queer as Folk S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189683.mp4', 'http://timg.bdta.pro/images/4e74596253de58ede442ee476ed38d04.jpg'),
(89905, 6271, 'Queer as Folk S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189684.mp4', 'http://timg.bdta.pro/images/be63fe8c3e9ebfca59638a2598fa94d5.jpg'),
(89906, 6271, 'Queer as Folk S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189685.mp4', 'http://timg.bdta.pro/images/61479da8125277db17da58ba5fbd99e6.jpg'),
(89907, 6271, 'Queer as Folk S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189686.mp4', 'http://timg.bdta.pro/images/73f83f6562ed80913c73de6b1b093ed7.jpg'),
(89908, 6272, 'Reformas Inacreditáveis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189671.mp4', 'http://timg.bdta.pro/images/623407e3951c1f5f92a75a984a82eddc.jpg'),
(89909, 6272, 'Reformas Inacreditáveis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189672.mp4', 'http://timg.bdta.pro/images/2bb129262a2c633864b810c54b7944de.jpg'),
(89910, 6272, 'Reformas Inacreditáveis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189673.mp4', 'http://timg.bdta.pro/images/0fb2c0c679bb819a6f3860cb8dc11ac2.jpg'),
(89911, 6272, 'Reformas Inacreditáveis S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189674.mp4', 'http://timg.bdta.pro/images/4c9f2e4e2fb597372ad9539b247b6fd8.jpg'),
(89912, 6272, 'Reformas Inacreditáveis S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189675.mp4', 'http://timg.bdta.pro/images/6a27b60517e96d8ac0d303238e1f7162.jpg'),
(89913, 6272, 'Reformas Inacreditáveis S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189676.mp4', 'http://timg.bdta.pro/images/32d10a1354d84cfaf20b47ba0ff00171.jpg'),
(89914, 6272, 'Reformas Inacreditáveis S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189677.mp4', 'http://timg.bdta.pro/images/57e89eab291e34427e2bb76db7429ddb.jpg'),
(89915, 6272, 'Reformas Inacreditáveis S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189678.mp4', 'http://timg.bdta.pro/images/6d8eea2ea7a3e25c8dc404ba32129445.jpg'),
(89916, 6273, 'Rensga Hits! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189663.mp4', 'http://timg.bdta.pro/images/cf8f796a3bff1d9c9c3d9dc6c59d2ce6.jpg'),
(89917, 6273, 'Rensga Hits! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189664.mp4', 'http://timg.bdta.pro/images/1d6f98204981a20e8b489775101d4955.jpg'),
(89918, 6273, 'Rensga Hits! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189665.mp4', 'http://timg.bdta.pro/images/7b5251cf1889ea5579c4f0179626f2e6.jpg'),
(89919, 6273, 'Rensga Hits! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189666.mp4', 'http://timg.bdta.pro/images/6c5990c98a96ddacbce9d77e7f9202e8.jpg'),
(89920, 6273, 'Rensga Hits! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189667.mp4', 'http://timg.bdta.pro/images/4e7db6b34c9439013b22be623aba187d.jpg'),
(89921, 6273, 'Rensga Hits! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189668.mp4', 'http://timg.bdta.pro/images/704a4c228ac07add67243ab1d7611bd0.jpg'),
(89922, 6273, 'Rensga Hits! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189669.mp4', 'http://timg.bdta.pro/images/070d1b1e46cc5caa06a2ce8ec1b01406.jpg'),
(89923, 6273, 'Rensga Hits! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189670.mp4', 'http://timg.bdta.pro/images/7b6852fa69f81cd0eaa1ccdd031471c2.jpg'),
(89924, 6274, 'Rensga Hits! S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/463759.mp4', 'http://gstaticontent.com/images/39f20e10570ec40dcbf2aad3d8abe0ce.jpg'),
(89925, 6274, 'Rensga Hits! S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/463760.mp4', 'http://gstaticontent.com/images/39f20e10570ec40dcbf2aad3d8abe0ce.jpg'),
(89926, 6274, 'Rensga Hits! S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/463761.mp4', 'http://gstaticontent.com/images/39f20e10570ec40dcbf2aad3d8abe0ce.jpg'),
(89927, 6274, 'Rensga Hits! S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/463762.mp4', 'http://gstaticontent.com/images/39f20e10570ec40dcbf2aad3d8abe0ce.jpg'),
(89928, 6274, 'Rensga Hits! S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/472302.mp4', 'http://gstaticontent.com/images/39f20e10570ec40dcbf2aad3d8abe0ce.jpg'),
(89929, 6274, 'Rensga Hits! S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/472303.mp4', 'http://gstaticontent.com/images/39f20e10570ec40dcbf2aad3d8abe0ce.jpg'),
(89930, 6274, 'Rensga Hits! S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/485227.mp4', 'http://gstaticontent.com/images/39f20e10570ec40dcbf2aad3d8abe0ce.jpg'),
(89931, 6274, 'Rensga Hits! S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/485228.mp4', 'http://gstaticontent.com/images/39f20e10570ec40dcbf2aad3d8abe0ce.jpg'),
(89932, 6275, 'Rensga Hits! S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/864998.mp4', 'http://gstaticontent.com/images/39f20e10570ec40dcbf2aad3d8abe0ce.jpg'),
(89933, 6275, 'Rensga Hits! S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/864999.mp4', 'http://gstaticontent.com/images/39f20e10570ec40dcbf2aad3d8abe0ce.jpg'),
(89934, 6275, 'Rensga Hits! S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/865000.mp4', 'http://gstaticontent.com/images/39f20e10570ec40dcbf2aad3d8abe0ce.jpg'),
(89935, 6275, 'Rensga Hits! S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/865001.mp4', 'http://gstaticontent.com/images/39f20e10570ec40dcbf2aad3d8abe0ce.jpg'),
(89936, 6275, 'Rensga Hits! S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/865002.mp4', 'http://gstaticontent.com/images/39f20e10570ec40dcbf2aad3d8abe0ce.jpg'),
(89937, 6275, 'Rensga Hits! S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/865003.mp4', 'http://gstaticontent.com/images/39f20e10570ec40dcbf2aad3d8abe0ce.jpg'),
(89938, 6275, 'Rensga Hits! S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/865004.mp4', 'http://gstaticontent.com/images/39f20e10570ec40dcbf2aad3d8abe0ce.jpg'),
(89939, 6275, 'Rensga Hits! S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/865005.mp4', 'http://gstaticontent.com/images/39f20e10570ec40dcbf2aad3d8abe0ce.jpg'),
(89940, 6276, 'S.M.A.S.H. Acampamento de Super herois S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189650.mp4', 'http://gstaticontent.com/images/9b6bae16984400a713b2183f814671da.jpg'),
(89941, 6276, 'S.M.A.S.H. Acampamento de Super herois S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189651.mp4', 'http://gstaticontent.com/images/9b6bae16984400a713b2183f814671da.jpg'),
(89942, 6276, 'S.M.A.S.H. Acampamento de Super herois S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189652.mp4', 'http://gstaticontent.com/images/9b6bae16984400a713b2183f814671da.jpg'),
(89943, 6276, 'S.M.A.S.H. Acampamento de Super herois S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189653.mp4', 'http://gstaticontent.com/images/9b6bae16984400a713b2183f814671da.jpg'),
(89944, 6276, 'S.M.A.S.H. Acampamento de Super herois S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189654.mp4', 'http://gstaticontent.com/images/9b6bae16984400a713b2183f814671da.jpg'),
(89945, 6276, 'S.M.A.S.H. Acampamento de Super herois S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189655.mp4', 'http://gstaticontent.com/images/9b6bae16984400a713b2183f814671da.jpg'),
(89946, 6276, 'S.M.A.S.H. Acampamento de Super herois S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189656.mp4', 'http://gstaticontent.com/images/9b6bae16984400a713b2183f814671da.jpg'),
(89947, 6276, 'S.M.A.S.H. Acampamento de Super herois S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189657.mp4', 'http://gstaticontent.com/images/9b6bae16984400a713b2183f814671da.jpg'),
(89948, 6276, 'S.M.A.S.H. Acampamento de Super herois S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/189658.mp4', 'http://gstaticontent.com/images/9b6bae16984400a713b2183f814671da.jpg'),
(89949, 6276, 'S.M.A.S.H. Acampamento de Super herois S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/189659.mp4', 'http://gstaticontent.com/images/9b6bae16984400a713b2183f814671da.jpg'),
(89950, 6276, 'S.M.A.S.H. Acampamento de Super herois S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/189660.mp4', 'http://gstaticontent.com/images/9b6bae16984400a713b2183f814671da.jpg'),
(89951, 6276, 'S.M.A.S.H. Acampamento de Super herois S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/189661.mp4', 'http://gstaticontent.com/images/9b6bae16984400a713b2183f814671da.jpg'),
(89952, 6276, 'S.M.A.S.H. Acampamento de Super herois S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/189662.mp4', 'http://gstaticontent.com/images/9b6bae16984400a713b2183f814671da.jpg'),
(89953, 6277, 'Saihate no Paladin S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189638.mp4', 'http://timg.bdta.pro/images/74b75ab4131a3bd913284f83f0e9eb6a.jpg'),
(89954, 6277, 'Saihate no Paladin S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189639.mp4', 'http://timg.bdta.pro/images/854f233d1cafa257b4f68d8aef8488a8.jpg'),
(89955, 6277, 'Saihate no Paladin S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189640.mp4', 'http://timg.bdta.pro/images/7fc5b9ecb4f9ced34c90f1fefe33acd1.jpg'),
(89956, 6277, 'Saihate no Paladin S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189641.mp4', 'http://timg.bdta.pro/images/a7f778fd90a710384afd810a5d74ea56.jpg'),
(89957, 6277, 'Saihate no Paladin S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189642.mp4', 'http://timg.bdta.pro/images/52982db50c8402bf1c8c231b99ef19b4.jpg'),
(89958, 6277, 'Saihate no Paladin S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189643.mp4', 'http://timg.bdta.pro/images/34cedce72ee0f16fb0d9a0226a051a38.jpg'),
(89959, 6277, 'Saihate no Paladin S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189644.mp4', 'http://timg.bdta.pro/images/33cc642e360ed82e252f6d215be7246d.jpg'),
(89960, 6277, 'Saihate no Paladin S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189645.mp4', 'http://timg.bdta.pro/images/b5f97a0029460d0b35ecb411c70273f9.jpg'),
(89961, 6277, 'Saihate no Paladin S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/189646.mp4', 'http://timg.bdta.pro/images/5b5d988e5cd72449605880c9907d5086.jpg'),
(89962, 6277, 'Saihate no Paladin S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/189647.mp4', 'http://timg.bdta.pro/images/fbdd16dffc74e87090b9ae6f208e989a.jpg'),
(89963, 6277, 'Saihate no Paladin S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/189648.mp4', 'http://timg.bdta.pro/images/f1e1b0a4fb97bf1b8f6aa15cbc577756.jpg'),
(89964, 6277, 'Saihate no Paladin S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/189649.mp4', 'http://timg.bdta.pro/images/762a6f85bdef60df686d5e62f4d80d1f.jpg'),
(89965, 6278, 'The Girl from Plainville S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189630.mp4', 'http://timg.bdta.pro/images/3b3d2366fa395347a70d1e911d98db73.jpg'),
(89966, 6278, 'The Girl from Plainville S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189631.mp4', 'http://timg.bdta.pro/images/7c9c13dedf422be78cbcf303a9390d7c.jpg'),
(89967, 6278, 'The Girl from Plainville S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189632.mp4', 'http://timg.bdta.pro/images/067091282c57e05027c3c37c960332ab.jpg'),
(89968, 6278, 'The Girl from Plainville S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189633.mp4', 'http://timg.bdta.pro/images/b366e26ad5835b79224296d2ec6dc713.jpg'),
(89969, 6278, 'The Girl from Plainville S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189634.mp4', 'http://timg.bdta.pro/images/1ba9c0d5d7757591bf71941e1f19b15b.jpg'),
(89970, 6278, 'The Girl from Plainville S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189635.mp4', 'http://timg.bdta.pro/images/b66d99464ae8c030ee58de235b164e08.jpg'),
(89971, 6278, 'The Girl from Plainville S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189636.mp4', 'http://timg.bdta.pro/images/e4c38c8224b43b5745d17dfde609db18.jpg'),
(89972, 6278, 'The Girl from Plainville S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189637.mp4', 'http://timg.bdta.pro/images/17ec4ee8d79d46270017538e0ce0c0b5.jpg'),
(89973, 6279, 'The Old Man S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192246.mp4', 'http://timg.bdta.pro/images/be2c99245efdc618e05c7ef6b17b409c.jpg'),
(89974, 6279, 'The Old Man S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192247.mp4', 'http://timg.bdta.pro/images/6444e483124e87113e39f9496824bc75.jpg'),
(89975, 6279, 'The Old Man S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192248.mp4', 'http://timg.bdta.pro/images/f38b4f236738b5e8fe905283ac05bbbc.jpg'),
(89976, 6279, 'The Old Man S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192249.mp4', 'http://timg.bdta.pro/images/5068c2d17927b68ec565bfd386452c61.jpg'),
(89977, 6279, 'The Old Man S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192250.mp4', 'http://timg.bdta.pro/images/761ab9833771446e267a5ac7fcb2c085.jpg'),
(89978, 6279, 'The Old Man S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192251.mp4', 'http://timg.bdta.pro/images/04c353bc09fefab837b480917cb874bf.jpg'),
(89979, 6279, 'The Old Man S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192252.mp4', 'http://timg.bdta.pro/images/ed22544e663073bfc706ff6b3f2238b2.jpg'),
(89980, 6280, 'The Old Man S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/454205.mp4', 'http://gstaticontent.com/images/28370db4d9decc833566b22597235c0f.jpg'),
(89981, 6280, 'The Old Man S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/454206.mp4', 'http://gstaticontent.com/images/28370db4d9decc833566b22597235c0f.jpg'),
(89982, 6280, 'The Old Man S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/458910.mp4', 'http://gstaticontent.com/images/28370db4d9decc833566b22597235c0f.jpg'),
(89983, 6280, 'The Old Man S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/466203.mp4', 'http://gstaticontent.com/images/28370db4d9decc833566b22597235c0f.jpg'),
(89984, 6280, 'The Old Man S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/471765.mp4', 'http://gstaticontent.com/images/28370db4d9decc833566b22597235c0f.jpg'),
(89985, 6280, 'The Old Man S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/484869.mp4', 'http://gstaticontent.com/images/28370db4d9decc833566b22597235c0f.jpg'),
(89986, 6280, 'The Old Man S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/488055.mp4', 'http://gstaticontent.com/images/28370db4d9decc833566b22597235c0f.jpg'),
(89987, 6280, 'The Old Man S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/489940.mp4', 'http://gstaticontent.com/images/28370db4d9decc833566b22597235c0f.jpg'),
(89988, 6281, 'The Orville S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189594.mp4', 'http://timg.bdta.pro/images/38b407f517e8831a1e393d3c80b5fc18.jpg'),
(89989, 6281, 'The Orville S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189595.mp4', 'http://timg.bdta.pro/images/ea4f156a00df1a84958b141f051775c3.jpg'),
(89990, 6281, 'The Orville S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189596.mp4', 'http://timg.bdta.pro/images/50bfe5d9108777fbaa2e17e289810c5b.jpg'),
(89991, 6281, 'The Orville S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189597.mp4', 'http://timg.bdta.pro/images/64cddd51eafd71e7631b17e15e5da1e1.jpg'),
(89992, 6281, 'The Orville S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189598.mp4', 'http://timg.bdta.pro/images/80d5f0349993aace13273fb2ff91ae59.jpg'),
(89993, 6281, 'The Orville S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189599.mp4', 'http://timg.bdta.pro/images/b32c313c28a55bc7b410aa7e9542d83b.jpg'),
(89994, 6281, 'The Orville S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189600.mp4', 'http://timg.bdta.pro/images/a6d2e7a59856a5a3e6ea67e80d80a6a4.jpg'),
(89995, 6281, 'The Orville S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189601.mp4', 'http://timg.bdta.pro/images/ff86c7b3ed811c6e716562132fa50004.jpg'),
(89996, 6281, 'The Orville S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/189602.mp4', 'http://timg.bdta.pro/images/68ce2af74d18e49e1b4f41b91a88b1fd.jpg'),
(89997, 6281, 'The Orville S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/189603.mp4', 'http://timg.bdta.pro/images/22ae2a25389e61969a7fbd4672213cab.jpg'),
(89998, 6281, 'The Orville S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/189604.mp4', 'http://timg.bdta.pro/images/7151e1b27fc8533ff6f085dd4e8c6a0c.jpg'),
(89999, 6281, 'The Orville S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/189605.mp4', 'http://timg.bdta.pro/images/8cd8bc9528871b53b700a9b609738cd1.jpg'),
(90000, 6282, 'The Orville S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189606.mp4', 'http://timg.bdta.pro/images/84c74e7c6ad4d891e31dad30c777fc89.jpg'),
(90001, 6282, 'The Orville S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189607.mp4', 'http://timg.bdta.pro/images/7b0bfab0402635f2a91ed645120e3ad2.jpg'),
(90002, 6282, 'The Orville S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189608.mp4', 'http://timg.bdta.pro/images/cc0d13001f2f537eedb5a154adcc722f.jpg'),
(90003, 6282, 'The Orville S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189609.mp4', 'http://timg.bdta.pro/images/4e0d39d6749b40dc2d0a76ed6c1f2140.jpg'),
(90004, 6282, 'The Orville S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189610.mp4', 'http://timg.bdta.pro/images/26a4d01d428ca4abeede2b9835010da9.jpg'),
(90005, 6282, 'The Orville S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189611.mp4', 'http://timg.bdta.pro/images/c3cf1d2dadf08b2471088713374016c2.jpg'),
(90006, 6282, 'The Orville S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189612.mp4', 'http://timg.bdta.pro/images/3f6e81d835ac715c614eaa4e626cc977.jpg'),
(90007, 6282, 'The Orville S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189613.mp4', 'http://timg.bdta.pro/images/14b0b58100c402011d81b79749aa1d1e.jpg'),
(90008, 6282, 'The Orville S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/189614.mp4', 'http://timg.bdta.pro/images/e71a377f21850b6a137377eb5e7e3a35.jpg'),
(90009, 6282, 'The Orville S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/189615.mp4', 'http://timg.bdta.pro/images/6103404d3ff2159c26045b99a5ff0362.jpg'),
(90010, 6282, 'The Orville S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/189616.mp4', 'http://timg.bdta.pro/images/ac1c9709870fcc944024811fb51ccb23.jpg'),
(90011, 6282, 'The Orville S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/189617.mp4', 'http://timg.bdta.pro/images/99cdcac877e2a46e7defdd5533b03a48.jpg'),
(90012, 6282, 'The Orville S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/189618.mp4', 'http://timg.bdta.pro/images/a2c9bd990b27b4e4e9bd50c70cf0d080.jpg'),
(90013, 6282, 'The Orville S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/189619.mp4', 'http://timg.bdta.pro/images/96509b17c3f96ea8c0fb77f57244d594.jpg'),
(90014, 6283, 'The Orville S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189620.mp4', 'http://timg.bdta.pro/images/7d81eb3c6da0475f1f8568158638ba19.jpg'),
(90015, 6283, 'The Orville S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189621.mp4', 'http://timg.bdta.pro/images/543ad7db8c3fdaca0adc1b0ae24814c7.jpg'),
(90016, 6283, 'The Orville S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189622.mp4', 'http://timg.bdta.pro/images/795a341571ac5de6d61b3062134c73ee.jpg'),
(90017, 6283, 'The Orville S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189623.mp4', 'http://timg.bdta.pro/images/38c099a4cb610094e46ec4d63770aeb7.jpg'),
(90018, 6283, 'The Orville S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189624.mp4', 'http://timg.bdta.pro/images/76e0205eac74ff03efd737b5e45596d7.jpg'),
(90019, 6283, 'The Orville S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189625.mp4', 'http://timg.bdta.pro/images/8761b3de2cf9b83e68698df5f0d65771.jpg'),
(90020, 6283, 'The Orville S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189626.mp4', 'http://timg.bdta.pro/images/82518d5e548edea208d6a26a61fdf939.jpg'),
(90021, 6283, 'The Orville S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189627.mp4', 'http://timg.bdta.pro/images/8d5c4b8c1f79e73386334bb6e26c612c.jpg'),
(90022, 6283, 'The Orville S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/189628.mp4', 'http://timg.bdta.pro/images/824e07309a6f23d3116af9c6762b64b4.jpg'),
(90023, 6283, 'The Orville S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/189629.mp4', 'http://timg.bdta.pro/images/18fb47ed5cf8f37b94c88d507d0f1718.jpg'),
(90024, 6284, 'Uma Equipe Muito Especial S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189586.mp4', 'http://timg.bdta.pro/images/03957a8ec9c7d2e5b8c4fd4ceff0043d.jpg'),
(90025, 6284, 'Uma Equipe Muito Especial S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189587.mp4', 'http://timg.bdta.pro/images/9a4655df30380067afae4ee87b4e8518.jpg'),
(90026, 6284, 'Uma Equipe Muito Especial S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189588.mp4', 'http://timg.bdta.pro/images/b6749730a63ad80ec2ccd4d687ad470a.jpg'),
(90027, 6284, 'Uma Equipe Muito Especial S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189589.mp4', 'http://timg.bdta.pro/images/a0f237e3a61adca3e150e130940316a0.jpg'),
(90028, 6284, 'Uma Equipe Muito Especial S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189590.mp4', 'http://timg.bdta.pro/images/44c2d53dfbb21bb02f74c718c77ea792.jpg'),
(90029, 6284, 'Uma Equipe Muito Especial S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189591.mp4', 'http://timg.bdta.pro/images/75d2c248e85e4b39f96587c045b8f607.jpg'),
(90030, 6284, 'Uma Equipe Muito Especial S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189592.mp4', 'http://timg.bdta.pro/images/7bcc86aadfe4ccea2bdb37ebfec9095a.jpg'),
(90031, 6284, 'Uma Equipe Muito Especial S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189593.mp4', 'http://timg.bdta.pro/images/69f2d9cb32a4b65836eb8153df3a8a50.jpg'),
(90032, 6285, 'Uma Família Exemplar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189576.mp4', 'http://timg.bdta.pro/images/2034960cfe94199023208f931df86ec8.jpg'),
(90033, 6285, 'Uma Família Exemplar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189577.mp4', 'http://timg.bdta.pro/images/25e73aae6edbc09ae2f189bb66473cf7.jpg'),
(90034, 6285, 'Uma Família Exemplar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189578.mp4', 'http://timg.bdta.pro/images/134681896212ce59bf78897f8a245019.jpg'),
(90035, 6285, 'Uma Família Exemplar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189579.mp4', 'http://timg.bdta.pro/images/0c58145805b7d21b03727cf2920a3b94.jpg'),
(90036, 6285, 'Uma Família Exemplar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189580.mp4', 'http://timg.bdta.pro/images/cc9aa212bf789ad9e68963963b3d96b9.jpg'),
(90037, 6285, 'Uma Família Exemplar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189581.mp4', 'http://timg.bdta.pro/images/79d4363ffa702208dd5d019083086cf4.jpg'),
(90038, 6285, 'Uma Família Exemplar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/189582.mp4', 'http://timg.bdta.pro/images/b2cfc31fb7d27c9db254fc5f16fae900.jpg'),
(90039, 6285, 'Uma Família Exemplar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/189583.mp4', 'http://timg.bdta.pro/images/86549894beb48edefd2adf77c4fe8253.jpg'),
(90040, 6285, 'Uma Família Exemplar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/189584.mp4', 'http://timg.bdta.pro/images/248af7751679a4ba1850327795c0acb9.jpg'),
(90041, 6285, 'Uma Família Exemplar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/189585.mp4', 'http://timg.bdta.pro/images/260ae4c4ddbfb193cee6765aadc574b9.jpg'),
(90042, 6286, 'Unbroken: Nada A Perder S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/189570.mp4', 'http://timg.bdta.pro/images/9763b3f9ea5e2b9464746fed20146300.jpg'),
(90043, 6286, 'Unbroken: Nada A Perder S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/189571.mp4', 'http://timg.bdta.pro/images/95a3d92277e0c482d4c7ba1356dce8f2.jpg'),
(90044, 6286, 'Unbroken: Nada A Perder S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/189572.mp4', 'http://timg.bdta.pro/images/f90c53c5e0bb7ef43df55237cc319613.jpg'),
(90045, 6286, 'Unbroken: Nada A Perder S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/189573.mp4', 'http://timg.bdta.pro/images/bae16d13bdf4c3a78daa74877b2ce107.jpg'),
(90046, 6286, 'Unbroken: Nada A Perder S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/189574.mp4', 'http://timg.bdta.pro/images/de7f3cb1831172fc0cd41463eaccd3bd.jpg'),
(90047, 6286, 'Unbroken: Nada A Perder S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/189575.mp4', 'http://timg.bdta.pro/images/84faab4923fc02544ca53a907e4b8a9a.jpg'),
(90048, 6287, 'À Prova de Tudo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195176.mp4', 'http://gstaticontent.com/images/729b4fa4183d91fb9d72851dd627e2e4.jpg'),
(90049, 6287, 'À Prova de Tudo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195177.mp4', 'http://gstaticontent.com/images/729b4fa4183d91fb9d72851dd627e2e4.jpg'),
(90050, 6287, 'À Prova de Tudo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195178.mp4', 'http://gstaticontent.com/images/729b4fa4183d91fb9d72851dd627e2e4.jpg'),
(90051, 6287, 'À Prova de Tudo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195179.mp4', 'http://gstaticontent.com/images/729b4fa4183d91fb9d72851dd627e2e4.jpg'),
(90052, 6287, 'À Prova de Tudo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195180.mp4', 'http://gstaticontent.com/images/729b4fa4183d91fb9d72851dd627e2e4.jpg'),
(90053, 6287, 'À Prova de Tudo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195181.mp4', 'http://gstaticontent.com/images/729b4fa4183d91fb9d72851dd627e2e4.jpg'),
(90054, 6287, 'À Prova de Tudo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195182.mp4', 'http://timg.bdta.pro/images/732fa5707858329ec3a4048c38e1c3e4.jpg'),
(90055, 6287, 'À Prova de Tudo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195183.mp4', 'http://gstaticontent.com/images/729b4fa4183d91fb9d72851dd627e2e4.jpg'),
(90056, 6287, 'À Prova de Tudo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195184.mp4', 'http://gstaticontent.com/images/729b4fa4183d91fb9d72851dd627e2e4.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(90057, 6287, 'À Prova de Tudo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195185.mp4', 'http://timg.bdta.pro/images/e128c787b2b92a9d9822e756eb01b121.jpg'),
(90058, 6287, 'À Prova de Tudo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/195186.mp4', 'http://timg.bdta.pro/images/f9b4317351e40b3efaa0ca9e7bef3d03.jpg'),
(90059, 6287, 'À Prova de Tudo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/195187.mp4', 'http://timg.bdta.pro/images/e17a6ca2e7e97f9d2e8ba23666ea2cae.jpg'),
(90060, 6287, 'À Prova de Tudo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/195188.mp4', 'http://timg.bdta.pro/images/5d5d46ea04de46dc5fd9adad1188caec.jpg'),
(90061, 6287, 'À Prova de Tudo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/195189.mp4', 'http://timg.bdta.pro/images/eb4e6343b7295a4f9f8fb4eefdb9133c.jpg'),
(90062, 6287, 'À Prova de Tudo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/195190.mp4', 'http://timg.bdta.pro/images/d2a6b8ffd4b6a76127d9c00c4381f194.jpg'),
(90063, 6288, 'À Prova de Tudo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195191.mp4', 'http://timg.bdta.pro/images/78735d50a48fe9de6d91f1b2feb69c2c.jpg'),
(90064, 6288, 'À Prova de Tudo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195192.mp4', 'http://timg.bdta.pro/images/e15f81ede526b524f7e39349e8edfa8c.jpg'),
(90065, 6288, 'À Prova de Tudo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195193.mp4', 'http://timg.bdta.pro/images/a39aa469122a74fc6b5e824818477cf1.jpg'),
(90066, 6288, 'À Prova de Tudo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195194.mp4', 'http://timg.bdta.pro/images/6a98f21049d01a6dfccec43b96ab3bc0.jpg'),
(90067, 6288, 'À Prova de Tudo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195195.mp4', 'http://timg.bdta.pro/images/51af6f150c746dd36e9138586ebd5e47.jpg'),
(90068, 6288, 'À Prova de Tudo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195196.mp4', 'http://timg.bdta.pro/images/ede1fe7319507838b0dab6040a699438.jpg'),
(90069, 6288, 'À Prova de Tudo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195197.mp4', 'http://timg.bdta.pro/images/d7a7e9ad206d356e63a3dd15b91bbdd9.jpg'),
(90070, 6288, 'À Prova de Tudo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195198.mp4', 'http://timg.bdta.pro/images/1f439998ee9523902873387c723661c9.jpg'),
(90071, 6288, 'À Prova de Tudo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195199.mp4', 'http://timg.bdta.pro/images/9af0d8593cfb19a19413b9089951b139.jpg'),
(90072, 6288, 'À Prova de Tudo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195200.mp4', 'http://timg.bdta.pro/images/832133dcdf11135ed9223374e4882fbc.jpg'),
(90073, 6288, 'À Prova de Tudo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/195201.mp4', 'http://timg.bdta.pro/images/15286a499d07b18bb90751847ba19693.jpg'),
(90074, 6288, 'À Prova de Tudo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/195202.mp4', 'http://timg.bdta.pro/images/2581dc0ace37daeeb62a686777601686.jpg'),
(90075, 6288, 'À Prova de Tudo S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/195203.mp4', 'http://timg.bdta.pro/images/cd8d043fb9ca1ec3bed6d575fbe2bc58.jpg'),
(90076, 6289, 'À Prova de Tudo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195204.mp4', 'http://timg.bdta.pro/images/01c3e1c4257f303f3583cabbd5ee866f.jpg'),
(90077, 6289, 'À Prova de Tudo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195205.mp4', 'http://timg.bdta.pro/images/fc68ece66d8239482fde32792d44471f.jpg'),
(90078, 6289, 'À Prova de Tudo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195206.mp4', 'http://timg.bdta.pro/images/d12868cedec0671fa367ab69574d3437.jpg'),
(90079, 6289, 'À Prova de Tudo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195207.mp4', 'http://timg.bdta.pro/images/6c00e5f55d72e91ffbc5257906359ff4.jpg'),
(90080, 6289, 'À Prova de Tudo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195208.mp4', 'http://timg.bdta.pro/images/13765468d7b82dcce3abaeb203e78276.jpg'),
(90081, 6289, 'À Prova de Tudo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195209.mp4', 'http://timg.bdta.pro/images/3ce27dac42c6d562b17e2e6b3bebccaa.jpg'),
(90082, 6289, 'À Prova de Tudo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195210.mp4', 'http://timg.bdta.pro/images/61e65de58074f316c0ff228a6741c450.jpg'),
(90083, 6289, 'À Prova de Tudo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195211.mp4', 'http://timg.bdta.pro/images/dc859754cc2c28e54de2e772d78082ef.jpg'),
(90084, 6289, 'À Prova de Tudo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195212.mp4', 'http://timg.bdta.pro/images/cc48d3a25c7029d3b454cd242c0b62e0.jpg'),
(90085, 6289, 'À Prova de Tudo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195213.mp4', 'http://timg.bdta.pro/images/75758df4f2e7c8e66782d21ba1572820.jpg'),
(90086, 6289, 'À Prova de Tudo S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/195214.mp4', 'http://gstaticontent.com/images/729b4fa4183d91fb9d72851dd627e2e4.jpg'),
(90087, 6290, 'À Prova de Tudo S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195215.mp4', 'http://timg.bdta.pro/images/b4fae97f7a5076bbb89fb3fecc993aed.jpg'),
(90088, 6290, 'À Prova de Tudo S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195216.mp4', 'http://timg.bdta.pro/images/3b1db2cc4fb5953531c789982559589a.jpg'),
(90089, 6290, 'À Prova de Tudo S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195217.mp4', 'http://timg.bdta.pro/images/a3e3775d7daa83255e0932582efbb221.jpg'),
(90090, 6290, 'À Prova de Tudo S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195218.mp4', 'http://timg.bdta.pro/images/2a57339cbdcebf0ad27532328864a07d.jpg'),
(90091, 6290, 'À Prova de Tudo S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195219.mp4', 'http://timg.bdta.pro/images/d4a37ec453bffd7d5a2330c26f6e1422.jpg'),
(90092, 6290, 'À Prova de Tudo S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195220.mp4', 'http://timg.bdta.pro/images/85c48f3403b92f71da36684bbef86978.jpg'),
(90093, 6290, 'À Prova de Tudo S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195221.mp4', 'http://timg.bdta.pro/images/4bfe5ef9a1ed2ec6838be18cc193970c.jpg'),
(90094, 6290, 'À Prova de Tudo S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195222.mp4', 'http://timg.bdta.pro/images/39a39fe1e39d3d946e69674c71ba50c3.jpg'),
(90095, 6290, 'À Prova de Tudo S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195223.mp4', 'http://timg.bdta.pro/images/ee3c1d669a6a7b8b17352bd153cd4bee.jpg'),
(90096, 6290, 'À Prova de Tudo S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195224.mp4', 'http://timg.bdta.pro/images/24b3580f9cee213c0af600255b912680.jpg'),
(90097, 6290, 'À Prova de Tudo S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/195225.mp4', 'http://gstaticontent.com/images/729b4fa4183d91fb9d72851dd627e2e4.jpg'),
(90098, 6290, 'À Prova de Tudo S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/195226.mp4', 'http://gstaticontent.com/images/729b4fa4183d91fb9d72851dd627e2e4.jpg'),
(90099, 6290, 'À Prova de Tudo S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/195227.mp4', 'http://gstaticontent.com/images/729b4fa4183d91fb9d72851dd627e2e4.jpg'),
(90100, 6291, 'À Prova de Tudo S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195228.mp4', 'http://timg.bdta.pro/images/022531ba3593e88a1c478a162b3d4241.jpg'),
(90101, 6291, 'À Prova de Tudo S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195229.mp4', 'http://timg.bdta.pro/images/c6bfd41a259ad1b05fea880f8862444d.jpg'),
(90102, 6291, 'À Prova de Tudo S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195230.mp4', 'http://timg.bdta.pro/images/2a57339cbdcebf0ad27532328864a07d.jpg'),
(90103, 6291, 'À Prova de Tudo S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195231.mp4', 'http://gstaticontent.com/images/729b4fa4183d91fb9d72851dd627e2e4.jpg'),
(90104, 6291, 'À Prova de Tudo S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195232.mp4', 'http://timg.bdta.pro/images/1664ad5aa2895ced3cde46ff3d8207da.jpg'),
(90105, 6291, 'À Prova de Tudo S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195233.mp4', 'http://gstaticontent.com/images/729b4fa4183d91fb9d72851dd627e2e4.jpg'),
(90106, 6292, 'À Prova de Tudo S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195234.mp4', 'http://gstaticontent.com/images/729b4fa4183d91fb9d72851dd627e2e4.jpg'),
(90107, 6292, 'À Prova de Tudo S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195235.mp4', 'http://timg.bdta.pro/images/605d2be38717a2e056c09cb93e7cecef.jpg'),
(90108, 6292, 'À Prova de Tudo S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195236.mp4', 'http://timg.bdta.pro/images/d9b09cc23514601eea91c2a47038b90b.jpg'),
(90109, 6292, 'À Prova de Tudo S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195237.mp4', 'http://timg.bdta.pro/images/25890efec7debce4c21488372d1cab3b.jpg'),
(90110, 6292, 'À Prova de Tudo S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195238.mp4', 'http://timg.bdta.pro/images/4f07a7eeeeb8daa8986588065085af1e.jpg'),
(90111, 6292, 'À Prova de Tudo S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195239.mp4', 'http://timg.bdta.pro/images/6ccbf8e936e85a6ed33fb732c0c67a17.jpg'),
(90112, 6293, 'À Prova de Tudo S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195240.mp4', 'http://gstaticontent.com/images/729b4fa4183d91fb9d72851dd627e2e4.jpg'),
(90113, 6293, 'À Prova de Tudo S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195241.mp4', 'http://timg.bdta.pro/images/535d1cab3b3d9dbd9cbed665285834e6.jpg'),
(90114, 6293, 'À Prova de Tudo S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195242.mp4', 'http://timg.bdta.pro/images/de8de5555b17456972006f446a837afc.jpg'),
(90115, 6293, 'À Prova de Tudo S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195243.mp4', 'http://timg.bdta.pro/images/bcc11cfb68aea20b136b1a58b759e158.jpg'),
(90116, 6293, 'À Prova de Tudo S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195244.mp4', 'http://timg.bdta.pro/images/5afb75ce02ec61991543de2df96e6c5a.jpg'),
(90117, 6294, 'Downton Abbey S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195119.mp4', 'http://timg.bdta.pro/images/61bdecae2459f7c50ca0f8596ee859a2.jpg'),
(90118, 6294, 'Downton Abbey S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195120.mp4', 'http://timg.bdta.pro/images/d66f1abaf2a418d837cd68e950df3573.jpg'),
(90119, 6294, 'Downton Abbey S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195121.mp4', 'http://timg.bdta.pro/images/422aaf5ff4626a6631c99dd8ec280d67.jpg'),
(90120, 6294, 'Downton Abbey S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195122.mp4', 'http://timg.bdta.pro/images/09cc577ab0692bf92cc6ebd2aa832eb7.jpg'),
(90121, 6294, 'Downton Abbey S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195123.mp4', 'http://timg.bdta.pro/images/161cef8553dfd0ead911a63e858bf16e.jpg'),
(90122, 6294, 'Downton Abbey S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195124.mp4', 'http://timg.bdta.pro/images/85bf1a3cd998df9d6007bd6659a201ab.jpg'),
(90123, 6294, 'Downton Abbey S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195125.mp4', 'http://timg.bdta.pro/images/3300abcc10ebbbd3978f39a6617748d0.jpg'),
(90124, 6295, 'Downton Abbey S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195126.mp4', 'http://timg.bdta.pro/images/1b04552ba69aac3502c8c2e44c93bd33.jpg'),
(90125, 6295, 'Downton Abbey S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195127.mp4', 'http://timg.bdta.pro/images/1369714d046b90e594a8fcc9cc51e3a4.jpg'),
(90126, 6295, 'Downton Abbey S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195128.mp4', 'http://timg.bdta.pro/images/ad148fe39cbe7dedbf263a8670f36a9b.jpg'),
(90127, 6295, 'Downton Abbey S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195129.mp4', 'http://timg.bdta.pro/images/c5b339e64dddd9cde2e11e30f5af8d80.jpg'),
(90128, 6295, 'Downton Abbey S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195130.mp4', 'http://timg.bdta.pro/images/01eae28397310b7d0182f39f889270e6.jpg'),
(90129, 6295, 'Downton Abbey S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195131.mp4', 'http://timg.bdta.pro/images/95386a96af68c4cb397fc841fa9573d3.jpg'),
(90130, 6295, 'Downton Abbey S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195132.mp4', 'http://timg.bdta.pro/images/b39c5993b2b1e5775ba8936971323ab2.jpg'),
(90131, 6295, 'Downton Abbey S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195133.mp4', 'http://timg.bdta.pro/images/a34701b281dabb51b2fb9ec9ef1cb8c9.jpg'),
(90132, 6295, 'Downton Abbey S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195134.mp4', 'http://gstaticontent.com/images/5c4ed8b89a3c674753317d893d165a23.jpg'),
(90133, 6295, 'Downton Abbey S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195135.mp4', 'http://gstaticontent.com/images/5c4ed8b89a3c674753317d893d165a23.jpg'),
(90134, 6296, 'Downton Abbey S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195136.mp4', 'http://timg.bdta.pro/images/eceb050f7262e1990a6febe908e95b9c.jpg'),
(90135, 6296, 'Downton Abbey S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195137.mp4', 'http://timg.bdta.pro/images/fbdba583556df1a5068c9d1af30b7678.jpg'),
(90136, 6296, 'Downton Abbey S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195138.mp4', 'http://timg.bdta.pro/images/eb30570e396a028e8a13bafbe7ee1ef7.jpg'),
(90137, 6296, 'Downton Abbey S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195139.mp4', 'http://timg.bdta.pro/images/fad7e4e750b674e5cd2174b114400dd4.jpg'),
(90138, 6296, 'Downton Abbey S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195140.mp4', 'http://timg.bdta.pro/images/d825db2886a62639810e4a0f94242234.jpg'),
(90139, 6296, 'Downton Abbey S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195141.mp4', 'http://timg.bdta.pro/images/f6c34fc5cccc1fe3e031922c461096d0.jpg'),
(90140, 6296, 'Downton Abbey S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195142.mp4', 'http://timg.bdta.pro/images/48af84ecb7376484d41a20a2c3dddd40.jpg'),
(90141, 6296, 'Downton Abbey S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195143.mp4', 'http://timg.bdta.pro/images/b3c1705e58d0fd4c66d533585db7bb92.jpg'),
(90142, 6296, 'Downton Abbey S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195144.mp4', 'http://gstaticontent.com/images/5c4ed8b89a3c674753317d893d165a23.jpg'),
(90143, 6296, 'Downton Abbey S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195145.mp4', 'http://gstaticontent.com/images/5c4ed8b89a3c674753317d893d165a23.jpg'),
(90144, 6297, 'Downton Abbey S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195146.mp4', 'http://timg.bdta.pro/images/375c9e0ffb9a40c10f22d2bfe4568c81.jpg'),
(90145, 6297, 'Downton Abbey S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195147.mp4', 'http://timg.bdta.pro/images/70fc0f0a58bd4ffa9928e95a4cd57da9.jpg'),
(90146, 6297, 'Downton Abbey S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195148.mp4', 'http://timg.bdta.pro/images/e32cedf67d7ab8e5ca43a6d83e2d2433.jpg'),
(90147, 6297, 'Downton Abbey S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195149.mp4', 'http://timg.bdta.pro/images/6af932d791a0af1183b0a654ff9d5b09.jpg'),
(90148, 6297, 'Downton Abbey S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195150.mp4', 'http://timg.bdta.pro/images/a95f6d836e4b7ba03936bc114216f1ac.jpg'),
(90149, 6297, 'Downton Abbey S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195151.mp4', 'http://timg.bdta.pro/images/814f6f5fef273b3f1469686e64339b89.jpg'),
(90150, 6297, 'Downton Abbey S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195152.mp4', 'http://timg.bdta.pro/images/76fbbb57edfef439530e2362ded9aa57.jpg'),
(90151, 6297, 'Downton Abbey S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195153.mp4', 'http://timg.bdta.pro/images/7b14caad14a83de82b3dce4e10dbb0fa.jpg'),
(90152, 6297, 'Downton Abbey S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195154.mp4', 'http://gstaticontent.com/images/5c4ed8b89a3c674753317d893d165a23.jpg'),
(90153, 6297, 'Downton Abbey S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195155.mp4', 'http://gstaticontent.com/images/5c4ed8b89a3c674753317d893d165a23.jpg'),
(90154, 6298, 'Downton Abbey S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195156.mp4', 'http://timg.bdta.pro/images/71862d66881f6c6f0944a7c5717c542e.jpg'),
(90155, 6298, 'Downton Abbey S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195157.mp4', 'http://timg.bdta.pro/images/071c6803b63ef6c08e5097154da14219.jpg'),
(90156, 6298, 'Downton Abbey S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195158.mp4', 'http://timg.bdta.pro/images/829f854a8fae631cce207f8d904cbbab.jpg'),
(90157, 6298, 'Downton Abbey S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195159.mp4', 'http://timg.bdta.pro/images/6b1ba15e96b13e2f015142751f9fbb9b.jpg'),
(90158, 6298, 'Downton Abbey S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195160.mp4', 'http://timg.bdta.pro/images/d1988f75debf8ced67a16551facd0729.jpg'),
(90159, 6298, 'Downton Abbey S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195161.mp4', 'http://timg.bdta.pro/images/143a19ca447ec757b99deb128b7bdafa.jpg'),
(90160, 6298, 'Downton Abbey S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195162.mp4', 'http://timg.bdta.pro/images/80ac5c0eef7b59f98aeef9d33e15b1b2.jpg'),
(90161, 6298, 'Downton Abbey S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195163.mp4', 'http://timg.bdta.pro/images/69b37a3583494d6da5cce680c17e5376.jpg'),
(90162, 6298, 'Downton Abbey S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195164.mp4', 'http://gstaticontent.com/images/5c4ed8b89a3c674753317d893d165a23.jpg'),
(90163, 6298, 'Downton Abbey S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195165.mp4', 'http://gstaticontent.com/images/5c4ed8b89a3c674753317d893d165a23.jpg'),
(90164, 6299, 'Downton Abbey S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195166.mp4', 'http://timg.bdta.pro/images/03fdf2756f4bf6a4b4efc2c59f4357e8.jpg'),
(90165, 6299, 'Downton Abbey S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195167.mp4', 'http://timg.bdta.pro/images/650809d3452b1db9fd0d466f6100563a.jpg'),
(90166, 6299, 'Downton Abbey S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195168.mp4', 'http://timg.bdta.pro/images/ae099fdf027429d74e83a605717da343.jpg'),
(90167, 6299, 'Downton Abbey S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195169.mp4', 'http://timg.bdta.pro/images/af189a987b7946c265cb57744bae7283.jpg'),
(90168, 6299, 'Downton Abbey S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195170.mp4', 'http://timg.bdta.pro/images/0dcd36b5b3eec1f64fd5bd0def10231b.jpg'),
(90169, 6299, 'Downton Abbey S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195171.mp4', 'http://timg.bdta.pro/images/228b674e3d27a3a61778482fb52fe8bc.jpg'),
(90170, 6299, 'Downton Abbey S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195172.mp4', 'http://timg.bdta.pro/images/314ae262c3aa43701465bd0cf9c9f07f.jpg'),
(90171, 6299, 'Downton Abbey S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195173.mp4', 'http://timg.bdta.pro/images/f3c69a48d7502ddf8c6afcfffd0a5f81.jpg'),
(90172, 6299, 'Downton Abbey S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195174.mp4', 'http://gstaticontent.com/images/5c4ed8b89a3c674753317d893d165a23.jpg'),
(90173, 6299, 'Downton Abbey S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195175.mp4', 'http://gstaticontent.com/images/5c4ed8b89a3c674753317d893d165a23.jpg'),
(90174, 6300, 'Fairy Tail S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195047.mp4', 'http://timg.bdta.pro/images/21276cbc570c2893559dda2a03a054b1.jpg'),
(90175, 6300, 'Fairy Tail S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195048.mp4', 'http://timg.bdta.pro/images/781f2d864b968c0fdbe444838974cb38.jpg'),
(90176, 6300, 'Fairy Tail S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195049.mp4', 'http://timg.bdta.pro/images/7a4eea38b7ebb69a6c33cf694def1d36.jpg'),
(90177, 6300, 'Fairy Tail S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195050.mp4', 'http://timg.bdta.pro/images/80b2415d0196d4dbe7a33a0610739dd3.jpg'),
(90178, 6300, 'Fairy Tail S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195051.mp4', 'http://timg.bdta.pro/images/07de39468edc5ca4b7bb7bdd015fd75c.jpg'),
(90179, 6300, 'Fairy Tail S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195052.mp4', 'http://timg.bdta.pro/images/c674241773cb118b52363ada4af683da.jpg'),
(90180, 6300, 'Fairy Tail S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195053.mp4', 'http://timg.bdta.pro/images/8ed3f4ac95ac134fc2abd8cf9ce0875d.jpg'),
(90181, 6300, 'Fairy Tail S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195054.mp4', 'http://timg.bdta.pro/images/c7d04a15dcad33c7f6efde5a829bec6c.jpg'),
(90182, 6300, 'Fairy Tail S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195055.mp4', 'http://timg.bdta.pro/images/861f7a545710f885208fd924dbb126ac.jpg'),
(90183, 6300, 'Fairy Tail S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195056.mp4', 'http://timg.bdta.pro/images/a2edbd689f665338c72a70cf3a314d39.jpg'),
(90184, 6300, 'Fairy Tail S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/195057.mp4', 'http://timg.bdta.pro/images/a65f63de0b18fa26d294385adfcffefa.jpg'),
(90185, 6300, 'Fairy Tail S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/195058.mp4', 'http://timg.bdta.pro/images/e2a1394c3fd2c2ca32753a6acdd69f85.jpg'),
(90186, 6300, 'Fairy Tail S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/195059.mp4', 'http://timg.bdta.pro/images/7728c33fde75ff2ffce85e5523b70f26.jpg'),
(90187, 6300, 'Fairy Tail S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/195060.mp4', 'http://timg.bdta.pro/images/d51fb727367df6b22bb1fb61d3320c16.jpg'),
(90188, 6300, 'Fairy Tail S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/195061.mp4', 'http://timg.bdta.pro/images/6839d42c0abbadbd53ea67bf5e354761.jpg'),
(90189, 6300, 'Fairy Tail S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/195062.mp4', 'http://timg.bdta.pro/images/44c2960c35bdb494ad79b78c94aa889a.jpg'),
(90190, 6300, 'Fairy Tail S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/195063.mp4', 'http://timg.bdta.pro/images/eaffe69349db762c362b0a200c9d8874.jpg'),
(90191, 6300, 'Fairy Tail S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/195064.mp4', 'http://timg.bdta.pro/images/9634c0f6d056de1021869408c8e0d57b.jpg'),
(90192, 6300, 'Fairy Tail S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/195065.mp4', 'http://timg.bdta.pro/images/653abe589e0e8709635c951a959625c5.jpg'),
(90193, 6300, 'Fairy Tail S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/195066.mp4', 'http://timg.bdta.pro/images/73c81877e42026dd33b39e665bbd92ff.jpg'),
(90194, 6300, 'Fairy Tail S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/195067.mp4', 'http://timg.bdta.pro/images/9b870e937099e43ad69d29e9e08c6d76.jpg'),
(90195, 6300, 'Fairy Tail S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/195068.mp4', 'http://timg.bdta.pro/images/ad6ee1f8a56b408f8fefb73f8924ab18.jpg'),
(90196, 6300, 'Fairy Tail S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/195069.mp4', 'http://timg.bdta.pro/images/e841f4a006bce10cbdc686e1ddd2bae3.jpg'),
(90197, 6300, 'Fairy Tail S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/195070.mp4', 'http://timg.bdta.pro/images/1de27fa8dbdbdd67d0d68cd9ffe70a1d.jpg'),
(90198, 6300, 'Fairy Tail S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/195071.mp4', 'http://timg.bdta.pro/images/86dc9f4c3852918a6f85d253d97afcf0.jpg'),
(90199, 6300, 'Fairy Tail S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/195072.mp4', 'http://timg.bdta.pro/images/c6fd2941785e4201b626efbeb0b1ce97.jpg'),
(90200, 6300, 'Fairy Tail S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/195073.mp4', 'http://timg.bdta.pro/images/f400b6526dbe4083931daf50bb0231d5.jpg'),
(90201, 6300, 'Fairy Tail S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/195074.mp4', 'http://timg.bdta.pro/images/a2a008be71b758c5ad1ad1908d8ab223.jpg'),
(90202, 6300, 'Fairy Tail S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/195075.mp4', 'http://timg.bdta.pro/images/74e21d57f506b584bbbcb412c41aeb65.jpg'),
(90203, 6300, 'Fairy Tail S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/195076.mp4', 'http://timg.bdta.pro/images/a8b36dd166e1c9dba2110b7b8d5b3cea.jpg'),
(90204, 6300, 'Fairy Tail S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/195077.mp4', 'http://timg.bdta.pro/images/816e5b1413fb26ce4fb704ed1e917a6f.jpg'),
(90205, 6300, 'Fairy Tail S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/195078.mp4', 'http://timg.bdta.pro/images/622bae2e74125c768ab82601dd359498.jpg'),
(90206, 6300, 'Fairy Tail S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/195079.mp4', 'http://timg.bdta.pro/images/715b597424f61f2dd35efb5bbb3fc065.jpg'),
(90207, 6300, 'Fairy Tail S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/195080.mp4', 'http://timg.bdta.pro/images/b919700c6bb69a55f4e358f684af08be.jpg'),
(90208, 6300, 'Fairy Tail S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/195081.mp4', 'http://timg.bdta.pro/images/956c7b6690998023ffd5f5f617878f17.jpg'),
(90209, 6300, 'Fairy Tail S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/195082.mp4', 'http://timg.bdta.pro/images/9b3345bc853047fe84bdaf5b179d815b.jpg'),
(90210, 6300, 'Fairy Tail S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/195083.mp4', 'http://timg.bdta.pro/images/519486e1d69dd28ade74c5d9186778b9.jpg'),
(90211, 6300, 'Fairy Tail S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/195084.mp4', 'http://timg.bdta.pro/images/eff5cf6ef457dc676e0880c1042af7ef.jpg'),
(90212, 6300, 'Fairy Tail S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/195085.mp4', 'http://timg.bdta.pro/images/8ba8f2c9b2eeddb81dcdc2eb3519b97c.jpg'),
(90213, 6300, 'Fairy Tail S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/195086.mp4', 'http://timg.bdta.pro/images/a918a5645871befab0402a7e68b9cad1.jpg'),
(90214, 6300, 'Fairy Tail S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/195087.mp4', 'http://timg.bdta.pro/images/ad0f897a76b2166ba78f4b129fd8eea5.jpg'),
(90215, 6300, 'Fairy Tail S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/195088.mp4', 'http://timg.bdta.pro/images/b92eee6fea6242bad1a32c8b5bf4764f.jpg'),
(90216, 6300, 'Fairy Tail S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/195089.mp4', 'http://timg.bdta.pro/images/b7ac12e8f6f4cc117ac95da7f590dadc.jpg'),
(90217, 6300, 'Fairy Tail S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/195090.mp4', 'http://timg.bdta.pro/images/6510412f53f5f4d8ff241c61b9d7e84b.jpg'),
(90218, 6300, 'Fairy Tail S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/195091.mp4', 'http://timg.bdta.pro/images/674673fda5e9797a579a8019990966a0.jpg'),
(90219, 6300, 'Fairy Tail S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/195092.mp4', 'http://timg.bdta.pro/images/eef8b00dfeef16e73c6829fe7ff74d8b.jpg'),
(90220, 6300, 'Fairy Tail S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/195093.mp4', 'http://timg.bdta.pro/images/dd67405cdaae24179d71382951cb176c.jpg'),
(90221, 6300, 'Fairy Tail S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/195094.mp4', 'http://timg.bdta.pro/images/bba6cf0b64b949fd3fa005e0a366dc7c.jpg'),
(90222, 6301, 'Fairy Tail S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195095.mp4', 'http://timg.bdta.pro/images/d54b296dff2f4eaae6580a53dbd687ea.jpg'),
(90223, 6301, 'Fairy Tail S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195096.mp4', 'http://timg.bdta.pro/images/98cc4ffb0ede2546b937193df144d928.jpg'),
(90224, 6301, 'Fairy Tail S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195097.mp4', 'http://timg.bdta.pro/images/0d8929a975c02af5b9f2d4262ec0a079.jpg'),
(90225, 6301, 'Fairy Tail S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195098.mp4', 'http://timg.bdta.pro/images/999ff242cf9c017df49ec0e4a8e56078.jpg'),
(90226, 6301, 'Fairy Tail S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195099.mp4', 'http://timg.bdta.pro/images/3583061eeaa0abf938f4ed95b94ca279.jpg'),
(90227, 6301, 'Fairy Tail S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195100.mp4', 'http://timg.bdta.pro/images/2f79f590fe6f284f205f96e455ec5688.jpg'),
(90228, 6301, 'Fairy Tail S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195101.mp4', 'http://timg.bdta.pro/images/6a2c49de3e827863147d42c96fdb2c03.jpg'),
(90229, 6301, 'Fairy Tail S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195102.mp4', 'http://timg.bdta.pro/images/93fbc085804ece92351c10efe9d28a05.jpg'),
(90230, 6301, 'Fairy Tail S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195103.mp4', 'http://timg.bdta.pro/images/258a9d2fec59b5ceb665f192d03df1eb.jpg'),
(90231, 6301, 'Fairy Tail S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195104.mp4', 'http://timg.bdta.pro/images/a8cd1b25854facd4c3a75163a1c89969.jpg'),
(90232, 6301, 'Fairy Tail S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/195105.mp4', 'http://timg.bdta.pro/images/6884da38ed4cc2eba2017be84f6aee88.jpg'),
(90233, 6301, 'Fairy Tail S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/195106.mp4', 'http://timg.bdta.pro/images/2f7dd5d121b4a23e598ee0644d8e243a.jpg'),
(90234, 6301, 'Fairy Tail S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/195107.mp4', 'http://timg.bdta.pro/images/e60d67d80cb0b6085f942fe5057dc9c3.jpg'),
(90235, 6301, 'Fairy Tail S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/195108.mp4', 'http://timg.bdta.pro/images/7f64f4ae65a282e04114d3cd27d97c48.jpg'),
(90236, 6301, 'Fairy Tail S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/195109.mp4', 'http://timg.bdta.pro/images/b668bf6a29242b2239cd90fff366ad6a.jpg'),
(90237, 6301, 'Fairy Tail S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/195110.mp4', 'http://timg.bdta.pro/images/91736f7e43c367cc160dea9d0e141b27.jpg'),
(90238, 6301, 'Fairy Tail S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/195111.mp4', 'http://timg.bdta.pro/images/638c2cc95acbeaa37ae61f3744ebc2f3.jpg'),
(90239, 6301, 'Fairy Tail S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/195112.mp4', 'http://timg.bdta.pro/images/85c0bbd2216ad3a30f06f6e0c8e6a910.jpg'),
(90240, 6301, 'Fairy Tail S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/195113.mp4', 'http://timg.bdta.pro/images/baa9e82b8f0521fb0caa81a4bebf4fe2.jpg'),
(90241, 6301, 'Fairy Tail S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/195114.mp4', 'http://timg.bdta.pro/images/6d44e1b1a32fca0b3c63af492f8efca9.jpg'),
(90242, 6301, 'Fairy Tail S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/195115.mp4', 'http://timg.bdta.pro/images/b0807cfaea3ad68bbd6c759960724c9a.jpg'),
(90243, 6301, 'Fairy Tail S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/195116.mp4', 'http://timg.bdta.pro/images/2b6131357ce0cc74d9f0c89fafe468c8.jpg'),
(90244, 6301, 'Fairy Tail S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/195117.mp4', 'http://timg.bdta.pro/images/962f9844d2f7a9654a4644d21f2c300a.jpg'),
(90245, 6301, 'Fairy Tail S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/195118.mp4', 'http://timg.bdta.pro/images/6b251053ad13bf3dfb810c719191adb3.jpg'),
(90246, 6302, 'Harper\'s Island: O Mistério da Ilha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195034.mp4', 'http://timg.bdta.pro/images/65bb5d5cdad24b4c457947d8da78b87c.jpg'),
(90247, 6302, 'Harper\'s Island: O Mistério da Ilha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195035.mp4', 'http://timg.bdta.pro/images/69e7a3f81830031097a844c1822ba2e2.jpg'),
(90248, 6302, 'Harper\'s Island: O Mistério da Ilha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195036.mp4', 'http://timg.bdta.pro/images/a15644bdf1f111e7ac756d265b2aa81d.jpg'),
(90249, 6302, 'Harper\'s Island: O Mistério da Ilha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195037.mp4', 'http://timg.bdta.pro/images/2c82ab46d9d19ee3b8d721fc1bf3da8f.jpg'),
(90250, 6302, 'Harper\'s Island: O Mistério da Ilha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195038.mp4', 'http://timg.bdta.pro/images/6e101b8d398ff8c369a1eba40fc21945.jpg'),
(90251, 6302, 'Harper\'s Island: O Mistério da Ilha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195039.mp4', 'http://timg.bdta.pro/images/2620afeab8321be3f9b6bf5964464f4e.jpg'),
(90252, 6302, 'Harper\'s Island: O Mistério da Ilha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195040.mp4', 'http://timg.bdta.pro/images/ab9d07627b4064c290bb5aa17ec7a991.jpg'),
(90253, 6302, 'Harper\'s Island: O Mistério da Ilha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195041.mp4', 'http://timg.bdta.pro/images/0e2dbbff0b4d89e390858a4ee02f2543.jpg'),
(90254, 6302, 'Harper\'s Island: O Mistério da Ilha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195042.mp4', 'http://timg.bdta.pro/images/db4b79c66c2981db3246a160e3f9d1ff.jpg'),
(90255, 6302, 'Harper\'s Island: O Mistério da Ilha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195043.mp4', 'http://timg.bdta.pro/images/bd36cc103a0904b950f9c41ccf767815.jpg'),
(90256, 6302, 'Harper\'s Island: O Mistério da Ilha S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/195044.mp4', 'http://timg.bdta.pro/images/9d7cb525e37df4f293c26951fc92ac7a.jpg'),
(90257, 6302, 'Harper\'s Island: O Mistério da Ilha S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/195045.mp4', 'http://timg.bdta.pro/images/dcfce7568b9437e5ec112483ce104521.jpg'),
(90258, 6302, 'Harper\'s Island: O Mistério da Ilha S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/195046.mp4', 'http://timg.bdta.pro/images/c820ef77b141810ec51ac4b1c7e79ec0.jpg'),
(90259, 6303, 'O Senhor dos Anéis: Os Anéis de Poder S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200199.mp4', 'http://timg.bdta.pro/images/a2ca642a8a52451a0c4fea9b210b51a3.jpg'),
(90260, 6303, 'O Senhor dos Anéis: Os Anéis de Poder S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200200.mp4', 'http://timg.bdta.pro/images/71156be3eb3c2e0afa39cab1f41aeb15.jpg'),
(90261, 6303, 'O Senhor dos Anéis: Os Anéis de Poder S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200201.mp4', 'http://timg.bdta.pro/images/7f03c283a55e19a579c0e27a6613293d.jpg'),
(90262, 6303, 'O Senhor dos Anéis: Os Anéis de Poder S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200202.mp4', 'http://timg.bdta.pro/images/019ad329123b0a92ef15907b6900799b.jpg'),
(90263, 6303, 'O Senhor dos Anéis: Os Anéis de Poder S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200203.mp4', 'http://timg.bdta.pro/images/b15e138ef012a49d6c23adff4a4134d4.jpg'),
(90264, 6303, 'O Senhor dos Anéis: Os Anéis de Poder S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200204.mp4', 'http://timg.bdta.pro/images/37a406daea097adf253d9a1fac4941ee.jpg'),
(90265, 6303, 'O Senhor dos Anéis: Os Anéis de Poder S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200205.mp4', 'http://timg.bdta.pro/images/7d64564f72e81f1641b514f2573e9f5c.jpg'),
(90266, 6303, 'O Senhor dos Anéis: Os Anéis de Poder S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200206.mp4', 'http://timg.bdta.pro/images/7749105bc25f55c4f1304cef73c29cb7.jpg'),
(90267, 6304, 'O Senhor dos Anéis: Os Anéis de Poder S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/441677.mp4', 'http://gstaticontent.com/images/1808b6d053c0051bdf22991a3d4fcba6.jpg'),
(90268, 6304, 'O Senhor dos Anéis: Os Anéis de Poder S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/441678.mp4', 'http://gstaticontent.com/images/1808b6d053c0051bdf22991a3d4fcba6.jpg'),
(90269, 6304, 'O Senhor dos Anéis: Os Anéis de Poder S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/441679.mp4', 'http://gstaticontent.com/images/1808b6d053c0051bdf22991a3d4fcba6.jpg'),
(90270, 6304, 'O Senhor dos Anéis: Os Anéis de Poder S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/447066.mp4', 'http://gstaticontent.com/images/1808b6d053c0051bdf22991a3d4fcba6.jpg'),
(90271, 6304, 'O Senhor dos Anéis: Os Anéis de Poder S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/452271.mp4', 'http://gstaticontent.com/images/1808b6d053c0051bdf22991a3d4fcba6.jpg'),
(90272, 6304, 'O Senhor dos Anéis: Os Anéis de Poder S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/460557.mp4', 'http://gstaticontent.com/images/1808b6d053c0051bdf22991a3d4fcba6.jpg'),
(90273, 6304, 'O Senhor dos Anéis: Os Anéis de Poder S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/464055.mp4', 'http://gstaticontent.com/images/1808b6d053c0051bdf22991a3d4fcba6.jpg'),
(90274, 6304, 'O Senhor dos Anéis: Os Anéis de Poder S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/469784.mp4', 'http://gstaticontent.com/images/1808b6d053c0051bdf22991a3d4fcba6.jpg'),
(90275, 6305, 'O Senhor dos Anéis: Os Anéis de Poder [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200191.mp4', 'http://timg.bdta.pro/images/a2ca642a8a52451a0c4fea9b210b51a3.jpg'),
(90276, 6305, 'O Senhor dos Anéis: Os Anéis de Poder [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200192.mp4', 'http://timg.bdta.pro/images/71156be3eb3c2e0afa39cab1f41aeb15.jpg'),
(90277, 6305, 'O Senhor dos Anéis: Os Anéis de Poder [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200193.mp4', 'http://timg.bdta.pro/images/7f03c283a55e19a579c0e27a6613293d.jpg'),
(90278, 6305, 'O Senhor dos Anéis: Os Anéis de Poder [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200194.mp4', 'http://timg.bdta.pro/images/019ad329123b0a92ef15907b6900799b.jpg'),
(90279, 6305, 'O Senhor dos Anéis: Os Anéis de Poder [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200195.mp4', 'http://timg.bdta.pro/images/b15e138ef012a49d6c23adff4a4134d4.jpg'),
(90280, 6305, 'O Senhor dos Anéis: Os Anéis de Poder [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200196.mp4', 'http://timg.bdta.pro/images/37a406daea097adf253d9a1fac4941ee.jpg'),
(90281, 6305, 'O Senhor dos Anéis: Os Anéis de Poder [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200197.mp4', 'http://timg.bdta.pro/images/7d64564f72e81f1641b514f2573e9f5c.jpg'),
(90282, 6305, 'O Senhor dos Anéis: Os Anéis de Poder [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200198.mp4', 'http://timg.bdta.pro/images/7749105bc25f55c4f1304cef73c29cb7.jpg'),
(90283, 6306, 'A Guardiã da Floresta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195026.mp4', 'http://timg.bdta.pro/images/402be4295bb5fcdbe4ba83f920a219e3.jpg'),
(90284, 6306, 'A Guardiã da Floresta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195027.mp4', 'http://timg.bdta.pro/images/9432bc28fe8d50537932ef43fad4d754.jpg'),
(90285, 6306, 'A Guardiã da Floresta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195028.mp4', 'http://timg.bdta.pro/images/d23e40017f0aecde9bf3176553dd3081.jpg'),
(90286, 6306, 'A Guardiã da Floresta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195029.mp4', 'http://timg.bdta.pro/images/8c4452156cf9b596278c798cc01e1c2c.jpg'),
(90287, 6306, 'A Guardiã da Floresta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195030.mp4', 'http://timg.bdta.pro/images/5f97abd2607b4636213a8570e7147e3a.jpg'),
(90288, 6306, 'A Guardiã da Floresta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195031.mp4', 'http://timg.bdta.pro/images/8c7b1b253d4cfcfbb1e143d56a76b3a9.jpg'),
(90289, 6306, 'A Guardiã da Floresta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195032.mp4', 'http://timg.bdta.pro/images/c0f591802ea8b72c6a9db52bbee82434.jpg'),
(90290, 6306, 'A Guardiã da Floresta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195033.mp4', 'http://timg.bdta.pro/images/05b1ea41a5eeb799f7c9eb15e6b0526c.jpg'),
(90291, 6307, 'Amber Brown S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195016.mp4', 'http://timg.bdta.pro/images/9064909b7c3561b5fe0ec394482c0c5c.jpg'),
(90292, 6307, 'Amber Brown S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195017.mp4', 'http://timg.bdta.pro/images/bf299dff4095db576d4880cc17a0351b.jpg'),
(90293, 6307, 'Amber Brown S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195018.mp4', 'http://timg.bdta.pro/images/02cc430e319495cd3f3433d7dd21c79f.jpg'),
(90294, 6307, 'Amber Brown S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195019.mp4', 'http://timg.bdta.pro/images/4c7a5b0c3031262800a57d4a2be9fd95.jpg'),
(90295, 6307, 'Amber Brown S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195020.mp4', 'http://timg.bdta.pro/images/b7f4038d2e874f7e72e00a7e94162a58.jpg'),
(90296, 6307, 'Amber Brown S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195021.mp4', 'http://timg.bdta.pro/images/0ca45a8a380b5bc4f218579554e888a9.jpg'),
(90297, 6307, 'Amber Brown S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195022.mp4', 'http://timg.bdta.pro/images/ccb61233eb9e9e5478798976ee5bcc08.jpg'),
(90298, 6307, 'Amber Brown S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195023.mp4', 'http://timg.bdta.pro/images/b300716727e8b3f6419581cbfebe4ad5.jpg'),
(90299, 6307, 'Amber Brown S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195024.mp4', 'http://timg.bdta.pro/images/77a68b3219fa94e0c8a0ab21e35e5cb7.jpg'),
(90300, 6307, 'Amber Brown S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195025.mp4', 'http://timg.bdta.pro/images/050fd61903b11d1b0013a3cf47e6c39a.jpg'),
(90301, 6308, 'Anita Mui: A Rainha Pop da Ásia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195011.mp4', 'http://timg.bdta.pro/images/9ccc8c690e391d943e0b20213b5ef0c5.jpg'),
(90302, 6308, 'Anita Mui: A Rainha Pop da Ásia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195012.mp4', 'http://timg.bdta.pro/images/697f4b23bb38f4ab5fbae0f6ea0193af.jpg'),
(90303, 6308, 'Anita Mui: A Rainha Pop da Ásia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195013.mp4', 'http://timg.bdta.pro/images/f99207bb1ec239fa69358c5507f837cb.jpg'),
(90304, 6308, 'Anita Mui: A Rainha Pop da Ásia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195014.mp4', 'http://timg.bdta.pro/images/dc1f4e8dd22858f58ad1078d5f59655d.jpg'),
(90305, 6308, 'Anita Mui: A Rainha Pop da Ásia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195015.mp4', 'http://timg.bdta.pro/images/415a38e5df22ad7bb06135e5e5f9dae3.jpg'),
(90306, 6309, 'As Falsificadoras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194991.mp4', 'http://timg.bdta.pro/images/0a3a32986077f2a7104ec13c5cb8acbe.jpg'),
(90307, 6309, 'As Falsificadoras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194992.mp4', 'http://timg.bdta.pro/images/2046d98b786bd08bf6a74090ec1d5cfd.jpg'),
(90308, 6309, 'As Falsificadoras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194993.mp4', 'http://timg.bdta.pro/images/23422ad0af4180158954ea760b211d99.jpg'),
(90309, 6309, 'As Falsificadoras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194994.mp4', 'http://timg.bdta.pro/images/81e25e89a0cf132a23bfdd801962cd79.jpg'),
(90310, 6309, 'As Falsificadoras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194995.mp4', 'http://timg.bdta.pro/images/3f112661e70495e7ebb5b2c434f6f9a8.jpg'),
(90311, 6309, 'As Falsificadoras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194996.mp4', 'http://timg.bdta.pro/images/6128bef8d860ca978ca07106a002136c.jpg'),
(90312, 6309, 'As Falsificadoras S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194997.mp4', 'http://timg.bdta.pro/images/8de33c9ddcfb7d0e6f1ecf2496206a98.jpg'),
(90313, 6309, 'As Falsificadoras S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194998.mp4', 'http://timg.bdta.pro/images/4c90f86fd76b869dbe2a6f22519b2948.jpg'),
(90314, 6309, 'As Falsificadoras S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194999.mp4', 'http://timg.bdta.pro/images/b8732e30544e8962e68286c473c2dd22.jpg'),
(90315, 6309, 'As Falsificadoras S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195000.mp4', 'http://timg.bdta.pro/images/e18675eaa91f8ef7312926a7700643d3.jpg'),
(90316, 6310, 'As Meninas de Surfside S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194981.mp4', 'http://timg.bdta.pro/images/bdb53af4da7a4a0032f6c10fc603986b.jpg'),
(90317, 6310, 'As Meninas de Surfside S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194982.mp4', 'http://timg.bdta.pro/images/50e7c73f45292139e2dfa82cd18d73f2.jpg'),
(90318, 6310, 'As Meninas de Surfside S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194983.mp4', 'http://timg.bdta.pro/images/4d39aea150de5033822157ef78b05fbc.jpg'),
(90319, 6310, 'As Meninas de Surfside S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194984.mp4', 'http://timg.bdta.pro/images/c73519825625285d0f84123d60e78e35.jpg'),
(90320, 6310, 'As Meninas de Surfside S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194985.mp4', 'http://timg.bdta.pro/images/cde2f94ca9a75ac5a3f07cd094bfbf1a.jpg'),
(90321, 6310, 'As Meninas de Surfside S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194986.mp4', 'http://timg.bdta.pro/images/7fa5cc2de1aaf51d5567722530fe540b.jpg'),
(90322, 6310, 'As Meninas de Surfside S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194987.mp4', 'http://timg.bdta.pro/images/779ae5c30b88b780153b716b9106bc2d.jpg'),
(90323, 6310, 'As Meninas de Surfside S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194988.mp4', 'http://timg.bdta.pro/images/121ead118f22549fb4011ef403b1c20d.jpg'),
(90324, 6310, 'As Meninas de Surfside S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194989.mp4', 'http://timg.bdta.pro/images/68d3e467c6dc4dbbf684970653b413d2.jpg'),
(90325, 6310, 'As Meninas de Surfside S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194990.mp4', 'http://timg.bdta.pro/images/000659e070092af5ae49bb93efb2c810.jpg'),
(90326, 6311, 'Dated and Related S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194971.mp4', 'http://gstaticontent.com/images/2c0f73f3e12a339ededf944def6bc9ea.jpg'),
(90327, 6311, 'Dated and Related S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194972.mp4', 'http://gstaticontent.com/images/2c0f73f3e12a339ededf944def6bc9ea.jpg'),
(90328, 6311, 'Dated and Related S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194973.mp4', 'http://gstaticontent.com/images/2c0f73f3e12a339ededf944def6bc9ea.jpg'),
(90329, 6311, 'Dated and Related S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194974.mp4', 'http://gstaticontent.com/images/2c0f73f3e12a339ededf944def6bc9ea.jpg'),
(90330, 6311, 'Dated and Related S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194975.mp4', 'http://gstaticontent.com/images/2c0f73f3e12a339ededf944def6bc9ea.jpg'),
(90331, 6311, 'Dated and Related S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194976.mp4', 'http://gstaticontent.com/images/2c0f73f3e12a339ededf944def6bc9ea.jpg'),
(90332, 6311, 'Dated and Related S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194977.mp4', 'http://gstaticontent.com/images/2c0f73f3e12a339ededf944def6bc9ea.jpg'),
(90333, 6311, 'Dated and Related S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194978.mp4', 'http://gstaticontent.com/images/2c0f73f3e12a339ededf944def6bc9ea.jpg'),
(90334, 6311, 'Dated and Related S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194979.mp4', 'http://gstaticontent.com/images/2c0f73f3e12a339ededf944def6bc9ea.jpg'),
(90335, 6311, 'Dated and Related S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194980.mp4', 'http://gstaticontent.com/images/2c0f73f3e12a339ededf944def6bc9ea.jpg'),
(90336, 6312, 'Detox S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194965.mp4', 'http://timg.bdta.pro/images/c337bcd1a5e0e3162e87987b38cac883.jpg'),
(90337, 6312, 'Detox S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194966.mp4', 'http://timg.bdta.pro/images/830d3f532c25fa680df11cecea046c67.jpg'),
(90338, 6312, 'Detox S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194967.mp4', 'http://timg.bdta.pro/images/9ddce869b97e7d2ed1e793cba3a26241.jpg'),
(90339, 6312, 'Detox S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194968.mp4', 'http://timg.bdta.pro/images/081c6e46ab09ce9c8ab1b79bb996462d.jpg'),
(90340, 6312, 'Detox S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194969.mp4', 'http://timg.bdta.pro/images/471c242d6635502baf7e21a683a7084a.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(90341, 6312, 'Detox S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194970.mp4', 'http://timg.bdta.pro/images/a86d23e2a26810ba31aead6af46e0dd1.jpg'),
(90342, 6313, 'House of Hammer: Segredos de Família S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194962.mp4', 'http://timg.bdta.pro/images/974bcf7c38c6cf9283a4186e85cfd6c0.jpg'),
(90343, 6313, 'House of Hammer: Segredos de Família S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194963.mp4', 'http://timg.bdta.pro/images/243892cbdf75d558b17999d968f91fb2.jpg'),
(90344, 6313, 'House of Hammer: Segredos de Família S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194964.mp4', 'http://timg.bdta.pro/images/624287f4c470317f667041e415a24aa6.jpg'),
(90345, 6314, 'O Diabo em Ohio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194954.mp4', 'http://timg.bdta.pro/images/7bca589302d30110e27e5f18020cbfb3.jpg'),
(90346, 6314, 'O Diabo em Ohio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194955.mp4', 'http://timg.bdta.pro/images/c847263eae51b3af8e4d61edbb3a6d28.jpg'),
(90347, 6314, 'O Diabo em Ohio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194956.mp4', 'http://timg.bdta.pro/images/91013d6b315884c3ac0a1e62444d6e83.jpg'),
(90348, 6314, 'O Diabo em Ohio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194957.mp4', 'http://timg.bdta.pro/images/56ffbe06beec95ce1dbbfa3eedff9633.jpg'),
(90349, 6314, 'O Diabo em Ohio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194958.mp4', 'http://timg.bdta.pro/images/0f13aefe0a7ae90c006cbec0089a1a80.jpg'),
(90350, 6314, 'O Diabo em Ohio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194959.mp4', 'http://timg.bdta.pro/images/59d577fccab9f35e6efc3678aa9e48de.jpg'),
(90351, 6314, 'O Diabo em Ohio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194960.mp4', 'http://timg.bdta.pro/images/5ad1aaeab3a5c2d76e82f9457cd6ef0a.jpg'),
(90352, 6314, 'O Diabo em Ohio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194961.mp4', 'http://timg.bdta.pro/images/697794d7d5cb97e0d8e1516409f87bf5.jpg'),
(90353, 6315, 'O Pequeno Urso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194890.mp4', 'http://timg.bdta.pro/images/67869312f20fbcc79e5e5f39bca50a26.jpg'),
(90354, 6315, 'O Pequeno Urso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194891.mp4', 'http://timg.bdta.pro/images/676a11e52030ff28c9a295eae1a8a196.jpg'),
(90355, 6315, 'O Pequeno Urso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194892.mp4', 'http://timg.bdta.pro/images/7785c11f08a7596a57646499d090b5f1.jpg'),
(90356, 6315, 'O Pequeno Urso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194893.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90357, 6315, 'O Pequeno Urso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194894.mp4', 'http://timg.bdta.pro/images/7c847d6ca05866606373bf21dffe5730.jpg'),
(90358, 6315, 'O Pequeno Urso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194895.mp4', 'http://timg.bdta.pro/images/9456d9b97c29c8a96dc2a84479fbc693.jpg'),
(90359, 6315, 'O Pequeno Urso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194896.mp4', 'http://timg.bdta.pro/images/3aae3dd5e41f92487745a650b0aa31c5.jpg'),
(90360, 6315, 'O Pequeno Urso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194897.mp4', 'http://timg.bdta.pro/images/8534c9413f7523a694666565cab95314.jpg'),
(90361, 6315, 'O Pequeno Urso S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194898.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90362, 6315, 'O Pequeno Urso S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194899.mp4', 'http://timg.bdta.pro/images/adc00b917a67ed0327a06010940fbbfe.jpg'),
(90363, 6315, 'O Pequeno Urso S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194900.mp4', 'http://timg.bdta.pro/images/6b8e2b1e7e41c5a0019dbeebef1d0c6e.jpg'),
(90364, 6315, 'O Pequeno Urso S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194901.mp4', 'http://timg.bdta.pro/images/3501b2485325cec9624a6d57959355fe.jpg'),
(90365, 6315, 'O Pequeno Urso S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/194902.mp4', 'http://timg.bdta.pro/images/d112a4af47fff3b6e3ed16531095b5c9.jpg'),
(90366, 6315, 'O Pequeno Urso S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/194903.mp4', 'http://timg.bdta.pro/images/cbd0bda0e25d42cb23f9c50bd743ee5a.jpg'),
(90367, 6315, 'O Pequeno Urso S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/194904.mp4', 'http://timg.bdta.pro/images/795d0e4a71d72cc854e04413a9307a50.jpg'),
(90368, 6316, 'O Pequeno Urso S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194905.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90369, 6316, 'O Pequeno Urso S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194906.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90370, 6316, 'O Pequeno Urso S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194907.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90371, 6316, 'O Pequeno Urso S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194908.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90372, 6316, 'O Pequeno Urso S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194909.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90373, 6316, 'O Pequeno Urso S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194910.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90374, 6316, 'O Pequeno Urso S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194911.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90375, 6316, 'O Pequeno Urso S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194912.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90376, 6316, 'O Pequeno Urso S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194913.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90377, 6316, 'O Pequeno Urso S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194914.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90378, 6316, 'O Pequeno Urso S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194915.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90379, 6316, 'O Pequeno Urso S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194916.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90380, 6316, 'O Pequeno Urso S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/194917.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90381, 6316, 'O Pequeno Urso S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/194918.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90382, 6317, 'O Pequeno Urso S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194919.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90383, 6317, 'O Pequeno Urso S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194920.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90384, 6317, 'O Pequeno Urso S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194921.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90385, 6317, 'O Pequeno Urso S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194922.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90386, 6317, 'O Pequeno Urso S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194923.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90387, 6317, 'O Pequeno Urso S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194924.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90388, 6317, 'O Pequeno Urso S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194925.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90389, 6317, 'O Pequeno Urso S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194926.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90390, 6317, 'O Pequeno Urso S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194927.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90391, 6317, 'O Pequeno Urso S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194928.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90392, 6317, 'O Pequeno Urso S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194929.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90393, 6317, 'O Pequeno Urso S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194930.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90394, 6317, 'O Pequeno Urso S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/194931.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90395, 6318, 'O Pequeno Urso S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194932.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90396, 6318, 'O Pequeno Urso S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194933.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90397, 6318, 'O Pequeno Urso S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194934.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90398, 6318, 'O Pequeno Urso S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194935.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90399, 6318, 'O Pequeno Urso S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194936.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90400, 6318, 'O Pequeno Urso S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194937.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90401, 6318, 'O Pequeno Urso S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194938.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90402, 6318, 'O Pequeno Urso S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194939.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90403, 6318, 'O Pequeno Urso S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194940.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90404, 6318, 'O Pequeno Urso S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194941.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90405, 6319, 'O Pequeno Urso S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194942.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90406, 6319, 'O Pequeno Urso S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194943.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90407, 6319, 'O Pequeno Urso S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194944.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90408, 6319, 'O Pequeno Urso S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194945.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90409, 6319, 'O Pequeno Urso S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194946.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90410, 6319, 'O Pequeno Urso S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194947.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90411, 6319, 'O Pequeno Urso S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194948.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90412, 6319, 'O Pequeno Urso S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194949.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90413, 6319, 'O Pequeno Urso S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194950.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90414, 6319, 'O Pequeno Urso S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194951.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90415, 6319, 'O Pequeno Urso S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194952.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90416, 6319, 'O Pequeno Urso S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194953.mp4', 'http://gstaticontent.com/images/9a212a55903fca5b8e51bf68107d240e.jpg'),
(90417, 6320, 'Passageiros: A Última Viagem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194882.mp4', 'http://gstaticontent.com/images/49287ba04f1979392605647effcfb17f.jpg'),
(90418, 6320, 'Passageiros: A Última Viagem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194883.mp4', 'http://gstaticontent.com/images/49287ba04f1979392605647effcfb17f.jpg'),
(90419, 6320, 'Passageiros: A Última Viagem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194884.mp4', 'http://gstaticontent.com/images/49287ba04f1979392605647effcfb17f.jpg'),
(90420, 6320, 'Passageiros: A Última Viagem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194885.mp4', 'http://gstaticontent.com/images/49287ba04f1979392605647effcfb17f.jpg'),
(90421, 6320, 'Passageiros: A Última Viagem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194886.mp4', 'http://gstaticontent.com/images/49287ba04f1979392605647effcfb17f.jpg'),
(90422, 6320, 'Passageiros: A Última Viagem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194887.mp4', 'http://gstaticontent.com/images/49287ba04f1979392605647effcfb17f.jpg'),
(90423, 6320, 'Passageiros: A Última Viagem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194888.mp4', 'http://gstaticontent.com/images/49287ba04f1979392605647effcfb17f.jpg'),
(90424, 6320, 'Passageiros: A Última Viagem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194889.mp4', 'http://gstaticontent.com/images/49287ba04f1979392605647effcfb17f.jpg'),
(90425, 6321, 'Quem Vai Comprar Minha Casa? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194876.mp4', 'http://gstaticontent.com/images/937f8e60a070dd543419c29035423bf1.jpg'),
(90426, 6321, 'Quem Vai Comprar Minha Casa? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194877.mp4', 'http://gstaticontent.com/images/937f8e60a070dd543419c29035423bf1.jpg'),
(90427, 6321, 'Quem Vai Comprar Minha Casa? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194878.mp4', 'http://gstaticontent.com/images/937f8e60a070dd543419c29035423bf1.jpg'),
(90428, 6321, 'Quem Vai Comprar Minha Casa? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194879.mp4', 'http://gstaticontent.com/images/937f8e60a070dd543419c29035423bf1.jpg'),
(90429, 6321, 'Quem Vai Comprar Minha Casa? S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194880.mp4', 'http://gstaticontent.com/images/937f8e60a070dd543419c29035423bf1.jpg'),
(90430, 6321, 'Quem Vai Comprar Minha Casa? S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194881.mp4', 'http://gstaticontent.com/images/937f8e60a070dd543419c29035423bf1.jpg'),
(90431, 6322, 'Revelações de Família S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194868.mp4', 'http://timg.bdta.pro/images/e2d10489b4179144aed0d0bfdcf5dab9.jpg'),
(90432, 6322, 'Revelações de Família S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194869.mp4', 'http://timg.bdta.pro/images/c0b68e486949933fcdf7a74401aa2422.jpg'),
(90433, 6322, 'Revelações de Família S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194870.mp4', 'http://timg.bdta.pro/images/b23a346239674132ff53458ed2020cfa.jpg'),
(90434, 6322, 'Revelações de Família S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194871.mp4', 'http://timg.bdta.pro/images/92508ab10a6aca2d2edce76400b6757f.jpg'),
(90435, 6322, 'Revelações de Família S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194872.mp4', 'http://timg.bdta.pro/images/ae66d3e15c8c945d7f90f1264737a45d.jpg'),
(90436, 6322, 'Revelações de Família S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194873.mp4', 'http://timg.bdta.pro/images/f52ca000686577f85b7eb1a560867e4a.jpg'),
(90437, 6322, 'Revelações de Família S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194874.mp4', 'http://timg.bdta.pro/images/ae392f612db27fe759332d8fc5d9b6cc.jpg'),
(90438, 6322, 'Revelações de Família S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194875.mp4', 'http://timg.bdta.pro/images/495180dcc1ad394a3eff8dbcc6c2b876.jpg'),
(90439, 6323, 'Tales of the Walking Dead [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192253.mp4', 'http://timg.bdta.pro/images/f29b326d4d3a8e99c1f55918e251036b.jpg'),
(90440, 6323, 'Tales of the Walking Dead [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192254.mp4', 'http://timg.bdta.pro/images/f320edaf3fddbcce8984d11dd80b1dbc.jpg'),
(90441, 6323, 'Tales of the Walking Dead [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192255.mp4', 'http://timg.bdta.pro/images/b952d4b5f00b476cd9ed08544287ef81.jpg'),
(90442, 6323, 'Tales of the Walking Dead [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192256.mp4', 'http://timg.bdta.pro/images/ce74a0cd0846cd9abcdd382218ccfe6c.jpg'),
(90443, 6323, 'Tales of the Walking Dead [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192257.mp4', 'http://timg.bdta.pro/images/a41a16606172585ed35e63a2d17021df.jpg'),
(90444, 6323, 'Tales of the Walking Dead [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192258.mp4', 'http://timg.bdta.pro/images/789cfc3d7f535a1c0ef17e7f28fefd4d.jpg'),
(90445, 6324, 'Uma Advogada Extraordinária S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194852.mp4', 'http://timg.bdta.pro/images/7755e98bc6402e00555b52913c65bbc1.jpg'),
(90446, 6324, 'Uma Advogada Extraordinária S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194853.mp4', 'http://timg.bdta.pro/images/ffd24e70dea32106e5ad8e41f1874dc2.jpg'),
(90447, 6324, 'Uma Advogada Extraordinária S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194854.mp4', 'http://timg.bdta.pro/images/ed91c417ada5f6415825f6a31c0788df.jpg'),
(90448, 6324, 'Uma Advogada Extraordinária S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194855.mp4', 'http://timg.bdta.pro/images/f62b9cd22ef9eb0e1965a62e7a904a37.jpg'),
(90449, 6324, 'Uma Advogada Extraordinária S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194856.mp4', 'http://timg.bdta.pro/images/2fbf0c13e3ca92693750dd0c69f4ced8.jpg'),
(90450, 6324, 'Uma Advogada Extraordinária S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194857.mp4', 'http://timg.bdta.pro/images/959be0e00d9d33db22836d12f14e27e6.jpg'),
(90451, 6324, 'Uma Advogada Extraordinária S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194858.mp4', 'http://timg.bdta.pro/images/42a9adada8ff167c8a85fb44b5d3d7dc.jpg'),
(90452, 6324, 'Uma Advogada Extraordinária S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194859.mp4', 'http://timg.bdta.pro/images/81c1e759b5b1e4d04036c82441202791.jpg'),
(90453, 6324, 'Uma Advogada Extraordinária S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194860.mp4', 'http://timg.bdta.pro/images/4e0cca8d218a8dcbd7291d9e13fee5b5.jpg'),
(90454, 6324, 'Uma Advogada Extraordinária S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194861.mp4', 'http://timg.bdta.pro/images/67b841c0f9a9aa2ad45ccab925b69bfc.jpg'),
(90455, 6324, 'Uma Advogada Extraordinária S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194862.mp4', 'http://timg.bdta.pro/images/76eed27df03e36183e40911397f13847.jpg'),
(90456, 6324, 'Uma Advogada Extraordinária S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194863.mp4', 'http://timg.bdta.pro/images/80fb5cb0a9e18cf9f4f6827b1d5d49b9.jpg'),
(90457, 6324, 'Uma Advogada Extraordinária S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/194864.mp4', 'http://timg.bdta.pro/images/db4dcb7a9ea75eaecab8f0bb22e95b4a.jpg'),
(90458, 6324, 'Uma Advogada Extraordinária S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/194865.mp4', 'http://timg.bdta.pro/images/7121c6bd879ff2a4944943dffeeef9c4.jpg'),
(90459, 6324, 'Uma Advogada Extraordinária S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/194866.mp4', 'http://timg.bdta.pro/images/94cfa9b990da23c705b70f6a52a297f6.jpg'),
(90460, 6324, 'Uma Advogada Extraordinária S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/194867.mp4', 'http://timg.bdta.pro/images/8a0838f265a055de384ef13fb99fdde6.jpg'),
(90461, 6325, 'Você Não é Especial S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194846.mp4', 'http://timg.bdta.pro/images/85c2a0b53c16870befccb68f1aca1abd.jpg'),
(90462, 6325, 'Você Não é Especial S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194847.mp4', 'http://timg.bdta.pro/images/34e824f715abc00b0f3cde2daa8cf1f6.jpg'),
(90463, 6325, 'Você Não é Especial S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194848.mp4', 'http://timg.bdta.pro/images/a815d610866895a98b02bd2d46f3f744.jpg'),
(90464, 6325, 'Você Não é Especial S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194849.mp4', 'http://timg.bdta.pro/images/cc0e69ed9183f2c2889ad57a32113513.jpg'),
(90465, 6325, 'Você Não é Especial S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194850.mp4', 'http://timg.bdta.pro/images/0ea4cca378ecbae2858af6c8b410610a.jpg'),
(90466, 6325, 'Você Não é Especial S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194851.mp4', 'http://timg.bdta.pro/images/8bd44fa5fc1eab5cfc03a4727f4c57c9.jpg'),
(90467, 6326, 'A Vida Segundo Ella S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195001.mp4', 'http://timg.bdta.pro/images/911f584c1b83a3d952e775c29e529ca2.jpg'),
(90468, 6326, 'A Vida Segundo Ella S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195002.mp4', 'http://timg.bdta.pro/images/89afe4783119757261b4643bd0cf37af.jpg'),
(90469, 6326, 'A Vida Segundo Ella S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195003.mp4', 'http://timg.bdta.pro/images/f48022e3f87407b17a32ed6525dd8d78.jpg'),
(90470, 6326, 'A Vida Segundo Ella S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195004.mp4', 'http://timg.bdta.pro/images/28c8a5c13215d2af1ddc05d845c679c6.jpg'),
(90471, 6326, 'A Vida Segundo Ella S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195005.mp4', 'http://timg.bdta.pro/images/ef246c611411e721a3ce95b9db507474.jpg'),
(90472, 6326, 'A Vida Segundo Ella S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195006.mp4', 'http://timg.bdta.pro/images/e56d35fcb82d42d81a130669e3432fd7.jpg'),
(90473, 6326, 'A Vida Segundo Ella S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195007.mp4', 'http://timg.bdta.pro/images/9dfe77ac875c27155fa80217927417b5.jpg'),
(90474, 6326, 'A Vida Segundo Ella S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195008.mp4', 'http://timg.bdta.pro/images/c6920275ded501da352fe05d71a8d7a8.jpg'),
(90475, 6326, 'A Vida Segundo Ella S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195009.mp4', 'http://timg.bdta.pro/images/96b621bb315127ab6bf20be5bdb59923.jpg'),
(90476, 6326, 'A Vida Segundo Ella S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195010.mp4', 'http://timg.bdta.pro/images/f9308ef965d6d77df21288a9be9ed0a0.jpg'),
(90477, 6327, 'The Knick S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194826.mp4', 'http://timg.bdta.pro/images/07ffea84228c434871e657a3c6f67b92.jpg'),
(90478, 6327, 'The Knick S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194827.mp4', 'http://timg.bdta.pro/images/6e6c0f09f705ce85891652c3feec1eae.jpg'),
(90479, 6327, 'The Knick S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194828.mp4', 'http://timg.bdta.pro/images/fc30796c0611c8a483e24552cd6566f2.jpg'),
(90480, 6327, 'The Knick S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194829.mp4', 'http://timg.bdta.pro/images/f9f3ad793bc1f40d897ace7b8c4215fd.jpg'),
(90481, 6327, 'The Knick S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194830.mp4', 'http://timg.bdta.pro/images/871190e5e2481807d59b90d03ca3ff55.jpg'),
(90482, 6327, 'The Knick S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194831.mp4', 'http://timg.bdta.pro/images/d278b854b357904f21ec6d94b831cc75.jpg'),
(90483, 6327, 'The Knick S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194832.mp4', 'http://timg.bdta.pro/images/bb46a3062d812a672f2bbbdbb2e0ea4b.jpg'),
(90484, 6327, 'The Knick S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194833.mp4', 'http://timg.bdta.pro/images/14c4958ed331a4805ff12b14c729bd50.jpg'),
(90485, 6327, 'The Knick S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194834.mp4', 'http://timg.bdta.pro/images/7d7fb24dec4fe41f76d3c307d6ba5da7.jpg'),
(90486, 6327, 'The Knick S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194835.mp4', 'http://timg.bdta.pro/images/6b0ebfe7ddc17db048752939b331011c.jpg'),
(90487, 6328, 'The Knick S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194836.mp4', 'http://timg.bdta.pro/images/371040c44bc56837567d2483dd752f20.jpg'),
(90488, 6328, 'The Knick S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194837.mp4', 'http://timg.bdta.pro/images/27e13cabfabe2606beb4253f8a8535d4.jpg'),
(90489, 6328, 'The Knick S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194838.mp4', 'http://timg.bdta.pro/images/1d91876eb475efbc5c600646d0c0ae97.jpg'),
(90490, 6328, 'The Knick S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194839.mp4', 'http://timg.bdta.pro/images/dd785772e5cf88c1805db02b102fc5b1.jpg'),
(90491, 6328, 'The Knick S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194840.mp4', 'http://timg.bdta.pro/images/5fefb61d35d5f0fe07826cbc052f1bb0.jpg'),
(90492, 6328, 'The Knick S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194841.mp4', 'http://timg.bdta.pro/images/b13944fca1e4c88029c4ea2aba451a18.jpg'),
(90493, 6328, 'The Knick S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194842.mp4', 'http://timg.bdta.pro/images/90ef7c62708853c8cd7643560bc4667d.jpg'),
(90494, 6328, 'The Knick S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194843.mp4', 'http://timg.bdta.pro/images/a367a4be04aa518e0209527895ac12db.jpg'),
(90495, 6328, 'The Knick S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194844.mp4', 'http://timg.bdta.pro/images/0e7bd2763eaa99f5c68ce9766eb87400.jpg'),
(90496, 6328, 'The Knick S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194845.mp4', 'http://timg.bdta.pro/images/3da841006d28b089dced90ef06056e2f.jpg'),
(90497, 6329, 'Esquadrão Especial Winspector S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/194422.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90498, 6329, 'Esquadrão Especial Winspector S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/194423.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90499, 6329, 'Esquadrão Especial Winspector S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/194424.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90500, 6329, 'Esquadrão Especial Winspector S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/194425.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90501, 6329, 'Esquadrão Especial Winspector S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/194426.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90502, 6329, 'Esquadrão Especial Winspector S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/194427.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90503, 6329, 'Esquadrão Especial Winspector S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/194428.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90504, 6329, 'Esquadrão Especial Winspector S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/194429.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90505, 6329, 'Esquadrão Especial Winspector S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/194430.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90506, 6329, 'Esquadrão Especial Winspector S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/194431.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90507, 6329, 'Esquadrão Especial Winspector S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/194432.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90508, 6329, 'Esquadrão Especial Winspector S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/194433.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90509, 6329, 'Esquadrão Especial Winspector S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/194434.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90510, 6329, 'Esquadrão Especial Winspector S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/194435.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90511, 6329, 'Esquadrão Especial Winspector S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/194436.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90512, 6329, 'Esquadrão Especial Winspector S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/194437.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90513, 6329, 'Esquadrão Especial Winspector S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/194438.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90514, 6329, 'Esquadrão Especial Winspector S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/194439.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90515, 6329, 'Esquadrão Especial Winspector S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/194440.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90516, 6329, 'Esquadrão Especial Winspector S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/194441.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90517, 6329, 'Esquadrão Especial Winspector S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/194442.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90518, 6329, 'Esquadrão Especial Winspector S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/194443.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90519, 6329, 'Esquadrão Especial Winspector S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/194444.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90520, 6329, 'Esquadrão Especial Winspector S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/194445.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90521, 6329, 'Esquadrão Especial Winspector S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/194446.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90522, 6329, 'Esquadrão Especial Winspector S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/194447.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90523, 6329, 'Esquadrão Especial Winspector S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/194448.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90524, 6329, 'Esquadrão Especial Winspector S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/194449.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90525, 6329, 'Esquadrão Especial Winspector S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/194450.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90526, 6329, 'Esquadrão Especial Winspector S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/194451.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90527, 6329, 'Esquadrão Especial Winspector S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/194452.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90528, 6329, 'Esquadrão Especial Winspector S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/194453.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90529, 6329, 'Esquadrão Especial Winspector S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/194454.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90530, 6329, 'Esquadrão Especial Winspector S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/194455.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90531, 6329, 'Esquadrão Especial Winspector S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/194456.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90532, 6329, 'Esquadrão Especial Winspector S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/194457.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90533, 6329, 'Esquadrão Especial Winspector S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/194458.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90534, 6329, 'Esquadrão Especial Winspector S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/194459.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90535, 6329, 'Esquadrão Especial Winspector S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/194460.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90536, 6329, 'Esquadrão Especial Winspector S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/194461.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90537, 6329, 'Esquadrão Especial Winspector S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/194462.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90538, 6329, 'Esquadrão Especial Winspector S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/194463.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90539, 6329, 'Esquadrão Especial Winspector S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/194464.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90540, 6329, 'Esquadrão Especial Winspector S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/194465.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90541, 6329, 'Esquadrão Especial Winspector S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/194466.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90542, 6329, 'Esquadrão Especial Winspector S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/194467.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90543, 6329, 'Esquadrão Especial Winspector S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/194468.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90544, 6329, 'Esquadrão Especial Winspector S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/194469.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90545, 6329, 'Esquadrão Especial Winspector S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/194470.mp4', 'http://gstaticontent.com/images/7adbdd68481646fe4ab8377aa1337be9.jpg'),
(90546, 6330, 'As Aventuras de Bertie Gregory S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192776.mp4', 'http://timg.bdta.pro/images/6fd4978600de5befac4f90c054f5e64a.jpg'),
(90547, 6330, 'As Aventuras de Bertie Gregory S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192777.mp4', 'http://timg.bdta.pro/images/11c7651496a55a613519ed9a58e798f9.jpg'),
(90548, 6330, 'As Aventuras de Bertie Gregory S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192778.mp4', 'http://timg.bdta.pro/images/0fef2548564154f8a4fbe8395ce1da38.jpg'),
(90549, 6330, 'As Aventuras de Bertie Gregory S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192779.mp4', 'http://timg.bdta.pro/images/9afd3b4ba8d01053fa241c8de55498e5.jpg'),
(90550, 6330, 'As Aventuras de Bertie Gregory S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192780.mp4', 'http://timg.bdta.pro/images/36500a648a9ae2ae29aa48eed8905937.jpg'),
(90551, 6331, 'Carros na Estrada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192767.mp4', 'http://timg.bdta.pro/images/964a4c28ab799b1903d73366a2b5ccae.jpg'),
(90552, 6331, 'Carros na Estrada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192768.mp4', 'http://timg.bdta.pro/images/7e2e82129144e7556a7a405b4ad57c10.jpg'),
(90553, 6331, 'Carros na Estrada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192769.mp4', 'http://timg.bdta.pro/images/de5472c8933df362a7398a044ff38c50.jpg'),
(90554, 6331, 'Carros na Estrada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192770.mp4', 'http://timg.bdta.pro/images/3ced2c8c3ba743082a3d3acd58ae45e8.jpg'),
(90555, 6331, 'Carros na Estrada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192771.mp4', 'http://timg.bdta.pro/images/ccf89965f1580a548f0a8c8ed91c2947.jpg'),
(90556, 6331, 'Carros na Estrada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192772.mp4', 'http://timg.bdta.pro/images/c1df808e049f76be9af8aafec4c77e89.jpg'),
(90557, 6331, 'Carros na Estrada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192773.mp4', 'http://timg.bdta.pro/images/ea5cb10497b26d52a510bf7f16a076ca.jpg'),
(90558, 6331, 'Carros na Estrada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192774.mp4', 'http://timg.bdta.pro/images/fbc2115360a169ab7bec8e0755958cba.jpg'),
(90559, 6331, 'Carros na Estrada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192775.mp4', 'http://timg.bdta.pro/images/cfc078a79da9c01dcdc4434f3e291b7c.jpg'),
(90560, 6332, 'Celebridades à Prova de Tudo: O Desafio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257335.mp4', 'http://gstaticontent.com/images/a95e4ad651aa421ab252eae518bc5635.jpg'),
(90561, 6332, 'Celebridades à Prova de Tudo: O Desafio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257336.mp4', 'http://gstaticontent.com/images/a95e4ad651aa421ab252eae518bc5635.jpg'),
(90562, 6332, 'Celebridades à Prova de Tudo: O Desafio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257337.mp4', 'http://gstaticontent.com/images/a95e4ad651aa421ab252eae518bc5635.jpg'),
(90563, 6332, 'Celebridades à Prova de Tudo: O Desafio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257338.mp4', 'http://gstaticontent.com/images/a95e4ad651aa421ab252eae518bc5635.jpg'),
(90564, 6332, 'Celebridades à Prova de Tudo: O Desafio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257339.mp4', 'http://gstaticontent.com/images/a95e4ad651aa421ab252eae518bc5635.jpg'),
(90565, 6332, 'Celebridades à Prova de Tudo: O Desafio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257340.mp4', 'http://gstaticontent.com/images/a95e4ad651aa421ab252eae518bc5635.jpg'),
(90566, 6333, 'Celebridades à Prova de Tudo: O Desafio S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257341.mp4', 'http://gstaticontent.com/images/a95e4ad651aa421ab252eae518bc5635.jpg'),
(90567, 6333, 'Celebridades à Prova de Tudo: O Desafio S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257342.mp4', 'http://gstaticontent.com/images/a95e4ad651aa421ab252eae518bc5635.jpg'),
(90568, 6333, 'Celebridades à Prova de Tudo: O Desafio S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257343.mp4', 'http://gstaticontent.com/images/a95e4ad651aa421ab252eae518bc5635.jpg'),
(90569, 6333, 'Celebridades à Prova de Tudo: O Desafio S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257344.mp4', 'http://gstaticontent.com/images/a95e4ad651aa421ab252eae518bc5635.jpg'),
(90570, 6333, 'Celebridades à Prova de Tudo: O Desafio S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257345.mp4', 'http://gstaticontent.com/images/a95e4ad651aa421ab252eae518bc5635.jpg'),
(90571, 6333, 'Celebridades à Prova de Tudo: O Desafio S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257346.mp4', 'http://gstaticontent.com/images/a95e4ad651aa421ab252eae518bc5635.jpg'),
(90572, 6333, 'Celebridades à Prova de Tudo: O Desafio S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257347.mp4', 'http://gstaticontent.com/images/a95e4ad651aa421ab252eae518bc5635.jpg'),
(90573, 6333, 'Celebridades à Prova de Tudo: O Desafio S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/492901.mp4', 'http://gstaticontent.com/images/a95e4ad651aa421ab252eae518bc5635.jpg'),
(90574, 6334, 'Chef\'s Table: Pizza S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192761.mp4', 'http://gstaticontent.com/images/9ae415662e138c9b8178fc1bf7f73af4.jpg'),
(90575, 6334, 'Chef\'s Table: Pizza S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192762.mp4', 'http://gstaticontent.com/images/9ae415662e138c9b8178fc1bf7f73af4.jpg'),
(90576, 6334, 'Chef\'s Table: Pizza S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192763.mp4', 'http://gstaticontent.com/images/9ae415662e138c9b8178fc1bf7f73af4.jpg'),
(90577, 6334, 'Chef\'s Table: Pizza S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192764.mp4', 'http://gstaticontent.com/images/9ae415662e138c9b8178fc1bf7f73af4.jpg'),
(90578, 6334, 'Chef\'s Table: Pizza S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192765.mp4', 'http://gstaticontent.com/images/9ae415662e138c9b8178fc1bf7f73af4.jpg'),
(90579, 6334, 'Chef\'s Table: Pizza S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192766.mp4', 'http://gstaticontent.com/images/9ae415662e138c9b8178fc1bf7f73af4.jpg'),
(90580, 6335, 'Crescendo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192751.mp4', 'http://timg.bdta.pro/images/99f07c8357f10053ad3b7f855027e03a.jpg'),
(90581, 6335, 'Crescendo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192752.mp4', 'http://timg.bdta.pro/images/3dce19317c8e58d256e5b5aff3ed9cf7.jpg'),
(90582, 6335, 'Crescendo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192753.mp4', 'http://timg.bdta.pro/images/53bd381bdedede927672a0372a2df4dd.jpg'),
(90583, 6335, 'Crescendo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192754.mp4', 'http://timg.bdta.pro/images/8b819d833d875b98015e146bfb4c4600.jpg'),
(90584, 6335, 'Crescendo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192755.mp4', 'http://timg.bdta.pro/images/05e9d66e3228e3ecb0ed1168d124b940.jpg'),
(90585, 6335, 'Crescendo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192756.mp4', 'http://timg.bdta.pro/images/7f5dbf3de7a8fc9675c5180fe60dc585.jpg'),
(90586, 6335, 'Crescendo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192757.mp4', 'http://timg.bdta.pro/images/b03da9fb3aa1d7a73f39a3382ddef461.jpg'),
(90587, 6335, 'Crescendo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192758.mp4', 'http://timg.bdta.pro/images/768a83acad898c93231405f207e05505.jpg'),
(90588, 6335, 'Crescendo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192759.mp4', 'http://timg.bdta.pro/images/8db41747d2b58ca420ee4e7c0a61e7b0.jpg'),
(90589, 6335, 'Crescendo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192760.mp4', 'http://timg.bdta.pro/images/93f8ef825748b6b45e2549b9ba816be3.jpg'),
(90590, 6336, 'Diário de um Gigolô S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192741.mp4', 'http://timg.bdta.pro/images/9c5b2042c76fae0dda86af03dc26ba34.jpg'),
(90591, 6336, 'Diário de um Gigolô S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192742.mp4', 'http://timg.bdta.pro/images/ae64664fd166a26eda89da336472b3fb.jpg'),
(90592, 6336, 'Diário de um Gigolô S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192743.mp4', 'http://timg.bdta.pro/images/3a04949209724732f902c7fab513f53e.jpg'),
(90593, 6336, 'Diário de um Gigolô S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192744.mp4', 'http://timg.bdta.pro/images/885115d2964f3001af001a463feeaac5.jpg'),
(90594, 6336, 'Diário de um Gigolô S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192745.mp4', 'http://timg.bdta.pro/images/7390ffe520cbd7a147d8d3c39546f458.jpg'),
(90595, 6336, 'Diário de um Gigolô S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192746.mp4', 'http://timg.bdta.pro/images/2af208d07c42ca5507037724a70ca9a1.jpg'),
(90596, 6336, 'Diário de um Gigolô S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192747.mp4', 'http://timg.bdta.pro/images/320eb995aa4702da255ea41ec4072b37.jpg'),
(90597, 6336, 'Diário de um Gigolô S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192748.mp4', 'http://timg.bdta.pro/images/a58a87d87abeed5c5a2904067740f898.jpg'),
(90598, 6336, 'Diário de um Gigolô S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192749.mp4', 'http://timg.bdta.pro/images/300cb6557d5e3ad28b0d6cb4c409ad25.jpg'),
(90599, 6336, 'Diário de um Gigolô S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192750.mp4', 'http://timg.bdta.pro/images/4c7b70d45beac82560b829e33e59727a.jpg'),
(90600, 6337, 'Edição de Amanhã S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/310525.mp4', 'http://timg.bdta.pro/images/0a5f535834ff35e2b25a9eca27d2d312.jpg'),
(90601, 6337, 'Edição de Amanhã S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192674.mp4', 'http://timg.bdta.pro/images/f7935e69e4887eae8e788804e6802d69.jpg'),
(90602, 6337, 'Edição de Amanhã S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192675.mp4', 'http://timg.bdta.pro/images/6d345ed8767c780ee5624e028d70774d.jpg'),
(90603, 6337, 'Edição de Amanhã S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192676.mp4', 'http://timg.bdta.pro/images/415b2126f737258a8278173965e05357.jpg'),
(90604, 6337, 'Edição de Amanhã S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192677.mp4', 'http://timg.bdta.pro/images/948ab70097ab3baf53a838fd4ea44761.jpg'),
(90605, 6337, 'Edição de Amanhã S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192678.mp4', 'http://timg.bdta.pro/images/42092be893ef3658e017da5f26bd5aac.jpg'),
(90606, 6337, 'Edição de Amanhã S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192679.mp4', 'http://timg.bdta.pro/images/b020adba6c1b3b51e992a864d5336902.jpg'),
(90607, 6337, 'Edição de Amanhã S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192680.mp4', 'http://timg.bdta.pro/images/8b4ef12cabdffe48f105cc8fadccdab1.jpg'),
(90608, 6337, 'Edição de Amanhã S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192681.mp4', 'http://timg.bdta.pro/images/2f84034a778eafb868e7dd2dc918fe3c.jpg'),
(90609, 6337, 'Edição de Amanhã S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192682.mp4', 'http://timg.bdta.pro/images/cab212486056456c5e3a3ba590b3976f.jpg'),
(90610, 6337, 'Edição de Amanhã S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192683.mp4', 'http://timg.bdta.pro/images/317c77d7ed25c5c31c1a663debc4cf40.jpg'),
(90611, 6337, 'Edição de Amanhã S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192684.mp4', 'http://timg.bdta.pro/images/a090e4d4c68f758e415c81949c5c33e8.jpg'),
(90612, 6337, 'Edição de Amanhã S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/192685.mp4', 'http://timg.bdta.pro/images/d21a08efe14896ab5aa0ee94af7a23c0.jpg'),
(90613, 6337, 'Edição de Amanhã S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/192686.mp4', 'http://timg.bdta.pro/images/8c18f5edcc2c90022f657173bca2d0d8.jpg'),
(90614, 6337, 'Edição de Amanhã S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/192687.mp4', 'http://timg.bdta.pro/images/233d90fbf78dafa4c576c2bb2b42f986.jpg'),
(90615, 6337, 'Edição de Amanhã S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/192688.mp4', 'http://timg.bdta.pro/images/c0594cfe0db13660b4041ea42adb96c1.jpg'),
(90616, 6337, 'Edição de Amanhã S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/192689.mp4', 'http://timg.bdta.pro/images/ab5d94ddd5d3e54fc6ea0402ddae7925.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(90617, 6337, 'Edição de Amanhã S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/192690.mp4', 'http://timg.bdta.pro/images/ff7672eba13d42ae4426ef4e8399d03c.jpg'),
(90618, 6337, 'Edição de Amanhã S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/192691.mp4', 'http://timg.bdta.pro/images/aedf1fb3aafa0d1329114c939b88d0bf.jpg'),
(90619, 6337, 'Edição de Amanhã S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/192692.mp4', 'http://timg.bdta.pro/images/e7e0f1673734ee3d83a1ee7bc52a119a.jpg'),
(90620, 6337, 'Edição de Amanhã S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/192693.mp4', 'http://timg.bdta.pro/images/1e6b5a3a0721b80ac6eadf253e241257.jpg'),
(90621, 6337, 'Edição de Amanhã S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/192694.mp4', 'http://timg.bdta.pro/images/8b37ba17970a6e29a59e74ad80ce5026.jpg'),
(90622, 6337, 'Edição de Amanhã S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/192695.mp4', 'http://timg.bdta.pro/images/e0953a5c4d77e4e6791e33428177afcf.jpg'),
(90623, 6338, 'Edição de Amanhã S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192696.mp4', 'http://timg.bdta.pro/images/9be3b3f4df63a836233d14873df6f00b.jpg'),
(90624, 6338, 'Edição de Amanhã S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192697.mp4', 'http://timg.bdta.pro/images/aab188ad7ca111b8b8b55b7ba891636f.jpg'),
(90625, 6338, 'Edição de Amanhã S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192698.mp4', 'http://timg.bdta.pro/images/1792c5c66fda3767ec35554051a6aa89.jpg'),
(90626, 6338, 'Edição de Amanhã S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192699.mp4', 'http://timg.bdta.pro/images/233d13aacd192c930a100f6613184be0.jpg'),
(90627, 6338, 'Edição de Amanhã S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192700.mp4', 'http://timg.bdta.pro/images/15bafa9e4be40ff9bc89cb33d33582a4.jpg'),
(90628, 6338, 'Edição de Amanhã S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192701.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90629, 6338, 'Edição de Amanhã S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192702.mp4', 'http://timg.bdta.pro/images/3fc3e924f1009ca1ee437af47d1826fa.jpg'),
(90630, 6338, 'Edição de Amanhã S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192703.mp4', 'http://timg.bdta.pro/images/1655cf9f134fe1a93b2e17220ca36eda.jpg'),
(90631, 6338, 'Edição de Amanhã S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192704.mp4', 'http://timg.bdta.pro/images/ac0cad2c3f7ad26458336349556c9366.jpg'),
(90632, 6338, 'Edição de Amanhã S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192705.mp4', 'http://timg.bdta.pro/images/7acdef7c9d7738a302efb7bd76d318a8.jpg'),
(90633, 6338, 'Edição de Amanhã S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192706.mp4', 'http://timg.bdta.pro/images/6ab92a0d0b29c84572f73b9e99759e59.jpg'),
(90634, 6338, 'Edição de Amanhã S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192707.mp4', 'http://timg.bdta.pro/images/428719dbbf8ba09d40f8ae0a5f12a062.jpg'),
(90635, 6338, 'Edição de Amanhã S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/192708.mp4', 'http://timg.bdta.pro/images/f33955b5fbc2a3f533e307c69702af39.jpg'),
(90636, 6338, 'Edição de Amanhã S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/192709.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90637, 6338, 'Edição de Amanhã S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/192710.mp4', 'http://timg.bdta.pro/images/a0755c29ab8dc2129c7a3d6af78110de.jpg'),
(90638, 6338, 'Edição de Amanhã S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/192711.mp4', 'http://timg.bdta.pro/images/803f2c1c817637deb87f5662581a236c.jpg'),
(90639, 6338, 'Edição de Amanhã S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/192712.mp4', 'http://timg.bdta.pro/images/ce379973100670f31129ce2290a0026e.jpg'),
(90640, 6338, 'Edição de Amanhã S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/192713.mp4', 'http://timg.bdta.pro/images/d0afeeb3fc16cb6f193792b199074c28.jpg'),
(90641, 6338, 'Edição de Amanhã S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/192714.mp4', 'http://timg.bdta.pro/images/ad36c73d61c890729dded43c83b74f56.jpg'),
(90642, 6338, 'Edição de Amanhã S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/192715.mp4', 'http://timg.bdta.pro/images/ccb5ff7a7a729329a1c6e9486740dcc9.jpg'),
(90643, 6338, 'Edição de Amanhã S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/192716.mp4', 'http://timg.bdta.pro/images/4bb2d3e87f59ad4e9c00e4fd63a5f097.jpg'),
(90644, 6338, 'Edição de Amanhã S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/192717.mp4', 'http://timg.bdta.pro/images/558b5f3e53ba306d33faaaf47868254f.jpg'),
(90645, 6339, 'Edição de Amanhã S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192718.mp4', 'http://timg.bdta.pro/images/8dec263845f7d128d4206c6ce9bbc63f.jpg'),
(90646, 6339, 'Edição de Amanhã S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192719.mp4', 'http://timg.bdta.pro/images/e09865a246500211f20034dbe8c7f1c0.jpg'),
(90647, 6339, 'Edição de Amanhã S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192720.mp4', 'http://timg.bdta.pro/images/ec935bfe80f1d3971dff5c649ac074f1.jpg'),
(90648, 6339, 'Edição de Amanhã S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192721.mp4', 'http://timg.bdta.pro/images/58d6c197a931c0d1324872ad48f78be3.jpg'),
(90649, 6339, 'Edição de Amanhã S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192722.mp4', 'http://timg.bdta.pro/images/4fac98b2d0bd10b6b68972cf5856908f.jpg'),
(90650, 6339, 'Edição de Amanhã S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192723.mp4', 'http://timg.bdta.pro/images/78061d3c8591cb62e9acad4f3602a20c.jpg'),
(90651, 6339, 'Edição de Amanhã S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192724.mp4', 'http://timg.bdta.pro/images/2b05949af96775c6a02a56d67e1015f7.jpg'),
(90652, 6339, 'Edição de Amanhã S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192725.mp4', 'http://timg.bdta.pro/images/50d42fcb7b6fde780770bdf3409bdb7d.jpg'),
(90653, 6339, 'Edição de Amanhã S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192726.mp4', 'http://timg.bdta.pro/images/6ff6479a2fd1805c5faec819b088658b.jpg'),
(90654, 6339, 'Edição de Amanhã S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192727.mp4', 'http://timg.bdta.pro/images/efae807b800ec40f37b71449cd1d2968.jpg'),
(90655, 6339, 'Edição de Amanhã S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192728.mp4', 'http://timg.bdta.pro/images/5162b58118e6fa568b472352821bebdf.jpg'),
(90656, 6339, 'Edição de Amanhã S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192729.mp4', 'http://timg.bdta.pro/images/c6b8e81e47018c8f789975e4afd86750.jpg'),
(90657, 6339, 'Edição de Amanhã S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/192730.mp4', 'http://timg.bdta.pro/images/f4e51b49f0202a02c446e79514a23308.jpg'),
(90658, 6339, 'Edição de Amanhã S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/192731.mp4', 'http://timg.bdta.pro/images/6dcc2cb74b2461c2342b51c392067cba.jpg'),
(90659, 6339, 'Edição de Amanhã S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/192732.mp4', 'http://timg.bdta.pro/images/5beb0aa26e2a4f43918e03621bce6895.jpg'),
(90660, 6339, 'Edição de Amanhã S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/192733.mp4', 'http://timg.bdta.pro/images/3abedec9e3f6a99b56878ba7b011055c.jpg'),
(90661, 6339, 'Edição de Amanhã S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/192734.mp4', 'http://timg.bdta.pro/images/cd08176ae20aaa8b346409e6f11564c3.jpg'),
(90662, 6339, 'Edição de Amanhã S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/192735.mp4', 'http://timg.bdta.pro/images/32f741818ba47a2b00ebbd25a8cab8cb.jpg'),
(90663, 6339, 'Edição de Amanhã S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/192736.mp4', 'http://timg.bdta.pro/images/68ab22f9ce4bf6f3d45be067faa67075.jpg'),
(90664, 6339, 'Edição de Amanhã S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/192737.mp4', 'http://timg.bdta.pro/images/3bde4c5fbea682f13750f837647c79c8.jpg'),
(90665, 6339, 'Edição de Amanhã S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/192738.mp4', 'http://timg.bdta.pro/images/2e6f4571504f5fdef9e23e372fc40889.jpg'),
(90666, 6339, 'Edição de Amanhã S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/192739.mp4', 'http://timg.bdta.pro/images/c745b35c26fcfc7785fd303c472b700d.jpg'),
(90667, 6339, 'Edição de Amanhã S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/192740.mp4', 'http://timg.bdta.pro/images/81e10a4cd2939dfcc2e6f496f6e52375.jpg'),
(90668, 6340, 'Edição de Amanhã S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/310593.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90669, 6340, 'Edição de Amanhã S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/310594.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90670, 6340, 'Edição de Amanhã S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/310595.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90671, 6340, 'Edição de Amanhã S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/310596.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90672, 6340, 'Edição de Amanhã S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/310597.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90673, 6340, 'Edição de Amanhã S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/310598.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90674, 6340, 'Edição de Amanhã S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/310599.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90675, 6340, 'Edição de Amanhã S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/310600.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90676, 6340, 'Edição de Amanhã S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/310601.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90677, 6340, 'Edição de Amanhã S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/310602.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90678, 6340, 'Edição de Amanhã S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/310603.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90679, 6340, 'Edição de Amanhã S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/310604.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90680, 6340, 'Edição de Amanhã S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/310605.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90681, 6340, 'Edição de Amanhã S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/310606.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90682, 6340, 'Edição de Amanhã S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/310607.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90683, 6340, 'Edição de Amanhã S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/310608.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90684, 6340, 'Edição de Amanhã S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/310609.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90685, 6340, 'Edição de Amanhã S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/310610.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90686, 6340, 'Edição de Amanhã S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/310611.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90687, 6340, 'Edição de Amanhã S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/310612.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90688, 6340, 'Edição de Amanhã S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/310613.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90689, 6340, 'Edição de Amanhã S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/310614.mp4', 'http://gstaticontent.com/images/4afbbb8767f79ce41718b057c2252307.jpg'),
(90690, 6341, 'Entrapped S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192667.mp4', 'http://timg.bdta.pro/images/6df8251ba389f493238c0752405246d2.jpg'),
(90691, 6341, 'Entrapped S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192668.mp4', 'http://timg.bdta.pro/images/86f1e37c00b9255923a64f3f0ff40514.jpg'),
(90692, 6341, 'Entrapped S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192669.mp4', 'http://timg.bdta.pro/images/6afc7bfd8128f87bba3e0301553cea0d.jpg'),
(90693, 6341, 'Entrapped S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192670.mp4', 'http://timg.bdta.pro/images/c1d5d2584eecc591b037175957778ad1.jpg'),
(90694, 6341, 'Entrapped S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192671.mp4', 'http://timg.bdta.pro/images/6df8251ba389f493238c0752405246d2.jpg'),
(90695, 6341, 'Entrapped S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192672.mp4', 'http://timg.bdta.pro/images/6afc7bfd8128f87bba3e0301553cea0d.jpg'),
(90696, 6342, 'Entre Casamentos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192659.mp4', 'http://timg.bdta.pro/images/8fe8d2a1cbe2e9df455790779c7c3ee4.jpg'),
(90697, 6342, 'Entre Casamentos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192660.mp4', 'http://timg.bdta.pro/images/cb1a5c617d4beff74df9a0d072f377e1.jpg'),
(90698, 6342, 'Entre Casamentos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192661.mp4', 'http://timg.bdta.pro/images/df3145a1f212e08724628f46843dbb01.jpg'),
(90699, 6342, 'Entre Casamentos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192662.mp4', 'http://timg.bdta.pro/images/27f6cb9c79e770cd8a739ba2926925fd.jpg'),
(90700, 6342, 'Entre Casamentos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192663.mp4', 'http://timg.bdta.pro/images/01b758c188c6a6beb9cd76aa861c7138.jpg'),
(90701, 6342, 'Entre Casamentos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192664.mp4', 'http://timg.bdta.pro/images/f5575a2d972c858a14e8fb1fc56cd659.jpg'),
(90702, 6342, 'Entre Casamentos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192665.mp4', 'http://timg.bdta.pro/images/2b8108f41a4d3227429ef8d640d60d2a.jpg'),
(90703, 6342, 'Entre Casamentos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192666.mp4', 'http://timg.bdta.pro/images/3b8b6c7db938114170ebebee456a563d.jpg'),
(90704, 6343, 'Fogo Ardente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192620.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90705, 6343, 'Fogo Ardente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192621.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90706, 6343, 'Fogo Ardente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192622.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90707, 6343, 'Fogo Ardente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192623.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90708, 6343, 'Fogo Ardente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192624.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90709, 6343, 'Fogo Ardente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192625.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90710, 6343, 'Fogo Ardente S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192626.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90711, 6343, 'Fogo Ardente S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192627.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90712, 6343, 'Fogo Ardente S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192628.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90713, 6343, 'Fogo Ardente S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192629.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90714, 6343, 'Fogo Ardente S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192630.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90715, 6343, 'Fogo Ardente S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192631.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90716, 6343, 'Fogo Ardente S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/192632.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90717, 6343, 'Fogo Ardente S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/192633.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90718, 6343, 'Fogo Ardente S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/192634.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90719, 6343, 'Fogo Ardente S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/192635.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90720, 6343, 'Fogo Ardente S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/192636.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90721, 6343, 'Fogo Ardente S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/192637.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90722, 6343, 'Fogo Ardente S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/192638.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90723, 6343, 'Fogo Ardente S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/192639.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90724, 6343, 'Fogo Ardente S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/192640.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90725, 6343, 'Fogo Ardente S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/192641.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90726, 6343, 'Fogo Ardente S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/192642.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90727, 6343, 'Fogo Ardente S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/192643.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90728, 6343, 'Fogo Ardente S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/192644.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90729, 6343, 'Fogo Ardente S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/192645.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90730, 6343, 'Fogo Ardente S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/192646.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90731, 6343, 'Fogo Ardente S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/192647.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90732, 6343, 'Fogo Ardente S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/192648.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90733, 6343, 'Fogo Ardente S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/192649.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90734, 6343, 'Fogo Ardente S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/192650.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90735, 6343, 'Fogo Ardente S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/192651.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90736, 6343, 'Fogo Ardente S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/192652.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90737, 6343, 'Fogo Ardente S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/192653.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90738, 6343, 'Fogo Ardente S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/192654.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90739, 6343, 'Fogo Ardente S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/192655.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90740, 6343, 'Fogo Ardente S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/192656.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90741, 6343, 'Fogo Ardente S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/192657.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90742, 6343, 'Fogo Ardente S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/192658.mp4', 'http://gstaticontent.com/images/1a7242cabcef81a8f9cf1c3f52f68864.jpg'),
(90743, 6344, 'Hebe: Um Brinde à Vida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192616.mp4', 'http://timg.bdta.pro/images/c78905ff6697123ff435d11d428e8210.jpg'),
(90744, 6344, 'Hebe: Um Brinde à Vida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192617.mp4', 'http://timg.bdta.pro/images/636687a7d7955e5aae46cc87ef399361.jpg'),
(90745, 6344, 'Hebe: Um Brinde à Vida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192618.mp4', 'http://timg.bdta.pro/images/45b6185c7de25b31730b0211180046df.jpg'),
(90746, 6344, 'Hebe: Um Brinde à Vida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192619.mp4', 'http://timg.bdta.pro/images/09d1544d4f747b4f6e231e8b42bca4e6.jpg'),
(90747, 6345, 'Imperfeitos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192606.mp4', 'http://timg.bdta.pro/images/f8cc66c53fd67e33b18f6648354838c1.jpg'),
(90748, 6345, 'Imperfeitos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192607.mp4', 'http://timg.bdta.pro/images/f901228788f56d0d4f82b51c47cf3aaa.jpg'),
(90749, 6345, 'Imperfeitos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192608.mp4', 'http://timg.bdta.pro/images/f98589465ff881d1c0b2cee381a83a62.jpg'),
(90750, 6345, 'Imperfeitos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192609.mp4', 'http://timg.bdta.pro/images/763d48d724c38a7ce2e7f9f6723d8bbd.jpg'),
(90751, 6345, 'Imperfeitos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192610.mp4', 'http://timg.bdta.pro/images/eb24ac00b19494b92b92995cb4ef1c48.jpg'),
(90752, 6345, 'Imperfeitos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192611.mp4', 'http://timg.bdta.pro/images/f985d16c9670f8f2426ecc407fe88b5d.jpg'),
(90753, 6345, 'Imperfeitos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192612.mp4', 'http://timg.bdta.pro/images/2a2bc67aa4c0f9b928f8a0c6757fa1ee.jpg'),
(90754, 6345, 'Imperfeitos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192613.mp4', 'http://timg.bdta.pro/images/b860bc1541bbdeb21581702417a36422.jpg'),
(90755, 6345, 'Imperfeitos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192614.mp4', 'http://timg.bdta.pro/images/10078293088e6aad1649838afde7cf0d.jpg'),
(90756, 6345, 'Imperfeitos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192615.mp4', 'http://timg.bdta.pro/images/ee6ba6a819015876fdd4886e00eacb1f.jpg'),
(90757, 6346, 'Lupin the 3rd Part 6 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192581.mp4', 'http://timg.bdta.pro/images/69395b2e41be5019d5799601d20f0d06.jpg'),
(90758, 6346, 'Lupin the 3rd Part 6 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192582.mp4', 'http://timg.bdta.pro/images/3aac2397b2a651974b9269866424278d.jpg'),
(90759, 6346, 'Lupin the 3rd Part 6 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192583.mp4', 'http://timg.bdta.pro/images/5ecb8c383f2bb4b83ede695bbedce8e3.jpg'),
(90760, 6346, 'Lupin the 3rd Part 6 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192584.mp4', 'http://timg.bdta.pro/images/e753ff866f09ea2bd5675e8a689c7710.jpg'),
(90761, 6346, 'Lupin the 3rd Part 6 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192585.mp4', 'http://timg.bdta.pro/images/6851124805f886be4ae6609d5a563337.jpg'),
(90762, 6346, 'Lupin the 3rd Part 6 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192586.mp4', 'http://timg.bdta.pro/images/5fc50b3293718a837363fa00daed6355.jpg'),
(90763, 6346, 'Lupin the 3rd Part 6 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192587.mp4', 'http://timg.bdta.pro/images/5b08b71f0a56a1989a06bcfe2c23cdac.jpg'),
(90764, 6346, 'Lupin the 3rd Part 6 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192588.mp4', 'http://timg.bdta.pro/images/98fe744512c14906a1a1b1f9b700dbc7.jpg'),
(90765, 6346, 'Lupin the 3rd Part 6 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192589.mp4', 'http://timg.bdta.pro/images/56e91d31ee9cc681378f6ab6d90f9b3d.jpg'),
(90766, 6346, 'Lupin the 3rd Part 6 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192590.mp4', 'http://timg.bdta.pro/images/8bb3310a0d8e2a639609b446c9f77fd2.jpg'),
(90767, 6346, 'Lupin the 3rd Part 6 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192591.mp4', 'http://timg.bdta.pro/images/12d96a0b7f647a3a72a2849df5aa44a1.jpg'),
(90768, 6346, 'Lupin the 3rd Part 6 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192592.mp4', 'http://timg.bdta.pro/images/79b0732bed3e2292a69ad04fa7a58dbc.jpg'),
(90769, 6346, 'Lupin the 3rd Part 6 S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/192593.mp4', 'http://timg.bdta.pro/images/36e471ac1a858cfb50918082cca3a473.jpg'),
(90770, 6346, 'Lupin the 3rd Part 6 S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/192594.mp4', 'http://timg.bdta.pro/images/63698e37169c85d033573ae137a89610.jpg'),
(90771, 6346, 'Lupin the 3rd Part 6 S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/192595.mp4', 'http://timg.bdta.pro/images/ef936d8cfb827efa691fbfd37606c64f.jpg'),
(90772, 6346, 'Lupin the 3rd Part 6 S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/192596.mp4', 'http://timg.bdta.pro/images/ce23a6f4703d1fb5c44041df5c70ed9b.jpg'),
(90773, 6346, 'Lupin the 3rd Part 6 S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/192597.mp4', 'http://timg.bdta.pro/images/0ce06f06c199ac2ee567ab3f0cf9045b.jpg'),
(90774, 6346, 'Lupin the 3rd Part 6 S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/192598.mp4', 'http://timg.bdta.pro/images/a8199d17a6b908fc8412393e1d69ab85.jpg'),
(90775, 6346, 'Lupin the 3rd Part 6 S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/192599.mp4', 'http://timg.bdta.pro/images/51af7cc7583becd354c7cf41fdaaa649.jpg'),
(90776, 6346, 'Lupin the 3rd Part 6 S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/192600.mp4', 'http://timg.bdta.pro/images/c3b7fe6e8f945c365ec19fd19e2997ad.jpg'),
(90777, 6346, 'Lupin the 3rd Part 6 S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/192601.mp4', 'http://timg.bdta.pro/images/65f557dae03abeeefa0938083f620bb3.jpg'),
(90778, 6346, 'Lupin the 3rd Part 6 S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/192602.mp4', 'http://timg.bdta.pro/images/7d2f32ff8f235f4f5e1c5b25c32479ea.jpg'),
(90779, 6346, 'Lupin the 3rd Part 6 S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/192603.mp4', 'http://timg.bdta.pro/images/1bad10dbb45636b9c5f84453bddef3eb.jpg'),
(90780, 6346, 'Lupin the 3rd Part 6 S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/192604.mp4', 'http://gstaticontent.com/images/8d948015d24c58c500d71d2e83f16142.jpg'),
(90781, 6346, 'Lupin the 3rd Part 6 S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/192605.mp4', 'http://gstaticontent.com/images/8d948015d24c58c500d71d2e83f16142.jpg'),
(90782, 6347, 'Malcolm S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204436.mp4', 'http://timg.bdta.pro/images/367dff2fd1ef24d3a3afbb5816f03245.jpg'),
(90783, 6347, 'Malcolm S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204437.mp4', 'http://timg.bdta.pro/images/d9106016e577d07a2661c3f875c00f78.jpg'),
(90784, 6347, 'Malcolm S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204438.mp4', 'http://timg.bdta.pro/images/e4e4f120b61c13e32111646e8041a42b.jpg'),
(90785, 6347, 'Malcolm S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204439.mp4', 'http://timg.bdta.pro/images/d1807ddf9a35e6cb705baffa2a72dce1.jpg'),
(90786, 6347, 'Malcolm S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204440.mp4', 'http://timg.bdta.pro/images/cbe5f7dc1493378979dbc6feb0a2cd92.jpg'),
(90787, 6347, 'Malcolm S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204441.mp4', 'http://timg.bdta.pro/images/5128fe48bcbb1ac76c3c5e0a69e9f364.jpg'),
(90788, 6347, 'Malcolm S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204442.mp4', 'http://timg.bdta.pro/images/2d48ab4a74e601ccb9ccc3353b4b0a28.jpg'),
(90789, 6347, 'Malcolm S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204443.mp4', 'http://timg.bdta.pro/images/089d734878edcb3427dd146e3c031efd.jpg'),
(90790, 6347, 'Malcolm S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204444.mp4', 'http://timg.bdta.pro/images/ea06a590842d82346d5de80511c516db.jpg'),
(90791, 6347, 'Malcolm S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204445.mp4', 'http://timg.bdta.pro/images/3cce19d15e9942759309f3e8645b2de9.jpg'),
(90792, 6347, 'Malcolm S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204446.mp4', 'http://timg.bdta.pro/images/bf1760d61732aedf39bd9a06a3f17d78.jpg'),
(90793, 6347, 'Malcolm S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204447.mp4', 'http://timg.bdta.pro/images/3f2c40e27d8a3b494d8b1151d16f52bc.jpg'),
(90794, 6347, 'Malcolm S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204448.mp4', 'http://timg.bdta.pro/images/ed910bdb5385609fd39f276fb2cb5e89.jpg'),
(90795, 6347, 'Malcolm S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/204449.mp4', 'http://timg.bdta.pro/images/3c787b6c05e3a7bf8ee318bc804282d4.jpg'),
(90796, 6347, 'Malcolm S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/204450.mp4', 'http://timg.bdta.pro/images/3c87e2b4f04fb9f59d98aaaf59dd5632.jpg'),
(90797, 6347, 'Malcolm S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/204451.mp4', 'http://timg.bdta.pro/images/7e80630bf8356d321b8478f04852d0a8.jpg'),
(90798, 6348, 'Malcolm S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204452.mp4', 'http://timg.bdta.pro/images/b00298321ea0135dbdc243e8a8ebbd55.jpg'),
(90799, 6348, 'Malcolm S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204453.mp4', 'http://timg.bdta.pro/images/09bebe68d86b1005fbdfc67cd97d83a0.jpg'),
(90800, 6348, 'Malcolm S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204454.mp4', 'http://timg.bdta.pro/images/b29c0d632a5ada103176ec0a0089805e.jpg'),
(90801, 6348, 'Malcolm S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204455.mp4', 'http://timg.bdta.pro/images/5eb8a3355034e1ed6b0e8ee92831dec7.jpg'),
(90802, 6348, 'Malcolm S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204456.mp4', 'http://timg.bdta.pro/images/5ebd04f2880ad7f6189dab1d9c2a7e09.jpg'),
(90803, 6348, 'Malcolm S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204457.mp4', 'http://timg.bdta.pro/images/ce1a33ed0e008b210808d43fb7a26dbc.jpg'),
(90804, 6348, 'Malcolm S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204458.mp4', 'http://timg.bdta.pro/images/839df74067153b56da9abda1f01d929b.jpg'),
(90805, 6348, 'Malcolm S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204459.mp4', 'http://timg.bdta.pro/images/69d71a5b32aef3d5da6bd155c45d9369.jpg'),
(90806, 6348, 'Malcolm S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204460.mp4', 'http://timg.bdta.pro/images/280468d0c735e3999109ca2f6b4d0efd.jpg'),
(90807, 6348, 'Malcolm S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204461.mp4', 'http://timg.bdta.pro/images/96926f86cd544f5f55e5f829501c9356.jpg'),
(90808, 6348, 'Malcolm S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204462.mp4', 'http://timg.bdta.pro/images/5517b65191bc5d22008ddcf666a9e40f.jpg'),
(90809, 6348, 'Malcolm S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204463.mp4', 'http://timg.bdta.pro/images/7e4b9dc6928957a42951dac9fa9877ad.jpg'),
(90810, 6348, 'Malcolm S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204464.mp4', 'http://timg.bdta.pro/images/e718189ef0e0757f8079a1d34b3cd4ca.jpg'),
(90811, 6348, 'Malcolm S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/204465.mp4', 'http://timg.bdta.pro/images/af1db13e588588203d6e0ec2926953b8.jpg'),
(90812, 6348, 'Malcolm S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/204466.mp4', 'http://timg.bdta.pro/images/d082fc70336cdce21c48726cef116823.jpg'),
(90813, 6348, 'Malcolm S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/204467.mp4', 'http://timg.bdta.pro/images/768cf08d3ef6b7d5600f5637f78186e2.jpg'),
(90814, 6348, 'Malcolm S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/204468.mp4', 'http://timg.bdta.pro/images/327416f35f466f16c0bf0e1f7391c130.jpg'),
(90815, 6348, 'Malcolm S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/204469.mp4', 'http://timg.bdta.pro/images/87be0fcd352fd92c57cba9b3daafd130.jpg'),
(90816, 6348, 'Malcolm S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/204470.mp4', 'http://timg.bdta.pro/images/19e9406e7dde108bab70e8bdaf631709.jpg'),
(90817, 6348, 'Malcolm S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/204471.mp4', 'http://timg.bdta.pro/images/cbf38b5d32fb68c412496469daa60256.jpg'),
(90818, 6348, 'Malcolm S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/204472.mp4', 'http://timg.bdta.pro/images/01cabb2156ee6269bb8f088837ebb886.jpg'),
(90819, 6348, 'Malcolm S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/204473.mp4', 'http://timg.bdta.pro/images/2f93a3bc3a3eda0c5ab98275a9aa7f44.jpg'),
(90820, 6348, 'Malcolm S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/204474.mp4', 'http://timg.bdta.pro/images/0d6263e665570a79241fc1f25bda2b72.jpg'),
(90821, 6348, 'Malcolm S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/204475.mp4', 'http://timg.bdta.pro/images/86e397471ee40292fd3d9416056a0520.jpg'),
(90822, 6349, 'Malcolm S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204476.mp4', 'http://timg.bdta.pro/images/697b50fd12d7eb4eb7fe7a45b8581755.jpg'),
(90823, 6349, 'Malcolm S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204477.mp4', 'http://timg.bdta.pro/images/cc612024f68204fd851ffe747f6108e9.jpg'),
(90824, 6349, 'Malcolm S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204478.mp4', 'http://timg.bdta.pro/images/878865069ee47ef114217375221cb00d.jpg'),
(90825, 6349, 'Malcolm S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204479.mp4', 'http://timg.bdta.pro/images/add9444a45bef45a24faf9546b735173.jpg'),
(90826, 6349, 'Malcolm S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204480.mp4', 'http://timg.bdta.pro/images/6f42a59bf8dc30feef1ebfcdcd097a88.jpg'),
(90827, 6349, 'Malcolm S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204481.mp4', 'http://timg.bdta.pro/images/f05c20fb1b99a896b883b1a99da308e7.jpg'),
(90828, 6349, 'Malcolm S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204482.mp4', 'http://timg.bdta.pro/images/cc992cb277b04441df17d66f1261b436.jpg'),
(90829, 6349, 'Malcolm S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204483.mp4', 'http://timg.bdta.pro/images/8216c2cb75d007e9d70253511dc10311.jpg'),
(90830, 6349, 'Malcolm S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204484.mp4', 'http://timg.bdta.pro/images/9359696b377c7c587950cc98082626e8.jpg'),
(90831, 6349, 'Malcolm S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204485.mp4', 'http://timg.bdta.pro/images/20d02d28fc32dd05552678ba710e9687.jpg'),
(90832, 6349, 'Malcolm S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204486.mp4', 'http://timg.bdta.pro/images/27b3f4059b302f8272624452bf8d2dfa.jpg'),
(90833, 6349, 'Malcolm S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204487.mp4', 'http://timg.bdta.pro/images/5b9a8c895676ec1cf9b1ba62abd48adf.jpg'),
(90834, 6349, 'Malcolm S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204488.mp4', 'http://timg.bdta.pro/images/5ad9cd5591f770c4a3a0e8e9ca625cc3.jpg'),
(90835, 6349, 'Malcolm S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/204489.mp4', 'http://timg.bdta.pro/images/806616ed4a2912c412d2eb4bbcb23208.jpg'),
(90836, 6349, 'Malcolm S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/204490.mp4', 'http://timg.bdta.pro/images/01f31fa6afc8cd63d7f567bd3c1cea91.jpg'),
(90837, 6350, 'Malcolm S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204491.mp4', 'http://timg.bdta.pro/images/8f2b77e85169b39897fc8d8bd5cf7336.jpg'),
(90838, 6350, 'Malcolm S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204492.mp4', 'http://timg.bdta.pro/images/d51a81b5d2f68eb877057178575e2807.jpg'),
(90839, 6350, 'Malcolm S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204493.mp4', 'http://timg.bdta.pro/images/16fcf829b79972151c287555972375ad.jpg'),
(90840, 6350, 'Malcolm S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204494.mp4', 'http://timg.bdta.pro/images/391d2db783965b8a2fe19eb09c8fdbc8.jpg'),
(90841, 6350, 'Malcolm S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204495.mp4', 'http://timg.bdta.pro/images/43fb4b289a2182169d50faa79dea199e.jpg'),
(90842, 6350, 'Malcolm S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204496.mp4', 'http://timg.bdta.pro/images/ed63ab89f277634824d949cc1c1ffe6f.jpg'),
(90843, 6350, 'Malcolm S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204497.mp4', 'http://timg.bdta.pro/images/0b99f26c200962a54c66c4a4013369c4.jpg'),
(90844, 6350, 'Malcolm S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204498.mp4', 'http://timg.bdta.pro/images/6eade2fd1d51965d4074aaba974704af.jpg'),
(90845, 6350, 'Malcolm S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204499.mp4', 'http://timg.bdta.pro/images/1e646b1dc46e5a53e44bdde7a3507f21.jpg'),
(90846, 6350, 'Malcolm S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204500.mp4', 'http://timg.bdta.pro/images/caf2f3cd47418f2bd04b151cfd8a5dea.jpg'),
(90847, 6350, 'Malcolm S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204501.mp4', 'http://timg.bdta.pro/images/9998519880a825d6319ff03ce4d25493.jpg'),
(90848, 6350, 'Malcolm S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204502.mp4', 'http://timg.bdta.pro/images/508847d9d3e3f96352304b153857f7f3.jpg'),
(90849, 6350, 'Malcolm S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204503.mp4', 'http://timg.bdta.pro/images/67a42120d313f2841bbb3d23a2c50f5b.jpg'),
(90850, 6350, 'Malcolm S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/204504.mp4', 'http://timg.bdta.pro/images/bd4b4ff9a6e3eeedaddd09cb39ea4698.jpg'),
(90851, 6350, 'Malcolm S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/204505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/WfD201VetLHutaZ5IncGzRpWTI.jpg'),
(90852, 6350, 'Malcolm S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/204506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2nCEBzjSMALpdPKNFc6TVi90PoT.jpg'),
(90853, 6350, 'Malcolm S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/204507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/96NAqWhYKZJnfLaoKpEBNuv1GiB.jpg'),
(90854, 6350, 'Malcolm S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/204508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uMQ15kB01h7VkHTcw5NPj3cangP.jpg'),
(90855, 6350, 'Malcolm S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/204509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/62w0wCGmz77Y9Nlt5t5PHZiYiR7.jpg'),
(90856, 6350, 'Malcolm S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/204510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gf7UBXldCJ2FU4EKtdbj7aMi2Lb.jpg'),
(90857, 6350, 'Malcolm S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/204511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bq0LwGQPDEmz8kOugNN24xZ4F9v.jpg'),
(90858, 6351, 'Malcolm S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yG9bTe30UmSWoBSZQhrpQ2BRM4X.jpg'),
(90859, 6351, 'Malcolm S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jqiBjPLrV3Oqt7Vj4OX9kMNfvwA.jpg'),
(90860, 6351, 'Malcolm S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/on0t7A0dcgcOdivVTuJUTw5Q37I.jpg'),
(90861, 6351, 'Malcolm S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/80MlvKrLUmmPFkqZuBlAL8i09QT.jpg'),
(90862, 6351, 'Malcolm S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qJXLXlLQv4Mv3ktDPIJ7xZt5gBr.jpg'),
(90863, 6351, 'Malcolm S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wrkLgL6Ff4ckfRz7Gjw7RG0bPZs.jpg'),
(90864, 6351, 'Malcolm S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4BHRk23uPvwocKi71b4AWo065XL.jpg'),
(90865, 6351, 'Malcolm S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xlVknKXpfE3xk3gJfoGWSMG65S.jpg'),
(90866, 6351, 'Malcolm S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7DvnFH2Zu2GglFEs5QeWSWiLiul.jpg'),
(90867, 6351, 'Malcolm S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8L3ZYxNAcSzqFljXNOYHMo3i6bG.jpg'),
(90868, 6351, 'Malcolm S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhqbsBAhWaPeB8i7NEPWCT2ilzp.jpg'),
(90869, 6351, 'Malcolm S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/clvokONdVTAJWWOVGszYRr1aPJs.jpg'),
(90870, 6351, 'Malcolm S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AnBk8YuGPX6lxJ7au3RXjWDxOge.jpg'),
(90871, 6351, 'Malcolm S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/204525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bxEiGSXZe5bSaZSZ8elKXpRqtoT.jpg'),
(90872, 6351, 'Malcolm S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/204526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nGeMQWKvhGRsSLeRorUahHdmcX9.jpg'),
(90873, 6351, 'Malcolm S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/204527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mfNmDXHUnxHCZBRQtDK9kfVUDFO.jpg'),
(90874, 6351, 'Malcolm S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/204528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCi6h0lyIcqR8UTCt9Llim8psWt.jpg'),
(90875, 6351, 'Malcolm S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/204529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9jpyfHMQy3KKd0aPGeg5EFbh0xb.jpg'),
(90876, 6351, 'Malcolm S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/204530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iMO90dwaKaWuwclwhqec155Mqi7.jpg'),
(90877, 6351, 'Malcolm S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/204531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2bOa88fxk1xB3sHe1lrmfcSANpl.jpg'),
(90878, 6351, 'Malcolm S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/204532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dnQ9xAPYfXjbfn0YJMFvw7MzFY6.jpg'),
(90879, 6351, 'Malcolm S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/204533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKKpgJtEnIn6lYjTX7YWZgKaXGJ.jpg'),
(90880, 6352, 'Malcolm S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vOM99CPiApTQREmszJmQOwsRN9w.jpg'),
(90881, 6352, 'Malcolm S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7dneO4H77iLUXhw3ae8ZtydH1cJ.jpg'),
(90882, 6352, 'Malcolm S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yedJz4OGx6x54WVgzCx1GbYKcrL.jpg'),
(90883, 6352, 'Malcolm S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rIVuApr4ruRLFdrGTCtbSDVNz5e.jpg'),
(90884, 6352, 'Malcolm S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ubSEVcL6Y471n2dNAOrKxu5myk2.jpg'),
(90885, 6352, 'Malcolm S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dLTkm1Zsleb5hSqOAH3tWhY1Eh2.jpg'),
(90886, 6352, 'Malcolm S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybHFVCzVsXYmqNqrNmhLTcDHi17.jpg'),
(90887, 6352, 'Malcolm S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nNTF6NbASI2tTqj3dgruufv6rV9.jpg'),
(90888, 6352, 'Malcolm S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nfgLYp4fQjD4WpKxOqhZubPRanK.jpg'),
(90889, 6352, 'Malcolm S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nYIL8mmMeRZiSea2I59bA05uMrn.jpg'),
(90890, 6352, 'Malcolm S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/no1dPRsZ71M9vDNScC4nA3u5Zot.jpg'),
(90891, 6352, 'Malcolm S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/61QWIRDBrhPNZ7ZEffcISx9CGtG.jpg'),
(90892, 6352, 'Malcolm S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/exIvTHRESIvp3V6NTS2INpoQ9ZY.jpg'),
(90893, 6352, 'Malcolm S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/204547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6znLTdSrnRfR1YuoVArBHir2GQY.jpg'),
(90894, 6352, 'Malcolm S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/204548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3QMolfGwR9btOJa6xFf027DVYpS.jpg'),
(90895, 6352, 'Malcolm S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/204549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hGIIvk5oZdBAjVZSAx6ihiUELu5.jpg'),
(90896, 6352, 'Malcolm S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/204550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tD10r5mDKbB4FhVvIcyv1x2G5ci.jpg'),
(90897, 6352, 'Malcolm S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/204551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2bM71Rmi6MSJvK23gXA8nHtWnAK.jpg'),
(90898, 6352, 'Malcolm S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/204552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Uq7QOB3Tm3oMDTeYOgUF3rVSUO.jpg'),
(90899, 6352, 'Malcolm S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/204553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mGEji1rwtJn6mOOVFcFcG4AoG2J.jpg'),
(90900, 6352, 'Malcolm S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/204554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dR3r3qXeQwKFhAJhyMCh7vha4AZ.jpg'),
(90901, 6352, 'Malcolm S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/204555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nbZSmancbT0pbY3Kyrdiqs0Ud98.jpg'),
(90902, 6353, 'Na Mira do Fogo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192571.mp4', 'http://timg.bdta.pro/images/c94f1304db568c3e5e4d5272c90b1b9f.jpg'),
(90903, 6353, 'Na Mira do Fogo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192572.mp4', 'http://timg.bdta.pro/images/4e83f6bbf4c8faa881a6435e9ecc1d39.jpg'),
(90904, 6353, 'Na Mira do Fogo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192573.mp4', 'http://timg.bdta.pro/images/d083a6d4e0767e087618fa0ac0098086.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(90905, 6353, 'Na Mira do Fogo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192574.mp4', 'http://timg.bdta.pro/images/7c01b23b7dc1be501fad6276465ca41f.jpg'),
(90906, 6353, 'Na Mira do Fogo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192575.mp4', 'http://timg.bdta.pro/images/6d27abd6afc6053a5ba258e816ea7d06.jpg'),
(90907, 6353, 'Na Mira do Fogo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192576.mp4', 'http://timg.bdta.pro/images/2422d319e1d463cb2edb4e0f63908627.jpg'),
(90908, 6353, 'Na Mira do Fogo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192577.mp4', 'http://timg.bdta.pro/images/7a2fa6f8eb0287bd0c08625cf3b91988.jpg'),
(90909, 6353, 'Na Mira do Fogo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192578.mp4', 'http://timg.bdta.pro/images/47d003aa84caa743aa14adbb85c075c0.jpg'),
(90910, 6353, 'Na Mira do Fogo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192579.mp4', 'http://timg.bdta.pro/images/3737fc91ae8e57d62f955a20dab07f40.jpg'),
(90911, 6353, 'Na Mira do Fogo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192580.mp4', 'http://timg.bdta.pro/images/4a4620efd8c3783a93b99c2449573c81.jpg'),
(90912, 6354, 'Narco-Santos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192565.mp4', 'http://timg.bdta.pro/images/3b2eced74c13468609eeadff8f2db246.jpg'),
(90913, 6354, 'Narco-Santos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192566.mp4', 'http://timg.bdta.pro/images/35d6150ef07061c7eddda80cae7a5364.jpg'),
(90914, 6354, 'Narco-Santos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192567.mp4', 'http://timg.bdta.pro/images/9c6ad74e2fa73e4bffe4f389ba39db0f.jpg'),
(90915, 6354, 'Narco-Santos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192568.mp4', 'http://timg.bdta.pro/images/5d344b70037636a73f46c3f2e796706c.jpg'),
(90916, 6354, 'Narco-Santos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192569.mp4', 'http://timg.bdta.pro/images/e17bcfa776a92e4ab6eafc72ec00a921.jpg'),
(90917, 6354, 'Narco-Santos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192570.mp4', 'http://timg.bdta.pro/images/b0fb9691ff6a398ad0d30dd650506987.jpg'),
(90918, 5937, 'Ele Não S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192553.mp4', 'http://timg.bdta.pro/images/5fce5a9f251d1b99b584639331ee6a89.jpg'),
(90919, 5937, 'Ele Não S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192554.mp4', 'http://timg.bdta.pro/images/36f84f27b76b70e2305642edbb766035.jpg'),
(90920, 5937, 'Ele Não S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192555.mp4', 'http://timg.bdta.pro/images/2b54f0eca5b1394378206d6d975c30ea.jpg'),
(90921, 5937, 'Ele Não S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192556.mp4', 'http://timg.bdta.pro/images/21c8675a70f80ad274982c1393391c35.jpg'),
(90922, 5937, 'Ele Não S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192557.mp4', 'http://timg.bdta.pro/images/22973a8ec0cdd790c20927dfdf8344e4.jpg'),
(90923, 5937, 'Ele Não S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192558.mp4', 'http://timg.bdta.pro/images/5fc983feb5f5a6c0db75cf0017a58e8a.jpg'),
(90924, 5937, 'Ele Não S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192559.mp4', 'http://timg.bdta.pro/images/9869685b135ebe551eb0b6d22804f1a0.jpg'),
(90925, 5937, 'Ele Não S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192560.mp4', 'http://timg.bdta.pro/images/c0e845c7060efa96c4b194983e139474.jpg'),
(90926, 5937, 'Ele Não S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192561.mp4', 'http://timg.bdta.pro/images/364ebe9203d9076e3bc1980b7a578b7d.jpg'),
(90927, 5937, 'Ele Não S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192562.mp4', 'http://timg.bdta.pro/images/0c91c1e01028529340d68c446f43654f.jpg'),
(90928, 5937, 'Ele Não S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192563.mp4', 'http://timg.bdta.pro/images/3a2a8948bc3143379a382e1201281787.jpg'),
(90929, 5937, 'Ele Não S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192564.mp4', 'http://timg.bdta.pro/images/0b499de647de7bc483928dc90a6025d3.jpg'),
(90930, 6355, 'Plantão Sem Fim S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192533.mp4', 'http://timg.bdta.pro/images/5d303cab9fb2a74e46a116da06ccb934.jpg'),
(90931, 6355, 'Plantão Sem Fim S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192534.mp4', 'http://timg.bdta.pro/images/f90a154aaf4eccc891e843727a472447.jpg'),
(90932, 6355, 'Plantão Sem Fim S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192535.mp4', 'http://timg.bdta.pro/images/d442f7bfbcb71bed589ca347d8db0982.jpg'),
(90933, 6355, 'Plantão Sem Fim S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192536.mp4', 'http://timg.bdta.pro/images/4a9657d59103295f57c4a190b9113f28.jpg'),
(90934, 6355, 'Plantão Sem Fim S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192537.mp4', 'http://timg.bdta.pro/images/6d7d4ab17b2629de03b98a790ed12161.jpg'),
(90935, 6355, 'Plantão Sem Fim S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192538.mp4', 'http://timg.bdta.pro/images/466d56d5df769d6aa683457a32f9ef28.jpg'),
(90936, 6355, 'Plantão Sem Fim S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192539.mp4', 'http://timg.bdta.pro/images/f70ca5fa7f9453d783c634bd91c1abef.jpg'),
(90937, 6355, 'Plantão Sem Fim S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192540.mp4', 'http://timg.bdta.pro/images/15e25fcb988f8fa64e7cdd9009a8d521.jpg'),
(90938, 6355, 'Plantão Sem Fim S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192541.mp4', 'http://timg.bdta.pro/images/c7295328e0a54c99d8039c8b937cd6d8.jpg'),
(90939, 6355, 'Plantão Sem Fim S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192542.mp4', 'http://timg.bdta.pro/images/5a1691d458d1657fae53a071139ca3bb.jpg'),
(90940, 6355, 'Plantão Sem Fim S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192543.mp4', 'http://timg.bdta.pro/images/0a6f98ac06da47842ecefa3359f24c03.jpg'),
(90941, 6355, 'Plantão Sem Fim S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192544.mp4', 'http://timg.bdta.pro/images/cbc28bf8034349b2161a3aed83516f92.jpg'),
(90942, 6355, 'Plantão Sem Fim S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/192545.mp4', 'http://timg.bdta.pro/images/d4c2a731b9b3c63113037cdf3e44396f.jpg'),
(90943, 6355, 'Plantão Sem Fim S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/192546.mp4', 'http://timg.bdta.pro/images/a4456be639db52c22169c9ca1b2b0ceb.jpg'),
(90944, 6355, 'Plantão Sem Fim S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/192547.mp4', 'http://timg.bdta.pro/images/3026a0978626b63dd33495d602cbbfec.jpg'),
(90945, 6355, 'Plantão Sem Fim S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/192548.mp4', 'http://timg.bdta.pro/images/87d92412a44d6f1b3cb11ed1b22bacf0.jpg'),
(90946, 6355, 'Plantão Sem Fim S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/192549.mp4', 'http://gstaticontent.com/images/375e0ebef83927d9eb35982eec0b0eae.jpg'),
(90947, 6355, 'Plantão Sem Fim S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/192550.mp4', 'http://gstaticontent.com/images/375e0ebef83927d9eb35982eec0b0eae.jpg'),
(90948, 6355, 'Plantão Sem Fim S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/192551.mp4', 'http://gstaticontent.com/images/375e0ebef83927d9eb35982eec0b0eae.jpg'),
(90949, 6355, 'Plantão Sem Fim S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/192552.mp4', 'http://gstaticontent.com/images/375e0ebef83927d9eb35982eec0b0eae.jpg'),
(90950, 6356, 'Contratempos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192525.mp4', 'http://timg.bdta.pro/images/22f32e7402ff6e3ff121d0173bc713ea.jpg'),
(90951, 6356, 'Contratempos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192526.mp4', 'http://timg.bdta.pro/images/801a93099421f467f3e3c4554bcd7af5.jpg'),
(90952, 6356, 'Contratempos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192527.mp4', 'http://timg.bdta.pro/images/a4a6f40c04b7fa1b2e01714493ed2ece.jpg'),
(90953, 6356, 'Contratempos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192528.mp4', 'http://timg.bdta.pro/images/a5f2d5c2f71b601bac2897361720e639.jpg'),
(90954, 6356, 'Contratempos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192529.mp4', 'http://timg.bdta.pro/images/bac7bc729458cf100d20be5634b323d3.jpg'),
(90955, 6356, 'Contratempos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192530.mp4', 'http://timg.bdta.pro/images/8c3053c80a44093900d9c47cfa9bdc1d.jpg'),
(90956, 6356, 'Contratempos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192531.mp4', 'http://timg.bdta.pro/images/f2b4d06c45e8bcc53aafd93af20c6881.jpg'),
(90957, 6356, 'Contratempos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192532.mp4', 'http://timg.bdta.pro/images/56e4ced5c1e6dac89af1d8c3d58dcf8e.jpg'),
(90958, 6357, 'Reyka S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192517.mp4', 'http://timg.bdta.pro/images/ee3c6a96ad9c94e90f5da0fa7ddac80a.jpg'),
(90959, 6357, 'Reyka S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192518.mp4', 'http://timg.bdta.pro/images/9157a0fff786109f49dd677c50c3794d.jpg'),
(90960, 6357, 'Reyka S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192519.mp4', 'http://timg.bdta.pro/images/32f05e75e3c245ad96c6fa7298b58246.jpg'),
(90961, 6357, 'Reyka S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192520.mp4', 'http://timg.bdta.pro/images/4455e54888e93c18f7828f327646e793.jpg'),
(90962, 6357, 'Reyka S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192521.mp4', 'http://timg.bdta.pro/images/47a734ad73397e27ee8e46de41bd9a0a.jpg'),
(90963, 6357, 'Reyka S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192522.mp4', 'http://timg.bdta.pro/images/24dde0d7b7e532ea03bdf6f637849f0d.jpg'),
(90964, 6357, 'Reyka S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192523.mp4', 'http://timg.bdta.pro/images/927296bea5a21c33026d59eb84f73b2d.jpg'),
(90965, 6357, 'Reyka S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192524.mp4', 'http://timg.bdta.pro/images/3340d617ecef39607ca19fee1920da0e.jpg'),
(90966, 6358, 'Shinka no Mi: Shiranai Uchi ni Kachigumi Jinsei S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192505.mp4', 'http://timg.bdta.pro/images/111da77d26d5614100dab7c791373d68.jpg'),
(90967, 6358, 'Shinka no Mi: Shiranai Uchi ni Kachigumi Jinsei S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192506.mp4', 'http://timg.bdta.pro/images/a93cae361b2ed3a1ea6a84bf06ddbb94.jpg'),
(90968, 6358, 'Shinka no Mi: Shiranai Uchi ni Kachigumi Jinsei S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192507.mp4', 'http://timg.bdta.pro/images/a66f8c154333179967ee900dc6066654.jpg'),
(90969, 6358, 'Shinka no Mi: Shiranai Uchi ni Kachigumi Jinsei S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192508.mp4', 'http://timg.bdta.pro/images/5c51e2ddf47b2a9cde9d61436627eef9.jpg'),
(90970, 6358, 'Shinka no Mi: Shiranai Uchi ni Kachigumi Jinsei S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192509.mp4', 'http://timg.bdta.pro/images/40321abf10605848cc301fa8e2c69e03.jpg'),
(90971, 6358, 'Shinka no Mi: Shiranai Uchi ni Kachigumi Jinsei S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192510.mp4', 'http://timg.bdta.pro/images/b8e9d4f30438e7218a3c3a43f6bb9ff1.jpg'),
(90972, 6358, 'Shinka no Mi: Shiranai Uchi ni Kachigumi Jinsei S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192511.mp4', 'http://timg.bdta.pro/images/99830144c2e2990c0c545c9119069176.jpg'),
(90973, 6358, 'Shinka no Mi: Shiranai Uchi ni Kachigumi Jinsei S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192512.mp4', 'http://timg.bdta.pro/images/1cb5fdc9309ed2e365684d8dbf19fe7e.jpg'),
(90974, 6358, 'Shinka no Mi: Shiranai Uchi ni Kachigumi Jinsei S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192513.mp4', 'http://timg.bdta.pro/images/b6318ec68df1969a507fe35fe3024754.jpg'),
(90975, 6358, 'Shinka no Mi: Shiranai Uchi ni Kachigumi Jinsei S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192514.mp4', 'http://timg.bdta.pro/images/a7c356c64adee118c8ab5e1159d0bcd3.jpg'),
(90976, 6358, 'Shinka no Mi: Shiranai Uchi ni Kachigumi Jinsei S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192515.mp4', 'http://timg.bdta.pro/images/06112b00ee58b23481c5ab8164d974b7.jpg'),
(90977, 6358, 'Shinka no Mi: Shiranai Uchi ni Kachigumi Jinsei S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192516.mp4', 'http://timg.bdta.pro/images/851d47417c256821527ab432e0b6176a.jpg'),
(90978, 6359, 'Solte o Ar Bem Devagar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192493.mp4', 'http://timg.bdta.pro/images/f790087b98ee49c080dc4ac2aafa49fb.jpg'),
(90979, 6359, 'Solte o Ar Bem Devagar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192494.mp4', 'http://timg.bdta.pro/images/f81f1771f35418702e9592591c4013c5.jpg'),
(90980, 6359, 'Solte o Ar Bem Devagar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9aeA7cFSvdy4tx4yc2Wb18UZ9n.jpg'),
(90981, 6359, 'Solte o Ar Bem Devagar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192496.mp4', 'http://timg.bdta.pro/images/546185ff13fe84ae3efb3b49c1505664.jpg'),
(90982, 6359, 'Solte o Ar Bem Devagar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192497.mp4', 'http://timg.bdta.pro/images/3ec3edf163cf58353442275bcf80afc3.jpg'),
(90983, 6359, 'Solte o Ar Bem Devagar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192498.mp4', 'http://timg.bdta.pro/images/4659080c87969464588fa0457b1ee704.jpg'),
(90984, 6359, 'Solte o Ar Bem Devagar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192499.mp4', 'http://timg.bdta.pro/images/0acc779dec5c92d6d66bba80c925e589.jpg'),
(90985, 6359, 'Solte o Ar Bem Devagar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192500.mp4', 'http://timg.bdta.pro/images/c77f6fd96014b3ffca501fe084973a77.jpg'),
(90986, 6359, 'Solte o Ar Bem Devagar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192501.mp4', 'http://timg.bdta.pro/images/b0ee84f7ccc7f85d2c5bb294c13940c8.jpg'),
(90987, 6359, 'Solte o Ar Bem Devagar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192502.mp4', 'http://timg.bdta.pro/images/dcd9f41d3eae6484326a4b1f47ad2a59.jpg'),
(90988, 6359, 'Solte o Ar Bem Devagar S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192503.mp4', 'http://timg.bdta.pro/images/2332e15e24879d7e9af3c779fde5d948.jpg'),
(90989, 6359, 'Solte o Ar Bem Devagar S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192504.mp4', 'http://timg.bdta.pro/images/091030fcf3dbdf87604b3173dffa9ec4.jpg'),
(90990, 6360, 'Terra Incógnita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254199.mp4', 'http://timg.bdta.pro/images/fe82b20e7a2e3caec70fa1c778b070d7.jpg'),
(90991, 6360, 'Terra Incógnita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254200.mp4', 'http://timg.bdta.pro/images/a7b9763d895361077bdeb8483cf88c6a.jpg'),
(90992, 6360, 'Terra Incógnita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254201.mp4', 'http://timg.bdta.pro/images/5216c7e2c22d36f667eff2027b3a0aaf.jpg'),
(90993, 6360, 'Terra Incógnita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254202.mp4', 'http://timg.bdta.pro/images/e8a29ab5f49d602c8a9d5a40868a3c97.jpg'),
(90994, 6360, 'Terra Incógnita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254203.mp4', 'http://timg.bdta.pro/images/0a3f42a44c2140a743454cacedf25c7a.jpg'),
(90995, 6360, 'Terra Incógnita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254204.mp4', 'http://timg.bdta.pro/images/ba85c3f42cd3a7dd953a396b51ba60f7.jpg'),
(90996, 6360, 'Terra Incógnita S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254205.mp4', 'http://timg.bdta.pro/images/760458fc43348333e0c798824e2c90d6.jpg'),
(90997, 6360, 'Terra Incógnita S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254206.mp4', 'http://timg.bdta.pro/images/3a62d28c1d4c57fa3f3f43ecac76fa53.jpg'),
(90998, 6361, 'Terra Incógnita S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254207.mp4', 'http://gstaticontent.com/images/4a303248f186b25c78d1011d333cad11.jpg'),
(90999, 6361, 'Terra Incógnita S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254208.mp4', 'http://gstaticontent.com/images/4a303248f186b25c78d1011d333cad11.jpg'),
(91000, 6361, 'Terra Incógnita S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254209.mp4', 'http://gstaticontent.com/images/4a303248f186b25c78d1011d333cad11.jpg'),
(91001, 6361, 'Terra Incógnita S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254210.mp4', 'http://gstaticontent.com/images/4a303248f186b25c78d1011d333cad11.jpg'),
(91002, 6361, 'Terra Incógnita S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254211.mp4', 'http://gstaticontent.com/images/4a303248f186b25c78d1011d333cad11.jpg'),
(91003, 6361, 'Terra Incógnita S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254212.mp4', 'http://gstaticontent.com/images/4a303248f186b25c78d1011d333cad11.jpg'),
(91004, 6361, 'Terra Incógnita S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254213.mp4', 'http://gstaticontent.com/images/4a303248f186b25c78d1011d333cad11.jpg'),
(91005, 6361, 'Terra Incógnita S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254214.mp4', 'http://gstaticontent.com/images/4a303248f186b25c78d1011d333cad11.jpg'),
(91006, 6362, 'Alasca: Sabedoria Nativa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192485.mp4', 'http://gstaticontent.com/images/1853c909159f1c998903a12a52024a32.jpg'),
(91007, 6362, 'Alasca: Sabedoria Nativa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192486.mp4', 'http://gstaticontent.com/images/1853c909159f1c998903a12a52024a32.jpg'),
(91008, 6362, 'Alasca: Sabedoria Nativa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192487.mp4', 'http://gstaticontent.com/images/1853c909159f1c998903a12a52024a32.jpg'),
(91009, 6362, 'Alasca: Sabedoria Nativa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192488.mp4', 'http://gstaticontent.com/images/1853c909159f1c998903a12a52024a32.jpg'),
(91010, 6362, 'Alasca: Sabedoria Nativa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192489.mp4', 'http://gstaticontent.com/images/1853c909159f1c998903a12a52024a32.jpg'),
(91011, 6362, 'Alasca: Sabedoria Nativa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192490.mp4', 'http://gstaticontent.com/images/1853c909159f1c998903a12a52024a32.jpg'),
(91012, 6362, 'Alasca: Sabedoria Nativa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192491.mp4', 'http://gstaticontent.com/images/1853c909159f1c998903a12a52024a32.jpg'),
(91013, 6362, 'Alasca: Sabedoria Nativa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192492.mp4', 'http://gstaticontent.com/images/1853c909159f1c998903a12a52024a32.jpg'),
(91014, 6363, 'As Maravilhas dos Estados Unidos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192479.mp4', 'http://timg.bdta.pro/images/1642342c2db405b1385732d775ec638e.jpg'),
(91015, 6363, 'As Maravilhas dos Estados Unidos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192480.mp4', 'http://timg.bdta.pro/images/caf356d0eff2a44b8868da7bcb741bca.jpg'),
(91016, 6363, 'As Maravilhas dos Estados Unidos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192481.mp4', 'http://timg.bdta.pro/images/3a2cfacb95b72e21abd2677a91a25ba5.jpg'),
(91017, 6363, 'As Maravilhas dos Estados Unidos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192482.mp4', 'http://timg.bdta.pro/images/3f9dad96bb7d8ea6d51a75e40d7dd826.jpg'),
(91018, 6363, 'As Maravilhas dos Estados Unidos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192483.mp4', 'http://timg.bdta.pro/images/fec78ad40483404411a1aa933dfee448.jpg'),
(91019, 6363, 'As Maravilhas dos Estados Unidos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192484.mp4', 'http://timg.bdta.pro/images/032a8ff73439d3b8c003ba16e2b66864.jpg'),
(91020, 6364, 'Aventura em Matilha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192473.mp4', 'http://gstaticontent.com/images/3f704f0cc964e798375d4e339eede7ae.jpg'),
(91021, 6364, 'Aventura em Matilha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192474.mp4', 'http://gstaticontent.com/images/3f704f0cc964e798375d4e339eede7ae.jpg'),
(91022, 6364, 'Aventura em Matilha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192475.mp4', 'http://gstaticontent.com/images/3f704f0cc964e798375d4e339eede7ae.jpg'),
(91023, 6364, 'Aventura em Matilha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192476.mp4', 'http://gstaticontent.com/images/3f704f0cc964e798375d4e339eede7ae.jpg'),
(91024, 6364, 'Aventura em Matilha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192477.mp4', 'http://gstaticontent.com/images/3f704f0cc964e798375d4e339eede7ae.jpg'),
(91025, 6364, 'Aventura em Matilha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192478.mp4', 'http://gstaticontent.com/images/3f704f0cc964e798375d4e339eede7ae.jpg'),
(91026, 6365, 'BASTARD!! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227301.mp4', 'http://timg.bdta.pro/images/05a7d19b8278f44675d94b52c6e94575.jpg'),
(91027, 6365, 'BASTARD!! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227302.mp4', 'http://timg.bdta.pro/images/3e0722e63c17f77a3fb7650c7ed9b033.jpg'),
(91028, 6365, 'BASTARD!! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227303.mp4', 'http://timg.bdta.pro/images/a48b1d0c35b40fa1c2917d3cd611b68e.jpg'),
(91029, 6365, 'BASTARD!! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227304.mp4', 'http://timg.bdta.pro/images/0ad7b1edc241754511ee7a3885a9e565.jpg'),
(91030, 6365, 'BASTARD!! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227305.mp4', 'http://timg.bdta.pro/images/9502f554e11b69ac89e8b6784c60ed43.jpg'),
(91031, 6365, 'BASTARD!! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227306.mp4', 'http://timg.bdta.pro/images/663d1ee02fdb533bce49af94de7c6364.jpg'),
(91032, 6365, 'BASTARD!! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227307.mp4', 'http://timg.bdta.pro/images/e60146a51eb1b7097750a0c27c1714f8.jpg'),
(91033, 6365, 'BASTARD!! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227308.mp4', 'http://timg.bdta.pro/images/b40af7bf9fe8adf8d63406df005468dc.jpg'),
(91034, 6365, 'BASTARD!! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227309.mp4', 'http://timg.bdta.pro/images/2aa85113087b42cc7f4d0710f91da523.jpg'),
(91035, 6365, 'BASTARD!! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227310.mp4', 'http://timg.bdta.pro/images/75fbc3052665ef1bd0af202dcef4989e.jpg'),
(91036, 6365, 'BASTARD!! S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227311.mp4', 'http://timg.bdta.pro/images/538a3f77f8f33333b704ffc78a5b52f1.jpg'),
(91037, 6365, 'BASTARD!! S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/227312.mp4', 'http://timg.bdta.pro/images/be40cdde84f2c2ecf1438169ac93b35b.jpg'),
(91038, 6365, 'BASTARD!! S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/227313.mp4', 'http://timg.bdta.pro/images/0b80cc5fe5be30e41343e641481790f1.jpg'),
(91039, 6365, 'BASTARD!! S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/227314.mp4', 'http://timg.bdta.pro/images/bda2214670e8042c8352fb07d4d45b54.jpg'),
(91040, 6365, 'BASTARD!! S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/227315.mp4', 'http://timg.bdta.pro/images/150b5c4b109fccfe6352e7720da6f2f1.jpg'),
(91041, 6365, 'BASTARD!! S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/227316.mp4', 'http://timg.bdta.pro/images/4f0ac7b4a35ce51ee1f50aa5b2fe4180.jpg'),
(91042, 6365, 'BASTARD!! S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/227317.mp4', 'http://timg.bdta.pro/images/b31f9ae02fe0028921e317222704e573.jpg'),
(91043, 6365, 'BASTARD!! S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/227318.mp4', 'http://timg.bdta.pro/images/a3d944ff71bf4b34a35bc397def2265e.jpg'),
(91044, 6365, 'BASTARD!! S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/227319.mp4', 'http://timg.bdta.pro/images/9c9d99ee236155820108c7cc894c24a8.jpg'),
(91045, 6365, 'BASTARD!! S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/227320.mp4', 'http://timg.bdta.pro/images/9013c8e4421ca436589478c162ddb7e6.jpg'),
(91046, 6365, 'BASTARD!! S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/227321.mp4', 'http://timg.bdta.pro/images/eed77c5bbc5ffde013993159b601acea.jpg'),
(91047, 6365, 'BASTARD!! S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/227322.mp4', 'http://timg.bdta.pro/images/7c73ed0a38512e425080d26c54d529c4.jpg'),
(91048, 6365, 'BASTARD!! S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/227323.mp4', 'http://timg.bdta.pro/images/527c053be6ef45eb8ba9b661da250b74.jpg'),
(91049, 6365, 'BASTARD!! S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/227324.mp4', 'http://timg.bdta.pro/images/8eb1a54465e41f21737e00fd688ef1ed.jpg'),
(91050, 6366, 'BASTARD!! S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fWetJsKMvNAqfsTL30J9RpidRpU.jpg'),
(91051, 6366, 'BASTARD!! S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kIb6Rcc6JqCqB4cfUWnYyGywtwA.jpg'),
(91052, 6366, 'BASTARD!! S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zETSCazY8Sy9JJXUqFFqvugLrlU.jpg'),
(91053, 6366, 'BASTARD!! S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3LryD8ya4OHvcmGU2dDHTMRfVlT.jpg'),
(91054, 6366, 'BASTARD!! S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ua5oB010fgYWmFG8JJm6akvJr8a.jpg'),
(91055, 6366, 'BASTARD!! S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dhGxyfgTNmnxX9Yuf4DPChDSwqr.jpg'),
(91056, 6366, 'BASTARD!! S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fZpXSAhOE9tpa2IE7zsPznSJtoq.jpg'),
(91057, 6366, 'BASTARD!! S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTtBX7f76tXNMuY80SeW21HOOH4.jpg'),
(91058, 6366, 'BASTARD!! S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHxnXEQDDNJjT1Q9d8XwQd3rPTR.jpg'),
(91059, 6366, 'BASTARD!! S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wLlmZsNgpvWPw0dxT8qIdKRsvkO.jpg'),
(91060, 6366, 'BASTARD!! S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h2VY5IgBpst6YwXPB0rmXZYYlGE.jpg'),
(91061, 6366, 'BASTARD!! S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/227336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kyZ3fewX9Ok8ofGVyUzDOAy5lXY.jpg'),
(91062, 6366, 'BASTARD!! S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/227337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f7SJexFcisqOshvbT1va3xjlcCC.jpg'),
(91063, 6366, 'BASTARD!! S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/227338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dvHRSB69hiCAIa2jTqR94ghGbgm.jpg'),
(91064, 6366, 'BASTARD!! S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/227339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wvRrIcdlqmDJzUdflxg7QaZlnbO.jpg'),
(91065, 6367, 'Cyberpunk: Mercenários S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192463.mp4', 'http://timg.bdta.pro/images/309237e804f15bdebbf47a4ca1ac1d6d.jpg'),
(91066, 6367, 'Cyberpunk: Mercenários S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192464.mp4', 'http://timg.bdta.pro/images/ebceb6254cc25219f3a5f73ce57e2681.jpg'),
(91067, 6367, 'Cyberpunk: Mercenários S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192465.mp4', 'http://timg.bdta.pro/images/59affd2ef00460d954343a4b358a2e19.jpg'),
(91068, 6367, 'Cyberpunk: Mercenários S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192466.mp4', 'http://timg.bdta.pro/images/4b8c674bc1982b4c3ff6ffc00f9acc9d.jpg'),
(91069, 6367, 'Cyberpunk: Mercenários S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192467.mp4', 'http://timg.bdta.pro/images/5ffc6d93071bae7e7f37171a048b8175.jpg'),
(91070, 6367, 'Cyberpunk: Mercenários S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192468.mp4', 'http://timg.bdta.pro/images/8a8cce15729c9ff6cdd35096844d1409.jpg'),
(91071, 6367, 'Cyberpunk: Mercenários S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192469.mp4', 'http://timg.bdta.pro/images/1550a673e8abc1922ca5111f3f3631ba.jpg'),
(91072, 6367, 'Cyberpunk: Mercenários S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192470.mp4', 'http://timg.bdta.pro/images/b024a68cb5f9f66bfe8d6d3fbe4360b4.jpg'),
(91073, 6367, 'Cyberpunk: Mercenários S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192471.mp4', 'http://timg.bdta.pro/images/af9edf348743724aaf7f65915b4c0a03.jpg'),
(91074, 6367, 'Cyberpunk: Mercenários S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192472.mp4', 'http://timg.bdta.pro/images/ae26ee71ccdb0e5d9d31d3654c54b1ae.jpg'),
(91075, 6368, 'Desaparecimento na Noruega S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192458.mp4', 'http://timg.bdta.pro/images/05e59f6adbbf7821ed652c7e6a56bcb4.jpg'),
(91076, 6368, 'Desaparecimento na Noruega S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192459.mp4', 'http://timg.bdta.pro/images/720ad60bf975cc59feb54d8b75094b01.jpg'),
(91077, 6368, 'Desaparecimento na Noruega S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192460.mp4', 'http://timg.bdta.pro/images/08596a7d40eaeb351f0a2a46dd9175d8.jpg'),
(91078, 6368, 'Desaparecimento na Noruega S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192461.mp4', 'http://timg.bdta.pro/images/5c2919a95cf6722f450cc9d0fd48d318.jpg'),
(91079, 6368, 'Desaparecimento na Noruega S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192462.mp4', 'http://timg.bdta.pro/images/8fa413cf2c6aa41babca7382af64b87c.jpg'),
(91080, 6369, 'Desventuras de Amor em Paris S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192452.mp4', 'http://gstaticontent.com/images/3e776247d125cc4e7fa883a190848b4f.jpg'),
(91081, 6369, 'Desventuras de Amor em Paris S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192453.mp4', 'http://gstaticontent.com/images/3e776247d125cc4e7fa883a190848b4f.jpg'),
(91082, 6369, 'Desventuras de Amor em Paris S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192454.mp4', 'http://gstaticontent.com/images/3e776247d125cc4e7fa883a190848b4f.jpg'),
(91083, 6369, 'Desventuras de Amor em Paris S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192455.mp4', 'http://gstaticontent.com/images/3e776247d125cc4e7fa883a190848b4f.jpg'),
(91084, 6369, 'Desventuras de Amor em Paris S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192456.mp4', 'http://gstaticontent.com/images/3e776247d125cc4e7fa883a190848b4f.jpg'),
(91085, 6369, 'Desventuras de Amor em Paris S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192457.mp4', 'http://gstaticontent.com/images/3e776247d125cc4e7fa883a190848b4f.jpg'),
(91086, 6370, 'Dr. Delirium e os Experimentos em Edgewood S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192451.mp4', 'http://gstaticontent.com/images/ced795ae793fa249c4f09e42be1197f3.jpg'),
(91087, 6371, 'Eric Hollenbeck: O Mestre da Restauração S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192446.mp4', 'http://timg.bdta.pro/images/49d182046c39460d2bb4df9bba5c7422.jpg'),
(91088, 6371, 'Eric Hollenbeck: O Mestre da Restauração S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192447.mp4', 'http://timg.bdta.pro/images/3cf9727c785a4e57d1ad7dbd48b6e28b.jpg'),
(91089, 6371, 'Eric Hollenbeck: O Mestre da Restauração S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192448.mp4', 'http://timg.bdta.pro/images/d1e873a6c50fe1edb69ff08b6fd9760e.jpg'),
(91090, 6371, 'Eric Hollenbeck: O Mestre da Restauração S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192449.mp4', 'http://timg.bdta.pro/images/bb2970def1d7b79b36840106a1488f26.jpg'),
(91091, 6371, 'Eric Hollenbeck: O Mestre da Restauração S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192450.mp4', 'http://timg.bdta.pro/images/76a94487eed456601904a3645d1c4d24.jpg'),
(91092, 6372, 'Fatih Terim: Lenda do Futebol S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192429.mp4', 'http://timg.bdta.pro/images/79b4c161622216fba298f7199cb8e089.jpg'),
(91093, 6372, 'Fatih Terim: Lenda do Futebol S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192430.mp4', 'http://timg.bdta.pro/images/a28e1c202f5114e21f2f173aa84006a8.jpg'),
(91094, 6372, 'Fatih Terim: Lenda do Futebol S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192431.mp4', 'http://timg.bdta.pro/images/5626b8c1d8a8641f044cdc82eb8cfa96.jpg'),
(91095, 6372, 'Fatih Terim: Lenda do Futebol S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192432.mp4', 'http://timg.bdta.pro/images/ea42aac3dc2723f6d688ef1a095340c2.jpg'),
(91096, 6373, 'Heartbreak High: Onde Tudo Acontece S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192421.mp4', 'http://timg.bdta.pro/images/56e2e52ba5bf65bcf439191001d09e19.jpg'),
(91097, 6373, 'Heartbreak High: Onde Tudo Acontece S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192422.mp4', 'http://timg.bdta.pro/images/2baf982b97468ccc896475e921b6f287.jpg'),
(91098, 6373, 'Heartbreak High: Onde Tudo Acontece S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192423.mp4', 'http://timg.bdta.pro/images/518417ec38a9496d98b2d617ba4d199a.jpg'),
(91099, 6373, 'Heartbreak High: Onde Tudo Acontece S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192424.mp4', 'http://timg.bdta.pro/images/717fbf7776f85e5a564782254a024644.jpg'),
(91100, 6373, 'Heartbreak High: Onde Tudo Acontece S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192425.mp4', 'http://timg.bdta.pro/images/480629dccaf31bf2969b0de1861f63bf.jpg'),
(91101, 6373, 'Heartbreak High: Onde Tudo Acontece S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192426.mp4', 'http://timg.bdta.pro/images/d57b58fae562e3eeb2c1cbd273e6bb42.jpg'),
(91102, 6373, 'Heartbreak High: Onde Tudo Acontece S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192427.mp4', 'http://timg.bdta.pro/images/ab83ce12dc82ee9b7ecd2d5aa8f0e4b8.jpg'),
(91103, 6373, 'Heartbreak High: Onde Tudo Acontece S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192428.mp4', 'http://timg.bdta.pro/images/40dd47c16140b5e0faaf0c814e7d8c80.jpg'),
(91104, 6374, 'Heartbreak High: Onde Tudo Acontece S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331418.mp4', 'http://gstaticontent.com/images/2c0864c444ac295b229ea12506d88935.jpg'),
(91105, 6374, 'Heartbreak High: Onde Tudo Acontece S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331419.mp4', 'http://gstaticontent.com/images/2c0864c444ac295b229ea12506d88935.jpg'),
(91106, 6374, 'Heartbreak High: Onde Tudo Acontece S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331420.mp4', 'http://gstaticontent.com/images/2c0864c444ac295b229ea12506d88935.jpg'),
(91107, 6374, 'Heartbreak High: Onde Tudo Acontece S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331421.mp4', 'http://gstaticontent.com/images/2c0864c444ac295b229ea12506d88935.jpg'),
(91108, 6374, 'Heartbreak High: Onde Tudo Acontece S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331422.mp4', 'http://gstaticontent.com/images/2c0864c444ac295b229ea12506d88935.jpg'),
(91109, 6374, 'Heartbreak High: Onde Tudo Acontece S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331423.mp4', 'http://gstaticontent.com/images/2c0864c444ac295b229ea12506d88935.jpg'),
(91110, 6374, 'Heartbreak High: Onde Tudo Acontece S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331424.mp4', 'http://gstaticontent.com/images/2c0864c444ac295b229ea12506d88935.jpg'),
(91111, 6374, 'Heartbreak High: Onde Tudo Acontece S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331425.mp4', 'http://gstaticontent.com/images/2c0864c444ac295b229ea12506d88935.jpg'),
(91112, 6375, 'Mike: Além de Tyson S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192413.mp4', 'http://timg.bdta.pro/images/cd4daa20c1c4232f56a51ad13e900d37.jpg'),
(91113, 6375, 'Mike: Além de Tyson S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192414.mp4', 'http://timg.bdta.pro/images/4ccf3325ae9b4875e22a28e7dbff96e0.jpg'),
(91114, 6375, 'Mike: Além de Tyson S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192415.mp4', 'http://timg.bdta.pro/images/e8cfc214ff487b11c3e6af21c6977bd3.jpg'),
(91115, 6375, 'Mike: Além de Tyson S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192416.mp4', 'http://timg.bdta.pro/images/9a52558b2a16cb0ace0cae298f345a48.jpg'),
(91116, 6375, 'Mike: Além de Tyson S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192417.mp4', 'http://timg.bdta.pro/images/733ec62f9fe39eacdfcae4e1da2c08d0.jpg'),
(91117, 6375, 'Mike: Além de Tyson S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192418.mp4', 'http://timg.bdta.pro/images/78363c69e7c3fecd66f1d88b070a0260.jpg'),
(91118, 6375, 'Mike: Além de Tyson S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192419.mp4', 'http://timg.bdta.pro/images/aa781b3192a6328e5a0e26abfa3b8fb0.jpg'),
(91119, 6375, 'Mike: Além de Tyson S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192420.mp4', 'http://timg.bdta.pro/images/f9a37717bdd39177ac562063d3d143ce.jpg'),
(91120, 6376, 'Os Crimes da Nossa Mãe S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192410.mp4', 'http://timg.bdta.pro/images/7521427c202b400df972d231f0193cba.jpg'),
(91121, 6376, 'Os Crimes da Nossa Mãe S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192411.mp4', 'http://timg.bdta.pro/images/475a94b110ef7b50f9addd327c9717b2.jpg'),
(91122, 6376, 'Os Crimes da Nossa Mãe S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192412.mp4', 'http://timg.bdta.pro/images/86cd23141f51988941c78034b623b8de.jpg'),
(91123, 6377, 'Rock in Rio - 2022 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192369.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91124, 6377, 'Rock in Rio - 2022 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192370.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91125, 6377, 'Rock in Rio - 2022 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192371.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91126, 6377, 'Rock in Rio - 2022 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192372.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91127, 6377, 'Rock in Rio - 2022 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192373.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91128, 6377, 'Rock in Rio - 2022 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192374.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91129, 6377, 'Rock in Rio - 2022 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192375.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91130, 6377, 'Rock in Rio - 2022 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192376.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91131, 6377, 'Rock in Rio - 2022 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192377.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91132, 6377, 'Rock in Rio - 2022 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192378.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91133, 6377, 'Rock in Rio - 2022 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192379.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91134, 6377, 'Rock in Rio - 2022 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192380.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91135, 6377, 'Rock in Rio - 2022 S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/192381.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91136, 6377, 'Rock in Rio - 2022 S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/192382.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91137, 6377, 'Rock in Rio - 2022 S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/192383.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91138, 6377, 'Rock in Rio - 2022 S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/192384.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91139, 6377, 'Rock in Rio - 2022 S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/192385.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91140, 6377, 'Rock in Rio - 2022 S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/192386.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91141, 6377, 'Rock in Rio - 2022 S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/192387.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91142, 6377, 'Rock in Rio - 2022 S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/192388.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91143, 6377, 'Rock in Rio - 2022 S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/192389.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91144, 6377, 'Rock in Rio - 2022 S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/192390.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91145, 6377, 'Rock in Rio - 2022 S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/192391.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91146, 6377, 'Rock in Rio - 2022 S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/192392.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91147, 6377, 'Rock in Rio - 2022 S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/192393.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91148, 6377, 'Rock in Rio - 2022 S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/192394.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91149, 6377, 'Rock in Rio - 2022 S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/192395.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91150, 6377, 'Rock in Rio - 2022 S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/192396.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91151, 6377, 'Rock in Rio - 2022 S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/192397.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91152, 6377, 'Rock in Rio - 2022 S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/192398.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91153, 6377, 'Rock in Rio - 2022 S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/192399.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91154, 6377, 'Rock in Rio - 2022 S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/192400.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91155, 6377, 'Rock in Rio - 2022 S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/192401.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91156, 6377, 'Rock in Rio - 2022 S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/192402.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91157, 6377, 'Rock in Rio - 2022 S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/192403.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91158, 6377, 'Rock in Rio - 2022 S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/192404.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91159, 6377, 'Rock in Rio - 2022 S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/192405.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91160, 6377, 'Rock in Rio - 2022 S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/192406.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91161, 6377, 'Rock in Rio - 2022 S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/192407.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91162, 6377, 'Rock in Rio - 2022 S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/192408.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91163, 6377, 'Rock in Rio - 2022 S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/192409.mp4', 'http://gstaticontent.com/images/53c65f8e16707fd45aec5537eee38719.jpg'),
(91164, 6378, 'Santo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192363.mp4', 'http://timg.bdta.pro/images/ac68eb261db76b9208123f95a0927792.jpg'),
(91165, 6378, 'Santo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192364.mp4', 'http://timg.bdta.pro/images/172b04a83558a9cc078a8c018d07d252.jpg'),
(91166, 6378, 'Santo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192365.mp4', 'http://timg.bdta.pro/images/97448047ceb3a41200ddfb21585a4136.jpg'),
(91167, 6378, 'Santo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192366.mp4', 'http://timg.bdta.pro/images/4e035cf0acc316b47c1d5b7a63aa55d2.jpg'),
(91168, 6378, 'Santo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192367.mp4', 'http://timg.bdta.pro/images/a721c82097c4d4e12e1027f78d1b7805.jpg'),
(91169, 6378, 'Santo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192368.mp4', 'http://timg.bdta.pro/images/674c52e2c113cdd5804729365645a7f5.jpg'),
(91170, 6379, 'Segunda Chance: Academia de Ginástica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192353.mp4', 'http://gstaticontent.com/images/e07094fb5281e6e88530b8ea0d1768f3.jpg'),
(91171, 6379, 'Segunda Chance: Academia de Ginástica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192354.mp4', 'http://gstaticontent.com/images/e07094fb5281e6e88530b8ea0d1768f3.jpg'),
(91172, 6379, 'Segunda Chance: Academia de Ginástica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192355.mp4', 'http://gstaticontent.com/images/e07094fb5281e6e88530b8ea0d1768f3.jpg'),
(91173, 6379, 'Segunda Chance: Academia de Ginástica S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192356.mp4', 'http://gstaticontent.com/images/e07094fb5281e6e88530b8ea0d1768f3.jpg'),
(91174, 6379, 'Segunda Chance: Academia de Ginástica S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192357.mp4', 'http://gstaticontent.com/images/e07094fb5281e6e88530b8ea0d1768f3.jpg'),
(91175, 6379, 'Segunda Chance: Academia de Ginástica S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192358.mp4', 'http://gstaticontent.com/images/e07094fb5281e6e88530b8ea0d1768f3.jpg'),
(91176, 6379, 'Segunda Chance: Academia de Ginástica S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192359.mp4', 'http://gstaticontent.com/images/e07094fb5281e6e88530b8ea0d1768f3.jpg'),
(91177, 6379, 'Segunda Chance: Academia de Ginástica S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192360.mp4', 'http://gstaticontent.com/images/e07094fb5281e6e88530b8ea0d1768f3.jpg'),
(91178, 6379, 'Segunda Chance: Academia de Ginástica S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192361.mp4', 'http://gstaticontent.com/images/e07094fb5281e6e88530b8ea0d1768f3.jpg'),
(91179, 6379, 'Segunda Chance: Academia de Ginástica S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192362.mp4', 'http://gstaticontent.com/images/e07094fb5281e6e88530b8ea0d1768f3.jpg'),
(91180, 6380, 'Supervalentes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192347.mp4', 'http://timg.bdta.pro/images/45a97888931c66d08889764ebda83ef3.jpg'),
(91181, 6380, 'Supervalentes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192348.mp4', 'http://timg.bdta.pro/images/fc97ad8ff12316ff8acb9cc762e4d936.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(91182, 6380, 'Supervalentes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192349.mp4', 'http://timg.bdta.pro/images/8a85ac21c77435352370790e15744483.jpg'),
(91183, 6380, 'Supervalentes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192350.mp4', 'http://timg.bdta.pro/images/4c6cbf3c4bac4b10c79a6da688df9676.jpg'),
(91184, 6380, 'Supervalentes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192351.mp4', 'http://timg.bdta.pro/images/881e1170f414b94aa7fc63aa5b176d91.jpg'),
(91185, 6380, 'Supervalentes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192352.mp4', 'http://timg.bdta.pro/images/105821b8cf852793ecf02e5799b7e892.jpg'),
(91186, 6381, 'Um Assunto Privado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192339.mp4', 'http://timg.bdta.pro/images/c21a9abf07c67036ae7e0df946a7c0e8.jpg'),
(91187, 6381, 'Um Assunto Privado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192340.mp4', 'http://timg.bdta.pro/images/6c5563e7fcea6cf26b1cd93a7bfb97f3.jpg'),
(91188, 6381, 'Um Assunto Privado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192341.mp4', 'http://timg.bdta.pro/images/44e11b6b65ffb33cc40aed80d466e35f.jpg'),
(91189, 6381, 'Um Assunto Privado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192342.mp4', 'http://timg.bdta.pro/images/8c55c39957585c4fec51977b3f1e1311.jpg'),
(91190, 6381, 'Um Assunto Privado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192343.mp4', 'http://timg.bdta.pro/images/5fa4ae99e103fa8937cade400a6cbdbc.jpg'),
(91191, 6381, 'Um Assunto Privado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192344.mp4', 'http://timg.bdta.pro/images/e9acb67db125cfb3d6f7a6955319886d.jpg'),
(91192, 6381, 'Um Assunto Privado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192345.mp4', 'http://timg.bdta.pro/images/0943978286172d518945f7c7933a65b6.jpg'),
(91193, 6381, 'Um Assunto Privado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192346.mp4', 'http://timg.bdta.pro/images/18545edb978d6eabb049c8dc03386900.jpg'),
(91194, 6382, 'A Maldição de Oak Island S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192218.mp4', 'http://timg.bdta.pro/images/4265f5460f785962b441c878313d7ca4.jpg'),
(91195, 6382, 'A Maldição de Oak Island S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192219.mp4', 'http://timg.bdta.pro/images/11419b3e9652e7d6be8497a8a4b42b09.jpg'),
(91196, 6382, 'A Maldição de Oak Island S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192220.mp4', 'http://timg.bdta.pro/images/c13bf8945fabeae76ab62fe5a553a3ce.jpg'),
(91197, 6382, 'A Maldição de Oak Island S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192221.mp4', 'http://timg.bdta.pro/images/5e913884df22dcb62d7fbe8c8a67894c.jpg'),
(91198, 6382, 'A Maldição de Oak Island S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192222.mp4', 'http://timg.bdta.pro/images/ada95583c3fca7d9fb3384598302385a.jpg'),
(91199, 6383, 'A Maldição de Oak Island S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192223.mp4', 'http://timg.bdta.pro/images/bb82f6f122e834c786295b77103a1bd5.jpg'),
(91200, 6383, 'A Maldição de Oak Island S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192224.mp4', 'http://timg.bdta.pro/images/26df0f4a8f5ec7830b66955a6100b8c9.jpg'),
(91201, 6383, 'A Maldição de Oak Island S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192225.mp4', 'http://timg.bdta.pro/images/84531280f8df6bbd9a7327bc31e36f50.jpg'),
(91202, 6383, 'A Maldição de Oak Island S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192226.mp4', 'http://timg.bdta.pro/images/de157acd9ed2e9f1219cc428b9c97a64.jpg'),
(91203, 6383, 'A Maldição de Oak Island S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192227.mp4', 'http://timg.bdta.pro/images/709171f984b7daf2268c942f6550a85b.jpg'),
(91204, 6383, 'A Maldição de Oak Island S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192228.mp4', 'http://timg.bdta.pro/images/a5fff2a29845cd8c12b1eb0f56527ae7.jpg'),
(91205, 6383, 'A Maldição de Oak Island S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192229.mp4', 'http://timg.bdta.pro/images/00fc53727895e0c0957477a771f1dd2e.jpg'),
(91206, 6383, 'A Maldição de Oak Island S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192230.mp4', 'http://timg.bdta.pro/images/224034803e3398ec70a1314790c37770.jpg'),
(91207, 6383, 'A Maldição de Oak Island S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192231.mp4', 'http://timg.bdta.pro/images/cad3f437c519406dbba286799f60245f.jpg'),
(91208, 6383, 'A Maldição de Oak Island S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192232.mp4', 'http://timg.bdta.pro/images/0d863f075827a28907fe6ed93dd5f184.jpg'),
(91209, 6384, 'A Maldição de Oak Island S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192233.mp4', 'http://timg.bdta.pro/images/6bc20d6c8881f12a911e8caad2722c1f.jpg'),
(91210, 6384, 'A Maldição de Oak Island S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192234.mp4', 'http://timg.bdta.pro/images/dc6250ada8f6a1e651a93bf963638cbd.jpg'),
(91211, 6384, 'A Maldição de Oak Island S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192235.mp4', 'http://timg.bdta.pro/images/c472497a934b969b5414dfa1561569c1.jpg'),
(91212, 6384, 'A Maldição de Oak Island S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lAi75mbI8IesCdAOXOa9pdW813V.jpg'),
(91213, 6384, 'A Maldição de Oak Island S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192237.mp4', 'http://timg.bdta.pro/images/a4cb5f2503c44ab3efe1df2fb4d58f7d.jpg'),
(91214, 6384, 'A Maldição de Oak Island S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192238.mp4', 'http://timg.bdta.pro/images/f33616db654360addc35aadb87709cbd.jpg'),
(91215, 6384, 'A Maldição de Oak Island S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192239.mp4', 'http://timg.bdta.pro/images/532e87459f4764282393d4ffdaed16ae.jpg'),
(91216, 6384, 'A Maldição de Oak Island S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192240.mp4', 'http://timg.bdta.pro/images/ed8fe1c63997252a4aa6223bb11598aa.jpg'),
(91217, 6384, 'A Maldição de Oak Island S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192241.mp4', 'http://timg.bdta.pro/images/dfd4952ebc78ec5f42bb9de050d2b4a4.jpg'),
(91218, 6384, 'A Maldição de Oak Island S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192242.mp4', 'http://timg.bdta.pro/images/d85756f42fd4b88c6d61cfba42eca784.jpg'),
(91219, 6384, 'A Maldição de Oak Island S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192243.mp4', 'http://timg.bdta.pro/images/773d062f78c3f628b8e3326365a1d164.jpg'),
(91220, 6384, 'A Maldição de Oak Island S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192244.mp4', 'http://timg.bdta.pro/images/f5fd7b2524db4cd4a10316b0cac37a38.jpg'),
(91221, 6384, 'A Maldição de Oak Island S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/192245.mp4', 'http://timg.bdta.pro/images/5f425d88ccc3a7588a5d0ff2138c65ce.jpg'),
(91222, 6385, 'Batman: A Série Animada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192133.mp4', 'http://timg.bdta.pro/images/3793f437a4e30136e1f21b023d53bd89.jpg'),
(91223, 6385, 'Batman: A Série Animada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192134.mp4', 'http://timg.bdta.pro/images/a2537e2ae16203ba2ed0542886c070fc.jpg'),
(91224, 6385, 'Batman: A Série Animada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192135.mp4', 'http://timg.bdta.pro/images/1cda0d50dc48939f871738cc04a28179.jpg'),
(91225, 6385, 'Batman: A Série Animada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192136.mp4', 'http://timg.bdta.pro/images/b77ad7ce0410aeeee82b1bdab66949c2.jpg'),
(91226, 6385, 'Batman: A Série Animada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192137.mp4', 'http://timg.bdta.pro/images/24589d99e23a35f097172d0a25cf669e.jpg'),
(91227, 6385, 'Batman: A Série Animada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192138.mp4', 'http://timg.bdta.pro/images/4fd79306ce24c2df9deeb047d501a1a5.jpg'),
(91228, 6385, 'Batman: A Série Animada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192139.mp4', 'http://timg.bdta.pro/images/5f5c554149696d5dab613df2f9ddaa8e.jpg'),
(91229, 6385, 'Batman: A Série Animada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192140.mp4', 'http://timg.bdta.pro/images/e6f1384ce5c0e060ac80471c1f4ce067.jpg'),
(91230, 6385, 'Batman: A Série Animada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192141.mp4', 'http://timg.bdta.pro/images/08afcc2710cb893dcbe7a088a4c6cf7c.jpg'),
(91231, 6385, 'Batman: A Série Animada S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192142.mp4', 'http://timg.bdta.pro/images/36b9f563bcd5cc1fee1a8b58a81edc32.jpg'),
(91232, 6385, 'Batman: A Série Animada S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192143.mp4', 'http://timg.bdta.pro/images/527b60ac9d859d40a9ab761376979693.jpg'),
(91233, 6385, 'Batman: A Série Animada S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192144.mp4', 'http://timg.bdta.pro/images/95a2208d373a595b21d32b846e1cb0b5.jpg'),
(91234, 6385, 'Batman: A Série Animada S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/192145.mp4', 'http://timg.bdta.pro/images/5bac8dd6eb8348792f3436a2edaed48c.jpg'),
(91235, 6385, 'Batman: A Série Animada S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/192146.mp4', 'http://timg.bdta.pro/images/d2a256e096957bcab0328c61b12b6cc3.jpg'),
(91236, 6385, 'Batman: A Série Animada S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/192147.mp4', 'http://timg.bdta.pro/images/07cb74d114afd7588f930ba780aa8bdf.jpg'),
(91237, 6385, 'Batman: A Série Animada S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/192148.mp4', 'http://timg.bdta.pro/images/eeec9a42a0c6e6777a1df0bc2f412a43.jpg'),
(91238, 6385, 'Batman: A Série Animada S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/192149.mp4', 'http://timg.bdta.pro/images/c2a0fc944f9b28792079d35c435c9969.jpg'),
(91239, 6385, 'Batman: A Série Animada S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/192150.mp4', 'http://timg.bdta.pro/images/d642fd1ba925bea92e208145a8d76beb.jpg'),
(91240, 6385, 'Batman: A Série Animada S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/192151.mp4', 'http://timg.bdta.pro/images/9e91178e6d44e6f87127bac6cda0771d.jpg'),
(91241, 6385, 'Batman: A Série Animada S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/192152.mp4', 'http://timg.bdta.pro/images/1e07c5b8ce0b679bd84b2ad34aaa928c.jpg'),
(91242, 6385, 'Batman: A Série Animada S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/192153.mp4', 'http://timg.bdta.pro/images/9959aa153ee3b14066a533dc227b9a99.jpg'),
(91243, 6385, 'Batman: A Série Animada S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/192154.mp4', 'http://timg.bdta.pro/images/f41b8a1172c0f4d01eb2428183ffce08.jpg'),
(91244, 6385, 'Batman: A Série Animada S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/192155.mp4', 'http://timg.bdta.pro/images/330fdeff65603b90dee671c7a41a7e2c.jpg'),
(91245, 6385, 'Batman: A Série Animada S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/192156.mp4', 'http://timg.bdta.pro/images/eee540b472a0667792417a8b04efb7bd.jpg'),
(91246, 6385, 'Batman: A Série Animada S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/192157.mp4', 'http://timg.bdta.pro/images/89cdb1318e573c8c885d1d27bdb41c7a.jpg'),
(91247, 6385, 'Batman: A Série Animada S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/192158.mp4', 'http://timg.bdta.pro/images/6f4e7d7db8885cdb986a526a47516383.jpg'),
(91248, 6385, 'Batman: A Série Animada S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/192159.mp4', 'http://timg.bdta.pro/images/1200922f1924137c110eb362e4dcb143.jpg'),
(91249, 6385, 'Batman: A Série Animada S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/192160.mp4', 'http://timg.bdta.pro/images/71a4e7d42222e05242aac8794f0496b7.jpg'),
(91250, 6386, 'Batman: A Série Animada S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192161.mp4', 'http://timg.bdta.pro/images/63cdffdc83cf131e13e2ee514bbb768e.jpg'),
(91251, 6386, 'Batman: A Série Animada S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192162.mp4', 'http://timg.bdta.pro/images/9585ecc8f5a0dedbcbbe5444b7709aef.jpg'),
(91252, 6386, 'Batman: A Série Animada S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192163.mp4', 'http://timg.bdta.pro/images/a562c806ccabe60eef1cbece4bfa1ae7.jpg'),
(91253, 6386, 'Batman: A Série Animada S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192164.mp4', 'http://timg.bdta.pro/images/7491e20f6be0711de79464f2dd8d11a2.jpg'),
(91254, 6386, 'Batman: A Série Animada S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192165.mp4', 'http://timg.bdta.pro/images/b4c39f3f2998c9d0735a5248931ec75d.jpg'),
(91255, 6386, 'Batman: A Série Animada S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192166.mp4', 'http://timg.bdta.pro/images/c3a5eae668a7053314f1c68bb1b155e1.jpg'),
(91256, 6386, 'Batman: A Série Animada S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192167.mp4', 'http://timg.bdta.pro/images/3aea534ee6eabde230c11f95710511a2.jpg'),
(91257, 6386, 'Batman: A Série Animada S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192168.mp4', 'http://timg.bdta.pro/images/b7c1ac53427d7882dcf5b98ab17f48c8.jpg'),
(91258, 6386, 'Batman: A Série Animada S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192169.mp4', 'http://timg.bdta.pro/images/2f14692ada32e93ee4d569b49aabbccb.jpg'),
(91259, 6386, 'Batman: A Série Animada S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192170.mp4', 'http://timg.bdta.pro/images/59a0d625500ab51f4d3e1d158bff8de0.jpg'),
(91260, 6386, 'Batman: A Série Animada S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192171.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91261, 6386, 'Batman: A Série Animada S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192172.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91262, 6386, 'Batman: A Série Animada S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/192173.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91263, 6386, 'Batman: A Série Animada S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/192174.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91264, 6386, 'Batman: A Série Animada S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/192175.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91265, 6386, 'Batman: A Série Animada S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/192176.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91266, 6386, 'Batman: A Série Animada S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/192177.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91267, 6386, 'Batman: A Série Animada S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/192178.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91268, 6386, 'Batman: A Série Animada S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/192179.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91269, 6386, 'Batman: A Série Animada S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/192180.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91270, 6386, 'Batman: A Série Animada S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/192181.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91271, 6386, 'Batman: A Série Animada S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/192182.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91272, 6386, 'Batman: A Série Animada S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/192183.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91273, 6386, 'Batman: A Série Animada S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/192184.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91274, 6386, 'Batman: A Série Animada S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/192185.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91275, 6386, 'Batman: A Série Animada S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/192186.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91276, 6386, 'Batman: A Série Animada S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/192187.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91277, 6386, 'Batman: A Série Animada S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/192188.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91278, 6387, 'Batman: A Série Animada S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192189.mp4', 'http://timg.bdta.pro/images/c86c85d7fef2b6ca637792d20e07c843.jpg'),
(91279, 6387, 'Batman: A Série Animada S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192190.mp4', 'http://timg.bdta.pro/images/998c3587ebf474dd5d04e9a3f5b96de9.jpg'),
(91280, 6387, 'Batman: A Série Animada S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192191.mp4', 'http://timg.bdta.pro/images/daeaccb2942b53de758b102975e00a3b.jpg'),
(91281, 6387, 'Batman: A Série Animada S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192192.mp4', 'http://timg.bdta.pro/images/e5380934779c920272f44ec54232a23e.jpg'),
(91282, 6387, 'Batman: A Série Animada S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192193.mp4', 'http://timg.bdta.pro/images/b7c40a747d2da7f13fcc4609f1d73ade.jpg'),
(91283, 6387, 'Batman: A Série Animada S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192194.mp4', 'http://timg.bdta.pro/images/b720e98708e71af516d5f6023684f11f.jpg'),
(91284, 6387, 'Batman: A Série Animada S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192195.mp4', 'http://timg.bdta.pro/images/c11fa23c9b925338251b5ceadf87ff6e.jpg'),
(91285, 6387, 'Batman: A Série Animada S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192196.mp4', 'http://timg.bdta.pro/images/7008586cf583e5b4d36be1325c61f9fd.jpg'),
(91286, 6387, 'Batman: A Série Animada S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192197.mp4', 'http://timg.bdta.pro/images/a2cf3b1d2047715f60b078f1812817c8.jpg'),
(91287, 6387, 'Batman: A Série Animada S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192198.mp4', 'http://timg.bdta.pro/images/33ed1ba450d728fb7e749d0882bcced4.jpg'),
(91288, 6387, 'Batman: A Série Animada S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192199.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91289, 6387, 'Batman: A Série Animada S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192200.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91290, 6387, 'Batman: A Série Animada S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/192201.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91291, 6387, 'Batman: A Série Animada S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/192202.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91292, 6387, 'Batman: A Série Animada S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/192203.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91293, 6387, 'Batman: A Série Animada S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/192204.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91294, 6387, 'Batman: A Série Animada S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/192205.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91295, 6387, 'Batman: A Série Animada S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/192206.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91296, 6387, 'Batman: A Série Animada S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/192207.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91297, 6387, 'Batman: A Série Animada S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/192208.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91298, 6387, 'Batman: A Série Animada S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/192209.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91299, 6387, 'Batman: A Série Animada S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/192210.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91300, 6387, 'Batman: A Série Animada S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/192211.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91301, 6387, 'Batman: A Série Animada S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/192212.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91302, 6387, 'Batman: A Série Animada S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/192213.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91303, 6387, 'Batman: A Série Animada S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/192214.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91304, 6387, 'Batman: A Série Animada S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/192215.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91305, 6387, 'Batman: A Série Animada S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/192216.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91306, 6387, 'Batman: A Série Animada S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/192217.mp4', 'http://gstaticontent.com/images/309b85a587222baf49fb070d5f9ce861.jpg'),
(91307, 6388, 'A Artista da Enganação S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192129.mp4', 'http://timg.bdta.pro/images/2c873d17caae308c8b33736293738432.jpg'),
(91308, 6388, 'A Artista da Enganação S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192130.mp4', 'http://timg.bdta.pro/images/e31b0150f943ce67f68389523a58d5ac.jpg'),
(91309, 6388, 'A Artista da Enganação S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192131.mp4', 'http://timg.bdta.pro/images/f73c4e0c79ef5865c206213fdd6d2f4e.jpg'),
(91310, 6388, 'A Artista da Enganação S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192132.mp4', 'http://timg.bdta.pro/images/433154eb45e86ed4e6fb36fea4f6d0df.jpg'),
(91311, 6389, 'As Garotas do Fundão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192123.mp4', 'http://timg.bdta.pro/images/1acac697656f5cfe00385e694b4474bd.jpg'),
(91312, 6389, 'As Garotas do Fundão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192124.mp4', 'http://timg.bdta.pro/images/dd6fb696bd9f6dce1900a3498c43aa12.jpg'),
(91313, 6389, 'As Garotas do Fundão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192125.mp4', 'http://timg.bdta.pro/images/b5e617e12b9d9f6827f0244a4332ad37.jpg'),
(91314, 6389, 'As Garotas do Fundão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192126.mp4', 'http://timg.bdta.pro/images/db76bbf6f05cd016e75b25cd0c73316f.jpg'),
(91315, 6389, 'As Garotas do Fundão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192127.mp4', 'http://timg.bdta.pro/images/bce3fc1df1534fb56e4c6d92683e7b12.jpg'),
(91316, 6389, 'As Garotas do Fundão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192128.mp4', 'http://timg.bdta.pro/images/a4d8c49fe44dd307ce0f0db13ddcb243.jpg'),
(91317, 6390, 'Awkward. S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192058.mp4', 'http://timg.bdta.pro/images/635b92bdb20fbc02f2592c1e1fbb9fb1.jpg'),
(91318, 6390, 'Awkward. S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192059.mp4', 'http://timg.bdta.pro/images/b88ec44c564462bb44f19c9a2ffe8afd.jpg'),
(91319, 6390, 'Awkward. S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192060.mp4', 'http://timg.bdta.pro/images/fd79ecb4ff511c016943105cae4afec9.jpg'),
(91320, 6390, 'Awkward. S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192061.mp4', 'http://timg.bdta.pro/images/d024c326e6e9fe0bbcf56b9f3489f91e.jpg'),
(91321, 6390, 'Awkward. S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192062.mp4', 'http://timg.bdta.pro/images/56ad714315239e58837b651b7be3737d.jpg'),
(91322, 6390, 'Awkward. S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192063.mp4', 'http://timg.bdta.pro/images/aacb61e39ca9bbd88905c80d11d3d7d9.jpg'),
(91323, 6390, 'Awkward. S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192064.mp4', 'http://timg.bdta.pro/images/61bf553e62f01b04a481f59443a7023e.jpg'),
(91324, 6390, 'Awkward. S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192065.mp4', 'http://timg.bdta.pro/images/57c48a0c28409452f287b9c73ef2f113.jpg'),
(91325, 6390, 'Awkward. S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192066.mp4', 'http://timg.bdta.pro/images/9ee21f8494c46756345634c9a8f65a62.jpg'),
(91326, 6390, 'Awkward. S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192067.mp4', 'http://timg.bdta.pro/images/96482c294ffe38bf1751856c8bd9b199.jpg'),
(91327, 6390, 'Awkward. S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192068.mp4', 'http://timg.bdta.pro/images/59d897033fc96a50f1132ba939fbfe2f.jpg'),
(91328, 6390, 'Awkward. S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192069.mp4', 'http://timg.bdta.pro/images/3c4e5e3365693791e4ea63af8185b29d.jpg'),
(91329, 6391, 'Awkward. S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192070.mp4', 'http://timg.bdta.pro/images/6a93a53010b263f7f73874f41157c427.jpg'),
(91330, 6391, 'Awkward. S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192071.mp4', 'http://timg.bdta.pro/images/bbb63a922afb5ead23215fc5acda1d2b.jpg'),
(91331, 6391, 'Awkward. S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192072.mp4', 'http://timg.bdta.pro/images/a3f0807ea9bf22dbd18336cbeaca3ef1.jpg'),
(91332, 6391, 'Awkward. S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192073.mp4', 'http://timg.bdta.pro/images/7c8de0ad4322bde6efdbac1f2cae58b9.jpg'),
(91333, 6391, 'Awkward. S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192074.mp4', 'http://timg.bdta.pro/images/9820b29d712cde172633c07b6a4d08c7.jpg'),
(91334, 6391, 'Awkward. S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192075.mp4', 'http://timg.bdta.pro/images/8820212efa6e2ed61a6cd5f6ee15d4c4.jpg'),
(91335, 6391, 'Awkward. S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192076.mp4', 'http://timg.bdta.pro/images/27b37180ac18a1232f19094491e723f5.jpg'),
(91336, 6391, 'Awkward. S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192077.mp4', 'http://timg.bdta.pro/images/dd185f87172553eb2192b5c0dc4a9486.jpg'),
(91337, 6391, 'Awkward. S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192078.mp4', 'http://timg.bdta.pro/images/07b795734a00471d854363e18b34ec98.jpg'),
(91338, 6391, 'Awkward. S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192079.mp4', 'http://timg.bdta.pro/images/cfb4c228fcf6aeec5d5b2ca47dfc012c.jpg'),
(91339, 6391, 'Awkward. S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192080.mp4', 'http://timg.bdta.pro/images/b3d9c639a25b59fa2429ba2ba0ba6fca.jpg'),
(91340, 6391, 'Awkward. S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192081.mp4', 'http://timg.bdta.pro/images/944fae85141f60be1aee93294add75a7.jpg'),
(91341, 6392, 'Awkward. S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192082.mp4', 'http://timg.bdta.pro/images/2ac74055a346ec026e4cfdc77e33a5e6.jpg'),
(91342, 6392, 'Awkward. S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192083.mp4', 'http://timg.bdta.pro/images/30639a074acad19b4ae54785caaa0f92.jpg'),
(91343, 6392, 'Awkward. S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192084.mp4', 'http://timg.bdta.pro/images/ddd801d0d21a9194f8e734c6003ac861.jpg'),
(91344, 6392, 'Awkward. S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192085.mp4', 'http://timg.bdta.pro/images/e8189fd164d7c8921ac464bf7798478b.jpg'),
(91345, 6392, 'Awkward. S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192086.mp4', 'http://timg.bdta.pro/images/d5238f1ccdb7e0a46a3a241095c030e7.jpg'),
(91346, 6392, 'Awkward. S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192087.mp4', 'http://timg.bdta.pro/images/82837cf14d17f7cebfacf18765b27f02.jpg'),
(91347, 6392, 'Awkward. S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192088.mp4', 'http://timg.bdta.pro/images/c1c2869ce2ac4a63d0544c1924b9bb4d.jpg'),
(91348, 6392, 'Awkward. S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192089.mp4', 'http://timg.bdta.pro/images/fcb75bc46cdd69dd0cb58b54718e5d72.jpg'),
(91349, 6392, 'Awkward. S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192090.mp4', 'http://timg.bdta.pro/images/ad75b7a12d0fd7a8229ed58be37acbd2.jpg'),
(91350, 6392, 'Awkward. S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192091.mp4', 'http://timg.bdta.pro/images/1e9625c5f5a06ce71f838d4772a6f1a5.jpg'),
(91351, 6392, 'Awkward. S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192092.mp4', 'http://timg.bdta.pro/images/4e4b692b02e39d6e7492c44d484c0f61.jpg'),
(91352, 6392, 'Awkward. S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192093.mp4', 'http://timg.bdta.pro/images/43d21b403e34b98f09390cf19caa7afa.jpg'),
(91353, 6392, 'Awkward. S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/192094.mp4', 'http://timg.bdta.pro/images/ea258a1e689cf20356f9016aa4e9f2ff.jpg'),
(91354, 6392, 'Awkward. S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/192095.mp4', 'http://timg.bdta.pro/images/c862445998854df7311a117592172adc.jpg'),
(91355, 6392, 'Awkward. S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/192096.mp4', 'http://timg.bdta.pro/images/289f712a0d3784b8bd635932f083312f.jpg'),
(91356, 6392, 'Awkward. S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/192097.mp4', 'http://timg.bdta.pro/images/8f0584d1de404d76be6e1fa284d9a73c.jpg'),
(91357, 6392, 'Awkward. S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/192098.mp4', 'http://timg.bdta.pro/images/b7032a92d3990f714f1a8ca22a1a19a5.jpg'),
(91358, 6392, 'Awkward. S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/192099.mp4', 'http://timg.bdta.pro/images/6c74201ac02e1c0c223a88ff95cb8231.jpg'),
(91359, 6392, 'Awkward. S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/192100.mp4', 'http://timg.bdta.pro/images/8067659f93836d914972001a6911303c.jpg'),
(91360, 6392, 'Awkward. S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/192101.mp4', 'http://timg.bdta.pro/images/03832c2eb8728838b6065441396bce04.jpg'),
(91361, 6393, 'Awkward. S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192102.mp4', 'http://timg.bdta.pro/images/03b30fc81956b3751605472c9fcf4679.jpg'),
(91362, 6393, 'Awkward. S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192103.mp4', 'http://timg.bdta.pro/images/a9e5a496f8db6de3b5c1754bb04cd334.jpg'),
(91363, 6393, 'Awkward. S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192104.mp4', 'http://timg.bdta.pro/images/2dbd9e277c1bcbd7386469082e4c4877.jpg'),
(91364, 6393, 'Awkward. S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192105.mp4', 'http://timg.bdta.pro/images/083fe1f994271dc78e2f1a6e7d873486.jpg'),
(91365, 6393, 'Awkward. S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192106.mp4', 'http://timg.bdta.pro/images/9923568f2103e5bcdad4e31b2159edba.jpg'),
(91366, 6393, 'Awkward. S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192107.mp4', 'http://timg.bdta.pro/images/a3f8fc2ac748cf5e09b8237699aa706b.jpg'),
(91367, 6393, 'Awkward. S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192108.mp4', 'http://timg.bdta.pro/images/20ea45ebe46b58d2a74056dfb8415657.jpg'),
(91368, 6393, 'Awkward. S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192109.mp4', 'http://timg.bdta.pro/images/85b5eabec78f9301ad342e430126431b.jpg'),
(91369, 6393, 'Awkward. S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192110.mp4', 'http://timg.bdta.pro/images/e3b1138c49aa8454f43186adb39dce2d.jpg'),
(91370, 6393, 'Awkward. S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192111.mp4', 'http://timg.bdta.pro/images/f29168fd75ae5f51837488c65805a08c.jpg'),
(91371, 6393, 'Awkward. S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/192112.mp4', 'http://timg.bdta.pro/images/43c280356029933bed78472cecdca0b2.jpg'),
(91372, 6393, 'Awkward. S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/192113.mp4', 'http://timg.bdta.pro/images/b815f3d73fc8beaff3c23e5ccf87f9e7.jpg'),
(91373, 6393, 'Awkward. S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/192114.mp4', 'http://timg.bdta.pro/images/35ba095d1f4e0481df18ce04c4955b75.jpg'),
(91374, 6393, 'Awkward. S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/192115.mp4', 'http://timg.bdta.pro/images/199e6e62ba36e1215b7ccf4cc58766c9.jpg'),
(91375, 6393, 'Awkward. S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/192116.mp4', 'http://timg.bdta.pro/images/979f8e4b9a18ff78538c4450d8d4b2f2.jpg'),
(91376, 6393, 'Awkward. S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/192117.mp4', 'http://timg.bdta.pro/images/fa3f2d6f527ec4e869b2dcf2c8cb9fce.jpg'),
(91377, 6393, 'Awkward. S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/192118.mp4', 'http://timg.bdta.pro/images/08b0e0eb932b0f7e1e7e51297893a94e.jpg'),
(91378, 6393, 'Awkward. S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/192119.mp4', 'http://timg.bdta.pro/images/d86f9eae3225e95391fb00aae37917d3.jpg'),
(91379, 6393, 'Awkward. S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/192120.mp4', 'http://timg.bdta.pro/images/1a177b12de90e9ee5cf66c5ea09df022.jpg'),
(91380, 6393, 'Awkward. S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/192121.mp4', 'http://timg.bdta.pro/images/161f6723401da30f69d8e2e713fea3f7.jpg'),
(91381, 6393, 'Awkward. S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/192122.mp4', 'http://timg.bdta.pro/images/986317f5bad2c1439bdf8179866ef1f9.jpg'),
(91382, 6394, 'Bling Ring: A História por Trás dos Roubos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192055.mp4', 'http://timg.bdta.pro/images/5b5a3c0640f3c1d180c63dfa3708bd56.jpg'),
(91383, 6394, 'Bling Ring: A História por Trás dos Roubos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192056.mp4', 'http://timg.bdta.pro/images/43740a6e659cb452d090449e38b4c9e3.jpg'),
(91384, 6394, 'Bling Ring: A História por Trás dos Roubos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192057.mp4', 'http://timg.bdta.pro/images/5f91e27634d8e694b57026a4b8cf0be2.jpg'),
(91385, 6395, 'Dahmer: Um Canibal Americano S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/192045.mp4', 'http://timg.bdta.pro/images/9c6796bb87514eb790493954ca1693ad.jpg'),
(91386, 6395, 'Dahmer: Um Canibal Americano S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/192046.mp4', 'http://timg.bdta.pro/images/a269943c3fbead6c3ca9d31adbc4153c.jpg'),
(91387, 6395, 'Dahmer: Um Canibal Americano S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/192047.mp4', 'http://timg.bdta.pro/images/2c926cd5da2a9e6257730a6082fb81a2.jpg'),
(91388, 6395, 'Dahmer: Um Canibal Americano S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/192048.mp4', 'http://timg.bdta.pro/images/7bf4e2840a9abe552a1c11e7d77b7f97.jpg'),
(91389, 6395, 'Dahmer: Um Canibal Americano S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/192049.mp4', 'http://timg.bdta.pro/images/6bed0649c0d0a51999b32e0a4044253f.jpg'),
(91390, 6395, 'Dahmer: Um Canibal Americano S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/192050.mp4', 'http://timg.bdta.pro/images/df4195ca3f1b1a65fbfcbc9759c5b30d.jpg'),
(91391, 6395, 'Dahmer: Um Canibal Americano S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/192051.mp4', 'http://timg.bdta.pro/images/4e25dba1a1b1a1f7416dcaa9ea868ff1.jpg'),
(91392, 6395, 'Dahmer: Um Canibal Americano S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/192052.mp4', 'http://timg.bdta.pro/images/d98a8089537604b582edde5fac2e9c3c.jpg'),
(91393, 6395, 'Dahmer: Um Canibal Americano S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/192053.mp4', 'http://timg.bdta.pro/images/3f91fa993912616275213513290861fb.jpg'),
(91394, 6395, 'Dahmer: Um Canibal Americano S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/192054.mp4', 'http://timg.bdta.pro/images/f41b55b3a68de15685696b24e7821133.jpg'),
(91395, 6396, 'De Férias com o Ex: América Latina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266617.mp4', 'http://timg.bdta.pro/images/1b788c25dcdb66cba6c89b462ddb1299.jpg'),
(91396, 6396, 'De Férias com o Ex: América Latina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266618.mp4', 'http://timg.bdta.pro/images/222f46a9ba9843b9012adad2053b89b0.jpg'),
(91397, 6396, 'De Férias com o Ex: América Latina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266619.mp4', 'http://timg.bdta.pro/images/6638b68c106b44d94bcfde383b60586a.jpg'),
(91398, 6396, 'De Férias com o Ex: América Latina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266620.mp4', 'http://timg.bdta.pro/images/e4c4f2398fdb577a5ab4f77a784986b5.jpg'),
(91399, 6396, 'De Férias com o Ex: América Latina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266621.mp4', 'http://timg.bdta.pro/images/f12eb1640c269cf9d7053dd164f36352.jpg'),
(91400, 6396, 'De Férias com o Ex: América Latina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266622.mp4', 'http://timg.bdta.pro/images/5105fe87bd51ef522ee28ddc4630f1f2.jpg'),
(91401, 6396, 'De Férias com o Ex: América Latina S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266623.mp4', 'http://timg.bdta.pro/images/57347bbf1c5f23fcbf298824ef03ab55.jpg'),
(91402, 6396, 'De Férias com o Ex: América Latina S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266624.mp4', 'http://timg.bdta.pro/images/4cf75f465c7813e080717e2ef87f6868.jpg'),
(91403, 6396, 'De Férias com o Ex: América Latina S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266625.mp4', 'http://timg.bdta.pro/images/a758c0e2f43ab95598d981a0abbb288f.jpg'),
(91404, 6396, 'De Férias com o Ex: América Latina S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266626.mp4', 'http://timg.bdta.pro/images/f7e6c19d7b6cdd96d15099654749b8c7.jpg'),
(91405, 6396, 'De Férias com o Ex: América Latina S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266627.mp4', 'http://timg.bdta.pro/images/a76b84f1a3c6b26000e68bf72645b75b.jpg'),
(91406, 6396, 'De Férias com o Ex: América Latina S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266628.mp4', 'http://timg.bdta.pro/images/6bf3ae878277b8bfc79ee0578df1e016.jpg'),
(91407, 6397, 'De Férias com o Ex: América Latina S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6sGXisgm3rp408yz2NOdNpoQxVC.jpg'),
(91408, 6397, 'De Férias com o Ex: América Latina S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/snZ9CwUyRZAAzjh6iS1nJla7eHg.jpg'),
(91409, 6397, 'De Férias com o Ex: América Latina S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266631.mp4', 'http://image.tmdb.org/t/p/w1280/s0971p5oRLzFpjhMj3c0EcMJUc.jpg'),
(91410, 6397, 'De Férias com o Ex: América Latina S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266632.mp4', 'http://gstaticontent.com/images/e25ffc5bd6e34aa46f188ebac03f7ca0.jpg'),
(91411, 6397, 'De Férias com o Ex: América Latina S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266633.mp4', 'http://gstaticontent.com/images/e25ffc5bd6e34aa46f188ebac03f7ca0.jpg'),
(91412, 6397, 'De Férias com o Ex: América Latina S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266634.mp4', 'http://gstaticontent.com/images/e25ffc5bd6e34aa46f188ebac03f7ca0.jpg'),
(91413, 6397, 'De Férias com o Ex: América Latina S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266635.mp4', 'http://gstaticontent.com/images/e25ffc5bd6e34aa46f188ebac03f7ca0.jpg'),
(91414, 6397, 'De Férias com o Ex: América Latina S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266636.mp4', 'http://gstaticontent.com/images/e25ffc5bd6e34aa46f188ebac03f7ca0.jpg'),
(91415, 6397, 'De Férias com o Ex: América Latina S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266637.mp4', 'http://gstaticontent.com/images/e25ffc5bd6e34aa46f188ebac03f7ca0.jpg'),
(91416, 6397, 'De Férias com o Ex: América Latina S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266638.mp4', 'http://gstaticontent.com/images/e25ffc5bd6e34aa46f188ebac03f7ca0.jpg'),
(91417, 6397, 'De Férias com o Ex: América Latina S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266639.mp4', 'http://gstaticontent.com/images/e25ffc5bd6e34aa46f188ebac03f7ca0.jpg'),
(91418, 6397, 'De Férias com o Ex: América Latina S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266640.mp4', 'http://gstaticontent.com/images/e25ffc5bd6e34aa46f188ebac03f7ca0.jpg'),
(91419, 6398, 'De Férias com o Ex: América Latina S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266641.mp4', 'http://gstaticontent.com/images/e25ffc5bd6e34aa46f188ebac03f7ca0.jpg'),
(91420, 6398, 'De Férias com o Ex: América Latina S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266642.mp4', 'http://gstaticontent.com/images/e25ffc5bd6e34aa46f188ebac03f7ca0.jpg'),
(91421, 6398, 'De Férias com o Ex: América Latina S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266643.mp4', 'http://gstaticontent.com/images/e25ffc5bd6e34aa46f188ebac03f7ca0.jpg'),
(91422, 6398, 'De Férias com o Ex: América Latina S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266644.mp4', 'http://gstaticontent.com/images/e25ffc5bd6e34aa46f188ebac03f7ca0.jpg'),
(91423, 6398, 'De Férias com o Ex: América Latina S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266645.mp4', 'http://gstaticontent.com/images/e25ffc5bd6e34aa46f188ebac03f7ca0.jpg'),
(91424, 6398, 'De Férias com o Ex: América Latina S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266646.mp4', 'http://gstaticontent.com/images/e25ffc5bd6e34aa46f188ebac03f7ca0.jpg'),
(91425, 6398, 'De Férias com o Ex: América Latina S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266647.mp4', 'http://gstaticontent.com/images/e25ffc5bd6e34aa46f188ebac03f7ca0.jpg'),
(91426, 6398, 'De Férias com o Ex: América Latina S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266648.mp4', 'http://gstaticontent.com/images/e25ffc5bd6e34aa46f188ebac03f7ca0.jpg'),
(91427, 6398, 'De Férias com o Ex: América Latina S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266649.mp4', 'http://gstaticontent.com/images/e25ffc5bd6e34aa46f188ebac03f7ca0.jpg'),
(91428, 6398, 'De Férias com o Ex: América Latina S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/271616.mp4', 'http://gstaticontent.com/images/e25ffc5bd6e34aa46f188ebac03f7ca0.jpg'),
(91429, 6398, 'De Férias com o Ex: América Latina S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/273075.mp4', 'http://gstaticontent.com/images/e25ffc5bd6e34aa46f188ebac03f7ca0.jpg'),
(91430, 6398, 'De Férias com o Ex: América Latina S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/274789.mp4', 'http://gstaticontent.com/images/e25ffc5bd6e34aa46f188ebac03f7ca0.jpg'),
(91431, 6399, 'Exposta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198259.mp4', 'http://timg.bdta.pro/images/5417a874dff5603809a4a118d1adf046.jpg'),
(91432, 6399, 'Exposta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198260.mp4', 'http://timg.bdta.pro/images/9b8945d46f5c49958fb864908aeb83b9.jpg'),
(91433, 6399, 'Exposta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198261.mp4', 'http://timg.bdta.pro/images/e8ff31e859b21459b2be690f3b52b38a.jpg'),
(91434, 6399, 'Exposta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198262.mp4', 'http://timg.bdta.pro/images/48f62ac451c0d997c15e099f5bceec12.jpg'),
(91435, 6399, 'Exposta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198263.mp4', 'http://timg.bdta.pro/images/c5bef87b2ab71a68fa4d7459ead8ddf5.jpg'),
(91436, 6399, 'Exposta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198264.mp4', 'http://timg.bdta.pro/images/7868b0b5af4c052676d66dd5c139fca3.jpg'),
(91437, 6399, 'Exposta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198265.mp4', 'http://timg.bdta.pro/images/5f0c0bb28a5f014ff18bf8beb37ae278.jpg'),
(91438, 6400, 'Germinal: A Revolução S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198233.mp4', 'http://timg.bdta.pro/images/3729b82c1bb3022abfe7df6a0fe7bf11.jpg'),
(91439, 6400, 'Germinal: A Revolução S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198234.mp4', 'http://timg.bdta.pro/images/42accd1163fdcc2507216c419e09d993.jpg'),
(91440, 6400, 'Germinal: A Revolução S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198235.mp4', 'http://timg.bdta.pro/images/1cdc8b7d49b0bc9b4967f742998bf701.jpg'),
(91441, 6400, 'Germinal: A Revolução S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198236.mp4', 'http://timg.bdta.pro/images/17bd1cdeb85e37d96eabb2e42e9bbca8.jpg'),
(91442, 6400, 'Germinal: A Revolução S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198237.mp4', 'http://timg.bdta.pro/images/53d64d4b135275316d428a8f11de6311.jpg'),
(91443, 6400, 'Germinal: A Revolução S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198238.mp4', 'http://timg.bdta.pro/images/13a3f0873e995c28572e7526957ccf2c.jpg'),
(91444, 6401, 'HouseBroken S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247791.mp4', 'http://timg.bdta.pro/images/3b2912a9d55b177c8ea49f6544a95461.jpg'),
(91445, 6401, 'HouseBroken S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247792.mp4', 'http://timg.bdta.pro/images/d7ea71bfbef65b60d85b0d9e1115165d.jpg'),
(91446, 6401, 'HouseBroken S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247793.mp4', 'http://timg.bdta.pro/images/e221e7a86e2d5a8f112de3bc7cfd301f.jpg'),
(91447, 6401, 'HouseBroken S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247794.mp4', 'http://timg.bdta.pro/images/b7c474eaba44640c029e6dc68f7af5c6.jpg'),
(91448, 6401, 'HouseBroken S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247795.mp4', 'http://timg.bdta.pro/images/ec8b3697eb6ef43039384cd4c23681c2.jpg'),
(91449, 6401, 'HouseBroken S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247796.mp4', 'http://timg.bdta.pro/images/05f61711eb6177bba6c1cabc3beeaa6f.jpg'),
(91450, 6401, 'HouseBroken S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247797.mp4', 'http://timg.bdta.pro/images/7336ab4d8c884b4ca4fa06d021f7af96.jpg'),
(91451, 6401, 'HouseBroken S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247798.mp4', 'http://timg.bdta.pro/images/144085429f5c8fd23caa2946542514b2.jpg'),
(91452, 6401, 'HouseBroken S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247799.mp4', 'http://timg.bdta.pro/images/3be9bb94943e9ad12b7dd0a9d292efaf.jpg'),
(91453, 6401, 'HouseBroken S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247800.mp4', 'http://timg.bdta.pro/images/e8a1a2bbd5d467955bafc9a0790105c4.jpg'),
(91454, 6401, 'HouseBroken S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247801.mp4', 'http://timg.bdta.pro/images/0d7f682beba3d214a807d2ef3da8faaf.jpg'),
(91455, 6402, 'HouseBroken S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247802.mp4', 'http://gstaticontent.com/images/974e849af938d35e724331888fa8602c.jpg'),
(91456, 6402, 'HouseBroken S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247803.mp4', 'http://gstaticontent.com/images/974e849af938d35e724331888fa8602c.jpg'),
(91457, 6402, 'HouseBroken S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247804.mp4', 'http://gstaticontent.com/images/974e849af938d35e724331888fa8602c.jpg'),
(91458, 6402, 'HouseBroken S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247805.mp4', 'http://gstaticontent.com/images/974e849af938d35e724331888fa8602c.jpg'),
(91459, 6402, 'HouseBroken S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247806.mp4', 'http://gstaticontent.com/images/974e849af938d35e724331888fa8602c.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(91460, 6402, 'HouseBroken S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247807.mp4', 'http://gstaticontent.com/images/974e849af938d35e724331888fa8602c.jpg'),
(91461, 6402, 'HouseBroken S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247808.mp4', 'http://gstaticontent.com/images/974e849af938d35e724331888fa8602c.jpg'),
(91462, 6402, 'HouseBroken S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247809.mp4', 'http://gstaticontent.com/images/974e849af938d35e724331888fa8602c.jpg'),
(91463, 6402, 'HouseBroken S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247810.mp4', 'http://gstaticontent.com/images/974e849af938d35e724331888fa8602c.jpg'),
(91464, 6402, 'HouseBroken S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247811.mp4', 'http://gstaticontent.com/images/974e849af938d35e724331888fa8602c.jpg'),
(91465, 6402, 'HouseBroken S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247812.mp4', 'http://gstaticontent.com/images/974e849af938d35e724331888fa8602c.jpg'),
(91466, 6402, 'HouseBroken S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247813.mp4', 'http://gstaticontent.com/images/974e849af938d35e724331888fa8602c.jpg'),
(91467, 6402, 'HouseBroken S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247814.mp4', 'http://gstaticontent.com/images/974e849af938d35e724331888fa8602c.jpg'),
(91468, 6402, 'HouseBroken S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/247815.mp4', 'http://gstaticontent.com/images/974e849af938d35e724331888fa8602c.jpg'),
(91469, 6402, 'HouseBroken S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/247816.mp4', 'http://gstaticontent.com/images/974e849af938d35e724331888fa8602c.jpg'),
(91470, 6402, 'HouseBroken S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/247817.mp4', 'http://gstaticontent.com/images/974e849af938d35e724331888fa8602c.jpg'),
(91471, 6402, 'HouseBroken S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/247818.mp4', 'http://gstaticontent.com/images/974e849af938d35e724331888fa8602c.jpg'),
(91472, 6402, 'HouseBroken S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/247819.mp4', 'http://gstaticontent.com/images/974e849af938d35e724331888fa8602c.jpg'),
(91473, 6402, 'HouseBroken S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/247820.mp4', 'http://gstaticontent.com/images/974e849af938d35e724331888fa8602c.jpg'),
(91474, 6403, 'Iron Chef: México S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198225.mp4', 'http://gstaticontent.com/images/50e9e3e2d46408d7ebe17752fdcacd5e.jpg'),
(91475, 6403, 'Iron Chef: México S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198226.mp4', 'http://gstaticontent.com/images/50e9e3e2d46408d7ebe17752fdcacd5e.jpg'),
(91476, 6403, 'Iron Chef: México S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198227.mp4', 'http://gstaticontent.com/images/50e9e3e2d46408d7ebe17752fdcacd5e.jpg'),
(91477, 6403, 'Iron Chef: México S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198228.mp4', 'http://gstaticontent.com/images/50e9e3e2d46408d7ebe17752fdcacd5e.jpg'),
(91478, 6403, 'Iron Chef: México S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198229.mp4', 'http://gstaticontent.com/images/50e9e3e2d46408d7ebe17752fdcacd5e.jpg'),
(91479, 6403, 'Iron Chef: México S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198230.mp4', 'http://gstaticontent.com/images/50e9e3e2d46408d7ebe17752fdcacd5e.jpg'),
(91480, 6403, 'Iron Chef: México S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198231.mp4', 'http://gstaticontent.com/images/50e9e3e2d46408d7ebe17752fdcacd5e.jpg'),
(91481, 6403, 'Iron Chef: México S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198232.mp4', 'http://gstaticontent.com/images/50e9e3e2d46408d7ebe17752fdcacd5e.jpg'),
(91482, 6404, 'Jeffrey Dahmer: Assassino Canibal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198221.mp4', 'http://gstaticontent.com/images/caf3f3ab408ffb32382a782afad5d031.jpg'),
(91483, 6404, 'Jeffrey Dahmer: Assassino Canibal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198222.mp4', 'http://gstaticontent.com/images/caf3f3ab408ffb32382a782afad5d031.jpg'),
(91484, 6404, 'Jeffrey Dahmer: Assassino Canibal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198223.mp4', 'http://gstaticontent.com/images/caf3f3ab408ffb32382a782afad5d031.jpg'),
(91485, 6404, 'Jeffrey Dahmer: Assassino Canibal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198224.mp4', 'http://gstaticontent.com/images/caf3f3ab408ffb32382a782afad5d031.jpg'),
(91486, 6405, 'Normal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198213.mp4', 'http://gstaticontent.com/images/7988dd480a7ad30f041f5316713266dc.jpg'),
(91487, 6405, 'Normal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198214.mp4', 'http://gstaticontent.com/images/7988dd480a7ad30f041f5316713266dc.jpg'),
(91488, 6405, 'Normal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198215.mp4', 'http://gstaticontent.com/images/7988dd480a7ad30f041f5316713266dc.jpg'),
(91489, 6405, 'Normal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198216.mp4', 'http://gstaticontent.com/images/7988dd480a7ad30f041f5316713266dc.jpg'),
(91490, 6405, 'Normal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198217.mp4', 'http://gstaticontent.com/images/7988dd480a7ad30f041f5316713266dc.jpg'),
(91491, 6405, 'Normal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198218.mp4', 'http://gstaticontent.com/images/7988dd480a7ad30f041f5316713266dc.jpg'),
(91492, 6405, 'Normal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198219.mp4', 'http://gstaticontent.com/images/7988dd480a7ad30f041f5316713266dc.jpg'),
(91493, 6405, 'Normal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198220.mp4', 'http://gstaticontent.com/images/7988dd480a7ad30f041f5316713266dc.jpg'),
(91494, 6406, 'O Diagnóstico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198203.mp4', 'http://gstaticontent.com/images/f7f3a153f962d70e0e52661d87a46d98.jpg'),
(91495, 6406, 'O Diagnóstico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198204.mp4', 'http://gstaticontent.com/images/f7f3a153f962d70e0e52661d87a46d98.jpg'),
(91496, 6406, 'O Diagnóstico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198205.mp4', 'http://gstaticontent.com/images/f7f3a153f962d70e0e52661d87a46d98.jpg'),
(91497, 6406, 'O Diagnóstico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198206.mp4', 'http://gstaticontent.com/images/f7f3a153f962d70e0e52661d87a46d98.jpg'),
(91498, 6406, 'O Diagnóstico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198207.mp4', 'http://gstaticontent.com/images/f7f3a153f962d70e0e52661d87a46d98.jpg'),
(91499, 6406, 'O Diagnóstico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198208.mp4', 'http://gstaticontent.com/images/f7f3a153f962d70e0e52661d87a46d98.jpg'),
(91500, 6406, 'O Diagnóstico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198209.mp4', 'http://gstaticontent.com/images/f7f3a153f962d70e0e52661d87a46d98.jpg'),
(91501, 6406, 'O Diagnóstico S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198210.mp4', 'http://gstaticontent.com/images/f7f3a153f962d70e0e52661d87a46d98.jpg'),
(91502, 6406, 'O Diagnóstico S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198211.mp4', 'http://gstaticontent.com/images/f7f3a153f962d70e0e52661d87a46d98.jpg'),
(91503, 6406, 'O Diagnóstico S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198212.mp4', 'http://gstaticontent.com/images/f7f3a153f962d70e0e52661d87a46d98.jpg'),
(91504, 6407, 'O Repatriado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198193.mp4', 'http://timg.bdta.pro/images/2f673b785f55d2eda98534d6300dd701.jpg'),
(91505, 6407, 'O Repatriado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198194.mp4', 'http://timg.bdta.pro/images/02fb6dc318ba90ea472b3197a8b97697.jpg'),
(91506, 6407, 'O Repatriado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198195.mp4', 'http://timg.bdta.pro/images/7f8b08b900bd2cbafb4f1aff90daa447.jpg'),
(91507, 6407, 'O Repatriado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198196.mp4', 'http://timg.bdta.pro/images/a52b3b886c8cd59fd82c2668e769af94.jpg'),
(91508, 6407, 'O Repatriado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198197.mp4', 'http://timg.bdta.pro/images/9da2c447d926e43fa43ca11da0908433.jpg'),
(91509, 6407, 'O Repatriado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198198.mp4', 'http://timg.bdta.pro/images/651702716d7f2349f0baf4cf55cae618.jpg'),
(91510, 6407, 'O Repatriado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198199.mp4', 'http://timg.bdta.pro/images/5c643ace1cb4f06ae0dcfc5f301bad7d.jpg'),
(91511, 6407, 'O Repatriado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198200.mp4', 'http://timg.bdta.pro/images/eb4b0cd31cbd9fe2e38f82931ebd2c04.jpg'),
(91512, 6407, 'O Repatriado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198201.mp4', 'http://timg.bdta.pro/images/7ec0d02d7d60b875e3e6334fbfd18a61.jpg'),
(91513, 6407, 'O Repatriado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198202.mp4', 'http://timg.bdta.pro/images/22ded770a25dd5eb46310e36453019f0.jpg'),
(91514, 6408, 'O Resgate na Caverna Tailandesa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198187.mp4', 'http://timg.bdta.pro/images/6a933759332c8fcee940106997c8ca7f.jpg'),
(91515, 6408, 'O Resgate na Caverna Tailandesa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198188.mp4', 'http://timg.bdta.pro/images/cce9e81a8735871d238595cbcd176ff0.jpg'),
(91516, 6408, 'O Resgate na Caverna Tailandesa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198189.mp4', 'http://timg.bdta.pro/images/85a65b81a35ffd6aa01c681ee61e1f78.jpg'),
(91517, 6408, 'O Resgate na Caverna Tailandesa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198190.mp4', 'http://timg.bdta.pro/images/5b85b0ebdbc430c74a6ca858f2cf865c.jpg'),
(91518, 6408, 'O Resgate na Caverna Tailandesa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198191.mp4', 'http://timg.bdta.pro/images/d29db7cfd125f912dfbe40fab9f79bd3.jpg'),
(91519, 6408, 'O Resgate na Caverna Tailandesa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198192.mp4', 'http://timg.bdta.pro/images/aa2d9296aa8691f7740a53f64114f04c.jpg'),
(91520, 6409, 'Prisma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198179.mp4', 'http://timg.bdta.pro/images/f6069bb850e73fc2ca7e0d54cc470952.jpg'),
(91521, 6409, 'Prisma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198180.mp4', 'http://timg.bdta.pro/images/b289efa2c9428cf939050f14a95a3879.jpg'),
(91522, 6409, 'Prisma S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198181.mp4', 'http://timg.bdta.pro/images/d6e0ceb32c336f465e9f6680f9f3e2ea.jpg'),
(91523, 6409, 'Prisma S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198182.mp4', 'http://timg.bdta.pro/images/cbfcce006debac9cb19f58170480e423.jpg'),
(91524, 6409, 'Prisma S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198183.mp4', 'http://timg.bdta.pro/images/5b44ed5f378ab211f1502d3d5f1b7b55.jpg'),
(91525, 6409, 'Prisma S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198184.mp4', 'http://timg.bdta.pro/images/7cf693b45f3239604ec31d0b23ece83f.jpg'),
(91526, 6409, 'Prisma S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198185.mp4', 'http://timg.bdta.pro/images/48b22d192af8884ffff62c45f48cd4f5.jpg'),
(91527, 6409, 'Prisma S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198186.mp4', 'http://timg.bdta.pro/images/c906f980403fe6f645ca395471713565.jpg'),
(91528, 6410, 'Reformas de Luxo em Miami S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198171.mp4', 'http://gstaticontent.com/images/27a1275237fa58eb0bbefd52a80e1988.jpg'),
(91529, 6410, 'Reformas de Luxo em Miami S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198172.mp4', 'http://gstaticontent.com/images/27a1275237fa58eb0bbefd52a80e1988.jpg'),
(91530, 6410, 'Reformas de Luxo em Miami S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198173.mp4', 'http://gstaticontent.com/images/27a1275237fa58eb0bbefd52a80e1988.jpg'),
(91531, 6410, 'Reformas de Luxo em Miami S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198174.mp4', 'http://gstaticontent.com/images/27a1275237fa58eb0bbefd52a80e1988.jpg'),
(91532, 6410, 'Reformas de Luxo em Miami S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198175.mp4', 'http://gstaticontent.com/images/27a1275237fa58eb0bbefd52a80e1988.jpg'),
(91533, 6410, 'Reformas de Luxo em Miami S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198176.mp4', 'http://gstaticontent.com/images/27a1275237fa58eb0bbefd52a80e1988.jpg'),
(91534, 6410, 'Reformas de Luxo em Miami S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198177.mp4', 'http://gstaticontent.com/images/27a1275237fa58eb0bbefd52a80e1988.jpg'),
(91535, 6410, 'Reformas de Luxo em Miami S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198178.mp4', 'http://gstaticontent.com/images/27a1275237fa58eb0bbefd52a80e1988.jpg'),
(91536, 6411, 'SkyMed S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259008.mp4', 'http://timg.bdta.pro/images/339bbb2646f7fcb6372f5f8185debb67.jpg'),
(91537, 6411, 'SkyMed S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259009.mp4', 'http://timg.bdta.pro/images/0999df0930083a87e545afeaddae1f6e.jpg'),
(91538, 6411, 'SkyMed S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259010.mp4', 'http://timg.bdta.pro/images/f736b59ce9e2aad1a31c115a47e87501.jpg'),
(91539, 6411, 'SkyMed S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259011.mp4', 'http://timg.bdta.pro/images/8c85b9e228eec23ca524720c8c546b14.jpg'),
(91540, 6411, 'SkyMed S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259012.mp4', 'http://timg.bdta.pro/images/78bfc27996dc3d355e36465954a9fbb1.jpg'),
(91541, 6411, 'SkyMed S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259013.mp4', 'http://timg.bdta.pro/images/d00a1d366ec60e1d2d9cd18784c5c1e4.jpg'),
(91542, 6411, 'SkyMed S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259014.mp4', 'http://timg.bdta.pro/images/67d3326f66a733f21c5e0430c3f3dac1.jpg'),
(91543, 6411, 'SkyMed S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259015.mp4', 'http://timg.bdta.pro/images/01c74d584080d949829d71c4e700c1a1.jpg'),
(91544, 6411, 'SkyMed S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259016.mp4', 'http://timg.bdta.pro/images/82239d5e8e2f1f78a7fe45eedc19f167.jpg'),
(91545, 6412, 'SkyMed S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259017.mp4', 'http://gstaticontent.com/images/f334289a6f7ba52e9cfdfb32639a9612.jpg'),
(91546, 6412, 'SkyMed S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259018.mp4', 'http://gstaticontent.com/images/f334289a6f7ba52e9cfdfb32639a9612.jpg'),
(91547, 6412, 'SkyMed S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259019.mp4', 'http://gstaticontent.com/images/f334289a6f7ba52e9cfdfb32639a9612.jpg'),
(91548, 6412, 'SkyMed S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259020.mp4', 'http://gstaticontent.com/images/f334289a6f7ba52e9cfdfb32639a9612.jpg'),
(91549, 6412, 'SkyMed S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259021.mp4', 'http://gstaticontent.com/images/f334289a6f7ba52e9cfdfb32639a9612.jpg'),
(91550, 6412, 'SkyMed S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259022.mp4', 'http://gstaticontent.com/images/f334289a6f7ba52e9cfdfb32639a9612.jpg'),
(91551, 6412, 'SkyMed S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259023.mp4', 'http://gstaticontent.com/images/f334289a6f7ba52e9cfdfb32639a9612.jpg'),
(91552, 6412, 'SkyMed S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259024.mp4', 'http://gstaticontent.com/images/f334289a6f7ba52e9cfdfb32639a9612.jpg'),
(91553, 6412, 'SkyMed S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259025.mp4', 'http://gstaticontent.com/images/f334289a6f7ba52e9cfdfb32639a9612.jpg'),
(91554, 6413, 'Só Se For Por Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198165.mp4', 'http://gstaticontent.com/images/b7e707ecca7c86eb4cd3054b8cbe5d00.jpg'),
(91555, 6413, 'Só Se For Por Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198166.mp4', 'http://gstaticontent.com/images/b7e707ecca7c86eb4cd3054b8cbe5d00.jpg'),
(91556, 6413, 'Só Se For Por Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198167.mp4', 'http://gstaticontent.com/images/b7e707ecca7c86eb4cd3054b8cbe5d00.jpg'),
(91557, 6413, 'Só Se For Por Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198168.mp4', 'http://gstaticontent.com/images/b7e707ecca7c86eb4cd3054b8cbe5d00.jpg'),
(91558, 6413, 'Só Se For Por Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198169.mp4', 'http://gstaticontent.com/images/b7e707ecca7c86eb4cd3054b8cbe5d00.jpg'),
(91559, 6413, 'Só Se For Por Amor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198170.mp4', 'http://gstaticontent.com/images/b7e707ecca7c86eb4cd3054b8cbe5d00.jpg'),
(91560, 6414, 'Super Natural S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198159.mp4', 'http://timg.bdta.pro/images/712f2674e2ef628fc8d8b7ed4db09571.jpg'),
(91561, 6414, 'Super Natural S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198160.mp4', 'http://timg.bdta.pro/images/85a06cc2965c0f308e5e6dc5dbeb9482.jpg'),
(91562, 6414, 'Super Natural S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198161.mp4', 'http://timg.bdta.pro/images/9080167f4cfe648068e66a7306770205.jpg'),
(91563, 6414, 'Super Natural S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198162.mp4', 'http://timg.bdta.pro/images/901d6d81640dccba3a8f16bb3e7b2c10.jpg'),
(91564, 6414, 'Super Natural S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198163.mp4', 'http://timg.bdta.pro/images/2677ca29413a782577c18b9030308f4e.jpg'),
(91565, 6414, 'Super Natural S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198164.mp4', 'http://timg.bdta.pro/images/2c0b4ce0f4176c5196b8c0cb3225bddf.jpg'),
(91566, 6415, 'The Boys from Brazil: Rise of the Bolsonaros [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198156.mp4', 'http://timg.bdta.pro/images/418845040afb29d172476ba48b5f6484.jpg'),
(91567, 6415, 'The Boys from Brazil: Rise of the Bolsonaros [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198157.mp4', 'http://timg.bdta.pro/images/4c169b0abc4dd5a7cb26e3585c0d7322.jpg'),
(91568, 6415, 'The Boys from Brazil: Rise of the Bolsonaros [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198158.mp4', 'http://timg.bdta.pro/images/aa40692230bdb736f472566e28c215b8.jpg'),
(91569, 6416, 'Todo o Sangue S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201667.mp4', 'http://timg.bdta.pro/images/b161ecfd14bf6facd7516d15501c4808.jpg'),
(91570, 6416, 'Todo o Sangue S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201668.mp4', 'http://timg.bdta.pro/images/6fd3cc7e4d5d59c7c854968575909768.jpg'),
(91571, 6416, 'Todo o Sangue S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201669.mp4', 'http://gstaticontent.com/images/ed908352011074684d8ee9e23c1fa47e.jpg'),
(91572, 6416, 'Todo o Sangue S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201670.mp4', 'http://timg.bdta.pro/images/38540880e9c76c9271e1cb2582cf30ee.jpg'),
(91573, 6416, 'Todo o Sangue S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201671.mp4', 'http://gstaticontent.com/images/ed908352011074684d8ee9e23c1fa47e.jpg'),
(91574, 6416, 'Todo o Sangue S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201672.mp4', 'http://gstaticontent.com/images/ed908352011074684d8ee9e23c1fa47e.jpg'),
(91575, 6416, 'Todo o Sangue S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201673.mp4', 'http://gstaticontent.com/images/ed908352011074684d8ee9e23c1fa47e.jpg'),
(91576, 6416, 'Todo o Sangue S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201674.mp4', 'http://gstaticontent.com/images/ed908352011074684d8ee9e23c1fa47e.jpg'),
(91577, 6416, 'Todo o Sangue S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201675.mp4', 'http://gstaticontent.com/images/ed908352011074684d8ee9e23c1fa47e.jpg'),
(91578, 6416, 'Todo o Sangue S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201676.mp4', 'http://gstaticontent.com/images/ed908352011074684d8ee9e23c1fa47e.jpg'),
(91579, 6417, 'Cachorro. Vai! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198130.mp4', 'http://timg.bdta.pro/images/a2448eec73d2189a78400f0309ee372b.jpg'),
(91580, 6417, 'Cachorro. Vai! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198131.mp4', 'http://timg.bdta.pro/images/9fb416313534e59b223556d58e428326.jpg'),
(91581, 6417, 'Cachorro. Vai! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198132.mp4', 'http://timg.bdta.pro/images/fc3879d262b2c7def5731b0ad6f4a218.jpg'),
(91582, 6417, 'Cachorro. Vai! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198133.mp4', 'http://timg.bdta.pro/images/a580c0131a02c7984d361b9021d634a4.jpg'),
(91583, 6417, 'Cachorro. Vai! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198134.mp4', 'http://timg.bdta.pro/images/15cad8d28e7340a5cc30f845d53da432.jpg'),
(91584, 6417, 'Cachorro. Vai! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198135.mp4', 'http://timg.bdta.pro/images/e3f150cafbe870a7c658840e5a21b0fe.jpg'),
(91585, 6417, 'Cachorro. Vai! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198136.mp4', 'http://timg.bdta.pro/images/1e567a51bc8c8e3314e6a3f86d222ff5.jpg'),
(91586, 6417, 'Cachorro. Vai! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198137.mp4', 'http://timg.bdta.pro/images/7d291b46bb0136b890941b2f0dd04a12.jpg'),
(91587, 6417, 'Cachorro. Vai! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198138.mp4', 'http://timg.bdta.pro/images/935de576c0490617a7462f97fb64032d.jpg'),
(91588, 6418, 'Cachorro. Vai! S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198139.mp4', 'http://timg.bdta.pro/images/404789ae393cb61cfeb0c58d884605f3.jpg'),
(91589, 6418, 'Cachorro. Vai! S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198140.mp4', 'http://timg.bdta.pro/images/193f7c8ab88c9548a9756763049542f7.jpg'),
(91590, 6418, 'Cachorro. Vai! S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198141.mp4', 'http://timg.bdta.pro/images/e62c9dc8311aeddc31e430f5c5a0c3cb.jpg'),
(91591, 6418, 'Cachorro. Vai! S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198142.mp4', 'http://timg.bdta.pro/images/22950318310ffaa30cf281638361b9b8.jpg'),
(91592, 6418, 'Cachorro. Vai! S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198143.mp4', 'http://timg.bdta.pro/images/b5496c54cd35723f142ea8c2a756c092.jpg'),
(91593, 6418, 'Cachorro. Vai! S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198144.mp4', 'http://timg.bdta.pro/images/4389e27845f35192341e018b0558dc9d.jpg'),
(91594, 6418, 'Cachorro. Vai! S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198145.mp4', 'http://timg.bdta.pro/images/60ddb612cc74a84e787a3693c07e3dfc.jpg'),
(91595, 6418, 'Cachorro. Vai! S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198146.mp4', 'http://timg.bdta.pro/images/b469bcae00784ba92be3b3cb546e9566.jpg'),
(91596, 6418, 'Cachorro. Vai! S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198147.mp4', 'http://timg.bdta.pro/images/862f71471e59455656fa161cf8e9a728.jpg'),
(91597, 6419, 'Cachorro. Vai! S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198148.mp4', 'http://gstaticontent.com/images/c435af436252d7c755bbeff925779f15.jpg'),
(91598, 6419, 'Cachorro. Vai! S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198149.mp4', 'http://gstaticontent.com/images/c435af436252d7c755bbeff925779f15.jpg'),
(91599, 6419, 'Cachorro. Vai! S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198150.mp4', 'http://gstaticontent.com/images/c435af436252d7c755bbeff925779f15.jpg'),
(91600, 6419, 'Cachorro. Vai! S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198151.mp4', 'http://gstaticontent.com/images/c435af436252d7c755bbeff925779f15.jpg'),
(91601, 6419, 'Cachorro. Vai! S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198152.mp4', 'http://gstaticontent.com/images/c435af436252d7c755bbeff925779f15.jpg'),
(91602, 6419, 'Cachorro. Vai! S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198153.mp4', 'http://gstaticontent.com/images/c435af436252d7c755bbeff925779f15.jpg'),
(91603, 6419, 'Cachorro. Vai! S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198154.mp4', 'http://gstaticontent.com/images/c435af436252d7c755bbeff925779f15.jpg'),
(91604, 6419, 'Cachorro. Vai! S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198155.mp4', 'http://gstaticontent.com/images/c435af436252d7c755bbeff925779f15.jpg'),
(91605, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197953.mp4', 'http://timg.bdta.pro/images/02e7b6300b2c9fa86453bb79192b86f9.jpg'),
(91606, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197954.mp4', 'http://timg.bdta.pro/images/6c3e607331cff4ad8a20556271015a7d.jpg'),
(91607, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197955.mp4', 'http://timg.bdta.pro/images/7a9664d1300a640bba51441eb04dcf68.jpg'),
(91608, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197956.mp4', 'http://timg.bdta.pro/images/81fc4284f444dafc2695c6f997e46279.jpg'),
(91609, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197957.mp4', 'http://timg.bdta.pro/images/2fb1fc105304e1ee79f8dd893d2b8ad0.jpg'),
(91610, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197958.mp4', 'http://timg.bdta.pro/images/774ba437e21cc21d31b0afd103de3769.jpg'),
(91611, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197959.mp4', 'http://timg.bdta.pro/images/1a4405108b3538232c1df8aef07c602e.jpg'),
(91612, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197960.mp4', 'http://timg.bdta.pro/images/ce872138600b6d2c9d393b2f4e4e2b99.jpg'),
(91613, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/197961.mp4', 'http://timg.bdta.pro/images/d0224b748663b0af813a8f6e995c40b9.jpg'),
(91614, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/197962.mp4', 'http://timg.bdta.pro/images/0fd3644d42028912d0dd8f1c860fd1fb.jpg'),
(91615, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/197963.mp4', 'http://timg.bdta.pro/images/12669af0406c9ef8b2d601fd79ad995e.jpg'),
(91616, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/197964.mp4', 'http://timg.bdta.pro/images/8d026ed65542327b1df3d959c11ab11e.jpg'),
(91617, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/197965.mp4', 'http://timg.bdta.pro/images/f9a390bb906beaca208cad03e1bb3130.jpg'),
(91618, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/197966.mp4', 'http://timg.bdta.pro/images/7f9ec06b9563b18f77e37758842f4a39.jpg'),
(91619, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/197967.mp4', 'http://timg.bdta.pro/images/f885e1e9fabfd1956a02ffc412d97eb4.jpg'),
(91620, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/197968.mp4', 'http://timg.bdta.pro/images/a22161738d7409a3429f8fb677225877.jpg'),
(91621, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/197969.mp4', 'http://timg.bdta.pro/images/403726a954d9c5cd28243947034f3665.jpg'),
(91622, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/197970.mp4', 'http://timg.bdta.pro/images/af2120bddeb3fa79c8117a7514d6df40.jpg'),
(91623, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/197971.mp4', 'http://timg.bdta.pro/images/58bf54856cf0a68135860a42af7a2883.jpg'),
(91624, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/197972.mp4', 'http://timg.bdta.pro/images/60669cd6d2b78647122140793034e13d.jpg'),
(91625, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/197973.mp4', 'http://timg.bdta.pro/images/db97c59cef2761a83b48c7e8bf65a08b.jpg'),
(91626, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/197974.mp4', 'http://timg.bdta.pro/images/368ff48644a211d7a0d4f9500b8db8f5.jpg'),
(91627, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/197975.mp4', 'http://timg.bdta.pro/images/744334aae8f0f46bd936aeab129fd43c.jpg'),
(91628, 6420, 'Kiseijuu: Sei no Kakuritsu S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/197976.mp4', 'http://timg.bdta.pro/images/cb725685c6369bf67dce076b4375b80b.jpg'),
(91629, 6421, 'Noragami S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199374.mp4', 'http://timg.bdta.pro/images/00c37f20f60923e535509e3383fc6efd.jpg'),
(91630, 6421, 'Noragami S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199375.mp4', 'http://timg.bdta.pro/images/3d52e8f2ccc2536877779f5b97d37192.jpg'),
(91631, 6421, 'Noragami S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199376.mp4', 'http://timg.bdta.pro/images/872fe6771546c6402aeb0ddc20472a6c.jpg'),
(91632, 6421, 'Noragami S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199377.mp4', 'http://timg.bdta.pro/images/4351b41b7d6980843837ca251e5f5d9b.jpg'),
(91633, 6421, 'Noragami S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199378.mp4', 'http://timg.bdta.pro/images/7d482defdf63d0e5978603b2782780c2.jpg'),
(91634, 6421, 'Noragami S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199379.mp4', 'http://timg.bdta.pro/images/9dd9a566551ad5d587081af458366a91.jpg'),
(91635, 6421, 'Noragami S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199380.mp4', 'http://timg.bdta.pro/images/8bdbcfef7e0bf56bd52b214bee808854.jpg'),
(91636, 6421, 'Noragami S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199381.mp4', 'http://timg.bdta.pro/images/b036cc41a4d9966a15ccb054fe9c5d1b.jpg'),
(91637, 6421, 'Noragami S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199382.mp4', 'http://timg.bdta.pro/images/22dd1a84c62f2160c2bc46950c320d05.jpg'),
(91638, 6421, 'Noragami S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199383.mp4', 'http://timg.bdta.pro/images/e4daeb2a491b7bc8d97b798b0c4118e8.jpg'),
(91639, 6421, 'Noragami S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199384.mp4', 'http://timg.bdta.pro/images/4c4f5c5b3e2eccc7d859b93480284d99.jpg'),
(91640, 6421, 'Noragami S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199385.mp4', 'http://timg.bdta.pro/images/e150126b15c67762b41c28eaf51d4fc8.jpg'),
(91641, 6421, 'Noragami S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/199386.mp4', 'http://gstaticontent.com/images/66af05ae09cff6e63da877cd49046ad3.jpg'),
(91642, 6421, 'Noragami S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/199387.mp4', 'http://gstaticontent.com/images/66af05ae09cff6e63da877cd49046ad3.jpg'),
(91643, 6422, 'Noragami S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5wDIYJYG7U2OyW7WrNId6rirOlJ.jpg'),
(91644, 6422, 'Noragami S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oJUTURGF73D3Ss5trAM2ggbXR4S.jpg'),
(91645, 6422, 'Noragami S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lIZ7V0SzeggFYPo0dgswPsU7NyY.jpg'),
(91646, 6422, 'Noragami S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7tN9KnNZeygambS52biY4XagrAQ.jpg'),
(91647, 6422, 'Noragami S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qtmymqtVxCp5Nn4rmxX4v6iVzE0.jpg'),
(91648, 6422, 'Noragami S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kipC7uGT6166jk9vS7nQnpYA5B9.jpg'),
(91649, 6422, 'Noragami S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/epOjfYxowWlD1opLSUBgz4Puv9a.jpg'),
(91650, 6422, 'Noragami S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/23uuhqHuWjcuAZxOXYljitv2wHp.jpg'),
(91651, 6422, 'Noragami S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24SFLYEZ0s6ExCH3zIFDbSL9hUe.jpg'),
(91652, 6422, 'Noragami S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ldXWLzUIittOEX2Q9A7eQ6yBZEz.jpg'),
(91653, 6422, 'Noragami S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/39QvLb6JsO8rBjSMsjkL4kbSQfJ.jpg'),
(91654, 6422, 'Noragami S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eYLCybPoHBtNRVRukKiBaX8YqKz.jpg'),
(91655, 6422, 'Noragami S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/199400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qj9AqHHws2H1IKlQrDJ9Vbieq8j.jpg'),
(91656, 6422, 'Noragami S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/199401.mp4', 'http://gstaticontent.com/images/66af05ae09cff6e63da877cd49046ad3.jpg'),
(91657, 6422, 'Noragami S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/199402.mp4', 'http://gstaticontent.com/images/66af05ae09cff6e63da877cd49046ad3.jpg'),
(91658, 6423, 'InuYasha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197520.mp4', 'http://timg.bdta.pro/images/70e193e860c68d88dca7a2714322294b.jpg'),
(91659, 6423, 'InuYasha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197521.mp4', 'http://timg.bdta.pro/images/21fbd842ead061ed28ba69f3b727944c.jpg'),
(91660, 6423, 'InuYasha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197522.mp4', 'http://timg.bdta.pro/images/87964f2fa9724488355e6d77c1b89421.jpg'),
(91661, 6423, 'InuYasha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197523.mp4', 'http://timg.bdta.pro/images/c6f8a8cfb8aaba6b01328bbb6752c2ef.jpg'),
(91662, 6423, 'InuYasha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197524.mp4', 'http://timg.bdta.pro/images/9bd7758a07f207084935b08b5eac7f25.jpg'),
(91663, 6423, 'InuYasha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197525.mp4', 'http://timg.bdta.pro/images/4639ff1d8ce6ed1a031a93e7b670f005.jpg'),
(91664, 6423, 'InuYasha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197526.mp4', 'http://timg.bdta.pro/images/6f205bbfec4f2da0e51e3af156a2fb15.jpg'),
(91665, 6423, 'InuYasha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197527.mp4', 'http://timg.bdta.pro/images/cdb567cd6f3721101a57cd0cbcd62cdb.jpg'),
(91666, 6423, 'InuYasha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/197528.mp4', 'http://timg.bdta.pro/images/417acbc245b44109d96ff1f5f0835024.jpg'),
(91667, 6423, 'InuYasha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/197529.mp4', 'http://timg.bdta.pro/images/7d4ab7fa833a3c0edc9f2750508ed102.jpg'),
(91668, 6423, 'InuYasha S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/197530.mp4', 'http://timg.bdta.pro/images/e863c8ac673b138076b3c359bed313f1.jpg'),
(91669, 6423, 'InuYasha S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/197531.mp4', 'http://timg.bdta.pro/images/783b970eaf9e406850fcf44d76069823.jpg'),
(91670, 6423, 'InuYasha S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/197532.mp4', 'http://timg.bdta.pro/images/4a1b048aa229e6febd13bff49d268e80.jpg'),
(91671, 6423, 'InuYasha S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/197533.mp4', 'http://timg.bdta.pro/images/1c192e3aa79425c0aa48f734a6aa8341.jpg'),
(91672, 6423, 'InuYasha S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/197534.mp4', 'http://timg.bdta.pro/images/69f7164a0782ae4573902544d61adf69.jpg'),
(91673, 6423, 'InuYasha S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/197535.mp4', 'http://timg.bdta.pro/images/1a0cc04ea2e5607d7841042c21ed9211.jpg'),
(91674, 6423, 'InuYasha S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/197536.mp4', 'http://timg.bdta.pro/images/3ac370dca1c628f2f8069355e326ed1e.jpg'),
(91675, 6423, 'InuYasha S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/197537.mp4', 'http://timg.bdta.pro/images/c0345154082d137ddd9c9755ec2b18cd.jpg'),
(91676, 6423, 'InuYasha S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/197538.mp4', 'http://timg.bdta.pro/images/ed47ccbc4d24d8f529d1aa12ca6d953f.jpg'),
(91677, 6423, 'InuYasha S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/197539.mp4', 'http://timg.bdta.pro/images/3bb0fb7ab82d7af8c219ad9dc0d6df50.jpg'),
(91678, 6423, 'InuYasha S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/197540.mp4', 'http://timg.bdta.pro/images/7e7d1014b1fafde3ddf20bdecc53da1e.jpg'),
(91679, 6423, 'InuYasha S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/197541.mp4', 'http://timg.bdta.pro/images/568dd0b1d004762973c880ecea288dc2.jpg'),
(91680, 6423, 'InuYasha S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/197542.mp4', 'http://timg.bdta.pro/images/6fed594704b97378ef2b827a4bddaaad.jpg'),
(91681, 6423, 'InuYasha S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/197543.mp4', 'http://timg.bdta.pro/images/5c0c7b7b95868f4a8c3eed75b08399fd.jpg'),
(91682, 6423, 'InuYasha S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/197544.mp4', 'http://timg.bdta.pro/images/026490ddfe1f494db24a9c47543eff70.jpg'),
(91683, 6423, 'InuYasha S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/197545.mp4', 'http://timg.bdta.pro/images/dfca5606402cf1e7b865681b6e3d8a4c.jpg'),
(91684, 6423, 'InuYasha S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/197546.mp4', 'http://timg.bdta.pro/images/2ba62a99659d897c7c1c370888eaae91.jpg'),
(91685, 6424, 'InuYasha S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197547.mp4', 'http://timg.bdta.pro/images/c8a7d008f91c32756df2a24ad5ef8b22.jpg'),
(91686, 6424, 'InuYasha S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197548.mp4', 'http://timg.bdta.pro/images/30dc1bf9bf97e25de4189b213e7bcefa.jpg'),
(91687, 6424, 'InuYasha S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197549.mp4', 'http://timg.bdta.pro/images/6f570284ec24c2596f9087d69f905b7e.jpg'),
(91688, 6424, 'InuYasha S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197550.mp4', 'http://timg.bdta.pro/images/19bfac6438c98f3084480fd3f6058382.jpg'),
(91689, 6424, 'InuYasha S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197551.mp4', 'http://timg.bdta.pro/images/50b3917245d60b63b77c7dbb2e6a5b56.jpg'),
(91690, 6424, 'InuYasha S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197552.mp4', 'http://timg.bdta.pro/images/46aa55139f8ef45695ef47cd3f32e731.jpg'),
(91691, 6424, 'InuYasha S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197553.mp4', 'http://timg.bdta.pro/images/0e73899fc88bbb5ad4b8543d0a0bbdcc.jpg'),
(91692, 6424, 'InuYasha S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197554.mp4', 'http://timg.bdta.pro/images/2d46427d62776df813bd6378f9fd31cc.jpg'),
(91693, 6424, 'InuYasha S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/197555.mp4', 'http://timg.bdta.pro/images/70cbcc3b2a374c79fdc66904be1883b0.jpg'),
(91694, 6424, 'InuYasha S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/197556.mp4', 'http://timg.bdta.pro/images/4a377f5a189b8020f16de88358f057e1.jpg'),
(91695, 6424, 'InuYasha S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/197557.mp4', 'http://timg.bdta.pro/images/348cc44f5d8ea498440e4b03a03a7a51.jpg'),
(91696, 6424, 'InuYasha S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/197558.mp4', 'http://timg.bdta.pro/images/970f2878bbbc64a7bea7cb0794378659.jpg'),
(91697, 6424, 'InuYasha S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/197559.mp4', 'http://timg.bdta.pro/images/5d8ca5c92c23310af6a36fdbae222241.jpg'),
(91698, 6424, 'InuYasha S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/197560.mp4', 'http://timg.bdta.pro/images/aff4bd5201ab86b4ce01970199819a75.jpg'),
(91699, 6424, 'InuYasha S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/197561.mp4', 'http://timg.bdta.pro/images/ec0b78075c30f5520f7363dc60c552b7.jpg'),
(91700, 6424, 'InuYasha S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/197562.mp4', 'http://timg.bdta.pro/images/025d2d699a57202c31086af54bea9a1f.jpg'),
(91701, 6424, 'InuYasha S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/197563.mp4', 'http://timg.bdta.pro/images/ab585282b1fb858440dd3c49ab1d6e9b.jpg'),
(91702, 6424, 'InuYasha S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/197564.mp4', 'http://timg.bdta.pro/images/7327e4b87daed84619f2392de6cd8dfc.jpg'),
(91703, 6424, 'InuYasha S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/197565.mp4', 'http://timg.bdta.pro/images/2104c270a05db82f29397f84db664584.jpg'),
(91704, 6424, 'InuYasha S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/197566.mp4', 'http://timg.bdta.pro/images/c02908a4506804921e39b219f247be93.jpg'),
(91705, 6424, 'InuYasha S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/197567.mp4', 'http://timg.bdta.pro/images/e1720d798cb8dcd202421f89926d6926.jpg'),
(91706, 6424, 'InuYasha S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/197568.mp4', 'http://timg.bdta.pro/images/f7d13ec346d7d8dd949b98c25cca1440.jpg'),
(91707, 6424, 'InuYasha S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/197569.mp4', 'http://timg.bdta.pro/images/cafb0a73fac7a8ebdeae3e1b92dd643a.jpg'),
(91708, 6424, 'InuYasha S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/197570.mp4', 'http://timg.bdta.pro/images/192ee16cf7eb3d745a185337580c63fa.jpg'),
(91709, 6424, 'InuYasha S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/197571.mp4', 'http://timg.bdta.pro/images/61dfc7bfb7e60f6398a9bdb9e80536c3.jpg'),
(91710, 6424, 'InuYasha S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/197572.mp4', 'http://timg.bdta.pro/images/4e873b3c0626ed6bc1b7fb4d404252a2.jpg'),
(91711, 6424, 'InuYasha S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/197573.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91712, 6425, 'InuYasha S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197574.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91713, 6425, 'InuYasha S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197575.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91714, 6425, 'InuYasha S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197576.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91715, 6425, 'InuYasha S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197577.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91716, 6425, 'InuYasha S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197578.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91717, 6425, 'InuYasha S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197579.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91718, 6425, 'InuYasha S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197580.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91719, 6425, 'InuYasha S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197581.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91720, 6425, 'InuYasha S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/197582.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91721, 6425, 'InuYasha S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/197583.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91722, 6425, 'InuYasha S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/197584.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91723, 6425, 'InuYasha S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/197585.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91724, 6425, 'InuYasha S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/197586.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91725, 6425, 'InuYasha S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/197587.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91726, 6425, 'InuYasha S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/197588.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91727, 6425, 'InuYasha S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/197589.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91728, 6425, 'InuYasha S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/197590.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91729, 6425, 'InuYasha S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/197591.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91730, 6425, 'InuYasha S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/197592.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91731, 6425, 'InuYasha S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/197593.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91732, 6425, 'InuYasha S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/197594.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91733, 6425, 'InuYasha S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/197595.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91734, 6425, 'InuYasha S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/197596.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91735, 6425, 'InuYasha S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/197597.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91736, 6425, 'InuYasha S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/197598.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91737, 6425, 'InuYasha S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/197599.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91738, 6425, 'InuYasha S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/197600.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91739, 6425, 'InuYasha S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/197601.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91740, 6426, 'InuYasha S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197602.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91741, 6426, 'InuYasha S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197603.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91742, 6426, 'InuYasha S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197604.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91743, 6426, 'InuYasha S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197605.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91744, 6426, 'InuYasha S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197606.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91745, 6426, 'InuYasha S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197607.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91746, 6426, 'InuYasha S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197608.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91747, 6426, 'InuYasha S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197609.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(91748, 6426, 'InuYasha S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/197610.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91749, 6426, 'InuYasha S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/197611.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91750, 6426, 'InuYasha S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/197612.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91751, 6426, 'InuYasha S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/197613.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91752, 6426, 'InuYasha S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/197614.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91753, 6426, 'InuYasha S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/197615.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91754, 6426, 'InuYasha S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/197616.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91755, 6426, 'InuYasha S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/197617.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91756, 6426, 'InuYasha S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/197618.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91757, 6426, 'InuYasha S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/197619.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91758, 6426, 'InuYasha S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/197620.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91759, 6426, 'InuYasha S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/197621.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91760, 6426, 'InuYasha S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/197622.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91761, 6426, 'InuYasha S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/197623.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91762, 6426, 'InuYasha S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/197624.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91763, 6426, 'InuYasha S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/197625.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91764, 6426, 'InuYasha S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/197626.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91765, 6426, 'InuYasha S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/197627.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91766, 6426, 'InuYasha S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/197628.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91767, 6426, 'InuYasha S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/197629.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91768, 6427, 'InuYasha S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197630.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91769, 6427, 'InuYasha S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197631.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91770, 6427, 'InuYasha S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197632.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91771, 6427, 'InuYasha S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197633.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91772, 6427, 'InuYasha S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197634.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91773, 6427, 'InuYasha S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197635.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91774, 6427, 'InuYasha S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197636.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91775, 6427, 'InuYasha S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197637.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91776, 6427, 'InuYasha S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/197638.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91777, 6427, 'InuYasha S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/197639.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91778, 6427, 'InuYasha S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/197640.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91779, 6427, 'InuYasha S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/197641.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91780, 6427, 'InuYasha S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/197642.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91781, 6427, 'InuYasha S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/197643.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91782, 6427, 'InuYasha S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/197644.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91783, 6427, 'InuYasha S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/197645.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91784, 6427, 'InuYasha S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/197646.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91785, 6427, 'InuYasha S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/197647.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91786, 6427, 'InuYasha S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/197648.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91787, 6427, 'InuYasha S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/197649.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91788, 6427, 'InuYasha S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/197650.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91789, 6427, 'InuYasha S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/197651.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91790, 6427, 'InuYasha S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/197652.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91791, 6427, 'InuYasha S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/197653.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91792, 6427, 'InuYasha S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/197654.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91793, 6427, 'InuYasha S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/197655.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91794, 6427, 'InuYasha S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/197656.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91795, 6427, 'InuYasha S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/197657.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91796, 6428, 'InuYasha S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197658.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91797, 6428, 'InuYasha S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197659.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91798, 6428, 'InuYasha S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197660.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91799, 6428, 'InuYasha S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197661.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91800, 6428, 'InuYasha S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197662.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91801, 6428, 'InuYasha S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197663.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91802, 6428, 'InuYasha S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197664.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91803, 6428, 'InuYasha S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197665.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91804, 6428, 'InuYasha S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/197666.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91805, 6428, 'InuYasha S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/197667.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91806, 6428, 'InuYasha S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/197668.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91807, 6428, 'InuYasha S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/197669.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91808, 6428, 'InuYasha S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/197670.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91809, 6428, 'InuYasha S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/197671.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91810, 6428, 'InuYasha S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/197672.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91811, 6428, 'InuYasha S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/197673.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91812, 6428, 'InuYasha S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/197674.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91813, 6428, 'InuYasha S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/197675.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91814, 6428, 'InuYasha S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/197676.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91815, 6428, 'InuYasha S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/197677.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91816, 6428, 'InuYasha S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/197678.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91817, 6428, 'InuYasha S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/197679.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91818, 6428, 'InuYasha S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/197680.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91819, 6428, 'InuYasha S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/197681.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91820, 6428, 'InuYasha S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/197682.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91821, 6428, 'InuYasha S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/197683.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91822, 6428, 'InuYasha S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/197684.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91823, 6428, 'InuYasha S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/197685.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91824, 6428, 'InuYasha S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/197686.mp4', 'http://gstaticontent.com/images/9a4cbafb50e71991134a93bc9b07fc9f.jpg'),
(91825, 6429, 'Cine Holliúdy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223381.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91826, 6429, 'Cine Holliúdy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223382.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91827, 6429, 'Cine Holliúdy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223383.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91828, 6429, 'Cine Holliúdy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223384.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91829, 6429, 'Cine Holliúdy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223385.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91830, 6429, 'Cine Holliúdy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223386.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91831, 6429, 'Cine Holliúdy S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223387.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91832, 6429, 'Cine Holliúdy S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223388.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91833, 6429, 'Cine Holliúdy S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223389.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91834, 6429, 'Cine Holliúdy S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223390.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91835, 6430, 'Cine Holliúdy S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223391.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91836, 6430, 'Cine Holliúdy S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223392.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91837, 6430, 'Cine Holliúdy S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223393.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91838, 6430, 'Cine Holliúdy S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223394.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91839, 6430, 'Cine Holliúdy S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223395.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91840, 6430, 'Cine Holliúdy S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223396.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91841, 6430, 'Cine Holliúdy S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223397.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91842, 6430, 'Cine Holliúdy S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223398.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91843, 6430, 'Cine Holliúdy S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223399.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91844, 6430, 'Cine Holliúdy S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223400.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91845, 6430, 'Cine Holliúdy S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223401.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91846, 6431, 'Cine Holliúdy S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223402.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91847, 6431, 'Cine Holliúdy S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223403.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91848, 6431, 'Cine Holliúdy S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223404.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91849, 6431, 'Cine Holliúdy S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223405.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91850, 6431, 'Cine Holliúdy S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223406.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91851, 6431, 'Cine Holliúdy S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223407.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91852, 6431, 'Cine Holliúdy S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223408.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91853, 6431, 'Cine Holliúdy S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223409.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91854, 6431, 'Cine Holliúdy S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223410.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91855, 6431, 'Cine Holliúdy S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223411.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91856, 6431, 'Cine Holliúdy S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223412.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91857, 6431, 'Cine Holliúdy S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223413.mp4', 'http://gstaticontent.com/images/d9a6f20767bbb7d884d978e179a6b76e.jpg'),
(91858, 6432, 'A Acusação S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197087.mp4', 'http://timg.bdta.pro/images/c497b95c2dc4a629827941311b4d6932.jpg'),
(91859, 6432, 'A Acusação S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197088.mp4', 'http://timg.bdta.pro/images/d8d7df68f494d4732857a910ab617537.jpg'),
(91860, 6432, 'A Acusação S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197089.mp4', 'http://timg.bdta.pro/images/1eb1642234ba77117ec78fbfee279717.jpg'),
(91861, 6432, 'A Acusação S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197090.mp4', 'http://timg.bdta.pro/images/5f20ac73169415f2172fbb2443128e8b.jpg'),
(91862, 6433, 'A Batalha dos Piores Cozinheiros Em Pratos Limpos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197080.mp4', 'http://gstaticontent.com/images/796b27696ef0237c3b3f6a2b28acbd99.jpg'),
(91863, 6433, 'A Batalha dos Piores Cozinheiros Em Pratos Limpos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197081.mp4', 'http://gstaticontent.com/images/796b27696ef0237c3b3f6a2b28acbd99.jpg'),
(91864, 6433, 'A Batalha dos Piores Cozinheiros Em Pratos Limpos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197082.mp4', 'http://gstaticontent.com/images/796b27696ef0237c3b3f6a2b28acbd99.jpg'),
(91865, 6433, 'A Batalha dos Piores Cozinheiros Em Pratos Limpos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197083.mp4', 'http://gstaticontent.com/images/796b27696ef0237c3b3f6a2b28acbd99.jpg'),
(91866, 6433, 'A Batalha dos Piores Cozinheiros Em Pratos Limpos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197084.mp4', 'http://gstaticontent.com/images/796b27696ef0237c3b3f6a2b28acbd99.jpg'),
(91867, 6433, 'A Batalha dos Piores Cozinheiros Em Pratos Limpos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197085.mp4', 'http://gstaticontent.com/images/796b27696ef0237c3b3f6a2b28acbd99.jpg'),
(91868, 6433, 'A Batalha dos Piores Cozinheiros Em Pratos Limpos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197086.mp4', 'http://gstaticontent.com/images/796b27696ef0237c3b3f6a2b28acbd99.jpg'),
(91869, 6434, 'A Imperatriz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197074.mp4', 'http://timg.bdta.pro/images/d96bced4488a2406c0b407954c146bd7.jpg'),
(91870, 6434, 'A Imperatriz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197075.mp4', 'http://timg.bdta.pro/images/8be19f856b80abeda592909280796e2e.jpg'),
(91871, 6434, 'A Imperatriz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197076.mp4', 'http://timg.bdta.pro/images/b7fe6afef2d5e42b2131534557aabf3e.jpg'),
(91872, 6434, 'A Imperatriz S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197077.mp4', 'http://timg.bdta.pro/images/ac03e0b9add66f0cf94b43c6a84382f3.jpg'),
(91873, 6434, 'A Imperatriz S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197078.mp4', 'http://timg.bdta.pro/images/fd99dd0798dc13fefbd45c46bfa674e2.jpg'),
(91874, 6434, 'A Imperatriz S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197079.mp4', 'http://timg.bdta.pro/images/58a6b8022e37e6758c0b46bc1eccc760.jpg'),
(91875, 6435, 'A Imperatriz S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508593.mp4', 'http://gstaticontent.com/images/cae7457fb65e011216e4747fb0dde334.jpg'),
(91876, 6435, 'A Imperatriz S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508594.mp4', 'http://gstaticontent.com/images/cae7457fb65e011216e4747fb0dde334.jpg'),
(91877, 6435, 'A Imperatriz S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508595.mp4', 'http://gstaticontent.com/images/cae7457fb65e011216e4747fb0dde334.jpg'),
(91878, 6435, 'A Imperatriz S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508596.mp4', 'http://gstaticontent.com/images/cae7457fb65e011216e4747fb0dde334.jpg'),
(91879, 6435, 'A Imperatriz S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508597.mp4', 'http://gstaticontent.com/images/cae7457fb65e011216e4747fb0dde334.jpg'),
(91880, 6435, 'A Imperatriz S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508598.mp4', 'http://gstaticontent.com/images/cae7457fb65e011216e4747fb0dde334.jpg'),
(91881, 6436, 'cientista S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197054.mp4', 'http://timg.bdta.pro/images/64ad9a01050e6ab11a2098aa19084429.jpg'),
(91882, 6436, 'cientista S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197055.mp4', 'http://timg.bdta.pro/images/84c6ec85aed7d130eb92d823d8ce7667.jpg'),
(91883, 6436, 'cientista S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197056.mp4', 'http://timg.bdta.pro/images/be1acf4ce8a17687ebdf54851650c0bb.jpg'),
(91884, 6436, 'cientista S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197057.mp4', 'http://timg.bdta.pro/images/443ba4085f6ed7e3f92160d5276eeb7d.jpg'),
(91885, 6436, 'cientista S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197058.mp4', 'http://timg.bdta.pro/images/10a4c9070658fd84292ca6e40590ee4a.jpg'),
(91886, 6436, 'cientista S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197059.mp4', 'http://timg.bdta.pro/images/5c14d3e77938e48a41dc8433a501d12a.jpg'),
(91887, 6437, 'cientista S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197060.mp4', 'http://gstaticontent.com/images/2fd9238c1463d5cacd953654e0bd3109.jpg'),
(91888, 6437, 'cientista S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197061.mp4', 'http://gstaticontent.com/images/2fd9238c1463d5cacd953654e0bd3109.jpg'),
(91889, 6437, 'cientista S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197062.mp4', 'http://gstaticontent.com/images/2fd9238c1463d5cacd953654e0bd3109.jpg'),
(91890, 6437, 'cientista S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197063.mp4', 'http://gstaticontent.com/images/2fd9238c1463d5cacd953654e0bd3109.jpg'),
(91891, 6437, 'cientista S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197064.mp4', 'http://gstaticontent.com/images/2fd9238c1463d5cacd953654e0bd3109.jpg'),
(91892, 6437, 'cientista S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197065.mp4', 'http://gstaticontent.com/images/2fd9238c1463d5cacd953654e0bd3109.jpg'),
(91893, 6438, 'cientista S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197066.mp4', 'http://gstaticontent.com/images/2fd9238c1463d5cacd953654e0bd3109.jpg'),
(91894, 6438, 'cientista S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197067.mp4', 'http://gstaticontent.com/images/2fd9238c1463d5cacd953654e0bd3109.jpg'),
(91895, 6438, 'cientista S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197068.mp4', 'http://gstaticontent.com/images/2fd9238c1463d5cacd953654e0bd3109.jpg'),
(91896, 6438, 'cientista S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197069.mp4', 'http://gstaticontent.com/images/2fd9238c1463d5cacd953654e0bd3109.jpg'),
(91897, 6438, 'cientista S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197070.mp4', 'http://gstaticontent.com/images/2fd9238c1463d5cacd953654e0bd3109.jpg'),
(91898, 6438, 'cientista S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197071.mp4', 'http://gstaticontent.com/images/2fd9238c1463d5cacd953654e0bd3109.jpg'),
(91899, 6438, 'cientista S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197072.mp4', 'http://gstaticontent.com/images/2fd9238c1463d5cacd953654e0bd3109.jpg'),
(91900, 6438, 'cientista S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197073.mp4', 'http://gstaticontent.com/images/2fd9238c1463d5cacd953654e0bd3109.jpg'),
(91901, 6439, 'Alquimia das Almas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207152.mp4', 'http://timg.bdta.pro/images/c79d8fa7a0cb41fada474dc94fd55052.jpg'),
(91902, 6439, 'Alquimia das Almas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207153.mp4', 'http://timg.bdta.pro/images/cf5666d225d641d596df4681e4047898.jpg'),
(91903, 6439, 'Alquimia das Almas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207154.mp4', 'http://timg.bdta.pro/images/ba2de4ce878b33c561169c3df6be5e22.jpg'),
(91904, 6439, 'Alquimia das Almas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207155.mp4', 'http://timg.bdta.pro/images/6d409f25b7ed0d05333616362e542205.jpg'),
(91905, 6439, 'Alquimia das Almas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207156.mp4', 'http://timg.bdta.pro/images/e903bbedb726187fd039ea16c76ca5e0.jpg'),
(91906, 6439, 'Alquimia das Almas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207157.mp4', 'http://timg.bdta.pro/images/9b5bbb677fd9f584842f0cb44565ac20.jpg'),
(91907, 6439, 'Alquimia das Almas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207158.mp4', 'http://timg.bdta.pro/images/c6dda8beaa6ba484ba5e82f29f8676a6.jpg'),
(91908, 6439, 'Alquimia das Almas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207159.mp4', 'http://timg.bdta.pro/images/e25e364b09204c05792998f6812d98e2.jpg'),
(91909, 6439, 'Alquimia das Almas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207160.mp4', 'http://timg.bdta.pro/images/2a95d12030c0513ae3414d263e06e70a.jpg'),
(91910, 6439, 'Alquimia das Almas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207161.mp4', 'http://timg.bdta.pro/images/30465bf2584c19b7b5e3387503571104.jpg'),
(91911, 6439, 'Alquimia das Almas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207162.mp4', 'http://timg.bdta.pro/images/c6dcd006d9933ed5636e2beff4d7f478.jpg'),
(91912, 6439, 'Alquimia das Almas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207163.mp4', 'http://timg.bdta.pro/images/d10403a83a149db55f67ee047964fcce.jpg'),
(91913, 6439, 'Alquimia das Almas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207164.mp4', 'http://timg.bdta.pro/images/fa80b2ef43801f849d1864093521c73d.jpg'),
(91914, 6439, 'Alquimia das Almas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/207165.mp4', 'http://timg.bdta.pro/images/86cfe8e593a0647b26cd13e03caf46b2.jpg'),
(91915, 6439, 'Alquimia das Almas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/207166.mp4', 'http://timg.bdta.pro/images/f842db8154906590262a2b09747cca30.jpg'),
(91916, 6439, 'Alquimia das Almas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/207167.mp4', 'http://timg.bdta.pro/images/1df5f58d1894ac8ad0bae3d7b3ad4489.jpg'),
(91917, 6439, 'Alquimia das Almas S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/207168.mp4', 'http://timg.bdta.pro/images/eb993748b48fd49fee7b345ff0adfc67.jpg'),
(91918, 6439, 'Alquimia das Almas S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/207169.mp4', 'http://timg.bdta.pro/images/6dad4ed2a4242512a8d9577b18af7895.jpg'),
(91919, 6439, 'Alquimia das Almas S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/207170.mp4', 'http://timg.bdta.pro/images/b025f50d9c19f7e3fc21976c989d4c3e.jpg'),
(91920, 6439, 'Alquimia das Almas S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/207171.mp4', 'http://timg.bdta.pro/images/2fc1713262930139af02464a5d4d87b3.jpg'),
(91921, 6440, 'Alquimia das Almas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vEZFVXimuSDceYo1wmzhnoV4zEO.jpg'),
(91922, 6440, 'Alquimia das Almas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b73NgTJ72EmsmpEvkVgVdQ9xWBi.jpg'),
(91923, 6440, 'Alquimia das Almas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207174.mp4', 'http://image.tmdb.org/t/p/w1280/835GkYrRZumoFb5E3soMm1Dr9gA.jpg'),
(91924, 6440, 'Alquimia das Almas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207175.mp4', 'http://image.tmdb.org/t/p/w1280/je08z2bL83VbAYAEX1QBq6P5oWw.jpg'),
(91925, 6440, 'Alquimia das Almas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207176.mp4', 'http://image.tmdb.org/t/p/w1280/h6ldQ3oSaEPjYkJETqFSq5NYvuV.jpg'),
(91926, 6440, 'Alquimia das Almas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207177.mp4', 'http://image.tmdb.org/t/p/w1280/fqcklt5pMzBUHHmSr9n9WIbNAUB.jpg'),
(91927, 6440, 'Alquimia das Almas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207178.mp4', 'http://image.tmdb.org/t/p/w1280/zz0iH71wKxEGPaiz0ajFWuVOQog.jpg'),
(91928, 6440, 'Alquimia das Almas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207179.mp4', 'http://image.tmdb.org/t/p/w1280/iGha1fkG7fggvLL5qiJ5SQNG2cN.jpg'),
(91929, 6440, 'Alquimia das Almas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207180.mp4', 'http://image.tmdb.org/t/p/w1280/4EnYloyJKh9BFszrEv9GnyfXQ1x.jpg'),
(91930, 6440, 'Alquimia das Almas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207181.mp4', 'http://image.tmdb.org/t/p/w1280/rcKP1eYnwXRLJa2tQqEZnJ1fKSh.jpg'),
(91931, 6441, 'Cachorrinhos do Outro Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197044.mp4', 'http://timg.bdta.pro/images/4b0d23ec4a41a7d3f94030537c364027.jpg'),
(91932, 6441, 'Cachorrinhos do Outro Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197045.mp4', 'http://timg.bdta.pro/images/a79c618df17afc962f55aa4ce731e834.jpg'),
(91933, 6441, 'Cachorrinhos do Outro Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197046.mp4', 'http://timg.bdta.pro/images/d2a784aace8825db8a081b0a9535cbf5.jpg'),
(91934, 6441, 'Cachorrinhos do Outro Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197047.mp4', 'http://timg.bdta.pro/images/55d6a5dfb579becb2668a581137ef613.jpg'),
(91935, 6441, 'Cachorrinhos do Outro Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197048.mp4', 'http://timg.bdta.pro/images/2215ee578043d9492f3c349d3c57b207.jpg'),
(91936, 6441, 'Cachorrinhos do Outro Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197049.mp4', 'http://timg.bdta.pro/images/dd7d9cd2d8ed2155b9d39e8dcebc3f0a.jpg'),
(91937, 6441, 'Cachorrinhos do Outro Mundo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197050.mp4', 'http://timg.bdta.pro/images/925236ba5a2f5f437a4614b3a60304b1.jpg'),
(91938, 6441, 'Cachorrinhos do Outro Mundo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197051.mp4', 'http://timg.bdta.pro/images/26f0abd40d7ee583c9924bd00c31b245.jpg'),
(91939, 6441, 'Cachorrinhos do Outro Mundo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/197052.mp4', 'http://timg.bdta.pro/images/05d3c1f28eb505bdf740a93d586d9294.jpg'),
(91940, 6441, 'Cachorrinhos do Outro Mundo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/197053.mp4', 'http://timg.bdta.pro/images/4a5607f40af6264c0907be2d1d77c50c.jpg'),
(91941, 6442, 'Café Minamdang S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197026.mp4', 'http://timg.bdta.pro/images/684be3226dd28e99084d11e57dbf316e.jpg'),
(91942, 6442, 'Café Minamdang S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197027.mp4', 'http://timg.bdta.pro/images/8c9d71b5d75272d454ea349243062dce.jpg'),
(91943, 6442, 'Café Minamdang S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197028.mp4', 'http://timg.bdta.pro/images/7aeb4cdef5e8f287ee1a628dca1d1bd1.jpg'),
(91944, 6442, 'Café Minamdang S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197029.mp4', 'http://timg.bdta.pro/images/3e4821904e8b1604bd7d0779c55bd0af.jpg'),
(91945, 6442, 'Café Minamdang S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197030.mp4', 'http://timg.bdta.pro/images/b2b8e04d181669d98a9494ed2ddc2609.jpg'),
(91946, 6442, 'Café Minamdang S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197031.mp4', 'http://timg.bdta.pro/images/ec81deb6fd227df52461c4938da503d1.jpg'),
(91947, 6442, 'Café Minamdang S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197032.mp4', 'http://timg.bdta.pro/images/e0f13a02ed50843c730ce500339598c4.jpg'),
(91948, 6442, 'Café Minamdang S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197033.mp4', 'http://timg.bdta.pro/images/1d207fcf45bcde85ecdea343963bdaff.jpg'),
(91949, 6442, 'Café Minamdang S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/197034.mp4', 'http://timg.bdta.pro/images/91c84291f6334b7044e3d61d805c38e7.jpg'),
(91950, 6442, 'Café Minamdang S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/197035.mp4', 'http://timg.bdta.pro/images/e091ae63fcc9eebf640e1051235bc89b.jpg'),
(91951, 6442, 'Café Minamdang S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/197036.mp4', 'http://timg.bdta.pro/images/6bb292a1ca61f0a3bd9fbf6baacf5d56.jpg'),
(91952, 6442, 'Café Minamdang S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/197037.mp4', 'http://timg.bdta.pro/images/59dca6d90cf923f36e86b3ed0babbad2.jpg'),
(91953, 6442, 'Café Minamdang S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/197038.mp4', 'http://timg.bdta.pro/images/de6542327a2063a12da07a421cc53f9e.jpg'),
(91954, 6442, 'Café Minamdang S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/197039.mp4', 'http://timg.bdta.pro/images/d6491308c8b19ca50217bca28e021563.jpg'),
(91955, 6442, 'Café Minamdang S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/197040.mp4', 'http://timg.bdta.pro/images/dfec105c12f7d55bc46403589441106c.jpg'),
(91956, 6442, 'Café Minamdang S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/197041.mp4', 'http://timg.bdta.pro/images/1c4ee87cd8235b203380f3c694c2bafc.jpg'),
(91957, 6442, 'Café Minamdang S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/197042.mp4', 'http://timg.bdta.pro/images/a0e5d4e41a0085462ee6d314268c4b24.jpg'),
(91958, 6442, 'Café Minamdang S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/197043.mp4', 'http://timg.bdta.pro/images/b01a87d57a3ff1b29f8e9ed405767f27.jpg'),
(91959, 6443, 'Candy: Uma História de Paixão e Crime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/197021.mp4', 'http://timg.bdta.pro/images/81768a6845358199f7690c418ad30260.jpg'),
(91960, 6443, 'Candy: Uma História de Paixão e Crime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197022.mp4', 'http://timg.bdta.pro/images/fe649c39c1a46115d4d07cecf6bb1abd.jpg'),
(91961, 6443, 'Candy: Uma História de Paixão e Crime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197023.mp4', 'http://timg.bdta.pro/images/b32808aaab6b0138af44bc984fb4553f.jpg'),
(91962, 6443, 'Candy: Uma História de Paixão e Crime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197024.mp4', 'http://timg.bdta.pro/images/a33f5de9acec63899b9ba84fd8d5e0fa.jpg'),
(91963, 6443, 'Candy: Uma História de Paixão e Crime S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197025.mp4', 'http://timg.bdta.pro/images/eab863423dfa9f0d15d99093bee58d0f.jpg'),
(91964, 6444, 'Como Sobreviver Entre Irmãos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196992.mp4', 'http://timg.bdta.pro/images/1e70fa30abf1c0d54da300e692631505.jpg'),
(91965, 6444, 'Como Sobreviver Entre Irmãos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196993.mp4', 'http://timg.bdta.pro/images/d5613b1a7e5ed97ba2a62308d208f18c.jpg'),
(91966, 6444, 'Como Sobreviver Entre Irmãos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196994.mp4', 'http://timg.bdta.pro/images/00dd1f22a180bdaccd052a8ad03a5b02.jpg'),
(91967, 6444, 'Como Sobreviver Entre Irmãos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196995.mp4', 'http://timg.bdta.pro/images/60e09d68ac91d0481557ec2918aae355.jpg'),
(91968, 6444, 'Como Sobreviver Entre Irmãos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196996.mp4', 'http://timg.bdta.pro/images/e28ac1994a426540a2d38eb6b9491dbf.jpg'),
(91969, 6444, 'Como Sobreviver Entre Irmãos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196997.mp4', 'http://timg.bdta.pro/images/056cf32d61715d6f3b719bf3c890b126.jpg'),
(91970, 6444, 'Como Sobreviver Entre Irmãos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196998.mp4', 'http://timg.bdta.pro/images/fcfa79dc9c97606c9fb6ab0b453ba83e.jpg'),
(91971, 6445, 'Como Sobreviver Entre Irmãos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196999.mp4', 'http://timg.bdta.pro/images/0caf677c81fc3e8948e086f4bf881a77.jpg'),
(91972, 6445, 'Como Sobreviver Entre Irmãos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/197000.mp4', 'http://timg.bdta.pro/images/32acd104760bd00471ca637d24f11f26.jpg'),
(91973, 6445, 'Como Sobreviver Entre Irmãos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/197001.mp4', 'http://timg.bdta.pro/images/01f7adc65800398fb2f3e184d44a4305.jpg'),
(91974, 6445, 'Como Sobreviver Entre Irmãos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/197002.mp4', 'http://timg.bdta.pro/images/17933cd8d4a20addb6775633962013d3.jpg'),
(91975, 6445, 'Como Sobreviver Entre Irmãos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/197003.mp4', 'http://timg.bdta.pro/images/817b08782279447a1cb588aeb7aeaabc.jpg'),
(91976, 6445, 'Como Sobreviver Entre Irmãos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/197004.mp4', 'http://timg.bdta.pro/images/3b7937e63ff5550d7bdd77fda0b95a21.jpg'),
(91977, 6445, 'Como Sobreviver Entre Irmãos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/197005.mp4', 'http://timg.bdta.pro/images/9fc5ff233a009210baeaea3b640c8794.jpg'),
(91978, 6445, 'Como Sobreviver Entre Irmãos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/197006.mp4', 'http://timg.bdta.pro/images/9b33c47664f00322cb44e11c05ca6a18.jpg'),
(91979, 6445, 'Como Sobreviver Entre Irmãos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/197007.mp4', 'http://timg.bdta.pro/images/8ba7dea8c565f9e73c7183c55dae0b36.jpg'),
(91980, 6445, 'Como Sobreviver Entre Irmãos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/197008.mp4', 'http://timg.bdta.pro/images/f356d7b7844e9f7994be9e45ee6247c2.jpg'),
(91981, 6445, 'Como Sobreviver Entre Irmãos S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/197009.mp4', 'http://timg.bdta.pro/images/8cc27a3b0a4900097582efa32a090812.jpg'),
(91982, 6445, 'Como Sobreviver Entre Irmãos S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/197010.mp4', 'http://timg.bdta.pro/images/d7c583d993256eecd842aed8f8d734f5.jpg'),
(91983, 6445, 'Como Sobreviver Entre Irmãos S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/197011.mp4', 'http://timg.bdta.pro/images/7f045a893cab4ed2cfcbc50b8e5fb618.jpg'),
(91984, 6445, 'Como Sobreviver Entre Irmãos S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/563417.mp4', 'http://gstaticontent.com/images/e571301d547093560a992db37927544f.jpg'),
(91985, 6445, 'Como Sobreviver Entre Irmãos S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/197013.mp4', 'http://gstaticontent.com/images/e571301d547093560a992db37927544f.jpg'),
(91986, 6445, 'Como Sobreviver Entre Irmãos S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/197014.mp4', 'http://gstaticontent.com/images/e571301d547093560a992db37927544f.jpg'),
(91987, 6445, 'Como Sobreviver Entre Irmãos S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/197015.mp4', 'http://gstaticontent.com/images/e571301d547093560a992db37927544f.jpg'),
(91988, 6445, 'Como Sobreviver Entre Irmãos S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/197016.mp4', 'http://gstaticontent.com/images/e571301d547093560a992db37927544f.jpg'),
(91989, 6445, 'Como Sobreviver Entre Irmãos S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/197017.mp4', 'http://gstaticontent.com/images/e571301d547093560a992db37927544f.jpg'),
(91990, 6445, 'Como Sobreviver Entre Irmãos S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/197018.mp4', 'http://gstaticontent.com/images/e571301d547093560a992db37927544f.jpg'),
(91991, 6445, 'Como Sobreviver Entre Irmãos S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/197019.mp4', 'http://gstaticontent.com/images/e571301d547093560a992db37927544f.jpg'),
(91992, 6445, 'Como Sobreviver Entre Irmãos S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/197020.mp4', 'http://gstaticontent.com/images/e571301d547093560a992db37927544f.jpg'),
(91993, 6446, 'Coração Suburbano S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196986.mp4', 'http://timg.bdta.pro/images/26b42b8b6b5201655cc09c5d49473214.jpg'),
(91994, 6446, 'Coração Suburbano S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196987.mp4', 'http://timg.bdta.pro/images/b0f890551915f015d15e9631eeaa35a9.jpg'),
(91995, 6446, 'Coração Suburbano S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196988.mp4', 'http://timg.bdta.pro/images/ea329fcca38a1e17de8b333ce4e77cbc.jpg'),
(91996, 6446, 'Coração Suburbano S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196989.mp4', 'http://timg.bdta.pro/images/3d04f51767dab4e40cfcafcf28e1dac2.jpg'),
(91997, 6446, 'Coração Suburbano S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196990.mp4', 'http://timg.bdta.pro/images/2c459d8df3159711eb10812e07ff0e6a.jpg'),
(91998, 6446, 'Coração Suburbano S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196991.mp4', 'http://timg.bdta.pro/images/27d198865b90448d17f2120fb34d5c2b.jpg'),
(91999, 6447, 'Esportes pelo Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196980.mp4', 'http://timg.bdta.pro/images/c7d8d98c83c1a236e10a2369427e68fa.jpg'),
(92000, 6447, 'Esportes pelo Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196981.mp4', 'http://timg.bdta.pro/images/4439695f90543de9c00e8a512d58fc28.jpg'),
(92001, 6447, 'Esportes pelo Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196982.mp4', 'http://timg.bdta.pro/images/0546241e3dd4fe87b3f6d3038455a203.jpg'),
(92002, 6447, 'Esportes pelo Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196983.mp4', 'http://timg.bdta.pro/images/9825ed691c91315e81e13421d0e7beeb.jpg'),
(92003, 6447, 'Esportes pelo Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196984.mp4', 'http://timg.bdta.pro/images/9664e844149a3c0aee93ad757cf4f138.jpg'),
(92004, 6447, 'Esportes pelo Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196985.mp4', 'http://timg.bdta.pro/images/9ae199d07ac3dac471a591f605d227fa.jpg'),
(92005, 6448, 'Filhotes Selvagens S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196972.mp4', 'http://timg.bdta.pro/images/ddf7e8339e5645fb0e66dbcaad0433a0.jpg'),
(92006, 6448, 'Filhotes Selvagens S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196973.mp4', 'http://timg.bdta.pro/images/2b7d26837ab2e99e60e6990837374fea.jpg'),
(92007, 6448, 'Filhotes Selvagens S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196974.mp4', 'http://timg.bdta.pro/images/56c602e43f93f9a0c187fb6e9873f850.jpg'),
(92008, 6448, 'Filhotes Selvagens S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196975.mp4', 'http://timg.bdta.pro/images/4db5d337db2bcace339de44c7d2fec4f.jpg'),
(92009, 6448, 'Filhotes Selvagens S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196976.mp4', 'http://timg.bdta.pro/images/038821c59767761644a9f7c2cb1c3852.jpg'),
(92010, 6448, 'Filhotes Selvagens S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196977.mp4', 'http://timg.bdta.pro/images/767edcf56375143a85bbf1d9a1ad2cb3.jpg'),
(92011, 6448, 'Filhotes Selvagens S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196978.mp4', 'http://timg.bdta.pro/images/b8a03e57b3ab6e250ed5cff89736dad3.jpg'),
(92012, 6448, 'Filhotes Selvagens S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196979.mp4', 'http://timg.bdta.pro/images/8735f2866e37a3bcfb54ace4b45600da.jpg'),
(92013, 6449, 'GameStop Contra Wall Street S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196969.mp4', 'http://gstaticontent.com/images/ae77bc19f22bc67b3dfdd3db6965b6f4.jpg'),
(92014, 6449, 'GameStop Contra Wall Street S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196970.mp4', 'http://gstaticontent.com/images/ae77bc19f22bc67b3dfdd3db6965b6f4.jpg'),
(92015, 6449, 'GameStop Contra Wall Street S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196971.mp4', 'http://gstaticontent.com/images/ae77bc19f22bc67b3dfdd3db6965b6f4.jpg'),
(92016, 6450, 'Kiddie Kai: O Universo das Artes Marciais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196963.mp4', 'http://gstaticontent.com/images/48d78c6340cfe2315b18084ba4a286e4.jpg'),
(92017, 6450, 'Kiddie Kai: O Universo das Artes Marciais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196964.mp4', 'http://gstaticontent.com/images/48d78c6340cfe2315b18084ba4a286e4.jpg'),
(92018, 6450, 'Kiddie Kai: O Universo das Artes Marciais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196965.mp4', 'http://gstaticontent.com/images/48d78c6340cfe2315b18084ba4a286e4.jpg'),
(92019, 6450, 'Kiddie Kai: O Universo das Artes Marciais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196966.mp4', 'http://gstaticontent.com/images/48d78c6340cfe2315b18084ba4a286e4.jpg'),
(92020, 6450, 'Kiddie Kai: O Universo das Artes Marciais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196967.mp4', 'http://gstaticontent.com/images/48d78c6340cfe2315b18084ba4a286e4.jpg'),
(92021, 6450, 'Kiddie Kai: O Universo das Artes Marciais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196968.mp4', 'http://gstaticontent.com/images/48d78c6340cfe2315b18084ba4a286e4.jpg'),
(92022, 6451, 'Limbo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196953.mp4', 'http://timg.bdta.pro/images/a0d40ec4eecc59748bb259982000c988.jpg'),
(92023, 6451, 'Limbo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196954.mp4', 'http://timg.bdta.pro/images/139a95705b5968b1d71ca3c4977b7ed2.jpg'),
(92024, 6451, 'Limbo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196955.mp4', 'http://timg.bdta.pro/images/a5c3f6964ce153bbd6f8a18fcd02db19.jpg'),
(92025, 6451, 'Limbo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196956.mp4', 'http://timg.bdta.pro/images/bcfb9790f5fd78456a904f39ea8c4f7d.jpg'),
(92026, 6451, 'Limbo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196957.mp4', 'http://timg.bdta.pro/images/4ef48c0e27fcc79619bb028580258d88.jpg'),
(92027, 6451, 'Limbo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196958.mp4', 'http://timg.bdta.pro/images/52c32018d88d128ec76dca43cff1b7d0.jpg'),
(92028, 6451, 'Limbo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196959.mp4', 'http://timg.bdta.pro/images/4f7c56950e26790f931d83dbae0fb7ec.jpg'),
(92029, 6451, 'Limbo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196960.mp4', 'http://timg.bdta.pro/images/7e18f83e4ac69239466b528302c5cf23.jpg'),
(92030, 6451, 'Limbo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196961.mp4', 'http://timg.bdta.pro/images/5d9f9be310ef63c32268eb366c60ddee.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(92031, 6451, 'Limbo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196962.mp4', 'http://timg.bdta.pro/images/deb6bb3a67adca66f9839c5f6ff6de26.jpg'),
(92032, 6452, 'O Coro: Sucesso Aqui Vou Eu! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196943.mp4', 'http://timg.bdta.pro/images/1311813cb4fdbedb3e7440d0c1860443.jpg'),
(92033, 6452, 'O Coro: Sucesso Aqui Vou Eu! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196944.mp4', 'http://timg.bdta.pro/images/85f659a64ec27fd7fe56d073004ccc9c.jpg'),
(92034, 6452, 'O Coro: Sucesso Aqui Vou Eu! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196945.mp4', 'http://timg.bdta.pro/images/972a4a23eafb4150398f3429fc8a7157.jpg'),
(92035, 6452, 'O Coro: Sucesso Aqui Vou Eu! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196946.mp4', 'http://timg.bdta.pro/images/bdedf71d6495d57f37da659b3462f00a.jpg'),
(92036, 6452, 'O Coro: Sucesso Aqui Vou Eu! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196947.mp4', 'http://timg.bdta.pro/images/b9d62314db7fd1ad764a8df6b667869b.jpg'),
(92037, 6452, 'O Coro: Sucesso Aqui Vou Eu! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196948.mp4', 'http://timg.bdta.pro/images/ac200bc0c46ab6dbab9f482d06241ee9.jpg'),
(92038, 6452, 'O Coro: Sucesso Aqui Vou Eu! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196949.mp4', 'http://timg.bdta.pro/images/dc66c765b2bbf204526c5945e50e17d0.jpg'),
(92039, 6452, 'O Coro: Sucesso Aqui Vou Eu! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196950.mp4', 'http://timg.bdta.pro/images/b2896b9f4a9581bcca355d98dca30fce.jpg'),
(92040, 6452, 'O Coro: Sucesso Aqui Vou Eu! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196951.mp4', 'http://timg.bdta.pro/images/f35a72f8174221f3cef9899ae3a92051.jpg'),
(92041, 6452, 'O Coro: Sucesso Aqui Vou Eu! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196952.mp4', 'http://timg.bdta.pro/images/379b594f1be364b6ed5ca1d1e96cdc9a.jpg'),
(92042, 6453, 'Scooby-Doo e Scooby-Loo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199462.mp4', 'http://timg.bdta.pro/images/a239812b4fa74bd3100c5b76d3a2e846.jpg'),
(92043, 6453, 'Scooby-Doo e Scooby-Loo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199463.mp4', 'http://timg.bdta.pro/images/c41e4562253aedf08e1c6e66389e58da.jpg'),
(92044, 6453, 'Scooby-Doo e Scooby-Loo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199464.mp4', 'http://timg.bdta.pro/images/33b837e984848149205ef9bab129d50b.jpg'),
(92045, 6453, 'Scooby-Doo e Scooby-Loo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199465.mp4', 'http://timg.bdta.pro/images/118113fee2e70928a25795e7bb0d20ca.jpg'),
(92046, 6453, 'Scooby-Doo e Scooby-Loo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199466.mp4', 'http://timg.bdta.pro/images/2877f7d32d83cd485b92263092e05ed4.jpg'),
(92047, 6453, 'Scooby-Doo e Scooby-Loo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199467.mp4', 'http://timg.bdta.pro/images/d27c37d3f767a6aa2d5ccf427246d773.jpg'),
(92048, 6453, 'Scooby-Doo e Scooby-Loo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199468.mp4', 'http://timg.bdta.pro/images/5511470368c55e5fc29665399da57572.jpg'),
(92049, 6453, 'Scooby-Doo e Scooby-Loo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199469.mp4', 'http://timg.bdta.pro/images/0c859fc7ec25e490dc2bd834db6bb332.jpg'),
(92050, 6453, 'Scooby-Doo e Scooby-Loo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199470.mp4', 'http://timg.bdta.pro/images/bde843812ceefda66f944dc192061ebd.jpg'),
(92051, 6453, 'Scooby-Doo e Scooby-Loo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199471.mp4', 'http://timg.bdta.pro/images/6605a10af0fd82507d03ef5fa02f9749.jpg'),
(92052, 6453, 'Scooby-Doo e Scooby-Loo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199472.mp4', 'http://timg.bdta.pro/images/366d51ffb0035df29167515cf0265e6b.jpg'),
(92053, 6453, 'Scooby-Doo e Scooby-Loo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199473.mp4', 'http://timg.bdta.pro/images/bf8d17d4f831d50f2b504432d05baddc.jpg'),
(92054, 6453, 'Scooby-Doo e Scooby-Loo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/199474.mp4', 'http://timg.bdta.pro/images/e45efddbf584ca2457d1fa4763d38778.jpg'),
(92055, 6453, 'Scooby-Doo e Scooby-Loo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/199475.mp4', 'http://timg.bdta.pro/images/4e860d43c15b11c65e75501072a876b6.jpg'),
(92056, 6453, 'Scooby-Doo e Scooby-Loo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/199476.mp4', 'http://timg.bdta.pro/images/41076382602b461a05e3f0e275ff5fa9.jpg'),
(92057, 6453, 'Scooby-Doo e Scooby-Loo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/199477.mp4', 'http://timg.bdta.pro/images/a27493cab16576df1dff4c1ac213d2a1.jpg'),
(92058, 6454, 'Scooby-Doo e Scooby-Loo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199478.mp4', 'http://timg.bdta.pro/images/e561654e6e2f7bbbfab7cd46c77277ad.jpg'),
(92059, 6454, 'Scooby-Doo e Scooby-Loo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199479.mp4', 'http://timg.bdta.pro/images/cba349860f1f0aa75b3b97c7e9f99c1f.jpg'),
(92060, 6454, 'Scooby-Doo e Scooby-Loo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199480.mp4', 'http://timg.bdta.pro/images/b17a8cf7acc32988ce49767b8f131fcd.jpg'),
(92061, 6454, 'Scooby-Doo e Scooby-Loo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199481.mp4', 'http://timg.bdta.pro/images/c1b8978391a01bb2bbfc5762e7bcc3c5.jpg'),
(92062, 6454, 'Scooby-Doo e Scooby-Loo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199482.mp4', 'http://timg.bdta.pro/images/a57a4a15b0828dda4977bc3a83eb52a2.jpg'),
(92063, 6454, 'Scooby-Doo e Scooby-Loo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199483.mp4', 'http://timg.bdta.pro/images/79bd8c04729ab5b5056f1cce3ba02614.jpg'),
(92064, 6454, 'Scooby-Doo e Scooby-Loo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199484.mp4', 'http://timg.bdta.pro/images/f94b918b9e0e1766ad00ab0ee086b390.jpg'),
(92065, 6454, 'Scooby-Doo e Scooby-Loo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199485.mp4', 'http://timg.bdta.pro/images/b3fa999c5ceb7605b10629bce3abacf6.jpg'),
(92066, 6454, 'Scooby-Doo e Scooby-Loo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199486.mp4', 'http://timg.bdta.pro/images/0dc4887236494ddd2069ce118c05b66e.jpg'),
(92067, 6454, 'Scooby-Doo e Scooby-Loo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199487.mp4', 'http://timg.bdta.pro/images/656df97db9bedcf2990c5be1e6cbc768.jpg'),
(92068, 6454, 'Scooby-Doo e Scooby-Loo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199488.mp4', 'http://timg.bdta.pro/images/1eca3d6ae8f8891bcb95c208ef4c3470.jpg'),
(92069, 6454, 'Scooby-Doo e Scooby-Loo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199489.mp4', 'http://timg.bdta.pro/images/0f2e0915386e0954dd03e5c1d9ee1e65.jpg'),
(92070, 6454, 'Scooby-Doo e Scooby-Loo S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/199490.mp4', 'http://timg.bdta.pro/images/8dd21e4a94256078198d1507de41050b.jpg'),
(92071, 6454, 'Scooby-Doo e Scooby-Loo S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/199491.mp4', 'http://timg.bdta.pro/images/81d1a98b0925910e24364100406433ce.jpg'),
(92072, 6454, 'Scooby-Doo e Scooby-Loo S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/199492.mp4', 'http://timg.bdta.pro/images/486664c54d8c131aa5cbbabe6b184aa3.jpg'),
(92073, 6454, 'Scooby-Doo e Scooby-Loo S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/199493.mp4', 'http://timg.bdta.pro/images/462447b76920520d52de2947a21dd95b.jpg'),
(92074, 6454, 'Scooby-Doo e Scooby-Loo S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/199494.mp4', 'http://timg.bdta.pro/images/d95e4214bed436de24a0e43a1a1076ac.jpg'),
(92075, 6454, 'Scooby-Doo e Scooby-Loo S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/199495.mp4', 'http://timg.bdta.pro/images/5a6fecbf84c0e930aa72788d3bb053ba.jpg'),
(92076, 6454, 'Scooby-Doo e Scooby-Loo S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/199496.mp4', 'http://timg.bdta.pro/images/25de90409172da6f0ebc48c4ba602996.jpg'),
(92077, 6454, 'Scooby-Doo e Scooby-Loo S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/199497.mp4', 'http://timg.bdta.pro/images/a1c205994f224fae73375fe56fc08384.jpg'),
(92078, 6454, 'Scooby-Doo e Scooby-Loo S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/199498.mp4', 'http://timg.bdta.pro/images/280bc98d7f720abff0907400cb4b6027.jpg'),
(92079, 6454, 'Scooby-Doo e Scooby-Loo S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/199499.mp4', 'http://timg.bdta.pro/images/1f86951224823652d96fcb946334ff11.jpg'),
(92080, 6454, 'Scooby-Doo e Scooby-Loo S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/199500.mp4', 'http://timg.bdta.pro/images/fe82cf80d398c9a26bbb54f6cfcd48f1.jpg'),
(92081, 6454, 'Scooby-Doo e Scooby-Loo S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/199501.mp4', 'http://timg.bdta.pro/images/e07d09faccb34cb98283e294bae1f870.jpg'),
(92082, 6454, 'Scooby-Doo e Scooby-Loo S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/199502.mp4', 'http://timg.bdta.pro/images/fe82cf80d398c9a26bbb54f6cfcd48f1.jpg'),
(92083, 6454, 'Scooby-Doo e Scooby-Loo S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/199503.mp4', 'http://timg.bdta.pro/images/a9497f36074570100c78b0f2921af779.jpg'),
(92084, 6454, 'Scooby-Doo e Scooby-Loo S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/199504.mp4', 'http://timg.bdta.pro/images/3e3825c93be0f10de54f42a3f210b205.jpg'),
(92085, 6454, 'Scooby-Doo e Scooby-Loo S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/199505.mp4', 'http://timg.bdta.pro/images/89b53a6dc3ddc1fc0792e933d0abf0f8.jpg'),
(92086, 6454, 'Scooby-Doo e Scooby-Loo S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/199506.mp4', 'http://timg.bdta.pro/images/3d84ad68df05b71cc6a3e61ebe5a08d2.jpg'),
(92087, 6454, 'Scooby-Doo e Scooby-Loo S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/199507.mp4', 'http://timg.bdta.pro/images/89b53a6dc3ddc1fc0792e933d0abf0f8.jpg'),
(92088, 6454, 'Scooby-Doo e Scooby-Loo S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/199508.mp4', 'http://timg.bdta.pro/images/ebadfe45964cf9788fae711f3fccadb1.jpg'),
(92089, 6454, 'Scooby-Doo e Scooby-Loo S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/199509.mp4', 'http://timg.bdta.pro/images/58bc01245f5461e52c4ee9ad8ebdd568.jpg'),
(92090, 6454, 'Scooby-Doo e Scooby-Loo S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/199510.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92091, 6454, 'Scooby-Doo e Scooby-Loo S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/199511.mp4', 'http://timg.bdta.pro/images/63563e98071fa6f00cb1e293be6b86da.jpg'),
(92092, 6454, 'Scooby-Doo e Scooby-Loo S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/199512.mp4', 'http://timg.bdta.pro/images/5b7e9619da6d3e5b89c5c4283b7a2651.jpg'),
(92093, 6454, 'Scooby-Doo e Scooby-Loo S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/199513.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92094, 6454, 'Scooby-Doo e Scooby-Loo S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/199514.mp4', 'http://timg.bdta.pro/images/63563e98071fa6f00cb1e293be6b86da.jpg'),
(92095, 6454, 'Scooby-Doo e Scooby-Loo S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/199515.mp4', 'http://timg.bdta.pro/images/0de89d737e010152b8a00f9bae971a1d.jpg'),
(92096, 6454, 'Scooby-Doo e Scooby-Loo S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/199516.mp4', 'http://timg.bdta.pro/images/63563e98071fa6f00cb1e293be6b86da.jpg'),
(92097, 6454, 'Scooby-Doo e Scooby-Loo S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/199517.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92098, 6454, 'Scooby-Doo e Scooby-Loo S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/199518.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92099, 6454, 'Scooby-Doo e Scooby-Loo S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/199519.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92100, 6455, 'Scooby-Doo e Scooby-Loo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199520.mp4', 'http://timg.bdta.pro/images/0649c369a867e46a303edc419e19e25e.jpg'),
(92101, 6455, 'Scooby-Doo e Scooby-Loo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199521.mp4', 'http://timg.bdta.pro/images/b8406d1955e34363227a159e14539f69.jpg'),
(92102, 6455, 'Scooby-Doo e Scooby-Loo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199522.mp4', 'http://timg.bdta.pro/images/c2b2d73afed0ae0dd064a8c6a2b1e3de.jpg'),
(92103, 6455, 'Scooby-Doo e Scooby-Loo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199523.mp4', 'http://timg.bdta.pro/images/643a4ed4e3a316912505913a71dbd7aa.jpg'),
(92104, 6455, 'Scooby-Doo e Scooby-Loo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199524.mp4', 'http://timg.bdta.pro/images/04ab0cbb46e9d4f3c1a0c8a7a2327be0.jpg'),
(92105, 6455, 'Scooby-Doo e Scooby-Loo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199525.mp4', 'http://timg.bdta.pro/images/f98be29be67a8f5f1634908c0619a2e8.jpg'),
(92106, 6455, 'Scooby-Doo e Scooby-Loo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199526.mp4', 'http://timg.bdta.pro/images/1d90d1ac3b7acb86d27d078e688592e6.jpg'),
(92107, 6455, 'Scooby-Doo e Scooby-Loo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199527.mp4', 'http://timg.bdta.pro/images/60c9114e6895a7216c29867a536f2791.jpg'),
(92108, 6455, 'Scooby-Doo e Scooby-Loo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199528.mp4', 'http://timg.bdta.pro/images/628fd54658ec276370622908c2fc6b64.jpg'),
(92109, 6455, 'Scooby-Doo e Scooby-Loo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199529.mp4', 'http://timg.bdta.pro/images/3f45149be7e05c8d1c432d41b3679555.jpg'),
(92110, 6455, 'Scooby-Doo e Scooby-Loo S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199530.mp4', 'http://timg.bdta.pro/images/d99aa2f14737ec89eb4cf64c69f43dc1.jpg'),
(92111, 6455, 'Scooby-Doo e Scooby-Loo S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199531.mp4', 'http://timg.bdta.pro/images/aafd05d0b40dfd8691031f6803132495.jpg'),
(92112, 6455, 'Scooby-Doo e Scooby-Loo S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/199532.mp4', 'http://timg.bdta.pro/images/b246729c14e095e6c936f98cf1e46c41.jpg'),
(92113, 6455, 'Scooby-Doo e Scooby-Loo S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/199533.mp4', 'http://timg.bdta.pro/images/2650253c33c1bef989d4f7ceb18984f0.jpg'),
(92114, 6455, 'Scooby-Doo e Scooby-Loo S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/199534.mp4', 'http://timg.bdta.pro/images/1544a2cb291fda06102369c866c716e0.jpg'),
(92115, 6455, 'Scooby-Doo e Scooby-Loo S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/199535.mp4', 'http://timg.bdta.pro/images/6ce4e0438bea080dc9d17d3941940c5d.jpg'),
(92116, 6455, 'Scooby-Doo e Scooby-Loo S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/199536.mp4', 'http://timg.bdta.pro/images/0fc1abb3b35358925e06c1e930e1d416.jpg'),
(92117, 6455, 'Scooby-Doo e Scooby-Loo S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/199537.mp4', 'http://timg.bdta.pro/images/8273f525710cc8a8904dd64bb4357ebd.jpg'),
(92118, 6456, 'Scooby-Doo e Scooby-Loo S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199538.mp4', 'http://timg.bdta.pro/images/6c876aaa253eba9346dfba59a896a374.jpg'),
(92119, 6456, 'Scooby-Doo e Scooby-Loo S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199539.mp4', 'http://timg.bdta.pro/images/97667a0364af94286d78f055ea8af61d.jpg'),
(92120, 6456, 'Scooby-Doo e Scooby-Loo S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199540.mp4', 'http://timg.bdta.pro/images/9c3c8d41ce8fbaf54839025a58e3157f.jpg'),
(92121, 6456, 'Scooby-Doo e Scooby-Loo S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199541.mp4', 'http://timg.bdta.pro/images/5fda9812ad2745ff6117ef630b6545fa.jpg'),
(92122, 6456, 'Scooby-Doo e Scooby-Loo S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199542.mp4', 'http://timg.bdta.pro/images/d6bf471db607fdcfb9b7dccd29418efd.jpg'),
(92123, 6456, 'Scooby-Doo e Scooby-Loo S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199543.mp4', 'http://timg.bdta.pro/images/70234752a467f242d8a083860e7a9f53.jpg'),
(92124, 6456, 'Scooby-Doo e Scooby-Loo S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199544.mp4', 'http://timg.bdta.pro/images/8906bb4641512bcba628951a656c80fd.jpg'),
(92125, 6456, 'Scooby-Doo e Scooby-Loo S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199545.mp4', 'http://timg.bdta.pro/images/785c3710ea5f06c7a85ab75c42e6afd8.jpg'),
(92126, 6456, 'Scooby-Doo e Scooby-Loo S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199546.mp4', 'http://timg.bdta.pro/images/7ff3a20909de65519522d765d634a7bf.jpg'),
(92127, 6456, 'Scooby-Doo e Scooby-Loo S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199547.mp4', 'http://timg.bdta.pro/images/404df6e2461798fec76c43ced454d462.jpg'),
(92128, 6456, 'Scooby-Doo e Scooby-Loo S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199548.mp4', 'http://timg.bdta.pro/images/12f514323bac595b3007c48593362d52.jpg'),
(92129, 6456, 'Scooby-Doo e Scooby-Loo S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199549.mp4', 'http://timg.bdta.pro/images/eef089394f48f4096b41392c6f48d5f7.jpg'),
(92130, 6456, 'Scooby-Doo e Scooby-Loo S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/199550.mp4', 'http://timg.bdta.pro/images/270e59d2600852c6fc4388d5d8ebd83c.jpg'),
(92131, 6456, 'Scooby-Doo e Scooby-Loo S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/199551.mp4', 'http://timg.bdta.pro/images/98fd62f41b71830c11fdb9b59441bf5c.jpg'),
(92132, 6456, 'Scooby-Doo e Scooby-Loo S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/199552.mp4', 'http://timg.bdta.pro/images/6eb45022cc150a612954cc8496428c8b.jpg'),
(92133, 6456, 'Scooby-Doo e Scooby-Loo S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/199553.mp4', 'http://timg.bdta.pro/images/12651cefc7207f4e2df43d61d912b5f2.jpg'),
(92134, 6456, 'Scooby-Doo e Scooby-Loo S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/199554.mp4', 'http://timg.bdta.pro/images/76a83e3c56b666aef174bdcbd1a1bc9a.jpg'),
(92135, 6456, 'Scooby-Doo e Scooby-Loo S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/199555.mp4', 'http://timg.bdta.pro/images/d0068ec601975415679ba94912907148.jpg'),
(92136, 6456, 'Scooby-Doo e Scooby-Loo S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/199556.mp4', 'http://timg.bdta.pro/images/a23b03dbfa06e54c0684ae230efd65fc.jpg'),
(92137, 6456, 'Scooby-Doo e Scooby-Loo S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/199557.mp4', 'http://timg.bdta.pro/images/e650035acc5bc1cd3ad14dc66d5b7f0e.jpg'),
(92138, 6456, 'Scooby-Doo e Scooby-Loo S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/199558.mp4', 'http://timg.bdta.pro/images/9c32c88e304da310371a1b4d623f2df8.jpg'),
(92139, 6456, 'Scooby-Doo e Scooby-Loo S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/199559.mp4', 'http://timg.bdta.pro/images/5069c0f41bec972536f6ebbebe789c6e.jpg'),
(92140, 6456, 'Scooby-Doo e Scooby-Loo S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/199560.mp4', 'http://timg.bdta.pro/images/b57c9b5047f32777d667faec4e158cb8.jpg'),
(92141, 6456, 'Scooby-Doo e Scooby-Loo S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/199561.mp4', 'http://timg.bdta.pro/images/f884678a6efd8524216ecbdeb74341aa.jpg'),
(92142, 6456, 'Scooby-Doo e Scooby-Loo S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/199562.mp4', 'http://timg.bdta.pro/images/513a8fe9670be0b72406f98d6637ef50.jpg'),
(92143, 6456, 'Scooby-Doo e Scooby-Loo S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/199563.mp4', 'http://timg.bdta.pro/images/ec218272ae5eddb37090e61767f2b4ad.jpg'),
(92144, 6456, 'Scooby-Doo e Scooby-Loo S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/199564.mp4', 'http://timg.bdta.pro/images/e4b199afa1f7a522f04da9279b512419.jpg'),
(92145, 6456, 'Scooby-Doo e Scooby-Loo S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/199565.mp4', 'http://timg.bdta.pro/images/1c7c7e7afef666dc89b0ce03439275a1.jpg'),
(92146, 6456, 'Scooby-Doo e Scooby-Loo S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/199566.mp4', 'http://timg.bdta.pro/images/aeb999029d1e12ffe95b3e2c5b59cf9f.jpg'),
(92147, 6456, 'Scooby-Doo e Scooby-Loo S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/199567.mp4', 'http://timg.bdta.pro/images/aeb999029d1e12ffe95b3e2c5b59cf9f.jpg'),
(92148, 6456, 'Scooby-Doo e Scooby-Loo S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/199568.mp4', 'http://timg.bdta.pro/images/3c2f9ab97c26bfc6db4a398277e22f1f.jpg'),
(92149, 6456, 'Scooby-Doo e Scooby-Loo S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/199569.mp4', 'http://timg.bdta.pro/images/72ce26ec5e83f976551f0a7fa2c04a3d.jpg'),
(92150, 6456, 'Scooby-Doo e Scooby-Loo S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/199570.mp4', 'http://timg.bdta.pro/images/071b54fd0d13f7cbeda0463d9aef25a5.jpg'),
(92151, 6456, 'Scooby-Doo e Scooby-Loo S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/199571.mp4', 'http://timg.bdta.pro/images/be3274f753ea0a48409092a95deda09d.jpg'),
(92152, 6456, 'Scooby-Doo e Scooby-Loo S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/199572.mp4', 'http://timg.bdta.pro/images/31ef208cdf196c8c8431b511a6c4f4f1.jpg'),
(92153, 6456, 'Scooby-Doo e Scooby-Loo S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/199573.mp4', 'http://timg.bdta.pro/images/6515c659c7ffbf519e93f17390259f40.jpg'),
(92154, 6456, 'Scooby-Doo e Scooby-Loo S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/199574.mp4', 'http://timg.bdta.pro/images/3dd6eeb31a420c76fb1ad964d3f9488a.jpg'),
(92155, 6456, 'Scooby-Doo e Scooby-Loo S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/199575.mp4', 'http://timg.bdta.pro/images/16430d7e393495b93567567dbcf7a470.jpg'),
(92156, 6456, 'Scooby-Doo e Scooby-Loo S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/199576.mp4', 'http://timg.bdta.pro/images/622943e7e9a743bde97bd29b330e4e3c.jpg'),
(92157, 6457, 'Scooby-Doo e Scooby-Loo S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199577.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92158, 6457, 'Scooby-Doo e Scooby-Loo S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199578.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92159, 6457, 'Scooby-Doo e Scooby-Loo S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199579.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92160, 6457, 'Scooby-Doo e Scooby-Loo S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199580.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92161, 6457, 'Scooby-Doo e Scooby-Loo S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199581.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92162, 6457, 'Scooby-Doo e Scooby-Loo S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199582.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92163, 6457, 'Scooby-Doo e Scooby-Loo S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199583.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92164, 6457, 'Scooby-Doo e Scooby-Loo S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199584.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92165, 6457, 'Scooby-Doo e Scooby-Loo S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199585.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92166, 6457, 'Scooby-Doo e Scooby-Loo S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199586.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92167, 6457, 'Scooby-Doo e Scooby-Loo S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199587.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92168, 6457, 'Scooby-Doo e Scooby-Loo S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199588.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92169, 6457, 'Scooby-Doo e Scooby-Loo S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/199589.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92170, 6457, 'Scooby-Doo e Scooby-Loo S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/199590.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92171, 6457, 'Scooby-Doo e Scooby-Loo S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/199591.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92172, 6457, 'Scooby-Doo e Scooby-Loo S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/199592.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92173, 6457, 'Scooby-Doo e Scooby-Loo S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/199593.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92174, 6457, 'Scooby-Doo e Scooby-Loo S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/199594.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92175, 6457, 'Scooby-Doo e Scooby-Loo S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/199595.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92176, 6457, 'Scooby-Doo e Scooby-Loo S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/199596.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92177, 6457, 'Scooby-Doo e Scooby-Loo S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/199597.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92178, 6457, 'Scooby-Doo e Scooby-Loo S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/199598.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92179, 6457, 'Scooby-Doo e Scooby-Loo S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/199599.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92180, 6457, 'Scooby-Doo e Scooby-Loo S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/199600.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92181, 6457, 'Scooby-Doo e Scooby-Loo S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/199601.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92182, 6457, 'Scooby-Doo e Scooby-Loo S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/199602.mp4', 'http://gstaticontent.com/images/2c4f5a91f31c009a5323c1c4c72d59cc.jpg'),
(92183, 6458, 'Vale Tudo com Tim Maia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196940.mp4', 'http://gstaticontent.com/images/a71d365298cc16be6ef2507b55664f21.jpg'),
(92184, 6458, 'Vale Tudo com Tim Maia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196941.mp4', 'http://gstaticontent.com/images/a71d365298cc16be6ef2507b55664f21.jpg'),
(92185, 6458, 'Vale Tudo com Tim Maia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196942.mp4', 'http://gstaticontent.com/images/a71d365298cc16be6ef2507b55664f21.jpg'),
(92186, 6459, 'Visitors S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196932.mp4', 'http://timg.bdta.pro/images/34610b9677e27a7fdf7e2ef48d8fd284.jpg'),
(92187, 6459, 'Visitors S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196933.mp4', 'http://timg.bdta.pro/images/4344a99bb109cae9dd4bff2952e21982.jpg'),
(92188, 6459, 'Visitors S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196934.mp4', 'http://timg.bdta.pro/images/f1a67a746c6d501e8c9cbf78c4aad434.jpg'),
(92189, 6459, 'Visitors S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196935.mp4', 'http://timg.bdta.pro/images/9439155beaf76404a73bdb106cd0881f.jpg'),
(92190, 6459, 'Visitors S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196936.mp4', 'http://timg.bdta.pro/images/11afd2a3d719301b6d639170c66af02b.jpg'),
(92191, 6459, 'Visitors S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196937.mp4', 'http://timg.bdta.pro/images/353eb3c3bd037323652d504c73fa56f1.jpg'),
(92192, 6459, 'Visitors S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196938.mp4', 'http://timg.bdta.pro/images/8e6c22fe4eaa2278e154c9c7ede9d24c.jpg'),
(92193, 6459, 'Visitors S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196939.mp4', 'http://timg.bdta.pro/images/ac13b40189de41d9e3f56a817d6d5f05.jpg'),
(92194, 6460, 'Lewis e Tolkien S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bPsyyI6Ia5aJhs5p8KMDYpIiupz.jpg'),
(92195, 6460, 'Lewis e Tolkien S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bPsyyI6Ia5aJhs5p8KMDYpIiupz.jpg'),
(92196, 6460, 'Lewis e Tolkien S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bPsyyI6Ia5aJhs5p8KMDYpIiupz.jpg'),
(92197, 6461, 'Bob\'s Burgers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196542.mp4', 'http://timg.bdta.pro/images/2cbb9e07d63ac6ee6ba9c5a5be74caaa.jpg'),
(92198, 6461, 'Bob\'s Burgers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196543.mp4', 'http://timg.bdta.pro/images/7af9e1602af1c63b589ccc25f83741a1.jpg'),
(92199, 6461, 'Bob\'s Burgers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196544.mp4', 'http://timg.bdta.pro/images/fb9f6b592d156acec956954772906397.jpg'),
(92200, 6461, 'Bob\'s Burgers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196545.mp4', 'http://timg.bdta.pro/images/de4e9cc1679b86d6027df9fe4b5b5e4d.jpg'),
(92201, 6461, 'Bob\'s Burgers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196546.mp4', 'http://timg.bdta.pro/images/b85d4c10b4ec4d5c689c4555bcd19ec4.jpg'),
(92202, 6461, 'Bob\'s Burgers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196547.mp4', 'http://timg.bdta.pro/images/de70e7dab9af27d65390b5c58270d1de.jpg'),
(92203, 6461, 'Bob\'s Burgers S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196548.mkv', 'http://timg.bdta.pro/images/81c0566aea839f28b1db421fc30bef95.jpg'),
(92204, 6461, 'Bob\'s Burgers S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196549.mp4', 'http://timg.bdta.pro/images/c20ffc958cabf7099bae7ea09b2396c9.jpg'),
(92205, 6461, 'Bob\'s Burgers S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196550.mkv', 'http://timg.bdta.pro/images/1ffef17ea7b4636d4bc1fc1993640f08.jpg'),
(92206, 6461, 'Bob\'s Burgers S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196551.mp4', 'http://timg.bdta.pro/images/3a51baa7ae5e9a80a20f14b34881096c.jpg'),
(92207, 6461, 'Bob\'s Burgers S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196552.mp4', 'http://timg.bdta.pro/images/fdcc51e569d5ad0de685ce35bf3ad9b3.jpg'),
(92208, 6461, 'Bob\'s Burgers S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196553.mp4', 'http://timg.bdta.pro/images/6bfb302a9a933908f2557638c34527f5.jpg'),
(92209, 6461, 'Bob\'s Burgers S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196554.mp4', 'http://timg.bdta.pro/images/91b5bbc83fbd721b978c9a510c4a6054.jpg'),
(92210, 6462, 'Bob\'s Burgers S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196555.mp4', 'http://timg.bdta.pro/images/c3d0d328598979aed23ece61a627caab.jpg'),
(92211, 6462, 'Bob\'s Burgers S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196556.mp4', 'http://timg.bdta.pro/images/c72b9f1d5b148c3050a90098991961eb.jpg'),
(92212, 6462, 'Bob\'s Burgers S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196557.mp4', 'http://timg.bdta.pro/images/280b84b110172accd6b63b583ca75e6b.jpg'),
(92213, 6462, 'Bob\'s Burgers S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196558.mp4', 'http://timg.bdta.pro/images/85e0ec92bfc7aaa884acbe0aaf93ea65.jpg'),
(92214, 6462, 'Bob\'s Burgers S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196559.mp4', 'http://timg.bdta.pro/images/b6fda7f3fb3d7cb6524553dd8a396efd.jpg'),
(92215, 6462, 'Bob\'s Burgers S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196560.mp4', 'http://timg.bdta.pro/images/f3e8afeeeafa77c51cff518abcaa916e.jpg'),
(92216, 6462, 'Bob\'s Burgers S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196561.mp4', 'http://timg.bdta.pro/images/b1b0f377d13b13e8cf2b9d978760c84c.jpg'),
(92217, 6462, 'Bob\'s Burgers S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196562.mp4', 'http://timg.bdta.pro/images/1a25bbbe39ccbb902a0454e831a1867d.jpg'),
(92218, 6462, 'Bob\'s Burgers S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196563.mp4', 'http://timg.bdta.pro/images/2b0f981cc86be84efbf426daba0b0578.jpg'),
(92219, 6463, 'Bob\'s Burgers S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196564.mp4', 'http://timg.bdta.pro/images/c32883ff7221d1d36df2802b9d04ffe0.jpg'),
(92220, 6463, 'Bob\'s Burgers S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196565.mp4', 'http://timg.bdta.pro/images/1cbeb2575989d7f26ba0f09b534499a4.jpg'),
(92221, 6463, 'Bob\'s Burgers S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196566.mp4', 'http://timg.bdta.pro/images/b02232b799d8a49665ef7f0b152efcba.jpg'),
(92222, 6463, 'Bob\'s Burgers S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196567.mp4', 'http://timg.bdta.pro/images/8e396780cef7ede4dc40196894aa984e.jpg'),
(92223, 6463, 'Bob\'s Burgers S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196568.mp4', 'http://timg.bdta.pro/images/82eefbc2d1e36cbd11f97dedc1006e38.jpg'),
(92224, 6463, 'Bob\'s Burgers S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196569.mp4', 'http://timg.bdta.pro/images/d8e6dba9e370efdf1aa6768d026fbe3b.jpg'),
(92225, 6463, 'Bob\'s Burgers S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196570.mp4', 'http://timg.bdta.pro/images/911d145723776e3a894a9eef88e568c4.jpg'),
(92226, 6463, 'Bob\'s Burgers S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196571.mp4', 'http://timg.bdta.pro/images/fe3680e4cb32cb6783ac924fce0591a3.jpg'),
(92227, 6463, 'Bob\'s Burgers S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196572.mp4', 'http://timg.bdta.pro/images/7227ea444ebb1867ae4a0848e52beb02.jpg'),
(92228, 6463, 'Bob\'s Burgers S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196573.mp4', 'http://timg.bdta.pro/images/bfa741b3e1f99ca608bdd75a3502e491.jpg'),
(92229, 6463, 'Bob\'s Burgers S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196574.mp4', 'http://timg.bdta.pro/images/1fc848572aa3af72c4eab4ffbe8f2715.jpg'),
(92230, 6463, 'Bob\'s Burgers S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196575.mp4', 'http://timg.bdta.pro/images/5275947a04e33dfa9c13e6887babbe5d.jpg'),
(92231, 6463, 'Bob\'s Burgers S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196576.mp4', 'http://timg.bdta.pro/images/e867df45eb046dd50f73f8963828035d.jpg'),
(92232, 6463, 'Bob\'s Burgers S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/196577.mp4', 'http://timg.bdta.pro/images/3d9229510131f2e5474b9328ad665ca3.jpg'),
(92233, 6463, 'Bob\'s Burgers S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/196578.mp4', 'http://timg.bdta.pro/images/aaa320694e81fe79861546ae27e94b76.jpg'),
(92234, 6463, 'Bob\'s Burgers S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/196579.mp4', 'http://timg.bdta.pro/images/d0c3558c15fd6aed963b62ae049b8141.jpg'),
(92235, 6463, 'Bob\'s Burgers S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/196580.mp4', 'http://timg.bdta.pro/images/7a78a9cb531337358b6d92a5131337af.jpg'),
(92236, 6463, 'Bob\'s Burgers S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/196581.mp4', 'http://timg.bdta.pro/images/b0f441e368e337512246c5fd85d61932.jpg'),
(92237, 6463, 'Bob\'s Burgers S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/196582.mp4', 'http://timg.bdta.pro/images/a2f9f217aa85c85f929fe1a8d0058364.jpg'),
(92238, 6463, 'Bob\'s Burgers S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/196583.mp4', 'http://timg.bdta.pro/images/76884dc6c57d892153acd0fbfe6ba03c.jpg'),
(92239, 6463, 'Bob\'s Burgers S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/196584.mp4', 'http://timg.bdta.pro/images/0f13ddcf05b916844dc8fbcbb388d4db.jpg'),
(92240, 6463, 'Bob\'s Burgers S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/196585.mp4', 'http://timg.bdta.pro/images/8a6be0be624c270e04fa129e37cd9737.jpg'),
(92241, 6463, 'Bob\'s Burgers S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/196586.mp4', 'http://timg.bdta.pro/images/d77044122b9ccee5d654bf9d9a13fb4f.jpg'),
(92242, 6464, 'Bob\'s Burgers S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196587.mp4', 'http://timg.bdta.pro/images/4554ab32dfe67924a428f3380243a749.jpg'),
(92243, 6464, 'Bob\'s Burgers S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196588.mp4', 'http://timg.bdta.pro/images/79a11d36971a5c47ec4476d87923564e.jpg'),
(92244, 6464, 'Bob\'s Burgers S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196589.mp4', 'http://timg.bdta.pro/images/4d2d397af826c5af0ac2f7e8bd797d5d.jpg'),
(92245, 6464, 'Bob\'s Burgers S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196590.mp4', 'http://timg.bdta.pro/images/57793a724adbb402cec92293a56cc6c3.jpg'),
(92246, 6464, 'Bob\'s Burgers S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196591.mp4', 'http://timg.bdta.pro/images/4d87399ad2b28131f11df0a413685de8.jpg'),
(92247, 6464, 'Bob\'s Burgers S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196592.mp4', 'http://timg.bdta.pro/images/c52cd77d51159e75d0769ae27c5d4051.jpg'),
(92248, 6464, 'Bob\'s Burgers S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196593.mp4', 'http://timg.bdta.pro/images/81c18c5bea5ededc1ae0e5557d1dd984.jpg'),
(92249, 6464, 'Bob\'s Burgers S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196594.mp4', 'http://timg.bdta.pro/images/922f3aef8e538eb7ef23fc7e0837693c.jpg'),
(92250, 6464, 'Bob\'s Burgers S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196595.mp4', 'http://timg.bdta.pro/images/e67348f126c8ce3d2c6cc5039c4bac0f.jpg'),
(92251, 6464, 'Bob\'s Burgers S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196596.mp4', 'http://timg.bdta.pro/images/100a1ee3c9ffe2795bd6509ba16e3777.jpg'),
(92252, 6464, 'Bob\'s Burgers S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196597.mp4', 'http://timg.bdta.pro/images/7ec18c92b6874d3c33f3012ad8b16fc9.jpg'),
(92253, 6464, 'Bob\'s Burgers S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196598.mp4', 'http://timg.bdta.pro/images/c6d8794b58634af7b2ec99eb9e8e4eef.jpg'),
(92254, 6464, 'Bob\'s Burgers S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196599.mp4', 'http://timg.bdta.pro/images/61daf82b9abdb4b98f5bdd82822396ec.jpg'),
(92255, 6464, 'Bob\'s Burgers S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/196600.mp4', 'http://timg.bdta.pro/images/a963acfd84189061dc73ac665e55c892.jpg'),
(92256, 6464, 'Bob\'s Burgers S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/196601.mp4', 'http://timg.bdta.pro/images/a0d8931f89265b3fb7ff988617fa6a29.jpg'),
(92257, 6464, 'Bob\'s Burgers S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/196602.mp4', 'http://timg.bdta.pro/images/3bbbae5e8d86b1fe9144cfdcb6cc513b.jpg'),
(92258, 6464, 'Bob\'s Burgers S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/196603.mp4', 'http://timg.bdta.pro/images/725645c83d90e5755627f5ab61202dbd.jpg'),
(92259, 6464, 'Bob\'s Burgers S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/196604.mp4', 'http://timg.bdta.pro/images/d1f91bd7df06bf47ef067516bdcda92e.jpg'),
(92260, 6464, 'Bob\'s Burgers S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/196605.mp4', 'http://timg.bdta.pro/images/1a3dc73efd5da7dd8d66b322fd6d7f20.jpg'),
(92261, 6464, 'Bob\'s Burgers S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/196606.mp4', 'http://timg.bdta.pro/images/752d1273913015151e3d57ebfa459a10.jpg'),
(92262, 6464, 'Bob\'s Burgers S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/196607.mp4', 'http://timg.bdta.pro/images/b26aeface4dab20b20bf77553dd3c942.jpg'),
(92263, 6464, 'Bob\'s Burgers S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/196608.mp4', 'http://timg.bdta.pro/images/57fd2050e23ef7f151bad15b17a0599b.jpg'),
(92264, 6465, 'Bob\'s Burgers S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196609.mp4', 'http://timg.bdta.pro/images/d4e05f9e4b9de0f95d51af9c7e767258.jpg'),
(92265, 6465, 'Bob\'s Burgers S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196610.mp4', 'http://timg.bdta.pro/images/4aac7ff4e28c6df0790ed674bfb507f6.jpg'),
(92266, 6465, 'Bob\'s Burgers S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196611.mp4', 'http://timg.bdta.pro/images/2abe9bb4d500762a623fa55b45f1c52c.jpg'),
(92267, 6465, 'Bob\'s Burgers S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196612.mp4', 'http://timg.bdta.pro/images/fc7db463759460f61c8419cc8ca65d04.jpg'),
(92268, 6465, 'Bob\'s Burgers S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196613.mp4', 'http://timg.bdta.pro/images/b563d67a8064eefdd33cd026a6c83de3.jpg'),
(92269, 6465, 'Bob\'s Burgers S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196614.mp4', 'http://timg.bdta.pro/images/b415d4373c64414ca8c7c5ec13a02aff.jpg'),
(92270, 6465, 'Bob\'s Burgers S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196615.mp4', 'http://timg.bdta.pro/images/32fb79180d30feed3ea13c950018fce7.jpg'),
(92271, 6465, 'Bob\'s Burgers S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196616.mp4', 'http://timg.bdta.pro/images/b38cdf9e540a33ba7652e2937652f157.jpg'),
(92272, 6465, 'Bob\'s Burgers S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196617.mp4', 'http://timg.bdta.pro/images/8a3cada8e36727407e66ae6de02c9bc8.jpg'),
(92273, 6465, 'Bob\'s Burgers S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196618.mp4', 'http://timg.bdta.pro/images/7e96dfacffc7b867b557437955590523.jpg'),
(92274, 6465, 'Bob\'s Burgers S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196619.mp4', 'http://timg.bdta.pro/images/c9ba768eba996c6a2cfff2713394234d.jpg'),
(92275, 6465, 'Bob\'s Burgers S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196620.mp4', 'http://timg.bdta.pro/images/3568bdda951b16c6c8fa6a9a68e2ec89.jpg'),
(92276, 6465, 'Bob\'s Burgers S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196621.mp4', 'http://timg.bdta.pro/images/c1865806b21852cdee19fe644baba6bc.jpg'),
(92277, 6465, 'Bob\'s Burgers S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/196622.mp4', 'http://timg.bdta.pro/images/d23554262d9b4370e5a183757d61578b.jpg'),
(92278, 6465, 'Bob\'s Burgers S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/196623.mp4', 'http://timg.bdta.pro/images/b4f19fb54efae8d2941ab96e68fa06eb.jpg'),
(92279, 6465, 'Bob\'s Burgers S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/196624.mp4', 'http://timg.bdta.pro/images/32f1b03e25d544d3b0ead2d46cb6efaf.jpg'),
(92280, 6465, 'Bob\'s Burgers S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/196625.mp4', 'http://timg.bdta.pro/images/127b07ca45a2e347021907e37398db3e.jpg'),
(92281, 6465, 'Bob\'s Burgers S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/196626.mp4', 'http://timg.bdta.pro/images/531c2bf7a6ef56052a82451e096a6f80.jpg'),
(92282, 6465, 'Bob\'s Burgers S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/196627.mp4', 'http://timg.bdta.pro/images/086c478e7ead0218fe9b887b2e7e154d.jpg'),
(92283, 6465, 'Bob\'s Burgers S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/196628.mp4', 'http://timg.bdta.pro/images/5d4b2b98319596c787c53cc79e991fb8.jpg'),
(92284, 6465, 'Bob\'s Burgers S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/196629.mp4', 'http://timg.bdta.pro/images/4ef0c3189f9f58c5f4b978ce74127473.jpg'),
(92285, 6466, 'Bob\'s Burgers S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196630.mp4', 'http://timg.bdta.pro/images/cfb3dced5dd9cca659f7679e574d075f.jpg'),
(92286, 6466, 'Bob\'s Burgers S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196631.mp4', 'http://timg.bdta.pro/images/56c619c41b01211367cc5454b6af3a42.jpg'),
(92287, 6466, 'Bob\'s Burgers S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196632.mp4', 'http://timg.bdta.pro/images/1a165d200cb4cc0ea737df1e0015813a.jpg'),
(92288, 6466, 'Bob\'s Burgers S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196633.mp4', 'http://timg.bdta.pro/images/01a00d639e551df501e3ddb09e055991.jpg'),
(92289, 6466, 'Bob\'s Burgers S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196634.mp4', 'http://timg.bdta.pro/images/2bd1f8216467295db8db50f9af5618bd.jpg'),
(92290, 6466, 'Bob\'s Burgers S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196635.mp4', 'http://timg.bdta.pro/images/aa81fee55b47f787badebb9a834e17cb.jpg'),
(92291, 6466, 'Bob\'s Burgers S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196636.mp4', 'http://timg.bdta.pro/images/1ac16d14b9dab0efc922254b27c3e537.jpg'),
(92292, 6466, 'Bob\'s Burgers S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196637.mp4', 'http://timg.bdta.pro/images/924b72f42027482650e1f2c4253d4418.jpg'),
(92293, 6466, 'Bob\'s Burgers S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196638.mp4', 'http://timg.bdta.pro/images/41a5f655d96cd3ee0aa8e87fcc31d857.jpg'),
(92294, 6466, 'Bob\'s Burgers S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196639.mp4', 'http://timg.bdta.pro/images/7298f33cb8d768499d5863c66846759a.jpg'),
(92295, 6466, 'Bob\'s Burgers S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196640.mp4', 'http://timg.bdta.pro/images/65f1db813e8702889ea47193f0e26536.jpg'),
(92296, 6466, 'Bob\'s Burgers S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196641.mp4', 'http://timg.bdta.pro/images/735978865e189a6d751568a3373e5fb1.jpg'),
(92297, 6466, 'Bob\'s Burgers S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196642.mp4', 'http://timg.bdta.pro/images/929d871226a154b74e1fbf10f9e3cb24.jpg'),
(92298, 6466, 'Bob\'s Burgers S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/196643.mp4', 'http://timg.bdta.pro/images/21e832dc6fa2d9ef2f82ca6bd605226b.jpg'),
(92299, 6466, 'Bob\'s Burgers S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/196644.mp4', 'http://timg.bdta.pro/images/6a496a8241edb4c1d3166e2871efadbd.jpg'),
(92300, 6466, 'Bob\'s Burgers S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/196645.mp4', 'http://timg.bdta.pro/images/2e517ab26c3c69cecbfa26ac65de821a.jpg'),
(92301, 6466, 'Bob\'s Burgers S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/196646.mp4', 'http://timg.bdta.pro/images/ec28d547f8c3189ca9e3135ffb5441db.jpg'),
(92302, 6466, 'Bob\'s Burgers S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/196647.mp4', 'http://timg.bdta.pro/images/3592cb2df4b67496da7e2b29db3d5ac2.jpg'),
(92303, 6466, 'Bob\'s Burgers S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/196648.mp4', 'http://timg.bdta.pro/images/137ef0db7ec6bdce7607f852aba1625d.jpg'),
(92304, 6467, 'Bob\'s Burgers S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196649.mp4', 'http://timg.bdta.pro/images/c5a237197f3a2bae1c196a723e63c3d6.jpg'),
(92305, 6467, 'Bob\'s Burgers S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196650.mp4', 'http://timg.bdta.pro/images/068cf523f122bab6d2d128adf844610f.jpg'),
(92306, 6467, 'Bob\'s Burgers S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196651.mp4', 'http://timg.bdta.pro/images/0591b1f87567e355ee35c49dca2cdeb9.jpg'),
(92307, 6467, 'Bob\'s Burgers S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196652.mp4', 'http://timg.bdta.pro/images/361ac00ed5e0023b2054a12ddc50ceb6.jpg'),
(92308, 6467, 'Bob\'s Burgers S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196653.mp4', 'http://timg.bdta.pro/images/a513c4af0e69c4f9660d913999b2844d.jpg'),
(92309, 6467, 'Bob\'s Burgers S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196654.mp4', 'http://timg.bdta.pro/images/29dfbfe76a23862bd276b28ada82a73e.jpg'),
(92310, 6467, 'Bob\'s Burgers S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196655.mp4', 'http://timg.bdta.pro/images/73345c153794f8eab4209830382b9aba.jpg'),
(92311, 6467, 'Bob\'s Burgers S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196656.mp4', 'http://timg.bdta.pro/images/fb6a4f18bc0bacb7eefb96893e257e91.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(92312, 6467, 'Bob\'s Burgers S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196657.mp4', 'http://timg.bdta.pro/images/7db05eee3d96846c9b037bb04e232e8e.jpg'),
(92313, 6467, 'Bob\'s Burgers S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196658.mp4', 'http://timg.bdta.pro/images/e6704940fcc63d47e8f2ec2361e64273.jpg'),
(92314, 6467, 'Bob\'s Burgers S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196659.mp4', 'http://timg.bdta.pro/images/8c9fb83639613b7b873ec1c9fac4111b.jpg'),
(92315, 6467, 'Bob\'s Burgers S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196660.mp4', 'http://timg.bdta.pro/images/f030e276de9d2e14d3fdfb5038f3ab58.jpg'),
(92316, 6467, 'Bob\'s Burgers S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196661.mp4', 'http://timg.bdta.pro/images/a3349d60394f85506ea765cb2f3307b2.jpg'),
(92317, 6467, 'Bob\'s Burgers S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/196662.mp4', 'http://timg.bdta.pro/images/325d37250eb9e2f5a8efb3b3a3d4bf0f.jpg'),
(92318, 6467, 'Bob\'s Burgers S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/196663.mp4', 'http://timg.bdta.pro/images/c106c082d4950b93a4c166ad75da12c6.jpg'),
(92319, 6467, 'Bob\'s Burgers S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/196664.mp4', 'http://timg.bdta.pro/images/f93174a748fd6e65e644a244eb664538.jpg'),
(92320, 6467, 'Bob\'s Burgers S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/196665.mp4', 'http://timg.bdta.pro/images/b718f2462420ca8932ffed404bc07bdd.jpg'),
(92321, 6467, 'Bob\'s Burgers S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/196666.mp4', 'http://timg.bdta.pro/images/96269b38947036b9071e0aa7cdfcb0a5.jpg'),
(92322, 6467, 'Bob\'s Burgers S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/196667.mp4', 'http://timg.bdta.pro/images/004dc4abd28f13137f140fced1568e21.jpg'),
(92323, 6467, 'Bob\'s Burgers S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/196668.mp4', 'http://timg.bdta.pro/images/97821f258dc0589a58c0fb7a4a3d84b7.jpg'),
(92324, 6467, 'Bob\'s Burgers S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/196669.mp4', 'http://timg.bdta.pro/images/6c4a3cfe0ace913f82117c016db47171.jpg'),
(92325, 6467, 'Bob\'s Burgers S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/196670.mp4', 'http://timg.bdta.pro/images/2c1d251a69d1b6245035db8067fdcb48.jpg'),
(92326, 6468, 'Bob\'s Burgers S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196671.mp4', 'http://timg.bdta.pro/images/ad6b704204d8eafa87a6c464fe85f5e0.jpg'),
(92327, 6468, 'Bob\'s Burgers S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196672.mp4', 'http://timg.bdta.pro/images/44de9f80e328f9da1422ad5cf2106b60.jpg'),
(92328, 6468, 'Bob\'s Burgers S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196673.mp4', 'http://timg.bdta.pro/images/14dfcf85946211632874f261f0a720d3.jpg'),
(92329, 6468, 'Bob\'s Burgers S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196674.mp4', 'http://timg.bdta.pro/images/8e6b971852ee1989eea7f76ed76fe2ee.jpg'),
(92330, 6468, 'Bob\'s Burgers S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196675.mp4', 'http://timg.bdta.pro/images/af522c394b916f71e7c055057bd95f55.jpg'),
(92331, 6468, 'Bob\'s Burgers S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196676.mp4', 'http://timg.bdta.pro/images/6d6d0cdd9a8890b13ff329ee7c372501.jpg'),
(92332, 6468, 'Bob\'s Burgers S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196677.mp4', 'http://timg.bdta.pro/images/316738964d5f6c3c6d045b00ee4b0a0b.jpg'),
(92333, 6468, 'Bob\'s Burgers S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196678.mp4', 'http://timg.bdta.pro/images/27621f154301b63230b4be918c419a8c.jpg'),
(92334, 6468, 'Bob\'s Burgers S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196679.mp4', 'http://timg.bdta.pro/images/01cbac424f2ac645019a7575edaaf17f.jpg'),
(92335, 6468, 'Bob\'s Burgers S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196680.mp4', 'http://timg.bdta.pro/images/cde15b5c09db13dde2274d58e5789841.jpg'),
(92336, 6468, 'Bob\'s Burgers S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196681.mp4', 'http://timg.bdta.pro/images/f4be8507f019e1f3e11107b2f2a932f4.jpg'),
(92337, 6468, 'Bob\'s Burgers S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196682.mp4', 'http://timg.bdta.pro/images/0d8a9ecb7f5277229fde7e63d264c867.jpg'),
(92338, 6468, 'Bob\'s Burgers S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196683.mp4', 'http://timg.bdta.pro/images/e990a9209d085412f88c5fbec80d64d8.jpg'),
(92339, 6468, 'Bob\'s Burgers S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/196684.mp4', 'http://timg.bdta.pro/images/c4df92de07402bcca3e188a4e0d9f793.jpg'),
(92340, 6468, 'Bob\'s Burgers S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/196685.mp4', 'http://timg.bdta.pro/images/ae17c5c0d9bff76bcfcac47cad19da90.jpg'),
(92341, 6468, 'Bob\'s Burgers S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/196686.mp4', 'http://timg.bdta.pro/images/a91ff96724a6ce4dfd7fb76a6c37e571.jpg'),
(92342, 6468, 'Bob\'s Burgers S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/196687.mp4', 'http://timg.bdta.pro/images/e237933caeb04a596fad57e156e729ac.jpg'),
(92343, 6468, 'Bob\'s Burgers S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/196688.mp4', 'http://timg.bdta.pro/images/a4f4adf4b6701e4e2205f3276678aab4.jpg'),
(92344, 6468, 'Bob\'s Burgers S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/196689.mp4', 'http://timg.bdta.pro/images/fbe9ee311eec75a594cb8087160b0171.jpg'),
(92345, 6468, 'Bob\'s Burgers S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/196690.mp4', 'http://timg.bdta.pro/images/7827d457677501add0a152f947cdc83d.jpg'),
(92346, 6468, 'Bob\'s Burgers S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/196691.mp4', 'http://timg.bdta.pro/images/ac2cc7aba39d74c870c50f5e959b2513.jpg'),
(92347, 6469, 'Bob\'s Burgers S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196692.mp4', 'http://timg.bdta.pro/images/ea812d63b20fd18fcd87c75ed1931c91.jpg'),
(92348, 6469, 'Bob\'s Burgers S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196693.mp4', 'http://timg.bdta.pro/images/4f75089296785a0718d522b3ec960fdb.jpg'),
(92349, 6469, 'Bob\'s Burgers S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196694.mp4', 'http://timg.bdta.pro/images/da8247e0fd5c149d2e0d4794982925b1.jpg'),
(92350, 6469, 'Bob\'s Burgers S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196695.mp4', 'http://timg.bdta.pro/images/ead20af0aee52410e1a3a60fd45364f6.jpg'),
(92351, 6469, 'Bob\'s Burgers S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196696.mp4', 'http://timg.bdta.pro/images/58e2fa2ab7e54dca645b411dd3112339.jpg'),
(92352, 6469, 'Bob\'s Burgers S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196697.mp4', 'http://timg.bdta.pro/images/96f73e939cc036ea601bfe87d44a0abb.jpg'),
(92353, 6469, 'Bob\'s Burgers S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196698.mp4', 'http://timg.bdta.pro/images/08447e526aec35eb272ae0a2b179a874.jpg'),
(92354, 6469, 'Bob\'s Burgers S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196699.mp4', 'http://timg.bdta.pro/images/8ab02f8f91f8163424a99161526a9fd7.jpg'),
(92355, 6469, 'Bob\'s Burgers S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196700.mp4', 'http://timg.bdta.pro/images/f305e1be9501f4e4880e936a8955980a.jpg'),
(92356, 6469, 'Bob\'s Burgers S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196701.mp4', 'http://timg.bdta.pro/images/74bfdd2b264a58fd3b76df4c34339bc2.jpg'),
(92357, 6469, 'Bob\'s Burgers S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196702.mp4', 'http://timg.bdta.pro/images/55be525c7ed19a38e7e554c5aa7f691f.jpg'),
(92358, 6469, 'Bob\'s Burgers S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196703.mp4', 'http://timg.bdta.pro/images/27e860ef8405287a305f1567aafd374c.jpg'),
(92359, 6469, 'Bob\'s Burgers S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196704.mp4', 'http://timg.bdta.pro/images/00aef5cc52ef86204f44a5b8ef81e28e.jpg'),
(92360, 6469, 'Bob\'s Burgers S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/196705.mp4', 'http://timg.bdta.pro/images/261e70755dd68d2766e96a840587c8b3.jpg'),
(92361, 6469, 'Bob\'s Burgers S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/196706.mp4', 'http://timg.bdta.pro/images/e9c1d9493975160425b0679d9b396be4.jpg'),
(92362, 6469, 'Bob\'s Burgers S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/196707.mp4', 'http://timg.bdta.pro/images/9b9659cc09e5d4b8b61dbd180abc8a03.jpg'),
(92363, 6469, 'Bob\'s Burgers S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/196708.mp4', 'http://timg.bdta.pro/images/07acd2b348b3a51138d47a2c9e6b1b23.jpg'),
(92364, 6469, 'Bob\'s Burgers S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/196709.mp4', 'http://timg.bdta.pro/images/779a1560d4bb22edeb95c1c39fdeae9c.jpg'),
(92365, 6469, 'Bob\'s Burgers S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/196710.mp4', 'http://timg.bdta.pro/images/2ff09dedd42f58f9c1b3c24e5e50e7aa.jpg'),
(92366, 6469, 'Bob\'s Burgers S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/196711.mp4', 'http://timg.bdta.pro/images/8a8a5f5acb246c3082b13d844b698419.jpg'),
(92367, 6469, 'Bob\'s Burgers S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/196712.mp4', 'http://timg.bdta.pro/images/3ad4b7414525274afce4b867d598fca6.jpg'),
(92368, 6469, 'Bob\'s Burgers S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/196713.mp4', 'http://timg.bdta.pro/images/7391532be4459349eebc8c77f795c416.jpg'),
(92369, 6470, 'Bob\'s Burgers S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196714.mp4', 'http://timg.bdta.pro/images/f7840638788e3da76e6546cb21c6c8f4.jpg'),
(92370, 6470, 'Bob\'s Burgers S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196715.mp4', 'http://timg.bdta.pro/images/1d1de47b51ba3b2464239fc66b28205a.jpg'),
(92371, 6470, 'Bob\'s Burgers S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196716.mp4', 'http://timg.bdta.pro/images/818672fe32b6181d85428152aa0365fe.jpg'),
(92372, 6470, 'Bob\'s Burgers S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196717.mp4', 'http://timg.bdta.pro/images/93bf7182e4cd25758d7a377ec7fb7bf6.jpg'),
(92373, 6470, 'Bob\'s Burgers S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196718.mp4', 'http://timg.bdta.pro/images/697451c455b2d0fb65bc5a4429549379.jpg'),
(92374, 6470, 'Bob\'s Burgers S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196719.mp4', 'http://timg.bdta.pro/images/06bc0806ab7e69256b0f7743b3f2643b.jpg'),
(92375, 6470, 'Bob\'s Burgers S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196720.mp4', 'http://timg.bdta.pro/images/94a8dce2ef85e748e4ffe022c61bd232.jpg'),
(92376, 6470, 'Bob\'s Burgers S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196721.mp4', 'http://timg.bdta.pro/images/d5ccd1de505181822701ddc945fddf0b.jpg'),
(92377, 6470, 'Bob\'s Burgers S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196722.mp4', 'http://timg.bdta.pro/images/abece2169b343f9a1fce1190d06c1e20.jpg'),
(92378, 6470, 'Bob\'s Burgers S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196723.mp4', 'http://timg.bdta.pro/images/4451b9e2eeb1fb69588626204bc2ded6.jpg'),
(92379, 6470, 'Bob\'s Burgers S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196724.mp4', 'http://timg.bdta.pro/images/d9a2e14ee5ebdb96dea3220e5f4fa112.jpg'),
(92380, 6470, 'Bob\'s Burgers S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196725.mp4', 'http://timg.bdta.pro/images/7034105e6f812a1b7d8f1e4a916bd886.jpg'),
(92381, 6470, 'Bob\'s Burgers S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196726.mp4', 'http://timg.bdta.pro/images/7104d5eb2c68eb9349f0a55cc56b99ed.jpg'),
(92382, 6470, 'Bob\'s Burgers S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/196727.mp4', 'http://timg.bdta.pro/images/c5cb2144fe5c986a96733e346be14d38.jpg'),
(92383, 6470, 'Bob\'s Burgers S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/196728.mp4', 'http://timg.bdta.pro/images/b440b5b00b151fb66ea15118e48a2fc9.jpg'),
(92384, 6470, 'Bob\'s Burgers S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/196729.mp4', 'http://timg.bdta.pro/images/cb89c2c878eb39b2d3bd2fc8630b74a8.jpg'),
(92385, 6470, 'Bob\'s Burgers S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/196730.mp4', 'http://timg.bdta.pro/images/59a3a7edadc6e369a8205f1fdda90c89.jpg'),
(92386, 6470, 'Bob\'s Burgers S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/196731.mp4', 'http://timg.bdta.pro/images/5465daba824170e2b5e0d0aa47c2e603.jpg'),
(92387, 6470, 'Bob\'s Burgers S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/196732.mp4', 'http://timg.bdta.pro/images/92c198e50041231b31c6cf7dce501d76.jpg'),
(92388, 6470, 'Bob\'s Burgers S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/196733.mp4', 'http://timg.bdta.pro/images/277a7c6b1b3486668cb90a21e081ea00.jpg'),
(92389, 6470, 'Bob\'s Burgers S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/196734.mp4', 'http://timg.bdta.pro/images/955677143ea688ae93f805838bba9e66.jpg'),
(92390, 6470, 'Bob\'s Burgers S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/196735.mp4', 'http://timg.bdta.pro/images/a03c567574fb5cb557ed27372ceb8b27.jpg'),
(92391, 6471, 'Bob\'s Burgers S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196736.mp4', 'http://timg.bdta.pro/images/da774e96095137564bd67679c29a14fb.jpg'),
(92392, 6471, 'Bob\'s Burgers S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196737.mp4', 'http://timg.bdta.pro/images/dd90d51409e7c7288479d578fb5c7852.jpg'),
(92393, 6471, 'Bob\'s Burgers S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196738.mp4', 'http://timg.bdta.pro/images/fe24d3767192acbb5e2a50181fba49bd.jpg'),
(92394, 6471, 'Bob\'s Burgers S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196739.mp4', 'http://timg.bdta.pro/images/4261cebd3f86806d3286899553756170.jpg'),
(92395, 6471, 'Bob\'s Burgers S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196740.mp4', 'http://timg.bdta.pro/images/a75e8441f5002f44901ad32a6dbbc0db.jpg'),
(92396, 6471, 'Bob\'s Burgers S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196741.mp4', 'http://timg.bdta.pro/images/8ab0d754bf4a2e60abb6a870238b3d12.jpg'),
(92397, 6471, 'Bob\'s Burgers S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196742.mp4', 'http://timg.bdta.pro/images/ba7d1e2106a8e908d08e4d0a9a701ba8.jpg'),
(92398, 6471, 'Bob\'s Burgers S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196743.mp4', 'http://timg.bdta.pro/images/f65527cc8962a3d2cff77484ea310b81.jpg'),
(92399, 6471, 'Bob\'s Burgers S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196744.mp4', 'http://timg.bdta.pro/images/8adc0985ea41423803517c208c7e3213.jpg'),
(92400, 6471, 'Bob\'s Burgers S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196745.mp4', 'http://timg.bdta.pro/images/0edd6fb8db467123ab1bedec5cacf5a0.jpg'),
(92401, 6471, 'Bob\'s Burgers S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196746.mp4', 'http://timg.bdta.pro/images/2953ce17373e73d002becef2aaaabc4c.jpg'),
(92402, 6471, 'Bob\'s Burgers S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196747.mp4', 'http://timg.bdta.pro/images/db8e27bd7e33d0b391189dede1eebc3c.jpg'),
(92403, 6471, 'Bob\'s Burgers S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196748.mp4', 'http://timg.bdta.pro/images/81d8c35eee07e0ba265a1ac11b63dcda.jpg'),
(92404, 6471, 'Bob\'s Burgers S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/196749.mp4', 'http://timg.bdta.pro/images/0a5743dab731a38bfca234bb879e7560.jpg'),
(92405, 6471, 'Bob\'s Burgers S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/196750.mp4', 'http://timg.bdta.pro/images/4d22dc6137ee1cddb881ab48e6f6a8a4.jpg'),
(92406, 6471, 'Bob\'s Burgers S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/196751.mp4', 'http://timg.bdta.pro/images/484ef63dd9bcc94fe49e5850a8165dd4.jpg'),
(92407, 6471, 'Bob\'s Burgers S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/196752.mp4', 'http://timg.bdta.pro/images/5614962ea6d0631a1caa8883302a23ca.jpg'),
(92408, 6471, 'Bob\'s Burgers S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/196753.mp4', 'http://timg.bdta.pro/images/9ac77c01eb170ccaf3920114ef33d844.jpg'),
(92409, 6471, 'Bob\'s Burgers S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/196754.mp4', 'http://timg.bdta.pro/images/34a5a48313e89a55fb1764b3ad6095b9.jpg'),
(92410, 6471, 'Bob\'s Burgers S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/196755.mp4', 'http://timg.bdta.pro/images/16aef992bde58e8220c68c3f2108f811.jpg'),
(92411, 6471, 'Bob\'s Burgers S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/196756.mp4', 'http://timg.bdta.pro/images/74d7785bfb36fb9acfb23558b3bc989b.jpg'),
(92412, 6471, 'Bob\'s Burgers S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/196757.mp4', 'http://timg.bdta.pro/images/bdcf84b0e186bc146be8df31493fd27d.jpg'),
(92413, 6472, 'Bob\'s Burgers S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/464651.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92414, 6472, 'Bob\'s Burgers S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/464652.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92415, 6472, 'Bob\'s Burgers S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/464653.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92416, 6472, 'Bob\'s Burgers S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/464654.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92417, 6472, 'Bob\'s Burgers S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/464655.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92418, 6472, 'Bob\'s Burgers S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/464656.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92419, 6472, 'Bob\'s Burgers S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/464657.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92420, 6472, 'Bob\'s Burgers S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/464658.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92421, 6472, 'Bob\'s Burgers S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/298431.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92422, 6472, 'Bob\'s Burgers S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/298432.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92423, 6472, 'Bob\'s Burgers S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/298433.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92424, 6472, 'Bob\'s Burgers S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/350383.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92425, 6472, 'Bob\'s Burgers S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/375400.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92426, 6472, 'Bob\'s Burgers S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/464669.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92427, 6472, 'Bob\'s Burgers S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/464670.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92428, 6472, 'Bob\'s Burgers S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/464671.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92429, 6473, 'Bob\'s Burgers S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/660738.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92430, 6473, 'Bob\'s Burgers S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/660739.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92431, 6473, 'Bob\'s Burgers S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/660740.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92432, 6473, 'Bob\'s Burgers S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/660741.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92433, 6473, 'Bob\'s Burgers S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/660742.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92434, 6473, 'Bob\'s Burgers S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/660743.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92435, 6473, 'Bob\'s Burgers S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/660744.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92436, 6473, 'Bob\'s Burgers S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/665669.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92437, 6473, 'Bob\'s Burgers S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/680829.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92438, 6473, 'Bob\'s Burgers S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/691757.mp4', 'http://gstaticontent.com/images/b5fa438e0d24ce9b897df4a41f6aa4b0.jpg'),
(92439, 6474, 'Mistérios do Detetive Murdoch S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196464.mp4', 'http://timg.bdta.pro/images/406ddb7c977439654e634125d8f81f1a.jpg'),
(92440, 6474, 'Mistérios do Detetive Murdoch S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196465.mp4', 'http://timg.bdta.pro/images/18f8d73658d720db513ad14282912c14.jpg'),
(92441, 6474, 'Mistérios do Detetive Murdoch S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196466.mp4', 'http://timg.bdta.pro/images/b2cefe21f0fb2485644cb321d417c813.jpg'),
(92442, 6474, 'Mistérios do Detetive Murdoch S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196467.mp4', 'http://timg.bdta.pro/images/294c9f49d19b92f7085888cf5bc4561d.jpg'),
(92443, 6474, 'Mistérios do Detetive Murdoch S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196468.mp4', 'http://timg.bdta.pro/images/14c5049d5b61f23637ec7b55717d428b.jpg'),
(92444, 6474, 'Mistérios do Detetive Murdoch S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196469.mp4', 'http://timg.bdta.pro/images/aba45dd1cb21bf5f1c8909ee957113f0.jpg'),
(92445, 6474, 'Mistérios do Detetive Murdoch S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196470.mp4', 'http://timg.bdta.pro/images/d7313319a29742234484568c37271039.jpg'),
(92446, 6474, 'Mistérios do Detetive Murdoch S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196471.mp4', 'http://timg.bdta.pro/images/448a1b30525e1ca54f385c430548f1a6.jpg'),
(92447, 6474, 'Mistérios do Detetive Murdoch S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196472.mp4', 'http://timg.bdta.pro/images/b18cf5a53328c71e7c314f317f4332ae.jpg'),
(92448, 6474, 'Mistérios do Detetive Murdoch S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196473.mp4', 'http://timg.bdta.pro/images/175a3f6c61faee859599d885f9c55bde.jpg'),
(92449, 6474, 'Mistérios do Detetive Murdoch S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196474.mp4', 'http://timg.bdta.pro/images/4d7f7672568a6a2deb19e49319ae1b52.jpg'),
(92450, 6474, 'Mistérios do Detetive Murdoch S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196475.mp4', 'http://timg.bdta.pro/images/8884a84dec2a68a9e959fc048e546313.jpg'),
(92451, 6474, 'Mistérios do Detetive Murdoch S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196476.mp4', 'http://timg.bdta.pro/images/b2e0f72cd9a40e82204f3b601ebdcb0d.jpg'),
(92452, 6475, 'Mistérios do Detetive Murdoch S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196477.mp4', 'http://timg.bdta.pro/images/8e3c22570ce6e8c333ac4b15fcffe6d0.jpg'),
(92453, 6475, 'Mistérios do Detetive Murdoch S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196478.mp4', 'http://timg.bdta.pro/images/2ed4885917938b96eefb5a2ef07afc2c.jpg'),
(92454, 6475, 'Mistérios do Detetive Murdoch S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196479.mp4', 'http://timg.bdta.pro/images/96ed7f20f9905ce500a93c305c03a1cf.jpg'),
(92455, 6475, 'Mistérios do Detetive Murdoch S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196480.mp4', 'http://timg.bdta.pro/images/70b26018adc0a8eb4e23ff69b2e7e5b4.jpg'),
(92456, 6475, 'Mistérios do Detetive Murdoch S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196481.mp4', 'http://timg.bdta.pro/images/481f43bfb625ba6840967f62b5177c20.jpg'),
(92457, 6475, 'Mistérios do Detetive Murdoch S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196482.mp4', 'http://timg.bdta.pro/images/11dafb5c727e2ce4450adba77cb46d15.jpg'),
(92458, 6475, 'Mistérios do Detetive Murdoch S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196483.mp4', 'http://timg.bdta.pro/images/9adb582b90cb921187726fca053728e5.jpg'),
(92459, 6475, 'Mistérios do Detetive Murdoch S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196484.mp4', 'http://timg.bdta.pro/images/4181e4b99bd409c58d85f6109e03d1db.jpg'),
(92460, 6475, 'Mistérios do Detetive Murdoch S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196485.mp4', 'http://timg.bdta.pro/images/8fcdb38bfca28c1af6d05e1bcf0b98e6.jpg'),
(92461, 6475, 'Mistérios do Detetive Murdoch S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196486.mp4', 'http://timg.bdta.pro/images/044242944dc3562d278e5a93d005c986.jpg'),
(92462, 6475, 'Mistérios do Detetive Murdoch S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196487.mp4', 'http://timg.bdta.pro/images/5b29866727bfcd60e3bdc5e66f687d4b.jpg'),
(92463, 6475, 'Mistérios do Detetive Murdoch S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196488.mp4', 'http://timg.bdta.pro/images/a0998bffb324f811701d027d80603f46.jpg'),
(92464, 6475, 'Mistérios do Detetive Murdoch S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196489.mp4', 'http://timg.bdta.pro/images/13c846afd9d5e0ef4f88fd45019524d8.jpg'),
(92465, 6476, 'Mistérios do Detetive Murdoch S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196490.mp4', 'http://timg.bdta.pro/images/f2ad0b3852fb56cd443e70b0f05f094c.jpg'),
(92466, 6476, 'Mistérios do Detetive Murdoch S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196491.mp4', 'http://timg.bdta.pro/images/87a41d4b6eccf1628c965c08f07e870e.jpg'),
(92467, 6476, 'Mistérios do Detetive Murdoch S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196492.mp4', 'http://timg.bdta.pro/images/c195a6658fea0a0dd6e75a99d23972e0.jpg'),
(92468, 6476, 'Mistérios do Detetive Murdoch S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196493.mp4', 'http://timg.bdta.pro/images/1a02169c2c6d3a6745f52792aaf2c813.jpg'),
(92469, 6476, 'Mistérios do Detetive Murdoch S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196494.mp4', 'http://timg.bdta.pro/images/67db7dbac58365883579ace0d27bae3e.jpg'),
(92470, 6476, 'Mistérios do Detetive Murdoch S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196495.mp4', 'http://timg.bdta.pro/images/cd5f2047c6ab5595ce1ba065d738cfa8.jpg'),
(92471, 6476, 'Mistérios do Detetive Murdoch S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196496.mp4', 'http://timg.bdta.pro/images/e7ae416d580d563e35dbb482f4eac301.jpg'),
(92472, 6476, 'Mistérios do Detetive Murdoch S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196497.mp4', 'http://timg.bdta.pro/images/3ac662f62fddcb9ccdb09022a25ebb71.jpg'),
(92473, 6476, 'Mistérios do Detetive Murdoch S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196498.mp4', 'http://timg.bdta.pro/images/82a734db7a38eb37b040e3a7e3644094.jpg'),
(92474, 6476, 'Mistérios do Detetive Murdoch S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196499.mp4', 'http://timg.bdta.pro/images/e6e1b89ae639b339040cf69532c8d0c8.jpg'),
(92475, 6476, 'Mistérios do Detetive Murdoch S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196500.mp4', 'http://timg.bdta.pro/images/66342052af8c7d9b79d7bbed8fe5e261.jpg'),
(92476, 6476, 'Mistérios do Detetive Murdoch S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196501.mp4', 'http://timg.bdta.pro/images/418476ac5fa328188699582415d2019b.jpg'),
(92477, 6476, 'Mistérios do Detetive Murdoch S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196502.mp4', 'http://timg.bdta.pro/images/a724b0a9d3522bd00c4cd005423d46a1.jpg'),
(92478, 6477, 'Mistérios do Detetive Murdoch S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196503.mp4', 'http://timg.bdta.pro/images/6e1c028772c96d92fac93f951713b922.jpg'),
(92479, 6477, 'Mistérios do Detetive Murdoch S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196504.mp4', 'http://timg.bdta.pro/images/ef5132a4315d6a1ca7acf10d9133e9e6.jpg'),
(92480, 6477, 'Mistérios do Detetive Murdoch S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196505.mp4', 'http://timg.bdta.pro/images/da0392f0a4b4e4be8200df7e39beb7dc.jpg'),
(92481, 6477, 'Mistérios do Detetive Murdoch S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196506.mp4', 'http://timg.bdta.pro/images/2f80a4594cc5047decfc5e149a4741a5.jpg'),
(92482, 6477, 'Mistérios do Detetive Murdoch S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196507.mp4', 'http://timg.bdta.pro/images/f642c1435f4f36ee7d21c0d158e27be2.jpg'),
(92483, 6477, 'Mistérios do Detetive Murdoch S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196508.mp4', 'http://timg.bdta.pro/images/c4e5af739ea231cb13a01309f266d74e.jpg'),
(92484, 6477, 'Mistérios do Detetive Murdoch S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196509.mp4', 'http://timg.bdta.pro/images/291de29f784f3c39eb336cdb714a87ed.jpg'),
(92485, 6477, 'Mistérios do Detetive Murdoch S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196510.mp4', 'http://timg.bdta.pro/images/fa72a586b444abe1113b6a30cabbaa9a.jpg'),
(92486, 6477, 'Mistérios do Detetive Murdoch S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196511.mp4', 'http://timg.bdta.pro/images/065a014c30636a2715d84f52f7249d7e.jpg'),
(92487, 6477, 'Mistérios do Detetive Murdoch S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196512.mp4', 'http://timg.bdta.pro/images/ba8ffb81cf4e7682aef0a52ea6122c83.jpg'),
(92488, 6477, 'Mistérios do Detetive Murdoch S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196513.mp4', 'http://timg.bdta.pro/images/2aaa1b7a1d0da799a55055181e647197.jpg'),
(92489, 6477, 'Mistérios do Detetive Murdoch S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196514.mp4', 'http://timg.bdta.pro/images/2b4f401c40f53900fbab0af487a914b5.jpg'),
(92490, 6477, 'Mistérios do Detetive Murdoch S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196515.mp4', 'http://timg.bdta.pro/images/fe82cf583bcb27ef597dab3eccc6ae2b.jpg'),
(92491, 6478, 'Mistérios do Detetive Murdoch S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196516.mp4', 'http://timg.bdta.pro/images/7a1ba9a998234285a56809f6a9014b4b.jpg'),
(92492, 6478, 'Mistérios do Detetive Murdoch S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196517.mp4', 'http://timg.bdta.pro/images/44e8321a6cca17cbd61ce22a30c948dd.jpg'),
(92493, 6478, 'Mistérios do Detetive Murdoch S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196518.mp4', 'http://timg.bdta.pro/images/3dad35e1fd22b8a88e7b7bb0a041da7a.jpg'),
(92494, 6478, 'Mistérios do Detetive Murdoch S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196519.mp4', 'http://timg.bdta.pro/images/b703d509400931341bec0c00f13f4f71.jpg'),
(92495, 6478, 'Mistérios do Detetive Murdoch S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196520.mp4', 'http://timg.bdta.pro/images/f66057d5c484a72de1b73408befdf9ce.jpg'),
(92496, 6478, 'Mistérios do Detetive Murdoch S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196521.mp4', 'http://timg.bdta.pro/images/bff4f7ff0d1fe1a8077ef7e3f523a743.jpg'),
(92497, 6478, 'Mistérios do Detetive Murdoch S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196522.mp4', 'http://timg.bdta.pro/images/7d194f5858493d12e459fdea9b61ff1a.jpg'),
(92498, 6478, 'Mistérios do Detetive Murdoch S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196523.mp4', 'http://timg.bdta.pro/images/22935e4119215b2646f1d25dc5825719.jpg'),
(92499, 6478, 'Mistérios do Detetive Murdoch S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196524.mp4', 'http://timg.bdta.pro/images/445ab1e101d01ffb24681eea4c256d58.jpg'),
(92500, 6478, 'Mistérios do Detetive Murdoch S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196525.mp4', 'http://timg.bdta.pro/images/5cbd30bd1ff2524753a8b26f9a2b9f7c.jpg'),
(92501, 6478, 'Mistérios do Detetive Murdoch S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196526.mp4', 'http://timg.bdta.pro/images/518dc55e9e5421caddbd4abde50f717f.jpg'),
(92502, 6478, 'Mistérios do Detetive Murdoch S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196527.mp4', 'http://timg.bdta.pro/images/056d8b0340e5eb501140b3014d5d8b28.jpg'),
(92503, 6478, 'Mistérios do Detetive Murdoch S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196528.mp4', 'http://timg.bdta.pro/images/48889672fdf96a5c1c3cd4ae240c4733.jpg'),
(92504, 6479, 'Mistérios do Detetive Murdoch S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196529.mp4', 'http://timg.bdta.pro/images/fd8fe378a75b0045e040c21acb653d40.jpg'),
(92505, 6479, 'Mistérios do Detetive Murdoch S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196530.mp4', 'http://timg.bdta.pro/images/5ff41983b2d689380f1b5da6b1e25a7f.jpg'),
(92506, 6479, 'Mistérios do Detetive Murdoch S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196531.mp4', 'http://timg.bdta.pro/images/3b5592ff97f3307266084a78bc6033cf.jpg'),
(92507, 6479, 'Mistérios do Detetive Murdoch S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196532.mp4', 'http://timg.bdta.pro/images/45373d8ee25eb0f7a45476268d1f47de.jpg'),
(92508, 6479, 'Mistérios do Detetive Murdoch S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196533.mp4', 'http://timg.bdta.pro/images/7ab1408c88a68891a765270b94c8cde7.jpg'),
(92509, 6479, 'Mistérios do Detetive Murdoch S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196534.mp4', 'http://timg.bdta.pro/images/924e8614c07394dc64dd839aba3b4d81.jpg'),
(92510, 6479, 'Mistérios do Detetive Murdoch S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196535.mp4', 'http://timg.bdta.pro/images/80e95e1efc5ff3601f01118a01a6b195.jpg'),
(92511, 6479, 'Mistérios do Detetive Murdoch S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196536.mp4', 'http://timg.bdta.pro/images/09200e9c8b712c9c3490213d3a43b061.jpg'),
(92512, 6479, 'Mistérios do Detetive Murdoch S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196537.mp4', 'http://timg.bdta.pro/images/d71586214d0b9b4e21c8dd3dd9d764a4.jpg'),
(92513, 6479, 'Mistérios do Detetive Murdoch S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196538.mp4', 'http://timg.bdta.pro/images/17e763592b56488e3edcfbdad1961b71.jpg'),
(92514, 6479, 'Mistérios do Detetive Murdoch S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196539.mp4', 'http://timg.bdta.pro/images/11250504425b9d21cc6a5e8b0cec24ab.jpg'),
(92515, 6479, 'Mistérios do Detetive Murdoch S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196540.mp4', 'http://timg.bdta.pro/images/5c2b7ece66acd3f9ccce46c729bc7174.jpg'),
(92516, 6479, 'Mistérios do Detetive Murdoch S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196541.mp4', 'http://timg.bdta.pro/images/0dd763639f0e0f68d9dcb62f3038cbaa.jpg'),
(92517, 6480, 'Mistérios do Detetive Murdoch S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462529.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y2bxrWgHUl0YzDemdoKuqLMJwR7.jpg'),
(92518, 6480, 'Mistérios do Detetive Murdoch S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462530.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nSHARCV9CWetOvpgE2UKPG3Nqal.jpg'),
(92519, 6480, 'Mistérios do Detetive Murdoch S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462531.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rpEeEtx3HaXhA0RlFOGBitouQ0k.jpg'),
(92520, 6480, 'Mistérios do Detetive Murdoch S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462532.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oKdN4u8BvjaEsOlPX6oMurMdVOR.jpg'),
(92521, 6480, 'Mistérios do Detetive Murdoch S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462533.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tmmYfAJAgxn8Zq7DCmOUSBj2a9H.jpg'),
(92522, 6480, 'Mistérios do Detetive Murdoch S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462534.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qakBPyvDVZ2XRg3jLmfmDkZSfb7.jpg'),
(92523, 6480, 'Mistérios do Detetive Murdoch S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462535.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/65ohB3MpHDEsjljMOvwXthqT0iX.jpg'),
(92524, 6480, 'Mistérios do Detetive Murdoch S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462536.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hbakq9WecZolAOaiB7QQHYYtuQH.jpg'),
(92525, 6480, 'Mistérios do Detetive Murdoch S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462537.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gOQkwmePbvg87QFMvl9gGigEdUi.jpg'),
(92526, 6480, 'Mistérios do Detetive Murdoch S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462538.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lUM7FHvz0Y40cU8l0sNjMqUIBHc.jpg'),
(92527, 6480, 'Mistérios do Detetive Murdoch S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/462539.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i2vPNc5ZiacxblJv2SWaPxyQt5a.jpg'),
(92528, 6480, 'Mistérios do Detetive Murdoch S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/462540.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pU2E4gMsbjHo4LcZ1stLghtdaki.jpg'),
(92529, 6480, 'Mistérios do Detetive Murdoch S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/462541.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t9rQf0qmiVLx3l9AijavgEIRp1j.jpg'),
(92530, 6480, 'Mistérios do Detetive Murdoch S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/462542.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJMLRt60gyO1QY6mKaZMcPuywF.jpg'),
(92531, 6480, 'Mistérios do Detetive Murdoch S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/462543.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/enwA4zITnwbFJnAP7CDCTvPGRdJ.jpg'),
(92532, 6480, 'Mistérios do Detetive Murdoch S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/462544.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a1pUR5coPJRHQxkWTzzdgcsLdkc.jpg'),
(92533, 6480, 'Mistérios do Detetive Murdoch S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/462545.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A9Rr4UMEFANe5NaYdUQqYDdKeG5.jpg'),
(92534, 6480, 'Mistérios do Detetive Murdoch S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/462546.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2SCrkEVoDy0IoxDbxB9vmoP9nWY.jpg'),
(92535, 6481, 'Mistérios do Detetive Murdoch S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462547.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A8E9Uj7TKIRVrK69VBUpMqx8Em0.jpg'),
(92536, 6481, 'Mistérios do Detetive Murdoch S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/620408.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A5YVTORBNAUYEYTqJnVSBYIyPsZ.jpg'),
(92537, 6481, 'Mistérios do Detetive Murdoch S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462549.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iuUmQRlj1eTrs3QwbqVLUeyAeGf.jpg'),
(92538, 6481, 'Mistérios do Detetive Murdoch S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462550.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Atend0BGXf3Te4STxeiSN3dAV7d.jpg'),
(92539, 6481, 'Mistérios do Detetive Murdoch S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462551.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m9r3KfBN0j7cmWQ6FjugWnuR9tS.jpg'),
(92540, 6481, 'Mistérios do Detetive Murdoch S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462552.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1ujXg4dGwY9DsZf9d8qx77SUh24.jpg'),
(92541, 6481, 'Mistérios do Detetive Murdoch S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462553.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3m0wS2qlyN0dnXkl0V9l3pHlNEe.jpg'),
(92542, 6481, 'Mistérios do Detetive Murdoch S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462554.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oaB0PiazeRNfi1G2cIXvO3nKWxP.jpg'),
(92543, 6481, 'Mistérios do Detetive Murdoch S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462555.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9gkQyUynNYgZ59BIMigvwOlxRZk.jpg'),
(92544, 6481, 'Mistérios do Detetive Murdoch S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462556.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vBLcFI0NPueyitLVJudwZ7V1lkY.jpg'),
(92545, 6481, 'Mistérios do Detetive Murdoch S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/462557.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e2wt2nd67QT5it217W42S3SYASs.jpg'),
(92546, 6481, 'Mistérios do Detetive Murdoch S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/462558.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uTHoNU8XNKCYTLohAgrQVSOTLUQ.jpg'),
(92547, 6481, 'Mistérios do Detetive Murdoch S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/462559.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pj63DRi382UXTrRWEr0FwTOmPfS.jpg'),
(92548, 6481, 'Mistérios do Detetive Murdoch S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/462560.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jvlvftx49STp7fdfX87ihsag2lp.jpg'),
(92549, 6481, 'Mistérios do Detetive Murdoch S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/462561.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5laeHTpYTyeUMEusACPPBFVp6SX.jpg'),
(92550, 6481, 'Mistérios do Detetive Murdoch S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/462562.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eFK2sKkPgim94muIWpOinFtW8Xr.jpg'),
(92551, 6481, 'Mistérios do Detetive Murdoch S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/462563.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4OIKuS5c0NRle1CqTxlUuYnFZQ7.jpg'),
(92552, 6481, 'Mistérios do Detetive Murdoch S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/462564.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9mra2eLnmxhgvZszGqjWLJ1AEjc.jpg'),
(92553, 6482, 'Mistérios do Detetive Murdoch S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462565.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/23JDUL6KQQXj8MR4szIYuskSYRg.jpg'),
(92554, 6482, 'Mistérios do Detetive Murdoch S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462566.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ykI1FuizduRAisV9REA5zjerQ4E.jpg'),
(92555, 6482, 'Mistérios do Detetive Murdoch S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462567.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1UvFAFTgBihTir7DVFIWEuuIG7W.jpg'),
(92556, 6482, 'Mistérios do Detetive Murdoch S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462568.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/duHAiLuGf7Uvbp7F3wuU6Unmrrp.jpg'),
(92557, 6482, 'Mistérios do Detetive Murdoch S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462569.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eauo2s66Qw2s5EOIYSGsvBX6tzN.jpg'),
(92558, 6482, 'Mistérios do Detetive Murdoch S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462570.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sqeBH6k7fPA9JYKFzgDwkJLZt1X.jpg'),
(92559, 6482, 'Mistérios do Detetive Murdoch S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462571.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v4Lh1wwDA2JPkVRscaNPWNbAwq2.jpg'),
(92560, 6482, 'Mistérios do Detetive Murdoch S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462572.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rBKNUsAZ1AN7DsdTPHBMlivdFtr.jpg'),
(92561, 6482, 'Mistérios do Detetive Murdoch S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462573.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oC8C8YMGLEr32EOSiNfkxrDk1Fb.jpg'),
(92562, 6482, 'Mistérios do Detetive Murdoch S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462574.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cexoIXASBaYXTPQpv4nVNXNHZOO.jpg'),
(92563, 6482, 'Mistérios do Detetive Murdoch S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/462575.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bA9Tz8Com6tCfHoM4pSOlts7ejt.jpg'),
(92564, 6482, 'Mistérios do Detetive Murdoch S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/462576.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aLRA8upC6SrT9i6P3EP34IDEDfw.jpg'),
(92565, 6482, 'Mistérios do Detetive Murdoch S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/462577.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nmL8gWZWhlu3K2GL9C7KGIGXm9k.jpg'),
(92566, 6482, 'Mistérios do Detetive Murdoch S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/462578.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1oKS4GvaDI6rHCsOZKEesnr4Qkh.jpg'),
(92567, 6482, 'Mistérios do Detetive Murdoch S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/462579.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uqBvWxmGwFSbo8S504vmkCoitqb.jpg'),
(92568, 6482, 'Mistérios do Detetive Murdoch S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/462580.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fFNKmx3P1MWSCKpEeOrNMzlbRXo.jpg'),
(92569, 6482, 'Mistérios do Detetive Murdoch S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/462581.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tTHyAP4uwsqNCjbIILyoFTTOJoC.jpg'),
(92570, 6482, 'Mistérios do Detetive Murdoch S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/462582.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5CZVBVekwNoNXvxb79nEo3COiwA.jpg'),
(92571, 6483, 'Mistérios do Detetive Murdoch S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462583.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eQ9OkCULASYlR14srTRM3BKezgA.jpg'),
(92572, 6483, 'Mistérios do Detetive Murdoch S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462584.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u0d9yG58go5kzdgiXTc3CilXkIR.jpg'),
(92573, 6483, 'Mistérios do Detetive Murdoch S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462585.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vo93d8y89aQlWr5Mca1NsodG99N.jpg'),
(92574, 6483, 'Mistérios do Detetive Murdoch S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462586.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9Uw6Zw6H3GBrlxcbSoO3MyCUVfm.jpg'),
(92575, 6483, 'Mistérios do Detetive Murdoch S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462587.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ghue7hzZWa3Aflzwbl2Hvt80JsS.jpg'),
(92576, 6483, 'Mistérios do Detetive Murdoch S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462588.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5TXF26t2hVcVtYFmmMi2uxAI5sE.jpg'),
(92577, 6483, 'Mistérios do Detetive Murdoch S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462589.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/90qDryhISvw8YNQCWqJb71sfyf3.jpg'),
(92578, 6483, 'Mistérios do Detetive Murdoch S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462590.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eEtERAf3hJZysqwnPtKV1AMKQZZ.jpg'),
(92579, 6483, 'Mistérios do Detetive Murdoch S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462591.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A5sL7vgIPsXWceyCNbzX3H5uw40.jpg'),
(92580, 6483, 'Mistérios do Detetive Murdoch S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462592.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cpiinEpw07Juuu1sXEroRkeR86u.jpg'),
(92581, 6483, 'Mistérios do Detetive Murdoch S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/462593.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nkphmgSpphdZNrnBnH0wUV69iL2.jpg'),
(92582, 6483, 'Mistérios do Detetive Murdoch S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/462594.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xZ0ieAvi7WLmoEgo4v4Io7G7xps.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(92583, 6483, 'Mistérios do Detetive Murdoch S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/462595.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xW4gX5AChq0Y1IHGx2r7JufAu5e.jpg'),
(92584, 6483, 'Mistérios do Detetive Murdoch S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/462596.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tCrSq87B3dnUkgTr9ooD71GXDn8.jpg'),
(92585, 6483, 'Mistérios do Detetive Murdoch S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/462597.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2nm1w8QPUzmHg0wc7c5mvKjVJZJ.jpg'),
(92586, 6483, 'Mistérios do Detetive Murdoch S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/462598.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g15EobDys1r4l1bq8dXoylII8E4.jpg'),
(92587, 6483, 'Mistérios do Detetive Murdoch S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/462599.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rebLBZFZ8XPwrbDNAPfqGDXsxLf.jpg'),
(92588, 6483, 'Mistérios do Detetive Murdoch S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/462600.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iysBkQVCqGLkgNHnBWuQslbZB8Q.jpg'),
(92589, 6483, 'Mistérios do Detetive Murdoch S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/462601.mp4', 'http://gstaticontent.com/images/3ace5e8596090027adc3c3cd41eee941.jpg'),
(92590, 6484, 'Mistérios do Detetive Murdoch S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462602.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nFpyu9McpWvrQ90hoXvWQMZQ9dB.jpg'),
(92591, 6484, 'Mistérios do Detetive Murdoch S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462603.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uywbS9p9RwC9Do7vJdW24QkHmYy.jpg'),
(92592, 6484, 'Mistérios do Detetive Murdoch S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462604.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rdNV6ed3jShdbBa65XseS3Bd2nM.jpg'),
(92593, 6484, 'Mistérios do Detetive Murdoch S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462605.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/beawWDv3TwPnItGMr1i6XcytPxN.jpg'),
(92594, 6484, 'Mistérios do Detetive Murdoch S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462606.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3rLwfr2tUk9PNpTeYpMKW8qnzg4.jpg'),
(92595, 6484, 'Mistérios do Detetive Murdoch S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462607.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pEoecygDJ7w2VSduGJiR8XXmqmX.jpg'),
(92596, 6484, 'Mistérios do Detetive Murdoch S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462608.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iCxz1vvXgqNjHz7HSNVps91rzpd.jpg'),
(92597, 6484, 'Mistérios do Detetive Murdoch S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462609.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cmA76rVLbGQ24kYMjDV6hKSf1ih.jpg'),
(92598, 6484, 'Mistérios do Detetive Murdoch S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462610.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yINjq2l1sdEY1uOEMpIjoqISnbn.jpg'),
(92599, 6484, 'Mistérios do Detetive Murdoch S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462611.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7hgHUbTlGdLPmPs4o5UeTmH7wu1.jpg'),
(92600, 6484, 'Mistérios do Detetive Murdoch S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/462612.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/epIHj7946YYoa1PvRkaXzfGvBoS.jpg'),
(92601, 6484, 'Mistérios do Detetive Murdoch S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/462613.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AGvFSL4JQhETcxYBJHCZaes6Rs.jpg'),
(92602, 6484, 'Mistérios do Detetive Murdoch S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/462614.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nhGAoMFTap4LmvVkCPlQPNRDR3n.jpg'),
(92603, 6484, 'Mistérios do Detetive Murdoch S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/462615.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kBvmQhif6WyQ3bY8zlahFWMkSC4.jpg'),
(92604, 6484, 'Mistérios do Detetive Murdoch S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/462616.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6lDSzjYQ8X5Xf0vItuKd3d68qSa.jpg'),
(92605, 6484, 'Mistérios do Detetive Murdoch S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/462617.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kWuQVVw9t6RLxSNYoX9MkLx9zGj.jpg'),
(92606, 6484, 'Mistérios do Detetive Murdoch S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/462618.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o4d4SYpV9zSVrn08EVd9DpcOfO1.jpg'),
(92607, 6484, 'Mistérios do Detetive Murdoch S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/462619.mp4', 'http://gstaticontent.com/images/3ace5e8596090027adc3c3cd41eee941.jpg'),
(92608, 6485, 'Mistérios do Detetive Murdoch S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462620.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Akr1nS0elt3SZjX2jx5MFrRzbn.jpg'),
(92609, 6485, 'Mistérios do Detetive Murdoch S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462621.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t5zvYAJ8ExIIonJ8h55falXn00L.jpg'),
(92610, 6485, 'Mistérios do Detetive Murdoch S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462622.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xCKCp0hFPjscgLmBUoFw16x8htw.jpg'),
(92611, 6485, 'Mistérios do Detetive Murdoch S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462623.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pAIfDOLcWg2GLjgPX6TJDIDZctP.jpg'),
(92612, 6485, 'Mistérios do Detetive Murdoch S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462624.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hPJOMNnrGuT6E4RqckHcap4UvCV.jpg'),
(92613, 6485, 'Mistérios do Detetive Murdoch S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462625.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aUU0PAKVEMhhVlWMLQfapbSY18Z.jpg'),
(92614, 6485, 'Mistérios do Detetive Murdoch S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462626.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jThVipFcDztP3zATOcDPmuQn400.jpg'),
(92615, 6485, 'Mistérios do Detetive Murdoch S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462627.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iZOLgLka98XwVYdLPnNGE96U7Jr.jpg'),
(92616, 6485, 'Mistérios do Detetive Murdoch S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462628.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/srSbt3f0N0qp0jZdEXmE48TXkO1.jpg'),
(92617, 6485, 'Mistérios do Detetive Murdoch S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462629.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qpnQeTFEfcXUxh5eU13e3zIcYtO.jpg'),
(92618, 6485, 'Mistérios do Detetive Murdoch S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/462630.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eTmOaJn7xRnYr6vOnngsK2Pv0xA.jpg'),
(92619, 6485, 'Mistérios do Detetive Murdoch S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/462631.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/enHgIZxZmffaGKdb3sjhdRl6UXN.jpg'),
(92620, 6485, 'Mistérios do Detetive Murdoch S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/462632.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1kabDny5XrfA6wxvFyEWy4zAY0d.jpg'),
(92621, 6485, 'Mistérios do Detetive Murdoch S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/462633.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/quwVg7WoUSrIsRvisNLxsY3aFjK.jpg'),
(92622, 6485, 'Mistérios do Detetive Murdoch S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/462634.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5XBYOfJZ2cMpc6kYfusjScSV8v7.jpg'),
(92623, 6485, 'Mistérios do Detetive Murdoch S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/462635.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h8eHAaosxUGFtBC5PnUIsC4nCwP.jpg'),
(92624, 6485, 'Mistérios do Detetive Murdoch S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/462636.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xzQDbYR1rnyiSVAGz4Ay8eIeL7l.jpg'),
(92625, 6485, 'Mistérios do Detetive Murdoch S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/462637.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7MuLHsbn4rHmiYT1MZawYhyHD4H.jpg'),
(92626, 6486, 'Mistérios do Detetive Murdoch S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462638.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mGZXmGenoy01HfNGjhjKArW7iJY.jpg'),
(92627, 6486, 'Mistérios do Detetive Murdoch S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462639.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cCHji6JBMNKX1UgPL5iGfqv5sTo.jpg'),
(92628, 6486, 'Mistérios do Detetive Murdoch S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462640.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2Pz6Ao0mNGMprOs4WQjkjKqnK3Q.jpg'),
(92629, 6486, 'Mistérios do Detetive Murdoch S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462641.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u9NnaaGzl74SpLmmPNaImh5OBZp.jpg'),
(92630, 6486, 'Mistérios do Detetive Murdoch S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462642.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8mBkDMn2DSAvNMbkDucNsotf88a.jpg'),
(92631, 6486, 'Mistérios do Detetive Murdoch S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462643.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m1FGzeAujsBGvaXWIi1ntzDbaem.jpg'),
(92632, 6486, 'Mistérios do Detetive Murdoch S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462644.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a84u08BH3qUCspTZCTiECXz100l.jpg'),
(92633, 6486, 'Mistérios do Detetive Murdoch S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462645.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qvvUrC6gVdaD4hlvVJa7TzZ06YC.jpg'),
(92634, 6486, 'Mistérios do Detetive Murdoch S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462646.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oFq45pcyB2o2Cq2sCK0ftPJwo4s.jpg'),
(92635, 6486, 'Mistérios do Detetive Murdoch S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462647.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m8sM0aeK9oBWsgQcVYudIONiSzN.jpg'),
(92636, 6486, 'Mistérios do Detetive Murdoch S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/462648.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qteJFbwKRHR1DEooopYtv1vNRQU.jpg'),
(92637, 6486, 'Mistérios do Detetive Murdoch S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/462649.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qXNCaE9WWm9gSJAkfncclVlMV4u.jpg'),
(92638, 6486, 'Mistérios do Detetive Murdoch S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/462650.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1ntQHDiUHfXngo7dadC5Pf7XoJj.jpg'),
(92639, 6486, 'Mistérios do Detetive Murdoch S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/462651.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xxVCWQ1lRVpUztGj5zmXe8CkWA5.jpg'),
(92640, 6486, 'Mistérios do Detetive Murdoch S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/462652.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6mzs2u3g1W7aMQgJ1JdZix9W1tn.jpg'),
(92641, 6486, 'Mistérios do Detetive Murdoch S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/462653.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rLeYx4YoJZXr4KeDaRkYYXWOmel.jpg'),
(92642, 6486, 'Mistérios do Detetive Murdoch S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/462654.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jCq0Tnv3zNCbiPERYBBFtMq3dxr.jpg'),
(92643, 6486, 'Mistérios do Detetive Murdoch S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/462655.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aRZ5MZLD4qORrmMaSgvC2SS0UwZ.jpg'),
(92644, 6487, 'Mistérios do Detetive Murdoch S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462656.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/veOXHrjVEX1T4oxs5gGA9G6PYCW.jpg'),
(92645, 6487, 'Mistérios do Detetive Murdoch S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462657.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aBeU0IpCziryHwF53kHJTuB9u2X.jpg'),
(92646, 6487, 'Mistérios do Detetive Murdoch S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462658.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e39GVT4jWpvQVmuYIcEHKcRWmgX.jpg'),
(92647, 6487, 'Mistérios do Detetive Murdoch S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462659.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eS5zUUSJvPL6KBOh1SAB4gH7nkp.jpg'),
(92648, 6487, 'Mistérios do Detetive Murdoch S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462660.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zSVbruCIKfgguaclbLbzTGQaq1m.jpg'),
(92649, 6487, 'Mistérios do Detetive Murdoch S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462661.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e9fzLGNYgEpawG1odHy0YNMNqfZ.jpg'),
(92650, 6487, 'Mistérios do Detetive Murdoch S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462662.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sgS1sUBEg8xsU3hNRQPiLJN7Mx8.jpg'),
(92651, 6487, 'Mistérios do Detetive Murdoch S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462663.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/royWskNzJmGlrMm4qsolpiOIsA6.jpg'),
(92652, 6487, 'Mistérios do Detetive Murdoch S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462664.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qvxyKhOULkJMm3fdRDFBXQVJ10Y.jpg'),
(92653, 6487, 'Mistérios do Detetive Murdoch S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462665.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cgxL7Yax6razw5PmlTwmUrbd1sh.jpg'),
(92654, 6487, 'Mistérios do Detetive Murdoch S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/462666.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/69pedH41WpZEjtnMyoZZcp2923p.jpg'),
(92655, 6488, 'A Barbara E O Troll S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196451.mp4', 'http://timg.bdta.pro/images/50e52320436d0d93c412db5a1dd7848b.jpg'),
(92656, 6488, 'A Barbara E O Troll S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196452.mp4', 'http://timg.bdta.pro/images/0226b86b551899d3ff68f121da204555.jpg'),
(92657, 6488, 'A Barbara E O Troll S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196453.mp4', 'http://timg.bdta.pro/images/1fb48ad80f953f86fdf310a210e5c0c7.jpg'),
(92658, 6488, 'A Barbara E O Troll S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196454.mp4', 'http://timg.bdta.pro/images/67baf3c95b79c9483b1f212c3c7add67.jpg'),
(92659, 6488, 'A Barbara E O Troll S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196455.mp4', 'http://timg.bdta.pro/images/f9380b5a5156b5f1fa05f9e6eee63d33.jpg'),
(92660, 6488, 'A Barbara E O Troll S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196456.mp4', 'http://timg.bdta.pro/images/818e83627e4a77115662deab09653aed.jpg'),
(92661, 6488, 'A Barbara E O Troll S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196457.mp4', 'http://timg.bdta.pro/images/c545cb5163a0ddedc95e4c163609bb89.jpg'),
(92662, 6488, 'A Barbara E O Troll S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196458.mp4', 'http://timg.bdta.pro/images/2df9c4cc89a7200ae328c8b1e76e2a31.jpg'),
(92663, 6488, 'A Barbara E O Troll S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196459.mp4', 'http://timg.bdta.pro/images/53fe3ab26c6c9de3f2d6f8d79b54fcfd.jpg'),
(92664, 6488, 'A Barbara E O Troll S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196460.mp4', 'http://timg.bdta.pro/images/adf5f0609f544895535d0607211a6c63.jpg'),
(92665, 6488, 'A Barbara E O Troll S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196461.mp4', 'http://timg.bdta.pro/images/85d83cae875e02888ed02a260452d938.jpg'),
(92666, 6488, 'A Barbara E O Troll S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196462.mp4', 'http://timg.bdta.pro/images/a506e5ef0c840ac0f5dec77fedfb5ebb.jpg'),
(92667, 6488, 'A Barbara E O Troll S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196463.mp4', 'http://timg.bdta.pro/images/00892ac86db406e77e0ffc054ca30e6a.jpg'),
(92668, 6489, 'A Inundação do Milênio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196445.mp4', 'http://timg.bdta.pro/images/cc2c0cacf0e98c64f1827a28cef5423c.jpg'),
(92669, 6489, 'A Inundação do Milênio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196446.mp4', 'http://timg.bdta.pro/images/9ecfbc6016fbf3b1f55614e856cb8054.jpg'),
(92670, 6489, 'A Inundação do Milênio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196447.mp4', 'http://timg.bdta.pro/images/75422a835d011f5121cb4bf32d3ff916.jpg'),
(92671, 6489, 'A Inundação do Milênio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196448.mp4', 'http://timg.bdta.pro/images/67943bec8dc8f699b6c837341f4c7114.jpg'),
(92672, 6489, 'A Inundação do Milênio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196449.mp4', 'http://timg.bdta.pro/images/66a8d7b6bfb2a95bdf440800e51daead.jpg'),
(92673, 6489, 'A Inundação do Milênio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196450.mp4', 'http://timg.bdta.pro/images/d881ecebc4d25d989ca9f44e4a1a1ae3.jpg'),
(92674, 6490, 'Angelyne: Por Trás do Ícone de Hollywood S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196440.mp4', 'http://timg.bdta.pro/images/c499a887b1f991fecb9fc9f7a3609b81.jpg'),
(92675, 6490, 'Angelyne: Por Trás do Ícone de Hollywood S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196441.mp4', 'http://timg.bdta.pro/images/2711d372d229468bc921ce3c4bdb80de.jpg'),
(92676, 6490, 'Angelyne: Por Trás do Ícone de Hollywood S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196442.mp4', 'http://timg.bdta.pro/images/105dde1161b833980cb81b7a649232a1.jpg'),
(92677, 6490, 'Angelyne: Por Trás do Ícone de Hollywood S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196443.mp4', 'http://timg.bdta.pro/images/b461f716329f85c4691c59f6630aa829.jpg'),
(92678, 6490, 'Angelyne: Por Trás do Ícone de Hollywood S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196444.mp4', 'http://timg.bdta.pro/images/1da60212dc691f624711d6af0fe130a7.jpg'),
(92679, 6491, 'Guerrero S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196434.mp4', 'http://timg.bdta.pro/images/513247261400b481b1f5ec78b60b903e.jpg'),
(92680, 6491, 'Guerrero S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196435.mp4', 'http://timg.bdta.pro/images/7023936ae2b8c0c80159d44e17b3335d.jpg'),
(92681, 6491, 'Guerrero S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196436.mp4', 'http://timg.bdta.pro/images/38f7b49db48ea035a19cb8ef859062ba.jpg'),
(92682, 6491, 'Guerrero S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196437.mp4', 'http://timg.bdta.pro/images/d8dc90e53611fd8dab044197cfc792ec.jpg'),
(92683, 6491, 'Guerrero S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196438.mp4', 'http://timg.bdta.pro/images/b3434426a219d05e3ac15f5329b444ce.jpg'),
(92684, 6491, 'Guerrero S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196439.mp4', 'http://timg.bdta.pro/images/dca7cf013e296804bbbb4763d2a8ac8d.jpg'),
(92685, 6492, 'Conversando com um Serial Killer: O Canibal de Milwaukee S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196431.mp4', 'http://timg.bdta.pro/images/5a9aeef239af955d6591a44da73472ef.jpg'),
(92686, 6492, 'Conversando com um Serial Killer: O Canibal de Milwaukee S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196432.mp4', 'http://timg.bdta.pro/images/8271df9189c0da0bdd7d5db440c2c7a3.jpg'),
(92687, 6492, 'Conversando com um Serial Killer: O Canibal de Milwaukee S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196433.mp4', 'http://timg.bdta.pro/images/41721fffede44669afbd6af8b42afa04.jpg'),
(92688, 6493, 'Der Pass S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196415.mp4', 'http://timg.bdta.pro/images/2ae5722a9b34ff504c257c2d98e4171d.jpg'),
(92689, 6493, 'Der Pass S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196416.mp4', 'http://timg.bdta.pro/images/7d5f38204a90985b6d200b253b85f46f.jpg'),
(92690, 6493, 'Der Pass S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196417.mp4', 'http://timg.bdta.pro/images/3f684c02839f67f8b6fb4e8891d60bc0.jpg'),
(92691, 6493, 'Der Pass S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196418.mp4', 'http://timg.bdta.pro/images/b0d8a003a783e8fcbb41862e0b62515a.jpg'),
(92692, 6493, 'Der Pass S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196419.mp4', 'http://timg.bdta.pro/images/4088f8db0713c72aa87d271e389668bd.jpg'),
(92693, 6493, 'Der Pass S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196420.mp4', 'http://timg.bdta.pro/images/dc1383c8917ba3c6f6b39516744232ea.jpg'),
(92694, 6493, 'Der Pass S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196421.mp4', 'http://timg.bdta.pro/images/b31b5884856c6af25f670590b000edbe.jpg'),
(92695, 6493, 'Der Pass S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196422.mp4', 'http://timg.bdta.pro/images/f63a3e946f288aeaa6cc069741efa21a.jpg'),
(92696, 6494, 'Der Pass S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196423.mp4', 'http://timg.bdta.pro/images/0c474e026f6bf593dfa1e3557c13322f.jpg'),
(92697, 6494, 'Der Pass S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196424.mp4', 'http://timg.bdta.pro/images/ad45b462dd222970a8fa7d6de2a90b85.jpg'),
(92698, 6494, 'Der Pass S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196425.mp4', 'http://timg.bdta.pro/images/febec66b5d154a5cfe4f7777e62204d4.jpg'),
(92699, 6494, 'Der Pass S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196426.mp4', 'http://timg.bdta.pro/images/c9bcac3354c879ba55c11ba419f1046d.jpg'),
(92700, 6494, 'Der Pass S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196427.mp4', 'http://timg.bdta.pro/images/d1d9989c0d8efbcb5114cdda3167f8df.jpg'),
(92701, 6494, 'Der Pass S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196428.mp4', 'http://timg.bdta.pro/images/3158f5d04cc833f89c77b3d47f89f9df.jpg'),
(92702, 6494, 'Der Pass S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196429.mp4', 'http://timg.bdta.pro/images/8272970a4169ecae00e1685f729709aa.jpg'),
(92703, 6494, 'Der Pass S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196430.mp4', 'http://timg.bdta.pro/images/cc4819c951cbd35c50fd8b594c001dbc.jpg'),
(92704, 6495, 'Eleita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196408.mp4', 'http://gstaticontent.com/images/d184a66566e6c3a8cb38efd7f1791db5.jpg'),
(92705, 6495, 'Eleita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196409.mp4', 'http://gstaticontent.com/images/d184a66566e6c3a8cb38efd7f1791db5.jpg'),
(92706, 6495, 'Eleita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196410.mp4', 'http://gstaticontent.com/images/d184a66566e6c3a8cb38efd7f1791db5.jpg'),
(92707, 6495, 'Eleita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196411.mp4', 'http://gstaticontent.com/images/d184a66566e6c3a8cb38efd7f1791db5.jpg'),
(92708, 6495, 'Eleita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196412.mp4', 'http://gstaticontent.com/images/d184a66566e6c3a8cb38efd7f1791db5.jpg'),
(92709, 6495, 'Eleita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196413.mp4', 'http://gstaticontent.com/images/d184a66566e6c3a8cb38efd7f1791db5.jpg'),
(92710, 6495, 'Eleita S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196414.mp4', 'http://gstaticontent.com/images/d184a66566e6c3a8cb38efd7f1791db5.jpg'),
(92711, 6496, 'Kanojo Okarishimasu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196358.mp4', 'http://timg.bdta.pro/images/050ee345ae62f135dea4dc92f3f5c21d.jpg'),
(92712, 6496, 'Kanojo Okarishimasu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196359.mp4', 'http://timg.bdta.pro/images/e5150e50a061ac6aedfc7ab1ce2dab8e.jpg'),
(92713, 6496, 'Kanojo Okarishimasu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196360.mp4', 'http://timg.bdta.pro/images/7b07a342da83a1c8d4c5a16f29bd15bc.jpg'),
(92714, 6496, 'Kanojo Okarishimasu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196361.mp4', 'http://timg.bdta.pro/images/7eebe8178c7a25a97ede5fbf57d7e618.jpg'),
(92715, 6496, 'Kanojo Okarishimasu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196362.mp4', 'http://timg.bdta.pro/images/7efc3d22c94908e8bd04e0b3e4f18819.jpg'),
(92716, 6496, 'Kanojo Okarishimasu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196363.mp4', 'http://timg.bdta.pro/images/c264fb248b63f6b26b78855ae2512e00.jpg'),
(92717, 6496, 'Kanojo Okarishimasu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196364.mp4', 'http://timg.bdta.pro/images/126d6425bdd89d2610b08f80e859bae4.jpg'),
(92718, 6496, 'Kanojo Okarishimasu S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196365.mp4', 'http://timg.bdta.pro/images/ff62fca7eb4599ab4dd01813e610a1f3.jpg'),
(92719, 6496, 'Kanojo Okarishimasu S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196366.mp4', 'http://timg.bdta.pro/images/f60a4e4b84c66e7d93b429a858f31cd5.jpg'),
(92720, 6496, 'Kanojo Okarishimasu S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196367.mp4', 'http://timg.bdta.pro/images/05330f8522fa426e26fc4fb0ba803c9b.jpg'),
(92721, 6496, 'Kanojo Okarishimasu S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196368.mp4', 'http://timg.bdta.pro/images/e69557476fff9ff6e33149940a0122e8.jpg'),
(92722, 6496, 'Kanojo Okarishimasu S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196369.mp4', 'http://timg.bdta.pro/images/355a45eb5db1d4f962bc86bbaaaa2ef5.jpg'),
(92723, 6497, 'Kanojo Okarishimasu S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196370.mp4', 'http://gstaticontent.com/images/1b0ae2e3b9f2752e4ada3074517db7bd.jpg'),
(92724, 6497, 'Kanojo Okarishimasu S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196371.mp4', 'http://gstaticontent.com/images/1b0ae2e3b9f2752e4ada3074517db7bd.jpg'),
(92725, 6497, 'Kanojo Okarishimasu S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196372.mp4', 'http://gstaticontent.com/images/1b0ae2e3b9f2752e4ada3074517db7bd.jpg'),
(92726, 6497, 'Kanojo Okarishimasu S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196373.mp4', 'http://gstaticontent.com/images/1b0ae2e3b9f2752e4ada3074517db7bd.jpg'),
(92727, 6497, 'Kanojo Okarishimasu S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196374.mp4', 'http://gstaticontent.com/images/1b0ae2e3b9f2752e4ada3074517db7bd.jpg'),
(92728, 6497, 'Kanojo Okarishimasu S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196375.mp4', 'http://gstaticontent.com/images/1b0ae2e3b9f2752e4ada3074517db7bd.jpg'),
(92729, 6497, 'Kanojo Okarishimasu S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196376.mp4', 'http://gstaticontent.com/images/1b0ae2e3b9f2752e4ada3074517db7bd.jpg'),
(92730, 6497, 'Kanojo Okarishimasu S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196377.mp4', 'http://gstaticontent.com/images/1b0ae2e3b9f2752e4ada3074517db7bd.jpg'),
(92731, 6497, 'Kanojo Okarishimasu S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196378.mp4', 'http://gstaticontent.com/images/1b0ae2e3b9f2752e4ada3074517db7bd.jpg'),
(92732, 6497, 'Kanojo Okarishimasu S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196379.mp4', 'http://gstaticontent.com/images/1b0ae2e3b9f2752e4ada3074517db7bd.jpg'),
(92733, 6497, 'Kanojo Okarishimasu S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196380.mp4', 'http://gstaticontent.com/images/1b0ae2e3b9f2752e4ada3074517db7bd.jpg'),
(92734, 6497, 'Kanojo Okarishimasu S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196381.mp4', 'http://gstaticontent.com/images/1b0ae2e3b9f2752e4ada3074517db7bd.jpg'),
(92735, 6136, 'Mahoutsukai Reimeiki S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196346.mp4', 'http://timg.bdta.pro/images/512f78373cf34035dd345886a020ba4f.jpg'),
(92736, 6136, 'Mahoutsukai Reimeiki S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196347.mp4', 'http://timg.bdta.pro/images/34d317786cd7c18bc6fd39daf6ab9422.jpg'),
(92737, 6136, 'Mahoutsukai Reimeiki S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196348.mp4', 'http://timg.bdta.pro/images/2ecf38b98856a842aeca8413f18676b1.jpg'),
(92738, 6136, 'Mahoutsukai Reimeiki S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196349.mp4', 'http://timg.bdta.pro/images/ca78b40b493566b94f8ff4fda67686f1.jpg'),
(92739, 6136, 'Mahoutsukai Reimeiki S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196350.mp4', 'http://timg.bdta.pro/images/4e991867f3ea55b35cf0f7cf4d124fbc.jpg'),
(92740, 6136, 'Mahoutsukai Reimeiki S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196351.mp4', 'http://timg.bdta.pro/images/57fb155d08902e605257d564f17a4527.jpg'),
(92741, 6136, 'Mahoutsukai Reimeiki S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196352.mp4', 'http://timg.bdta.pro/images/7d8192daa203678eed47c7bd214d7192.jpg'),
(92742, 6136, 'Mahoutsukai Reimeiki S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196353.mp4', 'http://timg.bdta.pro/images/9d3c5ecf542e379ba7213274405b0522.jpg'),
(92743, 6136, 'Mahoutsukai Reimeiki S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196354.mp4', 'http://timg.bdta.pro/images/3b786e2606c9c202b04a53eaad23d660.jpg'),
(92744, 6136, 'Mahoutsukai Reimeiki S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196355.mp4', 'http://timg.bdta.pro/images/a4da0f8d56c3e4297df6b1f31991c614.jpg'),
(92745, 6136, 'Mahoutsukai Reimeiki S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196356.mp4', 'http://timg.bdta.pro/images/8dd1bc053a06bc5bc491a6338441d7e7.jpg'),
(92746, 6136, 'Mahoutsukai Reimeiki S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196357.mp4', 'http://timg.bdta.pro/images/d6a8a3df395f189643a9b7a59adb9f95.jpg'),
(92747, 6498, 'O Clube da Meia-Noite S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196336.mp4', 'http://timg.bdta.pro/images/3e24f6dba706ce8fd9c165d4e12852d4.jpg'),
(92748, 6498, 'O Clube da Meia-Noite S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196337.mp4', 'http://timg.bdta.pro/images/4b86a7efd6d5b2ea7f982367aa46cb70.jpg'),
(92749, 6498, 'O Clube da Meia-Noite S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196338.mp4', 'http://timg.bdta.pro/images/04b2967347d0e29590f88937fe61fcf4.jpg'),
(92750, 6498, 'O Clube da Meia-Noite S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196339.mp4', 'http://timg.bdta.pro/images/3f86ee5499691a63c05d398f0a990384.jpg'),
(92751, 6498, 'O Clube da Meia-Noite S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196340.mp4', 'http://timg.bdta.pro/images/73696ce874b15a840a1af1bc13a72272.jpg'),
(92752, 6498, 'O Clube da Meia-Noite S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196341.mp4', 'http://timg.bdta.pro/images/a1b890bf7e9c111cd37fd2e9cc69a9a3.jpg'),
(92753, 6498, 'O Clube da Meia-Noite S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196342.mp4', 'http://timg.bdta.pro/images/3516dc0e2e05168bd03d57e8d05519c6.jpg'),
(92754, 6498, 'O Clube da Meia-Noite S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196343.mp4', 'http://timg.bdta.pro/images/c6308aae83748fcfb78e94ddf3b7a281.jpg'),
(92755, 6498, 'O Clube da Meia-Noite S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196344.mp4', 'http://timg.bdta.pro/images/df5864f502809a629db7fb4fb075c3de.jpg'),
(92756, 6498, 'O Clube da Meia-Noite S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196345.mp4', 'http://timg.bdta.pro/images/486dcb02f02a455a8d7450106e571713.jpg'),
(92757, 6499, 'O Curioso Mundo de James S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246683.mp4', 'http://timg.bdta.pro/images/75b3ad899389001a94bf0c9fc6d729cf.jpg'),
(92758, 6499, 'O Curioso Mundo de James S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246684.mp4', 'http://timg.bdta.pro/images/55acfa10822bf105dfd0d4b1c72ff3ef.jpg'),
(92759, 6499, 'O Curioso Mundo de James S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246685.mp4', 'http://timg.bdta.pro/images/11f8343ea950f5a38fb9da20c8ed6fba.jpg'),
(92760, 6499, 'O Curioso Mundo de James S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246686.mp4', 'http://timg.bdta.pro/images/8b1d2a8cf8794bd7be548e2d5e52e396.jpg'),
(92761, 6499, 'O Curioso Mundo de James S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246687.mp4', 'http://timg.bdta.pro/images/1b7abdc5b8bab0ca248472665474cd6b.jpg'),
(92762, 6499, 'O Curioso Mundo de James S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246688.mp4', 'http://timg.bdta.pro/images/ae55101b9d298b1674b2661c9cafdda8.jpg'),
(92763, 6499, 'O Curioso Mundo de James S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246689.mp4', 'http://timg.bdta.pro/images/556ac67bbd061c993cba0118f3cf95f8.jpg'),
(92764, 6499, 'O Curioso Mundo de James S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246690.mp4', 'http://timg.bdta.pro/images/1d28b33a05b9fb3d149d28d86b72bbf3.jpg'),
(92765, 6499, 'O Curioso Mundo de James S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246691.mp4', 'http://timg.bdta.pro/images/376deca2c451ea12cae713230b740399.jpg'),
(92766, 6499, 'O Curioso Mundo de James S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246692.mp4', 'http://timg.bdta.pro/images/01f207cd736c8570aea0c7ae33f803ea.jpg'),
(92767, 6499, 'O Curioso Mundo de James S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246693.mp4', 'http://timg.bdta.pro/images/59fc5ef9059e4927e0272d1b41624c8b.jpg'),
(92768, 6499, 'O Curioso Mundo de James S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246694.mp4', 'http://timg.bdta.pro/images/ce6b193094dfc97085f692d58c29064e.jpg'),
(92769, 6500, 'O Curioso Mundo de James S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246695.mp4', 'http://gstaticontent.com/images/914f06c2ee15c7084550219a9cb8ba1d.jpg'),
(92770, 6500, 'O Curioso Mundo de James S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246696.mp4', 'http://gstaticontent.com/images/914f06c2ee15c7084550219a9cb8ba1d.jpg'),
(92771, 6500, 'O Curioso Mundo de James S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246697.mp4', 'http://gstaticontent.com/images/914f06c2ee15c7084550219a9cb8ba1d.jpg'),
(92772, 6500, 'O Curioso Mundo de James S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246698.mp4', 'http://gstaticontent.com/images/914f06c2ee15c7084550219a9cb8ba1d.jpg'),
(92773, 6500, 'O Curioso Mundo de James S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246699.mp4', 'http://gstaticontent.com/images/914f06c2ee15c7084550219a9cb8ba1d.jpg'),
(92774, 6500, 'O Curioso Mundo de James S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246700.mp4', 'http://gstaticontent.com/images/914f06c2ee15c7084550219a9cb8ba1d.jpg'),
(92775, 6500, 'O Curioso Mundo de James S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246701.mp4', 'http://gstaticontent.com/images/914f06c2ee15c7084550219a9cb8ba1d.jpg'),
(92776, 6500, 'O Curioso Mundo de James S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246702.mp4', 'http://gstaticontent.com/images/914f06c2ee15c7084550219a9cb8ba1d.jpg'),
(92777, 6501, 'O Terremoto do Everest S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196333.mp4', 'http://gstaticontent.com/images/870c487e2e6a5711935398cc0942b35e.jpg'),
(92778, 6501, 'O Terremoto do Everest S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196334.mp4', 'http://gstaticontent.com/images/870c487e2e6a5711935398cc0942b35e.jpg'),
(92779, 6501, 'O Terremoto do Everest S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196335.mp4', 'http://gstaticontent.com/images/870c487e2e6a5711935398cc0942b35e.jpg'),
(92780, 6502, 'Ordinary Joe S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196304.mp4', 'http://timg.bdta.pro/images/f0558d5ef62b26ccedec82a490871382.jpg'),
(92781, 6502, 'Ordinary Joe S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196305.mp4', 'http://timg.bdta.pro/images/e315901fe2dcbf6180d20a5020e3cca6.jpg'),
(92782, 6502, 'Ordinary Joe S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196306.mp4', 'http://timg.bdta.pro/images/4872c5584c2a5ad9295065d5b7286f0a.jpg'),
(92783, 6502, 'Ordinary Joe S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196307.mp4', 'http://timg.bdta.pro/images/4d09dacacb0da09c703900636187fbfc.jpg'),
(92784, 6502, 'Ordinary Joe S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196308.mp4', 'http://timg.bdta.pro/images/9938b3980ef035db74480fd622ba62c3.jpg'),
(92785, 6502, 'Ordinary Joe S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196309.mp4', 'http://timg.bdta.pro/images/72278cc0ba4fe6231d55f8c6e56898ab.jpg'),
(92786, 6502, 'Ordinary Joe S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196310.mp4', 'http://timg.bdta.pro/images/51e3639a2ae357311e51a6adcada9ae6.jpg'),
(92787, 6502, 'Ordinary Joe S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196311.mp4', 'http://timg.bdta.pro/images/dc194956d8c8accabfd4a4d9b55ff7c4.jpg'),
(92788, 6502, 'Ordinary Joe S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196312.mp4', 'http://timg.bdta.pro/images/f40d1e3bbf45a4198a0952350c24e9c6.jpg'),
(92789, 6502, 'Ordinary Joe S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196313.mp4', 'http://timg.bdta.pro/images/e9276565390269d21c50663b01f8659c.jpg'),
(92790, 6502, 'Ordinary Joe S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196314.mp4', 'http://timg.bdta.pro/images/5c4aee716fd026a2c63feb14b0949073.jpg'),
(92791, 6502, 'Ordinary Joe S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196315.mp4', 'http://timg.bdta.pro/images/11b9c93677ea71d1286d756a10fb1a04.jpg'),
(92792, 6502, 'Ordinary Joe S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196316.mp4', 'http://timg.bdta.pro/images/e48c47771f5eff3cbbf50def053068bb.jpg'),
(92793, 6503, 'Os Fantasmas de Devil Perch S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196303.mp4', 'http://gstaticontent.com/images/f79deab2af4f0f6483e489f21b2714fc.jpg'),
(92794, 6504, 'Os Mistérios de Rock Island S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196293.mp4', 'http://gstaticontent.com/images/4161ebb8a2e9adb99c14ce1f1a17fe57.jpg'),
(92795, 6504, 'Os Mistérios de Rock Island S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196294.mp4', 'http://gstaticontent.com/images/4161ebb8a2e9adb99c14ce1f1a17fe57.jpg'),
(92796, 6504, 'Os Mistérios de Rock Island S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196295.mp4', 'http://gstaticontent.com/images/4161ebb8a2e9adb99c14ce1f1a17fe57.jpg'),
(92797, 6504, 'Os Mistérios de Rock Island S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196296.mp4', 'http://gstaticontent.com/images/4161ebb8a2e9adb99c14ce1f1a17fe57.jpg'),
(92798, 6504, 'Os Mistérios de Rock Island S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196297.mp4', 'http://gstaticontent.com/images/4161ebb8a2e9adb99c14ce1f1a17fe57.jpg'),
(92799, 6504, 'Os Mistérios de Rock Island S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196298.mp4', 'http://gstaticontent.com/images/4161ebb8a2e9adb99c14ce1f1a17fe57.jpg'),
(92800, 6504, 'Os Mistérios de Rock Island S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196299.mp4', 'http://gstaticontent.com/images/4161ebb8a2e9adb99c14ce1f1a17fe57.jpg'),
(92801, 6504, 'Os Mistérios de Rock Island S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196300.mp4', 'http://gstaticontent.com/images/4161ebb8a2e9adb99c14ce1f1a17fe57.jpg'),
(92802, 6504, 'Os Mistérios de Rock Island S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196301.mp4', 'http://gstaticontent.com/images/4161ebb8a2e9adb99c14ce1f1a17fe57.jpg'),
(92803, 6504, 'Os Mistérios de Rock Island S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196302.mp4', 'http://gstaticontent.com/images/4161ebb8a2e9adb99c14ce1f1a17fe57.jpg'),
(92804, 6505, 'Pearson S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196283.mp4', 'http://timg.bdta.pro/images/6f39bb0bf8e74a808ac5ea919d40615f.jpg'),
(92805, 6505, 'Pearson S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/562983.mp4', 'http://gstaticontent.com/images/730c874c7ee58b0eb0f442a8a4eb52a1.jpg'),
(92806, 6505, 'Pearson S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196285.mp4', 'http://timg.bdta.pro/images/00d3cabb25491600eee172432bb54447.jpg'),
(92807, 6505, 'Pearson S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196286.mp4', 'http://timg.bdta.pro/images/2264975f40e516cc70e0bb91c1ce9660.jpg'),
(92808, 6505, 'Pearson S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196287.mp4', 'http://timg.bdta.pro/images/c0db6f345c9b79f1d60acecfe225bc3d.jpg'),
(92809, 6505, 'Pearson S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196288.mp4', 'http://timg.bdta.pro/images/c3ab5d2097efc9c07cc21d1b16a86127.jpg'),
(92810, 6505, 'Pearson S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196289.mp4', 'http://timg.bdta.pro/images/5ca5788ce740ac436c94030d12211ff9.jpg'),
(92811, 6505, 'Pearson S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196290.mp4', 'http://timg.bdta.pro/images/fdf360d236a45f7e02e4d10166912a63.jpg'),
(92812, 6505, 'Pearson S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196291.mp4', 'http://timg.bdta.pro/images/5ee305ac0e45965ca4db5c745d324885.jpg'),
(92813, 6505, 'Pearson S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196292.mp4', 'http://timg.bdta.pro/images/9cddb755834ec722f0202e60e45e336c.jpg'),
(92814, 6506, 'Rota 66: A Polícia que Mata S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196275.mp4', 'http://gstaticontent.com/images/ec98217f5916e2b902640a3bb7b4aa7b.jpg'),
(92815, 6506, 'Rota 66: A Polícia que Mata S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196276.mp4', 'http://gstaticontent.com/images/ec98217f5916e2b902640a3bb7b4aa7b.jpg'),
(92816, 6506, 'Rota 66: A Polícia que Mata S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196277.mp4', 'http://gstaticontent.com/images/ec98217f5916e2b902640a3bb7b4aa7b.jpg'),
(92817, 6506, 'Rota 66: A Polícia que Mata S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196278.mp4', 'http://gstaticontent.com/images/ec98217f5916e2b902640a3bb7b4aa7b.jpg'),
(92818, 6506, 'Rota 66: A Polícia que Mata S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196279.mp4', 'http://gstaticontent.com/images/ec98217f5916e2b902640a3bb7b4aa7b.jpg'),
(92819, 6506, 'Rota 66: A Polícia que Mata S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196280.mp4', 'http://gstaticontent.com/images/ec98217f5916e2b902640a3bb7b4aa7b.jpg'),
(92820, 6506, 'Rota 66: A Polícia que Mata S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196281.mp4', 'http://gstaticontent.com/images/ec98217f5916e2b902640a3bb7b4aa7b.jpg'),
(92821, 6506, 'Rota 66: A Polícia que Mata S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196282.mp4', 'http://gstaticontent.com/images/ec98217f5916e2b902640a3bb7b4aa7b.jpg'),
(92822, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196229.mp4', 'http://timg.bdta.pro/images/723e422d7d22b75db3d69d8c84ba1804.jpg'),
(92823, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196230.mp4', 'http://timg.bdta.pro/images/c97fb2169019637e8a7fea45a70ff40a.jpg'),
(92824, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196231.mp4', 'http://timg.bdta.pro/images/2295de23714d714dc2d37669a391b0ac.jpg'),
(92825, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196232.mp4', 'http://timg.bdta.pro/images/632759173d92e1c6bca7322c697bb127.jpg'),
(92826, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196233.mp4', 'http://timg.bdta.pro/images/57be0c0ac57d88f4ae446107c3c2404c.jpg'),
(92827, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196234.mp4', 'http://timg.bdta.pro/images/da04b4804685048e7c87794870c14c8b.jpg'),
(92828, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196235.mp4', 'http://timg.bdta.pro/images/6d526c813385cac329dfcc0939517dc9.jpg'),
(92829, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196236.mp4', 'http://timg.bdta.pro/images/ecebb5a8099b145427d5a40ace6362a5.jpg'),
(92830, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196237.mp4', 'http://timg.bdta.pro/images/a1d9bc7515977085ba6cf1691cb107ad.jpg'),
(92831, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196238.mp4', 'http://timg.bdta.pro/images/a73c248dcbdcaa0c2de04cecc55594a6.jpg'),
(92832, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196239.mp4', 'http://timg.bdta.pro/images/f91fa3ef502628e441f9f1011d6826ce.jpg'),
(92833, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196240.mp4', 'http://timg.bdta.pro/images/1a1ae44b263f827bd356cae53fb29f96.jpg'),
(92834, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196241.mp4', 'http://timg.bdta.pro/images/1d020a5921390199063dd4b7e1b537f6.jpg'),
(92835, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/196242.mp4', 'http://timg.bdta.pro/images/b257ee1cc3786b78b473cbda33941208.jpg'),
(92836, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/196243.mp4', 'http://timg.bdta.pro/images/c3362bd0e137ff3254a355b678f0ca99.jpg'),
(92837, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/196244.mp4', 'http://timg.bdta.pro/images/dec8653b96973f4236795fe12fab00ee.jpg'),
(92838, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/196245.mp4', 'http://timg.bdta.pro/images/f34bef8f00d602d5d3817bc7d4c7560d.jpg'),
(92839, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/196246.mp4', 'http://timg.bdta.pro/images/f1dd2e34f7459da1d5721f8919e5d37a.jpg'),
(92840, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/196247.mp4', 'http://timg.bdta.pro/images/28f254962509560f1694ee4108ffb121.jpg'),
(92841, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/196248.mp4', 'http://timg.bdta.pro/images/5b77c6ed53c1b9ae2c5b0549b17eb62a.jpg'),
(92842, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/196249.mp4', 'http://timg.bdta.pro/images/78ac1845c0bf3ddf2fdf2ca0e7562904.jpg'),
(92843, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/196250.mp4', 'http://timg.bdta.pro/images/bb2af35a210d7c11485404e6e18dd3e6.jpg'),
(92844, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/196251.mp4', 'http://timg.bdta.pro/images/0d8731df8470ba2c492a3217621121cd.jpg'),
(92845, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/196252.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92846, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/196253.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92847, 6507, 'Side Hustle: Uma Tarefa Complicada S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/196254.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92848, 6508, 'Side Hustle: Uma Tarefa Complicada S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196255.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92849, 6508, 'Side Hustle: Uma Tarefa Complicada S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196256.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92850, 6508, 'Side Hustle: Uma Tarefa Complicada S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196257.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(92851, 6508, 'Side Hustle: Uma Tarefa Complicada S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196258.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92852, 6508, 'Side Hustle: Uma Tarefa Complicada S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196259.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92853, 6508, 'Side Hustle: Uma Tarefa Complicada S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196260.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92854, 6508, 'Side Hustle: Uma Tarefa Complicada S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196261.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92855, 6508, 'Side Hustle: Uma Tarefa Complicada S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196262.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92856, 6508, 'Side Hustle: Uma Tarefa Complicada S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196263.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92857, 6508, 'Side Hustle: Uma Tarefa Complicada S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196264.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92858, 6508, 'Side Hustle: Uma Tarefa Complicada S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196265.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92859, 6508, 'Side Hustle: Uma Tarefa Complicada S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196266.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92860, 6508, 'Side Hustle: Uma Tarefa Complicada S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196267.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92861, 6508, 'Side Hustle: Uma Tarefa Complicada S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/196268.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92862, 6508, 'Side Hustle: Uma Tarefa Complicada S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/196269.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92863, 6508, 'Side Hustle: Uma Tarefa Complicada S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/196270.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92864, 6508, 'Side Hustle: Uma Tarefa Complicada S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/196271.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92865, 6508, 'Side Hustle: Uma Tarefa Complicada S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/196272.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92866, 6508, 'Side Hustle: Uma Tarefa Complicada S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/196273.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92867, 6508, 'Side Hustle: Uma Tarefa Complicada S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/196274.mp4', 'http://gstaticontent.com/images/10e98cbdd57bb6b3a462d8eda9d01922.jpg'),
(92868, 6509, 'Theodosia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196203.mp4', 'http://timg.bdta.pro/images/b563f3251578d8e037ccc1babaf49462.jpg'),
(92869, 6509, 'Theodosia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196204.mp4', 'http://timg.bdta.pro/images/aec8381aefc9420fbc683020a0d03837.jpg'),
(92870, 6509, 'Theodosia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196205.mp4', 'http://timg.bdta.pro/images/caeb4a8ef1c63b22bef86d9151760a23.jpg'),
(92871, 6509, 'Theodosia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196206.mp4', 'http://timg.bdta.pro/images/3922e2f3380805a4485253b0a46e6def.jpg'),
(92872, 6509, 'Theodosia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196207.mp4', 'http://timg.bdta.pro/images/b2daee654bd9738c69c8b84e9e7ac38a.jpg'),
(92873, 6509, 'Theodosia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196208.mp4', 'http://timg.bdta.pro/images/8475d9449a530dcea3317f3a3bfdde3f.jpg'),
(92874, 6509, 'Theodosia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196209.mp4', 'http://timg.bdta.pro/images/717fbdc79bd8ff3f8481cff2bdbd07b8.jpg'),
(92875, 6509, 'Theodosia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196210.mp4', 'http://timg.bdta.pro/images/1aea460daa753c0ecd8e14d9acc8f24a.jpg'),
(92876, 6509, 'Theodosia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196211.mp4', 'http://timg.bdta.pro/images/ea83ae7f326db3555c4b832f29db889f.jpg'),
(92877, 6509, 'Theodosia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196212.mp4', 'http://timg.bdta.pro/images/c44a849b68d96be191585bd3f39849f4.jpg'),
(92878, 6509, 'Theodosia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196213.mp4', 'http://timg.bdta.pro/images/e4a4ecc70d2dfcf74383427fcffd8538.jpg'),
(92879, 6509, 'Theodosia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196214.mp4', 'http://timg.bdta.pro/images/e4437439dcedbc29cf657c2a80df0d73.jpg'),
(92880, 6509, 'Theodosia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196215.mp4', 'http://timg.bdta.pro/images/553d01bc5e97d5b501e699953beb61fb.jpg'),
(92881, 6509, 'Theodosia S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/196216.mp4', 'http://timg.bdta.pro/images/c8672165e168c1f888f6500f366df554.jpg'),
(92882, 6509, 'Theodosia S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/196217.mp4', 'http://timg.bdta.pro/images/4ca2e9bb50cbf0082a5693a00530fccc.jpg'),
(92883, 6509, 'Theodosia S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/196218.mp4', 'http://timg.bdta.pro/images/df6bc918423823b0dda185638673981a.jpg'),
(92884, 6509, 'Theodosia S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/196219.mp4', 'http://timg.bdta.pro/images/f013dc12856950187b02e9c414ee81e7.jpg'),
(92885, 6509, 'Theodosia S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/196220.mp4', 'http://timg.bdta.pro/images/01b62ec8f910aa465a64c4c9a0f74dad.jpg'),
(92886, 6509, 'Theodosia S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/196221.mp4', 'http://timg.bdta.pro/images/04e96aacc4ab489cb9b305b34a256672.jpg'),
(92887, 6509, 'Theodosia S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/196222.mp4', 'http://timg.bdta.pro/images/33e519e591efb60fcacd97a29eadc518.jpg'),
(92888, 6509, 'Theodosia S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/196223.mp4', 'http://timg.bdta.pro/images/b9fee23255b35b66535022ce9ac84b9f.jpg'),
(92889, 6509, 'Theodosia S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/196224.mp4', 'http://timg.bdta.pro/images/2a014aecec186decd976270b4a2b1b64.jpg'),
(92890, 6509, 'Theodosia S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/196225.mp4', 'http://timg.bdta.pro/images/43c5b8e26d32507acec74cddd78a78d5.jpg'),
(92891, 6509, 'Theodosia S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/196226.mp4', 'http://timg.bdta.pro/images/6c9dbd2ba029cc57445651814943b1a2.jpg'),
(92892, 6509, 'Theodosia S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/196227.mp4', 'http://timg.bdta.pro/images/73b91ccf1dc101a15f410647261bee88.jpg'),
(92893, 6509, 'Theodosia S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/196228.mp4', 'http://timg.bdta.pro/images/8c5ede6f0e0b7ec58bd44bcdc49f3927.jpg'),
(92894, 6510, 'Warped! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/196190.mp4', 'http://gstaticontent.com/images/25669099f93254eeacc597c588d692fa.jpg'),
(92895, 6510, 'Warped! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/196191.mp4', 'http://timg.bdta.pro/images/800947be297e420a16a6b199d11a4720.jpg'),
(92896, 6510, 'Warped! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/196192.mp4', 'http://gstaticontent.com/images/25669099f93254eeacc597c588d692fa.jpg'),
(92897, 6510, 'Warped! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/196193.mp4', 'http://gstaticontent.com/images/25669099f93254eeacc597c588d692fa.jpg'),
(92898, 6510, 'Warped! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/196194.mp4', 'http://gstaticontent.com/images/25669099f93254eeacc597c588d692fa.jpg'),
(92899, 6510, 'Warped! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/196195.mp4', 'http://gstaticontent.com/images/25669099f93254eeacc597c588d692fa.jpg'),
(92900, 6510, 'Warped! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/196196.mp4', 'http://gstaticontent.com/images/25669099f93254eeacc597c588d692fa.jpg'),
(92901, 6510, 'Warped! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/196197.mp4', 'http://gstaticontent.com/images/25669099f93254eeacc597c588d692fa.jpg'),
(92902, 6510, 'Warped! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/196198.mp4', 'http://gstaticontent.com/images/25669099f93254eeacc597c588d692fa.jpg'),
(92903, 6510, 'Warped! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/196199.mp4', 'http://gstaticontent.com/images/25669099f93254eeacc597c588d692fa.jpg'),
(92904, 6510, 'Warped! S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/196200.mp4', 'http://gstaticontent.com/images/25669099f93254eeacc597c588d692fa.jpg'),
(92905, 6510, 'Warped! S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/196201.mp4', 'http://gstaticontent.com/images/25669099f93254eeacc597c588d692fa.jpg'),
(92906, 6510, 'Warped! S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/196202.mp4', 'http://gstaticontent.com/images/25669099f93254eeacc597c588d692fa.jpg'),
(92907, 6511, 'Fronteira S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195942.mp4', 'http://timg.bdta.pro/images/ec55d85f18ebe77583c8ceadbfdc587b.jpg'),
(92908, 6511, 'Fronteira S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195943.mp4', 'http://timg.bdta.pro/images/781e9472351b2124bad5c6cce6537e60.jpg'),
(92909, 6511, 'Fronteira S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195944.mp4', 'http://timg.bdta.pro/images/03ef1e05eec7936119e39d7bf8d72587.jpg'),
(92910, 6511, 'Fronteira S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195945.mp4', 'http://timg.bdta.pro/images/45e047bd21a05a1a03caa45703453899.jpg'),
(92911, 6511, 'Fronteira S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195946.mp4', 'http://timg.bdta.pro/images/0b7dc524b5fae177d47b711899dc88ca.jpg'),
(92912, 6511, 'Fronteira S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195947.mp4', 'http://timg.bdta.pro/images/d6b3d92012ba0dc93f3b9761a7f59a1c.jpg'),
(92913, 6512, 'Fronteira S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195948.mp4', 'http://timg.bdta.pro/images/a68d2330b57442c3004df9d78bb0d553.jpg'),
(92914, 6512, 'Fronteira S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195949.mp4', 'http://timg.bdta.pro/images/bc34873fc39692ede698662d7ff8c5d6.jpg'),
(92915, 6512, 'Fronteira S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195950.mp4', 'http://timg.bdta.pro/images/d1d52869a5359d7261772ce39706fbec.jpg'),
(92916, 6512, 'Fronteira S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195951.mp4', 'http://timg.bdta.pro/images/7a049260e9f728a797d8e7aaee794ce1.jpg'),
(92917, 6512, 'Fronteira S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195952.mp4', 'http://timg.bdta.pro/images/3678240a05d476bee9a51507e491075d.jpg'),
(92918, 6512, 'Fronteira S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195953.mp4', 'http://timg.bdta.pro/images/2fc031c3c3ca8e5ee043278b4dcade80.jpg'),
(92919, 6513, 'Fronteira S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195954.mp4', 'http://timg.bdta.pro/images/b42e3ce6b19278b9f681782d54b6113f.jpg'),
(92920, 6513, 'Fronteira S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195955.mp4', 'http://timg.bdta.pro/images/32fde4a85991bcad2767844b51ccdd9b.jpg'),
(92921, 6513, 'Fronteira S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195956.mp4', 'http://timg.bdta.pro/images/808f98e3b4e944c35991a62573ebdd37.jpg'),
(92922, 6513, 'Fronteira S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195957.mp4', 'http://timg.bdta.pro/images/589e4cae6c5e1a9f4d4e983135c2fb7e.jpg'),
(92923, 6513, 'Fronteira S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195958.mp4', 'http://timg.bdta.pro/images/16edd4ed95e10908b93c358257d7d4a6.jpg'),
(92924, 6513, 'Fronteira S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195959.mp4', 'http://timg.bdta.pro/images/03d8bcbb6ceb3b6c83528819726ca229.jpg'),
(92925, 6514, 'A Primeira Dama do Estado Islamico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195941.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/sKaZoPFqxWYhUJf1u9OaHXwQkK.jpg'),
(92926, 6515, 'A Rainha Serpente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198981.mp4', 'http://timg.bdta.pro/images/3a3c7bb8a9e2d20403f2b0bab24b44e2.jpg'),
(92927, 6515, 'A Rainha Serpente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198982.mp4', 'http://timg.bdta.pro/images/3a52f20e01626e300c6ed3e73cf7c87b.jpg'),
(92928, 6515, 'A Rainha Serpente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198983.mp4', 'http://timg.bdta.pro/images/fc1d0b1cd21d97faae99453a7cbcc09c.jpg'),
(92929, 6515, 'A Rainha Serpente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198984.mp4', 'http://timg.bdta.pro/images/5ad7736e74ae804a584cd1594c526d20.jpg'),
(92930, 6515, 'A Rainha Serpente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198985.mp4', 'http://timg.bdta.pro/images/8eab0168ba13e4eda699c5380e36ab7c.jpg'),
(92931, 6515, 'A Rainha Serpente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198986.mp4', 'http://timg.bdta.pro/images/5585d43f5fec22c2c525a1b066281436.jpg'),
(92932, 6515, 'A Rainha Serpente S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198987.mp4', 'http://timg.bdta.pro/images/f9e9b78171659cac3cfd7bb9335386d1.jpg'),
(92933, 6515, 'A Rainha Serpente S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198988.mp4', 'http://image.tmdb.org/t/p/w1280/jF69a1TNsz0zWFlVQivDe3gLstN.jpg'),
(92934, 6516, 'A Rainha Serpente S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413064.mp4', 'http://gstaticontent.com/images/498629fc8bb538d19ae8213a18f9b4e7.jpg'),
(92935, 6516, 'A Rainha Serpente S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416120.mp4', 'http://gstaticontent.com/images/498629fc8bb538d19ae8213a18f9b4e7.jpg'),
(92936, 6516, 'A Rainha Serpente S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425588.mp4', 'http://gstaticontent.com/images/498629fc8bb538d19ae8213a18f9b4e7.jpg'),
(92937, 6516, 'A Rainha Serpente S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425589.mp4', 'http://gstaticontent.com/images/498629fc8bb538d19ae8213a18f9b4e7.jpg'),
(92938, 6516, 'A Rainha Serpente S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/432762.mp4', 'http://gstaticontent.com/images/498629fc8bb538d19ae8213a18f9b4e7.jpg'),
(92939, 6516, 'A Rainha Serpente S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/437689.mp4', 'http://gstaticontent.com/images/498629fc8bb538d19ae8213a18f9b4e7.jpg'),
(92940, 6516, 'A Rainha Serpente S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/437690.mp4', 'http://gstaticontent.com/images/498629fc8bb538d19ae8213a18f9b4e7.jpg'),
(92941, 6516, 'A Rainha Serpente S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445074.mp4', 'http://gstaticontent.com/images/498629fc8bb538d19ae8213a18f9b4e7.jpg'),
(92942, 6517, 'Almost Paradise S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250777.mp4', 'http://timg.bdta.pro/images/dbdabd8ed395e2dac4c48112ce21f945.jpg'),
(92943, 6517, 'Almost Paradise S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250778.mp4', 'http://timg.bdta.pro/images/b5ecea5a43db4bdf46a90693aa0917cd.jpg'),
(92944, 6517, 'Almost Paradise S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250779.mp4', 'http://timg.bdta.pro/images/88b357f33d48a3514b83e95a6112b646.jpg'),
(92945, 6517, 'Almost Paradise S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250780.mp4', 'http://timg.bdta.pro/images/3731eb93304224b9bfea6a87cb83311b.jpg'),
(92946, 6517, 'Almost Paradise S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250781.mp4', 'http://timg.bdta.pro/images/b41441dbe280db257b53e324d02b20b3.jpg'),
(92947, 6517, 'Almost Paradise S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fRiju5MR8Vpx1fZGdzkd17rZXw9.jpg'),
(92948, 6517, 'Almost Paradise S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/84L1hiLTdoonbeuVormwS4YMW98.jpg'),
(92949, 6517, 'Almost Paradise S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250784.mp4', 'http://image.tmdb.org/t/p/w1280/sKyJwat6wfgzoM32UnwQqZMwpXk.jpg'),
(92950, 6517, 'Almost Paradise S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cMfGQSWQlgErCYM58E9miDOGVES.jpg'),
(92951, 6517, 'Almost Paradise S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mVk4Eezcv3xqNwVJW3dwJwMFu2F.jpg'),
(92952, 6518, 'Almost Paradise S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250787.mp4', 'http://gstaticontent.com/images/9ae5708768f0778e0c83125f7390c195.jpg'),
(92953, 6518, 'Almost Paradise S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250788.mp4', 'http://gstaticontent.com/images/9ae5708768f0778e0c83125f7390c195.jpg'),
(92954, 6518, 'Almost Paradise S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250789.mp4', 'http://gstaticontent.com/images/9ae5708768f0778e0c83125f7390c195.jpg'),
(92955, 6518, 'Almost Paradise S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250790.mp4', 'http://gstaticontent.com/images/9ae5708768f0778e0c83125f7390c195.jpg'),
(92956, 6518, 'Almost Paradise S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250791.mp4', 'http://gstaticontent.com/images/9ae5708768f0778e0c83125f7390c195.jpg'),
(92957, 6518, 'Almost Paradise S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250792.mp4', 'http://gstaticontent.com/images/9ae5708768f0778e0c83125f7390c195.jpg'),
(92958, 6518, 'Almost Paradise S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250793.mp4', 'http://gstaticontent.com/images/9ae5708768f0778e0c83125f7390c195.jpg'),
(92959, 6518, 'Almost Paradise S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250794.mp4', 'http://gstaticontent.com/images/9ae5708768f0778e0c83125f7390c195.jpg'),
(92960, 6518, 'Almost Paradise S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250795.mp4', 'http://gstaticontent.com/images/9ae5708768f0778e0c83125f7390c195.jpg'),
(92961, 6518, 'Almost Paradise S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250796.mp4', 'http://gstaticontent.com/images/9ae5708768f0778e0c83125f7390c195.jpg'),
(92962, 6519, 'Bem-Vindos à Vizinhança S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195934.mp4', 'http://timg.bdta.pro/images/9d5f71ba159c9328229ccee4137e0c84.jpg'),
(92963, 6519, 'Bem-Vindos à Vizinhança S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195935.mp4', 'http://timg.bdta.pro/images/fba3446abc6056a7356419e49ea70a02.jpg'),
(92964, 6519, 'Bem-Vindos à Vizinhança S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195936.mp4', 'http://timg.bdta.pro/images/1abec8bf16d7fd9e283be4158fde2f7b.jpg'),
(92965, 6519, 'Bem-Vindos à Vizinhança S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195937.mp4', 'http://timg.bdta.pro/images/be05520ef08a2a5bb1db88ee2fb4e9a8.jpg'),
(92966, 6519, 'Bem-Vindos à Vizinhança S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195938.mp4', 'http://timg.bdta.pro/images/b2c60793a93ff912e6cc1184850c7168.jpg'),
(92967, 6519, 'Bem-Vindos à Vizinhança S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195939.mp4', 'http://timg.bdta.pro/images/8150cb66fe649f52a6655ca236551861.jpg'),
(92968, 6519, 'Bem-Vindos à Vizinhança S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195940.mp4', 'http://timg.bdta.pro/images/e9cab68ad55422d1903fe79ee9a4f97e.jpg'),
(92969, 6520, 'Borboletas Negras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195928.mp4', 'http://timg.bdta.pro/images/99531d115abc2c26c3fcd534fbb8013d.jpg'),
(92970, 6520, 'Borboletas Negras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195929.mp4', 'http://timg.bdta.pro/images/4779174e58fd83b6df2d59d8d347b397.jpg'),
(92971, 6520, 'Borboletas Negras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195930.mp4', 'http://timg.bdta.pro/images/4c331d5b1f400ddf4bd05c21ded5fd89.jpg'),
(92972, 6520, 'Borboletas Negras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195931.mp4', 'http://timg.bdta.pro/images/aa16ca2731cfa5d3abd93105b6594e44.jpg'),
(92973, 6520, 'Borboletas Negras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195932.mp4', 'http://timg.bdta.pro/images/2f74e8d501b01490234554b915c149c1.jpg'),
(92974, 6520, 'Borboletas Negras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195933.mp4', 'http://timg.bdta.pro/images/b2a71fd2aa01a21efb1cbb5d0c0d9f89.jpg'),
(92975, 6521, 'Detetive Belascoarán S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195925.mp4', 'http://gstaticontent.com/images/9e5d478ecfcabf499363e21700c3ca95.jpg'),
(92976, 6521, 'Detetive Belascoarán S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195926.mp4', 'http://gstaticontent.com/images/9e5d478ecfcabf499363e21700c3ca95.jpg'),
(92977, 6521, 'Detetive Belascoarán S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195927.mp4', 'http://gstaticontent.com/images/9e5d478ecfcabf499363e21700c3ca95.jpg'),
(92978, 6522, 'Exception S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195917.mp4', 'http://timg.bdta.pro/images/2a900a9b85525279f8c390a1483d6017.jpg'),
(92979, 6522, 'Exception S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195918.mp4', 'http://timg.bdta.pro/images/1e407621e6b638dfdc61119f6cd777de.jpg'),
(92980, 6522, 'Exception S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195919.mp4', 'http://timg.bdta.pro/images/56402ab4611d089ab09204209333bfdf.jpg'),
(92981, 6522, 'Exception S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195920.mp4', 'http://timg.bdta.pro/images/161aee3f777fdf4f19af6ee9719f322e.jpg'),
(92982, 6522, 'Exception S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195921.mp4', 'http://timg.bdta.pro/images/aeb7d59cf8cfabdfe4012e4b28ccb8ad.jpg'),
(92983, 6522, 'Exception S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195922.mp4', 'http://timg.bdta.pro/images/b5ff5d81b00ac306a5661d7807a3cfdd.jpg'),
(92984, 6522, 'Exception S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195923.mp4', 'http://timg.bdta.pro/images/5aa1fe8fab8ad0710caccb2ad48d8d65.jpg'),
(92985, 6522, 'Exception S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195924.mp4', 'http://timg.bdta.pro/images/b053d720217b30adeb54c02c2e4e26f6.jpg'),
(92986, 6523, 'Funkbol S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195912.mp4', 'http://timg.bdta.pro/images/76178a317616696632a4011adef1b6cd.jpg'),
(92987, 6523, 'Funkbol S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195913.mp4', 'http://timg.bdta.pro/images/8c34ce9ca153bd0ac5ed4cebeb823534.jpg'),
(92988, 6523, 'Funkbol S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195914.mp4', 'http://timg.bdta.pro/images/e98019583200ca836009628602b5bab1.jpg'),
(92989, 6523, 'Funkbol S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195915.mp4', 'http://timg.bdta.pro/images/eec71156d63b4f1b4514821061203329.jpg'),
(92990, 6523, 'Funkbol S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195916.mp4', 'http://timg.bdta.pro/images/66b0fa5bbc6b9508c64ddd24d5fecd85.jpg'),
(92991, 6524, 'Guardiões da Floresta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213202.mp4', 'http://gstaticontent.com/images/5bbc733c25187b36f4817db4a71e04f4.jpg'),
(92992, 6524, 'Guardiões da Floresta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213203.mp4', 'http://gstaticontent.com/images/5bbc733c25187b36f4817db4a71e04f4.jpg'),
(92993, 6524, 'Guardiões da Floresta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213204.mp4', 'http://gstaticontent.com/images/5bbc733c25187b36f4817db4a71e04f4.jpg'),
(92994, 6524, 'Guardiões da Floresta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213205.mp4', 'http://gstaticontent.com/images/5bbc733c25187b36f4817db4a71e04f4.jpg'),
(92995, 6524, 'Guardiões da Floresta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213206.mp4', 'http://gstaticontent.com/images/5bbc733c25187b36f4817db4a71e04f4.jpg'),
(92996, 6524, 'Guardiões da Floresta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213207.mp4', 'http://gstaticontent.com/images/5bbc733c25187b36f4817db4a71e04f4.jpg'),
(92997, 6524, 'Guardiões da Floresta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213208.mp4', 'http://gstaticontent.com/images/5bbc733c25187b36f4817db4a71e04f4.jpg'),
(92998, 6524, 'Guardiões da Floresta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213209.mp4', 'http://gstaticontent.com/images/5bbc733c25187b36f4817db4a71e04f4.jpg'),
(92999, 6524, 'Guardiões da Floresta S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213210.mp4', 'http://gstaticontent.com/images/5bbc733c25187b36f4817db4a71e04f4.jpg'),
(93000, 6524, 'Guardiões da Floresta S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213211.mp4', 'http://gstaticontent.com/images/5bbc733c25187b36f4817db4a71e04f4.jpg'),
(93001, 6525, 'Guardiões da Floresta S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213212.mp4', 'http://gstaticontent.com/images/5bbc733c25187b36f4817db4a71e04f4.jpg'),
(93002, 6525, 'Guardiões da Floresta S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213213.mp4', 'http://gstaticontent.com/images/5bbc733c25187b36f4817db4a71e04f4.jpg'),
(93003, 6525, 'Guardiões da Floresta S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213214.mp4', 'http://gstaticontent.com/images/5bbc733c25187b36f4817db4a71e04f4.jpg'),
(93004, 6525, 'Guardiões da Floresta S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213215.mp4', 'http://gstaticontent.com/images/5bbc733c25187b36f4817db4a71e04f4.jpg'),
(93005, 6525, 'Guardiões da Floresta S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213216.mp4', 'http://gstaticontent.com/images/5bbc733c25187b36f4817db4a71e04f4.jpg'),
(93006, 6525, 'Guardiões da Floresta S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213217.mp4', 'http://gstaticontent.com/images/5bbc733c25187b36f4817db4a71e04f4.jpg'),
(93007, 6525, 'Guardiões da Floresta S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213218.mp4', 'http://gstaticontent.com/images/5bbc733c25187b36f4817db4a71e04f4.jpg'),
(93008, 6525, 'Guardiões da Floresta S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213219.mp4', 'http://gstaticontent.com/images/5bbc733c25187b36f4817db4a71e04f4.jpg'),
(93009, 6525, 'Guardiões da Floresta S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213220.mp4', 'http://gstaticontent.com/images/5bbc733c25187b36f4817db4a71e04f4.jpg'),
(93010, 6525, 'Guardiões da Floresta S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213221.mp4', 'http://gstaticontent.com/images/5bbc733c25187b36f4817db4a71e04f4.jpg'),
(93011, 6526, 'Kenan S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/569036.mp4', 'http://gstaticontent.com/images/9b53e3d574bbf3654b8a84b8e1ae6639.jpg'),
(93012, 6526, 'Kenan S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/569038.mp4', 'http://gstaticontent.com/images/8cd0835e72a8c8e520d6b5f948751c55.jpg'),
(93013, 6526, 'Kenan S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/569040.mp4', 'http://gstaticontent.com/images/7a1f7c8d3b73e87f828a52cacbdba484.jpg'),
(93014, 6526, 'Kenan S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/569042.mp4', 'http://gstaticontent.com/images/e93d163029bdc487537f115ceb0a62e9.jpg'),
(93015, 6526, 'Kenan S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/569044.mp4', 'http://gstaticontent.com/images/7f389121d101ca3d44ee64e6b2e899a0.jpg'),
(93016, 6526, 'Kenan S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/569046.mp4', 'http://gstaticontent.com/images/f1727352d9712ae8b3a6175322bc15ae.jpg'),
(93017, 6526, 'Kenan S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/569048.mp4', 'http://gstaticontent.com/images/362fe4694a8e4740e42f166c807c7573.jpg'),
(93018, 6526, 'Kenan S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/569050.mp4', 'http://gstaticontent.com/images/772771603e625408bd9a4160efcf92a5.jpg'),
(93019, 6526, 'Kenan S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/569052.mp4', 'http://gstaticontent.com/images/95887db0afc0eede05219325c27d64c2.jpg'),
(93020, 6526, 'Kenan S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215444.mp4', 'http://image.tmdb.org/t/p/w1280/1cQkfbPBwtqLnmWrq5nTl72lKMA.jpg'),
(93021, 6527, 'Meu Tio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195906.mp4', 'http://timg.bdta.pro/images/769cd8b9d2910798e1ba4925c47ac828.jpg'),
(93022, 6527, 'Meu Tio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195907.mp4', 'http://timg.bdta.pro/images/b07064cb6602eb639ed9fea8c98f7488.jpg'),
(93023, 6527, 'Meu Tio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195908.mp4', 'http://timg.bdta.pro/images/5bb073fea4548e8889b831504a85b6ef.jpg'),
(93024, 6527, 'Meu Tio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195909.mp4', 'http://timg.bdta.pro/images/95a8107d707adbee0ee29f7210a3ef03.jpg'),
(93025, 6527, 'Meu Tio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195910.mp4', 'http://timg.bdta.pro/images/4f640d73b0666aaa1520d589f6113a15.jpg'),
(93026, 6527, 'Meu Tio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195911.mp4', 'http://timg.bdta.pro/images/9aca96d9fcfbdaca495f14de21a0a240.jpg'),
(93027, 6528, 'Os Lobos da Ilha de Vancouver S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195903.mp4', 'http://timg.bdta.pro/images/284b429839cabb893109b81f012e6be5.jpg'),
(93028, 6528, 'Os Lobos da Ilha de Vancouver S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195904.mp4', 'http://timg.bdta.pro/images/59736a261d26fcc5d3f14486991be62b.jpg'),
(93029, 6528, 'Os Lobos da Ilha de Vancouver S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195905.mp4', 'http://timg.bdta.pro/images/0f65b7874848e1f0d360948674596c93.jpg'),
(93030, 6529, 'Parques Nacionais dos Estados Unidos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195898.mp4', 'http://timg.bdta.pro/images/31e699a4849d6d29a8810d7ed8f2d152.jpg'),
(93031, 6529, 'Parques Nacionais dos Estados Unidos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195899.mp4', 'http://timg.bdta.pro/images/280961a3496f1a5b475c673bd13b0e32.jpg'),
(93032, 6529, 'Parques Nacionais dos Estados Unidos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195900.mp4', 'http://timg.bdta.pro/images/0ddd1ae7770c3423044cf424757468b2.jpg'),
(93033, 6529, 'Parques Nacionais dos Estados Unidos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195901.mp4', 'http://timg.bdta.pro/images/8f3acf83c13221531c86b85a776cd1f1.jpg'),
(93034, 6529, 'Parques Nacionais dos Estados Unidos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195902.mp4', 'http://timg.bdta.pro/images/4fe6751fc4dc50b972c1f1512e6efed9.jpg'),
(93035, 6530, 'Rookie Cops: Os Novatos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195882.mp4', 'http://timg.bdta.pro/images/d97f94750a1f56c68a8f8af97bf7983e.jpg'),
(93036, 6530, 'Rookie Cops: Os Novatos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195883.mp4', 'http://timg.bdta.pro/images/10926638d718d6e0510b0ede31044b60.jpg'),
(93037, 6530, 'Rookie Cops: Os Novatos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195884.mp4', 'http://timg.bdta.pro/images/c8d12c6b6322e3cc868f40a371cd5b97.jpg'),
(93038, 6530, 'Rookie Cops: Os Novatos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195885.mp4', 'http://timg.bdta.pro/images/5e86ba8587d24282e2ce9eb7661d22cd.jpg'),
(93039, 6530, 'Rookie Cops: Os Novatos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195886.mp4', 'http://timg.bdta.pro/images/5ca2da24fdc9c2b4c0007ec8cb8295fa.jpg'),
(93040, 6530, 'Rookie Cops: Os Novatos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195887.mp4', 'http://timg.bdta.pro/images/1b8a6b029b67f5bb7ccb73555c1cc1bc.jpg'),
(93041, 6530, 'Rookie Cops: Os Novatos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195888.mp4', 'http://timg.bdta.pro/images/71552ef38d053de765c5d29fd27e4d0b.jpg'),
(93042, 6530, 'Rookie Cops: Os Novatos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195889.mp4', 'http://timg.bdta.pro/images/d97d1c07b8275e942b8c3712d3e49e41.jpg'),
(93043, 6530, 'Rookie Cops: Os Novatos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195890.mp4', 'http://timg.bdta.pro/images/b7728b56d8739a9a3ac74c55da1a4395.jpg'),
(93044, 6530, 'Rookie Cops: Os Novatos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195891.mp4', 'http://timg.bdta.pro/images/269e1bc766005ff9a983db2c52fd03f4.jpg'),
(93045, 6530, 'Rookie Cops: Os Novatos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/195892.mp4', 'http://timg.bdta.pro/images/fba0b142d76c4a2ea4954b7b9eeab7b8.jpg'),
(93046, 6530, 'Rookie Cops: Os Novatos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/195893.mp4', 'http://timg.bdta.pro/images/f1cf59261e98932951cc9a815d25c40b.jpg'),
(93047, 6530, 'Rookie Cops: Os Novatos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/195894.mp4', 'http://timg.bdta.pro/images/73fabddffaf5964e39ac44e5c7210e0f.jpg'),
(93048, 6530, 'Rookie Cops: Os Novatos S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/195895.mp4', 'http://timg.bdta.pro/images/dfbf399d15f34b463587df9a945ad125.jpg'),
(93049, 6530, 'Rookie Cops: Os Novatos S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/195896.mp4', 'http://timg.bdta.pro/images/c22dc82cee55b44a3a6ede3e35c2180f.jpg'),
(93050, 6530, 'Rookie Cops: Os Novatos S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/195897.mp4', 'http://timg.bdta.pro/images/97a6517417e9565c6d7d67478684895c.jpg'),
(93051, 6531, 'Sagrada Família S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245538.mp4', 'http://timg.bdta.pro/images/9f8398cae4d569916e644c510fda2d3e.jpg'),
(93052, 6531, 'Sagrada Família S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245539.mp4', 'http://timg.bdta.pro/images/16057e90f6f5d306e2aea7e932783872.jpg'),
(93053, 6531, 'Sagrada Família S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245540.mp4', 'http://timg.bdta.pro/images/d7c46a4feb74426f859822d70031a73f.jpg'),
(93054, 6531, 'Sagrada Família S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245541.mp4', 'http://timg.bdta.pro/images/864b871cb3567007b9dfaea36e527440.jpg'),
(93055, 6531, 'Sagrada Família S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245542.mp4', 'http://timg.bdta.pro/images/bb0678ff305e22571685d6a693fc37b0.jpg'),
(93056, 6531, 'Sagrada Família S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245543.mp4', 'http://timg.bdta.pro/images/6de589c02a376e9f2428cf983afdaf0b.jpg'),
(93057, 6531, 'Sagrada Família S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245544.mp4', 'http://timg.bdta.pro/images/8cbe575148036bd7c82b744e99117071.jpg'),
(93058, 6531, 'Sagrada Família S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245545.mp4', 'http://timg.bdta.pro/images/4e4107e190c5cb0f3f68457411e9db6f.jpg'),
(93059, 6532, 'Sagrada Família S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245546.mp4', 'http://gstaticontent.com/images/b20e132b682e83512a3fdab818adc012.jpg'),
(93060, 6532, 'Sagrada Família S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245547.mp4', 'http://gstaticontent.com/images/b20e132b682e83512a3fdab818adc012.jpg'),
(93061, 6532, 'Sagrada Família S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245548.mp4', 'http://gstaticontent.com/images/b20e132b682e83512a3fdab818adc012.jpg'),
(93062, 6532, 'Sagrada Família S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245549.mp4', 'http://gstaticontent.com/images/b20e132b682e83512a3fdab818adc012.jpg'),
(93063, 6532, 'Sagrada Família S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245550.mp4', 'http://gstaticontent.com/images/b20e132b682e83512a3fdab818adc012.jpg'),
(93064, 6532, 'Sagrada Família S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245551.mp4', 'http://gstaticontent.com/images/b20e132b682e83512a3fdab818adc012.jpg'),
(93065, 6532, 'Sagrada Família S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245552.mp4', 'http://gstaticontent.com/images/b20e132b682e83512a3fdab818adc012.jpg'),
(93066, 6532, 'Sagrada Família S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245553.mp4', 'http://gstaticontent.com/images/b20e132b682e83512a3fdab818adc012.jpg'),
(93067, 6533, 'Shantaram S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203075.mp4', 'http://timg.bdta.pro/images/69bf709b73cba6952a64a5746b5b3489.jpg'),
(93068, 6533, 'Shantaram S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203076.mp4', 'http://timg.bdta.pro/images/17ac88ff13200a0fbad441b0ceaa9a86.jpg'),
(93069, 6533, 'Shantaram S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203077.mp4', 'http://timg.bdta.pro/images/f98d9d2d4fa6727ede1db0bce223a72c.jpg'),
(93070, 6533, 'Shantaram S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203078.mp4', 'http://timg.bdta.pro/images/e2c99505cd920446fe36df582688ae95.jpg'),
(93071, 6533, 'Shantaram S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j7q6QDKQt85RyrtG58GEDzsR6qU.jpg'),
(93072, 6533, 'Shantaram S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dN3YqRS2LvgqmNqKU3Fa9cfTywH.jpg'),
(93073, 6533, 'Shantaram S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203081.mp4', 'http://image.tmdb.org/t/p/w1280/ciY7pJpVLgj3q1nJBt6ViFGwXI8.jpg'),
(93074, 6533, 'Shantaram S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyMCYyDEo2pST1AzXKHeDxmLw8F.jpg'),
(93075, 6533, 'Shantaram S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nRPq8ACzpJAwM7la7bI7VhI68ef.jpg'),
(93076, 6533, 'Shantaram S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203084.mp4', 'http://image.tmdb.org/t/p/w1280/rZe60F75czAYdhtIXdlNsxCCPMD.jpg'),
(93077, 6533, 'Shantaram S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203085.mp4', 'http://image.tmdb.org/t/p/w1280/2EPw2s7H6shmPKl65dGQ8wM8WP1.jpg'),
(93078, 6533, 'Shantaram S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203086.mp4', 'http://image.tmdb.org/t/p/w1280/sKgkDKD9w3zG5qiiWVmvTNuFJwo.jpg'),
(93079, 6534, 'Som na Faixa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195876.mp4', 'http://timg.bdta.pro/images/37c428f9f704a3b532b0e509695dbf3a.jpg'),
(93080, 6534, 'Som na Faixa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195877.mp4', 'http://timg.bdta.pro/images/156d3a4ef4baec6441d3b8c07ea971d8.jpg'),
(93081, 6534, 'Som na Faixa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195878.mp4', 'http://timg.bdta.pro/images/5560d96bc183ecc1a933c14c90985863.jpg'),
(93082, 6534, 'Som na Faixa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195879.mp4', 'http://timg.bdta.pro/images/380827d1e100724e5cfcd0817309ae6c.jpg'),
(93083, 6534, 'Som na Faixa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195880.mp4', 'http://timg.bdta.pro/images/0817070df8381b3b865936762f64fc02.jpg'),
(93084, 6534, 'Som na Faixa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195881.mp4', 'http://timg.bdta.pro/images/fbe49021d713b98f4f1dff5e80118398.jpg'),
(93085, 6535, 'Terra de Crocodilos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195866.mp4', 'http://gstaticontent.com/images/c02f5e16192fbbe63f1384f356c1c743.jpg'),
(93086, 6535, 'Terra de Crocodilos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195867.mp4', 'http://gstaticontent.com/images/c02f5e16192fbbe63f1384f356c1c743.jpg'),
(93087, 6535, 'Terra de Crocodilos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195868.mp4', 'http://gstaticontent.com/images/c02f5e16192fbbe63f1384f356c1c743.jpg'),
(93088, 6535, 'Terra de Crocodilos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195869.mp4', 'http://gstaticontent.com/images/c02f5e16192fbbe63f1384f356c1c743.jpg'),
(93089, 6535, 'Terra de Crocodilos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195870.mp4', 'http://gstaticontent.com/images/c02f5e16192fbbe63f1384f356c1c743.jpg'),
(93090, 6535, 'Terra de Crocodilos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195871.mp4', 'http://gstaticontent.com/images/c02f5e16192fbbe63f1384f356c1c743.jpg'),
(93091, 6535, 'Terra de Crocodilos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195872.mp4', 'http://gstaticontent.com/images/c02f5e16192fbbe63f1384f356c1c743.jpg'),
(93092, 6535, 'Terra de Crocodilos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/195873.mp4', 'http://gstaticontent.com/images/c02f5e16192fbbe63f1384f356c1c743.jpg'),
(93093, 6535, 'Terra de Crocodilos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/195874.mp4', 'http://gstaticontent.com/images/c02f5e16192fbbe63f1384f356c1c743.jpg'),
(93094, 6535, 'Terra de Crocodilos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/195875.mp4', 'http://gstaticontent.com/images/c02f5e16192fbbe63f1384f356c1c743.jpg'),
(93095, 6536, 'Tesouros Perdidos de Roma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195860.mp4', 'http://timg.bdta.pro/images/2bdd28b0a9ff15e21878438d12eeca69.jpg'),
(93096, 6536, 'Tesouros Perdidos de Roma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195861.mp4', 'http://gstaticontent.com/images/7fa97666a54336d9916a47b8e4b441af.jpg'),
(93097, 6536, 'Tesouros Perdidos de Roma S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195862.mp4', 'http://gstaticontent.com/images/7fa97666a54336d9916a47b8e4b441af.jpg'),
(93098, 6536, 'Tesouros Perdidos de Roma S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195863.mp4', 'http://gstaticontent.com/images/7fa97666a54336d9916a47b8e4b441af.jpg'),
(93099, 6536, 'Tesouros Perdidos de Roma S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195864.mp4', 'http://gstaticontent.com/images/7fa97666a54336d9916a47b8e4b441af.jpg'),
(93100, 6536, 'Tesouros Perdidos de Roma S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195865.mp4', 'http://gstaticontent.com/images/7fa97666a54336d9916a47b8e4b441af.jpg'),
(93101, 6537, 'Tesouros Perdidos de Roma S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/511107.mp4', 'http://gstaticontent.com/images/7fa97666a54336d9916a47b8e4b441af.jpg'),
(93102, 6538, 'Tudo Pede Salvação S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/195853.mp4', 'http://timg.bdta.pro/images/3e66849a62c499f8fb8a28464b624058.jpg'),
(93103, 6538, 'Tudo Pede Salvação S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/195854.mp4', 'http://timg.bdta.pro/images/097da89cbdab515e9bbd61c711cd9a80.jpg'),
(93104, 6538, 'Tudo Pede Salvação S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/195855.mp4', 'http://timg.bdta.pro/images/f245ec879a341a6748cd555ee6dd8a30.jpg'),
(93105, 6538, 'Tudo Pede Salvação S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/195856.mp4', 'http://timg.bdta.pro/images/4452fdcd5d6348857ef70886b24aff96.jpg'),
(93106, 6538, 'Tudo Pede Salvação S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/195857.mp4', 'http://timg.bdta.pro/images/abc9830bacad5ec88c38fcf733e3956a.jpg'),
(93107, 6538, 'Tudo Pede Salvação S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/195858.mp4', 'http://timg.bdta.pro/images/b01c567efcac3ce9904eea9a7b1d900f.jpg'),
(93108, 6538, 'Tudo Pede Salvação S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/195859.mp4', 'http://timg.bdta.pro/images/7f09e605b101304f4f105f4e10b78cdf.jpg'),
(93109, 6539, 'Tudo Pede Salvação S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/463495.mp4', 'http://gstaticontent.com/images/0298faa89759e2537175c2d4ed245852.jpg'),
(93110, 6539, 'Tudo Pede Salvação S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/463496.mp4', 'http://gstaticontent.com/images/0298faa89759e2537175c2d4ed245852.jpg'),
(93111, 6539, 'Tudo Pede Salvação S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/463497.mp4', 'http://gstaticontent.com/images/0298faa89759e2537175c2d4ed245852.jpg'),
(93112, 6539, 'Tudo Pede Salvação S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/463498.mp4', 'http://gstaticontent.com/images/0298faa89759e2537175c2d4ed245852.jpg'),
(93113, 6539, 'Tudo Pede Salvação S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/463499.mp4', 'http://gstaticontent.com/images/0298faa89759e2537175c2d4ed245852.jpg'),
(93114, 6540, 'Todo Mundo Adora o Raymond S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199930.mp4', 'http://timg.bdta.pro/images/cad0efd38e0d3e862d4e0963a69c5f17.jpg'),
(93115, 6540, 'Todo Mundo Adora o Raymond S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199931.mp4', 'http://timg.bdta.pro/images/7f81a1cae28468be7b5d0c330dc080bc.jpg'),
(93116, 6540, 'Todo Mundo Adora o Raymond S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199932.mp4', 'http://timg.bdta.pro/images/1f7d943096428edf82bb0b36953c206b.jpg'),
(93117, 6540, 'Todo Mundo Adora o Raymond S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199933.mp4', 'http://timg.bdta.pro/images/7a7850b22153036134ddd172d1b177dd.jpg'),
(93118, 6540, 'Todo Mundo Adora o Raymond S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199934.mp4', 'http://timg.bdta.pro/images/e97d15225716d198d310cd27af9bb846.jpg'),
(93119, 6540, 'Todo Mundo Adora o Raymond S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199935.mp4', 'http://timg.bdta.pro/images/26340db646ea77d83aff3ad0d830e21c.jpg'),
(93120, 6540, 'Todo Mundo Adora o Raymond S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199936.mp4', 'http://timg.bdta.pro/images/94517396904dd43db61a7750ec232918.jpg'),
(93121, 6540, 'Todo Mundo Adora o Raymond S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199937.mp4', 'http://timg.bdta.pro/images/cdf7e649be21a9ae44009ccff775c1d7.jpg'),
(93122, 6540, 'Todo Mundo Adora o Raymond S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199938.mp4', 'http://timg.bdta.pro/images/f4c93aecae0c609299ff83855895cb1d.jpg'),
(93123, 6540, 'Todo Mundo Adora o Raymond S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199939.mp4', 'http://timg.bdta.pro/images/3c1af7e6c6b3fabfd621a1cf72aa18a7.jpg'),
(93124, 6540, 'Todo Mundo Adora o Raymond S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199940.mp4', 'http://timg.bdta.pro/images/4139b5704c8717b21c664ad0f2950a1b.jpg'),
(93125, 6540, 'Todo Mundo Adora o Raymond S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199941.mp4', 'http://timg.bdta.pro/images/8079b5e9387c25dfd16e729c2edebf4e.jpg'),
(93126, 6540, 'Todo Mundo Adora o Raymond S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/199942.mp4', 'http://timg.bdta.pro/images/179d6f2f20bdff0a65731e7f215e9557.jpg'),
(93127, 6540, 'Todo Mundo Adora o Raymond S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/199943.mp4', 'http://timg.bdta.pro/images/c46adf9eae46ecd8201f4f31abfc216c.jpg'),
(93128, 6540, 'Todo Mundo Adora o Raymond S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/199944.mp4', 'http://timg.bdta.pro/images/7fd3a4e07abedf1e223a7d065802703d.jpg'),
(93129, 6540, 'Todo Mundo Adora o Raymond S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/199945.mp4', 'http://timg.bdta.pro/images/338fbd4cc148aa1a8b6146186f0e107b.jpg'),
(93130, 6540, 'Todo Mundo Adora o Raymond S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/199946.mp4', 'http://timg.bdta.pro/images/04262683e00a3ee541f1e28f559728f2.jpg'),
(93131, 6540, 'Todo Mundo Adora o Raymond S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/199947.mp4', 'http://timg.bdta.pro/images/6287313f88a2a73b6386f08c05b52138.jpg'),
(93132, 6540, 'Todo Mundo Adora o Raymond S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/199948.mp4', 'http://timg.bdta.pro/images/9a03f84248713799d0c3ebdbc6556f54.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(93133, 6540, 'Todo Mundo Adora o Raymond S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/199949.mp4', 'http://timg.bdta.pro/images/7cf32d2dbd507cb76d477efeeaac23df.jpg'),
(93134, 6540, 'Todo Mundo Adora o Raymond S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/199950.mp4', 'http://timg.bdta.pro/images/38e965ec9f0779706f5351dbddb128f2.jpg'),
(93135, 6540, 'Todo Mundo Adora o Raymond S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/199951.mp4', 'http://timg.bdta.pro/images/dadc57caed4de8581d543d24ccc9b365.jpg'),
(93136, 6541, 'Todo Mundo Adora o Raymond S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199952.mp4', 'http://timg.bdta.pro/images/9ed983de607c4e5fed9fe31fadb1e1e2.jpg'),
(93137, 6541, 'Todo Mundo Adora o Raymond S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199953.mp4', 'http://timg.bdta.pro/images/f3e290323a03592407b3bde5bed1dc5d.jpg'),
(93138, 6541, 'Todo Mundo Adora o Raymond S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199954.mp4', 'http://timg.bdta.pro/images/4a76773315f335febcccc96fc7f7d6f2.jpg'),
(93139, 6541, 'Todo Mundo Adora o Raymond S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199955.mp4', 'http://timg.bdta.pro/images/adc5780af80efdd9d5e0ca4e5481a128.jpg'),
(93140, 6541, 'Todo Mundo Adora o Raymond S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199956.mp4', 'http://timg.bdta.pro/images/9a83a4a9859a76f172089a6b98649c99.jpg'),
(93141, 6541, 'Todo Mundo Adora o Raymond S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199957.mp4', 'http://timg.bdta.pro/images/8a6e482ec1add14f64975bf7302cb67c.jpg'),
(93142, 6541, 'Todo Mundo Adora o Raymond S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199958.mp4', 'http://timg.bdta.pro/images/d7448b7f07b0c6082d29be3053ab4e1b.jpg'),
(93143, 6541, 'Todo Mundo Adora o Raymond S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199959.mp4', 'http://timg.bdta.pro/images/e4fbd0fe42c98c2bfb7b677b5a6e6101.jpg'),
(93144, 6541, 'Todo Mundo Adora o Raymond S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199960.mp4', 'http://timg.bdta.pro/images/42ad8f296b9dc6125a0757fdd496a017.jpg'),
(93145, 6541, 'Todo Mundo Adora o Raymond S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199961.mp4', 'http://timg.bdta.pro/images/33078c2c8ab7cf0c24612e961ed76eca.jpg'),
(93146, 6541, 'Todo Mundo Adora o Raymond S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199962.mp4', 'http://timg.bdta.pro/images/1bc09814afa6161a9d2e08a61e1155b9.jpg'),
(93147, 6541, 'Todo Mundo Adora o Raymond S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199963.mp4', 'http://timg.bdta.pro/images/018a3d3648380fc024e2532b276a6d9e.jpg'),
(93148, 6541, 'Todo Mundo Adora o Raymond S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/199964.mp4', 'http://timg.bdta.pro/images/e4780bf42cb2c55f4500f1107a5a12a6.jpg'),
(93149, 6541, 'Todo Mundo Adora o Raymond S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/199965.mp4', 'http://timg.bdta.pro/images/8f93e4d53a597c3499a3f5eff626f887.jpg'),
(93150, 6541, 'Todo Mundo Adora o Raymond S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/199966.mp4', 'http://timg.bdta.pro/images/4bdd5ed490b041bc97b07c44a2a611d1.jpg'),
(93151, 6541, 'Todo Mundo Adora o Raymond S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/199967.mp4', 'http://timg.bdta.pro/images/e4093932b1d686686146aa351e518b14.jpg'),
(93152, 6541, 'Todo Mundo Adora o Raymond S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/199968.mp4', 'http://timg.bdta.pro/images/fd4eee4e0ed8ebc50dc55c0255e9d593.jpg'),
(93153, 6541, 'Todo Mundo Adora o Raymond S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/199969.mp4', 'http://timg.bdta.pro/images/b1c03c88916f4729029d289953feb3f2.jpg'),
(93154, 6541, 'Todo Mundo Adora o Raymond S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/199970.mp4', 'http://timg.bdta.pro/images/430174ef094e7430e1700b9ea62299ff.jpg'),
(93155, 6541, 'Todo Mundo Adora o Raymond S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/199971.mp4', 'http://timg.bdta.pro/images/fd9350f4b00b0dea598bf629c895ac4a.jpg'),
(93156, 6541, 'Todo Mundo Adora o Raymond S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/199972.mp4', 'http://timg.bdta.pro/images/58e743f51028151b92556a61dee7bf15.jpg'),
(93157, 6541, 'Todo Mundo Adora o Raymond S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/199973.mp4', 'http://timg.bdta.pro/images/87902c80d8b5df3ff35d5b1858ccc12d.jpg'),
(93158, 6541, 'Todo Mundo Adora o Raymond S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/199974.mp4', 'http://timg.bdta.pro/images/f2d7c0fd7ae29d0d5e2b62a7f32c2932.jpg'),
(93159, 6541, 'Todo Mundo Adora o Raymond S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/199975.mp4', 'http://timg.bdta.pro/images/a589d14d9f51a2ce9397039788227226.jpg'),
(93160, 6541, 'Todo Mundo Adora o Raymond S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/199976.mp4', 'http://timg.bdta.pro/images/64a006fafb868d1d8c33334d9d200581.jpg'),
(93161, 6542, 'Todo Mundo Adora o Raymond S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199977.mp4', 'http://timg.bdta.pro/images/1b55c34f397c8f972da7649ddf009131.jpg'),
(93162, 6542, 'Todo Mundo Adora o Raymond S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199978.mp4', 'http://timg.bdta.pro/images/07b031be03ba8ce442eb326acfa10520.jpg'),
(93163, 6542, 'Todo Mundo Adora o Raymond S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199979.mp4', 'http://timg.bdta.pro/images/a35a3db24e10037ff57b23bb0ffa36ac.jpg'),
(93164, 6542, 'Todo Mundo Adora o Raymond S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199980.mp4', 'http://timg.bdta.pro/images/fe81eb5c85507acee5ec676b31fe8e35.jpg'),
(93165, 6542, 'Todo Mundo Adora o Raymond S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199981.mp4', 'http://timg.bdta.pro/images/6fad1572c800ed3b9ab2fdc33ec28300.jpg'),
(93166, 6542, 'Todo Mundo Adora o Raymond S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199982.mp4', 'http://timg.bdta.pro/images/cf3807de8a14063a414dc0c8633fe5ee.jpg'),
(93167, 6542, 'Todo Mundo Adora o Raymond S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199983.mp4', 'http://timg.bdta.pro/images/458193b15084947ff2b9cfd7e36ae7a9.jpg'),
(93168, 6542, 'Todo Mundo Adora o Raymond S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199984.mp4', 'http://timg.bdta.pro/images/895552e0ab9a401f6bb96d1211ada3f3.jpg'),
(93169, 6542, 'Todo Mundo Adora o Raymond S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199985.mp4', 'http://timg.bdta.pro/images/07cb624ed2ee4ac498c49c3f8716a397.jpg'),
(93170, 6542, 'Todo Mundo Adora o Raymond S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199986.mp4', 'http://timg.bdta.pro/images/66c38f5f45c843e2ba49c0a5826249af.jpg'),
(93171, 6542, 'Todo Mundo Adora o Raymond S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199987.mp4', 'http://timg.bdta.pro/images/5fdae55b534927587f8cb9b34721526d.jpg'),
(93172, 6542, 'Todo Mundo Adora o Raymond S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199988.mp4', 'http://timg.bdta.pro/images/e7370927042ceb6a4eb03a294a3d8202.jpg'),
(93173, 6542, 'Todo Mundo Adora o Raymond S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/199989.mp4', 'http://timg.bdta.pro/images/d4d9827873fa972debca4715d1346643.jpg'),
(93174, 6542, 'Todo Mundo Adora o Raymond S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/199990.mp4', 'http://timg.bdta.pro/images/f1a7b91f1b7222a5ad20391ea0395271.jpg'),
(93175, 6542, 'Todo Mundo Adora o Raymond S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/199991.mp4', 'http://timg.bdta.pro/images/a5452ddaf410dc6b28dd3c99bd618ce7.jpg'),
(93176, 6542, 'Todo Mundo Adora o Raymond S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/199992.mp4', 'http://timg.bdta.pro/images/bfc920ea3b22f0221673eba0dc21dca0.jpg'),
(93177, 6542, 'Todo Mundo Adora o Raymond S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/199993.mp4', 'http://timg.bdta.pro/images/b33f988b8b24a3704644d6594dc3d307.jpg'),
(93178, 6542, 'Todo Mundo Adora o Raymond S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/199994.mp4', 'http://timg.bdta.pro/images/a4cefb1b0972ad6bfa801f16f0a98e19.jpg'),
(93179, 6542, 'Todo Mundo Adora o Raymond S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/199995.mp4', 'http://timg.bdta.pro/images/b9351192b13a3ba5295a53a2801c4380.jpg'),
(93180, 6542, 'Todo Mundo Adora o Raymond S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/199996.mp4', 'http://timg.bdta.pro/images/d153e41d1558a823365d97117fe1a9d2.jpg'),
(93181, 6542, 'Todo Mundo Adora o Raymond S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/199997.mp4', 'http://timg.bdta.pro/images/09018c12776bb42b368b5a49f7348159.jpg'),
(93182, 6542, 'Todo Mundo Adora o Raymond S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/199998.mp4', 'http://timg.bdta.pro/images/35e61411d7134f0ab1d044c81e9de3ec.jpg'),
(93183, 6542, 'Todo Mundo Adora o Raymond S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/199999.mp4', 'http://timg.bdta.pro/images/c93574dd181ebd619a5c2c8288a22d00.jpg'),
(93184, 6542, 'Todo Mundo Adora o Raymond S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/200000.mp4', 'http://timg.bdta.pro/images/66acc45d77ec179df3fb161ac19127b2.jpg'),
(93185, 6542, 'Todo Mundo Adora o Raymond S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/200001.mp4', 'http://timg.bdta.pro/images/d6a7e43a597dad6b3d39bfaa7a0f2d4d.jpg'),
(93186, 6542, 'Todo Mundo Adora o Raymond S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/200002.mp4', 'http://timg.bdta.pro/images/a582330693f49fb17a0708dbb2217402.jpg'),
(93187, 6543, 'Todo Mundo Adora o Raymond S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200003.mp4', 'http://timg.bdta.pro/images/eaa0560a6e725d300eb522f90b703227.jpg'),
(93188, 6543, 'Todo Mundo Adora o Raymond S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200004.mp4', 'http://timg.bdta.pro/images/0442449855f04ac39c214e7305016b5a.jpg'),
(93189, 6543, 'Todo Mundo Adora o Raymond S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200005.mp4', 'http://timg.bdta.pro/images/f0709269473525a28e78f6fda29ca4f8.jpg'),
(93190, 6543, 'Todo Mundo Adora o Raymond S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200006.mp4', 'http://timg.bdta.pro/images/03a431d2bd25911c7a711dbacec9b813.jpg'),
(93191, 6543, 'Todo Mundo Adora o Raymond S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200007.mp4', 'http://timg.bdta.pro/images/8b5d35e549a723ae14da122addfcaf69.jpg'),
(93192, 6543, 'Todo Mundo Adora o Raymond S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200008.mp4', 'http://timg.bdta.pro/images/c8081c34ae40c15b94f733ce4d458c94.jpg'),
(93193, 6543, 'Todo Mundo Adora o Raymond S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200009.mp4', 'http://timg.bdta.pro/images/3602e6cbe067fbd34a0ed8d3c7013fef.jpg'),
(93194, 6543, 'Todo Mundo Adora o Raymond S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200010.mp4', 'http://timg.bdta.pro/images/b933c3e16c8d47cf52acb1352ec13a49.jpg'),
(93195, 6543, 'Todo Mundo Adora o Raymond S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200011.mp4', 'http://timg.bdta.pro/images/545646234d1da1d2c68337ae87ae4253.jpg'),
(93196, 6543, 'Todo Mundo Adora o Raymond S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200012.mp4', 'http://timg.bdta.pro/images/13bdf54d75d215fe023ebeecf0ea0e88.jpg'),
(93197, 6543, 'Todo Mundo Adora o Raymond S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200013.mp4', 'http://timg.bdta.pro/images/473c9613f02ddc96a2e5a2a4f70d9e90.jpg'),
(93198, 6543, 'Todo Mundo Adora o Raymond S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200014.mp4', 'http://timg.bdta.pro/images/e6dc1f2a6e07748be23bca800606955d.jpg'),
(93199, 6543, 'Todo Mundo Adora o Raymond S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200015.mp4', 'http://timg.bdta.pro/images/7ebbe056ccfc896c423b3d43c7cb39ce.jpg'),
(93200, 6543, 'Todo Mundo Adora o Raymond S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/200016.mp4', 'http://timg.bdta.pro/images/8a9a62dfc523c521ab93c63a0f2cabbb.jpg'),
(93201, 6543, 'Todo Mundo Adora o Raymond S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/200017.mp4', 'http://timg.bdta.pro/images/b1c24180b79ddef6f764e363c3838d0e.jpg'),
(93202, 6543, 'Todo Mundo Adora o Raymond S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/200018.mp4', 'http://timg.bdta.pro/images/b1e1d3318ad60c075191f7e0a8d31d37.jpg'),
(93203, 6543, 'Todo Mundo Adora o Raymond S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/200019.mp4', 'http://timg.bdta.pro/images/735686c6254687856a33f8196e97e514.jpg'),
(93204, 6543, 'Todo Mundo Adora o Raymond S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/200020.mp4', 'http://timg.bdta.pro/images/eb9c829e5e7fba6e4a1b609b87f8f737.jpg'),
(93205, 6543, 'Todo Mundo Adora o Raymond S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/200021.mp4', 'http://timg.bdta.pro/images/0e903a54076223c5f69dffbce4dfb227.jpg'),
(93206, 6543, 'Todo Mundo Adora o Raymond S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/200022.mp4', 'http://timg.bdta.pro/images/8bac9401acd7a2cbd2a580a06c5d024e.jpg'),
(93207, 6543, 'Todo Mundo Adora o Raymond S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/200023.mp4', 'http://timg.bdta.pro/images/9c7789b3b2a242ff62a49af9ec05b096.jpg'),
(93208, 6543, 'Todo Mundo Adora o Raymond S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/200024.mp4', 'http://timg.bdta.pro/images/e022d8fc05775c5f236a3075906624e5.jpg'),
(93209, 6543, 'Todo Mundo Adora o Raymond S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/200025.mp4', 'http://timg.bdta.pro/images/36a74b968af6618243f47ac46b7e406e.jpg'),
(93210, 6543, 'Todo Mundo Adora o Raymond S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/200026.mp4', 'http://timg.bdta.pro/images/34fed7b7b565b513765663bf184f4351.jpg'),
(93211, 6544, 'Todo Mundo Adora o Raymond S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200027.mp4', 'http://timg.bdta.pro/images/33b17cf088d24fc562423829035de2b1.jpg'),
(93212, 6544, 'Todo Mundo Adora o Raymond S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200028.mp4', 'http://timg.bdta.pro/images/264b085f1cf40e39a376dfde1f4daeb8.jpg'),
(93213, 6544, 'Todo Mundo Adora o Raymond S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200029.mp4', 'http://timg.bdta.pro/images/1962d1233c0cd3b6e9acbb62e52eb213.jpg'),
(93214, 6544, 'Todo Mundo Adora o Raymond S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200030.mp4', 'http://timg.bdta.pro/images/fc4b6a5b6bd55fd6d81c878c78d86a25.jpg'),
(93215, 6544, 'Todo Mundo Adora o Raymond S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200031.mp4', 'http://timg.bdta.pro/images/f089a7c42f8330b5b92ce3687806875f.jpg'),
(93216, 6544, 'Todo Mundo Adora o Raymond S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200032.mp4', 'http://timg.bdta.pro/images/fe8f06133b6b2cd2e194666f84de773e.jpg'),
(93217, 6544, 'Todo Mundo Adora o Raymond S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200033.mp4', 'http://timg.bdta.pro/images/b06a2a66975e02dccd7257b5311fac77.jpg'),
(93218, 6544, 'Todo Mundo Adora o Raymond S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200034.mp4', 'http://timg.bdta.pro/images/252bb0b4a750a9a95d87ab8e0a9f7d07.jpg'),
(93219, 6544, 'Todo Mundo Adora o Raymond S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200035.mp4', 'http://timg.bdta.pro/images/c71f3ebbc021a768db02804673c5dc66.jpg'),
(93220, 6544, 'Todo Mundo Adora o Raymond S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200036.mp4', 'http://timg.bdta.pro/images/a69cbd0fd474112354beac04a3ec203b.jpg'),
(93221, 6544, 'Todo Mundo Adora o Raymond S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200037.mp4', 'http://timg.bdta.pro/images/98b7d597aa5d162314bfad8951775d6e.jpg'),
(93222, 6544, 'Todo Mundo Adora o Raymond S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200038.mp4', 'http://timg.bdta.pro/images/94eafd1a08b731ad9b08c2d3bcb986af.jpg'),
(93223, 6544, 'Todo Mundo Adora o Raymond S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200039.mp4', 'http://timg.bdta.pro/images/a5ad192bdfca73fa3e4a18eb68773567.jpg'),
(93224, 6544, 'Todo Mundo Adora o Raymond S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/200040.mp4', 'http://timg.bdta.pro/images/3efa5b7e93ef86247c6ca2f546a8075f.jpg'),
(93225, 6544, 'Todo Mundo Adora o Raymond S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/200041.mp4', 'http://timg.bdta.pro/images/5c8fc0bf8766ddb0b6473c768f06c444.jpg'),
(93226, 6544, 'Todo Mundo Adora o Raymond S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/200042.mp4', 'http://timg.bdta.pro/images/9c7c83269dbbe2b36ed7d752d90c33b1.jpg'),
(93227, 6544, 'Todo Mundo Adora o Raymond S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/200043.mp4', 'http://timg.bdta.pro/images/90b9b1b8df11a51adabccafd86b65817.jpg'),
(93228, 6544, 'Todo Mundo Adora o Raymond S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/200044.mp4', 'http://timg.bdta.pro/images/5c55623abcac77e76e9e3e2f74da2962.jpg'),
(93229, 6544, 'Todo Mundo Adora o Raymond S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/200045.mp4', 'http://timg.bdta.pro/images/17344b868eca1a68b6fea3c7383a97c8.jpg'),
(93230, 6544, 'Todo Mundo Adora o Raymond S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/200046.mp4', 'http://timg.bdta.pro/images/ad0eda2b4f4b531a51a057b03ed97580.jpg'),
(93231, 6544, 'Todo Mundo Adora o Raymond S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/200047.mp4', 'http://timg.bdta.pro/images/49e54c0f99966fa688e8d304b0265dae.jpg'),
(93232, 6544, 'Todo Mundo Adora o Raymond S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/200048.mp4', 'http://timg.bdta.pro/images/d4d96460dbdff5c2e4001b9068b3a563.jpg'),
(93233, 6544, 'Todo Mundo Adora o Raymond S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/200049.mp4', 'http://timg.bdta.pro/images/c4f96eed190ec947648a4ea96925fc22.jpg'),
(93234, 6544, 'Todo Mundo Adora o Raymond S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/200050.mp4', 'http://timg.bdta.pro/images/b4a33468f38488385f487a582bbf8c0d.jpg'),
(93235, 6544, 'Todo Mundo Adora o Raymond S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/200051.mp4', 'http://timg.bdta.pro/images/f708a56da9d737fcceaf5081969b8bdb.jpg'),
(93236, 6545, 'Todo Mundo Adora o Raymond S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200052.mp4', 'http://timg.bdta.pro/images/248d908471328f040c8b1024ed87cd05.jpg'),
(93237, 6545, 'Todo Mundo Adora o Raymond S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200053.mp4', 'http://timg.bdta.pro/images/968966cb26b5deb4cde54295169f5295.jpg'),
(93238, 6545, 'Todo Mundo Adora o Raymond S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200054.mp4', 'http://timg.bdta.pro/images/b0a36b92774b936e860ba85d80a5b37d.jpg'),
(93239, 6545, 'Todo Mundo Adora o Raymond S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200055.mp4', 'http://timg.bdta.pro/images/a9ce610b0a777c10131fd13d4ac0eb7c.jpg'),
(93240, 6545, 'Todo Mundo Adora o Raymond S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200056.mp4', 'http://timg.bdta.pro/images/e790a36170284cb1e169a519a70821c6.jpg'),
(93241, 6545, 'Todo Mundo Adora o Raymond S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200057.mp4', 'http://timg.bdta.pro/images/b2c734059e5e222c9774940bfc384992.jpg'),
(93242, 6545, 'Todo Mundo Adora o Raymond S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200058.mp4', 'http://timg.bdta.pro/images/55b375d39e78f4adc15e0d339a92cba8.jpg'),
(93243, 6545, 'Todo Mundo Adora o Raymond S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200059.mp4', 'http://timg.bdta.pro/images/078ac9ebbc03b9331d28361d0ba09c71.jpg'),
(93244, 6545, 'Todo Mundo Adora o Raymond S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200060.mp4', 'http://timg.bdta.pro/images/2b13f4912efaa4d5c2111e7b0481bece.jpg'),
(93245, 6545, 'Todo Mundo Adora o Raymond S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200061.mp4', 'http://timg.bdta.pro/images/53579badaa91fc4192198cc6eee7b5f7.jpg'),
(93246, 6545, 'Todo Mundo Adora o Raymond S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200062.mp4', 'http://timg.bdta.pro/images/c77dc1c5822a61d9e9a98e3bfd089354.jpg'),
(93247, 6545, 'Todo Mundo Adora o Raymond S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200063.mp4', 'http://timg.bdta.pro/images/d45d40d819d80c289d91c5d0b15d7005.jpg'),
(93248, 6545, 'Todo Mundo Adora o Raymond S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200064.mp4', 'http://timg.bdta.pro/images/1a6ec42b466fdc0ec4966f7c065813ed.jpg'),
(93249, 6545, 'Todo Mundo Adora o Raymond S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/200065.mp4', 'http://timg.bdta.pro/images/a1d471c6b8e3b54587d66519329947df.jpg'),
(93250, 6545, 'Todo Mundo Adora o Raymond S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/200066.mp4', 'http://timg.bdta.pro/images/04d3f2b9e153db0a26ccf4bfc4016ce3.jpg'),
(93251, 6545, 'Todo Mundo Adora o Raymond S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/200067.mp4', 'http://timg.bdta.pro/images/fcbeef19575c5b517ab2cb32165b6385.jpg'),
(93252, 6545, 'Todo Mundo Adora o Raymond S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/200068.mp4', 'http://timg.bdta.pro/images/847e9865bba685ec5c2862fd0e4d506d.jpg'),
(93253, 6545, 'Todo Mundo Adora o Raymond S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/200069.mp4', 'http://timg.bdta.pro/images/f0396376577dfbf0ddbb60ca1bf30104.jpg'),
(93254, 6545, 'Todo Mundo Adora o Raymond S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/200070.mp4', 'http://timg.bdta.pro/images/4b580c44d310ef2c416f7a57b3783fbf.jpg'),
(93255, 6545, 'Todo Mundo Adora o Raymond S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/200071.mp4', 'http://timg.bdta.pro/images/55869575304e7683c1f5028cad6cd5a1.jpg'),
(93256, 6545, 'Todo Mundo Adora o Raymond S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/200072.mp4', 'http://timg.bdta.pro/images/011565cb56244e6e285b45d08f06f5f0.jpg'),
(93257, 6545, 'Todo Mundo Adora o Raymond S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/200073.mp4', 'http://timg.bdta.pro/images/072e2b3ecfa5c514ca19cbb4230eebbb.jpg'),
(93258, 6545, 'Todo Mundo Adora o Raymond S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/200074.mp4', 'http://timg.bdta.pro/images/bc3a880ee4c198006a04a0c6533e2c8f.jpg'),
(93259, 6545, 'Todo Mundo Adora o Raymond S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/200075.mp4', 'http://timg.bdta.pro/images/4d0a55ef44aadd1ea28babf44efd9fa8.jpg'),
(93260, 6545, 'Todo Mundo Adora o Raymond S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/200076.mp4', 'http://gstaticontent.com/images/5e20421a18139219912db9e5e8d5836e.jpg'),
(93261, 6545, 'Todo Mundo Adora o Raymond S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/200077.mp4', 'http://gstaticontent.com/images/5e20421a18139219912db9e5e8d5836e.jpg'),
(93262, 6546, 'Todo Mundo Adora o Raymond S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200078.mp4', 'http://timg.bdta.pro/images/c8eafcc0c797538f2e325bab5a0a5a18.jpg'),
(93263, 6546, 'Todo Mundo Adora o Raymond S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200079.mp4', 'http://timg.bdta.pro/images/edeab8e62bbed0fcb701233127c85a37.jpg'),
(93264, 6546, 'Todo Mundo Adora o Raymond S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200080.mp4', 'http://timg.bdta.pro/images/2846ab12213ae45fbefbe9f69ee434b4.jpg'),
(93265, 6546, 'Todo Mundo Adora o Raymond S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200081.mp4', 'http://timg.bdta.pro/images/a831084cbeb670c6caf6b975879a8067.jpg'),
(93266, 6546, 'Todo Mundo Adora o Raymond S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200082.mp4', 'http://timg.bdta.pro/images/1449f2037169818fac2f44d2a5cb093b.jpg'),
(93267, 6546, 'Todo Mundo Adora o Raymond S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200083.mp4', 'http://timg.bdta.pro/images/fc5570a3b7da60ac87b6599c3abfb01b.jpg'),
(93268, 6546, 'Todo Mundo Adora o Raymond S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200084.mp4', 'http://timg.bdta.pro/images/55d87757728f14facc6b5a1bf19e5a98.jpg'),
(93269, 6546, 'Todo Mundo Adora o Raymond S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200085.mp4', 'http://timg.bdta.pro/images/d10bd651f968aaf900d541abfa050c8a.jpg'),
(93270, 6546, 'Todo Mundo Adora o Raymond S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200086.mp4', 'http://timg.bdta.pro/images/2d344609fa49f2b58363800305184dce.jpg'),
(93271, 6546, 'Todo Mundo Adora o Raymond S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200087.mp4', 'http://timg.bdta.pro/images/5a277dd869e04635d06f5bb5be847372.jpg'),
(93272, 6546, 'Todo Mundo Adora o Raymond S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200088.mp4', 'http://timg.bdta.pro/images/ee2307f554d688c62f284b995d2303fd.jpg'),
(93273, 6546, 'Todo Mundo Adora o Raymond S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200089.mp4', 'http://timg.bdta.pro/images/71c966b6f02682e2cc96b0b82c8f76e5.jpg'),
(93274, 6546, 'Todo Mundo Adora o Raymond S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200090.mp4', 'http://timg.bdta.pro/images/bc9d67f187c1b7236b08d70421b713ef.jpg'),
(93275, 6546, 'Todo Mundo Adora o Raymond S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/200091.mp4', 'http://timg.bdta.pro/images/56c3b7e76694f8ae83215f753d3f5edf.jpg'),
(93276, 6546, 'Todo Mundo Adora o Raymond S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/200092.mp4', 'http://timg.bdta.pro/images/a802dfcfe0e8a82139c87988fd15b55b.jpg'),
(93277, 6546, 'Todo Mundo Adora o Raymond S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/200093.mp4', 'http://timg.bdta.pro/images/d81372f65fcbd4ec3269094d44b36300.jpg'),
(93278, 6546, 'Todo Mundo Adora o Raymond S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/200094.mp4', 'http://timg.bdta.pro/images/469194fe7c4bcb422b9215b39206ddc0.jpg'),
(93279, 6546, 'Todo Mundo Adora o Raymond S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/200095.mp4', 'http://timg.bdta.pro/images/024896b42f584b015189cbe44f26b20c.jpg'),
(93280, 6546, 'Todo Mundo Adora o Raymond S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/200096.mp4', 'http://timg.bdta.pro/images/d6a61008a6ae0855513afaaf31b674ff.jpg'),
(93281, 6546, 'Todo Mundo Adora o Raymond S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/200097.mp4', 'http://timg.bdta.pro/images/b74cc612d9de9b41d7ab0ae574d5b5b2.jpg'),
(93282, 6546, 'Todo Mundo Adora o Raymond S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/200098.mp4', 'http://timg.bdta.pro/images/e650251667f61af9cb7ae5b80954ea14.jpg'),
(93283, 6546, 'Todo Mundo Adora o Raymond S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/200099.mp4', 'http://timg.bdta.pro/images/d707418aa2f78df715e7520c6ec6346a.jpg'),
(93284, 6546, 'Todo Mundo Adora o Raymond S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/200100.mp4', 'http://timg.bdta.pro/images/efb3ac72534d412b58d3c3c8bc40e4f2.jpg'),
(93285, 6546, 'Todo Mundo Adora o Raymond S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/200101.mp4', 'http://timg.bdta.pro/images/4de5d29a72c9af4b52a607643ecb51d3.jpg'),
(93286, 6546, 'Todo Mundo Adora o Raymond S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/200102.mp4', 'http://timg.bdta.pro/images/cb2bae84d06c348b15f680fc0d101fc5.jpg'),
(93287, 6547, 'Todo Mundo Adora o Raymond S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200103.mp4', 'http://timg.bdta.pro/images/d12329c232ba3b5c2c352fed36c9547f.jpg'),
(93288, 6547, 'Todo Mundo Adora o Raymond S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200104.mp4', 'http://timg.bdta.pro/images/9c58141012c19a0c97b6931d61ca13ed.jpg'),
(93289, 6547, 'Todo Mundo Adora o Raymond S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200105.mp4', 'http://timg.bdta.pro/images/46846058c46d3e4b7151da667162a619.jpg'),
(93290, 6547, 'Todo Mundo Adora o Raymond S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200106.mp4', 'http://timg.bdta.pro/images/e0ffbbbfd19ba836277fc1b8e2c593b2.jpg'),
(93291, 6547, 'Todo Mundo Adora o Raymond S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200107.mp4', 'http://timg.bdta.pro/images/4a4f67fac7e7737a072fc23fa2904ae2.jpg'),
(93292, 6547, 'Todo Mundo Adora o Raymond S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200108.mp4', 'http://timg.bdta.pro/images/a38e87bebbf02bd82262007823f61b9f.jpg'),
(93293, 6547, 'Todo Mundo Adora o Raymond S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200109.mp4', 'http://timg.bdta.pro/images/ebff8fc4c290fd1aff3753b0382fd801.jpg'),
(93294, 6547, 'Todo Mundo Adora o Raymond S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200110.mp4', 'http://timg.bdta.pro/images/d41036800852c230eea70debcc24ec0c.jpg'),
(93295, 6547, 'Todo Mundo Adora o Raymond S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200111.mp4', 'http://timg.bdta.pro/images/d3721eae3809d897a4b4331fd36a0943.jpg'),
(93296, 6547, 'Todo Mundo Adora o Raymond S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200112.mp4', 'http://timg.bdta.pro/images/38da6999ae80421cac0a95ccfece63ec.jpg'),
(93297, 6547, 'Todo Mundo Adora o Raymond S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200113.mp4', 'http://timg.bdta.pro/images/843511bc3cff084542e320d42c3ef4d6.jpg'),
(93298, 6547, 'Todo Mundo Adora o Raymond S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200114.mp4', 'http://timg.bdta.pro/images/f5362d2d73a01bcd2a55114b622209b2.jpg'),
(93299, 6547, 'Todo Mundo Adora o Raymond S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200115.mp4', 'http://timg.bdta.pro/images/a6f084a590a9a81ba10b5afe7ecf333b.jpg'),
(93300, 6547, 'Todo Mundo Adora o Raymond S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/200116.mp4', 'http://timg.bdta.pro/images/4258479888092bccf49029c6a9c330c9.jpg'),
(93301, 6547, 'Todo Mundo Adora o Raymond S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/200117.mp4', 'http://timg.bdta.pro/images/f94176e4e91b67ad20df13bedf3d21a4.jpg'),
(93302, 6547, 'Todo Mundo Adora o Raymond S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/200118.mp4', 'http://timg.bdta.pro/images/c749e526c95f7ac605003668e0346d86.jpg'),
(93303, 6547, 'Todo Mundo Adora o Raymond S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/200119.mp4', 'http://timg.bdta.pro/images/fd1f77528b4913332499bac4de7e7120.jpg'),
(93304, 6547, 'Todo Mundo Adora o Raymond S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/200120.mp4', 'http://timg.bdta.pro/images/e55fefd32f28156fe229dee64285572e.jpg'),
(93305, 6547, 'Todo Mundo Adora o Raymond S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/200121.mp4', 'http://timg.bdta.pro/images/c2edd899d558ffb13f6170f72847e8b8.jpg'),
(93306, 6547, 'Todo Mundo Adora o Raymond S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/200122.mp4', 'http://timg.bdta.pro/images/41a5f91259a28544484de98fb26570bd.jpg'),
(93307, 6547, 'Todo Mundo Adora o Raymond S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/200123.mp4', 'http://timg.bdta.pro/images/ae6adaf6c58d59ccadceaecba0b59a44.jpg'),
(93308, 6547, 'Todo Mundo Adora o Raymond S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/200124.mp4', 'http://timg.bdta.pro/images/34cfbc71e7e1627587c12b17afeb9165.jpg'),
(93309, 6547, 'Todo Mundo Adora o Raymond S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/200125.mp4', 'http://timg.bdta.pro/images/200b6bc31228d7d2492d17a54c6d75c0.jpg'),
(93310, 6548, 'Todo Mundo Adora o Raymond S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200126.mp4', 'http://timg.bdta.pro/images/f435f0340f39783f26d501a9ec8accd8.jpg'),
(93311, 6548, 'Todo Mundo Adora o Raymond S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200127.mp4', 'http://timg.bdta.pro/images/da44f8bb81c94111a146e18228b64718.jpg'),
(93312, 6548, 'Todo Mundo Adora o Raymond S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200128.mp4', 'http://timg.bdta.pro/images/0d39efde9f50e979746d82c500c743fa.jpg'),
(93313, 6548, 'Todo Mundo Adora o Raymond S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200129.mp4', 'http://timg.bdta.pro/images/868c2c2291f7d48632184d28a3f2d42a.jpg'),
(93314, 6548, 'Todo Mundo Adora o Raymond S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200130.mp4', 'http://timg.bdta.pro/images/96e62c3c72c321d067035fb33a816cc8.jpg'),
(93315, 6548, 'Todo Mundo Adora o Raymond S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200131.mp4', 'http://timg.bdta.pro/images/5bc5052a50a001c4b748c83d2b5b0735.jpg'),
(93316, 6548, 'Todo Mundo Adora o Raymond S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200132.mp4', 'http://timg.bdta.pro/images/0339ee5449b0c500951fd5c1f8947e75.jpg'),
(93317, 6548, 'Todo Mundo Adora o Raymond S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200133.mp4', 'http://timg.bdta.pro/images/b20cd904fd1ffa354fe7864c66462da0.jpg'),
(93318, 6548, 'Todo Mundo Adora o Raymond S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200134.mp4', 'http://timg.bdta.pro/images/9e6520da65fc92122569952b3dda293c.jpg'),
(93319, 6548, 'Todo Mundo Adora o Raymond S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200135.mp4', 'http://timg.bdta.pro/images/326a3353ae588f733caefe43a0613573.jpg'),
(93320, 6548, 'Todo Mundo Adora o Raymond S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200136.mp4', 'http://timg.bdta.pro/images/215f1b89e741d267c1284efd53843d63.jpg'),
(93321, 6548, 'Todo Mundo Adora o Raymond S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200137.mp4', 'http://timg.bdta.pro/images/b1867a01228738346f20a43604965253.jpg'),
(93322, 6548, 'Todo Mundo Adora o Raymond S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200138.mp4', 'http://timg.bdta.pro/images/fea44428eac663c481334a005b923e8a.jpg'),
(93323, 6548, 'Todo Mundo Adora o Raymond S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/200139.mp4', 'http://timg.bdta.pro/images/7aec26b5f0ee32100362659dd44d2055.jpg'),
(93324, 6548, 'Todo Mundo Adora o Raymond S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/200140.mp4', 'http://timg.bdta.pro/images/f07e0e8a46ccfcc02769643d92e356b4.jpg'),
(93325, 6548, 'Todo Mundo Adora o Raymond S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/200141.mp4', 'http://timg.bdta.pro/images/007caad7d476cd9006e4b8d19190946c.jpg'),
(93326, 6549, 'Garotas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199868.mp4', 'http://timg.bdta.pro/images/d9cd1531feadeaec2bf4bed8d97b55d9.jpg'),
(93327, 6549, 'Garotas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199869.mp4', 'http://timg.bdta.pro/images/fe608f1551d019a88a470d44e770fe95.jpg'),
(93328, 6549, 'Garotas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199870.mp4', 'http://timg.bdta.pro/images/3e67dcdefd56075a3f52baa2c386ff45.jpg'),
(93329, 6549, 'Garotas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199871.mp4', 'http://timg.bdta.pro/images/4a0e9fedd5bde14cc92a038cd4188395.jpg'),
(93330, 6549, 'Garotas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199872.mp4', 'http://timg.bdta.pro/images/a0631cca30f470ae34856bfceb59d47d.jpg'),
(93331, 6549, 'Garotas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199873.mp4', 'http://timg.bdta.pro/images/3005fd5d79250e584b629219b0131a33.jpg'),
(93332, 6549, 'Garotas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199874.mp4', 'http://timg.bdta.pro/images/d7a5ce55f578d65ca6e7ace8d9957d0b.jpg'),
(93333, 6549, 'Garotas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199875.mp4', 'http://timg.bdta.pro/images/da14a1c907816ed38813df5c71148df2.jpg'),
(93334, 6549, 'Garotas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199876.mp4', 'http://timg.bdta.pro/images/85fde2bd3965b5db1686acdb6388c647.jpg'),
(93335, 6549, 'Garotas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199877.mp4', 'http://timg.bdta.pro/images/f83936e770a416b7455a2cc38252fabd.jpg'),
(93336, 6550, 'Garotas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199878.mp4', 'http://timg.bdta.pro/images/391b34aa203a47b3c7717eed052de6ee.jpg'),
(93337, 6550, 'Garotas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199879.mp4', 'http://timg.bdta.pro/images/01a84adf28e79e8e8bd757b3a901a474.jpg'),
(93338, 6550, 'Garotas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199880.mp4', 'http://timg.bdta.pro/images/961ed46e8171e3061852275dc9e5755b.jpg'),
(93339, 6550, 'Garotas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199881.mp4', 'http://timg.bdta.pro/images/5a3550057ceb0587f48a34141e9a4071.jpg'),
(93340, 6550, 'Garotas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199882.mp4', 'http://timg.bdta.pro/images/4759d3ff9532f33f6529ea7a558e8e7c.jpg'),
(93341, 6550, 'Garotas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199883.mp4', 'http://timg.bdta.pro/images/f55be176b95f03428877044f844c2ac8.jpg'),
(93342, 6550, 'Garotas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199884.mp4', 'http://timg.bdta.pro/images/001f1cc33e7bcb51a17da8cc65c1a2bc.jpg'),
(93343, 6550, 'Garotas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199885.mp4', 'http://timg.bdta.pro/images/46c47cd1014074d873697c1c18b64237.jpg'),
(93344, 6550, 'Garotas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199886.mp4', 'http://timg.bdta.pro/images/5d2917a63073c62da89c283f34e0dff5.jpg'),
(93345, 6550, 'Garotas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199887.mp4', 'http://timg.bdta.pro/images/af2d087b9cb9fb32ac2cb414a1ec340b.jpg'),
(93346, 6551, 'Garotas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199888.mp4', 'http://timg.bdta.pro/images/dbf6aa65a20279e9679c9811f3cb86a1.jpg'),
(93347, 6551, 'Garotas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199889.mp4', 'http://timg.bdta.pro/images/eb15f522a2b28687c1b54100a875031f.jpg'),
(93348, 6551, 'Garotas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199890.mp4', 'http://timg.bdta.pro/images/06e291540fb6e3f7ebaffdbb9eaf4362.jpg'),
(93349, 6551, 'Garotas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199891.mp4', 'http://timg.bdta.pro/images/b1906f073f71ad4b95d2ac6d6a5256a5.jpg'),
(93350, 6551, 'Garotas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199892.mp4', 'http://timg.bdta.pro/images/f2eaf8c37fcaf4a837c0095bb4e797f3.jpg'),
(93351, 6551, 'Garotas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199893.mp4', 'http://timg.bdta.pro/images/b3fe0a85fbb59424d232c4ad7c039323.jpg'),
(93352, 6551, 'Garotas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199894.mp4', 'http://timg.bdta.pro/images/fb8b528826a17440a99ed986e198cff4.jpg'),
(93353, 6551, 'Garotas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199895.mp4', 'http://timg.bdta.pro/images/02f8b84aea2211b15e3ce4a19451b57a.jpg'),
(93354, 6551, 'Garotas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199896.mp4', 'http://timg.bdta.pro/images/389aaff2a93128f652b71e1a3a9e0f57.jpg'),
(93355, 6551, 'Garotas S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199897.mp4', 'http://timg.bdta.pro/images/a4af319fc6b0af6b82d5b00392b5ace7.jpg'),
(93356, 6551, 'Garotas S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199898.mp4', 'http://timg.bdta.pro/images/1e54ee42eae66f5c01e24e062600cebc.jpg'),
(93357, 6551, 'Garotas S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199899.mp4', 'http://timg.bdta.pro/images/c70577091c8642739949b84bda004091.jpg'),
(93358, 6552, 'Garotas S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199900.mp4', 'http://timg.bdta.pro/images/58092da024db4a9bfc68479586780031.jpg'),
(93359, 6552, 'Garotas S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199901.mp4', 'http://timg.bdta.pro/images/f742e3fffa4b69a19969fa77a799afb4.jpg'),
(93360, 6552, 'Garotas S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199902.mp4', 'http://timg.bdta.pro/images/08c61636161312882ac4a3677de14be3.jpg'),
(93361, 6552, 'Garotas S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199903.mp4', 'http://timg.bdta.pro/images/bbc38f437bc982de157e9e19cbb280ac.jpg'),
(93362, 6552, 'Garotas S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199904.mp4', 'http://timg.bdta.pro/images/4ed7dec62c83311c51a9d6d847f22a51.jpg'),
(93363, 6552, 'Garotas S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199905.mp4', 'http://timg.bdta.pro/images/328879994337e03880e0afbc968f7bb2.jpg'),
(93364, 6552, 'Garotas S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199906.mp4', 'http://timg.bdta.pro/images/4c44a98485d0035ffdaa71b729b67828.jpg'),
(93365, 6552, 'Garotas S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199907.mp4', 'http://timg.bdta.pro/images/c944fbfbfde26d0bd2bc5bb5237d321b.jpg'),
(93366, 6552, 'Garotas S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199908.mp4', 'http://timg.bdta.pro/images/9bd6cb879ab033665d847855285754b8.jpg'),
(93367, 6552, 'Garotas S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199909.mp4', 'http://timg.bdta.pro/images/0ebebd6d9247ca524343699404612876.jpg'),
(93368, 6553, 'Garotas S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199910.mp4', 'http://timg.bdta.pro/images/b183a71a1a9fb1d317c8bb5f71f559b6.jpg'),
(93369, 6553, 'Garotas S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199911.mp4', 'http://timg.bdta.pro/images/ec6589ef079aecc3423c31c1e91e0330.jpg'),
(93370, 6553, 'Garotas S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199912.mp4', 'http://timg.bdta.pro/images/c4a5616d09dc437b0cab16016af0dd7f.jpg'),
(93371, 6553, 'Garotas S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199913.mp4', 'http://timg.bdta.pro/images/41f791d3cae41a37ef66198c72339473.jpg'),
(93372, 6553, 'Garotas S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199914.mp4', 'http://timg.bdta.pro/images/67160d8660e5cc116cb38b29a9754af7.jpg'),
(93373, 6553, 'Garotas S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199915.mp4', 'http://timg.bdta.pro/images/d9db2bbc91122b875807485385fc34c9.jpg'),
(93374, 6553, 'Garotas S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199916.mp4', 'http://timg.bdta.pro/images/6a51d0aeea78f67bf62a345e6a94e5a9.jpg'),
(93375, 6553, 'Garotas S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199917.mp4', 'http://timg.bdta.pro/images/f566d74dd062928757bf6e24ac49e671.jpg'),
(93376, 6553, 'Garotas S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199918.mp4', 'http://timg.bdta.pro/images/b0fbcb488c09be2358ebbb264027a4cc.jpg'),
(93377, 6553, 'Garotas S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199919.mp4', 'http://timg.bdta.pro/images/37c65e451a762c0ff6d39aa8366e7974.jpg'),
(93378, 6554, 'Garotas S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199920.mp4', 'http://timg.bdta.pro/images/7ca3fb691c4e68de2761c37597795f75.jpg'),
(93379, 6554, 'Garotas S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199921.mp4', 'http://timg.bdta.pro/images/cbaa848e2a482d787976ec0e8a7fa22c.jpg'),
(93380, 6554, 'Garotas S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199922.mp4', 'http://timg.bdta.pro/images/4d26a8ff30bd0ee7233da60527fc5bd3.jpg'),
(93381, 6554, 'Garotas S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199923.mp4', 'http://timg.bdta.pro/images/2d37d5bebc7d60c13a96a7f9974d9144.jpg'),
(93382, 6554, 'Garotas S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199924.mp4', 'http://timg.bdta.pro/images/e4fe5b8788364179203fb45349f29227.jpg'),
(93383, 6554, 'Garotas S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199925.mp4', 'http://timg.bdta.pro/images/82b793abe8cfa74274258fa6240e2276.jpg'),
(93384, 6554, 'Garotas S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199926.mp4', 'http://timg.bdta.pro/images/b44e187b86e61bc46490aa4c8fd1ceab.jpg'),
(93385, 6554, 'Garotas S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199927.mp4', 'http://timg.bdta.pro/images/e96e01b187049017c79c8d1565a4ca1c.jpg'),
(93386, 6554, 'Garotas S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199928.mp4', 'http://timg.bdta.pro/images/185b7d28cc3eec5cf1b3c35421b4815c.jpg'),
(93387, 6554, 'Garotas S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199929.mp4', 'http://timg.bdta.pro/images/ad9fc952ee6f2640f86b77c6b783e09c.jpg'),
(93388, 6555, '28 Dias Assombrados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199862.mp4', 'http://timg.bdta.pro/images/ff4e2d69307355198beb7af1d5b99455.jpg'),
(93389, 6555, '28 Dias Assombrados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199863.mp4', 'http://timg.bdta.pro/images/ee997240a4ce3277e4b4c61b2f70be5a.jpg'),
(93390, 6555, '28 Dias Assombrados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199864.mp4', 'http://timg.bdta.pro/images/8e827395541050f6ee91f3f2772d8433.jpg'),
(93391, 6555, '28 Dias Assombrados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199865.mp4', 'http://timg.bdta.pro/images/6bc66e27fd4c9ab66a2a5cf09f8c5d84.jpg'),
(93392, 6555, '28 Dias Assombrados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199866.mp4', 'http://timg.bdta.pro/images/bd54b8519cefdd1c3c2d0546e753ef28.jpg'),
(93393, 6555, '28 Dias Assombrados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199867.mp4', 'http://timg.bdta.pro/images/bcd0f375c792d97b9eaaf8b062428ba9.jpg'),
(93394, 6556, 'A Gangue da Luva Verde S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199854.mp4', 'http://gstaticontent.com/images/60bb89240442da0f2ffa97c42eb5b45b.jpg'),
(93395, 6556, 'A Gangue da Luva Verde S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199855.mp4', 'http://gstaticontent.com/images/60bb89240442da0f2ffa97c42eb5b45b.jpg'),
(93396, 6556, 'A Gangue da Luva Verde S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199856.mp4', 'http://gstaticontent.com/images/60bb89240442da0f2ffa97c42eb5b45b.jpg'),
(93397, 6556, 'A Gangue da Luva Verde S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199857.mp4', 'http://gstaticontent.com/images/60bb89240442da0f2ffa97c42eb5b45b.jpg'),
(93398, 6556, 'A Gangue da Luva Verde S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199858.mp4', 'http://gstaticontent.com/images/60bb89240442da0f2ffa97c42eb5b45b.jpg'),
(93399, 6556, 'A Gangue da Luva Verde S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199859.mp4', 'http://gstaticontent.com/images/60bb89240442da0f2ffa97c42eb5b45b.jpg'),
(93400, 6556, 'A Gangue da Luva Verde S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199860.mp4', 'http://gstaticontent.com/images/60bb89240442da0f2ffa97c42eb5b45b.jpg'),
(93401, 6556, 'A Gangue da Luva Verde S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199861.mp4', 'http://gstaticontent.com/images/60bb89240442da0f2ffa97c42eb5b45b.jpg'),
(93402, 6557, 'A Gangue da Luva Verde S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413484.mp4', 'http://gstaticontent.com/images/60bb89240442da0f2ffa97c42eb5b45b.jpg'),
(93403, 6557, 'A Gangue da Luva Verde S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/413485.mp4', 'http://gstaticontent.com/images/60bb89240442da0f2ffa97c42eb5b45b.jpg'),
(93404, 6557, 'A Gangue da Luva Verde S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/413486.mp4', 'http://gstaticontent.com/images/60bb89240442da0f2ffa97c42eb5b45b.jpg'),
(93405, 6557, 'A Gangue da Luva Verde S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/413487.mp4', 'http://gstaticontent.com/images/60bb89240442da0f2ffa97c42eb5b45b.jpg'),
(93406, 6557, 'A Gangue da Luva Verde S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/413488.mp4', 'http://gstaticontent.com/images/60bb89240442da0f2ffa97c42eb5b45b.jpg'),
(93407, 6557, 'A Gangue da Luva Verde S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/413489.mp4', 'http://gstaticontent.com/images/60bb89240442da0f2ffa97c42eb5b45b.jpg'),
(93408, 6557, 'A Gangue da Luva Verde S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/413490.mp4', 'http://gstaticontent.com/images/60bb89240442da0f2ffa97c42eb5b45b.jpg'),
(93409, 6557, 'A Gangue da Luva Verde S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/413491.mp4', 'http://gstaticontent.com/images/60bb89240442da0f2ffa97c42eb5b45b.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(93410, 6558, 'A Garota Desaparecida do Vaticano S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199850.mp4', 'http://gstaticontent.com/images/413569465a47a65a6138e725ff2af893.jpg'),
(93411, 6558, 'A Garota Desaparecida do Vaticano S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199851.mp4', 'http://gstaticontent.com/images/413569465a47a65a6138e725ff2af893.jpg'),
(93412, 6558, 'A Garota Desaparecida do Vaticano S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199852.mp4', 'http://gstaticontent.com/images/413569465a47a65a6138e725ff2af893.jpg'),
(93413, 6558, 'A Garota Desaparecida do Vaticano S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199853.mp4', 'http://gstaticontent.com/images/413569465a47a65a6138e725ff2af893.jpg'),
(93414, 6559, 'A Vida Selvagem do Dr. Ole S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199842.mp4', 'http://timg.bdta.pro/images/26cb5a0d9b8d12f15906e7ba8e6213db.jpg'),
(93415, 6559, 'A Vida Selvagem do Dr. Ole S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199843.mp4', 'http://timg.bdta.pro/images/6c061053c572bea1a14827c6b875fa23.jpg'),
(93416, 6559, 'A Vida Selvagem do Dr. Ole S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199844.mp4', 'http://timg.bdta.pro/images/0c558ba4bb3671cc0de0cbcfbe62fd0d.jpg'),
(93417, 6559, 'A Vida Selvagem do Dr. Ole S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199845.mp4', 'http://timg.bdta.pro/images/2b654b20289898c2359801415c00c780.jpg'),
(93418, 6559, 'A Vida Selvagem do Dr. Ole S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199846.mp4', 'http://timg.bdta.pro/images/6d0e5ffc186f2ca96548927d8e7cc269.jpg'),
(93419, 6559, 'A Vida Selvagem do Dr. Ole S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199847.mp4', 'http://timg.bdta.pro/images/57ee6e81a221d52421625cfcaa9b3e7d.jpg'),
(93420, 6559, 'A Vida Selvagem do Dr. Ole S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199848.mp4', 'http://timg.bdta.pro/images/a5747cbfcc8b23acf8964edcc989b9fa.jpg'),
(93421, 6559, 'A Vida Selvagem do Dr. Ole S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199849.mp4', 'http://timg.bdta.pro/images/17d8f350616f8bb39d0eb1e7d99cbe84.jpg'),
(93422, 6560, 'Amor Moderno Tóquio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199835.mp4', 'http://timg.bdta.pro/images/8c7bfd0af479320239e87fab1075f9a6.jpg'),
(93423, 6560, 'Amor Moderno Tóquio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199836.mp4', 'http://timg.bdta.pro/images/c42f937258dbd72567717cd1b21d4169.jpg'),
(93424, 6560, 'Amor Moderno Tóquio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199837.mp4', 'http://timg.bdta.pro/images/ad12f546ae6d330e37237e240020655c.jpg'),
(93425, 6560, 'Amor Moderno Tóquio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199838.mp4', 'http://timg.bdta.pro/images/37d1e7f8f502a1ae90ee03faaee8be1b.jpg'),
(93426, 6560, 'Amor Moderno Tóquio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199839.mp4', 'http://timg.bdta.pro/images/b2f54341cfc0b9fee6aa04dcdb0fa587.jpg'),
(93427, 6560, 'Amor Moderno Tóquio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199840.mp4', 'http://timg.bdta.pro/images/76f468e1fd88b3172b02a7478be138bd.jpg'),
(93428, 6560, 'Amor Moderno Tóquio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199841.mp4', 'http://timg.bdta.pro/images/ed9340dd20993454cc8fd223abd29024.jpg'),
(93429, 6561, 'Anomalia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199825.mp4', 'http://timg.bdta.pro/images/873aed1810bb278c36b092e901292488.jpg'),
(93430, 6561, 'Anomalia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199826.mp4', 'http://timg.bdta.pro/images/401d5d85b4cbc2215ddaf519985d5793.jpg'),
(93431, 6561, 'Anomalia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199827.mp4', 'http://timg.bdta.pro/images/d9f7e084fa91f63bb9a1d356a38b4c80.jpg'),
(93432, 6561, 'Anomalia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199828.mp4', 'http://timg.bdta.pro/images/0fc15dc2fedb124d621ce8730eb27b1d.jpg'),
(93433, 6561, 'Anomalia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199829.mp4', 'http://timg.bdta.pro/images/220fa359bdf35d4ef03fa0030f2fdfb4.jpg'),
(93434, 6561, 'Anomalia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199830.mp4', 'http://timg.bdta.pro/images/d14ec5a9277f67619c161d58d41f7ba9.jpg'),
(93435, 6561, 'Anomalia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199831.mp4', 'http://timg.bdta.pro/images/00d86eaa2c6b49a6a590bbbfedee012e.jpg'),
(93436, 6561, 'Anomalia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199832.mp4', 'http://timg.bdta.pro/images/fba066036763f993ed090a2cfa734f93.jpg'),
(93437, 6561, 'Anomalia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199833.mp4', 'http://timg.bdta.pro/images/2b2c0d7d88074cd13eb0163098a5ecae.jpg'),
(93438, 6561, 'Anomalia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199834.mp4', 'http://timg.bdta.pro/images/54b7c5e31a6b55ce88b4ba25fa3611d3.jpg'),
(93439, 6562, 'Aos Olhos do Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199822.mp4', 'http://timg.bdta.pro/images/08abaf81e7d0139dc9dd2b4bada821ac.jpg'),
(93440, 6562, 'Aos Olhos do Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199823.mp4', 'http://timg.bdta.pro/images/31bcb97bd67f2c7821a426ea9d78dfa4.jpg'),
(93441, 6562, 'Aos Olhos do Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199824.mp4', 'http://timg.bdta.pro/images/a6fa3292e7926f9b39ae73f8c3900644.jpg'),
(93442, 6563, 'Bake Off Brasil: Mão na Massa S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238445.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93443, 6563, 'Bake Off Brasil: Mão na Massa S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238446.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93444, 6563, 'Bake Off Brasil: Mão na Massa S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238447.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93445, 6563, 'Bake Off Brasil: Mão na Massa S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238448.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93446, 6563, 'Bake Off Brasil: Mão na Massa S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238449.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93447, 6563, 'Bake Off Brasil: Mão na Massa S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238450.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93448, 6563, 'Bake Off Brasil: Mão na Massa S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238451.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93449, 6563, 'Bake Off Brasil: Mão na Massa S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238452.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93450, 6563, 'Bake Off Brasil: Mão na Massa S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238453.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93451, 6563, 'Bake Off Brasil: Mão na Massa S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238454.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93452, 6563, 'Bake Off Brasil: Mão na Massa S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/238455.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93453, 6563, 'Bake Off Brasil: Mão na Massa S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/238456.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93454, 6563, 'Bake Off Brasil: Mão na Massa S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/238457.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93455, 6563, 'Bake Off Brasil: Mão na Massa S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/238458.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93456, 6563, 'Bake Off Brasil: Mão na Massa S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/238459.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93457, 6563, 'Bake Off Brasil: Mão na Massa S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/238460.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93458, 6563, 'Bake Off Brasil: Mão na Massa S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/238461.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93459, 6563, 'Bake Off Brasil: Mão na Massa S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/238462.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93460, 6564, 'Bake Off Brasil: Mão na Massa S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238463.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93461, 6564, 'Bake Off Brasil: Mão na Massa S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238464.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93462, 6564, 'Bake Off Brasil: Mão na Massa S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238465.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93463, 6564, 'Bake Off Brasil: Mão na Massa S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238466.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93464, 6564, 'Bake Off Brasil: Mão na Massa S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238467.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93465, 6564, 'Bake Off Brasil: Mão na Massa S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238468.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93466, 6564, 'Bake Off Brasil: Mão na Massa S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238469.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93467, 6564, 'Bake Off Brasil: Mão na Massa S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238470.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93468, 6564, 'Bake Off Brasil: Mão na Massa S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238471.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93469, 6564, 'Bake Off Brasil: Mão na Massa S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238472.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93470, 6564, 'Bake Off Brasil: Mão na Massa S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/238473.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93471, 6564, 'Bake Off Brasil: Mão na Massa S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/238474.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93472, 6564, 'Bake Off Brasil: Mão na Massa S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/238475.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93473, 6564, 'Bake Off Brasil: Mão na Massa S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/238476.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93474, 6564, 'Bake Off Brasil: Mão na Massa S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/238477.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93475, 6564, 'Bake Off Brasil: Mão na Massa S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/238478.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93476, 6564, 'Bake Off Brasil: Mão na Massa S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/238479.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93477, 6564, 'Bake Off Brasil: Mão na Massa S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/238480.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93478, 6565, 'Bake Off Brasil: Mão na Massa S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238481.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93479, 6565, 'Bake Off Brasil: Mão na Massa S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238482.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93480, 6565, 'Bake Off Brasil: Mão na Massa S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238483.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93481, 6565, 'Bake Off Brasil: Mão na Massa S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238484.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93482, 6565, 'Bake Off Brasil: Mão na Massa S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238485.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93483, 6565, 'Bake Off Brasil: Mão na Massa S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238486.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93484, 6565, 'Bake Off Brasil: Mão na Massa S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238487.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93485, 6565, 'Bake Off Brasil: Mão na Massa S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238488.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93486, 6565, 'Bake Off Brasil: Mão na Massa S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238489.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93487, 6565, 'Bake Off Brasil: Mão na Massa S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238490.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93488, 6565, 'Bake Off Brasil: Mão na Massa S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/238491.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93489, 6565, 'Bake Off Brasil: Mão na Massa S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/238492.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93490, 6565, 'Bake Off Brasil: Mão na Massa S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/238493.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93491, 6565, 'Bake Off Brasil: Mão na Massa S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/238494.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93492, 6565, 'Bake Off Brasil: Mão na Massa S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/238495.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93493, 6565, 'Bake Off Brasil: Mão na Massa S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/238496.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93494, 6565, 'Bake Off Brasil: Mão na Massa S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/238497.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93495, 6565, 'Bake Off Brasil: Mão na Massa S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/238498.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93496, 6565, 'Bake Off Brasil: Mão na Massa S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/238499.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93497, 6565, 'Bake Off Brasil: Mão na Massa S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/238500.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93498, 6565, 'Bake Off Brasil: Mão na Massa S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/238501.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93499, 6566, 'Bake Off Brasil: Mão na Massa S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238502.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93500, 6566, 'Bake Off Brasil: Mão na Massa S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238503.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93501, 6566, 'Bake Off Brasil: Mão na Massa S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238504.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93502, 6566, 'Bake Off Brasil: Mão na Massa S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238505.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93503, 6566, 'Bake Off Brasil: Mão na Massa S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238506.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93504, 6566, 'Bake Off Brasil: Mão na Massa S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238507.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93505, 6566, 'Bake Off Brasil: Mão na Massa S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238508.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93506, 6566, 'Bake Off Brasil: Mão na Massa S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238509.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93507, 6566, 'Bake Off Brasil: Mão na Massa S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238510.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93508, 6566, 'Bake Off Brasil: Mão na Massa S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238511.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93509, 6566, 'Bake Off Brasil: Mão na Massa S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/238512.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93510, 6566, 'Bake Off Brasil: Mão na Massa S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/238513.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93511, 6566, 'Bake Off Brasil: Mão na Massa S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/238514.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93512, 6566, 'Bake Off Brasil: Mão na Massa S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/238515.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93513, 6566, 'Bake Off Brasil: Mão na Massa S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/238516.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93514, 6566, 'Bake Off Brasil: Mão na Massa S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/238517.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93515, 6566, 'Bake Off Brasil: Mão na Massa S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/238518.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93516, 6566, 'Bake Off Brasil: Mão na Massa S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/238519.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93517, 6566, 'Bake Off Brasil: Mão na Massa S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/892544.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93518, 6567, 'Bake Off Brasil: Mão na Massa S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238520.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93519, 6567, 'Bake Off Brasil: Mão na Massa S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238521.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93520, 6567, 'Bake Off Brasil: Mão na Massa S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238522.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93521, 6567, 'Bake Off Brasil: Mão na Massa S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238523.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93522, 6567, 'Bake Off Brasil: Mão na Massa S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238524.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93523, 6567, 'Bake Off Brasil: Mão na Massa S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238525.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93524, 6567, 'Bake Off Brasil: Mão na Massa S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238526.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93525, 6567, 'Bake Off Brasil: Mão na Massa S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238527.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93526, 6568, 'Bake Off Brasil: Mão na Massa S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/427988.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93527, 6568, 'Bake Off Brasil: Mão na Massa S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/429966.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93528, 6568, 'Bake Off Brasil: Mão na Massa S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/437630.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93529, 6568, 'Bake Off Brasil: Mão na Massa S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/442926.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93530, 6568, 'Bake Off Brasil: Mão na Massa S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/448797.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93531, 6568, 'Bake Off Brasil: Mão na Massa S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/452905.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93532, 6568, 'Bake Off Brasil: Mão na Massa S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/464791.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93533, 6568, 'Bake Off Brasil: Mão na Massa S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/464792.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93534, 6568, 'Bake Off Brasil: Mão na Massa S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/470885.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93535, 6568, 'Bake Off Brasil: Mão na Massa S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/479051.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93536, 6568, 'Bake Off Brasil: Mão na Massa S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/483462.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93537, 6568, 'Bake Off Brasil: Mão na Massa S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/491656.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93538, 6568, 'Bake Off Brasil: Mão na Massa S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/493080.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93539, 6568, 'Bake Off Brasil: Mão na Massa S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/506508.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93540, 6568, 'Bake Off Brasil: Mão na Massa S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/509712.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93541, 6568, 'Bake Off Brasil: Mão na Massa S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/515835.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93542, 6568, 'Bake Off Brasil: Mão na Massa S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/519025.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93543, 6568, 'Bake Off Brasil: Mão na Massa S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/520452.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93544, 6568, 'Bake Off Brasil: Mão na Massa S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/637461.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93545, 6569, 'Bake Off Brasil: Mão na Massa S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/880605.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93546, 6569, 'Bake Off Brasil: Mão na Massa S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/880893.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93547, 6569, 'Bake Off Brasil: Mão na Massa S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/881354.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93548, 6569, 'Bake Off Brasil: Mão na Massa S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/882877.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93549, 6569, 'Bake Off Brasil: Mão na Massa S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/884086.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93550, 6569, 'Bake Off Brasil: Mão na Massa S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/885856.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93551, 6569, 'Bake Off Brasil: Mão na Massa S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/886270.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93552, 6569, 'Bake Off Brasil: Mão na Massa S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/887753.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93553, 6569, 'Bake Off Brasil: Mão na Massa S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/888235.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93554, 6569, 'Bake Off Brasil: Mão na Massa S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/889644.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93555, 6569, 'Bake Off Brasil: Mão na Massa S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/890159.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93556, 6569, 'Bake Off Brasil: Mão na Massa S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/891069.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93557, 6569, 'Bake Off Brasil: Mão na Massa S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/892009.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93558, 6569, 'Bake Off Brasil: Mão na Massa S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/893394.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93559, 6569, 'Bake Off Brasil: Mão na Massa S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/893608.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93560, 6569, 'Bake Off Brasil: Mão na Massa S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/894943.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93561, 6569, 'Bake Off Brasil: Mão na Massa S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/895910.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93562, 6569, 'Bake Off Brasil: Mão na Massa S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/896721.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93563, 6569, 'Bake Off Brasil: Mão na Massa S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/897475.mp4', 'http://gstaticontent.com/images/036dd98fc817b99607c96eefdb5dc46d.jpg'),
(93564, 6570, 'Deixa Ela Entrar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202569.mp4', 'http://timg.bdta.pro/images/95edc8988f6ab50079e292caad38654d.jpg'),
(93565, 6570, 'Deixa Ela Entrar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/42jc5X8JGwQ71yXn3eJ4n24jT81.jpg'),
(93566, 6570, 'Deixa Ela Entrar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qg9zE6mgbXd5SRhDC49NhlO0gyB.jpg'),
(93567, 6570, 'Deixa Ela Entrar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202572.mp4', 'http://image.tmdb.org/t/p/w1280/AecpUXAjt5jrKpxVQG4cejsG1ds.jpg'),
(93568, 6570, 'Deixa Ela Entrar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iy8M0mFKoyGPzvecUoagicMWfAi.jpg'),
(93569, 6570, 'Deixa Ela Entrar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5sm8otBjxeWLCWq5Giu47SKj79N.jpg'),
(93570, 6570, 'Deixa Ela Entrar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202575.mp4', 'http://image.tmdb.org/t/p/w1280/4HRUhvtmVhnb7tnBnoDhi4eNJoS.jpg'),
(93571, 6570, 'Deixa Ela Entrar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202576.mp4', 'http://image.tmdb.org/t/p/w1280/puhyNDZPVuhUsMegRM9kbPNTGia.jpg'),
(93572, 6570, 'Deixa Ela Entrar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202577.mp4', 'http://image.tmdb.org/t/p/w1280/lsUx1eHJLO9yDPtZRxVaKt9S1wf.jpg'),
(93573, 6570, 'Deixa Ela Entrar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202578.mp4', 'http://image.tmdb.org/t/p/w1280/1GkoPKQHtfjzvLlUE0HV6Tn2Tap.jpg'),
(93574, 6571, 'Desafio em Dose Dupla Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199816.mp4', 'http://timg.bdta.pro/images/dd44af5ed3949f1bfda5a9bbf12f161a.jpg'),
(93575, 6571, 'Desafio em Dose Dupla Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199817.mp4', 'http://timg.bdta.pro/images/1b1e6da25adec4838faa89e54ca910f8.jpg'),
(93576, 6571, 'Desafio em Dose Dupla Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199818.mp4', 'http://timg.bdta.pro/images/220e3421c7fac91b1baf7eedfa458201.jpg'),
(93577, 6571, 'Desafio em Dose Dupla Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199819.mp4', 'http://timg.bdta.pro/images/92f1f7dbaa0f0807b6442b3465d49649.jpg'),
(93578, 6571, 'Desafio em Dose Dupla Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199820.mp4', 'http://timg.bdta.pro/images/0191a83f228ce18902baab40616bf54c.jpg'),
(93579, 6571, 'Desafio em Dose Dupla Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199821.mp4', 'http://timg.bdta.pro/images/449ceb3a166045cbee841ce2a2e3a98a.jpg'),
(93580, 6572, 'Este Tonto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199806.mp4', 'http://timg.bdta.pro/images/bcf79f807720337be6d420bb7a10650b.jpg'),
(93581, 6572, 'Este Tonto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199807.mp4', 'http://timg.bdta.pro/images/73096f10297c2896ef86662cf38368e0.jpg'),
(93582, 6572, 'Este Tonto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199808.mp4', 'http://timg.bdta.pro/images/b53da12f96fb41abc78fac534dad0391.jpg'),
(93583, 6572, 'Este Tonto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199809.mp4', 'http://timg.bdta.pro/images/dd9d3e9fdc002d64f86a667499adcf64.jpg'),
(93584, 6572, 'Este Tonto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199810.mp4', 'http://timg.bdta.pro/images/36b02f953f6da972fd3bb85eb03b40ff.jpg'),
(93585, 6572, 'Este Tonto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199811.mp4', 'http://timg.bdta.pro/images/ce6581c978fb481d08ec76c514a53018.jpg'),
(93586, 6572, 'Este Tonto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199812.mp4', 'http://timg.bdta.pro/images/c172ee3bf9fe17c5e6046c9df7077d04.jpg'),
(93587, 6572, 'Este Tonto S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199813.mp4', 'http://timg.bdta.pro/images/9a705f3913ad4089a84c2f166cc3802b.jpg'),
(93588, 6572, 'Este Tonto S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199814.mp4', 'http://timg.bdta.pro/images/dffea57d4b366c2e6102c1dad674d6d3.jpg'),
(93589, 6572, 'Este Tonto S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199815.mp4', 'http://timg.bdta.pro/images/5255828d372f61a6812f43152d608a13.jpg'),
(93590, 6573, 'Frasier S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199782.mp4', 'http://timg.bdta.pro/images/3b4b54ef9de007c71e7f7711ffe94196.jpg'),
(93591, 6573, 'Frasier S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199783.mp4', 'http://timg.bdta.pro/images/aa89d010f8cf6d742c8454f133dbaf9e.jpg'),
(93592, 6573, 'Frasier S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199784.mp4', 'http://timg.bdta.pro/images/703643e6866cbc994dd403fb93b1dc31.jpg'),
(93593, 6573, 'Frasier S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199785.mp4', 'http://timg.bdta.pro/images/31a6d1ad6ba8c3cb97684e65e1407f6a.jpg'),
(93594, 6573, 'Frasier S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199786.mp4', 'http://timg.bdta.pro/images/2a0071fa292183642372c5c20336568e.jpg'),
(93595, 6573, 'Frasier S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199787.mp4', 'http://timg.bdta.pro/images/9e053e7db81dee1b36d20d8eff537a57.jpg'),
(93596, 6573, 'Frasier S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199788.mp4', 'http://timg.bdta.pro/images/f1f1b8a85390c057dd1a3ca0855d29a0.jpg'),
(93597, 6573, 'Frasier S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199789.mp4', 'http://timg.bdta.pro/images/28f739ef85f5ec5329e74cc395a2e7f8.jpg'),
(93598, 6573, 'Frasier S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199790.mp4', 'http://timg.bdta.pro/images/f68b09600a02ae48ee41d125e47b60ce.jpg'),
(93599, 6573, 'Frasier S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199791.mp4', 'http://timg.bdta.pro/images/299f3985619ee6b6188d9543bf2df390.jpg'),
(93600, 6573, 'Frasier S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199792.mp4', 'http://timg.bdta.pro/images/9514cc900b022804f78b779aed9b6873.jpg'),
(93601, 6573, 'Frasier S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199793.mp4', 'http://timg.bdta.pro/images/b479d62c4ed739f4824f69dc202a1f2b.jpg'),
(93602, 6573, 'Frasier S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/199794.mp4', 'http://timg.bdta.pro/images/501a8b62c2c7a988f3dd55cc604fbc6f.jpg'),
(93603, 6573, 'Frasier S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/199795.mp4', 'http://timg.bdta.pro/images/1c0e462c4af34fa8f6a7f4ce7d295a01.jpg'),
(93604, 6573, 'Frasier S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/199796.mp4', 'http://timg.bdta.pro/images/2b3b559754937e5db2d6fd868c0be6de.jpg'),
(93605, 6573, 'Frasier S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/199797.mp4', 'http://timg.bdta.pro/images/cf11161fa47f93d403ff391c6d1dff87.jpg'),
(93606, 6573, 'Frasier S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/199798.mp4', 'http://timg.bdta.pro/images/44cfdacc2ba00d88b1f0d58705353a8d.jpg'),
(93607, 6573, 'Frasier S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/199799.mp4', 'http://timg.bdta.pro/images/2603b6d9ba8ec940d1cc02c20802d60d.jpg'),
(93608, 6573, 'Frasier S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/199800.mp4', 'http://timg.bdta.pro/images/f74e59ab4bc3da12463e7865ee555f24.jpg'),
(93609, 6573, 'Frasier S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/199801.mp4', 'http://timg.bdta.pro/images/5062cfd2c9b4ac2f8d159c45f1e848f8.jpg'),
(93610, 6573, 'Frasier S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/199802.mp4', 'http://timg.bdta.pro/images/0baa3f79d6bcbcefec10c2b73f9a754c.jpg'),
(93611, 6573, 'Frasier S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/199803.mp4', 'http://timg.bdta.pro/images/f5481b75f0e6bff4d67d6a991315c3e4.jpg'),
(93612, 6573, 'Frasier S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/199804.mp4', 'http://timg.bdta.pro/images/1c0256868d6bb13e0dea1bd9a3051b55.jpg'),
(93613, 6573, 'Frasier S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/199805.mp4', 'http://timg.bdta.pro/images/e798f92578a1caeb32f4e7b012dba142.jpg'),
(93614, 6574, 'Frasier S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/877365.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93615, 6574, 'Frasier S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/877366.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93616, 6574, 'Frasier S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/877367.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93617, 6574, 'Frasier S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/877368.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93618, 6574, 'Frasier S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/877369.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93619, 6574, 'Frasier S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/877370.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93620, 6574, 'Frasier S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/877371.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93621, 6574, 'Frasier S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/877372.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93622, 6574, 'Frasier S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/877373.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93623, 6574, 'Frasier S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/877374.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93624, 6574, 'Frasier S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/877375.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93625, 6574, 'Frasier S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/877376.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93626, 6574, 'Frasier S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/877377.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93627, 6574, 'Frasier S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/877378.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93628, 6574, 'Frasier S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/877379.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93629, 6574, 'Frasier S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/877380.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93630, 6574, 'Frasier S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/877381.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93631, 6574, 'Frasier S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/877382.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93632, 6574, 'Frasier S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/877383.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93633, 6574, 'Frasier S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/877384.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93634, 6574, 'Frasier S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/877385.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93635, 6574, 'Frasier S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/877386.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93636, 6574, 'Frasier S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/877387.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93637, 6574, 'Frasier S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/877388.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93638, 6575, 'Frasier S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/877389.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93639, 6575, 'Frasier S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/877390.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93640, 6575, 'Frasier S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/877391.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93641, 6575, 'Frasier S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/877392.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93642, 6575, 'Frasier S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/877393.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93643, 6575, 'Frasier S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/877394.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93644, 6575, 'Frasier S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/877395.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93645, 6575, 'Frasier S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/877396.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93646, 6575, 'Frasier S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/877397.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93647, 6575, 'Frasier S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/877398.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93648, 6575, 'Frasier S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/877399.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93649, 6575, 'Frasier S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/877400.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93650, 6575, 'Frasier S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/877401.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93651, 6575, 'Frasier S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/877402.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93652, 6575, 'Frasier S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/877403.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93653, 6575, 'Frasier S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/877404.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93654, 6575, 'Frasier S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/877405.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93655, 6575, 'Frasier S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/877406.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93656, 6575, 'Frasier S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/877407.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93657, 6575, 'Frasier S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/877408.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93658, 6575, 'Frasier S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/877409.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93659, 6575, 'Frasier S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/877410.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93660, 6575, 'Frasier S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/877411.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93661, 6575, 'Frasier S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/877412.mp4', 'http://gstaticontent.com/images/00990c35703a4c908fba40f3ae074ba4.jpg'),
(93662, 6576, 'Maggie: A Vidente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199769.mp4', 'http://timg.bdta.pro/images/3891bffe113d29680a7ede1b42ac70b8.jpg'),
(93663, 6576, 'Maggie: A Vidente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199770.mp4', 'http://timg.bdta.pro/images/36e9f1719c82b952d04817509f24cd58.jpg'),
(93664, 6576, 'Maggie: A Vidente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199771.mp4', 'http://timg.bdta.pro/images/7013594ca3c38c51c6a0560855eff3be.jpg'),
(93665, 6576, 'Maggie: A Vidente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199772.mp4', 'http://timg.bdta.pro/images/a7c3591120c2c037ebb8cb20de00a43a.jpg'),
(93666, 6576, 'Maggie: A Vidente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199773.mp4', 'http://timg.bdta.pro/images/237d1cd5ebcad7ca732c29f76d1bea37.jpg'),
(93667, 6576, 'Maggie: A Vidente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199774.mp4', 'http://timg.bdta.pro/images/e679e58d7ea4747cf72139cbed113713.jpg'),
(93668, 6576, 'Maggie: A Vidente S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199775.mp4', 'http://timg.bdta.pro/images/bd700f76e6ac9396ec452bfccd02abba.jpg'),
(93669, 6576, 'Maggie: A Vidente S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199776.mp4', 'http://timg.bdta.pro/images/eb2a88b8e9f2492960d7ac277b939f0d.jpg'),
(93670, 6576, 'Maggie: A Vidente S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199777.mp4', 'http://timg.bdta.pro/images/7d6f54b2e7ede3cf985069e359a7fff6.jpg'),
(93671, 6576, 'Maggie: A Vidente S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199778.mp4', 'http://timg.bdta.pro/images/15d3f314970b99a78d7e6bd37e71331b.jpg'),
(93672, 6576, 'Maggie: A Vidente S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199779.mp4', 'http://timg.bdta.pro/images/5a8609bc5950d88a4d6a9bb58cd9fbc1.jpg'),
(93673, 6576, 'Maggie: A Vidente S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199780.mp4', 'http://timg.bdta.pro/images/ab5bab608d2e9e8aa206f23521c6169c.jpg'),
(93674, 6576, 'Maggie: A Vidente S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/199781.mp4', 'http://timg.bdta.pro/images/636f5095dfd6005be71810f3e786a632.jpg'),
(93675, 6577, 'Nosso Segredo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199767.mp4', 'http://timg.bdta.pro/images/c514624d380a29aee4e399e5cb0c41d2.jpg'),
(93676, 6577, 'Nosso Segredo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199768.mp4', 'http://timg.bdta.pro/images/06a0e6a2077d9873a72fa1ed4c5e4305.jpg'),
(93677, 6578, 'Notre-Dame: Catedral em Chamas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199761.mp4', 'http://timg.bdta.pro/images/cb907b199b0e94f1142d15899990a0c3.jpg'),
(93678, 6578, 'Notre-Dame: Catedral em Chamas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199762.mp4', 'http://timg.bdta.pro/images/69d62b7be2589d1e190cb3aa7d6bbbbe.jpg'),
(93679, 6578, 'Notre-Dame: Catedral em Chamas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199763.mp4', 'http://timg.bdta.pro/images/dbecd79e940dfad90168fcb91fab06c4.jpg'),
(93680, 6578, 'Notre-Dame: Catedral em Chamas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199764.mp4', 'http://timg.bdta.pro/images/6fa379b4670288f34d3281e5ef15ce53.jpg'),
(93681, 6578, 'Notre-Dame: Catedral em Chamas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199765.mp4', 'http://timg.bdta.pro/images/5a31d238433f11d235eac7db9631e8e4.jpg'),
(93682, 6578, 'Notre-Dame: Catedral em Chamas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199766.mp4', 'http://timg.bdta.pro/images/c0104f2030f29ba2b1bbdb2f4fe019bf.jpg'),
(93683, 6579, 'O Rei da TV S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208510.mp4', 'http://timg.bdta.pro/images/5cf4647c819349cc5ce7b0877a63f714.jpg'),
(93684, 6579, 'O Rei da TV S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208511.mp4', 'http://timg.bdta.pro/images/6c8139f6a5f15228efb9719248e72d99.jpg'),
(93685, 6579, 'O Rei da TV S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208512.mp4', 'http://timg.bdta.pro/images/594f0f5c9cb7a95cdf1a6fd9e7bc70ef.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(93686, 6579, 'O Rei da TV S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208513.mp4', 'http://timg.bdta.pro/images/0fc1fcc2b3aa23c2042054eb3e4e8206.jpg'),
(93687, 6579, 'O Rei da TV S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208514.mp4', 'http://timg.bdta.pro/images/e330c5bd8788dbccf8843f8b0b3caa6f.jpg'),
(93688, 6579, 'O Rei da TV S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208515.mp4', 'http://timg.bdta.pro/images/f214ac88be95173aa143c75ae49c957c.jpg'),
(93689, 6579, 'O Rei da TV S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208516.mp4', 'http://timg.bdta.pro/images/103c5b44f7eced0d48239149994c3286.jpg'),
(93690, 6579, 'O Rei da TV S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208517.mp4', 'http://timg.bdta.pro/images/15042616779d8266921fd894ed391cab.jpg'),
(93691, 6580, 'O Rei da TV S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pFE4tQgONCrVuFc1rw2KgROtW2s.jpg'),
(93692, 6580, 'O Rei da TV S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w02n1MTsh2UUlhz1CgYDrtHK1yv.jpg'),
(93693, 6580, 'O Rei da TV S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qr2dfefSEK0CzFsDW6flQdVP0UF.jpg'),
(93694, 6580, 'O Rei da TV S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3SUVGtd8RZo2tJww1MZaaozovdZ.jpg'),
(93695, 6580, 'O Rei da TV S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oI4JVa5Dm6RiFfXButJFoPFpDpx.jpg'),
(93696, 6580, 'O Rei da TV S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zVMs4YivZ3FkoJA4qM0IaSbfNCZ.jpg'),
(93697, 6580, 'O Rei da TV S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aqk3xQRWF5bk5nNuk9qUHycblnw.jpg'),
(93698, 6580, 'O Rei da TV S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gp3e5cdRSgkv0h8FletJF0QeSUx.jpg'),
(93699, 6581, 'O Sabotador S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199751.mp4', 'http://timg.bdta.pro/images/90d5a0601558f6f61f22662ffceb1503.jpg'),
(93700, 6581, 'O Sabotador S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199752.mp4', 'http://timg.bdta.pro/images/fef9b5851cb02c559d482259982f5567.jpg'),
(93701, 6581, 'O Sabotador S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199753.mp4', 'http://timg.bdta.pro/images/351407b28cdc067e9e772ec6349b376e.jpg'),
(93702, 6581, 'O Sabotador S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199754.mp4', 'http://timg.bdta.pro/images/0fb2a8568bb49b480b92655b23f7426a.jpg'),
(93703, 6581, 'O Sabotador S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199755.mp4', 'http://timg.bdta.pro/images/ce66a9a5d54297e1638ca79bbca5776a.jpg'),
(93704, 6581, 'O Sabotador S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199756.mp4', 'http://timg.bdta.pro/images/43de643d5325c4bf12eebb4b69d582eb.jpg'),
(93705, 6581, 'O Sabotador S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199757.mp4', 'http://timg.bdta.pro/images/91c9119da2ccdca10fa29d64f25615a9.jpg'),
(93706, 6581, 'O Sabotador S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199758.mp4', 'http://timg.bdta.pro/images/5cff3a268b328dca3a6898f825a3f0aa.jpg'),
(93707, 6581, 'O Sabotador S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199759.mp4', 'http://timg.bdta.pro/images/e8cd11e2a14a060fd3671d595363eba1.jpg'),
(93708, 6581, 'O Sabotador S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199760.mp4', 'http://timg.bdta.pro/images/ddf01aa012ea82888123ef9ebfc0e82e.jpg'),
(93709, 6582, 'O Sabotador S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/411763.mp4', 'http://gstaticontent.com/images/67cd86495121c23ee725f46cf9b9e144.jpg'),
(93710, 6582, 'O Sabotador S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/411764.mp4', 'http://gstaticontent.com/images/67cd86495121c23ee725f46cf9b9e144.jpg'),
(93711, 6582, 'O Sabotador S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/411765.mp4', 'http://gstaticontent.com/images/67cd86495121c23ee725f46cf9b9e144.jpg'),
(93712, 6582, 'O Sabotador S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/411766.mp4', 'http://gstaticontent.com/images/67cd86495121c23ee725f46cf9b9e144.jpg'),
(93713, 6582, 'O Sabotador S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/411767.mp4', 'http://gstaticontent.com/images/67cd86495121c23ee725f46cf9b9e144.jpg'),
(93714, 6582, 'O Sabotador S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/411768.mp4', 'http://gstaticontent.com/images/67cd86495121c23ee725f46cf9b9e144.jpg'),
(93715, 6582, 'O Sabotador S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/411769.mp4', 'http://gstaticontent.com/images/67cd86495121c23ee725f46cf9b9e144.jpg'),
(93716, 6582, 'O Sabotador S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/411770.mp4', 'http://gstaticontent.com/images/67cd86495121c23ee725f46cf9b9e144.jpg'),
(93717, 6582, 'O Sabotador S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/411771.mp4', 'http://gstaticontent.com/images/67cd86495121c23ee725f46cf9b9e144.jpg'),
(93718, 6582, 'O Sabotador S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/411772.mp4', 'http://gstaticontent.com/images/67cd86495121c23ee725f46cf9b9e144.jpg'),
(93719, 6583, 'O Urso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226231.mp4', 'http://timg.bdta.pro/images/922ef3d0d2c6a7abeb495fabef9cd75a.jpg'),
(93720, 6583, 'O Urso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226232.mp4', 'http://timg.bdta.pro/images/f084cf932e7ca4091404f5d5d2552248.jpg'),
(93721, 6583, 'O Urso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226233.mp4', 'http://timg.bdta.pro/images/cfe878f114b121704f2dea1bf9031df1.jpg'),
(93722, 6583, 'O Urso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226234.mp4', 'http://timg.bdta.pro/images/8593637ec1056360060f3c967e0cd648.jpg'),
(93723, 6583, 'O Urso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226235.mp4', 'http://timg.bdta.pro/images/3b250d17fa69ebbe792b3347e2d09629.jpg'),
(93724, 6583, 'O Urso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226236.mp4', 'http://timg.bdta.pro/images/ed2e5894593be8ec267dadcce034962c.jpg'),
(93725, 6583, 'O Urso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226237.mp4', 'http://timg.bdta.pro/images/b63295ca8e239d17111832480fec5331.jpg'),
(93726, 6583, 'O Urso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226238.mp4', 'http://timg.bdta.pro/images/7e53db8252e0324c16e538d6bddc0c61.jpg'),
(93727, 6584, 'O Urso S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bV51sdguQRlPyXGnvYXrQ6vqfeL.jpg'),
(93728, 6584, 'O Urso S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p0a8ny2R7Y9vrtr9YrqoKNXxwEo.jpg'),
(93729, 6584, 'O Urso S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qEudocx2rslmbPiLRKNlnjXoil9.jpg'),
(93730, 6584, 'O Urso S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6tVDfwkpQvdJt2dmwXxMPk5L1lh.jpg'),
(93731, 6584, 'O Urso S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gohsyAFvncNUy04R4KAH51BVxHm.jpg'),
(93732, 6584, 'O Urso S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lr5HYA6HBrumWeo0gbrQtArDOTG.jpg'),
(93733, 6584, 'O Urso S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kfriW9qcOIUQCfUJnl3nM6HNNjO.jpg'),
(93734, 6584, 'O Urso S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qHU7uPRtwkbVczdE3nbqs6eimuK.jpg'),
(93735, 6584, 'O Urso S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kWfUNYDWjMxB5360Hgk4xTv6Uvg.jpg'),
(93736, 6584, 'O Urso S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z9f4K1WJT59N81ae1Uy0znb3c4C.jpg'),
(93737, 6585, 'O Urso S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/419408.mp4', 'http://gstaticontent.com/images/b046f814fca4cf4b24aecefad7ae7920.jpg'),
(93738, 6585, 'O Urso S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/404327.mp4', 'http://gstaticontent.com/images/b046f814fca4cf4b24aecefad7ae7920.jpg'),
(93739, 6585, 'O Urso S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/614471.mp4', 'http://gstaticontent.com/images/b046f814fca4cf4b24aecefad7ae7920.jpg'),
(93740, 6585, 'O Urso S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/408462.mp4', 'http://gstaticontent.com/images/b046f814fca4cf4b24aecefad7ae7920.jpg'),
(93741, 6585, 'O Urso S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/411752.mp4', 'http://gstaticontent.com/images/b046f814fca4cf4b24aecefad7ae7920.jpg'),
(93742, 6585, 'O Urso S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/419413.mp4', 'http://gstaticontent.com/images/b046f814fca4cf4b24aecefad7ae7920.jpg'),
(93743, 6585, 'O Urso S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/419414.mp4', 'http://gstaticontent.com/images/b046f814fca4cf4b24aecefad7ae7920.jpg'),
(93744, 6585, 'O Urso S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/419415.mp4', 'http://gstaticontent.com/images/b046f814fca4cf4b24aecefad7ae7920.jpg'),
(93745, 6585, 'O Urso S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/419416.mp4', 'http://gstaticontent.com/images/b046f814fca4cf4b24aecefad7ae7920.jpg'),
(93746, 6585, 'O Urso S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/421134.mp4', 'http://gstaticontent.com/images/b046f814fca4cf4b24aecefad7ae7920.jpg'),
(93747, 6586, 'O Urso S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/855796.mp4', 'http://gstaticontent.com/images/b046f814fca4cf4b24aecefad7ae7920.jpg'),
(93748, 6586, 'O Urso S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/855797.mp4', 'http://gstaticontent.com/images/b046f814fca4cf4b24aecefad7ae7920.jpg'),
(93749, 6586, 'O Urso S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/855798.mp4', 'http://gstaticontent.com/images/b046f814fca4cf4b24aecefad7ae7920.jpg'),
(93750, 6586, 'O Urso S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/855799.mp4', 'http://gstaticontent.com/images/b046f814fca4cf4b24aecefad7ae7920.jpg'),
(93751, 6586, 'O Urso S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/855800.mp4', 'http://gstaticontent.com/images/b046f814fca4cf4b24aecefad7ae7920.jpg'),
(93752, 6586, 'O Urso S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/855801.mp4', 'http://gstaticontent.com/images/b046f814fca4cf4b24aecefad7ae7920.jpg'),
(93753, 6586, 'O Urso S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/855802.mp4', 'http://gstaticontent.com/images/b046f814fca4cf4b24aecefad7ae7920.jpg'),
(93754, 6586, 'O Urso S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/855803.mp4', 'http://gstaticontent.com/images/b046f814fca4cf4b24aecefad7ae7920.jpg'),
(93755, 6586, 'O Urso S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/855804.mp4', 'http://gstaticontent.com/images/b046f814fca4cf4b24aecefad7ae7920.jpg'),
(93756, 6586, 'O Urso S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/855805.mp4', 'http://gstaticontent.com/images/b046f814fca4cf4b24aecefad7ae7920.jpg'),
(93757, 6587, 'Amor Rural S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199739.mp4', 'http://timg.bdta.pro/images/8797ef403abf3526ca1f42e79ac9a541.jpg'),
(93758, 6587, 'Amor Rural S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199740.mp4', 'http://timg.bdta.pro/images/2ad7d6a003bb458e4a87ec278acf9564.jpg'),
(93759, 6587, 'Amor Rural S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199741.mp4', 'http://timg.bdta.pro/images/d91986ec4fe7ff56faf62d8357a385f3.jpg'),
(93760, 6587, 'Amor Rural S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199742.mp4', 'http://timg.bdta.pro/images/9d19e9d6cf199323ccf2b6392777ec89.jpg'),
(93761, 6587, 'Amor Rural S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199743.mp4', 'http://timg.bdta.pro/images/4edc49d521c9263faa5f3a804a0e7bac.jpg'),
(93762, 6587, 'Amor Rural S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199744.mp4', 'http://timg.bdta.pro/images/1920ffb8c87fe624c06f49119dd821eb.jpg'),
(93763, 6587, 'Amor Rural S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199745.mp4', 'http://timg.bdta.pro/images/1e1fac857b37017b844cd05e68228b5c.jpg'),
(93764, 6587, 'Amor Rural S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199746.mp4', 'http://timg.bdta.pro/images/90fdfbb03c2a1863fe373e636a21128c.jpg'),
(93765, 6587, 'Amor Rural S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199747.mp4', 'http://timg.bdta.pro/images/05809f98bfe75362942e3dfff3270d17.jpg'),
(93766, 6587, 'Amor Rural S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199748.mp4', 'http://timg.bdta.pro/images/5596b500e3faa662d3d4b63ca74f506c.jpg'),
(93767, 6587, 'Amor Rural S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199749.mp4', 'http://timg.bdta.pro/images/3100a7f138acdd956e4d4e2f1f164344.jpg'),
(93768, 6587, 'Amor Rural S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199750.mp4', 'http://timg.bdta.pro/images/bb8e4d89285337f40b855049870c5c20.jpg'),
(93769, 6588, 'ONI: A Lenda do Deus do Trovão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199735.mp4', 'http://timg.bdta.pro/images/f87a2e1e506522040444e945d0692bc1.jpg'),
(93770, 6588, 'ONI: A Lenda do Deus do Trovão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199736.mp4', 'http://timg.bdta.pro/images/1b8e07426ce691b67999a5988b57565a.jpg'),
(93771, 6588, 'ONI: A Lenda do Deus do Trovão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199737.mp4', 'http://timg.bdta.pro/images/6c6a069e0b2247b858a0e9dac5d96401.jpg'),
(93772, 6588, 'ONI: A Lenda do Deus do Trovão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199738.mp4', 'http://timg.bdta.pro/images/0346a4f8b0d6ba86173a85d912811966.jpg'),
(93773, 6589, 'Os Franceses S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201932.mp4', 'http://timg.bdta.pro/images/193cdbd9aee4185b424daef1ce1ce94a.jpg'),
(93774, 6589, 'Os Franceses S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201933.mp4', 'http://timg.bdta.pro/images/21a306c383ca227fd952b2f9404a41a5.jpg'),
(93775, 6589, 'Os Franceses S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201934.mp4', 'http://timg.bdta.pro/images/361498075aa32931cb2d0f51a4486aab.jpg'),
(93776, 6589, 'Os Franceses S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201935.mp4', 'http://timg.bdta.pro/images/87ad729f7f0824434745425fbd5a2bfb.jpg'),
(93777, 6589, 'Os Franceses S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201936.mp4', 'http://timg.bdta.pro/images/9e3872a16cebd305da3e9d4a74be87c3.jpg'),
(93778, 6589, 'Os Franceses S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201937.mp4', 'http://timg.bdta.pro/images/5e082f1ea32eeabc6b4eeb7c8cf8b846.jpg'),
(93779, 6590, 'Os Franceses S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k5YIfdz1Ukl8Li2L2CtzKk7T2m3.jpg'),
(93780, 6590, 'Os Franceses S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oQvqpbcP8qJwcno1SzEVy2yM06r.jpg'),
(93781, 6590, 'Os Franceses S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTQbR5EZ2WrX4tlqk2dEpOnrFLv.jpg'),
(93782, 6590, 'Os Franceses S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7HjGetzvVkzivJNfqbguGCJbv1E.jpg'),
(93783, 6591, 'Pé-Grande do Alasca: O Assassino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199703.mp4', 'http://gstaticontent.com/images/cb5587a833351fcfff0787f1ad717eb6.jpg'),
(93784, 6591, 'Pé-Grande do Alasca: O Assassino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199704.mp4', 'http://gstaticontent.com/images/cb5587a833351fcfff0787f1ad717eb6.jpg'),
(93785, 6591, 'Pé-Grande do Alasca: O Assassino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199705.mp4', 'http://gstaticontent.com/images/cb5587a833351fcfff0787f1ad717eb6.jpg'),
(93786, 6591, 'Pé-Grande do Alasca: O Assassino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199706.mp4', 'http://gstaticontent.com/images/cb5587a833351fcfff0787f1ad717eb6.jpg'),
(93787, 6591, 'Pé-Grande do Alasca: O Assassino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199707.mp4', 'http://gstaticontent.com/images/cb5587a833351fcfff0787f1ad717eb6.jpg'),
(93788, 6591, 'Pé-Grande do Alasca: O Assassino S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199708.mp4', 'http://gstaticontent.com/images/cb5587a833351fcfff0787f1ad717eb6.jpg'),
(93789, 6591, 'Pé-Grande do Alasca: O Assassino S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199709.mp4', 'http://gstaticontent.com/images/cb5587a833351fcfff0787f1ad717eb6.jpg'),
(93790, 6591, 'Pé-Grande do Alasca: O Assassino S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199710.mp4', 'http://gstaticontent.com/images/cb5587a833351fcfff0787f1ad717eb6.jpg'),
(93791, 6592, 'Periféricos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200666.mp4', 'http://timg.bdta.pro/images/9bc13fb92e9d82557794b5fb3f79f390.jpg'),
(93792, 6592, 'Periféricos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200667.mp4', 'http://timg.bdta.pro/images/6f05a4564cb4b8095eabbd7c2a6ac99a.jpg'),
(93793, 6592, 'Periféricos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzwwOCHbpJoSuNe3FkNCzUVExBg.jpg'),
(93794, 6592, 'Periféricos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wdQeBYdEWtsjOqrYlTazIGkcAdU.jpg'),
(93795, 6592, 'Periféricos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200670.mp4', 'http://image.tmdb.org/t/p/w1280/8BxT8iY5J29d0F9LNTFQCJx7xlc.jpg'),
(93796, 6592, 'Periféricos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8n5RRQVN2aleqC7qdE4lqZZVVdo.jpg'),
(93797, 6592, 'Periféricos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7aVfZAyZwhjEnrMKoaBp4QUNO1X.jpg'),
(93798, 6592, 'Periféricos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200673.mp4', 'http://image.tmdb.org/t/p/w1280/3GkSWgNdOpzFLgiRhfzzmGzrGK1.jpg'),
(93799, 6593, 'Recomeço S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199695.mp4', 'http://timg.bdta.pro/images/525df40b8e56748880209b7e6a09c204.jpg'),
(93800, 6593, 'Recomeço S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199696.mp4', 'http://timg.bdta.pro/images/8757d9ff9b218ca9e7ffa51915c64fc5.jpg'),
(93801, 6593, 'Recomeço S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199697.mp4', 'http://timg.bdta.pro/images/63edec2b2808fda128580e1d67d2f824.jpg'),
(93802, 6593, 'Recomeço S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199698.mp4', 'http://timg.bdta.pro/images/cfb5a21ab1497097c7b102ae842f5627.jpg'),
(93803, 6593, 'Recomeço S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199699.mp4', 'http://timg.bdta.pro/images/eb83576bfd16c2d212dfe7c7ae644299.jpg'),
(93804, 6593, 'Recomeço S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199700.mp4', 'http://timg.bdta.pro/images/7868e885874b36815a37a9619dd22890.jpg'),
(93805, 6593, 'Recomeço S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199701.mp4', 'http://timg.bdta.pro/images/14c84214047d62f4bc6b26062703749c.jpg'),
(93806, 6593, 'Recomeço S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199702.mp4', 'http://timg.bdta.pro/images/4ff063ab5e022dba1fda029802a5773f.jpg'),
(93807, 6594, 'Snowdrop S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199679.mp4', 'http://timg.bdta.pro/images/99e84ddabd0e1d60f9be26a224f1c4ff.jpg'),
(93808, 6594, 'Snowdrop S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199680.mp4', 'http://timg.bdta.pro/images/a6eebee974df2018037d5c67d8ff3c3b.jpg'),
(93809, 6594, 'Snowdrop S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199681.mp4', 'http://timg.bdta.pro/images/4315df636532a0d7f04e70f9c8991c15.jpg'),
(93810, 6594, 'Snowdrop S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199682.mp4', 'http://timg.bdta.pro/images/99549d352485b8165b61b69ace2348dc.jpg'),
(93811, 6594, 'Snowdrop S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199683.mp4', 'http://timg.bdta.pro/images/7d4d74e79a86d7e32428a38ef6f9a506.jpg'),
(93812, 6594, 'Snowdrop S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199684.mp4', 'http://timg.bdta.pro/images/0149226f1404a4e6b0b998d1b38aef34.jpg'),
(93813, 6594, 'Snowdrop S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199685.mp4', 'http://timg.bdta.pro/images/bf2517b741c4da5258bd5b141f2db286.jpg'),
(93814, 6594, 'Snowdrop S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199686.mp4', 'http://timg.bdta.pro/images/385589ed7971c606b67a14d3b4db36be.jpg'),
(93815, 6594, 'Snowdrop S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199687.mp4', 'http://timg.bdta.pro/images/b210571426ede98979bbed82d233c25c.jpg'),
(93816, 6594, 'Snowdrop S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199688.mp4', 'http://timg.bdta.pro/images/5016e1a7a8421cb8fb6495ce0190350b.jpg'),
(93817, 6594, 'Snowdrop S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199689.mp4', 'http://timg.bdta.pro/images/b1cd95459d460fe627811f934a5930dc.jpg'),
(93818, 6594, 'Snowdrop S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199690.mp4', 'http://timg.bdta.pro/images/49728b99e38debbd3ad4e585ce5550ee.jpg'),
(93819, 6594, 'Snowdrop S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/199691.mp4', 'http://timg.bdta.pro/images/1b38bb749c92cd19b9a78697bbe6c266.jpg'),
(93820, 6594, 'Snowdrop S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/199692.mp4', 'http://timg.bdta.pro/images/957076fd967e13e7eac2b23248c391f5.jpg'),
(93821, 6594, 'Snowdrop S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/199693.mp4', 'http://timg.bdta.pro/images/bb0ce2c077a81e5eaefcdc89747becd9.jpg'),
(93822, 6594, 'Snowdrop S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/199694.mp4', 'http://timg.bdta.pro/images/eed3614dadb23c17982f084eae79ac3e.jpg'),
(93823, 6595, 'Soundtrack #1 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199675.mp4', 'http://timg.bdta.pro/images/ede6aaaa3529ee0f8773fafa5997641c.jpg'),
(93824, 6595, 'Soundtrack #1 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199676.mp4', 'http://timg.bdta.pro/images/da1956b382859e37bd8389ca296ec43d.jpg'),
(93825, 6595, 'Soundtrack #1 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199677.mp4', 'http://timg.bdta.pro/images/1fc016ea727769b7c8b2e69d81db62f6.jpg'),
(93826, 6595, 'Soundtrack #1 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199678.mp4', 'http://timg.bdta.pro/images/0e1b69aa24093d4b048d5780ca5fa0ca.jpg'),
(93827, 6596, 'The Vow S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200832.mp4', 'http://timg.bdta.pro/images/93212e4c85504707357ea965fbfd6278.jpg'),
(93828, 6596, 'The Vow S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200833.mp4', 'http://timg.bdta.pro/images/7ab1a387db3661e56f1f86796fd87c85.jpg'),
(93829, 6596, 'The Vow S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200834.mp4', 'http://timg.bdta.pro/images/854a9cc3fa24678c9966b52fab42e16c.jpg'),
(93830, 6596, 'The Vow S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200835.mp4', 'http://timg.bdta.pro/images/07d25253b84adb8c44fca2a2047e148a.jpg'),
(93831, 6596, 'The Vow S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200836.mp4', 'http://timg.bdta.pro/images/f06f9a2e4a02a117934109828da0154a.jpg'),
(93832, 6596, 'The Vow S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200837.mp4', 'http://timg.bdta.pro/images/37c7ec51a09cf4e7aba2f4d9f972c9e9.jpg'),
(93833, 6596, 'The Vow S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200838.mp4', 'http://timg.bdta.pro/images/73afa7636645c39f0b60f7a5c9625c64.jpg'),
(93834, 6596, 'The Vow S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200839.mp4', 'http://timg.bdta.pro/images/c20fabc02867f51a842568cf7a58fd3f.jpg'),
(93835, 6596, 'The Vow S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200840.mp4', 'http://timg.bdta.pro/images/e23a65b65f175c4331dbf7236794fe19.jpg'),
(93836, 6597, 'The Vow S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fgI7K8McA46tho2E0W57PHepQFG.jpg'),
(93837, 6597, 'The Vow S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ghG7xqduQWEBXUDkZVN1R1T8CLq.jpg'),
(93838, 6597, 'The Vow S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8mud1afS91nIFWeU6J9BVVZcROr.jpg'),
(93839, 6597, 'The Vow S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200844.mp4', 'http://image.tmdb.org/t/p/w1280/hueYPVCCHg6AYe7U27ictkDQpf5.jpg'),
(93840, 6597, 'The Vow S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e57AGoHItiq9JCDXkJhoYjdjV2n.jpg'),
(93841, 6597, 'The Vow S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tVF9Al0OnsQNd1CWFPcCCeEMoOn.jpg'),
(93842, 6598, 'Kaçış: Fuga Terrorista S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSypJLogcmFpE04ZLgF88mxqwb2.jpg'),
(93843, 6598, 'Kaçış: Fuga Terrorista S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lLaxQDzzCq8aL0ijQqm23CC7z7B.jpg'),
(93844, 6598, 'Kaçış: Fuga Terrorista S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mlhVc8JsZce37UXOv0jstZdtMBm.jpg'),
(93845, 6598, 'Kaçış: Fuga Terrorista S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kk6uZSQgVVNt5KBS8DFCNNyhGjX.jpg'),
(93846, 6598, 'Kaçış: Fuga Terrorista S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3wOMiTb2DbYdFSuBPmBOJUgfYdO.jpg'),
(93847, 6598, 'Kaçış: Fuga Terrorista S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/40oSCgVHBz7dyKNZz6qWuVdGp2R.jpg'),
(93848, 6598, 'Kaçış: Fuga Terrorista S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cpAGfK4PUCosz5wTG1s6LAVRIY.jpg'),
(93849, 6598, 'Kaçış: Fuga Terrorista S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmP6fDcJWXP0ezDby0NGq9yoQW9.jpg'),
(93850, 6599, 'A Hora do Diabo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6lcslvwrg4JZSb0Pm1Sz4LdX866.jpg'),
(93851, 6599, 'A Hora do Diabo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/foiRBYzJg32Dz6NyRyj6kWGTuV2.jpg'),
(93852, 6599, 'A Hora do Diabo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/61iJP0vi1q5d3TAI87PVVYxkhs0.jpg'),
(93853, 6599, 'A Hora do Diabo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4RXhpwZ6aMD843A2nrfeZbsjkPA.jpg'),
(93854, 6599, 'A Hora do Diabo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lL1CvYIrHHycFvx00WBNvPmRyTJ.jpg'),
(93855, 6599, 'A Hora do Diabo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t8qrk1bPFjNI1TIVqieuZDfEt3z.jpg'),
(93856, 6600, 'A Hora do Diabo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFU6ZPAs6g8Y9Eld28GULJYt3rC.jpg'),
(93857, 6600, 'A Hora do Diabo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFU6ZPAs6g8Y9Eld28GULJYt3rC.jpg'),
(93858, 6600, 'A Hora do Diabo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFU6ZPAs6g8Y9Eld28GULJYt3rC.jpg'),
(93859, 6600, 'A Hora do Diabo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFU6ZPAs6g8Y9Eld28GULJYt3rC.jpg'),
(93860, 6600, 'A Hora do Diabo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mFU6ZPAs6g8Y9Eld28GULJYt3rC.jpg'),
(93861, 6601, 'A Sétima Arte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/syIud9KHZGtNjxD0ALTAa8WCUMs.jpg'),
(93862, 6601, 'A Sétima Arte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/syIud9KHZGtNjxD0ALTAa8WCUMs.jpg'),
(93863, 6601, 'A Sétima Arte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/syIud9KHZGtNjxD0ALTAa8WCUMs.jpg'),
(93864, 6601, 'A Sétima Arte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/syIud9KHZGtNjxD0ALTAa8WCUMs.jpg'),
(93865, 6601, 'A Sétima Arte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/syIud9KHZGtNjxD0ALTAa8WCUMs.jpg'),
(93866, 6601, 'A Sétima Arte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/syIud9KHZGtNjxD0ALTAa8WCUMs.jpg'),
(93867, 6601, 'A Sétima Arte S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/syIud9KHZGtNjxD0ALTAa8WCUMs.jpg'),
(93868, 6602, 'Eu Serei o Amor de Alguém S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zMpJGjp0bQ4AJhS5WrdJFMiukZZ.jpg'),
(93869, 6602, 'Eu Serei o Amor de Alguém S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sB5w7a8moou5J60m67Z2r0kENwc.jpg'),
(93870, 6602, 'Eu Serei o Amor de Alguém S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ilkNODkvIJtpzLZlDizkMWHTVtm.jpg'),
(93871, 6602, 'Eu Serei o Amor de Alguém S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vIMTf1VSNM4tLRYTpHoStXuTTS0.jpg'),
(93872, 6602, 'Eu Serei o Amor de Alguém S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vHHvkQBJxyBahSZTREmL8uxGygj.jpg'),
(93873, 6602, 'Eu Serei o Amor de Alguém S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVcjOGLXz7WaU7TT48FH5GY9wgX.jpg'),
(93874, 6602, 'Eu Serei o Amor de Alguém S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wxcpqK8YHAF4P119rMdTFoiosmC.jpg'),
(93875, 6602, 'Eu Serei o Amor de Alguém S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pnkz23Mh0UJp2F43JaMXucalINH.jpg'),
(93876, 6602, 'Eu Serei o Amor de Alguém S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wz0wXbqHPSDpHlhnRRyiCFDSNli.jpg'),
(93877, 6602, 'Eu Serei o Amor de Alguém S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s2qrSAiO3IBOVg1NeoPcVbjb3R1.jpg'),
(93878, 6602, 'Eu Serei o Amor de Alguém S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v3BKxjqRZtGCLxtRxbtDXtx9IXT.jpg'),
(93879, 6602, 'Eu Serei o Amor de Alguém S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8VuRQq5pgFAT6SsF4jRzF4IleAU.jpg'),
(93880, 6603, 'As Três Irmãs S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lFzY5Qj1Wz6MNTf1Ws139WYWOGC.jpg'),
(93881, 6603, 'As Três Irmãs S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ab7w9F4DHMYobIEvSgQTVRNuRvk.jpg'),
(93882, 6603, 'As Três Irmãs S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gHF9MZClR8D0DjFIwgkHcMVi1In.jpg'),
(93883, 6603, 'As Três Irmãs S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/UBwAwFrOFi5HjiY9PYSfaw27I8.jpg'),
(93884, 6603, 'As Três Irmãs S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AhUS0scrVHkZosTmkwufSdQdnFE.jpg'),
(93885, 6603, 'As Três Irmãs S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/16bww1M0K5Hn7FSWHmXMI5MeP7X.jpg'),
(93886, 6603, 'As Três Irmãs S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kZ3JOak7Bwg7Q6yRxo0lwY9kI65.jpg'),
(93887, 6603, 'As Três Irmãs S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/byALTp3r4uuHRs4qo58YEaJXfyC.jpg'),
(93888, 6603, 'As Três Irmãs S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMv4NVKXBhwqK2QDmQIthD8JYEC.jpg'),
(93889, 6603, 'As Três Irmãs S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zFbcCZS6nf5fbv67I1i9VRHazIR.jpg'),
(93890, 6604, 'Blanca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/taRe6SnaRfGPn8ERYuEIrJ6oDED.jpg'),
(93891, 6604, 'Blanca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u6glBYiY0EWZ3b7hLJaQxbMenU1.jpg'),
(93892, 6604, 'Blanca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z3WvlNqN9Af74Uo99Jer9PS0mVr.jpg'),
(93893, 6604, 'Blanca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkug9AV938GLnKMfoqCWLx3c1xf.jpg'),
(93894, 6604, 'Blanca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/opvJERs6HUWqFDY5CadLQch6V9L.jpg'),
(93895, 6604, 'Blanca S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ud2eKVjXOqf4SzJYo2DvvDEIsI.jpg'),
(93896, 6604, 'Blanca S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ygLft4UvzyeMUZegHNwcCKo7TgG.jpg'),
(93897, 6604, 'Blanca S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ygLft4UvzyeMUZegHNwcCKo7TgG.jpg'),
(93898, 6604, 'Blanca S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ygLft4UvzyeMUZegHNwcCKo7TgG.jpg'),
(93899, 6604, 'Blanca S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ygLft4UvzyeMUZegHNwcCKo7TgG.jpg'),
(93900, 6604, 'Blanca S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ygLft4UvzyeMUZegHNwcCKo7TgG.jpg'),
(93901, 6604, 'Blanca S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ygLft4UvzyeMUZegHNwcCKo7TgG.jpg'),
(93902, 6605, 'Capitães S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zvPCvCO8ljuQ6NAOijSARuEqIsA.jpg'),
(93903, 6605, 'Capitães S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zvPCvCO8ljuQ6NAOijSARuEqIsA.jpg'),
(93904, 6605, 'Capitães S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zvPCvCO8ljuQ6NAOijSARuEqIsA.jpg'),
(93905, 6605, 'Capitães S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zvPCvCO8ljuQ6NAOijSARuEqIsA.jpg'),
(93906, 6605, 'Capitães S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zvPCvCO8ljuQ6NAOijSARuEqIsA.jpg'),
(93907, 6605, 'Capitães S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zvPCvCO8ljuQ6NAOijSARuEqIsA.jpg'),
(93908, 6605, 'Capitães S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zvPCvCO8ljuQ6NAOijSARuEqIsA.jpg'),
(93909, 6605, 'Capitães S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zvPCvCO8ljuQ6NAOijSARuEqIsA.jpg'),
(93910, 6606, 'Conversas Entre Amigos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oaQPNUFwnGv4gefQQVgjjATFOrN.jpg'),
(93911, 6606, 'Conversas Entre Amigos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yB5JWnVX9Ci2Kpel461CcH96FqO.jpg'),
(93912, 6606, 'Conversas Entre Amigos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ro4FILNlAytalNSgYptGByL4lBR.jpg'),
(93913, 6606, 'Conversas Entre Amigos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xY30DhrBZZXhQl3dkLkfLspZ3kG.jpg'),
(93914, 6606, 'Conversas Entre Amigos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7aJ06LbNZAZ0pcnG3Vp1hWeuABE.jpg'),
(93915, 6606, 'Conversas Entre Amigos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5qwYuYWB0xRHWYo7jukrCGugKMH.jpg'),
(93916, 6606, 'Conversas Entre Amigos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfDmaWpVsJsgoLCN7y6r8nZxp9V.jpg'),
(93917, 6606, 'Conversas Entre Amigos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bMTG2b9Nc0y7P18CWAhB8It8o0Y.jpg'),
(93918, 6606, 'Conversas Entre Amigos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rOB64akEkMT0f01btaw7i7qrAVd.jpg'),
(93919, 6606, 'Conversas Entre Amigos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1lk2tN2JDph8t71JxAFKRzgMT8G.jpg'),
(93920, 6606, 'Conversas Entre Amigos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mJ3ZmgMjWCmPDuBeN4y1R29vXJb.jpg'),
(93921, 6607, 'Drink Masters S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8vJeICkikSzd8ZNbc4T3EKneAwl.jpg'),
(93922, 6607, 'Drink Masters S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8vJeICkikSzd8ZNbc4T3EKneAwl.jpg'),
(93923, 6607, 'Drink Masters S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8vJeICkikSzd8ZNbc4T3EKneAwl.jpg'),
(93924, 6607, 'Drink Masters S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8vJeICkikSzd8ZNbc4T3EKneAwl.jpg'),
(93925, 6607, 'Drink Masters S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8vJeICkikSzd8ZNbc4T3EKneAwl.jpg'),
(93926, 6607, 'Drink Masters S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8vJeICkikSzd8ZNbc4T3EKneAwl.jpg'),
(93927, 6607, 'Drink Masters S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8vJeICkikSzd8ZNbc4T3EKneAwl.jpg'),
(93928, 6607, 'Drink Masters S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8vJeICkikSzd8ZNbc4T3EKneAwl.jpg'),
(93929, 6607, 'Drink Masters S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8vJeICkikSzd8ZNbc4T3EKneAwl.jpg'),
(93930, 6607, 'Drink Masters S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8vJeICkikSzd8ZNbc4T3EKneAwl.jpg'),
(93931, 6608, 'Dubai Ostentacao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93932, 6608, 'Dubai Ostentacao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93933, 6608, 'Dubai Ostentacao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93934, 6608, 'Dubai Ostentacao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93935, 6608, 'Dubai Ostentacao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93936, 6608, 'Dubai Ostentacao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93937, 6608, 'Dubai Ostentacao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93938, 6608, 'Dubai Ostentacao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93939, 6609, 'Dubai Ostentacao S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93940, 6609, 'Dubai Ostentacao S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93941, 6609, 'Dubai Ostentacao S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93942, 6609, 'Dubai Ostentacao S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93943, 6609, 'Dubai Ostentacao S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93944, 6609, 'Dubai Ostentacao S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93945, 6609, 'Dubai Ostentacao S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93946, 6609, 'Dubai Ostentacao S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93947, 6610, 'Dubai Ostentacao S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/663001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93948, 6610, 'Dubai Ostentacao S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/663002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93949, 6610, 'Dubai Ostentacao S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/663003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93950, 6610, 'Dubai Ostentacao S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/663004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93951, 6610, 'Dubai Ostentacao S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/663005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93952, 6610, 'Dubai Ostentacao S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/663006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93953, 6610, 'Dubai Ostentacao S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/663007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93954, 6610, 'Dubai Ostentacao S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/663008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93955, 6610, 'Dubai Ostentacao S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/663009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySa4J8De2SVGzzvmWzNfwlNkYqa.jpg'),
(93956, 6611, 'García! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b76mcJ9QeWAmdeVuOLeSXJSbqfw.jpg'),
(93957, 6611, 'García! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uHVV1GJ8N4xSkBbBFKzwtrgiOU0.jpg'),
(93958, 6611, 'García! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200994.mp4', 'http://image.tmdb.org/t/p/w1280/43OGMESnNhnLLekEYIsF4BnJWGA.jpg'),
(93959, 6611, 'García! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2egY2xKaDuTOMuESJ8qCgfTnr.jpg'),
(93960, 6611, 'García! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ojHEm5R0TRma9IzGGm47Y51PfhU.jpg'),
(93961, 6611, 'García! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i7tI4vwLKb5oXgcZTGeobm3b6rh.jpg'),
(93962, 6612, 'Gigolô Americano S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2aMiYA5osbqz5Fh8fdJEJzrrO6b.jpg'),
(93963, 6612, 'Gigolô Americano S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w04V4Qpk5nT2gus8BY9qajC2ZGQ.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(93964, 6612, 'Gigolô Americano S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8dr1rnUbSddHwVhOYT5K2LuulUb.jpg'),
(93965, 6612, 'Gigolô Americano S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zjWztKgFMWlSYbAgQlBUt5zonXX.jpg'),
(93966, 6612, 'Gigolô Americano S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pLQQcMj75RdRwy6lNkuGYhEGY7B.jpg'),
(93967, 6612, 'Gigolô Americano S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d70D7Bd0LYcGnJ5xbstZB0UY16N.jpg'),
(93968, 6612, 'Gigolô Americano S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6TWxxOCijp0yfOSH6pbaEuLf8c0.jpg'),
(93969, 6612, 'Gigolô Americano S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6ge02Cdc6Xm8sHpGhTXwyqWVwm.jpg'),
(93970, 6613, 'Kindaichi: O Jovem Detetive S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uIpb4CvwwZbVqkgvy9HMbMF7Ukc.jpg'),
(93971, 6613, 'Kindaichi: O Jovem Detetive S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wwtT5Y23yGKuKQDHBhVgxxANctz.jpg'),
(93972, 6613, 'Kindaichi: O Jovem Detetive S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e35yPibCevjr1OeKBRBjXWGnqGy.jpg'),
(93973, 6613, 'Kindaichi: O Jovem Detetive S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4DQhlz36GNaZnh5PC003JTeeIzZ.jpg'),
(93974, 6613, 'Kindaichi: O Jovem Detetive S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d7EeSRxq2BbxLBVE26vYwfzBPCp.jpg'),
(93975, 6613, 'Kindaichi: O Jovem Detetive S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cjh6xT2sREivhLhS6f0EfXuZadR.jpg'),
(93976, 6613, 'Kindaichi: O Jovem Detetive S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nj59yW4LbTm0d7IRK9LwXp3pC5d.jpg'),
(93977, 6613, 'Kindaichi: O Jovem Detetive S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6gllO12dIScSEYcKMM5eOHQTTgm.jpg'),
(93978, 6613, 'Kindaichi: O Jovem Detetive S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z1B7igD0YCHXUl5XsnY2ydUZJwj.jpg'),
(93979, 6613, 'Kindaichi: O Jovem Detetive S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/27B3d8p0Ur5SIHFV5VYikuMdY56.jpg'),
(93980, 6614, 'Minha Família em Jogo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2cTxWAHcmJAJz5w06HomnynQCMR.jpg'),
(93981, 6614, 'Minha Família em Jogo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6sDct3kCuuwOI9jXeGJTNmOunan.jpg'),
(93982, 6614, 'Minha Família em Jogo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bufdduTJGFxZ0jA2yOxuPSKvnoC.jpg'),
(93983, 6614, 'Minha Família em Jogo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kaLEDWZ4cdiuiTR9psM9JY0IdaP.jpg'),
(93984, 6614, 'Minha Família em Jogo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/21npVYn8TOMY0LRRHWZ8bRU39D0.jpg'),
(93985, 6614, 'Minha Família em Jogo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2FaZ59eOvqO6pz4TBoYScegbdEd.jpg'),
(93986, 6614, 'Minha Família em Jogo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xN2CNQLYKpiAc7tisw720rc2cpY.jpg'),
(93987, 6614, 'Minha Família em Jogo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w20Re4byyALZfdG3Dy5ktnL7XYu.jpg'),
(93988, 6614, 'Minha Família em Jogo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b4vutCSrZhIyFPr3HHoWnUnS4Uu.jpg'),
(93989, 6614, 'Minha Família em Jogo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVkZwjbTyUfygmPHQUtAXbr7Dvt.jpg'),
(93990, 6615, 'O Filho Bastardo do Diabo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iAiMFYTsy4NsOzZBrhH345k8bLT.jpg'),
(93991, 6615, 'O Filho Bastardo do Diabo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/72Vz8m6m3YnRNtTx3DAqmdErYj3.jpg'),
(93992, 6615, 'O Filho Bastardo do Diabo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/970SUckF8oUMzbGde6cOGpFG6mW.jpg'),
(93993, 6615, 'O Filho Bastardo do Diabo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aIju3bhXbUplfW8YJ8EEJogVGwJ.jpg'),
(93994, 6615, 'O Filho Bastardo do Diabo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wqaSPWwwiPQuIAzl405TqbMP714.jpg'),
(93995, 6615, 'O Filho Bastardo do Diabo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A6QlPgweCmOLGxNl1YXrObJr0G.jpg'),
(93996, 6615, 'O Filho Bastardo do Diabo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bZPeIEYRiyAEi4yPB6aNJ1kRWCF.jpg'),
(93997, 6615, 'O Filho Bastardo do Diabo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/agqIs2n3YWXurNmuK8Mm2KJ47cW.jpg'),
(93998, 6616, 'O Fim da Beleza S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nqcWiSSPDHKbwxNi07EwUNtWBs2.jpg'),
(93999, 6616, 'O Fim da Beleza S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nqcWiSSPDHKbwxNi07EwUNtWBs2.jpg'),
(94000, 6616, 'O Fim da Beleza S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nqcWiSSPDHKbwxNi07EwUNtWBs2.jpg'),
(94001, 6617, 'O Gabinete de Curiosidades de Guillermo Del Toro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9BaI9NeywOr6Ryr8kKSJmAOc47.jpg'),
(94002, 6617, 'O Gabinete de Curiosidades de Guillermo Del Toro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7r8bRcrf80yYsYN2ULpwXgiV4RN.jpg'),
(94003, 6617, 'O Gabinete de Curiosidades de Guillermo Del Toro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bcahKugkhxhXno6gUvOMZ4NhAA3.jpg'),
(94004, 6617, 'O Gabinete de Curiosidades de Guillermo Del Toro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Og8wdSUf2AWGkxPcVgT9HV6eLK.jpg'),
(94005, 6617, 'O Gabinete de Curiosidades de Guillermo Del Toro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2bLiL38YD0olc0aYyEf4gYeYodV.jpg'),
(94006, 6617, 'O Gabinete de Curiosidades de Guillermo Del Toro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/182bbFIeiRSIgU6QyEE8Ua5x38Z.jpg'),
(94007, 6617, 'O Gabinete de Curiosidades de Guillermo Del Toro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eHjG00GZHynWcYWMa8q02jx9zve.jpg'),
(94008, 6617, 'O Gabinete de Curiosidades de Guillermo Del Toro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/686Nn6vzOSovfUvv9vqLwH0VvEF.jpg'),
(94009, 6618, 'Os Winchesters S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ySv04LAFR8NlSmuaiJY7HPKnCy9.jpg'),
(94010, 6618, 'Os Winchesters S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/402Ec9MjpsgdRAttpm8PkwUrlJp.jpg'),
(94011, 6618, 'Os Winchesters S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJQea846zAa4EGUybqYj49aLxJx.jpg'),
(94012, 6618, 'Os Winchesters S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wn3xaavcGy2FVE8jz9qUNFvlEGD.jpg'),
(94013, 6618, 'Os Winchesters S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208839.mp4', 'http://image.tmdb.org/t/p/w1280/3w03ex7yhxUJDPQERpcbMybZsQN.jpg'),
(94014, 6618, 'Os Winchesters S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208840.mp4', 'http://image.tmdb.org/t/p/w1280/8bRi4cmCnMcFP1Hfbpe4vN9T5Kc.jpg'),
(94015, 6618, 'Os Winchesters S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208841.mp4', 'http://image.tmdb.org/t/p/w1280/v65I5VHdkh2HCSPSiOTH6c3BSDE.jpg'),
(94016, 6618, 'Os Winchesters S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208842.mp4', 'http://image.tmdb.org/t/p/w1280/8SMuarvwEfNR9Dl8bKrSMWJSLkV.jpg'),
(94017, 6618, 'Os Winchesters S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208843.mp4', 'http://image.tmdb.org/t/p/w1280/5yvTrEmqI0RwyDOXDDvRy9JFPCx.jpg'),
(94018, 6618, 'Os Winchesters S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208844.mp4', 'http://image.tmdb.org/t/p/w1280/ATi8Vya8yNkNgvKTPf2oOe575N.jpg'),
(94019, 6618, 'Os Winchesters S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208845.mp4', 'http://image.tmdb.org/t/p/w1280/tYMirJYoA0h4tWXU2niWbp0DkpW.jpg'),
(94020, 6618, 'Os Winchesters S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208846.mp4', 'http://image.tmdb.org/t/p/w1280/wmEtwhrU8vsshnIQrvQ7PTqoRcA.jpg'),
(94021, 6618, 'Os Winchesters S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/208847.mp4', 'http://image.tmdb.org/t/p/w1280/c56PbjjYMKSEZsB40p9LqEsyZy3.jpg'),
(94022, 6619, 'Os Winchesters [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ySv04LAFR8NlSmuaiJY7HPKnCy9.jpg'),
(94023, 6619, 'Os Winchesters [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/402Ec9MjpsgdRAttpm8PkwUrlJp.jpg'),
(94024, 6619, 'Os Winchesters [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJQea846zAa4EGUybqYj49aLxJx.jpg'),
(94025, 6619, 'Os Winchesters [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201451.mp4', 'http://image.tmdb.org/t/p/w1280/wn3xaavcGy2FVE8jz9qUNFvlEGD.jpg'),
(94026, 6619, 'Os Winchesters [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201452.mp4', 'http://image.tmdb.org/t/p/w1280/3w03ex7yhxUJDPQERpcbMybZsQN.jpg'),
(94027, 6620, 'Procura-se: O Maior Fugitivo das Américas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2rzULFFgMbNdyoHwqxhQK66Snt3.jpg'),
(94028, 6620, 'Procura-se: O Maior Fugitivo das Américas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9pflaO59MR5B3RIqhZRYiRnhmju.jpg'),
(94029, 6620, 'Procura-se: O Maior Fugitivo das Américas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lnDjRvkehtznLby0j5h5lpxz8rb.jpg'),
(94030, 6621, 'Repatriado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203852.mp4', 'http://timg.bdta.pro/images/2f673b785f55d2eda98534d6300dd701.jpg'),
(94031, 6621, 'Repatriado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203853.mp4', 'http://timg.bdta.pro/images/02fb6dc318ba90ea472b3197a8b97697.jpg'),
(94032, 6621, 'Repatriado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203854.mp4', 'http://timg.bdta.pro/images/7f8b08b900bd2cbafb4f1aff90daa447.jpg'),
(94033, 6621, 'Repatriado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203855.mp4', 'http://timg.bdta.pro/images/a52b3b886c8cd59fd82c2668e769af94.jpg'),
(94034, 6621, 'Repatriado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203856.mp4', 'http://timg.bdta.pro/images/9da2c447d926e43fa43ca11da0908433.jpg'),
(94035, 6621, 'Repatriado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203857.mp4', 'http://timg.bdta.pro/images/651702716d7f2349f0baf4cf55cae618.jpg'),
(94036, 6621, 'Repatriado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203858.mp4', 'http://timg.bdta.pro/images/5c643ace1cb4f06ae0dcfc5f301bad7d.jpg'),
(94037, 6621, 'Repatriado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203859.mp4', 'http://timg.bdta.pro/images/eb4b0cd31cbd9fe2e38f82931ebd2c04.jpg'),
(94038, 6621, 'Repatriado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203860.mp4', 'http://timg.bdta.pro/images/7ec0d02d7d60b875e3e6334fbfd18a61.jpg'),
(94039, 6621, 'Repatriado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203861.mp4', 'http://image.tmdb.org/t/p/w1280/6tWicKjttedj29a4qrNfAnyKvAJ.jpg'),
(94040, 6622, 'República Selvagem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2UwXCBByj6AfUjxXeEB0cXDXs5L.jpg'),
(94041, 6622, 'República Selvagem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ciIwJWgAdCahyCZToXttsHmOyJo.jpg'),
(94042, 6622, 'República Selvagem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8LAJKIbtmjVFlm4QNTGsfwH1Hml.jpg'),
(94043, 6622, 'República Selvagem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bpSo7DqM6AzF7SxjPzRHcJrT07h.jpg'),
(94044, 6622, 'República Selvagem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6DMhiPdWwTBlymJtOKvkgR3uR1G.jpg'),
(94045, 6622, 'República Selvagem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tsVtkPeY80xlctysFBbkhI8f2gs.jpg'),
(94046, 6622, 'República Selvagem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fsRb7hos30zvvc2w5jpa5u5703I.jpg'),
(94047, 6622, 'República Selvagem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bk0XWrHWD8xdJ05ManLdM3ca0X4.jpg'),
(94048, 6623, 'Romantic Killer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mpgIVj5v8DjFstSm8oDJDtAZsSp.jpg'),
(94049, 6623, 'Romantic Killer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l94xkSiGfuxdiA1CuYW7AdTbV7c.jpg'),
(94050, 6623, 'Romantic Killer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/teUJqed1VENciiwhopdgvsaqTUt.jpg'),
(94051, 6623, 'Romantic Killer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gq0j9DlO47ErrPW03nDHszMrysx.jpg'),
(94052, 6623, 'Romantic Killer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wt8nSWCVMIMzmSybm3aH90feD2j.jpg'),
(94053, 6623, 'Romantic Killer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/epbwrjU1v2cC8b4EDpiRqYSl24v.jpg'),
(94054, 6623, 'Romantic Killer S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3hQqZZKrilckiPq5BntHNsr6t0S.jpg'),
(94055, 6623, 'Romantic Killer S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m4WiPT7EkhEpig2pTLT2nvM1hCY.jpg'),
(94056, 6623, 'Romantic Killer S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyuXBhNJOW6RrMsSBEfsBqr5G5t.jpg'),
(94057, 6623, 'Romantic Killer S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/XswLGSvDWrcKVOcIoRpDkfopBs.jpg'),
(94058, 6623, 'Romantic Killer S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3xOPtR4AoMv1Oo3rAyLhOYvQbnR.jpg'),
(94059, 6623, 'Romantic Killer S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1iKcy4fQZiiM4J7rdk32ssEX6UK.jpg'),
(94060, 6624, 'Se Eu Soubesse S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r4RsxyfjWHH9l62fFB891H8fWed.jpg'),
(94061, 6624, 'Se Eu Soubesse S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r4RsxyfjWHH9l62fFB891H8fWed.jpg'),
(94062, 6624, 'Se Eu Soubesse S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r4RsxyfjWHH9l62fFB891H8fWed.jpg'),
(94063, 6624, 'Se Eu Soubesse S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r4RsxyfjWHH9l62fFB891H8fWed.jpg'),
(94064, 6624, 'Se Eu Soubesse S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r4RsxyfjWHH9l62fFB891H8fWed.jpg'),
(94065, 6624, 'Se Eu Soubesse S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r4RsxyfjWHH9l62fFB891H8fWed.jpg'),
(94066, 6624, 'Se Eu Soubesse S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r4RsxyfjWHH9l62fFB891H8fWed.jpg'),
(94067, 6624, 'Se Eu Soubesse S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r4RsxyfjWHH9l62fFB891H8fWed.jpg'),
(94068, 6625, 'Star Wars: Histórias dos Jedi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eml92TQ7fupbbqDBCPXfOAZepT2.jpg'),
(94069, 6625, 'Star Wars: Histórias dos Jedi S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9myhOLBqoNAYGbf7hLg167yjBdt.jpg'),
(94070, 6625, 'Star Wars: Histórias dos Jedi S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ykFWg8IUdOjzOLzKd0EQTgC1DZm.jpg'),
(94071, 6625, 'Star Wars: Histórias dos Jedi S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2I2ct24R5FDTLjjFmazkdosaBiC.jpg'),
(94072, 6625, 'Star Wars: Histórias dos Jedi S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s6A4oL9ep86fDftDgRh29xoNSVR.jpg'),
(94073, 6625, 'Star Wars: Histórias dos Jedi S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f8YLMAC7qsMJCGkitFPAfCVAoZF.jpg'),
(94074, 6626, 'Terra Tempestuosa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dNzoECyBQKgBT6ftcVqEVzjOQW3.jpg'),
(94075, 6626, 'Terra Tempestuosa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUPlw4iSwLEFTZIRXPgwWWVIsZq.jpg'),
(94076, 6626, 'Terra Tempestuosa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xFhjAnPyEbLiYd2VyauzFYhBmp0.jpg'),
(94077, 6626, 'Terra Tempestuosa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/evdxWOA2IiKfFE2gtggZqtTSlKW.jpg'),
(94078, 6627, 'Teal Swan: A Influencer Espiritual S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pefkHNJ2kNCLW3c2DXqmN4tA1aE.jpg'),
(94079, 6627, 'Teal Swan: A Influencer Espiritual S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z2aw8WQJNlGy9Xy0NizhUxMQvWB.jpg'),
(94080, 6627, 'Teal Swan: A Influencer Espiritual S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t6EpCkfwAmnwYMWpiwMB3956nYu.jpg'),
(94081, 6627, 'Teal Swan: A Influencer Espiritual S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yR0FRhvqvRK99OWXvoWTVVRpjnz.jpg'),
(94082, 6628, 'A Batalha das Pizzas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rmsFHzCxYFX2Ac89NqfpFyOB9f2.jpg'),
(94083, 6628, 'A Batalha das Pizzas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJh8h1UujOATIogx8zYQCXprAUx.jpg'),
(94084, 6628, 'A Batalha das Pizzas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ju0liulXlufy5TaRdlsOBeraKVA.jpg'),
(94085, 6628, 'A Batalha das Pizzas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bYryQ5i8GRkbxFZe9mE1E2QaOF0.jpg'),
(94086, 6628, 'A Batalha das Pizzas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y7CVgrem2zTYgRo3uElgSAaQmaM.jpg'),
(94087, 6628, 'A Batalha das Pizzas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bs6rMMYUJPcxo8Rx8Xs2tF2ozfA.jpg'),
(94088, 6628, 'A Batalha das Pizzas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fHG9sOYObM6lP6IR4A9fle23O2s.jpg'),
(94089, 6628, 'A Batalha das Pizzas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bsb2zkP52RSzaML7btqamiXx4AN.jpg'),
(94090, 6628, 'A Batalha das Pizzas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/76dUb6EHz5zNYJvAc1NW0BUDq7i.jpg'),
(94091, 6628, 'A Batalha das Pizzas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7sMGbiV5dloKfzIGr548dou9Kmm.jpg'),
(94092, 6629, 'A Primeira Arte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tSYcytTsdd8uRxJMtZmLh79VXsR.jpg'),
(94093, 6629, 'A Primeira Arte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bwBxW19Fg7kChPJyNMNKSkqEFfB.jpg'),
(94094, 6629, 'A Primeira Arte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUMDbcdOuNwl6MuCqvSkoWeGwMm.jpg'),
(94095, 6630, 'A Queda Argentina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yD2xIeSmzuri1BllN8iQ0dtnGUM.jpg'),
(94096, 6630, 'A Queda Argentina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zEdleDpuabrhoeMsRZfVyXQWL1Z.jpg'),
(94097, 6630, 'A Queda Argentina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/snGue0mGq9WoLYni6UXwXuNegPh.jpg'),
(94098, 6631, 'Star Wars: Andor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8g951txsYhXLg8Rr18fBm2q0fBA.jpg'),
(94099, 6631, 'Star Wars: Andor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/whihcfB2dZ0PEZC1bzux56B09pK.jpg'),
(94100, 6631, 'Star Wars: Andor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9M5mXdX8kfsopbuc9X6aBbyKNmw.jpg'),
(94101, 6631, 'Star Wars: Andor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mTjpxQW2xekhOkTbihvtjQ9vL1i.jpg'),
(94102, 6631, 'Star Wars: Andor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9XHSNgFHDybU94ql9NuHNgOqNYe.jpg'),
(94103, 6631, 'Star Wars: Andor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hWqnfYdPHtYlwRAzvcCgPFQiWR0.jpg'),
(94104, 6631, 'Star Wars: Andor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dxeAAAOIAIRrck62CksEmgQOXiS.jpg'),
(94105, 6631, 'Star Wars: Andor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mGQ9hkq07bOvw8wEY4Blrd0KzVU.jpg'),
(94106, 6631, 'Star Wars: Andor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7F5jhvS1XC7GgKRS9gWYMclh92H.jpg'),
(94107, 6631, 'Star Wars: Andor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201140.mp4', 'http://image.tmdb.org/t/p/w1280/rfClRbCXoXqF9eG3KlMpcFzkllJ.jpg'),
(94108, 6631, 'Star Wars: Andor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7dfaQ4qkByhVWrHE2DE4H5Tmvtt.jpg'),
(94109, 6631, 'Star Wars: Andor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1gRM3FIZFYttiXFyE476JzxYNU.jpg'),
(94110, 6632, 'Star Wars: Andor S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/778595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/59SVNwLfoMnZPPB6ukW6dlPxAdI.jpg'),
(94111, 6632, 'Star Wars: Andor S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/778596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/59SVNwLfoMnZPPB6ukW6dlPxAdI.jpg'),
(94112, 6632, 'Star Wars: Andor S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/778597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/59SVNwLfoMnZPPB6ukW6dlPxAdI.jpg'),
(94113, 6632, 'Star Wars: Andor S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/786508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/59SVNwLfoMnZPPB6ukW6dlPxAdI.jpg'),
(94114, 6632, 'Star Wars: Andor S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/786509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/59SVNwLfoMnZPPB6ukW6dlPxAdI.jpg'),
(94115, 6632, 'Star Wars: Andor S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/786510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/59SVNwLfoMnZPPB6ukW6dlPxAdI.jpg'),
(94116, 6632, 'Star Wars: Andor S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/789238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/59SVNwLfoMnZPPB6ukW6dlPxAdI.jpg'),
(94117, 6632, 'Star Wars: Andor S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/789239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/59SVNwLfoMnZPPB6ukW6dlPxAdI.jpg'),
(94118, 6632, 'Star Wars: Andor S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/789240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/59SVNwLfoMnZPPB6ukW6dlPxAdI.jpg'),
(94119, 6632, 'Star Wars: Andor S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/801970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/59SVNwLfoMnZPPB6ukW6dlPxAdI.jpg'),
(94120, 6632, 'Star Wars: Andor S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/801971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/59SVNwLfoMnZPPB6ukW6dlPxAdI.jpg'),
(94121, 6632, 'Star Wars: Andor S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/801972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/59SVNwLfoMnZPPB6ukW6dlPxAdI.jpg'),
(94122, 6633, 'Big Mouth: De Vigarista a Vingador S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5niBVqToGQfJnyrocEFCVnzZNXh.jpg'),
(94123, 6633, 'Big Mouth: De Vigarista a Vingador S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rQbLNhtFdbckse3hRIrF3lEk7WD.jpg'),
(94124, 6633, 'Big Mouth: De Vigarista a Vingador S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ltDgoW9awWqsZEiW3Q83Y4cgJvo.jpg'),
(94125, 6633, 'Big Mouth: De Vigarista a Vingador S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8UUpJiWqbtVlqdcFJT8hQpqN0gn.jpg'),
(94126, 6633, 'Big Mouth: De Vigarista a Vingador S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sODSsR0SONrU5UvL9soG3Ndlbxh.jpg'),
(94127, 6633, 'Big Mouth: De Vigarista a Vingador S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9PYW4leA5yj4i2KGT0b1PxT4jka.jpg'),
(94128, 6633, 'Big Mouth: De Vigarista a Vingador S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0yF4kbZKP1IrNcVohkSMlLlxEA.jpg'),
(94129, 6633, 'Big Mouth: De Vigarista a Vingador S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vy9dOWgLEOE4bGf4OFUh9LlYe0e.jpg'),
(94130, 6633, 'Big Mouth: De Vigarista a Vingador S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kOsFVAob22hhHCKMLn5Qs7HjjjW.jpg'),
(94131, 6633, 'Big Mouth: De Vigarista a Vingador S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q6abaakdqOPcccYu5zkinwLxeGc.jpg'),
(94132, 6633, 'Big Mouth: De Vigarista a Vingador S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fnPd8Ksx4nv4qM8DCcgLBME9cCb.jpg'),
(94133, 6633, 'Big Mouth: De Vigarista a Vingador S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vxYffZzZ3KsVkL8QIE9W4wwQS09.jpg'),
(94134, 6633, 'Big Mouth: De Vigarista a Vingador S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bjnM7gGVZpyyuopz106U7tvkGjy.jpg'),
(94135, 6633, 'Big Mouth: De Vigarista a Vingador S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/217493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mYehDX9rcRbWP0VlIpx2Pk7LCBs.jpg'),
(94136, 6633, 'Big Mouth: De Vigarista a Vingador S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/217494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Z4JoWTBfSy2pO8whozCsBOwZlX.jpg'),
(94137, 6633, 'Big Mouth: De Vigarista a Vingador S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/217495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAlPVaCmrC22KRUObtXgtTpaV71.jpg'),
(94138, 6634, 'Blockbuster S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4i3wHaSI4GQUUYKdMgPDIaTKEBh.jpg'),
(94139, 6634, 'Blockbuster S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pGquxzXAXc6JTlJivSw7ejDOKSb.jpg'),
(94140, 6634, 'Blockbuster S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7jDqYpKxaofXN2FY5IcgdzPVTiu.jpg'),
(94141, 6634, 'Blockbuster S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jyTQCWgKohDsNMR963xSBWivFEs.jpg'),
(94142, 6634, 'Blockbuster S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3KL5WBreXJjQNB9POZPJLdUmxra.jpg'),
(94143, 6634, 'Blockbuster S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tUJkWmcw7PUrBSC5dg3JMl2HS1y.jpg'),
(94144, 6634, 'Blockbuster S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/piRgNIXC2PRh2HYS5WT6wkCBZ7S.jpg'),
(94145, 6634, 'Blockbuster S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vH0nLE72eVkNestDT50vBRdYqSS.jpg'),
(94146, 6634, 'Blockbuster S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v9EPNBcXbJ6R8ezGPQSWTsCm7RJ.jpg'),
(94147, 6634, 'Blockbuster S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vdqRCVCR7Zy0d9S8GBnWCP5FNUm.jpg'),
(94148, 6635, 'Bosé S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oAwcDzrL4nsQpulvkI2YM0Fz44K.jpg'),
(94149, 6635, 'Bosé S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zCcxMEvg6JD4zOEaPEX7MlbV7sF.jpg'),
(94150, 6635, 'Bosé S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200676.mp4', 'http://image.tmdb.org/t/p/w1280/qTU1d787T6UEKu1xeetbb0XaFFe.jpg'),
(94151, 6635, 'Bosé S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bPn2aW1A4m7FfIAEKJLEqNSxGI7.jpg'),
(94152, 6635, 'Bosé S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bV4zefQbPCeh1cwI7h0WXnbRJ1t.jpg'),
(94153, 6635, 'Bosé S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200679.mp4', 'http://image.tmdb.org/t/p/w1280/36jWEC1Y8EuKBj7ygG1LBTcHfH2.jpg'),
(94154, 6636, 'Crazy Love S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iMV3tMnKWZVbWjk29QvDLsk0zQ9.jpg'),
(94155, 6636, 'Crazy Love S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nf5Rs79CwDr4AcZvw9TjATWwLHi.jpg'),
(94156, 6636, 'Crazy Love S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/516717.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xQzpESxXkPky0OoArd8Y6FtNIOn.jpg'),
(94157, 6636, 'Crazy Love S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/516718.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sz7oaeZyjv56X9DxgKYPUyMxoGX.jpg'),
(94158, 6636, 'Crazy Love S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/632665.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/seoWpndwtummpRu87uFyGRzLyMg.jpg'),
(94159, 6636, 'Crazy Love S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/516720.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bVyDJCSFY4zANsBnNWC6rTc0XDx.jpg'),
(94160, 6636, 'Crazy Love S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/516721.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/89ex7yBDiEg9NkotQ1mgbLd8I1Q.jpg'),
(94161, 6636, 'Crazy Love S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/516722.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r6OnEz1xnR6EByrrpreUSh9C7Qt.jpg'),
(94162, 6636, 'Crazy Love S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/516723.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ls0MtTxs001d3hmIf7RsvBPzK7x.jpg'),
(94163, 6636, 'Crazy Love S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/516725.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6j3t9sV0RvJLuvg7wwqkutL3ZU6.jpg'),
(94164, 6636, 'Crazy Love S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/516726.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sizeVmYXIpfBioErUXA6zYYwjRW.jpg'),
(94165, 6636, 'Crazy Love S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/516727.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bFfWkLKHLJljfqd57yuFR0aiO53.jpg'),
(94166, 6636, 'Crazy Love S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/516728.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7APcLBCK060ZJ6dhvHLiCWkEVLX.jpg'),
(94167, 6636, 'Crazy Love S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/516729.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8RQi4NlVM9aN54NjEuPX7XH2uOV.jpg'),
(94168, 6636, 'Crazy Love S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/516730.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yU7w0Q5tpl56PKtjHJO8xeCOMcT.jpg'),
(94169, 6637, 'Deceit S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4EFGuw2Z7Hu68S8IobHwursfkuj.jpg'),
(94170, 6637, 'Deceit S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZT5Cwj2oVCSvR0w0O5mL9Px1Nj.jpg'),
(94171, 6637, 'Deceit S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199194.mp4', 'http://timg.bdta.pro/images/adb8e3f45b9b2c910f96d78b93fd58f2.jpg'),
(94172, 6637, 'Deceit S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199195.mp4', 'http://timg.bdta.pro/images/33e2e2caff44d0cdfa3829a1e98da140.jpg'),
(94173, 6638, 'Deepa e Anoop S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ZkILVyhoUetnwo54M0GhMlrxi9.jpg'),
(94174, 6638, 'Deepa e Anoop S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ZkILVyhoUetnwo54M0GhMlrxi9.jpg'),
(94175, 6638, 'Deepa e Anoop S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tO5oPlxPjEAPKGrItIreKpt1jfD.jpg'),
(94176, 6638, 'Deepa e Anoop S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tO5oPlxPjEAPKGrItIreKpt1jfD.jpg'),
(94177, 6638, 'Deepa e Anoop S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/VJfqPONiniLsIG2bSANK6Ll41p.jpg'),
(94178, 6638, 'Deepa e Anoop S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/VJfqPONiniLsIG2bSANK6Ll41p.jpg'),
(94179, 6638, 'Deepa e Anoop S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hzXTrmlJgqfjoEEG1X02Dn0wp4D.jpg'),
(94180, 6638, 'Deepa e Anoop S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hzXTrmlJgqfjoEEG1X02Dn0wp4D.jpg'),
(94181, 6638, 'Deepa e Anoop S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a4p0fweS2O6N2ggsmtP7A9ZhVLE.jpg'),
(94182, 6638, 'Deepa e Anoop S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a4p0fweS2O6N2ggsmtP7A9ZhVLE.jpg'),
(94183, 6639, 'Deepa e Anoop S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tO8KI59jKM38PC0e2oDmCVnFykm.jpg'),
(94184, 6639, 'Deepa e Anoop S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tO8KI59jKM38PC0e2oDmCVnFykm.jpg'),
(94185, 6639, 'Deepa e Anoop S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tO8KI59jKM38PC0e2oDmCVnFykm.jpg'),
(94186, 6639, 'Deepa e Anoop S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tO8KI59jKM38PC0e2oDmCVnFykm.jpg'),
(94187, 6639, 'Deepa e Anoop S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tO8KI59jKM38PC0e2oDmCVnFykm.jpg'),
(94188, 6639, 'Deepa e Anoop S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tO8KI59jKM38PC0e2oDmCVnFykm.jpg'),
(94189, 6639, 'Deepa e Anoop S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tO8KI59jKM38PC0e2oDmCVnFykm.jpg'),
(94190, 6639, 'Deepa e Anoop S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tO8KI59jKM38PC0e2oDmCVnFykm.jpg'),
(94191, 6640, 'Eu Love Arlo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hy7g3coKhQVEoWKBFUAnYfnKVey.jpg'),
(94192, 6640, 'Eu Love Arlo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCJMONkBdf6FJonvPkX1nc9iZP5.jpg'),
(94193, 6640, 'Eu Love Arlo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y8F12kVI8kBulFoueMhzrJwOgOZ.jpg'),
(94194, 6640, 'Eu Love Arlo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ssWm2cs9VeTQirR7NFvZ0r6U10x.jpg'),
(94195, 6640, 'Eu Love Arlo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wlX4VZ9qwHspoCXcBjATLP6y1gx.jpg'),
(94196, 6640, 'Eu Love Arlo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i5vFue1lm1bH6nRsUrTewml5OUa.jpg'),
(94197, 6640, 'Eu Love Arlo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3miYXnSztCldcO9tox6POeddLMS.jpg'),
(94198, 6640, 'Eu Love Arlo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/afvWuSd8v7rOIHzHVGAR3Mj3FR9.jpg'),
(94199, 6640, 'Eu Love Arlo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w2pZ0vvwPIvE2Jk2ak478VRWqo5.jpg'),
(94200, 6640, 'Eu Love Arlo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dlWXs7sMbhm8ZIUezNfy5dMawYl.jpg'),
(94201, 6640, 'Eu Love Arlo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/idBL0ncY0fjNzTO6Wl6hb7ve1qD.jpg'),
(94202, 6640, 'Eu Love Arlo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3aTIUa3Jy23Z2ESFXlj7C2ODnHl.jpg'),
(94203, 6640, 'Eu Love Arlo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/199185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1wnIRAXQ5SW35JzZ673SGsDVY8P.jpg'),
(94204, 6640, 'Eu Love Arlo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/199186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lijOc6uD7vdtMURslk4eSewFcp9.jpg'),
(94205, 6640, 'Eu Love Arlo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/199187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/akiVoVZM8nkCFUKZE4KJkGR4qBh.jpg'),
(94206, 6640, 'Eu Love Arlo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/199188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xxZi7W9kogJHyLjN3SS81RAqMQK.jpg'),
(94207, 6640, 'Eu Love Arlo S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/199189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9YQsf8u2ytip4nUJmgjDmLHo0Ju.jpg'),
(94208, 6640, 'Eu Love Arlo S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/199190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zrfJIwsRISp3FAw6vFmC525GVLw.jpg'),
(94209, 6640, 'Eu Love Arlo S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/199191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gjgroOrDbs5bsLbXLXfDKj4QRNF.jpg'),
(94210, 6641, 'Flordelis: Questiona ou Adora S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i2raBDzIvDBu8UdD5otbzwpraVB.jpg'),
(94211, 6641, 'Flordelis: Questiona ou Adora S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rYxtHKyac0YceB9RGUxRpaVaQI8.jpg'),
(94212, 6641, 'Flordelis: Questiona ou Adora S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k5q9lfDJ8FxbH2Ji7rROru54aH3.jpg'),
(94213, 6641, 'Flordelis: Questiona ou Adora S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iieLh67OJdOL6kRw99Xa2Gp5BeE.jpg'),
(94214, 6641, 'Flordelis: Questiona ou Adora S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5iO3Bf9Nc1L4jeyVNA4PTiFmZIr.jpg'),
(94215, 6641, 'Flordelis: Questiona ou Adora S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i0smKjNNaQKyPs6huULFDRLQoqd.jpg'),
(94216, 6641, 'Flordelis: Questiona ou Adora S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gbJxZYqQfQb4r5k1fEk7tCIRR7q.jpg'),
(94217, 6642, 'Gol Contra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hl0C8p29Kr6pca17BHbDnFAsAcG.jpg'),
(94218, 6642, 'Gol Contra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hl0C8p29Kr6pca17BHbDnFAsAcG.jpg'),
(94219, 6642, 'Gol Contra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hl0C8p29Kr6pca17BHbDnFAsAcG.jpg'),
(94220, 6642, 'Gol Contra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hl0C8p29Kr6pca17BHbDnFAsAcG.jpg'),
(94221, 6642, 'Gol Contra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hl0C8p29Kr6pca17BHbDnFAsAcG.jpg'),
(94222, 6642, 'Gol Contra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hl0C8p29Kr6pca17BHbDnFAsAcG.jpg'),
(94223, 6643, 'Inside Man S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nuNPmLgxfs71SQPen08g3suBxdu.jpg'),
(94224, 6643, 'Inside Man S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4MBqIv56XBT0oVvkxI2B0iwnIzy.jpg'),
(94225, 6643, 'Inside Man S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cMnuJL9UY22zb97ERvcmXdCVpQD.jpg'),
(94226, 6643, 'Inside Man S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/raVbhLScPKqH3seFu4H1RkIZ46y.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(94227, 6644, 'Kakkou no Iinazuke S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h7FaWeZXEPcPL3p0hPh1EjBoK7x.jpg'),
(94228, 6644, 'Kakkou no Iinazuke S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5W6MXIAjt3UasYgeOqPkffLWNBI.jpg'),
(94229, 6644, 'Kakkou no Iinazuke S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aYEn3AuPqesUbOfeVS4ck4lBInl.jpg'),
(94230, 6644, 'Kakkou no Iinazuke S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pLFfXqHNlNx9sEyumQQKTKxKk4G.jpg'),
(94231, 6644, 'Kakkou no Iinazuke S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v1LzLLNi4N2PBvwQNWv1v2dEvSA.jpg'),
(94232, 6644, 'Kakkou no Iinazuke S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vCV6FOcm4bSIH0FWOXAVZlzffEV.jpg'),
(94233, 6644, 'Kakkou no Iinazuke S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJTBvyKDm1uM4cPt1CyrVd1eKGl.jpg'),
(94234, 6644, 'Kakkou no Iinazuke S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mQjxk0XU8ufaml7OV5jzdg5nC1B.jpg'),
(94235, 6644, 'Kakkou no Iinazuke S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3YTPKzXzd1yelFqTa9kdc1AQS1q.jpg'),
(94236, 6644, 'Kakkou no Iinazuke S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wjP1flkbEidbYFPksGY4HQgRAmM.jpg'),
(94237, 6644, 'Kakkou no Iinazuke S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sthqoUHUQWU6HL3cJzQBWj2w5hf.jpg'),
(94238, 6644, 'Kakkou no Iinazuke S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/olZM8TOwK3x20HAt6mTsoRQhLCq.jpg'),
(94239, 6644, 'Kakkou no Iinazuke S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/199151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eKxQa9vVmsEbu046AVRhH1ouZN.jpg'),
(94240, 6644, 'Kakkou no Iinazuke S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/199152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l20DhzGPxZcQkNPyjwRoRELmuSC.jpg'),
(94241, 6644, 'Kakkou no Iinazuke S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/199153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xVx5kydMlG6l679k2HZE7Z9eSDN.jpg'),
(94242, 6644, 'Kakkou no Iinazuke S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/199154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mqViJ0z95lDDtL8rqGJD0hh8qk6.jpg'),
(94243, 6644, 'Kakkou no Iinazuke S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/199155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dE8CkYCBfEX1HpX3ZvL9F8oBClK.jpg'),
(94244, 6644, 'Kakkou no Iinazuke S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/199156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aGzQWRadXDPugxw4QugVWIktSc3.jpg'),
(94245, 6644, 'Kakkou no Iinazuke S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/199157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5pP3Dr7o1skGE3FgaEptYFBZyNv.jpg'),
(94246, 6644, 'Kakkou no Iinazuke S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/199158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6UcnLyUUlRpOr6hhbUiX9fUnl9.jpg'),
(94247, 6644, 'Kakkou no Iinazuke S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/199159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nndfblHJoNBxmSh2t77qVzfDQ2O.jpg'),
(94248, 6644, 'Kakkou no Iinazuke S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/199160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eJI90hGwf98ho9H1I60xSFVhnbq.jpg'),
(94249, 6644, 'Kakkou no Iinazuke S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/199161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6RtwA8Orrxltrg8FysIT0H1Ek6v.jpg'),
(94250, 6644, 'Kakkou no Iinazuke S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/199162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zKHTbirGRzlBqxUX6HfMtvfZ4QH.jpg'),
(94251, 6645, 'Ligações Perigosas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pF4sIppXzUm4vH1Q0VCIAsCfXp8.jpg'),
(94252, 6645, 'Ligações Perigosas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202520.mp4', 'http://image.tmdb.org/t/p/w1280/bAj9BDddOg3SdAq6xqurgla1imG.jpg'),
(94253, 6645, 'Ligações Perigosas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qPKkpT5L5ZFx3nHQwJDE5vO2lvy.jpg'),
(94254, 6645, 'Ligações Perigosas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jO2pn0m2B76YrESyOEoQKLuF1BO.jpg'),
(94255, 6645, 'Ligações Perigosas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202523.mp4', 'http://image.tmdb.org/t/p/w1280/sA1TvKkWXyntcX1yjdQeo25wHVY.jpg'),
(94256, 6645, 'Ligações Perigosas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202524.mp4', 'http://image.tmdb.org/t/p/w1280/hhX7B6ah5O1VuRXNKosi9GDcorG.jpg'),
(94257, 6645, 'Ligações Perigosas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7YrDZBwtTaNsSiDwRr1stVMIfN3.jpg'),
(94258, 6645, 'Ligações Perigosas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQayYSrimMHYm3rKRnD3KdFoyS.jpg'),
(94259, 6646, 'Love Me S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sONBe0eBnj5n9v63w5UBEXxKxKm.jpg'),
(94260, 6646, 'Love Me S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/awC1q2t26wbi93zrJiStKFIwpZV.jpg'),
(94261, 6646, 'Love Me S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j6eCrUUZKd6YhqPL56p1kT8Te5p.jpg'),
(94262, 6646, 'Love Me S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmUL4jJRDf9RF60CPuyzaX1Jfsa.jpg'),
(94263, 6646, 'Love Me S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qAtCpN6n2jGGbtQOjJvsucbfcru.jpg'),
(94264, 6646, 'Love Me S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rOPHfMYxmtfhdQz5prNlIgBAJZY.jpg'),
(94265, 6647, 'Maior a Luta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQyd67oF9k0z80gYMwEKWT4y2au.jpg'),
(94266, 6647, 'Maior a Luta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQyd67oF9k0z80gYMwEKWT4y2au.jpg'),
(94267, 6647, 'Maior a Luta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQyd67oF9k0z80gYMwEKWT4y2au.jpg'),
(94268, 6647, 'Maior a Luta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQyd67oF9k0z80gYMwEKWT4y2au.jpg'),
(94269, 6648, 'Marvel Studios - Avante S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jLtlXFMU3n8Bdjy6s04zVcz4eV7.jpg'),
(94270, 6648, 'Marvel Studios - Avante S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z6uGCHpNnCH2aGVTlYmASvuHyq4.jpg'),
(94271, 6648, 'Marvel Studios - Avante S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r9tI9kjlKEGXbUO6vNK7A01sqGU.jpg'),
(94272, 6648, 'Marvel Studios - Avante S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/onMqQFo7kNpKsx3ItxH4DzO20vX.jpg'),
(94273, 6648, 'Marvel Studios - Avante S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a4M3Fmm2TDtUd9ylNRrMS1vSt7N.jpg'),
(94274, 6648, 'Marvel Studios - Avante S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b3MXuNnZIbf4oRsoFgJoAMsKf1J.jpg'),
(94275, 6648, 'Marvel Studios - Avante S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5vka0VyfgB7xNUAdQ3dOmwBeBdQ.jpg'),
(94276, 6648, 'Marvel Studios - Avante S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5vka0VyfgB7xNUAdQ3dOmwBeBdQ.jpg'),
(94277, 6648, 'Marvel Studios - Avante S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5vka0VyfgB7xNUAdQ3dOmwBeBdQ.jpg'),
(94278, 6648, 'Marvel Studios - Avante S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5vka0VyfgB7xNUAdQ3dOmwBeBdQ.jpg'),
(94279, 6648, 'Marvel Studios - Avante S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5vka0VyfgB7xNUAdQ3dOmwBeBdQ.jpg'),
(94280, 6648, 'Marvel Studios - Avante S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5vka0VyfgB7xNUAdQ3dOmwBeBdQ.jpg'),
(94281, 6648, 'Marvel Studios - Avante S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/208538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5vka0VyfgB7xNUAdQ3dOmwBeBdQ.jpg'),
(94282, 6648, 'Marvel Studios - Avante S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/208539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5vka0VyfgB7xNUAdQ3dOmwBeBdQ.jpg'),
(94283, 6649, 'Me Conte Mentiras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ugRy0VreoZkvkZ6EhJttaLaNJkR.jpg'),
(94284, 6649, 'Me Conte Mentiras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lFDCM9dwujNiIsPrpYyh1y4c3N3.jpg'),
(94285, 6649, 'Me Conte Mentiras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4UShJjwokQnV1u7rRpd2BGG3EfZ.jpg'),
(94286, 6649, 'Me Conte Mentiras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pq1sofKRPJsw7J4ondPyIwH3mU.jpg'),
(94287, 6649, 'Me Conte Mentiras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c1XoZoQq9IrenpkX9zgUSRvMlZG.jpg'),
(94288, 6649, 'Me Conte Mentiras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fEYnFd7WQTJ1ovUIPysReoSd6h2.jpg'),
(94289, 6649, 'Me Conte Mentiras S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7UaNYmTNYBxSga75gij7QGhrgIG.jpg'),
(94290, 6649, 'Me Conte Mentiras S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Q3FX7Ye4E6zE1yELGKMUvZs0nS.jpg'),
(94291, 6649, 'Me Conte Mentiras S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ZwvbqZb5XGpfogy2r0TuPH2ZdD.jpg'),
(94292, 6649, 'Me Conte Mentiras S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/21N3QojigtDSn1TtIxqlcibLzqK.jpg'),
(94293, 6650, 'Me Conte Mentiras S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/470009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ifyPotB2JuLlrhMEliZPsTh0IaM.jpg'),
(94294, 6650, 'Me Conte Mentiras S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/470010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ifyPotB2JuLlrhMEliZPsTh0IaM.jpg'),
(94295, 6650, 'Me Conte Mentiras S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/470011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ifyPotB2JuLlrhMEliZPsTh0IaM.jpg'),
(94296, 6650, 'Me Conte Mentiras S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/464100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ifyPotB2JuLlrhMEliZPsTh0IaM.jpg'),
(94297, 6650, 'Me Conte Mentiras S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/470013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ifyPotB2JuLlrhMEliZPsTh0IaM.jpg'),
(94298, 6650, 'Me Conte Mentiras S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/470014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ifyPotB2JuLlrhMEliZPsTh0IaM.jpg'),
(94299, 6650, 'Me Conte Mentiras S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/477549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ifyPotB2JuLlrhMEliZPsTh0IaM.jpg'),
(94300, 6650, 'Me Conte Mentiras S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/482704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ifyPotB2JuLlrhMEliZPsTh0IaM.jpg'),
(94301, 6577, 'Nosso Segredo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199115.mp4', 'http://timg.bdta.pro/images/c514624d380a29aee4e399e5cb0c41d2.jpg'),
(94302, 6577, 'Nosso Segredo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199116.mp4', 'http://timg.bdta.pro/images/06a0e6a2077d9873a72fa1ed4c5e4305.jpg'),
(94303, 6577, 'Nosso Segredo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2CsxzAuTgUrxL1v05pQORgSncli.jpg'),
(94304, 6577, 'Nosso Segredo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vmwbJ8GoGECTF858c2zNyZ4eBvZ.jpg'),
(94305, 6651, 'O Beijo do Destino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJZJZ90WvQ2i6nqfqn4hvnQJyFO.jpg'),
(94306, 6651, 'O Beijo do Destino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/efg6TqhP8V6SVmO7y0YEk2HzUjO.jpg'),
(94307, 6651, 'O Beijo do Destino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eOyQfD4MB9rTn7laygu1kAk9g7W.jpg'),
(94308, 6651, 'O Beijo do Destino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7SsXnubMCTqTaLFIizZMxopk1MQ.jpg'),
(94309, 6651, 'O Beijo do Destino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uCxjCOTnpiBg4IzJqnkh9Gcs2TE.jpg'),
(94310, 6651, 'O Beijo do Destino S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AdaW7sLyfQGzALaOcjULTwlDsdS.jpg'),
(94311, 6651, 'O Beijo do Destino S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZ5y54b0QzHGQYix52fxkXFwlxA.jpg'),
(94312, 6651, 'O Beijo do Destino S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kEY2oGnO1YwvbzqSjEP2WbS0z0u.jpg'),
(94313, 6651, 'O Beijo do Destino S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u2huUZJ0ILuAPoWI8DIJSdX67N4.jpg'),
(94314, 6651, 'O Beijo do Destino S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nn8LASYheNxcPsKYK7Ez0UU6QFv.jpg'),
(94315, 6651, 'O Beijo do Destino S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJMGsxvjVvTCs5zpNIWeCjIO6gn.jpg'),
(94316, 6651, 'O Beijo do Destino S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/VN01puCKAXK6lkou3GBLp3q8ng.jpg'),
(94317, 6652, 'O Fim do Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A1jvvku6ki1ShUqBc90HpNSchMy.jpg'),
(94318, 6652, 'O Fim do Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xqCy1tTkgiJhYoTG30p1eXNf8ic.jpg'),
(94319, 6652, 'O Fim do Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/BXwkhleybBcHL8eSPKKgam2af9.jpg'),
(94320, 6652, 'O Fim do Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5lEYMuzoljYmj2kSMnqbBRD5Was.jpg'),
(94321, 6652, 'O Fim do Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x6ay2E72iWHwP6UBg79QwD5wjGz.jpg'),
(94322, 6652, 'O Fim do Amor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/edQN10U6aK2p1fxfODodA12TZ7M.jpg'),
(94323, 6652, 'O Fim do Amor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z0sTZvZrOvpi1qMXVV5I288kX7M.jpg'),
(94324, 6652, 'O Fim do Amor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oomcIVP3JHGVuCt78IBf9c6O485.jpg'),
(94325, 6652, 'O Fim do Amor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hsLjTlpDEBhnE7BWgd1hzqq90hh.jpg'),
(94326, 6652, 'O Fim do Amor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUr6XVvdV3GiLmsxCavgzxpa40M.jpg'),
(94327, 6653, 'O Segredo da Família Greco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mLMDO774GLr5xxxy3hU41P3dOKL.jpg'),
(94328, 6653, 'O Segredo da Família Greco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xmlMkORT4tUKmSqL34KEqSbM4MU.jpg'),
(94329, 6653, 'O Segredo da Família Greco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nlbAFDOn2dKALbp9WzOVNyEx3w.jpg'),
(94330, 6653, 'O Segredo da Família Greco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ndcH0iLO9YSfin2hRiUx0LJcl85.jpg'),
(94331, 6653, 'O Segredo da Família Greco S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zade4QQZ5ly6CrsWc658HNmHTSt.jpg'),
(94332, 6653, 'O Segredo da Família Greco S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Kb2N03q3fvjdrIIkbpGydW0cvV.jpg'),
(94333, 6653, 'O Segredo da Família Greco S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wf5BruziTvDotLBaXKhTlXvTDRT.jpg'),
(94334, 6653, 'O Segredo da Família Greco S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/avmVCLJ7p1eVBEwAUZ775DV3IHW.jpg'),
(94335, 6653, 'O Segredo da Família Greco S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rRn3fs5s6TsN7g8ehPYTUF67p7u.jpg'),
(94336, 6654, 'Os Corretores de Beverly Hills S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iVxu1g6VebxVB1akD3rQdDi1UJd.jpg'),
(94337, 6654, 'Os Corretores de Beverly Hills S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uJKpXoEHenqAspwe9RQMaMFzt4z.jpg'),
(94338, 6654, 'Os Corretores de Beverly Hills S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fHy6JWt6nPvitZPQkcwpyLHaYTs.jpg'),
(94339, 6654, 'Os Corretores de Beverly Hills S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kWMjZLkcnESoP5RbZNAi5iM7i4F.jpg'),
(94340, 6654, 'Os Corretores de Beverly Hills S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ysWgVzxfJpttwT6nfpR5OSGiDZ.jpg'),
(94341, 6654, 'Os Corretores de Beverly Hills S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bNslDAtMHFa5m3M85kHOE1rRDpJ.jpg'),
(94342, 6654, 'Os Corretores de Beverly Hills S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tldBqgJPyDgkjbdlbzIQuNhvVtq.jpg'),
(94343, 6654, 'Os Corretores de Beverly Hills S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bt1Esfu0rTSqVtqJA3ZVYouHM2v.jpg'),
(94344, 6655, 'Reboot S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jn2Jrd8cVPwNtcQ3zG2pJxieO7S.jpg'),
(94345, 6655, 'Reboot S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k53iScQuo8msMHXg5UJVFLTlAnu.jpg'),
(94346, 6655, 'Reboot S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1MvftdMUEEePauALEN9NYc3BY29.jpg'),
(94347, 6655, 'Reboot S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3QoJs3BlAbBdmVHvqp5aTdu3v0p.jpg'),
(94348, 6655, 'Reboot S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hRQx7DBSdxDKEd02bFmsfVnYsCH.jpg'),
(94349, 6655, 'Reboot S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5jUcI9wvETtl4jrAjBs3QesmOL9.jpg'),
(94350, 6655, 'Reboot S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gtONUT6fbk38E9PWtWNP2TLGQBT.jpg'),
(94351, 6655, 'Reboot S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wHqioWMijHijbeUHfvDXnlWByEv.jpg'),
(94352, 6656, 'Rumo ao Desconhecido S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ENcpBsu6OKk0W3Hb4t4YNaLaKi.jpg'),
(94353, 6656, 'Rumo ao Desconhecido S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rlIZ9k2TI2anJbhdJLsnTejyp5u.jpg'),
(94354, 6656, 'Rumo ao Desconhecido S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kETInqUcGYUMcml2bnC6C6j8Bpq.jpg'),
(94355, 6656, 'Rumo ao Desconhecido S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7LB2pcaTXnllqEh41JtwtgDlMlk.jpg'),
(94356, 6656, 'Rumo ao Desconhecido S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m1yIZxGj95HCLA5vrY7Ft6YTwli.jpg'),
(94357, 6656, 'Rumo ao Desconhecido S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xepLbcDydhB0YaasL11iqcK5E6u.jpg'),
(94358, 6656, 'Rumo ao Desconhecido S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBHWssU0Nq8OH05LTFfB0iA6rSW.jpg'),
(94359, 6656, 'Rumo ao Desconhecido S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sRGSjgZRspeKwd54IBQ3YQx8SVb.jpg'),
(94360, 6656, 'Rumo ao Desconhecido S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tOq3epnlbuI7jSEJcO2CmErwsXI.jpg'),
(94361, 6656, 'Rumo ao Desconhecido S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kwTWcujRPTcqOnIlBXmJ4gUAThw.jpg'),
(94362, 6657, 'a Aprendiz de Feiticeira S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/40J9woqZKII5TfGGaHVnTT0ejDA.jpg'),
(94363, 6657, 'a Aprendiz de Feiticeira S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s2yJcqEdnuFO4BYs3yNMxdVEnWl.jpg'),
(94364, 6657, 'a Aprendiz de Feiticeira S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lNsHcDYBlQJDfQo2mc2sHqVXw51.jpg'),
(94365, 6657, 'a Aprendiz de Feiticeira S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y5K7nPrF6YZCcdnhBMvgoa65pp7.jpg'),
(94366, 6657, 'a Aprendiz de Feiticeira S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jer09OUErakIFNbva7AUe0c40x5.jpg'),
(94367, 6657, 'a Aprendiz de Feiticeira S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/94pM8bh2MRro8hApdBW4bGCVIvz.jpg'),
(94368, 6657, 'a Aprendiz de Feiticeira S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g4BEmdYUzZb2qOyuef71XKyU5WQ.jpg'),
(94369, 6657, 'a Aprendiz de Feiticeira S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lanhB0bvPmz6PAKiJOOfYJlxNhG.jpg'),
(94370, 6657, 'a Aprendiz de Feiticeira S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cZuOBvd4qQHEASpqyrq24pL6a2Y.jpg'),
(94371, 6657, 'a Aprendiz de Feiticeira S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nXtdq9mu0EX4qeqxn5S48TChyrY.jpg'),
(94372, 6657, 'a Aprendiz de Feiticeira S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/199044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uGoUjEoyjI0YaJJdkScx9Fx5e1t.jpg'),
(94373, 6657, 'a Aprendiz de Feiticeira S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/199045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rLVNlgkcbsigPnkCw3vAvXWJDoN.jpg'),
(94374, 6657, 'a Aprendiz de Feiticeira S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/199046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e08r5nTrOmmzky0u7usT5reHmXk.jpg'),
(94375, 6657, 'a Aprendiz de Feiticeira S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/199047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7GAba27HNjOtzQuA3oyhwJS0oX.jpg'),
(94376, 6657, 'a Aprendiz de Feiticeira S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/199048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1ovN5IBxmhcz6AFrGyFPRdAn6l.jpg'),
(94377, 6657, 'a Aprendiz de Feiticeira S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/199049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8eJsFMU4OHHZvD7up5jzB1iFGma.jpg'),
(94378, 6657, 'a Aprendiz de Feiticeira S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/199050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hsBRV9XELHozdqiduGKkNYWGNTw.jpg'),
(94379, 6657, 'a Aprendiz de Feiticeira S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/199051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aMNwc5GhwRsGZF9HwrZzPozw2JV.jpg'),
(94380, 6657, 'a Aprendiz de Feiticeira S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/199052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dh0gHgwAZqI4kUM5eX6ovQGrIyD.jpg'),
(94381, 6657, 'a Aprendiz de Feiticeira S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/199053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xXuFyDAVWzKXP5YKGAYkIZFJs6k.jpg'),
(94382, 6657, 'a Aprendiz de Feiticeira S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/199054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ib1P6rAMO5jQFZBkifMfXS9hbRO.jpg'),
(94383, 6657, 'a Aprendiz de Feiticeira S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/199055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgOMYX5ItiHcbmYAGIVLstoJq4C.jpg'),
(94384, 6657, 'a Aprendiz de Feiticeira S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/199056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nvDV8YKQNCaV35pBIQeFo0QOm4Q.jpg'),
(94385, 6657, 'a Aprendiz de Feiticeira S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/199057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQViWuWu0IgbPSoEsfJJXmzF5RK.jpg'),
(94386, 6658, 'Sally: Fisiculturismo e Assassinato S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zxFfGEOi75EYVM2KGXPh3CDUW3B.jpg'),
(94387, 6658, 'Sally: Fisiculturismo e Assassinato S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zQeyG2Fkcy89br9KbuEryp2TWsY.jpg'),
(94388, 6658, 'Sally: Fisiculturismo e Assassinato S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/34l31YowD4ATMTAADxtzsVyXGsX.jpg'),
(94389, 6659, 'Tá Tudo uma M&rd@! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8jtRIDbmTDf5r7Gy1gN8d83gsaB.jpg'),
(94390, 6659, 'Tá Tudo uma M&rd@! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Nzn7c7DO3U0SigsXA1jCZkTG9z.jpg'),
(94391, 6659, 'Tá Tudo uma M&rd@! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oORkB3TJqtcjgEL3ghqdJDB3Ff8.jpg'),
(94392, 6659, 'Tá Tudo uma M&rd@! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ozqOPXzc0SS5BiGw7kDbDuVclEg.jpg'),
(94393, 6659, 'Tá Tudo uma M&rd@! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyFMiPiHQyMn66dGrebocuokkk.jpg'),
(94394, 6659, 'Tá Tudo uma M&rd@! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/syzjf2qYlqnKTYDSXCrgR68RfPw.jpg'),
(94395, 6659, 'Tá Tudo uma M&rd@! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nAYAbWyX59ujAFemIuMt7Y5mlHW.jpg'),
(94396, 6659, 'Tá Tudo uma M&rd@! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ws0jIgveNXNktGkNDrX668AkxhP.jpg'),
(94397, 6659, 'Tá Tudo uma M&rd@! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pFZzopZKSmDtRW2ADeyo3EzJNop.jpg'),
(94398, 6659, 'Tá Tudo uma M&rd@! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200856.mp4', 'http://image.tmdb.org/t/p/w1280/ozWKDYzm6XsAzmBfU6PypjZ6xRM.jpg'),
(94399, 6660, 'The BMF Documentary: Blowing Money Fast S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kAj5QhyA52ZPALPHVcgzNR64Zqb.jpg'),
(94400, 6660, 'The BMF Documentary: Blowing Money Fast S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8zdRGPQEE7x4mZgljjAc8FzdxEZ.jpg'),
(94401, 6660, 'The BMF Documentary: Blowing Money Fast S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i9yprvmz8VSpg1HabaS4yYmPAfA.jpg'),
(94402, 6660, 'The BMF Documentary: Blowing Money Fast S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f9SlZMXOGDzfOmS3h1G0vZHBvkj.jpg'),
(94403, 6660, 'The BMF Documentary: Blowing Money Fast S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f9SlZMXOGDzfOmS3h1G0vZHBvkj.jpg'),
(94404, 6660, 'The BMF Documentary: Blowing Money Fast S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f9SlZMXOGDzfOmS3h1G0vZHBvkj.jpg'),
(94405, 6660, 'The BMF Documentary: Blowing Money Fast S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f9SlZMXOGDzfOmS3h1G0vZHBvkj.jpg'),
(94406, 6660, 'The BMF Documentary: Blowing Money Fast S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f9SlZMXOGDzfOmS3h1G0vZHBvkj.jpg'),
(94407, 6661, 'The File of Young Kindaichi Returns S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZB73xKtDC2t5LWV6lavon31whc.jpg'),
(94408, 6661, 'The File of Young Kindaichi Returns S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTqdDAp0Cuygu7viCG4sfxVjWKg.jpg'),
(94409, 6661, 'The File of Young Kindaichi Returns S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2r3ZQjHFPptuar3Oqa39xWdW0jX.jpg'),
(94410, 6661, 'The File of Young Kindaichi Returns S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/75hJssxpShkNjg2sSuxizAlH0YG.jpg'),
(94411, 6661, 'The File of Young Kindaichi Returns S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2OOfvp6f5YTnhYuc4PCY0Kv1C2K.jpg'),
(94412, 6661, 'The File of Young Kindaichi Returns S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/224YPkoyBRf6Kl8HqQrcHubNp9o.jpg'),
(94413, 6661, 'The File of Young Kindaichi Returns S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iNGQ8qOgTmL7u8AZU5n0yCiwTz1.jpg'),
(94414, 6661, 'The File of Young Kindaichi Returns S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8vcZ99a39W56IrDHBZR69hAPXiM.jpg'),
(94415, 6661, 'The File of Young Kindaichi Returns S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/199029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6lrZYrRgWKtlGdtjuHeV1ByJomW.jpg'),
(94416, 6661, 'The File of Young Kindaichi Returns S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/199030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9YvGQ4PhTQ7sBYLDZhyowBVUpJZ.jpg'),
(94417, 6662, 'Ultra Violeta e o Escorpião Negro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pCXKws8G7xUHcEly9Y9uYyufvaI.jpg'),
(94418, 6662, 'Ultra Violeta e o Escorpião Negro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sQm14OiH9ZMVxCUNyyMfrbDnv4y.jpg'),
(94419, 6662, 'Ultra Violeta e o Escorpião Negro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFg5NFc770wXaChCRYD59qujFwL.jpg'),
(94420, 6662, 'Ultra Violeta e o Escorpião Negro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y17nTOFy3eDjcfx4fFsj2rl4mUP.jpg'),
(94421, 6662, 'Ultra Violeta e o Escorpião Negro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aF1gja59XmoquvXsTQVeNltMysQ.jpg'),
(94422, 6662, 'Ultra Violeta e o Escorpião Negro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/WDQsTjvCigFk4l0OPmW05U0fjo.jpg'),
(94423, 6662, 'Ultra Violeta e o Escorpião Negro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wrp8M1Qep0DFPtcDbhDQetE9ZW.jpg'),
(94424, 6662, 'Ultra Violeta e o Escorpião Negro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aHXBR9mPtGeRdJB4jVzcm2EdZOG.jpg'),
(94425, 6662, 'Ultra Violeta e o Escorpião Negro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/20QI1KkUfVFEf98Z8vaCyo6Cwzx.jpg'),
(94426, 6662, 'Ultra Violeta e o Escorpião Negro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mSxQpZQoqzjJMETcloPLpMbgc53.jpg'),
(94427, 6662, 'Ultra Violeta e o Escorpião Negro S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7KcnJjaNfxBlT3kYXppZjdhXIAx.jpg'),
(94428, 6662, 'Ultra Violeta e o Escorpião Negro S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7KcnJjaNfxBlT3kYXppZjdhXIAx.jpg'),
(94429, 6662, 'Ultra Violeta e o Escorpião Negro S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/202445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7KcnJjaNfxBlT3kYXppZjdhXIAx.jpg'),
(94430, 6662, 'Ultra Violeta e o Escorpião Negro S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/202446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7KcnJjaNfxBlT3kYXppZjdhXIAx.jpg'),
(94431, 6662, 'Ultra Violeta e o Escorpião Negro S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/202447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7KcnJjaNfxBlT3kYXppZjdhXIAx.jpg'),
(94432, 6662, 'Ultra Violeta e o Escorpião Negro S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/202448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7KcnJjaNfxBlT3kYXppZjdhXIAx.jpg'),
(94433, 6663, 'Vale dos Esquecidos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t1DDUkTodZtrrj1QtcilofCalS7.jpg'),
(94434, 6663, 'Vale dos Esquecidos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dz1gXW2bmHaWpqwvE6IyY4XQKjV.jpg'),
(94435, 6663, 'Vale dos Esquecidos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dz1gXW2bmHaWpqwvE6IyY4XQKjV.jpg'),
(94436, 6663, 'Vale dos Esquecidos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dz1gXW2bmHaWpqwvE6IyY4XQKjV.jpg'),
(94437, 6663, 'Vale dos Esquecidos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dz1gXW2bmHaWpqwvE6IyY4XQKjV.jpg'),
(94438, 6663, 'Vale dos Esquecidos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dz1gXW2bmHaWpqwvE6IyY4XQKjV.jpg'),
(94439, 6663, 'Vale dos Esquecidos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dz1gXW2bmHaWpqwvE6IyY4XQKjV.jpg'),
(94440, 6663, 'Vale dos Esquecidos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dz1gXW2bmHaWpqwvE6IyY4XQKjV.jpg'),
(94441, 6663, 'Vale dos Esquecidos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dz1gXW2bmHaWpqwvE6IyY4XQKjV.jpg'),
(94442, 6663, 'Vale dos Esquecidos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dz1gXW2bmHaWpqwvE6IyY4XQKjV.jpg'),
(94443, 6664, 'Vale dos Reis: Tesouros do Egito S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4QSndNtpGO6YvjOCfAoAe2IRrqf.jpg'),
(94444, 6664, 'Vale dos Reis: Tesouros do Egito S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wSXlMxTkXu6uJBh0BDE4sdyemO0.jpg'),
(94445, 6664, 'Vale dos Reis: Tesouros do Egito S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k3iZKusQ4eu1qvr2qlD29g250g9.jpg'),
(94446, 6664, 'Vale dos Reis: Tesouros do Egito S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eAgrqAQ9jBoggWAA5o0PW4A9BPa.jpg'),
(94447, 6664, 'Vale dos Reis: Tesouros do Egito S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lauffO3eo6Tm1wSjGemcGO55FJE.jpg'),
(94448, 6664, 'Vale dos Reis: Tesouros do Egito S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mKGb5biBZsQFlxQ0wxOVKbsIEMX.jpg'),
(94449, 6665, 'Vale dos Reis: Tesouros do Egito S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t1jAVEmtebGAWha80Q01fUhqike.jpg'),
(94450, 6665, 'Vale dos Reis: Tesouros do Egito S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/725zkZW7teZ1vwsEEfjXhkIjGT8.jpg'),
(94451, 6665, 'Vale dos Reis: Tesouros do Egito S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iLtHAqEzX5G1fo7x5Ivt9zMOaRb.jpg'),
(94452, 6665, 'Vale dos Reis: Tesouros do Egito S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t0IrxR2DExk3Ob1w2LvcqZiAQAU.jpg'),
(94453, 6665, 'Vale dos Reis: Tesouros do Egito S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nz60uhlY6abG9UcYffvXfslsXrY.jpg'),
(94454, 6665, 'Vale dos Reis: Tesouros do Egito S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rtHHidTZW1mBfWVuaesJ8znF79t.jpg'),
(94455, 6665, 'Vale dos Reis: Tesouros do Egito S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2DPT1mLDxDYB93T9O1z4ZU0KLlU.jpg'),
(94456, 6665, 'Vale dos Reis: Tesouros do Egito S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yepAD6s0yknRhji7Ea78aXVydHm.jpg'),
(94457, 6666, 'Vale dos Reis: Tesouros do Egito S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/199013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yepAD6s0yknRhji7Ea78aXVydHm.jpg'),
(94458, 6666, 'Vale dos Reis: Tesouros do Egito S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/199014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yepAD6s0yknRhji7Ea78aXVydHm.jpg'),
(94459, 6666, 'Vale dos Reis: Tesouros do Egito S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/199015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yepAD6s0yknRhji7Ea78aXVydHm.jpg'),
(94460, 6666, 'Vale dos Reis: Tesouros do Egito S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/199016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yepAD6s0yknRhji7Ea78aXVydHm.jpg'),
(94461, 6666, 'Vale dos Reis: Tesouros do Egito S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/199017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/MVVefYnkksEnlLa2XSrfcoevtg.jpg'),
(94462, 6666, 'Vale dos Reis: Tesouros do Egito S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/199018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eVFThwAwHV7B5X5gyMbAO2ejg5r.jpg'),
(94463, 6666, 'Vale dos Reis: Tesouros do Egito S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/199019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yepAD6s0yknRhji7Ea78aXVydHm.jpg'),
(94464, 6666, 'Vale dos Reis: Tesouros do Egito S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/199020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yepAD6s0yknRhji7Ea78aXVydHm.jpg'),
(94465, 6667, 'Vale dos Reis: Tesouros do Egito S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/879385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yepAD6s0yknRhji7Ea78aXVydHm.jpg'),
(94466, 6667, 'Vale dos Reis: Tesouros do Egito S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/879386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yepAD6s0yknRhji7Ea78aXVydHm.jpg'),
(94467, 6667, 'Vale dos Reis: Tesouros do Egito S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/879387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yepAD6s0yknRhji7Ea78aXVydHm.jpg'),
(94468, 6667, 'Vale dos Reis: Tesouros do Egito S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/879388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yepAD6s0yknRhji7Ea78aXVydHm.jpg'),
(94469, 6667, 'Vale dos Reis: Tesouros do Egito S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/879389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yepAD6s0yknRhji7Ea78aXVydHm.jpg'),
(94470, 6667, 'Vale dos Reis: Tesouros do Egito S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/879390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yepAD6s0yknRhji7Ea78aXVydHm.jpg'),
(94471, 6667, 'Vale dos Reis: Tesouros do Egito S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/879391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yepAD6s0yknRhji7Ea78aXVydHm.jpg'),
(94472, 6667, 'Vale dos Reis: Tesouros do Egito S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/879392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yepAD6s0yknRhji7Ea78aXVydHm.jpg'),
(94473, 6668, 'Vilões de Valley View S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zebIXFEqmWnzky8oUTnYmB3wqx6.jpg'),
(94474, 6668, 'Vilões de Valley View S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/468534.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2PsNy9NHIhrSMi9sveVjcmQGuwf.jpg'),
(94475, 6668, 'Vilões de Valley View S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/468535.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kEl6lGZRhf8jItfuBFZ5Rqu03UZ.jpg'),
(94476, 6668, 'Vilões de Valley View S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zebIXFEqmWnzky8oUTnYmB3wqx6.jpg'),
(94477, 6668, 'Vilões de Valley View S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zebIXFEqmWnzky8oUTnYmB3wqx6.jpg'),
(94478, 6668, 'Vilões de Valley View S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zebIXFEqmWnzky8oUTnYmB3wqx6.jpg'),
(94479, 6668, 'Vilões de Valley View S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/618517.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2hfPJtkBdiK1a6iocpQ4SPwEe1D.jpg'),
(94480, 6668, 'Vilões de Valley View S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zebIXFEqmWnzky8oUTnYmB3wqx6.jpg'),
(94481, 6668, 'Vilões de Valley View S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/618519.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/joXjkYIBPhv6CdSjDrdHtBd5gRy.jpg'),
(94482, 6668, 'Vilões de Valley View S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210767.mp4', 'http://image.tmdb.org/t/p/w1280/y8rZzyB6w2X6RHPlxcgWGvqoBIG.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(94483, 6668, 'Vilões de Valley View S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/468544.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uakuxEzbvaGFH4xg3aSAIRmjkCx.jpg'),
(94484, 6669, 'Mike Judge\'s Beavis and Butt-Head S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/geHeBChJ7WdrGO6S0hckkB0yCGI.jpg'),
(94485, 6669, 'Mike Judge\'s Beavis and Butt-Head S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gsgNEhKhEOueyc1NfeDHlHB1FnU.jpg'),
(94486, 6669, 'Mike Judge\'s Beavis and Butt-Head S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Di1xCg9ttRULGYuNtmheCcwovL.jpg'),
(94487, 6669, 'Mike Judge\'s Beavis and Butt-Head S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ukeIgps8TdZ9bZQW5uUPqs5OuKF.jpg'),
(94488, 6669, 'Mike Judge\'s Beavis and Butt-Head S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1YF0VAWM7rvDhYyaPMQdTyo3Kv.jpg'),
(94489, 6669, 'Mike Judge\'s Beavis and Butt-Head S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7tJ8EB3vxu5xudgBivtiM963hom.jpg'),
(94490, 6669, 'Mike Judge\'s Beavis and Butt-Head S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/foBY67CYdh2epn3V8tABCRqGvRM.jpg'),
(94491, 6669, 'Mike Judge\'s Beavis and Butt-Head S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mHnyGiaWz0jLhPcgXuB9Iv7F4QN.jpg'),
(94492, 6669, 'Mike Judge\'s Beavis and Butt-Head S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJFQtgkWFQLdieI9wzfw02T3bm.jpg'),
(94493, 6669, 'Mike Judge\'s Beavis and Butt-Head S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iGIH554vQ8FRG5LixDWV7wfx9d2.jpg'),
(94494, 6669, 'Mike Judge\'s Beavis and Butt-Head S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219429.mp4', 'http://image.tmdb.org/t/p/w1280/lzR0ut3f3Gis2hp2xItxK4FqO90.jpg'),
(94495, 6669, 'Mike Judge\'s Beavis and Butt-Head S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219430.mp4', 'http://image.tmdb.org/t/p/w1280/tSBZJWXOwoJOK7tO19lySU2pQyO.jpg'),
(94496, 6670, 'Mike Judge\'s Beavis and Butt-Head S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mGmMozs7l3ri4YIdOUSPUxmYP4K.jpg'),
(94497, 6670, 'Mike Judge\'s Beavis and Butt-Head S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v6BjmYFiaTpp4x65ITvRNOtMKK3.jpg'),
(94498, 6670, 'Mike Judge\'s Beavis and Butt-Head S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219433.mp4', 'http://image.tmdb.org/t/p/w1280/tZh9SXXHLxZIuLatE2PcyzzcucO.jpg'),
(94499, 6670, 'Mike Judge\'s Beavis and Butt-Head S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219434.mp4', 'http://image.tmdb.org/t/p/w1280/utCBuq0FAdnzcKBOO5k51Tp9U7c.jpg'),
(94500, 6670, 'Mike Judge\'s Beavis and Butt-Head S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219435.mp4', 'http://image.tmdb.org/t/p/w1280/ymOTzKav67dvDRNfkUKPTRrIxL6.jpg'),
(94501, 6670, 'Mike Judge\'s Beavis and Butt-Head S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219436.mp4', 'http://image.tmdb.org/t/p/w1280/UrZZWPmcGw18FXf9lnrddgkb19.jpg'),
(94502, 6670, 'Mike Judge\'s Beavis and Butt-Head S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219437.mp4', 'http://image.tmdb.org/t/p/w1280/dlkOOhES9bS7pCSC95YrCFJVU98.jpg'),
(94503, 6670, 'Mike Judge\'s Beavis and Butt-Head S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219438.mp4', 'http://image.tmdb.org/t/p/w1280/zr16bykCcKZBKkgarD9ms4QKYRz.jpg'),
(94504, 6670, 'Mike Judge\'s Beavis and Butt-Head S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219439.mp4', 'http://image.tmdb.org/t/p/w1280/fEES9Mw58tWjsoqpfOPRMmvSQsS.jpg'),
(94505, 6670, 'Mike Judge\'s Beavis and Butt-Head S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/97Dok2tQ8GvVDfPBAVlZRiAlssC.jpg'),
(94506, 6670, 'Mike Judge\'s Beavis and Butt-Head S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219441.mp4', 'http://image.tmdb.org/t/p/w1280/fVb57EBJ2EMrUkoNwNofXYvtqFp.jpg'),
(94507, 6670, 'Mike Judge\'s Beavis and Butt-Head S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219442.mp4', 'http://image.tmdb.org/t/p/w1280/3wHvIbYK93f754ikeIhCFzEIJnn.jpg'),
(94508, 6671, 'Family Law S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ujqYFfdBkrLuJBDRVmM5ICElum7.jpg'),
(94509, 6671, 'Family Law S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uvwIyvohfcXZ3HAmevGN27EiSzO.jpg'),
(94510, 6671, 'Family Law S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9wHIuGlOAWCAW0Fq0dfn0umN3yZ.jpg'),
(94511, 6671, 'Family Law S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jdirW0Bp55AwqQgeRKQrZrZS3Vg.jpg'),
(94512, 6671, 'Family Law S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fw5sq5aExKgD338m350UBVHGmve.jpg'),
(94513, 6671, 'Family Law S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a8aJ3pFcrN7y3dnHeiIuWnHTpKV.jpg'),
(94514, 6671, 'Family Law S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9oyTcnBsRYFLEVf5uVBeu7t83hb.jpg'),
(94515, 6671, 'Family Law S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qX8YkpzI3JBSfOY9yG6DcxDagSn.jpg'),
(94516, 6671, 'Family Law S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hP2GGrHftnAUz4bjsawrJNbn8Is.jpg'),
(94517, 6671, 'Family Law S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/swO6M9zwYSziu4apZsmNvXc0bNr.jpg'),
(94518, 6672, 'Family Law S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jcw7u8ddToyCO64QpkJgbnTqi0M.jpg'),
(94519, 6672, 'Family Law S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6YLyXg3mXhyy62rSJBZzDjQvgWT.jpg'),
(94520, 6672, 'Family Law S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5vdxNynekVsfjXvX7o3uVPIS8CA.jpg'),
(94521, 6672, 'Family Law S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9fSYaOYWee8q6q52I5IYxnyP9mQ.jpg'),
(94522, 6672, 'Family Law S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mnS8H93GYFSYqk22iLqMm9fCZn2.jpg'),
(94523, 6672, 'Family Law S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rtffyznXB0ZbQ9tukj9WeQ7gFEp.jpg'),
(94524, 6672, 'Family Law S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vwfR41856MbJGDAnTeYHb9bJJbY.jpg'),
(94525, 6672, 'Family Law S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Y3O8lQxfC60KSFoU4QlAk3aZS3.jpg'),
(94526, 6672, 'Family Law S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vfJb196E4GzeVEarboIss81jVvJ.jpg'),
(94527, 6672, 'Family Law S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybuwJ9NWO75EJnWfjwmJEqAl8Jd.jpg'),
(94528, 6673, 'Family Law S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amxRi4RUIGuV0qaKiJPJpROruYR.jpg'),
(94529, 6673, 'Family Law S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amxRi4RUIGuV0qaKiJPJpROruYR.jpg'),
(94530, 6673, 'Family Law S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amxRi4RUIGuV0qaKiJPJpROruYR.jpg'),
(94531, 6673, 'Family Law S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/271411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amxRi4RUIGuV0qaKiJPJpROruYR.jpg'),
(94532, 6673, 'Family Law S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/272968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amxRi4RUIGuV0qaKiJPJpROruYR.jpg'),
(94533, 6673, 'Family Law S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amxRi4RUIGuV0qaKiJPJpROruYR.jpg'),
(94534, 6673, 'Family Law S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/292825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amxRi4RUIGuV0qaKiJPJpROruYR.jpg'),
(94535, 6673, 'Family Law S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amxRi4RUIGuV0qaKiJPJpROruYR.jpg'),
(94536, 6673, 'Family Law S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/300009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amxRi4RUIGuV0qaKiJPJpROruYR.jpg'),
(94537, 6673, 'Family Law S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/304977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amxRi4RUIGuV0qaKiJPJpROruYR.jpg'),
(94538, 6674, 'Family Law S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/879994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amxRi4RUIGuV0qaKiJPJpROruYR.jpg'),
(94539, 6674, 'Family Law S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/880585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amxRi4RUIGuV0qaKiJPJpROruYR.jpg'),
(94540, 6674, 'Family Law S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/881222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amxRi4RUIGuV0qaKiJPJpROruYR.jpg'),
(94541, 6674, 'Family Law S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/881340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amxRi4RUIGuV0qaKiJPJpROruYR.jpg'),
(94542, 6674, 'Family Law S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/882359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amxRi4RUIGuV0qaKiJPJpROruYR.jpg'),
(94543, 6674, 'Family Law S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/883805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amxRi4RUIGuV0qaKiJPJpROruYR.jpg'),
(94544, 6674, 'Family Law S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/885330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amxRi4RUIGuV0qaKiJPJpROruYR.jpg'),
(94545, 6674, 'Family Law S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/886086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amxRi4RUIGuV0qaKiJPJpROruYR.jpg'),
(94546, 6674, 'Family Law S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/887592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amxRi4RUIGuV0qaKiJPJpROruYR.jpg'),
(94547, 6674, 'Family Law S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/888208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amxRi4RUIGuV0qaKiJPJpROruYR.jpg'),
(94548, 6675, 'Legacy: A Verdadeira História dos Lakers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qPhu2Nh6MRduMeYoILelmiZcRDO.jpg'),
(94549, 6675, 'Legacy: A Verdadeira História dos Lakers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cR3P145RrEyD3QyaCriyPQH9SxJ.jpg'),
(94550, 6675, 'Legacy: A Verdadeira História dos Lakers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wJ26fsPASO8TtuYoaBO1bkYlTux.jpg'),
(94551, 6675, 'Legacy: A Verdadeira História dos Lakers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ex2kcViEXJHnj0XHuHmWBAeJhea.jpg'),
(94552, 6675, 'Legacy: A Verdadeira História dos Lakers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7iJ1IUJD6a9kC8eQxw46M7AEAoe.jpg'),
(94553, 6675, 'Legacy: A Verdadeira História dos Lakers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iovrPYiwGOc7LDsDoQ8dUGX9nMd.jpg'),
(94554, 6675, 'Legacy: A Verdadeira História dos Lakers S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200936.mp4', 'http://image.tmdb.org/t/p/w1280/d6IYr8oME7BjEGFgWHCMYLJNpgL.jpg'),
(94555, 6675, 'Legacy: A Verdadeira História dos Lakers S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3O9A4tMlXq3VC1YDOwlZNPYyKf6.jpg'),
(94556, 6675, 'Legacy: A Verdadeira História dos Lakers S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mc5Zm23WjAJSHfTIK9SqtyKi6Ek.jpg'),
(94557, 6675, 'Legacy: A Verdadeira História dos Lakers S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cEHXMy31mpRhM7vjOKRvd9kRf5O.jpg'),
(94558, 6676, 'A Taça é Nuestra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ftATU8hUTee9Qy1nwQ1LjCtZMY.jpg'),
(94559, 6676, 'A Taça é Nuestra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ik0tSqqzX4WxHuAz1z0vEZdpmK.jpg'),
(94560, 6676, 'A Taça é Nuestra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bRWzI896zH36I9IEUpe4PE2xo03.jpg'),
(94561, 6676, 'A Taça é Nuestra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7sm9oPJFsOjXvpRsDCVZJUa5rPS.jpg'),
(94562, 6676, 'A Taça é Nuestra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jH6o2WKXneXhQknu35QCQnxI94O.jpg'),
(94563, 6676, 'A Taça é Nuestra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wfZTEj4zhAsbjwpMdDICGhmrnoW.jpg'),
(94564, 6677, 'As Grandes Minorias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2iTobROW3oOYJyjAIFK2UnK76Ay.jpg'),
(94565, 6677, 'As Grandes Minorias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2iTobROW3oOYJyjAIFK2UnK76Ay.jpg'),
(94566, 6677, 'As Grandes Minorias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2iTobROW3oOYJyjAIFK2UnK76Ay.jpg'),
(94567, 6678, 'Bake Off Brasil - Cereja do Bolo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94568, 6678, 'Bake Off Brasil - Cereja do Bolo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94569, 6678, 'Bake Off Brasil - Cereja do Bolo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94570, 6678, 'Bake Off Brasil - Cereja do Bolo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94571, 6678, 'Bake Off Brasil - Cereja do Bolo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94572, 6678, 'Bake Off Brasil - Cereja do Bolo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94573, 6678, 'Bake Off Brasil - Cereja do Bolo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94574, 6678, 'Bake Off Brasil - Cereja do Bolo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94575, 6678, 'Bake Off Brasil - Cereja do Bolo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94576, 6678, 'Bake Off Brasil - Cereja do Bolo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94577, 6678, 'Bake Off Brasil - Cereja do Bolo S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94578, 6678, 'Bake Off Brasil - Cereja do Bolo S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94579, 6678, 'Bake Off Brasil - Cereja do Bolo S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94580, 6678, 'Bake Off Brasil - Cereja do Bolo S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/203422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94581, 6678, 'Bake Off Brasil - Cereja do Bolo S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/203423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94582, 6678, 'Bake Off Brasil - Cereja do Bolo S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/203424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94583, 6679, 'Bake Off Brasil - Cereja do Bolo S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94584, 6679, 'Bake Off Brasil - Cereja do Bolo S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94585, 6679, 'Bake Off Brasil - Cereja do Bolo S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94586, 6679, 'Bake Off Brasil - Cereja do Bolo S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94587, 6679, 'Bake Off Brasil - Cereja do Bolo S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94588, 6679, 'Bake Off Brasil - Cereja do Bolo S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94589, 6679, 'Bake Off Brasil - Cereja do Bolo S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94590, 6679, 'Bake Off Brasil - Cereja do Bolo S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94591, 6679, 'Bake Off Brasil - Cereja do Bolo S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94592, 6679, 'Bake Off Brasil - Cereja do Bolo S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94593, 6679, 'Bake Off Brasil - Cereja do Bolo S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94594, 6679, 'Bake Off Brasil - Cereja do Bolo S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94595, 6679, 'Bake Off Brasil - Cereja do Bolo S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94596, 6679, 'Bake Off Brasil - Cereja do Bolo S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/203438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94597, 6679, 'Bake Off Brasil - Cereja do Bolo S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/203439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bb1q3ytAW1PRHkIerljQz9yVXSR.jpg'),
(94598, 6680, 'Barbie: It Takes Two S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jFnzsH8ZKfP1ylAgvKOjnaAqKug.jpg'),
(94599, 6680, 'Barbie: It Takes Two S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sd3yL7QKwtuwyQhWIGMfqmuCHCh.jpg'),
(94600, 6680, 'Barbie: It Takes Two S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pWvAG4XOeIlSALIP5nuBVJbAodJ.jpg'),
(94601, 6680, 'Barbie: It Takes Two S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1n36Li6SipK6GN68q0NKThLjPXO.jpg'),
(94602, 6680, 'Barbie: It Takes Two S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mpFVWZxvCngloD0l58u38gNk0MF.jpg'),
(94603, 6680, 'Barbie: It Takes Two S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t5rwpzcng4apyZDJAvDcsnxvwiy.jpg'),
(94604, 6680, 'Barbie: It Takes Two S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rYGV3ATuBxh7xj72Ju96bC46u3V.jpg'),
(94605, 6680, 'Barbie: It Takes Two S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pXxIdZPDa7WQTUEWjgZrv5yM7w3.jpg'),
(94606, 6680, 'Barbie: It Takes Two S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/us7JHt9xEMuHKbfY7096oXAD63w.jpg'),
(94607, 6680, 'Barbie: It Takes Two S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g6AXSv8DIjvjwzrNb7BbxpfDNsH.jpg'),
(94608, 6680, 'Barbie: It Takes Two S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3fU8Px9fhSqGu1bZqhlXfegZVSY.jpg'),
(94609, 6680, 'Barbie: It Takes Two S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4LEgnvPNPNzsjYx5OFiPcpt2pt9.jpg'),
(94610, 6680, 'Barbie: It Takes Two S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xUt9Q2QAQaZ4AuWMUFCxBGn67aD.jpg'),
(94611, 6681, 'Barbie: It Takes Two S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mAKy58RSKIRbcFNlZc32WKUPAd0.jpg'),
(94612, 6681, 'Barbie: It Takes Two S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xgqYJUANbzVea2AMUfgV0F60h5F.jpg'),
(94613, 6681, 'Barbie: It Takes Two S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uaqmL8kOfXpqQUXa5ePqPcdf3EH.jpg'),
(94614, 6681, 'Barbie: It Takes Two S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/83W55Cbe9f5jA2GDdjmcKvAomXI.jpg'),
(94615, 6681, 'Barbie: It Takes Two S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dKoOzm5hMhZNiWg8lIAjwg5gyYs.jpg'),
(94616, 6681, 'Barbie: It Takes Two S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dpTcSVYTHwkTROP37MjahWbodJT.jpg'),
(94617, 6681, 'Barbie: It Takes Two S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qrd3PY8BRxKRUBth2q2wDH3NFwz.jpg'),
(94618, 6681, 'Barbie: It Takes Two S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gqZrfKhgteCPRHYOOH4nrw4K17A.jpg'),
(94619, 6681, 'Barbie: It Takes Two S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6UpeYhO3WybnTymSUO9ttgS13vy.jpg'),
(94620, 6681, 'Barbie: It Takes Two S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qOzVJBMs723D3gHozvwcuszN8op.jpg'),
(94621, 6681, 'Barbie: It Takes Two S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Ujj9OxQEAaKgJYipjzuoKklFA1.jpg'),
(94622, 6681, 'Barbie: It Takes Two S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fObE3IH21Q9RQRyxriXAUDmPzAc.jpg'),
(94623, 6681, 'Barbie: It Takes Two S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tbPKHDiALrr9yIMfZC8eVTS06AS.jpg'),
(94624, 6682, 'Beckham: Salve Nosso Time S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4cDE5C3HlUKzhrTbu7QCprMlfMB.jpg'),
(94625, 6682, 'Beckham: Salve Nosso Time S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/20gtIZ7HfdkOyw6l4MVhF2uJTzU.jpg'),
(94626, 6682, 'Beckham: Salve Nosso Time S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/clQzuOie6LPHsBRLhOig8x1MLv4.jpg'),
(94627, 6682, 'Beckham: Salve Nosso Time S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4buQvWQmLj7DGd9B1hYdnmho33V.jpg'),
(94628, 6683, 'Brasil: A Última Cruzada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wmTysh5rn3W91RG0DFWLwZIx15b.jpg'),
(94629, 6683, 'Brasil: A Última Cruzada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wmTysh5rn3W91RG0DFWLwZIx15b.jpg'),
(94630, 6683, 'Brasil: A Última Cruzada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wmTysh5rn3W91RG0DFWLwZIx15b.jpg'),
(94631, 6683, 'Brasil: A Última Cruzada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wmTysh5rn3W91RG0DFWLwZIx15b.jpg'),
(94632, 6683, 'Brasil: A Última Cruzada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wmTysh5rn3W91RG0DFWLwZIx15b.jpg'),
(94633, 6684, 'Contos Futurísticos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p8rHzth9gqQZD4IAscJSvY8eJFD.jpg'),
(94634, 6684, 'Contos Futurísticos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/MYwy9bU43J2UTgXInKQQzP0R74.jpg'),
(94635, 6684, 'Contos Futurísticos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t4xEvXeqdPz9eTt5prMkPJrmdFj.jpg'),
(94636, 6684, 'Contos Futurísticos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1D4Jxz6jcU9RIVgoKr3Zq5nJtL3.jpg'),
(94637, 6684, 'Contos Futurísticos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b6IG5Os9mKtVLIELjsqPJ6Y6fii.jpg'),
(94638, 6684, 'Contos Futurísticos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mBbrR7fle8Ciy8awUFMxQ8IO4XC.jpg'),
(94639, 6684, 'Contos Futurísticos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vYpO3zpifFPxiUaVh0O6XOBBR0d.jpg'),
(94640, 6685, 'Em Busca de Vingança S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dKRCwjZDkIA1VtIYTpIN3CUCWDL.jpg'),
(94641, 6685, 'Em Busca de Vingança S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9YuWp86ihlJiKmV4whsrTI8tiNZ.jpg'),
(94642, 6685, 'Em Busca de Vingança S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q6paXMBfBaaAmyPpXc4tYeTziJP.jpg'),
(94643, 6685, 'Em Busca de Vingança S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rXMMthOLLD6ssceVIlZO93NWCK0.jpg'),
(94644, 6685, 'Em Busca de Vingança S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x1xNLt68xMlCimjkjeab1WtAZIk.jpg'),
(94645, 6685, 'Em Busca de Vingança S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jAbGKzX9Z4OP2mpVgW8T8seKWyu.jpg'),
(94646, 6685, 'Em Busca de Vingança S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xlfuO4GumG2gMFGk6LEaZkaQEIw.jpg'),
(94647, 6685, 'Em Busca de Vingança S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVuAxof0mq7tGWyjbNnasdFcuVV.jpg'),
(94648, 6685, 'Em Busca de Vingança S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sIa83yZZrFdMu3XcpwHg3Q9BUAu.jpg'),
(94649, 6685, 'Em Busca de Vingança S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bnbMwVCjyapzzP2qEyMgVdpgqRK.jpg'),
(94650, 6685, 'Em Busca de Vingança S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/msM3ESyYPQRDnSGMZLWsfoosWm8.jpg'),
(94651, 6685, 'Em Busca de Vingança S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cdCgPpA6ObmKS2Zya9NCbKe75Aj.jpg'),
(94652, 6686, 'Esquemas da FIFA S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/miODaddaoBopQM7ALareERRCYXK.jpg'),
(94653, 6686, 'Esquemas da FIFA S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q22zPiQ8VQ28MFus22IneN2L1L7.jpg'),
(94654, 6686, 'Esquemas da FIFA S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5GEGqkJj6oOJZHREzYC9gaYSsq.jpg'),
(94655, 6686, 'Esquemas da FIFA S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yUBgFHWwitRAHSGTwv8VNg5DDTC.jpg'),
(94656, 6687, 'Fim Das Nações S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z0EWZS5FtSTh5KmVAmcrzNP1HCj.jpg'),
(94657, 6687, 'Fim Das Nações S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z0EWZS5FtSTh5KmVAmcrzNP1HCj.jpg'),
(94658, 6687, 'Fim Das Nações S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z0EWZS5FtSTh5KmVAmcrzNP1HCj.jpg'),
(94659, 6688, 'Fuuto Tantei S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/198267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cfmegdRMBiw0PfxpWvCisdV38Pb.jpg'),
(94660, 6688, 'Fuuto Tantei S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/198268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCbC21ClJ2GBjNmsdn13hWDecBi.jpg'),
(94661, 6688, 'Fuuto Tantei S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/198269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/90uy0v2tXKUyN24oLsYtNEu2CdN.jpg'),
(94662, 6688, 'Fuuto Tantei S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/198270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g3klN2raYsyhTyfsr4mBa0iW19j.jpg'),
(94663, 6688, 'Fuuto Tantei S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/198271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6sbnewJCLyCp7cwuypUhNqNZD6P.jpg'),
(94664, 6688, 'Fuuto Tantei S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/198272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t8QUY3r7TsRkfEO86hsAgblHEIN.jpg'),
(94665, 6688, 'Fuuto Tantei S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/198273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pqTCX2Udc8KK4EhOh3EMhILWuDE.jpg'),
(94666, 6688, 'Fuuto Tantei S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/198274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/DHfM15p70ci7uW4bQ7jrK3zGq5.jpg'),
(94667, 6688, 'Fuuto Tantei S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/198275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4gYZ17lTRcFDpvaT8uzbDllyX2m.jpg'),
(94668, 6688, 'Fuuto Tantei S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/198276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c1K9WaQluMOcawkZgJRyuYg8Dty.jpg'),
(94669, 6688, 'Fuuto Tantei S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/198277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gxLmL8GfVOi4sqD4iZnRR5iMPmy.jpg'),
(94670, 6688, 'Fuuto Tantei S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/198278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lSQbH5o2ys36ujeP2Ahb25Pvm5D.jpg'),
(94671, 6689, 'Insight BP S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vcRfKl8sYmFRbNPSIkFMr9XmlP3.jpg'),
(94672, 6689, 'Insight BP S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vcRfKl8sYmFRbNPSIkFMr9XmlP3.jpg'),
(94673, 6689, 'Insight BP S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vcRfKl8sYmFRbNPSIkFMr9XmlP3.jpg'),
(94674, 6689, 'Insight BP S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vcRfKl8sYmFRbNPSIkFMr9XmlP3.jpg'),
(94675, 6689, 'Insight BP S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vcRfKl8sYmFRbNPSIkFMr9XmlP3.jpg'),
(94676, 6689, 'Insight BP S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vcRfKl8sYmFRbNPSIkFMr9XmlP3.jpg'),
(94677, 6689, 'Insight BP S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vcRfKl8sYmFRbNPSIkFMr9XmlP3.jpg'),
(94678, 6689, 'Insight BP S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vcRfKl8sYmFRbNPSIkFMr9XmlP3.jpg'),
(94679, 6689, 'Insight BP S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vcRfKl8sYmFRbNPSIkFMr9XmlP3.jpg'),
(94680, 6689, 'Insight BP S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vcRfKl8sYmFRbNPSIkFMr9XmlP3.jpg'),
(94681, 6689, 'Insight BP S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vcRfKl8sYmFRbNPSIkFMr9XmlP3.jpg'),
(94682, 6690, 'Insight BP S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vcRfKl8sYmFRbNPSIkFMr9XmlP3.jpg'),
(94683, 6690, 'Insight BP S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vcRfKl8sYmFRbNPSIkFMr9XmlP3.jpg'),
(94684, 6690, 'Insight BP S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vcRfKl8sYmFRbNPSIkFMr9XmlP3.jpg'),
(94685, 6690, 'Insight BP S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vcRfKl8sYmFRbNPSIkFMr9XmlP3.jpg'),
(94686, 6690, 'Insight BP S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vcRfKl8sYmFRbNPSIkFMr9XmlP3.jpg'),
(94687, 6690, 'Insight BP S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vcRfKl8sYmFRbNPSIkFMr9XmlP3.jpg'),
(94688, 6690, 'Insight BP S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vcRfKl8sYmFRbNPSIkFMr9XmlP3.jpg'),
(94689, 6690, 'Insight BP S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vcRfKl8sYmFRbNPSIkFMr9XmlP3.jpg'),
(94690, 6691, 'Mulheres do Movimento S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/njkEpIJEF0VTkA5QNgrnPXNxr5L.jpg'),
(94691, 6691, 'Mulheres do Movimento S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8MKRMem0Htptlu8Mdc37Cz8Rvta.jpg'),
(94692, 6691, 'Mulheres do Movimento S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fByCNmmud2cfDQEFm9vVG6Yi86W.jpg'),
(94693, 6691, 'Mulheres do Movimento S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZpi3uKdSenOjJGdfARdoUJHxQM.jpg'),
(94694, 6691, 'Mulheres do Movimento S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z28fo5xn5Mr8wzFtwLZwpW8ZvmX.jpg'),
(94695, 6691, 'Mulheres do Movimento S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/31ao190wB7eloUosAwJwRqJ1fKq.jpg'),
(94696, 6692, 'No Mundo da Luna S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mBMjRgyRvqT5DNeqU5fUaKJE5BT.jpg'),
(94697, 6692, 'No Mundo da Luna S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mBMjRgyRvqT5DNeqU5fUaKJE5BT.jpg'),
(94698, 6692, 'No Mundo da Luna S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mBMjRgyRvqT5DNeqU5fUaKJE5BT.jpg'),
(94699, 6692, 'No Mundo da Luna S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mBMjRgyRvqT5DNeqU5fUaKJE5BT.jpg'),
(94700, 6692, 'No Mundo da Luna S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mBMjRgyRvqT5DNeqU5fUaKJE5BT.jpg'),
(94701, 6692, 'No Mundo da Luna S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mBMjRgyRvqT5DNeqU5fUaKJE5BT.jpg'),
(94702, 6692, 'No Mundo da Luna S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mBMjRgyRvqT5DNeqU5fUaKJE5BT.jpg'),
(94703, 6692, 'No Mundo da Luna S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mBMjRgyRvqT5DNeqU5fUaKJE5BT.jpg'),
(94704, 6692, 'No Mundo da Luna S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mBMjRgyRvqT5DNeqU5fUaKJE5BT.jpg'),
(94705, 6692, 'No Mundo da Luna S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mBMjRgyRvqT5DNeqU5fUaKJE5BT.jpg'),
(94706, 6693, 'Pátria Educadora S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v4JTl6g4IzRoH3qOeW6JHGTQEPu.jpg'),
(94707, 6693, 'Pátria Educadora S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v4JTl6g4IzRoH3qOeW6JHGTQEPu.jpg'),
(94708, 6693, 'Pátria Educadora S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v4JTl6g4IzRoH3qOeW6JHGTQEPu.jpg'),
(94709, 6694, 'Revelações Pré-históricas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9ywNXPHZBNwyELWrcWBFxACmULc.jpg'),
(94710, 6694, 'Revelações Pré-históricas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9ywNXPHZBNwyELWrcWBFxACmULc.jpg'),
(94711, 6694, 'Revelações Pré-históricas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9ywNXPHZBNwyELWrcWBFxACmULc.jpg'),
(94712, 6694, 'Revelações Pré-históricas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9ywNXPHZBNwyELWrcWBFxACmULc.jpg'),
(94713, 6694, 'Revelações Pré-históricas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9ywNXPHZBNwyELWrcWBFxACmULc.jpg'),
(94714, 6694, 'Revelações Pré-históricas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9ywNXPHZBNwyELWrcWBFxACmULc.jpg'),
(94715, 6694, 'Revelações Pré-históricas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9ywNXPHZBNwyELWrcWBFxACmULc.jpg'),
(94716, 6694, 'Revelações Pré-históricas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9ywNXPHZBNwyELWrcWBFxACmULc.jpg'),
(94717, 6695, 'Transformers: A Centelha da Terra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w4FdLgH6eJn3EoXX1JVH7wy026S.jpg'),
(94718, 6695, 'Transformers: A Centelha da Terra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94719, 6695, 'Transformers: A Centelha da Terra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jCJcIfVLhmC4BGvPCsKbgycslGZ.jpg'),
(94720, 6695, 'Transformers: A Centelha da Terra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237484.mp4', 'http://image.tmdb.org/t/p/w1280/ldCOK2vjRN8SOhw9JgWYKQOAzig.jpg'),
(94721, 6695, 'Transformers: A Centelha da Terra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237485.mp4', 'http://image.tmdb.org/t/p/w1280/nbMstr1M1v47pRZc3h0iCTyvrUC.jpg'),
(94722, 6695, 'Transformers: A Centelha da Terra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237486.mp4', 'http://image.tmdb.org/t/p/w1280/s7S9H5U90SagitcPMsyFs3kmGDE.jpg'),
(94723, 6695, 'Transformers: A Centelha da Terra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWMXXLTvTAxmi97kotFNEeW4uwG.jpg'),
(94724, 6695, 'Transformers: A Centelha da Terra S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j5rDhFnqwPBlyYQWCoiGG4anKCE.jpg'),
(94725, 6695, 'Transformers: A Centelha da Terra S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94726, 6695, 'Transformers: A Centelha da Terra S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94727, 6695, 'Transformers: A Centelha da Terra S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94728, 6695, 'Transformers: A Centelha da Terra S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94729, 6695, 'Transformers: A Centelha da Terra S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94730, 6695, 'Transformers: A Centelha da Terra S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94731, 6696, 'Transformers: A Centelha da Terra S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/401345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94732, 6696, 'Transformers: A Centelha da Terra S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/401346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94733, 6696, 'Transformers: A Centelha da Terra S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/401347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94734, 6696, 'Transformers: A Centelha da Terra S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/401348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94735, 6696, 'Transformers: A Centelha da Terra S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/401349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94736, 6696, 'Transformers: A Centelha da Terra S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/401350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94737, 6696, 'Transformers: A Centelha da Terra S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/401351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94738, 6696, 'Transformers: A Centelha da Terra S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/401352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94739, 6696, 'Transformers: A Centelha da Terra S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/401353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(94740, 6696, 'Transformers: A Centelha da Terra S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/401354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94741, 6697, 'Transformers: A Centelha da Terra S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/516943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94742, 6697, 'Transformers: A Centelha da Terra S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/516944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94743, 6697, 'Transformers: A Centelha da Terra S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/516945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94744, 6697, 'Transformers: A Centelha da Terra S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/516946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94745, 6697, 'Transformers: A Centelha da Terra S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/516947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94746, 6697, 'Transformers: A Centelha da Terra S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/516948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94747, 6697, 'Transformers: A Centelha da Terra S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/516949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94748, 6697, 'Transformers: A Centelha da Terra S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/516950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ceVun5ktxwbAQFliomMmzOl05S3.jpg'),
(94749, 6698, 'Vida de Casal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eik4XIkBec73S7eDYjm9AmferRx.jpg'),
(94750, 6698, 'Vida de Casal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eAHT9jCR4tI0w46RG2dbNtv5w9e.jpg'),
(94751, 6698, 'Vida de Casal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gqVFfWriSf3shbkI3MRqRZlMHF1.jpg'),
(94752, 6698, 'Vida de Casal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tw8IN2Djzn2VI9ubsWv6JdGKCEu.jpg'),
(94753, 6698, 'Vida de Casal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xqUKmPyCrNusYUNqJrxNX5jyzoZ.jpg'),
(94754, 6698, 'Vida de Casal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A9C0tMQbdCWCYTmgTR75q71HO8m.jpg'),
(94755, 6699, 'Zootopia+ S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9H9DBdtwNGvx0RAMP5YQobdX47t.jpg'),
(94756, 6699, 'Zootopia+ S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPgtZCi83zmA5dGo0GB5gEHtUFf.jpg'),
(94757, 6699, 'Zootopia+ S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ydFPHiFLZdleAUlEohANYSwneia.jpg'),
(94758, 6699, 'Zootopia+ S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lni7qNWyCOR5NmrceRxkUxsnxaJ.jpg'),
(94759, 6699, 'Zootopia+ S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7uawyVKWoU8GBknHsiDW074w84s.jpg'),
(94760, 6699, 'Zootopia+ S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dmigXGgbZqBJOIDoAs5AyWmlS9A.jpg'),
(94761, 6700, 'Febre do Ouro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h4Rhi8IoPNwijbETGNTHgfHDXFo.jpg'),
(94762, 6700, 'Febre do Ouro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zsGNZ909Gz4pkG2BVwNTDMcEsCi.jpg'),
(94763, 6700, 'Febre do Ouro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBuGlf5yyM3GvoqIH9FX384Zxx1.jpg'),
(94764, 6700, 'Febre do Ouro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/saHSize9we7CAKOCmjXbQ3lzIKk.jpg'),
(94765, 6700, 'Febre do Ouro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x1FhnIjTxcladcWLPRGlClpwmSs.jpg'),
(94766, 6700, 'Febre do Ouro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/itVZzNwvaZ6J0Y1ERUNcbqlfIZI.jpg'),
(94767, 6700, 'Febre do Ouro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ugfPiMuKg5mFOwkjteGtNSS1SKI.jpg'),
(94768, 6700, 'Febre do Ouro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9gsW4hFlOA6is0VrCdM7WpVMSPL.jpg'),
(94769, 6700, 'Febre do Ouro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c3MR8bJ8ntUMtVSt06hwSKMiJ3O.jpg'),
(94770, 6700, 'Febre do Ouro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9pzqpjkQxl1IsyYN33Iv0sGpx9e.jpg'),
(94771, 6701, 'Febre do Ouro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aagqw91T6lJMPyLHOcQCrMRGG4v.jpg'),
(94772, 6701, 'Febre do Ouro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/biqXqguU26JpZDZqFj11QM5bcxq.jpg'),
(94773, 6701, 'Febre do Ouro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6MJqz49i64v2n3OVvacJWVT2Ty.jpg'),
(94774, 6701, 'Febre do Ouro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qXIiPVPzgAvrdmr8vI2C1Pd1zP7.jpg'),
(94775, 6701, 'Febre do Ouro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDqfQZLk5SD6hueTYiObMUdHpTi.jpg'),
(94776, 6701, 'Febre do Ouro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jVwCBIhCIcH3aO70fwQskuhzmaO.jpg'),
(94777, 6701, 'Febre do Ouro S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sMD51FXw195alPrAM1ODcqVRScS.jpg'),
(94778, 6701, 'Febre do Ouro S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dXiuaxA1vaPK6UBWG875XCVcZdk.jpg'),
(94779, 6701, 'Febre do Ouro S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cz3DdoB6KXdH0acOUxkkdtmeZnr.jpg'),
(94780, 6701, 'Febre do Ouro S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mSbjxI6wTypjPfj7U7KyxRSnUDh.jpg'),
(94781, 6701, 'Febre do Ouro S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5WWxOcVqF5KmWPFnfJLQVz6IDhd.jpg'),
(94782, 6701, 'Febre do Ouro S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hhM4ALuvMx8JzGPvAjiOZKk21D8.jpg'),
(94783, 6701, 'Febre do Ouro S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v4nEvyFdNftBhxUxDxCQIZUES6v.jpg'),
(94784, 6701, 'Febre do Ouro S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/230269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uE7TmMXp37V9gjBJd6Isxo5Mw6p.jpg'),
(94785, 6702, 'Febre do Ouro S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(94786, 6702, 'Febre do Ouro S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1H6oX8zKtgSxo4vyGTFg9n8YO9p.jpg'),
(94787, 6702, 'Febre do Ouro S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/roBskPhUmYMB9umVHCvKNd7BGBn.jpg'),
(94788, 6702, 'Febre do Ouro S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/igP5tkoRX1VDLjeqlBYhRNFBpo4.jpg'),
(94789, 6702, 'Febre do Ouro S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oCjLtnesVvKHrhlsQH52sn6FMeZ.jpg'),
(94790, 6702, 'Febre do Ouro S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7PBdQ8mZuF3PuTfCWkHOz7seaWp.jpg'),
(94791, 6702, 'Febre do Ouro S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qs8WB0tlwC6ugfxoBTOJ67sbjsZ.jpg'),
(94792, 6702, 'Febre do Ouro S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/CGHUIaYSuVmY7MlC60oBYVrG3x.jpg'),
(94793, 6702, 'Febre do Ouro S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ie80qo5NETL5eILGiwXosKNrka.jpg'),
(94794, 6702, 'Febre do Ouro S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTGROELmTirYnJJs1lCBFaFuYKF.jpg'),
(94795, 6702, 'Febre do Ouro S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/guKypSR5HTCl1J24XsjUUj49iYD.jpg'),
(94796, 6702, 'Febre do Ouro S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJqUVuA36qHpDABfna6j08f4Bwj.jpg'),
(94797, 6702, 'Febre do Ouro S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zQwr6BVrjKC2GbhUvmTTuop7LF6.jpg'),
(94798, 6702, 'Febre do Ouro S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/230283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nGB6BFuYpIFemfsKVJzb23Ub1d4.jpg'),
(94799, 6702, 'Febre do Ouro S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/230284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sazW0MwgN4QkeZYkDDTbT1P6YkF.jpg'),
(94800, 6702, 'Febre do Ouro S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/230285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oc6kQXtauLIv26f7N8V4JV3tTtm.jpg'),
(94801, 6703, 'Febre do Ouro S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHIHsw1YAB0EYisUgdcYDjeQSA1.jpg'),
(94802, 6703, 'Febre do Ouro S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7YaVeOpy4SWGZX7yTQctYFHb2Qs.jpg'),
(94803, 6703, 'Febre do Ouro S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yoKbwkG15ZIL9w51r55LdjLItYN.jpg'),
(94804, 6703, 'Febre do Ouro S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/99EufuKRY853TaQ6PQ15p7LbcLs.jpg'),
(94805, 6703, 'Febre do Ouro S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uOljdJJJBVWDwwgDHh5c4mI5R6u.jpg'),
(94806, 6703, 'Febre do Ouro S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cuZj1aBjkyzpNvMXvm9XOpORx82.jpg'),
(94807, 6703, 'Febre do Ouro S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w7gpBrffJg9mUKUeaF9VPVrzqPr.jpg'),
(94808, 6703, 'Febre do Ouro S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pbHA68RjzXEhYnHUdcNnsHsVndm.jpg'),
(94809, 6703, 'Febre do Ouro S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(94810, 6703, 'Febre do Ouro S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2k9V65V9Ef0IFZsENzS7WRRwjVZ.jpg'),
(94811, 6703, 'Febre do Ouro S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rgOW10YnVd5tiK7UTPzLy8UTWY1.jpg'),
(94812, 6703, 'Febre do Ouro S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZ7bzI9pFUDSTZHMaX6OTCAarHW.jpg'),
(94813, 6703, 'Febre do Ouro S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/veb7ku8NfjSKB3JUEWD1vVppFyH.jpg'),
(94814, 6703, 'Febre do Ouro S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/230299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bytXLrqkdN2feeSrZ6L6qT79XaA.jpg'),
(94815, 6703, 'Febre do Ouro S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/230300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i4tR4M9GKGwIrz1iZJoIsiTAWXV.jpg'),
(94816, 6703, 'Febre do Ouro S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/230301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dfW5jq7ggAGPlAUl6qqkwXLbp5x.jpg'),
(94817, 6703, 'Febre do Ouro S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/230302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m9cqOBLzuKSg3HyQkpbp54UOUd0.jpg'),
(94818, 6703, 'Febre do Ouro S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/230303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(94819, 6704, 'Febre do Ouro S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3I4D0LHm19D2x8Q2Vj1MJ9Rg2KH.jpg'),
(94820, 6704, 'Febre do Ouro S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p7UdZPV49WGUPVUqGI6qRL7wcJo.jpg'),
(94821, 6704, 'Febre do Ouro S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cwXIX3UvbV0tdidRMgkZCa0F51e.jpg'),
(94822, 6704, 'Febre do Ouro S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zECTKGpWJfKn2IvZCyJ3DJUlRYQ.jpg'),
(94823, 6704, 'Febre do Ouro S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sTDgbAFC1QDKrrDWg63WEWmzYHi.jpg'),
(94824, 6704, 'Febre do Ouro S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kprQgfpo8urkN15DKq03sViiDLD.jpg'),
(94825, 6704, 'Febre do Ouro S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tFOzbZ9p2GAXoQ2Wgr9JAgVk39E.jpg'),
(94826, 6704, 'Febre do Ouro S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/72lUGYD21JrGXMv102RSlLAJkKY.jpg'),
(94827, 6704, 'Febre do Ouro S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gllpUSTrrwzCjB2nYEUca9s2HEW.jpg'),
(94828, 6704, 'Febre do Ouro S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m1IhEQ6inMxIJzxSKGHAtr5zjQG.jpg'),
(94829, 6704, 'Febre do Ouro S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vTQ62V7s6ekxqO5y05H0kVq7dZb.jpg'),
(94830, 6704, 'Febre do Ouro S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zh8gfWpZKNL8M45y9S71uHKSULb.jpg'),
(94831, 6704, 'Febre do Ouro S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/84ZSZe92PJiLpF6z8zFQvRAE8mx.jpg'),
(94832, 6704, 'Febre do Ouro S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/230317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ouV0gioXqt8AIev4batXS3I19ku.jpg'),
(94833, 6704, 'Febre do Ouro S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/230318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qABwVomHfcaDCmf7LxijDCWutRr.jpg'),
(94834, 6704, 'Febre do Ouro S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/230319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s8lm16SgSaiLGgaPlfkdwjKVI8P.jpg'),
(94835, 6704, 'Febre do Ouro S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/230320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/satB3ULxCesLcvesDo3KNvjZT29.jpg'),
(94836, 6704, 'Febre do Ouro S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/230321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xAaZLNjuIWfxsbcfrpBCRMnBmoS.jpg'),
(94837, 6704, 'Febre do Ouro S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/230322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/56ljPs8isPNBbF840P3g0UgKiVS.jpg'),
(94838, 6705, 'Febre do Ouro S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s2UG6cXqPutcPAZssf5GtFOjN3P.jpg'),
(94839, 6705, 'Febre do Ouro S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zj5KsfGIEcgCvmFJLc3XwP6gbzo.jpg'),
(94840, 6705, 'Febre do Ouro S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6haowAI2CWUWmNWTRacZe07RR9z.jpg'),
(94841, 6705, 'Febre do Ouro S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7pSPXuYQuxl5I002K26SUNERUL1.jpg'),
(94842, 6705, 'Febre do Ouro S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/463dgoBqZwXfHXnEuxcT5wWzc8f.jpg'),
(94843, 6705, 'Febre do Ouro S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u2RRoKo53iOtUwoK1SrbMtxneAK.jpg'),
(94844, 6705, 'Febre do Ouro S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lIICg9dTTR5Yp9ZOgrxPgtEpmPo.jpg'),
(94845, 6705, 'Febre do Ouro S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/18F8r8NCSMurMo6vntUGsrxrfxE.jpg'),
(94846, 6705, 'Febre do Ouro S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9BwVgdYijynENdGppxyl8Xr1SRg.jpg'),
(94847, 6705, 'Febre do Ouro S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4nKGbTxV9tATi7ZBtHjVnnc3Nfu.jpg'),
(94848, 6705, 'Febre do Ouro S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pwEGNnKOcN6Oodx9zwi097JP5S4.jpg'),
(94849, 6705, 'Febre do Ouro S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8MfnEcRsGMfMg2ECWhW0ccmLOwd.jpg'),
(94850, 6705, 'Febre do Ouro S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ju8QMzRS2BIuGk4GmgDpguvbJIM.jpg'),
(94851, 6705, 'Febre do Ouro S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/230336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gzp6c5sLF59FfusqXPDyqUX8VLF.jpg'),
(94852, 6705, 'Febre do Ouro S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/230337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1TEInSylphIIituwxpBBHIfT1Sq.jpg'),
(94853, 6705, 'Febre do Ouro S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/230338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iubv7gRG0tLycqZtlqQxiboBTwV.jpg'),
(94854, 6705, 'Febre do Ouro S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/230339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wjcW7Ozudjtq2O1eOMS9vEbks0Y.jpg'),
(94855, 6705, 'Febre do Ouro S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/230340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(94856, 6705, 'Febre do Ouro S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/230341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xGoxf8VH0VPT5wavumQyvMRTPzP.jpg'),
(94857, 6706, 'Febre do Ouro S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6QIwBBXyXaGgnwyLW152khbSiyr.jpg'),
(94858, 6706, 'Febre do Ouro S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shaJBQ7FwA4CrNDyAqbyl8yNpn8.jpg'),
(94859, 6706, 'Febre do Ouro S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1upHEUt17rKllUUkbbvnoMv6l3Y.jpg'),
(94860, 6706, 'Febre do Ouro S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5GOgxRKdRP1GipuQ58rs3XKDdZn.jpg'),
(94861, 6706, 'Febre do Ouro S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qWUYmGNaZImvazyhUwQARWYazkK.jpg'),
(94862, 6706, 'Febre do Ouro S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oGo6zArCdEqWfk7Pf4g3TwnUMzK.jpg'),
(94863, 6706, 'Febre do Ouro S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4c7xQRH97luwTBIvccPYfw56j0z.jpg'),
(94864, 6706, 'Febre do Ouro S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1EGaKAovcm77wk0qS1huJVRWj88.jpg'),
(94865, 6706, 'Febre do Ouro S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nKz1wYOsdXJk4MZBgc1ioOC5l8n.jpg'),
(94866, 6706, 'Febre do Ouro S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJyy0vzFp2HfGsDTBk4zodPjjGX.jpg'),
(94867, 6706, 'Febre do Ouro S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tWoxuH6agaoe5WTYra2lD0xq98E.jpg'),
(94868, 6706, 'Febre do Ouro S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xCt03wHUxmm2aGT0qiqNaZ7F8iu.jpg'),
(94869, 6706, 'Febre do Ouro S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9swG5VL7FuCtpNzsvawqdGnGCUB.jpg'),
(94870, 6706, 'Febre do Ouro S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/230355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9WSErS451XiXyoYjepETZs1s9Rv.jpg'),
(94871, 6706, 'Febre do Ouro S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/230356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rk3Qw7wyEpF4bPm5P7nivowvybP.jpg'),
(94872, 6706, 'Febre do Ouro S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/230357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7GKcoSczo1LYtYe9rRR5VNEW7CC.jpg'),
(94873, 6706, 'Febre do Ouro S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/230358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fTL6dq3fAR6HMcPs7Uk6Jy7mzAD.jpg'),
(94874, 6706, 'Febre do Ouro S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/230359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7dmdeLuhQs4maT7SM0h9SuYUvDe.jpg'),
(94875, 6706, 'Febre do Ouro S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/230360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2smBjlHEmzDN0nUf4mPo3bHC1Yb.jpg'),
(94876, 6706, 'Febre do Ouro S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/230361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AcF4PUyB05LE6Dous139UATSSGq.jpg'),
(94877, 6706, 'Febre do Ouro S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/230362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hxrTcIrIQjTh0dKGjKL9juOrJvL.jpg'),
(94878, 6707, 'Febre do Ouro S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uytStXlIrriMEWKUVEDtRgdMrJj.jpg'),
(94879, 6707, 'Febre do Ouro S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hVxhJuLdHRcLWnSExuQPW6BubwA.jpg'),
(94880, 6707, 'Febre do Ouro S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hrYboAgt6ivqtmF0nVOgUPBOCeU.jpg'),
(94881, 6707, 'Febre do Ouro S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(94882, 6707, 'Febre do Ouro S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q5C8lsRlPXbg86gyoDL2t4KlvSq.jpg'),
(94883, 6707, 'Febre do Ouro S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xyqUtPd63S1rYCEuDh8b47WPCN5.jpg'),
(94884, 6707, 'Febre do Ouro S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fyBo6RjwqUMZBqf6tqjkRMaMMZM.jpg'),
(94885, 6707, 'Febre do Ouro S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJ5x83dX3Wulz8PkFkMkGgrJfQe.jpg'),
(94886, 6707, 'Febre do Ouro S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Abl4Tl1q5vhCGCCc7roaGbtJEpI.jpg'),
(94887, 6707, 'Febre do Ouro S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a3nUs9RTyMJwuBdCpWv0qDMvm9Z.jpg'),
(94888, 6707, 'Febre do Ouro S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s0SXesVwm2cvYBfzpyX90gAbEdz.jpg'),
(94889, 6707, 'Febre do Ouro S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oyRcaYSwKZS6VQXPSQQdAA8i7lS.jpg'),
(94890, 6707, 'Febre do Ouro S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wsFe8Xfq3MvgEsWTzonI1DccxnT.jpg'),
(94891, 6707, 'Febre do Ouro S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/230376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ObmdAHxxblhaWvapbahk3jp1P8.jpg'),
(94892, 6707, 'Febre do Ouro S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/230377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/guFRFW7f8281bupxYaUC3xp92bq.jpg'),
(94893, 6707, 'Febre do Ouro S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/230378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2aobzwLYo8OMobBf7y8OsxJfmKn.jpg'),
(94894, 6707, 'Febre do Ouro S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/230379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wKXaGK54B0icGkRYrlfk6OjsR6q.jpg'),
(94895, 6707, 'Febre do Ouro S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/230380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zKRn4DsTw6DT2vognznhK1C8tRT.jpg'),
(94896, 6707, 'Febre do Ouro S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/230381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z4qTAnFat1fkI754rlIZ3evGKrh.jpg'),
(94897, 6708, 'Febre do Ouro S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/815434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(94898, 6708, 'Febre do Ouro S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/815435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4BbvPO2MKjFicWYWiKxKyUAAxmA.jpg'),
(94899, 6708, 'Febre do Ouro S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/815436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iGIybx7Fqbn4QgTtW4svTYribOX.jpg'),
(94900, 6708, 'Febre do Ouro S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/815437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/HaHopwa0BIwiFy0gGE65LN6oO3.jpg'),
(94901, 6708, 'Febre do Ouro S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/815438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o8u59M2gxdRWZsLrYomjub1C6x.jpg'),
(94902, 6708, 'Febre do Ouro S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/815439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5akWWPrQgRBUzPMnCMOUTv2Xw45.jpg'),
(94903, 6708, 'Febre do Ouro S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/815440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bsiiAQyT462pKFJxwqLYHO30BZp.jpg'),
(94904, 6708, 'Febre do Ouro S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/815441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3qhWjYMRaP8kUWt7kFtPNS7AW3R.jpg'),
(94905, 6708, 'Febre do Ouro S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/815442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gY712JwuEemCmscKRKiUQg5uIBU.jpg'),
(94906, 6708, 'Febre do Ouro S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/815443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jCx6UeCwTOJihViuC3uAjEnV3Sy.jpg'),
(94907, 6708, 'Febre do Ouro S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/815444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kRkneNPoEahaOI7huPCsMuiLKQK.jpg'),
(94908, 6708, 'Febre do Ouro S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/815445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tG3guqVgyqLfzH4nhW1TG1ijDC.jpg'),
(94909, 6708, 'Febre do Ouro S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/815446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6fpwb2WftC6oaUPKbWI9njPtPTM.jpg'),
(94910, 6708, 'Febre do Ouro S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/815447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bagLi4V2fNR6ZPfwd7wygXFSiBH.jpg'),
(94911, 6708, 'Febre do Ouro S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/815448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Mfpx2w2MXRSjeDSZyuno63QJih.jpg'),
(94912, 6708, 'Febre do Ouro S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/815449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mlwZG9bw3iVZOZbRzfjMZZQ7YwB.jpg'),
(94913, 6708, 'Febre do Ouro S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/815450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9D15zbVvh4QfMYwmDauN1dK6e3j.jpg'),
(94914, 6708, 'Febre do Ouro S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/815451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Kwp2sEl5NeTtDZbGWjCLXe5ma0.jpg'),
(94915, 6708, 'Febre do Ouro S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/815452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX13Emso4XROn3SIeAFmZGiiOrm.jpg'),
(94916, 6708, 'Febre do Ouro S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/815453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ojib1cvuCWEyUdFaa566XENtxK5.jpg'),
(94917, 6708, 'Febre do Ouro S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/815454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jpubTlINuUOE8DkoUmtagqivF8v.jpg'),
(94918, 6708, 'Febre do Ouro S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/815455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xs5ExZ7B0gnRdRRDFkuRprYFdZy.jpg'),
(94919, 6709, 'Febre do Ouro S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3zAhDD1AMES8wmMfsHNPA21wn2c.jpg'),
(94920, 6709, 'Febre do Ouro S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gps0rL1Fo2GOO8DHiEf5S5WVOiV.jpg'),
(94921, 6709, 'Febre do Ouro S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6BvV2E06NZMOK3qgZMeqluSioRz.jpg'),
(94922, 6709, 'Febre do Ouro S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odN5VR2hP3EELTpP2QmxYcCAiXA.jpg'),
(94923, 6709, 'Febre do Ouro S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kA55oedHPc8pRIsWuht4Pg7khla.jpg'),
(94924, 6709, 'Febre do Ouro S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4z25szjmlGVLSMMu8PGuAgmQH1Z.jpg'),
(94925, 6709, 'Febre do Ouro S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ptGWHHKmNXkwnMeaY3RBM3Qk0C.jpg'),
(94926, 6709, 'Febre do Ouro S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h2FFXIGRrPPkw81DNWJvme5TtOg.jpg'),
(94927, 6709, 'Febre do Ouro S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ryo5sGQk0f30CKcOWvlW9TQ69Ck.jpg'),
(94928, 6709, 'Febre do Ouro S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b4ulFsysmsc8cMmebZ0rSuGO1Cx.jpg'),
(94929, 6709, 'Febre do Ouro S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n0cqwKJUPODVdPhKWBnLdE4zvUp.jpg'),
(94930, 6709, 'Febre do Ouro S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d30m3GbXzt9NctYLoXL0f5lOAnC.jpg'),
(94931, 6709, 'Febre do Ouro S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ubhc8iw0pvKTB82DBuBxpSmJ40R.jpg'),
(94932, 6709, 'Febre do Ouro S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/230395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tBQEi5excdFtUojpUSmzQ6ahF9x.jpg'),
(94933, 6709, 'Febre do Ouro S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/230396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ljEv2iPgZtFV8b9NaGUVhCKfGzz.jpg'),
(94934, 6709, 'Febre do Ouro S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/230397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bQcvoeZWiuF4rnP3Hxs1kwBph41.jpg'),
(94935, 6709, 'Febre do Ouro S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/230398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y5OjQhSAMye67qqrFq48eJz4klv.jpg'),
(94936, 6709, 'Febre do Ouro S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/230399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zQyIvadZ2lgQpJbCQEbtAujSoyM.jpg'),
(94937, 6709, 'Febre do Ouro S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/230400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wPh8wHOKAjykDId5rTTNjwZnB5z.jpg'),
(94938, 6709, 'Febre do Ouro S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/230401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5goJ4sJfMKSKq4IiN92gDWmiQF.jpg'),
(94939, 6709, 'Febre do Ouro S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/230402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dvmnjNoBJmRiYhPGeGADZYAePD3.jpg'),
(94940, 6710, 'Febre do Ouro S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p5TOT7uqVU6rcU7RsjeMy5SUWH4.jpg'),
(94941, 6710, 'Febre do Ouro S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eFC8Y4vexaLfx1aTtCMWy1isDj4.jpg'),
(94942, 6710, 'Febre do Ouro S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBumhOPfvX5eHxW50X3bo6I1Ljl.jpg'),
(94943, 6710, 'Febre do Ouro S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uCM24uKRB64515wC1LqWnoILWIq.jpg'),
(94944, 6710, 'Febre do Ouro S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fRamNxmNeeTEYvrr3pE73eogfkB.jpg'),
(94945, 6710, 'Febre do Ouro S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fgQKxOIVpJzQY27PCS5MDzsYKkA.jpg'),
(94946, 6710, 'Febre do Ouro S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hcOMSeUyoaQmVDfO7buMxTD4eNf.jpg'),
(94947, 6710, 'Febre do Ouro S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8SwV1IX6uUrtVN0BDf87MReBXHX.jpg'),
(94948, 6710, 'Febre do Ouro S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4srydXFAXleQHjp27gZtJk0fezS.jpg'),
(94949, 6710, 'Febre do Ouro S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dQPfg9NexZlvLn0DZusyEsk4kk5.jpg'),
(94950, 6710, 'Febre do Ouro S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qNtNRhY94lIile5bRLo9vcDdLWF.jpg'),
(94951, 6710, 'Febre do Ouro S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bGDaxKjLSu79hewr3tpiqjnNsvy.jpg'),
(94952, 6710, 'Febre do Ouro S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/burxg5hxL6FbrWIWJUkRaQKjShY.jpg'),
(94953, 6710, 'Febre do Ouro S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/230416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8CnculSg04YjgnC2S71k0ZVDFyt.jpg'),
(94954, 6710, 'Febre do Ouro S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/230417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/65u6eKbXRL4sFC3f2bPdKOfugci.jpg'),
(94955, 6710, 'Febre do Ouro S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/230418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lI5tQmbLQ7W3DCBc68Q8u9P5v75.jpg'),
(94956, 6710, 'Febre do Ouro S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/230419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ca5cvNiIiVtouXxJwt1dAfc73u8.jpg'),
(94957, 6710, 'Febre do Ouro S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/230420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p5ROBWsI9B6QNHc7WNX4uutktuU.jpg'),
(94958, 6710, 'Febre do Ouro S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/230421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zwwa9vX1phpheZ7cp48ZZFgn9Eh.jpg'),
(94959, 6710, 'Febre do Ouro S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/230422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AtELWtt15oyauQqMCYyPETMKZLA.jpg'),
(94960, 6710, 'Febre do Ouro S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/230423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mgyCTqqZxFKMH4sKVVIQc5QM0nd.jpg'),
(94961, 6711, 'Febre do Ouro S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ADUamhTyXWRJtlf59NJGVaJCaH.jpg'),
(94962, 6711, 'Febre do Ouro S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sH6H4FPWk0kKfll0F2fTm9UtVhm.jpg'),
(94963, 6711, 'Febre do Ouro S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vbZMH7hIxNjo5ts9A4DDLUOunq5.jpg'),
(94964, 6711, 'Febre do Ouro S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zRX1qgy0d6JjTl9hlb7sRRHNzE5.jpg'),
(94965, 6711, 'Febre do Ouro S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fFzffQUu3gWoGOTSuZpSgV2A3k8.jpg'),
(94966, 6711, 'Febre do Ouro S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/azaBlgjXkzZjA9jmw0ropaCkkSH.jpg'),
(94967, 6711, 'Febre do Ouro S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u7dpVoTSynYk8Tn3KNnPN1cGkt5.jpg'),
(94968, 6711, 'Febre do Ouro S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ujw3YkPL66CGJd0C0Sym8DjJof.jpg'),
(94969, 6711, 'Febre do Ouro S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qAvENTjOURMhmY5FSdMV1qdbUXy.jpg'),
(94970, 6711, 'Febre do Ouro S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wfIsze5qEHkIIijXTAQQe08ElNy.jpg'),
(94971, 6711, 'Febre do Ouro S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qOeXErRVf9EYJY1yMQTd2EzL2Gx.jpg'),
(94972, 6711, 'Febre do Ouro S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5ONPhdin6thfK5vjRROrOpPLFn.jpg'),
(94973, 6711, 'Febre do Ouro S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/evnTxQpSIkYgNWeSSu8QSIt2ClQ.jpg'),
(94974, 6711, 'Febre do Ouro S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/230437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vvoJCDmDp4wgyBCjaMix4W4pPzV.jpg'),
(94975, 6711, 'Febre do Ouro S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/230438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t6NxJRu9fCCoA45xNSEBGppC6KA.jpg'),
(94976, 6711, 'Febre do Ouro S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/230439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kQjvdS4XjFbXzSES8w7YNYACxsM.jpg'),
(94977, 6711, 'Febre do Ouro S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/230440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/galUcGTUpJ6nRJIK3dZHhAhY9MD.jpg'),
(94978, 6711, 'Febre do Ouro S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/230441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eHfTHPzb87rXyf2rGiBdG6VKv35.jpg'),
(94979, 6711, 'Febre do Ouro S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/230442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LdaZ5V5FViV3UBzCjxmFe56Vu1.jpg'),
(94980, 6711, 'Febre do Ouro S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/230443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6iwhazV6sSS6zjAxq1VhqG1giny.jpg'),
(94981, 6711, 'Febre do Ouro S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/230444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bBUhTEnYBoXbxa6W1oRTH3EAPQd.jpg'),
(94982, 6711, 'Febre do Ouro S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/230445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyR44M7F0Juri35mObzm527iesO.jpg'),
(94983, 6711, 'Febre do Ouro S12 E23', 'http://sinalprivado.info:80/series/1533784/1533784/230446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e9XfYxXHbr8VefNosNGq6zfYWul.jpg'),
(94984, 6711, 'Febre do Ouro S12 E24', 'http://sinalprivado.info:80/series/1533784/1533784/230447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uPXAiLSQeAAq16ulqt4kGA4ohUp.jpg'),
(94985, 6712, 'Febre do Ouro S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4OTajM2zbPhZAHLUD6eFy43V92p.jpg'),
(94986, 6712, 'Febre do Ouro S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5eLpuIuVNJuS4ehPFczHQIj3ivJ.jpg'),
(94987, 6712, 'Febre do Ouro S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aRJZJWlniUBSMnSPny8stkv6SB0.jpg'),
(94988, 6712, 'Febre do Ouro S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uK8RlpehZ3GZ66OdaqzDNHnj9rh.jpg'),
(94989, 6712, 'Febre do Ouro S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7gh1XCpW8KBQUUwUCfsxwJ3xZCq.jpg'),
(94990, 6712, 'Febre do Ouro S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pD5iFf3oZNUsIBMErOnoi0NLb92.jpg'),
(94991, 6712, 'Febre do Ouro S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lPt2sLmLLyRJNp6hoLiRiDH28iz.jpg'),
(94992, 6712, 'Febre do Ouro S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/grvZFKdurNUJvE8Pv6DvZiCBXCI.jpg'),
(94993, 6712, 'Febre do Ouro S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AokRp7kXN1CcWLT1AYaaSwbbOck.jpg'),
(94994, 6712, 'Febre do Ouro S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tIUlQ2o02yjZy9R4Q6zgijQ2ofj.jpg'),
(94995, 6712, 'Febre do Ouro S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFkBnD5jfvy2cvR1ejxDQUksVQr.jpg'),
(94996, 6712, 'Febre do Ouro S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lQwB89hERBjPENNp5bxR48QTpDe.jpg'),
(94997, 6712, 'Febre do Ouro S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tgchkZSY03A2v6SnkCUSZdfIcGo.jpg'),
(94998, 6712, 'Febre do Ouro S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/230461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvCaNdozZIgZHc64ufYNe5zr6WW.jpg'),
(94999, 6712, 'Febre do Ouro S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/230462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y1Un4YFafAEoCMFOXyFmLnGbYbK.jpg'),
(95000, 6712, 'Febre do Ouro S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/230463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95001, 6712, 'Febre do Ouro S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/230464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95002, 6712, 'Febre do Ouro S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/230465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95003, 6712, 'Febre do Ouro S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/230466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95004, 6712, 'Febre do Ouro S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/230467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95005, 6712, 'Febre do Ouro S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/230468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95006, 6712, 'Febre do Ouro S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/230469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95007, 6712, 'Febre do Ouro S13 E23', 'http://sinalprivado.info:80/series/1533784/1533784/230470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(95008, 6712, 'Febre do Ouro S13 E24', 'http://sinalprivado.info:80/series/1533784/1533784/230471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95009, 6712, 'Febre do Ouro S13 E25', 'http://sinalprivado.info:80/series/1533784/1533784/230472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95010, 6712, 'Febre do Ouro S13 E26', 'http://sinalprivado.info:80/series/1533784/1533784/230473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95011, 6713, 'Febre do Ouro S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/304947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95012, 6713, 'Febre do Ouro S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/310300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95013, 6713, 'Febre do Ouro S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/317956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95014, 6713, 'Febre do Ouro S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/324230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95015, 6713, 'Febre do Ouro S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/328144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95016, 6713, 'Febre do Ouro S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/332985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95017, 6713, 'Febre do Ouro S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/352485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95018, 6713, 'Febre do Ouro S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/352486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95019, 6713, 'Febre do Ouro S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/352487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95020, 6713, 'Febre do Ouro S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/784823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95021, 6713, 'Febre do Ouro S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/368664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95022, 6713, 'Febre do Ouro S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/378132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95023, 6713, 'Febre do Ouro S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/461224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95024, 6713, 'Febre do Ouro S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/461225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95025, 6713, 'Febre do Ouro S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/461226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95026, 6713, 'Febre do Ouro S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/461227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95027, 6713, 'Febre do Ouro S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/461228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95028, 6713, 'Febre do Ouro S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/461229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95029, 6713, 'Febre do Ouro S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/461230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95030, 6713, 'Febre do Ouro S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/474496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95031, 6713, 'Febre do Ouro S14 E21', 'http://sinalprivado.info:80/series/1533784/1533784/474497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95032, 6713, 'Febre do Ouro S14 E22', 'http://sinalprivado.info:80/series/1533784/1533784/478311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95033, 6713, 'Febre do Ouro S14 E23', 'http://sinalprivado.info:80/series/1533784/1533784/478312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95034, 6714, 'Febre do Ouro S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/734594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95035, 6714, 'Febre do Ouro S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/739065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95036, 6714, 'Febre do Ouro S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/752282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95037, 6714, 'Febre do Ouro S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/760891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95038, 6714, 'Febre do Ouro S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/767163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95039, 6714, 'Febre do Ouro S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/776665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95040, 6714, 'Febre do Ouro S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/784843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95041, 6714, 'Febre do Ouro S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/794689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95042, 6714, 'Febre do Ouro S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/798616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95043, 6714, 'Febre do Ouro S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/806168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95044, 6714, 'Febre do Ouro S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/860382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8vuDp0n773JsUF99aWwroEQRz3v.jpg'),
(95045, 6714, 'Febre do Ouro S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/880494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95046, 6714, 'Febre do Ouro S15 E13', 'http://sinalprivado.info:80/series/1533784/1533784/880885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95047, 6714, 'Febre do Ouro S15 E14', 'http://sinalprivado.info:80/series/1533784/1533784/881338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95048, 6714, 'Febre do Ouro S15 E15', 'http://sinalprivado.info:80/series/1533784/1533784/881339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95049, 6714, 'Febre do Ouro S15 E16', 'http://sinalprivado.info:80/series/1533784/1533784/882876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95050, 6714, 'Febre do Ouro S15 E17', 'http://sinalprivado.info:80/series/1533784/1533784/884067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95051, 6714, 'Febre do Ouro S15 E18', 'http://sinalprivado.info:80/series/1533784/1533784/885161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95052, 6714, 'Febre do Ouro S15 E19', 'http://sinalprivado.info:80/series/1533784/1533784/886261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95053, 6714, 'Febre do Ouro S15 E20', 'http://sinalprivado.info:80/series/1533784/1533784/888351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95054, 6714, 'Febre do Ouro S15 E21', 'http://sinalprivado.info:80/series/1533784/1533784/888352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95055, 6714, 'Febre do Ouro S15 E22', 'http://sinalprivado.info:80/series/1533784/1533784/889636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95056, 6714, 'Febre do Ouro S15 E23', 'http://sinalprivado.info:80/series/1533784/1533784/890114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yuqnhkvkTi15ypUzlKtfzDZDjka.jpg'),
(95057, 6715, '1899 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mx2KyBXAELVKZ3RezPwNqvuO2bk.jpg'),
(95058, 6715, '1899 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dmjMR2eykpUTPiJdZyhOsg5QwPW.jpg'),
(95059, 6715, '1899 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7fV80OdNrRUOanKuCPljlKoc2XV.jpg'),
(95060, 6715, '1899 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qrpSmKHoY5O7poSAjdjgMWXMt8I.jpg'),
(95061, 6715, '1899 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dB7UMBHWOSXVMJDTknZI5Veyb8s.jpg'),
(95062, 6715, '1899 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3wsmDnmOUWRkfBbH1FWgA6iPUjI.jpg'),
(95063, 6715, '1899 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3Evm7CxhaTxZAXkjm6Gj3ML2qr.jpg'),
(95064, 6715, '1899 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4gdW382UCMOjMKlfYi9XzCpHHZY.jpg'),
(95065, 6716, 'Bem-vindos ao Wrexham S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ctr4TtRPklGFt6BgczdlLpf8rnt.jpg'),
(95066, 6716, 'Bem-vindos ao Wrexham S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203393.mp4', 'http://image.tmdb.org/t/p/w1280/tioRWLPpwIP0DGPr3Xtx6Sx5EkS.jpg'),
(95067, 6716, 'Bem-vindos ao Wrexham S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203394.mp4', 'http://image.tmdb.org/t/p/w1280/dpDNATSXcSuDfucX77ftvGVhgM5.jpg'),
(95068, 6716, 'Bem-vindos ao Wrexham S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uHsJ2taHy6Yd19jGBkwPX6BOr8R.jpg'),
(95069, 6716, 'Bem-vindos ao Wrexham S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1SFbdCNMvszVq5fBr9aQ3ZMHcsa.jpg'),
(95070, 6716, 'Bem-vindos ao Wrexham S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ZOU72ERL57B7A7ZW5Std3KK5mc.jpg'),
(95071, 6716, 'Bem-vindos ao Wrexham S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4j4QrAdoh3fAIrKhbTyYsLIfLHA.jpg'),
(95072, 6716, 'Bem-vindos ao Wrexham S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQfNwmJUQa1FIBeiEVaz54rQcQP.jpg'),
(95073, 6716, 'Bem-vindos ao Wrexham S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ilQ5ih9bq1Sbas2MY1Ys3OnTyA5.jpg'),
(95074, 6716, 'Bem-vindos ao Wrexham S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dDvBA1NxFtXVHV2UJDxbHUWERXO.jpg'),
(95075, 6716, 'Bem-vindos ao Wrexham S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/203402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7AhuOXg7WimB0QkacrhRndwCwho.jpg'),
(95076, 6716, 'Bem-vindos ao Wrexham S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/203403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cIXsupRbTQOjPZ94QmIPCdfpy1K.jpg'),
(95077, 6716, 'Bem-vindos ao Wrexham S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/203404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xMWzVvB834R08Nez8F46FjhCCcu.jpg'),
(95078, 6716, 'Bem-vindos ao Wrexham S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/203405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1FB6DkVd8uGLyunPPgQWUjvoL2X.jpg'),
(95079, 6716, 'Bem-vindos ao Wrexham S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/203406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8EXP3bqTCi2FV9LchnvOG6SegXm.jpg'),
(95080, 6716, 'Bem-vindos ao Wrexham S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/203407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nMCRDec52PngGwBlI8upoXzD8z3.jpg'),
(95081, 6716, 'Bem-vindos ao Wrexham S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/203408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q65JzstgfXAJHuatmg3H9gTv0rK.jpg'),
(95082, 6717, 'Cheaters: Amor e Traição S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v9wOqAcfuzZCUijTkcms3ts7YUc.jpg'),
(95083, 6717, 'Cheaters: Amor e Traição S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nGTGSD4p9pOJd9pYMva69aCTxXj.jpg'),
(95084, 6717, 'Cheaters: Amor e Traição S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yBgtndiKZwLhbqByoCHWQivlB5w.jpg'),
(95085, 6717, 'Cheaters: Amor e Traição S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bMw8Sv09ReoXMeuu4jts8phvFxH.jpg'),
(95086, 6717, 'Cheaters: Amor e Traição S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xPpdaCKspMzVV7ppAcx3CiIXqnA.jpg'),
(95087, 6717, 'Cheaters: Amor e Traição S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8QiJBGwcnB5PU40maChkWfkMQw.jpg'),
(95088, 6718, 'Encantado\'s S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g33dGgj05E39xO24vX7UoW8EqFh.jpg'),
(95089, 6718, 'Encantado\'s S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q5j4fTwpNdIL3V5lQH6hedfp2Bn.jpg'),
(95090, 6718, 'Encantado\'s S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/poyBLbNhlwIQ8BQyOe42EBqGghG.jpg'),
(95091, 6718, 'Encantado\'s S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fCJz6Mt8sDXKaXyf1p92EshRpbx.jpg'),
(95092, 6718, 'Encantado\'s S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4suZaiUbrvWOqok7pLFZOuxN6pq.jpg'),
(95093, 6718, 'Encantado\'s S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oazvyHIdIKzfbgotKKaFZtkHf0x.jpg'),
(95094, 6718, 'Encantado\'s S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vR1ApdyB7y3GthNgfqnE61fpSyq.jpg'),
(95095, 6718, 'Encantado\'s S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/42XiO47E0pZicLP4dseobdCbFAy.jpg'),
(95096, 6718, 'Encantado\'s S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUSrZHdn0Lz0SWr3Lu7y14ieSOv.jpg'),
(95097, 6718, 'Encantado\'s S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fXmmjZmk8ybZde8vXkEmfQUMvge.jpg'),
(95098, 6718, 'Encantado\'s S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qVRdr3olQKD4AxF8COpSJ9AVckF.jpg'),
(95099, 6719, 'Encantado\'s S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/302804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95100, 6719, 'Encantado\'s S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/302805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95101, 6719, 'Encantado\'s S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/302806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95102, 6719, 'Encantado\'s S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/302807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95103, 6719, 'Encantado\'s S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/302808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95104, 6719, 'Encantado\'s S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/302809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95105, 6719, 'Encantado\'s S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/302810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95106, 6719, 'Encantado\'s S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/302811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95107, 6719, 'Encantado\'s S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/302812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95108, 6719, 'Encantado\'s S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/302813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95109, 6719, 'Encantado\'s S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/302814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95110, 6719, 'Encantado\'s S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/302815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95111, 6720, 'Encantado\'s S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/826058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95112, 6720, 'Encantado\'s S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/826059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95113, 6720, 'Encantado\'s S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/826060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95114, 6720, 'Encantado\'s S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/826061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95115, 6720, 'Encantado\'s S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/826062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95116, 6720, 'Encantado\'s S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/826063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95117, 6720, 'Encantado\'s S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/826064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95118, 6720, 'Encantado\'s S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/826065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95119, 6720, 'Encantado\'s S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/826066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95120, 6720, 'Encantado\'s S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/826067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95121, 6720, 'Encantado\'s S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/826068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95122, 6720, 'Encantado\'s S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/833920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uxShhlZoGEYiwcHKkPjp7UrokI.jpg'),
(95123, 6721, 'Etiqueta pelo Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wMGH6Kfdz5TRWFzlLjUDsa28tQB.jpg'),
(95124, 6721, 'Etiqueta pelo Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/86xp9ljakYeTrAyXkwa5K467QdO.jpg'),
(95125, 6721, 'Etiqueta pelo Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9tctqAlaPsTzMCqjkxYkqKI79BS.jpg'),
(95126, 6721, 'Etiqueta pelo Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bH1ZOkgrJTlN4l6SI2ZEWQnoj3F.jpg'),
(95127, 6721, 'Etiqueta pelo Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A7ssAxTmMnOZkdcsCwKnJo51p0u.jpg'),
(95128, 6721, 'Etiqueta pelo Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jKKysqCibytgs639fLX0ijLvT5c.jpg'),
(95129, 6722, 'Febre do Ouro: Família Hoffman S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4LsjqqNwW6kf1UkaEOYlVmhxrTP.jpg'),
(95130, 6722, 'Febre do Ouro: Família Hoffman S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dmKBHJpqtCfCb5hcmE5Tv5LHVPY.jpg'),
(95131, 6722, 'Febre do Ouro: Família Hoffman S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264927.mp4', 'http://image.tmdb.org/t/p/w1280/dC5fh4HGdy99AbXkUO9wK4vXw9d.jpg'),
(95132, 6722, 'Febre do Ouro: Família Hoffman S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o4WwRH9nVppsDdf2ayxISPj4am7.jpg'),
(95133, 6722, 'Febre do Ouro: Família Hoffman S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uEiNPIZSRKbcXv2RQowYnI76A0w.jpg'),
(95134, 6722, 'Febre do Ouro: Família Hoffman S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tncBLXaCxT4apou5Y7zwltqh7FT.jpg'),
(95135, 6722, 'Febre do Ouro: Família Hoffman S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bdZk5Td7dHGtX0BXuG3F4ESJzdo.jpg'),
(95136, 6722, 'Febre do Ouro: Família Hoffman S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zNIRv0nv9nlxe8GRge99EFnThfn.jpg'),
(95137, 6722, 'Febre do Ouro: Família Hoffman S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4jp7eIlIhf1ASBNqSda2Z5oTOtG.jpg'),
(95138, 6722, 'Febre do Ouro: Família Hoffman S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Nr1cHqdkUV5Q38DxBUlCN93AXZ.jpg'),
(95139, 6723, 'Febre do Ouro: Família Hoffman S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95140, 6723, 'Febre do Ouro: Família Hoffman S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95141, 6723, 'Febre do Ouro: Família Hoffman S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95142, 6723, 'Febre do Ouro: Família Hoffman S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95143, 6723, 'Febre do Ouro: Família Hoffman S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95144, 6723, 'Febre do Ouro: Família Hoffman S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95145, 6723, 'Febre do Ouro: Família Hoffman S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95146, 6723, 'Febre do Ouro: Família Hoffman S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95147, 6723, 'Febre do Ouro: Família Hoffman S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95148, 6723, 'Febre do Ouro: Família Hoffman S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95149, 6723, 'Febre do Ouro: Família Hoffman S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95150, 6723, 'Febre do Ouro: Família Hoffman S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95151, 6724, 'Febre do Ouro: Família Hoffman S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/464389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95152, 6724, 'Febre do Ouro: Família Hoffman S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/464390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95153, 6724, 'Febre do Ouro: Família Hoffman S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/464391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95154, 6724, 'Febre do Ouro: Família Hoffman S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/492833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95155, 6724, 'Febre do Ouro: Família Hoffman S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/492834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95156, 6724, 'Febre do Ouro: Família Hoffman S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/478340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95157, 6724, 'Febre do Ouro: Família Hoffman S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/485389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95158, 6724, 'Febre do Ouro: Família Hoffman S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/492837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95159, 6724, 'Febre do Ouro: Família Hoffman S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/496728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95160, 6724, 'Febre do Ouro: Família Hoffman S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/506140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95161, 6724, 'Febre do Ouro: Família Hoffman S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/509466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95162, 6724, 'Febre do Ouro: Família Hoffman S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/515550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzd9osrWmzhewBSsnwLbJu0lFQ2.jpg'),
(95163, 6725, 'Housing Complex C S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqSXuFaMYAM4XCSSFyRz3ge9LQ5.jpg'),
(95164, 6725, 'Housing Complex C S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzzqLutL1Ey64MpeRayfSHVXJhB.jpg'),
(95165, 6725, 'Housing Complex C S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v3SCPcuwziUA9H6G4Ph6AUBYwmJ.jpg'),
(95166, 6725, 'Housing Complex C S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7nwDexwUIQ8C7XwhNIvaZt6mykm.jpg'),
(95167, 6726, 'Identidade Fragmentada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rni5QZLwpoTGaldZ6BbsBR6wlh5.jpg'),
(95168, 6726, 'Identidade Fragmentada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6KeXzmP2KMbphq553mcwvjY8K1Z.jpg'),
(95169, 6726, 'Identidade Fragmentada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oPhC5WKFwGh5w7CwUanBVx4BwYb.jpg'),
(95170, 6726, 'Identidade Fragmentada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aoq7nqZBoIGabuIcoptzR0adlCm.jpg'),
(95171, 6726, 'Identidade Fragmentada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hlwiGWmFEVmlGoaTri73QWgGXdQ.jpg'),
(95172, 6726, 'Identidade Fragmentada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gf4iQAQD5QxORx4NdxFQkoDoBnm.jpg'),
(95173, 6726, 'Identidade Fragmentada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qomV57dD5NdYcGQBNR0u2J2wxlC.jpg'),
(95174, 6726, 'Identidade Fragmentada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vGpjjDJJHaDTZvgfb5HH4S7RVKU.jpg'),
(95175, 6726, 'Identidade Fragmentada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/27d9p8K5PVeapYIvUewnWLS45Jh.jpg'),
(95176, 6727, 'Amor: Verdade ou Consequência - Sardenha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nyJJSdRH1NOqGBN5odRRvTZoF2B.jpg'),
(95177, 6727, 'Amor: Verdade ou Consequência - Sardenha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nyJJSdRH1NOqGBN5odRRvTZoF2B.jpg'),
(95178, 6727, 'Amor: Verdade ou Consequência - Sardenha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nyJJSdRH1NOqGBN5odRRvTZoF2B.jpg'),
(95179, 6727, 'Amor: Verdade ou Consequência - Sardenha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nyJJSdRH1NOqGBN5odRRvTZoF2B.jpg'),
(95180, 6727, 'Amor: Verdade ou Consequência - Sardenha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nyJJSdRH1NOqGBN5odRRvTZoF2B.jpg'),
(95181, 6727, 'Amor: Verdade ou Consequência - Sardenha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nyJJSdRH1NOqGBN5odRRvTZoF2B.jpg'),
(95182, 6727, 'Amor: Verdade ou Consequência - Sardenha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nyJJSdRH1NOqGBN5odRRvTZoF2B.jpg'),
(95183, 6727, 'Amor: Verdade ou Consequência - Sardenha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nyJJSdRH1NOqGBN5odRRvTZoF2B.jpg'),
(95184, 6728, 'MasterChef+ S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbGTwwYOCSvBO7KgxqCxpMVhnfL.jpg'),
(95185, 6728, 'MasterChef+ S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/edEpl7lvLOT0Nnxy0B90Xu3HfnD.jpg'),
(95186, 6728, 'MasterChef+ S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/edEpl7lvLOT0Nnxy0B90Xu3HfnD.jpg'),
(95187, 6728, 'MasterChef+ S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/edEpl7lvLOT0Nnxy0B90Xu3HfnD.jpg'),
(95188, 6728, 'MasterChef+ S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/edEpl7lvLOT0Nnxy0B90Xu3HfnD.jpg'),
(95189, 6729, 'MasterChef+ S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/edEpl7lvLOT0Nnxy0B90Xu3HfnD.jpg'),
(95190, 6729, 'MasterChef+ S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/edEpl7lvLOT0Nnxy0B90Xu3HfnD.jpg'),
(95191, 6729, 'MasterChef+ S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/edEpl7lvLOT0Nnxy0B90Xu3HfnD.jpg'),
(95192, 6729, 'MasterChef+ S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/edEpl7lvLOT0Nnxy0B90Xu3HfnD.jpg'),
(95193, 6729, 'MasterChef+ S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/edEpl7lvLOT0Nnxy0B90Xu3HfnD.jpg'),
(95194, 6729, 'MasterChef+ S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/edEpl7lvLOT0Nnxy0B90Xu3HfnD.jpg'),
(95195, 6730, 'Mercado Ilegal com Mariana van Zeller S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ob6xQzk2rAcrwjWy7RJb51BUNbw.jpg'),
(95196, 6730, 'Mercado Ilegal com Mariana van Zeller S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oVoKATmAvjvvWoG4xefB9lKbUd3.jpg'),
(95197, 6730, 'Mercado Ilegal com Mariana van Zeller S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h4OXMYodmhXligGbP4TNIXoFTrs.jpg'),
(95198, 6730, 'Mercado Ilegal com Mariana van Zeller S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rPzWupX154wn5VLm1JeJrgUzUL8.jpg'),
(95199, 6730, 'Mercado Ilegal com Mariana van Zeller S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wc9lzRPMUy3XBJQWPPZlzdctcDl.jpg'),
(95200, 6730, 'Mercado Ilegal com Mariana van Zeller S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9KXfk6od8RyQ3Jb3eCghtOLrZE7.jpg'),
(95201, 6730, 'Mercado Ilegal com Mariana van Zeller S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iTtN1hks4B9DSCaA8UlAcT92GZW.jpg'),
(95202, 6730, 'Mercado Ilegal com Mariana van Zeller S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0MabDh39WD416zsWqVxzOtZP8X.jpg'),
(95203, 6731, 'Mercado Ilegal com Mariana van Zeller S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ve12MbPlOY7C6u3ujmzDP7p4gzg.jpg'),
(95204, 6731, 'Mercado Ilegal com Mariana van Zeller S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lyNcwZQoTjY4J3ZmoQ1CQIuCTAg.jpg'),
(95205, 6731, 'Mercado Ilegal com Mariana van Zeller S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQV273bCdsXMlCX1jVicMDaHIqV.jpg'),
(95206, 6731, 'Mercado Ilegal com Mariana van Zeller S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kMetpwdQiJArkh6Jx1W0aSMByte.jpg'),
(95207, 6731, 'Mercado Ilegal com Mariana van Zeller S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hEmHfOt1s1uYQmo13gzM5jg8GOx.jpg'),
(95208, 6731, 'Mercado Ilegal com Mariana van Zeller S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rd6NWlaCLxoM4TE1TZ2s17W7gQ3.jpg'),
(95209, 6731, 'Mercado Ilegal com Mariana van Zeller S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tu4nYaxxcYVeT5SwWUAu0NINSi2.jpg'),
(95210, 6731, 'Mercado Ilegal com Mariana van Zeller S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kgQPzyFepKMuCzUOlS05cERIfTe.jpg'),
(95211, 6731, 'Mercado Ilegal com Mariana van Zeller S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sPrU9AuSo1JkSBalqu5IGlFc0I7.jpg'),
(95212, 6731, 'Mercado Ilegal com Mariana van Zeller S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cy0uRkofDSLxRPQ2goivtrQo67O.jpg'),
(95213, 6732, 'Mercado Ilegal com Mariana van Zeller S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/54R1Bm9q5qb7FouO91JJaiyyAy2.jpg'),
(95214, 6732, 'Mercado Ilegal com Mariana van Zeller S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/54R1Bm9q5qb7FouO91JJaiyyAy2.jpg'),
(95215, 6732, 'Mercado Ilegal com Mariana van Zeller S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/54R1Bm9q5qb7FouO91JJaiyyAy2.jpg'),
(95216, 6732, 'Mercado Ilegal com Mariana van Zeller S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/54R1Bm9q5qb7FouO91JJaiyyAy2.jpg'),
(95217, 6732, 'Mercado Ilegal com Mariana van Zeller S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/54R1Bm9q5qb7FouO91JJaiyyAy2.jpg'),
(95218, 6732, 'Mercado Ilegal com Mariana van Zeller S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/54R1Bm9q5qb7FouO91JJaiyyAy2.jpg'),
(95219, 6732, 'Mercado Ilegal com Mariana van Zeller S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/54R1Bm9q5qb7FouO91JJaiyyAy2.jpg'),
(95220, 6732, 'Mercado Ilegal com Mariana van Zeller S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/54R1Bm9q5qb7FouO91JJaiyyAy2.jpg'),
(95221, 6732, 'Mercado Ilegal com Mariana van Zeller S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/54R1Bm9q5qb7FouO91JJaiyyAy2.jpg'),
(95222, 6732, 'Mercado Ilegal com Mariana van Zeller S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/54R1Bm9q5qb7FouO91JJaiyyAy2.jpg'),
(95223, 6733, 'Mercado Ilegal com Mariana van Zeller S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/878870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/54R1Bm9q5qb7FouO91JJaiyyAy2.jpg'),
(95224, 6733, 'Mercado Ilegal com Mariana van Zeller S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/878871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/54R1Bm9q5qb7FouO91JJaiyyAy2.jpg'),
(95225, 6733, 'Mercado Ilegal com Mariana van Zeller S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/878872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/54R1Bm9q5qb7FouO91JJaiyyAy2.jpg'),
(95226, 6733, 'Mercado Ilegal com Mariana van Zeller S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/878873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/54R1Bm9q5qb7FouO91JJaiyyAy2.jpg'),
(95227, 6733, 'Mercado Ilegal com Mariana van Zeller S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/878874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/54R1Bm9q5qb7FouO91JJaiyyAy2.jpg'),
(95228, 6733, 'Mercado Ilegal com Mariana van Zeller S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/878875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/54R1Bm9q5qb7FouO91JJaiyyAy2.jpg'),
(95229, 6733, 'Mercado Ilegal com Mariana van Zeller S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/878876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/54R1Bm9q5qb7FouO91JJaiyyAy2.jpg'),
(95230, 6733, 'Mercado Ilegal com Mariana van Zeller S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/878877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/54R1Bm9q5qb7FouO91JJaiyyAy2.jpg'),
(95231, 6733, 'Mercado Ilegal com Mariana van Zeller S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/878878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/54R1Bm9q5qb7FouO91JJaiyyAy2.jpg'),
(95232, 6733, 'Mercado Ilegal com Mariana van Zeller S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/878879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/54R1Bm9q5qb7FouO91JJaiyyAy2.jpg'),
(95233, 6734, 'Meu Encontro com o Mal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gzwrfgu3FRk6bR6RzmnKjOF15nJ.jpg'),
(95234, 6734, 'Meu Encontro com o Mal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rZSHy4mEIiI4vL6X6hk2FgrNNms.jpg'),
(95235, 6734, 'Meu Encontro com o Mal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yED6DCH7n5uidPZjzIeBF2tapho.jpg'),
(95236, 6734, 'Meu Encontro com o Mal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oWdWTCAOniD2CNwpsTsZXMPpRRe.jpg'),
(95237, 6735, 'Meu Papai (Ainda) é Noel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/swoegAFWQ75elz90QKtuOIkhKL2.jpg'),
(95238, 6735, 'Meu Papai (Ainda) é Noel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3J0NFwqjtJtvnAngIdvUbdIxTlJ.jpg'),
(95239, 6735, 'Meu Papai (Ainda) é Noel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248687.mp4', 'http://image.tmdb.org/t/p/w1280/6vPItDUdZiEax5Ii3Pdvb5g6GpZ.jpg'),
(95240, 6735, 'Meu Papai (Ainda) é Noel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248688.mp4', 'http://image.tmdb.org/t/p/w1280/xGO5vwe2GsrBrIZota9sX2X8rMQ.jpg'),
(95241, 6735, 'Meu Papai (Ainda) é Noel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248689.mp4', 'http://image.tmdb.org/t/p/w1280/qnuJqdaga8HgsT1pvN8kosbvppt.jpg'),
(95242, 6735, 'Meu Papai (Ainda) é Noel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248690.mp4', 'http://image.tmdb.org/t/p/w1280/xEkkVinHxjSOQsgIgug5JKqQm8s.jpg'),
(95243, 6736, 'Meu Papai (Ainda) é Noel S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5H3R3dCvEbXKNReT0SxU3dWBPhr.jpg'),
(95244, 6736, 'Meu Papai (Ainda) é Noel S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5H3R3dCvEbXKNReT0SxU3dWBPhr.jpg'),
(95245, 6736, 'Meu Papai (Ainda) é Noel S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5H3R3dCvEbXKNReT0SxU3dWBPhr.jpg'),
(95246, 6736, 'Meu Papai (Ainda) é Noel S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5H3R3dCvEbXKNReT0SxU3dWBPhr.jpg'),
(95247, 6736, 'Meu Papai (Ainda) é Noel S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5H3R3dCvEbXKNReT0SxU3dWBPhr.jpg'),
(95248, 6736, 'Meu Papai (Ainda) é Noel S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5H3R3dCvEbXKNReT0SxU3dWBPhr.jpg'),
(95249, 6737, 'Nasdrovia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5nTqmybm22R4fx4xmg1Cb0MQOyz.jpg'),
(95250, 6737, 'Nasdrovia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnZDwsPeEIf1JppapgdyUy1IFFp.jpg'),
(95251, 6737, 'Nasdrovia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4FA4cSo3Yyom1Gq8VQuqY4TuVi8.jpg'),
(95252, 6737, 'Nasdrovia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i7viZ7lBY6GMMOKUGeqT7aOUB83.jpg'),
(95253, 6737, 'Nasdrovia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wbk7EZP2kbrBZ9huPrfQqkBPFKc.jpg'),
(95254, 6737, 'Nasdrovia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ladGtSRm5tlq7CfzVUUdkcPGDLQ.jpg'),
(95255, 6738, 'Nasdrovia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vXPSoxaNGvjDXzWtmJZPWWKgfej.jpg'),
(95256, 6738, 'Nasdrovia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xpTsWRIbmz1ylN1F86RNYImatV9.jpg'),
(95257, 6738, 'Nasdrovia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hzxtinulj7QYU9AmHmovBgMbFfi.jpg'),
(95258, 6738, 'Nasdrovia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6QyONpqkPuSOtD0Bm6v8Av2DlFb.jpg'),
(95259, 6738, 'Nasdrovia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Rsxe3cOJhAI1NbAxPdnpoojlbB.jpg'),
(95260, 6738, 'Nasdrovia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AgM84L653tHLLk1j9t1dFmpUrZJ.jpg'),
(95261, 6739, 'Os Novos Filmes do Scooby-Doo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/azjjl18wQiW1yQE4iW20R434IdM.jpg'),
(95262, 6739, 'Os Novos Filmes do Scooby-Doo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bdONUamSgk070ntsE4fmBewHw5D.jpg'),
(95263, 6739, 'Os Novos Filmes do Scooby-Doo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1pezMPxRutqCgpO6Ozg4tPBQsBh.jpg'),
(95264, 6739, 'Os Novos Filmes do Scooby-Doo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dviMHb6hiH2TqIWKIFN28hLjY0C.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(95265, 6739, 'Os Novos Filmes do Scooby-Doo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7KiDw05nVdFnHyfwJOEYx3g7BFP.jpg'),
(95266, 6739, 'Os Novos Filmes do Scooby-Doo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wREs1KmIV6OXV6EuDk41R5jPlCw.jpg'),
(95267, 6739, 'Os Novos Filmes do Scooby-Doo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mjnkLhK222igDUXXEgdfgFC7EPD.jpg'),
(95268, 6739, 'Os Novos Filmes do Scooby-Doo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hX26lFa8F2p44xzVyx6zfjZk7br.jpg'),
(95269, 6739, 'Os Novos Filmes do Scooby-Doo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yMi8tlc6VCWAO5iZJ5KEt4slbx6.jpg'),
(95270, 6739, 'Os Novos Filmes do Scooby-Doo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/inReZPNsHQXyifXdrD0xGQNsAEx.jpg'),
(95271, 6739, 'Os Novos Filmes do Scooby-Doo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ahuDciltciOXhsblmaegeQAzh7s.jpg'),
(95272, 6739, 'Os Novos Filmes do Scooby-Doo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s9rsN8WQ9nSQQ1imEEcPrRJsDBp.jpg'),
(95273, 6739, 'Os Novos Filmes do Scooby-Doo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jfmlN2bw7QfYx1fqziRo2qEnFR9.jpg'),
(95274, 6739, 'Os Novos Filmes do Scooby-Doo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/201536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4eKOzR6EJA0KLlRMa7vZ1fjVaWz.jpg'),
(95275, 6739, 'Os Novos Filmes do Scooby-Doo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/201537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6LQFZHLIXLYzJEhvMEd2TOGVw7q.jpg'),
(95276, 6739, 'Os Novos Filmes do Scooby-Doo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/201538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKlPWMj8R9Uvdh1nXuaGkazX9iO.jpg'),
(95277, 6740, 'Os Novos Filmes do Scooby-Doo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/atrhaEQI3axlrCHNrfU2tGzRDvS.jpg'),
(95278, 6740, 'Os Novos Filmes do Scooby-Doo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9IZthyM3IgwOTrtfwlSpnECtiyu.jpg'),
(95279, 6740, 'Os Novos Filmes do Scooby-Doo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eTHqzwIkAzcxPUz85k63lQifsWj.jpg'),
(95280, 6740, 'Os Novos Filmes do Scooby-Doo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p0UE8tIeZCAKt30OiiwampLVLT9.jpg'),
(95281, 6740, 'Os Novos Filmes do Scooby-Doo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oCuuOh8DBlIKMtfb3L7JZxGkOcV.jpg'),
(95282, 6740, 'Os Novos Filmes do Scooby-Doo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nAbzNUtCUmdez1IvAF7IUmAmnY8.jpg'),
(95283, 6740, 'Os Novos Filmes do Scooby-Doo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lWMoT9b1TnLzMISUMUudcCuzGfn.jpg'),
(95284, 6740, 'Os Novos Filmes do Scooby-Doo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hsBIbdEdZqNJOmIEC6aNpzvwJ95.jpg'),
(95285, 6741, 'Cadê Meu Avião? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kY4J5Qo4QQpoeybqhsF9G4xqIS.jpg'),
(95286, 6741, 'Cadê Meu Avião? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/918JrdzCBdS5mq1SIsKGH611Re1.jpg'),
(95287, 6741, 'Cadê Meu Avião? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bNk2R7YwEs0ZI0aIaQptQKCd93g.jpg'),
(95288, 6741, 'Cadê Meu Avião? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7trJwBiaDBRSbvxiCCfD8HgjWsj.jpg'),
(95289, 6742, 'Reign Supreme S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVnbQr1kOaRJwu3l8cDNQB8ncXn.jpg'),
(95290, 6742, 'Reign Supreme S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/alFbDGRvePXoUh2R5Lgmq2aqXt5.jpg'),
(95291, 6742, 'Reign Supreme S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lsXBNfP5n507ffFdOL8Cffq6fKn.jpg'),
(95292, 6742, 'Reign Supreme S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pMtXELDhVj34isqZN1BOKs3M3y5.jpg'),
(95293, 6742, 'Reign Supreme S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Wo1dFBzsBu5SbFqhi9PbTO5vEU.jpg'),
(95294, 6742, 'Reign Supreme S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2tZF5C0axG43CSdhHbzCJSAyHmW.jpg'),
(95295, 6743, 'Sem Limites com Chris Hemsworth S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7gNX24yBpKRD4J1x9fTLIUfwYPP.jpg'),
(95296, 6743, 'Sem Limites com Chris Hemsworth S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4qFPulSwVuzAcr2cyyeB6wyWzTe.jpg'),
(95297, 6743, 'Sem Limites com Chris Hemsworth S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vY1Y9RToolTAg7NycxLonHeSIyd.jpg'),
(95298, 6743, 'Sem Limites com Chris Hemsworth S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kU03n4MKinL9ByiZxXsrCItSPOv.jpg'),
(95299, 6743, 'Sem Limites com Chris Hemsworth S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l9uVJB2nUhLFkeB4yvDbSbwgiZS.jpg'),
(95300, 6743, 'Sem Limites com Chris Hemsworth S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yuDy9dmubXH9agVTPV7KV2gEB5.jpg'),
(95301, 6744, 'Somebody S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aqaAfuiCbnD5tpVaxhKijEKCKWZ.jpg'),
(95302, 6744, 'Somebody S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aaqr1jAGSlYM0LJqIggPsMLR1uo.jpg'),
(95303, 6744, 'Somebody S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ja6niUdYKWH5IAgq2baIyuBIdux.jpg'),
(95304, 6744, 'Somebody S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8r7e2Teo4RAHXHdiY3NvxUJeJtD.jpg'),
(95305, 6744, 'Somebody S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l9U2mNgGwhj05SBY1a42EjT7gtu.jpg'),
(95306, 6744, 'Somebody S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vmuDAX5p7tn0CboTb9vTUJXBTKi.jpg'),
(95307, 6744, 'Somebody S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wNxBhyODgKJDgm61ntNbU49lqVH.jpg'),
(95308, 6744, 'Somebody S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qLQqhJgiZIaX4Grxcj7tQW8OnBr.jpg'),
(95309, 6745, 'SPY×FAMILY S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201487.mp4', 'http://timg.bdta.pro/images/2fe6d2c4fc0aba20161fb40bca8e766e.jpg'),
(95310, 6745, 'SPY×FAMILY S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201488.mp4', 'http://timg.bdta.pro/images/d1b82a541dfeb75b5e2c9eedeb4f2aa3.jpg'),
(95311, 6745, 'SPY×FAMILY S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201489.mp4', 'http://timg.bdta.pro/images/ae0527da82462359e2d235efb94c9883.jpg'),
(95312, 6745, 'SPY×FAMILY S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201490.mp4', 'http://timg.bdta.pro/images/44dc6f92b035b7e231f6d55e4b47f0c4.jpg'),
(95313, 6745, 'SPY×FAMILY S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201491.mp4', 'http://timg.bdta.pro/images/d6ba57e23055e3563e789b67b306462a.jpg'),
(95314, 6745, 'SPY×FAMILY S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201492.mp4', 'http://timg.bdta.pro/images/6e09bcbaa7486ec3182483e168299396.jpg'),
(95315, 6745, 'SPY×FAMILY S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201493.mp4', 'http://timg.bdta.pro/images/bdf73242a0fcf87e71a0d9c17fc45068.jpg'),
(95316, 6745, 'SPY×FAMILY S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201494.mp4', 'http://timg.bdta.pro/images/8405e8c30537b3053fa29584a92009e3.jpg'),
(95317, 6745, 'SPY×FAMILY S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201495.mp4', 'http://timg.bdta.pro/images/813eb653c525efaa20ea59821d6a3cf7.jpg'),
(95318, 6745, 'SPY×FAMILY S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201496.mp4', 'http://timg.bdta.pro/images/c8e6be7dd6e1a858226897a13d1a5bba.jpg'),
(95319, 6745, 'SPY×FAMILY S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201497.mp4', 'http://timg.bdta.pro/images/d0326d0678bbd6e58c30d820acc8b1d0.jpg'),
(95320, 6745, 'SPY×FAMILY S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201498.mp4', 'http://timg.bdta.pro/images/a87a42be6168dccbc2fbcd77162e036e.jpg'),
(95321, 6746, 'Teletubbies S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95322, 6746, 'Teletubbies S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95323, 6746, 'Teletubbies S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95324, 6746, 'Teletubbies S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95325, 6746, 'Teletubbies S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95326, 6746, 'Teletubbies S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95327, 6746, 'Teletubbies S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95328, 6746, 'Teletubbies S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95329, 6746, 'Teletubbies S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95330, 6746, 'Teletubbies S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95331, 6746, 'Teletubbies S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95332, 6746, 'Teletubbies S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95333, 6746, 'Teletubbies S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95334, 6746, 'Teletubbies S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/201474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95335, 6746, 'Teletubbies S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/201475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95336, 6746, 'Teletubbies S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/201476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95337, 6746, 'Teletubbies S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/201477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95338, 6746, 'Teletubbies S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/201478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95339, 6746, 'Teletubbies S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/201479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95340, 6746, 'Teletubbies S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/201480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95341, 6746, 'Teletubbies S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/201481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95342, 6746, 'Teletubbies S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/201482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95343, 6746, 'Teletubbies S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/201483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95344, 6746, 'Teletubbies S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/201484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95345, 6746, 'Teletubbies S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/201485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95346, 6746, 'Teletubbies S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/201486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqS1PhOHoYosFMsx7prPO3dHEZu.jpg'),
(95347, 6747, 'Um Trem para o Qatar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mXdCmc3e9cSdNv7JlXXDsHs2syQ.jpg'),
(95348, 6747, 'Um Trem para o Qatar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mXdCmc3e9cSdNv7JlXXDsHs2syQ.jpg'),
(95349, 6747, 'Um Trem para o Qatar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mXdCmc3e9cSdNv7JlXXDsHs2syQ.jpg'),
(95350, 6747, 'Um Trem para o Qatar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mXdCmc3e9cSdNv7JlXXDsHs2syQ.jpg'),
(95351, 6747, 'Um Trem para o Qatar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mXdCmc3e9cSdNv7JlXXDsHs2syQ.jpg'),
(95352, 6747, 'Um Trem para o Qatar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mXdCmc3e9cSdNv7JlXXDsHs2syQ.jpg'),
(95353, 6747, 'Um Trem para o Qatar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mXdCmc3e9cSdNv7JlXXDsHs2syQ.jpg'),
(95354, 6747, 'Um Trem para o Qatar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mXdCmc3e9cSdNv7JlXXDsHs2syQ.jpg'),
(95355, 6748, 'Papel de Rainha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5o3vSa1PK6YmVd9v1HrPhzvUGYt.jpg'),
(95356, 6748, 'Papel de Rainha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/opHbjf0rWp8KM2e4Y7AppfbiO2H.jpg'),
(95357, 6748, 'Papel de Rainha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wzOP915dCr1dCUZlwu90D9nWP62.jpg'),
(95358, 6748, 'Papel de Rainha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5e1ZUw4LSTZPQYhknwCwYRVtIHp.jpg'),
(95359, 6748, 'Papel de Rainha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/irD9PmxaIpS3QorfdTDrOaV16Qf.jpg'),
(95360, 6748, 'Papel de Rainha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cwqan0CdC28mmk7d1ZB20dljf6z.jpg'),
(95361, 6748, 'Papel de Rainha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kFM4EHp4E9NF6FJWIvdjLfXE4KD.jpg'),
(95362, 6748, 'Papel de Rainha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sngIywscc0XcDhkMpFZMJADUlub.jpg'),
(95363, 6748, 'Papel de Rainha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ylCWnZoebbbrX2LfwiHUj0KKMO.jpg'),
(95364, 6748, 'Papel de Rainha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gIKmcxTFGeAqqhAe8vqQI7aV79.jpg'),
(95365, 6748, 'Papel de Rainha S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g8hq5FjUpBZCFUcFXvZK9Csjo2e.jpg'),
(95366, 6748, 'Papel de Rainha S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6EMRPTJ6PydBWFiA6V13p3yGbF0.jpg'),
(95367, 6748, 'Papel de Rainha S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5HFzmhk8wKsSzzgg1hdlAGGbGN4.jpg'),
(95368, 6748, 'Papel de Rainha S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/201914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qSdn6iDZ1O2wdKX3DXtaIPtTFRq.jpg'),
(95369, 6748, 'Papel de Rainha S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/201915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rgjjoG6XVxQQPKDStjpszWyGKfA.jpg'),
(95370, 6748, 'Papel de Rainha S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/201916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bjzDlpD29kPvDeUy1hV3V87zCzI.jpg'),
(95371, 6749, 'Caçadores de Naufrágios Austrália S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q9XIh8R3Zn8dStBAB0TYqGPPApp.jpg'),
(95372, 6749, 'Caçadores de Naufrágios Austrália S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ZrNTl106Eiw59u1fuy5oFWgvQ5.jpg'),
(95373, 6749, 'Caçadores de Naufrágios Austrália S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yk7Fx0Sa9XayHqYVbTBLdfz8zgS.jpg'),
(95374, 6749, 'Caçadores de Naufrágios Austrália S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pLsr4nxoflVxsKxcnfWr66Xgh0o.jpg'),
(95375, 6749, 'Caçadores de Naufrágios Austrália S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rrGKSjAfURFQENkhUgRWwosGhFL.jpg'),
(95376, 6749, 'Caçadores de Naufrágios Austrália S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iaxKwHlsDgr9RYcqiSS2c2HeAjr.jpg'),
(95377, 6750, 'Jogos Copa do Mundo 2022 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200754.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95378, 6750, 'Jogos Copa do Mundo 2022 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200755.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95379, 6750, 'Jogos Copa do Mundo 2022 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200756.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95380, 6750, 'Jogos Copa do Mundo 2022 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200757.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95381, 6750, 'Jogos Copa do Mundo 2022 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200758.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95382, 6750, 'Jogos Copa do Mundo 2022 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200759.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95383, 6750, 'Jogos Copa do Mundo 2022 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200760.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95384, 6750, 'Jogos Copa do Mundo 2022 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200761.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95385, 6750, 'Jogos Copa do Mundo 2022 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200762.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95386, 6750, 'Jogos Copa do Mundo 2022 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200763.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95387, 6750, 'Jogos Copa do Mundo 2022 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200764.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95388, 6750, 'Jogos Copa do Mundo 2022 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200765.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95389, 6750, 'Jogos Copa do Mundo 2022 S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200766.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95390, 6750, 'Jogos Copa do Mundo 2022 S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/200767.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95391, 6750, 'Jogos Copa do Mundo 2022 S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/200768.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95392, 6750, 'Jogos Copa do Mundo 2022 S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/200769.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95393, 6750, 'Jogos Copa do Mundo 2022 S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/200770.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95394, 6750, 'Jogos Copa do Mundo 2022 S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/200771.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95395, 6750, 'Jogos Copa do Mundo 2022 S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/200772.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95396, 6750, 'Jogos Copa do Mundo 2022 S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/200773.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95397, 6750, 'Jogos Copa do Mundo 2022 S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/200774.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95398, 6750, 'Jogos Copa do Mundo 2022 S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/200775.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95399, 6750, 'Jogos Copa do Mundo 2022 S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/200776.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95400, 6750, 'Jogos Copa do Mundo 2022 S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/200777.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95401, 6750, 'Jogos Copa do Mundo 2022 S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/200778.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95402, 6750, 'Jogos Copa do Mundo 2022 S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/200779.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95403, 6750, 'Jogos Copa do Mundo 2022 S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/200780.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95404, 6750, 'Jogos Copa do Mundo 2022 S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/200781.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95405, 6750, 'Jogos Copa do Mundo 2022 S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/200782.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95406, 6750, 'Jogos Copa do Mundo 2022 S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/200783.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95407, 6750, 'Jogos Copa do Mundo 2022 S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/200784.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95408, 6750, 'Jogos Copa do Mundo 2022 S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/200785.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95409, 6750, 'Jogos Copa do Mundo 2022 S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/200786.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95410, 6750, 'Jogos Copa do Mundo 2022 S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/200787.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95411, 6750, 'Jogos Copa do Mundo 2022 S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/200788.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95412, 6750, 'Jogos Copa do Mundo 2022 S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/200789.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95413, 6750, 'Jogos Copa do Mundo 2022 S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/200790.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95414, 6750, 'Jogos Copa do Mundo 2022 S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/200791.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95415, 6750, 'Jogos Copa do Mundo 2022 S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/200792.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95416, 6750, 'Jogos Copa do Mundo 2022 S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/200793.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95417, 6750, 'Jogos Copa do Mundo 2022 S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/200794.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95418, 6750, 'Jogos Copa do Mundo 2022 S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/200795.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95419, 6750, 'Jogos Copa do Mundo 2022 S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/200796.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95420, 6750, 'Jogos Copa do Mundo 2022 S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/200797.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95421, 6750, 'Jogos Copa do Mundo 2022 S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/200798.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95422, 6750, 'Jogos Copa do Mundo 2022 S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/200799.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95423, 6750, 'Jogos Copa do Mundo 2022 S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/200800.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95424, 6750, 'Jogos Copa do Mundo 2022 S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/200801.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95425, 6750, 'Jogos Copa do Mundo 2022 S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/200802.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95426, 6750, 'Jogos Copa do Mundo 2022 S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/200803.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95427, 6750, 'Jogos Copa do Mundo 2022 S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/200804.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95428, 6750, 'Jogos Copa do Mundo 2022 S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/200805.mp4', 'https://i.bj-share.info/d27c087e85da1e99992b6ead7f35b473.png'),
(95429, 6751, 'Junior Bake off Brasil S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Dq0moDWAF9t0esrnNX2UT3jrSl.jpg'),
(95430, 6751, 'Junior Bake off Brasil S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Dq0moDWAF9t0esrnNX2UT3jrSl.jpg'),
(95431, 6751, 'Junior Bake off Brasil S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Dq0moDWAF9t0esrnNX2UT3jrSl.jpg'),
(95432, 6751, 'Junior Bake off Brasil S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Dq0moDWAF9t0esrnNX2UT3jrSl.jpg'),
(95433, 6751, 'Junior Bake off Brasil S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Dq0moDWAF9t0esrnNX2UT3jrSl.jpg'),
(95434, 6751, 'Junior Bake off Brasil S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Dq0moDWAF9t0esrnNX2UT3jrSl.jpg'),
(95435, 6751, 'Junior Bake off Brasil S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Dq0moDWAF9t0esrnNX2UT3jrSl.jpg'),
(95436, 6752, 'Até que se Prove o Contrário S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1N6CdBKZ48DzRsxoXXWwqtOsSoS.jpg'),
(95437, 6752, 'Até que se Prove o Contrário S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bn6nT3EUoh9Ubz2IO2uHzsoyWR8.jpg'),
(95438, 6752, 'Até que se Prove o Contrário S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1LSkejDCAD5LzyZyn6cwmKsY7TX.jpg'),
(95439, 6752, 'Até que se Prove o Contrário S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vZBCvk0hU97taYCaJppDaFOfYdw.jpg'),
(95440, 6752, 'Até que se Prove o Contrário S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zUtUlTJdyYQuH19608VppUo1ESM.jpg'),
(95441, 6752, 'Até que se Prove o Contrário S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mly4AflVpYJuwnOYzheYRG1FgJ3.jpg'),
(95442, 6752, 'Até que se Prove o Contrário S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sYqeauePmLNvJlq9fIZ0uzYiApE.jpg'),
(95443, 6752, 'Até que se Prove o Contrário S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dywUd2PIG2HXKMR55z7Tk7t3iN4.jpg'),
(95444, 6752, 'Até que se Prove o Contrário S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zWF5frlegBoOT7fCuDtBIetqjtG.jpg'),
(95445, 6753, 'Bem-Vindos ao Clube da Sedução S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/170uuuYHbJtBM5vAWJcSj3WKBzh.jpg'),
(95446, 6753, 'Bem-Vindos ao Clube da Sedução S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o3siYFpUOSWfXpY6qXXLjmCKWal.jpg'),
(95447, 6753, 'Bem-Vindos ao Clube da Sedução S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202581.mp4', 'http://image.tmdb.org/t/p/w1280/8quxMmuSiyeuoEVG6VjU3qIk4OV.jpg'),
(95448, 6753, 'Bem-Vindos ao Clube da Sedução S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202582.mp4', 'http://image.tmdb.org/t/p/w1280/heNIP73WgqFlGYNceVoFZVjPt8Y.jpg'),
(95449, 6753, 'Bem-Vindos ao Clube da Sedução S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202583.mp4', 'http://image.tmdb.org/t/p/w1280/eghUvXTvgXePt8naaCCtGWhYfHX.jpg'),
(95450, 6753, 'Bem-Vindos ao Clube da Sedução S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sw5hC0nxMXso7twIMNM0vXG7Svt.jpg'),
(95451, 6753, 'Bem-Vindos ao Clube da Sedução S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v4NZb7C1Xo1ZrHMd3BXjSO1ORLL.jpg'),
(95452, 6754, 'Capitães da América S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2fB9nLLesHxUlOhXtraH8ItD0Ah.jpg'),
(95453, 6754, 'Capitães da América S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2fB9nLLesHxUlOhXtraH8ItD0Ah.jpg'),
(95454, 6754, 'Capitães da América S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2fB9nLLesHxUlOhXtraH8ItD0Ah.jpg'),
(95455, 6754, 'Capitães da América S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2fB9nLLesHxUlOhXtraH8ItD0Ah.jpg'),
(95456, 6755, 'Echo 3 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCFSSUyPUgV4vDiD6GhbuCqIZ3Q.jpg'),
(95457, 6755, 'Echo 3 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1USmSmCFZFqzYhegDElNzoyZJH.jpg'),
(95458, 6755, 'Echo 3 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4zyPUf89l1juKTaqtKaziG9AxvW.jpg'),
(95459, 6755, 'Echo 3 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205540.mp4', 'http://image.tmdb.org/t/p/w1280/45oWx4v7VeIpgBGAT9J6iqDmxlW.jpg'),
(95460, 6755, 'Echo 3 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205541.mp4', 'http://image.tmdb.org/t/p/w1280/8QNWE3RgpTGCnSZ83WA9YSYHjS6.jpg'),
(95461, 6755, 'Echo 3 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205542.mp4', 'http://image.tmdb.org/t/p/w1280/oi7C9uUq8PZFYeeW2VMoMD9zx7y.jpg'),
(95462, 6755, 'Echo 3 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lXCD61CvnfJenqYVJGPKL9k331m.jpg'),
(95463, 6755, 'Echo 3 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bZXIutxdkMxeV10cCNVXD8O2vsT.jpg'),
(95464, 6755, 'Echo 3 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205545.mp4', 'http://image.tmdb.org/t/p/w1280/eburwyVkDEsm1aAZIO1cpr6p0zu.jpg'),
(95465, 6755, 'Echo 3 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205546.mp4', 'http://image.tmdb.org/t/p/w1280/3SQHO18c6urgQzRUn5hunX9XAPg.jpg'),
(95466, 6756, 'Enigmas do Universo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/umJGl9UqTtiICqsho7U3FK3O44y.jpg'),
(95467, 6756, 'Enigmas do Universo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhAMySMD9e7E9mocL4X4pUo5Y6H.jpg'),
(95468, 6756, 'Enigmas do Universo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/phRFVKxWM08VHpzYq3VJ916kHIt.jpg'),
(95469, 6756, 'Enigmas do Universo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y7uHothPVEz2UViIIRPSPpWKBLp.jpg'),
(95470, 6756, 'Enigmas do Universo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jlZMOEt0pouwe6Ooxp2FxoZH7AH.jpg'),
(95471, 6756, 'Enigmas do Universo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vohfpE8HkrhRqi0qF2vFOPsPzAw.jpg'),
(95472, 6757, 'First Love S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/afYeSp6a8cNzqe6RIbxLQPZukeS.jpg'),
(95473, 6757, 'First Love S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hYSKlWR0Xx3uNrCAG1lBjJjeGUl.jpg'),
(95474, 6757, 'First Love S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ghI6gwzLNQLyfHLTaJBe9Y3QqBB.jpg'),
(95475, 6757, 'First Love S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e7HZvUSkkCl9aY0LQZYLN8ehhgJ.jpg'),
(95476, 6757, 'First Love S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pYJP33IbsjpLvYhA5G0suGj4irF.jpg'),
(95477, 6757, 'First Love S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r8nK1yZgS6ONhAqpsa0eHErUfgP.jpg'),
(95478, 6757, 'First Love S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1QqgWz44Pd7wQ1Wy1SZGZZDYxrp.jpg'),
(95479, 6757, 'First Love S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8eKHXenDKDhHC4gEtbLBE6kWVR.jpg'),
(95480, 6757, 'First Love S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pcsesD9EWxkeNcyJE3Mn8oArwAO.jpg'),
(95481, 6758, 'Funk.Doc: Popular & Proibido S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ra2ZHRp5TUlsc5IJLyjatDVBbej.jpg'),
(95482, 6758, 'Funk.Doc: Popular & Proibido S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pBZKkVkpu6eLh9t1dEk6i8cDtHZ.jpg'),
(95483, 6758, 'Funk.Doc: Popular & Proibido S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a1XizO958bYhDeLX9N5xcqxXeNN.jpg'),
(95484, 6758, 'Funk.Doc: Popular & Proibido S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a1XizO958bYhDeLX9N5xcqxXeNN.jpg'),
(95485, 6758, 'Funk.Doc: Popular & Proibido S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a1XizO958bYhDeLX9N5xcqxXeNN.jpg'),
(95486, 6758, 'Funk.Doc: Popular & Proibido S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a1XizO958bYhDeLX9N5xcqxXeNN.jpg'),
(95487, 6759, 'O Último Grande Peixe S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wm4lryiNAtNNxFyvNaxvjiLyJol.jpg'),
(95488, 6759, 'O Último Grande Peixe S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m11UcXCbXKdRU3KuE4p6TF46Dhi.jpg'),
(95489, 6759, 'O Último Grande Peixe S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AqP1lPZ0eLqOUTxBcQ3Wo80h5fQ.jpg'),
(95490, 6759, 'O Último Grande Peixe S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pTRoOX2ZUIO5xsfEYKn6xWnMd3X.jpg'),
(95491, 6759, 'O Último Grande Peixe S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pTRoOX2ZUIO5xsfEYKn6xWnMd3X.jpg'),
(95492, 6759, 'O Último Grande Peixe S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pTRoOX2ZUIO5xsfEYKn6xWnMd3X.jpg'),
(95493, 6759, 'O Último Grande Peixe S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pTRoOX2ZUIO5xsfEYKn6xWnMd3X.jpg'),
(95494, 6759, 'O Último Grande Peixe S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pTRoOX2ZUIO5xsfEYKn6xWnMd3X.jpg'),
(95495, 6760, 'Operação Fronteira: Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u6BCM40wgguzeErxC03pCa7FZDU.jpg'),
(95496, 6760, 'Operação Fronteira: Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Jrsvxac8gRSCzYrRtGh9ydzuGF.jpg'),
(95497, 6760, 'Operação Fronteira: Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mH9MMneaZ6FqjjMPnhJ4wCZIG16.jpg'),
(95498, 6760, 'Operação Fronteira: Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eVNzctkRXJQbTVUN96pYvqJ2YuQ.jpg'),
(95499, 6760, 'Operação Fronteira: Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3N2Iyph4QAaYsPtPCgPRVyVMiyX.jpg'),
(95500, 6760, 'Operação Fronteira: Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ter7vR8QMdH1kC43TGtUrbur0S3.jpg'),
(95501, 6760, 'Operação Fronteira: Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jao1G8GtiSfMCD3T6IvR66WSGYd.jpg'),
(95502, 6760, 'Operação Fronteira: Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zDH4F8E3pvgox0YehpTD1Ta93zW.jpg'),
(95503, 6760, 'Operação Fronteira: Brasil S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gb7vuwDxJWTf2lbdQH70MLIQrLA.jpg'),
(95504, 6760, 'Operação Fronteira: Brasil S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2MOERYzX55nhrfw25UMzl4TaWDC.jpg'),
(95505, 6760, 'Operação Fronteira: Brasil S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246021.mp4', 'http://image.tmdb.org/t/p/w1280/2phpBmE9aQLLFc1sd98zW7obLPK.jpg'),
(95506, 6760, 'Operação Fronteira: Brasil S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246022.mp4', 'http://image.tmdb.org/t/p/w1280/z2St7MxFkAKX1jhLIuypfzbhOX2.jpg'),
(95507, 6760, 'Operação Fronteira: Brasil S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/246023.mp4', 'http://image.tmdb.org/t/p/w1280/kI2BhVYB1rqvG1Fd2VwXkV3jvAQ.jpg'),
(95508, 6760, 'Operação Fronteira: Brasil S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/246024.mp4', 'http://image.tmdb.org/t/p/w1280/1jTYeMuTSdFBcLYScsujTOyd3V.jpg'),
(95509, 6760, 'Operação Fronteira: Brasil S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/246025.mp4', 'http://image.tmdb.org/t/p/w1280/pzQFAqlUnXxIa5UuUdE40SixrnH.jpg'),
(95510, 6760, 'Operação Fronteira: Brasil S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/246026.mp4', 'http://image.tmdb.org/t/p/w1280/ujrbfXCFSaCZmqoIOpvBGrOd4VZ.jpg'),
(95511, 6760, 'Operação Fronteira: Brasil S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/246027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95512, 6760, 'Operação Fronteira: Brasil S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/246028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95513, 6760, 'Operação Fronteira: Brasil S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/246029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95514, 6760, 'Operação Fronteira: Brasil S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/246030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95515, 6761, 'Operação Fronteira: Brasil S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95516, 6761, 'Operação Fronteira: Brasil S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95517, 6761, 'Operação Fronteira: Brasil S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95518, 6761, 'Operação Fronteira: Brasil S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95519, 6761, 'Operação Fronteira: Brasil S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95520, 6761, 'Operação Fronteira: Brasil S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95521, 6761, 'Operação Fronteira: Brasil S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95522, 6761, 'Operação Fronteira: Brasil S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95523, 6761, 'Operação Fronteira: Brasil S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95524, 6761, 'Operação Fronteira: Brasil S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95525, 6761, 'Operação Fronteira: Brasil S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246041.mp4', 'http://image.tmdb.org/t/p/w1280/UUhtK7pVvp1htg4MwM38scIgYU.jpg'),
(95526, 6761, 'Operação Fronteira: Brasil S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95527, 6761, 'Operação Fronteira: Brasil S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/246043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95528, 6761, 'Operação Fronteira: Brasil S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/246044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95529, 6761, 'Operação Fronteira: Brasil S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/246045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(95530, 6761, 'Operação Fronteira: Brasil S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/246046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95531, 6761, 'Operação Fronteira: Brasil S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/246047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95532, 6761, 'Operação Fronteira: Brasil S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/246048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95533, 6761, 'Operação Fronteira: Brasil S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/246049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95534, 6761, 'Operação Fronteira: Brasil S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/246050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95535, 6761, 'Operação Fronteira: Brasil S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/246051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95536, 6761, 'Operação Fronteira: Brasil S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/246052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95537, 6762, 'Operação Fronteira: Brasil S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/295485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95538, 6762, 'Operação Fronteira: Brasil S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/301370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95539, 6762, 'Operação Fronteira: Brasil S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/301371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95540, 6762, 'Operação Fronteira: Brasil S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/307427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95541, 6762, 'Operação Fronteira: Brasil S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/307428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95542, 6762, 'Operação Fronteira: Brasil S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/312309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95543, 6762, 'Operação Fronteira: Brasil S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/312310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95544, 6762, 'Operação Fronteira: Brasil S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/321340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95545, 6762, 'Operação Fronteira: Brasil S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/321341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95546, 6762, 'Operação Fronteira: Brasil S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/325504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95547, 6762, 'Operação Fronteira: Brasil S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/325505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95548, 6762, 'Operação Fronteira: Brasil S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/376624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95549, 6762, 'Operação Fronteira: Brasil S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/376625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95550, 6762, 'Operação Fronteira: Brasil S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/387304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95551, 6762, 'Operação Fronteira: Brasil S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/387305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95552, 6762, 'Operação Fronteira: Brasil S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/391225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95553, 6762, 'Operação Fronteira: Brasil S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/391226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95554, 6762, 'Operação Fronteira: Brasil S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/394668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95555, 6762, 'Operação Fronteira: Brasil S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/394669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95556, 6762, 'Operação Fronteira: Brasil S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/401727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95557, 6762, 'Operação Fronteira: Brasil S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/401728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95558, 6762, 'Operação Fronteira: Brasil S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/407328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95559, 6763, 'Operação Fronteira: Brasil S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/701372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95560, 6763, 'Operação Fronteira: Brasil S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/701373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95561, 6763, 'Operação Fronteira: Brasil S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/701374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95562, 6763, 'Operação Fronteira: Brasil S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/713580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95563, 6763, 'Operação Fronteira: Brasil S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/713581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95564, 6763, 'Operação Fronteira: Brasil S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/717759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95565, 6763, 'Operação Fronteira: Brasil S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/717760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95566, 6763, 'Operação Fronteira: Brasil S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/724516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95567, 6763, 'Operação Fronteira: Brasil S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/724517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95568, 6763, 'Operação Fronteira: Brasil S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/731170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95569, 6763, 'Operação Fronteira: Brasil S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/731171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95570, 6763, 'Operação Fronteira: Brasil S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/865103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95571, 6763, 'Operação Fronteira: Brasil S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/865104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95572, 6763, 'Operação Fronteira: Brasil S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/865105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95573, 6763, 'Operação Fronteira: Brasil S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/870315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95574, 6763, 'Operação Fronteira: Brasil S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/870316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2MwFaPbKC9zBuTBCEQw3SIdVO9x.jpg'),
(95575, 6764, 'Os Segredos de Anna S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WEGK8pX2X6SRLyuGsiCWE9bsgT.jpg'),
(95576, 6764, 'Os Segredos de Anna S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WEGK8pX2X6SRLyuGsiCWE9bsgT.jpg'),
(95577, 6764, 'Os Segredos de Anna S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WEGK8pX2X6SRLyuGsiCWE9bsgT.jpg'),
(95578, 6764, 'Os Segredos de Anna S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WEGK8pX2X6SRLyuGsiCWE9bsgT.jpg'),
(95579, 6764, 'Os Segredos de Anna S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WEGK8pX2X6SRLyuGsiCWE9bsgT.jpg'),
(95580, 6764, 'Os Segredos de Anna S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WEGK8pX2X6SRLyuGsiCWE9bsgT.jpg'),
(95581, 6764, 'Os Segredos de Anna S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WEGK8pX2X6SRLyuGsiCWE9bsgT.jpg'),
(95582, 6764, 'Os Segredos de Anna S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WEGK8pX2X6SRLyuGsiCWE9bsgT.jpg'),
(95583, 6764, 'Os Segredos de Anna S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WEGK8pX2X6SRLyuGsiCWE9bsgT.jpg'),
(95584, 6764, 'Os Segredos de Anna S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WEGK8pX2X6SRLyuGsiCWE9bsgT.jpg'),
(95585, 6764, 'Os Segredos de Anna S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WEGK8pX2X6SRLyuGsiCWE9bsgT.jpg'),
(95586, 6764, 'Os Segredos de Anna S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WEGK8pX2X6SRLyuGsiCWE9bsgT.jpg'),
(95587, 6765, 'Perícia Lab S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uTgsu2Ct1IgY1V28ttlKlHP9hhB.jpg'),
(95588, 6765, 'Perícia Lab S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uTgsu2Ct1IgY1V28ttlKlHP9hhB.jpg'),
(95589, 6765, 'Perícia Lab S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uTgsu2Ct1IgY1V28ttlKlHP9hhB.jpg'),
(95590, 6765, 'Perícia Lab S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uTgsu2Ct1IgY1V28ttlKlHP9hhB.jpg'),
(95591, 6765, 'Perícia Lab S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uTgsu2Ct1IgY1V28ttlKlHP9hhB.jpg'),
(95592, 6765, 'Perícia Lab S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/565518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uTgsu2Ct1IgY1V28ttlKlHP9hhB.jpg'),
(95593, 6765, 'Perícia Lab S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uTgsu2Ct1IgY1V28ttlKlHP9hhB.jpg'),
(95594, 6765, 'Perícia Lab S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uTgsu2Ct1IgY1V28ttlKlHP9hhB.jpg'),
(95595, 6765, 'Perícia Lab S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uTgsu2Ct1IgY1V28ttlKlHP9hhB.jpg'),
(95596, 6766, 'Sangue & Realeza S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d2cfGNrTvLfOFNrA3lgliZ7L2UZ.jpg'),
(95597, 6766, 'Sangue & Realeza S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/61xE79bu77KVsjALsNii2ZcSWUH.jpg'),
(95598, 6766, 'Sangue & Realeza S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hGGQzgIhuNO6ttL2iYdAfACXAUA.jpg'),
(95599, 6767, 'StoryBots: Hora da Resposta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mnegNlapnoGc0IsDPSKqwVzyi4G.jpg'),
(95600, 6767, 'StoryBots: Hora da Resposta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bPEMR20El4tdfHrm207eGSDro01.jpg'),
(95601, 6767, 'StoryBots: Hora da Resposta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0KHtL9uIHzBZJuIlRFVLJPoLGU.jpg'),
(95602, 6767, 'StoryBots: Hora da Resposta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2yx3BMwwYdvNBrRgjrs35oEnU7A.jpg'),
(95603, 6767, 'StoryBots: Hora da Resposta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7bK69EJvwJxWDFJxblwcD4C9DDx.jpg'),
(95604, 6767, 'StoryBots: Hora da Resposta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ECEKHctFEDJPxnIVXSXHudPkmm.jpg'),
(95605, 6767, 'StoryBots: Hora da Resposta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v5FICHO6osF3hkvitHBkqArlXlC.jpg'),
(95606, 6767, 'StoryBots: Hora da Resposta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yJtxIpC15kc55V2yWRFTXjrPEyC.jpg'),
(95607, 6767, 'StoryBots: Hora da Resposta S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ysoyR7fiiiMAYdlGfuaj4mwwuMQ.jpg'),
(95608, 6767, 'StoryBots: Hora da Resposta S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/GNAilBpkREoJPoMU75Czo1GL7g.jpg'),
(95609, 6768, 'StoryBots: Hora da Resposta S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ccMq0WNCvgq1GitFrBRbJ3BTzet.jpg'),
(95610, 6768, 'StoryBots: Hora da Resposta S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ccMq0WNCvgq1GitFrBRbJ3BTzet.jpg'),
(95611, 6768, 'StoryBots: Hora da Resposta S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ccMq0WNCvgq1GitFrBRbJ3BTzet.jpg'),
(95612, 6768, 'StoryBots: Hora da Resposta S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ccMq0WNCvgq1GitFrBRbJ3BTzet.jpg'),
(95613, 6768, 'StoryBots: Hora da Resposta S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ccMq0WNCvgq1GitFrBRbJ3BTzet.jpg'),
(95614, 6768, 'StoryBots: Hora da Resposta S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ccMq0WNCvgq1GitFrBRbJ3BTzet.jpg'),
(95615, 6768, 'StoryBots: Hora da Resposta S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ccMq0WNCvgq1GitFrBRbJ3BTzet.jpg'),
(95616, 6768, 'StoryBots: Hora da Resposta S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ccMq0WNCvgq1GitFrBRbJ3BTzet.jpg'),
(95617, 6768, 'StoryBots: Hora da Resposta S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ccMq0WNCvgq1GitFrBRbJ3BTzet.jpg'),
(95618, 6768, 'StoryBots: Hora da Resposta S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ccMq0WNCvgq1GitFrBRbJ3BTzet.jpg'),
(95619, 6768, 'StoryBots: Hora da Resposta S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ccMq0WNCvgq1GitFrBRbJ3BTzet.jpg'),
(95620, 6768, 'StoryBots: Hora da Resposta S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ccMq0WNCvgq1GitFrBRbJ3BTzet.jpg'),
(95621, 6769, 'Wandinha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vaoNDFmj7DQH7PpAy9YWgLVylPP.jpg'),
(95622, 6769, 'Wandinha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i9MLXA6C5VSpRSHzXEd2uHlj4pA.jpg'),
(95623, 6769, 'Wandinha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yikI4l7vKK4LkfFEIa5dXaqO97s.jpg'),
(95624, 6769, 'Wandinha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wV2de1W3td4zxaW97HATfktHjfd.jpg'),
(95625, 6769, 'Wandinha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3Tx4CXDhzOV103TuTwz461EdjF.jpg'),
(95626, 6769, 'Wandinha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cPHlYQ00832jS7IDqfHS7RWTz2k.jpg'),
(95627, 6769, 'Wandinha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aEmccS7KyFPQMAnuQ2C5sbyn5fc.jpg'),
(95628, 6769, 'Wandinha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3b42P1FuxWC9JXVIfnKAUUuq0zP.jpg'),
(95629, 6770, 'Wandinha S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/879914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctI52NGXwDluCmAY9kOLqGg9hb5.jpg'),
(95630, 6770, 'Wandinha S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/879915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctI52NGXwDluCmAY9kOLqGg9hb5.jpg'),
(95631, 6770, 'Wandinha S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/879916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctI52NGXwDluCmAY9kOLqGg9hb5.jpg'),
(95632, 6770, 'Wandinha S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/879917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctI52NGXwDluCmAY9kOLqGg9hb5.jpg'),
(95633, 6770, 'Wandinha S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/882189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctI52NGXwDluCmAY9kOLqGg9hb5.jpg'),
(95634, 6770, 'Wandinha S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/882190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctI52NGXwDluCmAY9kOLqGg9hb5.jpg'),
(95635, 6770, 'Wandinha S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/882191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctI52NGXwDluCmAY9kOLqGg9hb5.jpg'),
(95636, 6770, 'Wandinha S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/882192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctI52NGXwDluCmAY9kOLqGg9hb5.jpg'),
(95637, 6771, 'Amigas para Sempre S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xk9jwQ1bkh6SQ8dkM5rKZkfzwZv.jpg'),
(95638, 6771, 'Amigas para Sempre S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a7djtnQhn3dV1b53afdlaX9c7XG.jpg'),
(95639, 6771, 'Amigas para Sempre S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qsiPrhxHIGrKdIGwiidm572npyp.jpg'),
(95640, 6771, 'Amigas para Sempre S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i9eEMb1ux5bJm9ZpWBPdbu33aFI.jpg'),
(95641, 6771, 'Amigas para Sempre S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nQLD0itWjIlEiWSyrbPUl5WOmRW.jpg'),
(95642, 6771, 'Amigas para Sempre S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8rSPsskuHeFHc0HVqcuaKrEN5DD.jpg'),
(95643, 6771, 'Amigas para Sempre S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qGFrgcZ9fka70c6vlyQvNJ1ZcNc.jpg'),
(95644, 6771, 'Amigas para Sempre S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wad1d2zo9yn3sHdDrT9iN8HsyYF.jpg'),
(95645, 6771, 'Amigas para Sempre S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i941J4TTZITfQbE0kgUJNjUyXFc.jpg'),
(95646, 6771, 'Amigas para Sempre S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gYQNsTdO334aCWFRh1yH6ecaM9E.jpg'),
(95647, 6772, 'Amigas para Sempre S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lFXoHCJl5VjrJpSOjUyabtSbGdc.jpg'),
(95648, 6772, 'Amigas para Sempre S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nwTvq2nswAduH6OlO42wS8Dvcd2.jpg'),
(95649, 6772, 'Amigas para Sempre S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dh6Ys69zIpYWvF2T5KyrN57QY57.jpg'),
(95650, 6772, 'Amigas para Sempre S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hmzdoBiPD7fVC9QwuEtpHLhRdKw.jpg'),
(95651, 6772, 'Amigas para Sempre S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2jAVR3lBkFzFtby3yaWm2pTRBgM.jpg'),
(95652, 6772, 'Amigas para Sempre S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e8mgUACAbgMtOx5eJsTqXjRWJi6.jpg'),
(95653, 6772, 'Amigas para Sempre S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rtHV7KyfAn9KoOStFg971eM0YhI.jpg'),
(95654, 6772, 'Amigas para Sempre S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/phLcjDDgXnDLLRxkdc0odi8gdEf.jpg'),
(95655, 6772, 'Amigas para Sempre S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBMOxEyWeqd8T0vBki4s7ACQPXI.jpg'),
(95656, 6772, 'Amigas para Sempre S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/25rFAWNJ8ApKD8tJqspSvnsRUk.jpg'),
(95657, 6772, 'Amigas para Sempre S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/229563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oZR4X6au6LyZnFMRbG02xxjrg2s.jpg'),
(95658, 6772, 'Amigas para Sempre S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/229564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9IaGR47n0fKCLoIiiupoJEr5lZ3.jpg'),
(95659, 6772, 'Amigas para Sempre S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/229565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1RwO9eGXZvfxtiMcLSCBym3Aixs.jpg'),
(95660, 6772, 'Amigas para Sempre S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/229566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/groCdB5JKPrX7NmZOyyz7KNHOJd.jpg'),
(95661, 6772, 'Amigas para Sempre S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/229567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ypy5jvxt4aPyuXUDc71ZDSWImiP.jpg'),
(95662, 6772, 'Amigas para Sempre S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/229568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aP8IHaL6WlnD4KwvCmbj1MJHi08.jpg'),
(95663, 6773, 'Cabeça Quente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sRQoVTTasNwxqb9yFOtLUHuYtgL.jpg'),
(95664, 6773, 'Cabeça Quente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cs5nP5Ho87evVSk4RTTlhRsrlAg.jpg'),
(95665, 6773, 'Cabeça Quente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yX3617umxkgLhGKXRSuSlCidp58.jpg'),
(95666, 6773, 'Cabeça Quente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o7K5xhFjJVxNDb64jWWgwXqnjNM.jpg'),
(95667, 6773, 'Cabeça Quente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nQXKAqWsKQG5mYmZ0Dk5DgJvQx.jpg'),
(95668, 6773, 'Cabeça Quente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/voZYtRoUBxO6TBYMXj1iixDnC7C.jpg'),
(95669, 6773, 'Cabeça Quente S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dVwU12iJHRRKQV7c7eEDnYMmbrP.jpg'),
(95670, 6773, 'Cabeça Quente S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/epU8MDBgkGmmOKEd54PynKoUXic.jpg'),
(95671, 6774, 'Cena do Crime: O Campo da Morte no Texas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2YXJ7MkugI2OzV9Ek9hjFiT7lMj.jpg'),
(95672, 6774, 'Cena do Crime: O Campo da Morte no Texas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5L2qQ8R5t4DE4PIrC4iZGUfgj3H.jpg'),
(95673, 6774, 'Cena do Crime: O Campo da Morte no Texas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d7lcumhD5BLjV5sCYwqF93MMJDH.jpg'),
(95674, 6775, 'o Caçador de Magia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1y8CQVXaO5FZsmig6caKqDqUcdU.jpg'),
(95675, 6775, 'o Caçador de Magia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xWpngyMtcbKQ0QTqHNkooc0IQBW.jpg'),
(95676, 6775, 'o Caçador de Magia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jWXCS5yVZRYe7bfadgzba21q40Z.jpg'),
(95677, 6775, 'o Caçador de Magia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/318pCkVvbQfKSN7pyXrNNUkA6sv.jpg'),
(95678, 6775, 'o Caçador de Magia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xigW6SGeXI5C6zWNhEbpY1haQVu.jpg'),
(95679, 6775, 'o Caçador de Magia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m9lnaRs7lQ44hQfJN7PQxt6TOwb.jpg'),
(95680, 6775, 'o Caçador de Magia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOxffDRI3DMemzNVbi1LhLXuVmM.jpg'),
(95681, 6775, 'o Caçador de Magia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4kb047uoCKR7niojGJ7NDpMTkgf.jpg'),
(95682, 6775, 'o Caçador de Magia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cjxTIsQBuy0pllZAGsSLOWMTaSP.jpg'),
(95683, 6775, 'o Caçador de Magia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7xLz6sNiyfJawWhcoTXmJ155Ac.jpg'),
(95684, 6776, 'Estrada sem Saída S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3wZVLUCAySi2y9uUqOP8tfNxEEo.jpg'),
(95685, 6776, 'Estrada sem Saída S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h4bBiukINfCcSg2XS6K4OPYS813.jpg'),
(95686, 6776, 'Estrada sem Saída S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/64tlCIDCd5iBcmR9IPTExMDtCBy.jpg'),
(95687, 6776, 'Estrada sem Saída S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vkQf7p2gKo1aRiP7Pa30HzltKO4.jpg'),
(95688, 6776, 'Estrada sem Saída S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eKDgTcHVcB12gWu61mhsQcnPYp2.jpg'),
(95689, 6776, 'Estrada sem Saída S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7R5D86VqddJlhIxRoAn3JU680nC.jpg'),
(95690, 6777, 'Minha Vida Nada Ortodoxa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8J8DSr1Y4qKLdEWKuv4HqOMLK4X.jpg'),
(95691, 6777, 'Minha Vida Nada Ortodoxa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nl4LwIOy517ao9IumkextzH3cdi.jpg'),
(95692, 6777, 'Minha Vida Nada Ortodoxa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hhzAU1XwyNakzn6ONgyPmIV4trm.jpg'),
(95693, 6777, 'Minha Vida Nada Ortodoxa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qTUarhs183hkHEe3xEWR3qahtsz.jpg'),
(95694, 6777, 'Minha Vida Nada Ortodoxa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nA1IUrRUHma2EGa2YVFNsuNYSCs.jpg'),
(95695, 6777, 'Minha Vida Nada Ortodoxa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gaUeybbN2knlT1YgGe2kuKZQOVQ.jpg'),
(95696, 6777, 'Minha Vida Nada Ortodoxa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/igAWk1OXCotBrjf9Zh0F2ukIqMP.jpg'),
(95697, 6777, 'Minha Vida Nada Ortodoxa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zeTukPkm7Y6jWgMCSiOuSVcYU37.jpg'),
(95698, 6777, 'Minha Vida Nada Ortodoxa S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHAPUocH7H5d99e9GoKvz9Hcmip.jpg'),
(95699, 6778, 'Minha Vida Nada Ortodoxa S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4dVO1TRLstuoAjAKFCCrcMraHW8.jpg'),
(95700, 6778, 'Minha Vida Nada Ortodoxa S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/533KFCfxfU1eHY6DZpntiYyCZlc.jpg'),
(95701, 6778, 'Minha Vida Nada Ortodoxa S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5RZHfBjLzVjJhAYsCh1jQdDM7yW.jpg'),
(95702, 6778, 'Minha Vida Nada Ortodoxa S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eyChnmoVKPBur8C84IMWEioCjXC.jpg'),
(95703, 6778, 'Minha Vida Nada Ortodoxa S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rgCgtKg8lc6wSVJ2HhrtQLY6kui.jpg'),
(95704, 6778, 'Minha Vida Nada Ortodoxa S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/993Sk14iCTqUhpwykwIuJoJAmOZ.jpg'),
(95705, 6778, 'Minha Vida Nada Ortodoxa S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lgoiThVTBxSj0YONIIYuOXEW0Yj.jpg'),
(95706, 6778, 'Minha Vida Nada Ortodoxa S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rDkg5COtS7cF4vDB1IEk63kcrXm.jpg'),
(95707, 6778, 'Minha Vida Nada Ortodoxa S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qjYS5j76iVZ6csEQsMdtdQi0yN1.jpg'),
(95708, 6779, 'Patagônia Extraordinária S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zdBXnEoTscCbLaV5pIFe6iG8Ivo.jpg'),
(95709, 6779, 'Patagônia Extraordinária S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mpYFZLA4Ahje5peyPOmBjzhdRT2.jpg'),
(95710, 6779, 'Patagônia Extraordinária S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ruZmloX6zKmxP8oLh17TTBSbF2.jpg'),
(95711, 6779, 'Patagônia Extraordinária S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bbqF69eiRX11opOG5EPMiTN4nTi.jpg'),
(95712, 6779, 'Patagônia Extraordinária S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFdOd2HyhAZyCYvnwrKO3MGTjYz.jpg'),
(95713, 6779, 'Patagônia Extraordinária S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zosJNou7NbhNZuJD4USGnJE5iR1.jpg'),
(95714, 6780, 'Vou Viver de HQ S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zeOMq18KX5cAbJTzhEmy5YUAM4z.jpg'),
(95715, 6780, 'Vou Viver de HQ S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZ6uIidnFCN4eqL2WICV95ykb06.jpg'),
(95716, 6780, 'Vou Viver de HQ S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qjEOF4iT8UQ0VPSASyoVYhvGMDT.jpg'),
(95717, 6780, 'Vou Viver de HQ S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pPbUFxBorwOdU1Gz4FCCqpxJNOw.jpg'),
(95718, 6780, 'Vou Viver de HQ S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4WMeY2Scg00FHoilY4lPpvS4jne.jpg'),
(95719, 6780, 'Vou Viver de HQ S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8N22I5hFHdcSYQm3p1wAxGnl1JR.jpg'),
(95720, 6781, 'Willow S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fNlo0TJqLRuwGoogMK7tRevFSqo.jpg'),
(95721, 6781, 'Willow S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/99HTgLOFtZotTtHRwkXQFAOrDjN.jpg'),
(95722, 6781, 'Willow S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205467.mp4', 'http://image.tmdb.org/t/p/w1280/zCQ44uUqo1t8RtLYVvmnLLNHCHh.jpg'),
(95723, 6781, 'Willow S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205468.mp4', 'http://image.tmdb.org/t/p/w1280/aOGdTbrbnejZA917t8l4LyONhXd.jpg'),
(95724, 6781, 'Willow S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/90SxyOAoUkd5xTDOj31aul20GQ1.jpg'),
(95725, 6781, 'Willow S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lHShWKGRHilxTa3BWyQdtPIYc4P.jpg'),
(95726, 6781, 'Willow S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205471.mp4', 'http://image.tmdb.org/t/p/w1280/bKGIo8YNpWnG4kqk7ftLPj3DnUS.jpg'),
(95727, 6781, 'Willow S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205472.mp4', 'http://image.tmdb.org/t/p/w1280/94fsjdKiz7qLW5RMDAQ0ZAvHmWY.jpg'),
(95728, 6782, 'A Flor Mais Bela S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxarLSp4gUA8KwHOdewJodcf8Xi.jpg'),
(95729, 6782, 'A Flor Mais Bela S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxarLSp4gUA8KwHOdewJodcf8Xi.jpg'),
(95730, 6782, 'A Flor Mais Bela S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxarLSp4gUA8KwHOdewJodcf8Xi.jpg'),
(95731, 6782, 'A Flor Mais Bela S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxarLSp4gUA8KwHOdewJodcf8Xi.jpg'),
(95732, 6782, 'A Flor Mais Bela S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxarLSp4gUA8KwHOdewJodcf8Xi.jpg'),
(95733, 6782, 'A Flor Mais Bela S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxarLSp4gUA8KwHOdewJodcf8Xi.jpg'),
(95734, 6782, 'A Flor Mais Bela S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxarLSp4gUA8KwHOdewJodcf8Xi.jpg'),
(95735, 6782, 'A Flor Mais Bela S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxarLSp4gUA8KwHOdewJodcf8Xi.jpg'),
(95736, 6782, 'A Flor Mais Bela S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxarLSp4gUA8KwHOdewJodcf8Xi.jpg'),
(95737, 6782, 'A Flor Mais Bela S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zxarLSp4gUA8KwHOdewJodcf8Xi.jpg'),
(95738, 6783, 'Alasca: Em Busca da Notícia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oSoKfYlSbHgHgf7D2jCTWYtkDpD.jpg'),
(95739, 6783, 'Alasca: Em Busca da Notícia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/71icaWtjZH2hvYtT1JWbYkD8Lmr.jpg'),
(95740, 6783, 'Alasca: Em Busca da Notícia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKcua4nHAB8GrQF9hCZB6ZqElTE.jpg'),
(95741, 6783, 'Alasca: Em Busca da Notícia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKcua4nHAB8GrQF9hCZB6ZqElTE.jpg'),
(95742, 6783, 'Alasca: Em Busca da Notícia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKcua4nHAB8GrQF9hCZB6ZqElTE.jpg'),
(95743, 6783, 'Alasca: Em Busca da Notícia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKcua4nHAB8GrQF9hCZB6ZqElTE.jpg'),
(95744, 6783, 'Alasca: Em Busca da Notícia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210923.mp4', 'http://image.tmdb.org/t/p/w1280/w6VTfkRlXOH2OZBj7PRVlwtDTS2.jpg'),
(95745, 6783, 'Alasca: Em Busca da Notícia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bfLyoVo25WSsPDluc9bjmRylYSx.jpg'),
(95746, 6783, 'Alasca: Em Busca da Notícia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yOO9nZMpz2THZJhXYMhgCtvhNVh.jpg'),
(95747, 6783, 'Alasca: Em Busca da Notícia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUwaNTUvBdUDu06Zfgq6PzXGfCf.jpg'),
(95748, 6783, 'Alasca: Em Busca da Notícia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/210927.mp4', 'http://image.tmdb.org/t/p/w1280/o2aRUrRxxfPNo6c1tUgpKmip9z6.jpg'),
(95749, 4543, 'Angel: O Caça Vampiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ftyWrISuty7pqHnAbq5uDm647aY.jpg'),
(95750, 4543, 'Angel: O Caça Vampiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iX5VZDyI6vG6zsH4NhNBJyL9grk.jpg'),
(95751, 4543, 'Angel: O Caça Vampiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5lhwbtF4qrpShvlgQdxmVtx94th.jpg'),
(95752, 4543, 'Angel: O Caça Vampiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n9ZIIOxCSRw4OKE4IJjDInI26VL.jpg'),
(95753, 4543, 'Angel: O Caça Vampiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A7g71gOTU1cBrGthEU7vqwXv9Sf.jpg'),
(95754, 4543, 'Angel: O Caça Vampiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmi7idVYAKFODz7C86UGMsSp9E3.jpg'),
(95755, 4543, 'Angel: O Caça Vampiro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Dnn5hcCJqqXS6QRjoJrgukEfnw.jpg'),
(95756, 4543, 'Angel: O Caça Vampiro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j2vA2nQwp3b6yFVWqN9sn7CqPFm.jpg'),
(95757, 4543, 'Angel: O Caça Vampiro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/djyuK3T5IvL6JKHrfmeJB88L0F9.jpg'),
(95758, 4543, 'Angel: O Caça Vampiro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/psfqCIi3QYtbwrmcGPuIx7OK9tj.jpg'),
(95759, 4543, 'Angel: O Caça Vampiro S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8bGnwhecgFmwyNJspLJbiOu6c9l.jpg'),
(95760, 4543, 'Angel: O Caça Vampiro S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iLhMo0gZjDtZ88rHsSn14VDy0sq.jpg'),
(95761, 4543, 'Angel: O Caça Vampiro S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a54egFsfHfEjMm9kf8XbiT5yI0d.jpg'),
(95762, 4543, 'Angel: O Caça Vampiro S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/200372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JheY5jq5b0HBQonUVXvsM4RBt5.jpg'),
(95763, 4543, 'Angel: O Caça Vampiro S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/200373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a3RHcehEFmxo4dL9vr59pDgO2Bl.jpg'),
(95764, 4543, 'Angel: O Caça Vampiro S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/200374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nU9pUdcfUhI9Rrs7CC3Qv0bAnuj.jpg'),
(95765, 4543, 'Angel: O Caça Vampiro S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/200375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wNFw0ayI9hKfxY1hFPupIQ5bJO5.jpg'),
(95766, 4543, 'Angel: O Caça Vampiro S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/200376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QbKF1bqOtsSDvinTSseMNTTaVe.jpg'),
(95767, 4543, 'Angel: O Caça Vampiro S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/200377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOXR69N2Cc2aOIVk7wvO64szq9k.jpg'),
(95768, 4543, 'Angel: O Caça Vampiro S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/200378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCH8xVMzabweLF90jWPsqyZ65WA.jpg'),
(95769, 4543, 'Angel: O Caça Vampiro S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/200379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/66anqK48AxATU7VNK7dFdWfWcTD.jpg'),
(95770, 4543, 'Angel: O Caça Vampiro S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/200380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/23JZMZ9vUWcLOfwUWRptTaZwEsy.jpg'),
(95771, 4544, 'Angel: O Caça Vampiro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odLr8ckyZLccgclUSArxfE7IEPV.jpg'),
(95772, 4544, 'Angel: O Caça Vampiro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hFf4EgujzjdeKjjxxS9tYzQIHeA.jpg'),
(95773, 4544, 'Angel: O Caça Vampiro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Bw2TF82dpDA9wxQGGAcU2W61Lj.jpg'),
(95774, 4544, 'Angel: O Caça Vampiro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdjF2gMJ5HIFt7gD6b2dfyTJ0t1.jpg'),
(95775, 4544, 'Angel: O Caça Vampiro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1cpzFenzbGNj6XkeK8CJ6xA6Rqy.jpg'),
(95776, 4544, 'Angel: O Caça Vampiro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bpnuqUtXoMWW4OT5IHkv1EHAMEb.jpg'),
(95777, 4544, 'Angel: O Caça Vampiro S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kpT7dOe0se4zb0cClOKLOtg0YcY.jpg'),
(95778, 4544, 'Angel: O Caça Vampiro S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bSNEf8HHF3G3RqPDoH1tJ6scYiu.jpg'),
(95779, 4544, 'Angel: O Caça Vampiro S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6L6Z2GuUxYjFhHD8BoZz1MfU4ke.jpg'),
(95780, 4544, 'Angel: O Caça Vampiro S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oKWoe8VJDX7zTNqxJl6mSbM5Wbo.jpg'),
(95781, 4544, 'Angel: O Caça Vampiro S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHVzfSUv1ZojUXAl1veagRqkPgO.jpg'),
(95782, 4544, 'Angel: O Caça Vampiro S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/phuZJwbTlBvFaYi9KAUH2qC4e6G.jpg'),
(95783, 4544, 'Angel: O Caça Vampiro S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kMOIrEqbCXHTxrQMIqtw2hyURsI.jpg'),
(95784, 4544, 'Angel: O Caça Vampiro S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/200394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nNO7uYSpSp2T8afdc87bu1PmOzi.jpg'),
(95785, 4544, 'Angel: O Caça Vampiro S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/200395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qE5Tio3hSSQb71XRMS1Yn7EbFqs.jpg'),
(95786, 4544, 'Angel: O Caça Vampiro S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/200396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2e7wnnziP5GwNFg0oC526zqUGTu.jpg'),
(95787, 4544, 'Angel: O Caça Vampiro S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/200397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7TkGiPLGi3qzAdnJlHXYemlDb5V.jpg'),
(95788, 4544, 'Angel: O Caça Vampiro S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/200398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tXspUS4YZ5vFFoiOsu6K7JeOltF.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(95789, 4544, 'Angel: O Caça Vampiro S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/200399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aenyr3GV5pOVkv5Hvty4whVx8Hb.jpg'),
(95790, 4544, 'Angel: O Caça Vampiro S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/200400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wi5d0Z58NF9b9nLqLXmmf0ZxwwM.jpg'),
(95791, 4544, 'Angel: O Caça Vampiro S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/200401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s7QijF1JXKUUhJWEY9sSR9sKDwM.jpg'),
(95792, 4544, 'Angel: O Caça Vampiro S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/200402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4NweaqZefwO0TIe5znHVpcgHhoF.jpg'),
(95793, 4545, 'Angel: O Caça Vampiro S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/247p28c6b6KyTG4sHPAX6EjiVfs.jpg'),
(95794, 4545, 'Angel: O Caça Vampiro S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ziv71LrzGk8cDquNBwWkLFm9uGd.jpg'),
(95795, 4545, 'Angel: O Caça Vampiro S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bMbRxjUXKFv3eHDzKGhAVeugXNX.jpg'),
(95796, 4545, 'Angel: O Caça Vampiro S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f6Sl7v1G0Ilj13SLRXUcvuFfK7g.jpg'),
(95797, 4545, 'Angel: O Caça Vampiro S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oVtnHSR1p9dxVFrO1NseIrJg87h.jpg'),
(95798, 4545, 'Angel: O Caça Vampiro S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4TIr0giJK44ZJ7TGtnkg7Augjyr.jpg'),
(95799, 4545, 'Angel: O Caça Vampiro S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z6Q07NUsAn5dTkLrFDjA0qfxXtb.jpg'),
(95800, 4545, 'Angel: O Caça Vampiro S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fLmIMyRWiW6ayJMH9TijzkuBHBN.jpg'),
(95801, 4545, 'Angel: O Caça Vampiro S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3N3cVnAzvmxuIXWqMQq1V2VI1Nn.jpg'),
(95802, 4545, 'Angel: O Caça Vampiro S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wVm3wYeOXAoJDPZobo1ylx8HsWN.jpg'),
(95803, 4545, 'Angel: O Caça Vampiro S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dQCbMdWOaHQMsEkLLZk6h6rDq1I.jpg'),
(95804, 4545, 'Angel: O Caça Vampiro S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svhYw6lxsUPF5xn1CazUliSOiZN.jpg'),
(95805, 4545, 'Angel: O Caça Vampiro S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8FyWgzMiIPhQPulNg4dYnWMM65w.jpg'),
(95806, 4545, 'Angel: O Caça Vampiro S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/200416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ju5nfs51o3M2tq7yRluMmUrslZB.jpg'),
(95807, 4545, 'Angel: O Caça Vampiro S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/200417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/orDGT5e9ra9h3RoKKCrJni672GU.jpg'),
(95808, 4545, 'Angel: O Caça Vampiro S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/200418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5FNvvg7Cf3KARdZePfbyaBFuAOA.jpg'),
(95809, 4545, 'Angel: O Caça Vampiro S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/200419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2HjAiEHwxbU2WWAlFJ9bAoHyVM.jpg'),
(95810, 4545, 'Angel: O Caça Vampiro S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/200420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zHCrJkmWavw7uiKwPJbdwePNpgc.jpg'),
(95811, 4545, 'Angel: O Caça Vampiro S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/200421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dHM1UbdEwMrm1lQCHIXRd4371Zv.jpg'),
(95812, 4545, 'Angel: O Caça Vampiro S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/200422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1KNLC7d8GrrfyjK3g6x9fMgFZAI.jpg'),
(95813, 4545, 'Angel: O Caça Vampiro S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/200423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xXNhfNioEk9z6zXzXqC05gh8UkZ.jpg'),
(95814, 4545, 'Angel: O Caça Vampiro S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/200424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vLcSHtQoGjncNrbDYfKY5n2sdJc.jpg'),
(95815, 4546, 'Angel: O Caça Vampiro S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lWfC8WlaIUc6gOdhypAG0lty5YH.jpg'),
(95816, 4546, 'Angel: O Caça Vampiro S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqYoBPqZAMpWtERrDBKsU8rxt0Q.jpg'),
(95817, 4546, 'Angel: O Caça Vampiro S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8f7nypxPFostkCINowi1hHBwus.jpg'),
(95818, 4546, 'Angel: O Caça Vampiro S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/93ZXOyNmCtOgq6ZcM75YJbjeDtI.jpg'),
(95819, 4546, 'Angel: O Caça Vampiro S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVCrMG9NuL60afx8f9OKQ9iSogq.jpg'),
(95820, 4546, 'Angel: O Caça Vampiro S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hGT0yXo9NtzR7MsGhpRT7Bb0Mzc.jpg'),
(95821, 4546, 'Angel: O Caça Vampiro S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uJoZY8M9rTYcZRfTNEhIJFhPaC9.jpg'),
(95822, 4546, 'Angel: O Caça Vampiro S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qMp65SN8z6UDcgysKITDqNE9JQ3.jpg'),
(95823, 4546, 'Angel: O Caça Vampiro S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o4OzXKngUo8v2meIEjD0ha8yDUL.jpg'),
(95824, 4546, 'Angel: O Caça Vampiro S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5OO9EeE1LtgoKsSIrAveal0yCdx.jpg'),
(95825, 4546, 'Angel: O Caça Vampiro S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zm9YpCAsnKY2sf8i1cYlot7Ewqp.jpg'),
(95826, 4546, 'Angel: O Caça Vampiro S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qummsiqiCuFt3mzFRx8zgid6k5j.jpg'),
(95827, 4546, 'Angel: O Caça Vampiro S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AczH5WtdC2YRdCcGrQO5PLEmvcP.jpg'),
(95828, 4546, 'Angel: O Caça Vampiro S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/200438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7uTMve9FlZPTqCOpmQ4WixyO44F.jpg'),
(95829, 4546, 'Angel: O Caça Vampiro S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/200439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6HMEs0inQyZL38pSrsm1H1ZZZy.jpg'),
(95830, 4546, 'Angel: O Caça Vampiro S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/200440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8Uz8rgfV3mh0WpmQhMgTsPccG3.jpg'),
(95831, 4546, 'Angel: O Caça Vampiro S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/200441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cAxxLQacfLXldVYY2sRrou59Pyw.jpg'),
(95832, 4546, 'Angel: O Caça Vampiro S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/200442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEvOBGXdmD84xnfAbtOzxScHZbN.jpg'),
(95833, 4546, 'Angel: O Caça Vampiro S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/200443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uJYMwU238Vkhx9afdDSiip5Y6uO.jpg'),
(95834, 4546, 'Angel: O Caça Vampiro S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/200444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uLyhQPxuhrcuNBHtaJkg11nO79f.jpg'),
(95835, 4546, 'Angel: O Caça Vampiro S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/200445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b6kKvJve4zUayGabzWBOHcfhVhq.jpg'),
(95836, 4546, 'Angel: O Caça Vampiro S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/200446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rSvpuWypNpaeJt8hyVd95gIjUPD.jpg'),
(95837, 4547, 'Angel: O Caça Vampiro S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vgyvuSJApYA6LNg8VK9BgLgULj.jpg'),
(95838, 4547, 'Angel: O Caça Vampiro S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/64K3G1KPbjmC8fseJekhfx5JYA4.jpg'),
(95839, 4547, 'Angel: O Caça Vampiro S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nWGq5uIne6L1jqh3D1qq01LeEyz.jpg'),
(95840, 4547, 'Angel: O Caça Vampiro S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/haDk48omnUQWeuy2VUH5uoi8pIs.jpg'),
(95841, 4547, 'Angel: O Caça Vampiro S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBJNlXxFbO3d9ZpHFid3POpMyNO.jpg'),
(95842, 4547, 'Angel: O Caça Vampiro S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kZaDI13qktmCO1KCxo2vB4XkwTy.jpg'),
(95843, 4547, 'Angel: O Caça Vampiro S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i3eDIhoyxsDd7IINtOHctxT4kZ1.jpg'),
(95844, 4547, 'Angel: O Caça Vampiro S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iwdshTARGgQghY8WcFqnE15iKTp.jpg'),
(95845, 4547, 'Angel: O Caça Vampiro S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xzZZvSeUrES8UkDjmuQjRVXAaps.jpg'),
(95846, 4547, 'Angel: O Caça Vampiro S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6XeCUSxO3DwjPaCqWaCekWQrgo2.jpg'),
(95847, 4547, 'Angel: O Caça Vampiro S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqiC5XkCtkYXX7yntAOV48Ic8Qb.jpg'),
(95848, 4547, 'Angel: O Caça Vampiro S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i7qaWCVXWXK2KF6nwMbVHiI3diY.jpg'),
(95849, 4547, 'Angel: O Caça Vampiro S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ol1QphFBppcByLkG8QePKKidZF.jpg'),
(95850, 4547, 'Angel: O Caça Vampiro S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/200460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zH1IRrb5Exm8ofOt0EHTkPOudGI.jpg'),
(95851, 4547, 'Angel: O Caça Vampiro S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/200461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6rY0cHePE0Zsg808WeV9KcnoYns.jpg'),
(95852, 4547, 'Angel: O Caça Vampiro S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/200462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fVvoX2QQ8gzb73zy6cTaKzQucR3.jpg'),
(95853, 4547, 'Angel: O Caça Vampiro S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/200463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jqaqS9jUBF0tOPwqKeVz5R5ZLZI.jpg'),
(95854, 4547, 'Angel: O Caça Vampiro S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/200464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/chVQxMKsVCH1Lef1S5NcwBbNMmV.jpg'),
(95855, 4547, 'Angel: O Caça Vampiro S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/200465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jwpiNXTc4TsLJATPwFPp9jvxzkX.jpg'),
(95856, 4547, 'Angel: O Caça Vampiro S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/200466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uKK3QFKe07HBiyrDzIxfNwR2dKZ.jpg'),
(95857, 4547, 'Angel: O Caça Vampiro S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/200467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qLqOBw7eVdWWA1fXC6ecgaEzI29.jpg'),
(95858, 4547, 'Angel: O Caça Vampiro S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/200468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4j7Ly1iOdN5HaI5BOHTgzWvd0wR.jpg'),
(95859, 6784, 'Assassinos Indianos: Assassinato na Corte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ggnBlzK0cvvmo3iyfrsJUjjE4fu.jpg'),
(95860, 6784, 'Assassinos Indianos: Assassinato na Corte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wev7JU1yqbGEpn8mMgJRX6O3kh8.jpg'),
(95861, 6784, 'Assassinos Indianos: Assassinato na Corte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6lHclH2dAihoZCasXF3bg6RgSfB.jpg'),
(95862, 6785, 'Dragon Age: Absolvição S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wcbUCtts5OkzJzzsU2fxaSOPPBp.jpg'),
(95863, 6785, 'Dragon Age: Absolvição S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3vlYTqYEyFVdZBWHHuDGm2JVgcd.jpg'),
(95864, 6785, 'Dragon Age: Absolvição S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jckbMKt8xrQl8ShXzEPOcZ9JYJt.jpg'),
(95865, 6785, 'Dragon Age: Absolvição S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vfW8uDxrur3NYtWPwv2p95dy5OQ.jpg'),
(95866, 6785, 'Dragon Age: Absolvição S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kReexlwokmIRSHAuGEJYDhAHvDZ.jpg'),
(95867, 6785, 'Dragon Age: Absolvição S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oUom2X7RILDk0lBWH2f4evc4jS1.jpg'),
(95868, 6786, 'Eu Odeio Natal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nkPUc2mx6GxWjeL5YsiPnvmLeN7.jpg'),
(95869, 6786, 'Eu Odeio Natal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fyXPFDPbVeVukfEqyzJiGjbac5c.jpg'),
(95870, 6786, 'Eu Odeio Natal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AYrSJqEWTTi2S0ajY3Np2x2NGQ.jpg'),
(95871, 6786, 'Eu Odeio Natal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a2gsMtywSohAmZLO9GynNC63DBK.jpg'),
(95872, 6786, 'Eu Odeio Natal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/utKKuCdw2WKCBGeAABecnKBAsTq.jpg'),
(95873, 6786, 'Eu Odeio Natal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xoXnEuSGEoyq5nzgsHSl0F1gRpD.jpg'),
(95874, 6787, 'Eu Odeio Natal S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4x36JTjaCyB0QvMGmMNGuma6DpJ.jpg'),
(95875, 6787, 'Eu Odeio Natal S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4x36JTjaCyB0QvMGmMNGuma6DpJ.jpg'),
(95876, 6787, 'Eu Odeio Natal S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4x36JTjaCyB0QvMGmMNGuma6DpJ.jpg'),
(95877, 6787, 'Eu Odeio Natal S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4x36JTjaCyB0QvMGmMNGuma6DpJ.jpg'),
(95878, 6787, 'Eu Odeio Natal S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4x36JTjaCyB0QvMGmMNGuma6DpJ.jpg'),
(95879, 6787, 'Eu Odeio Natal S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4x36JTjaCyB0QvMGmMNGuma6DpJ.jpg'),
(95880, 6788, 'Flordelis: Em Nome da Mãe S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rfp1qTb9gTWJwycVAMy8zm1Azwy.jpg'),
(95881, 6788, 'Flordelis: Em Nome da Mãe S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/91CyLlbar8IvFvH1Dw3BuexA0iE.jpg'),
(95882, 6788, 'Flordelis: Em Nome da Mãe S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o3Phfzo1mo8F1n6IQEWzlGX6ijQ.jpg'),
(95883, 6788, 'Flordelis: Em Nome da Mãe S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3nb9zSiFPoK4S33kB6nM7tZKllL.jpg'),
(95884, 6789, 'Fudêncio e Seus Amigos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95885, 6789, 'Fudêncio e Seus Amigos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95886, 6789, 'Fudêncio e Seus Amigos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95887, 6789, 'Fudêncio e Seus Amigos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95888, 6789, 'Fudêncio e Seus Amigos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95889, 6789, 'Fudêncio e Seus Amigos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95890, 6789, 'Fudêncio e Seus Amigos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95891, 6789, 'Fudêncio e Seus Amigos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95892, 6789, 'Fudêncio e Seus Amigos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95893, 6789, 'Fudêncio e Seus Amigos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95894, 6789, 'Fudêncio e Seus Amigos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95895, 6789, 'Fudêncio e Seus Amigos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95896, 6789, 'Fudêncio e Seus Amigos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95897, 6789, 'Fudêncio e Seus Amigos S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/200221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95898, 6789, 'Fudêncio e Seus Amigos S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/200222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95899, 6789, 'Fudêncio e Seus Amigos S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/200223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95900, 6789, 'Fudêncio e Seus Amigos S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/200224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95901, 6789, 'Fudêncio e Seus Amigos S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/200225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95902, 6789, 'Fudêncio e Seus Amigos S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/200226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95903, 6789, 'Fudêncio e Seus Amigos S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/200227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95904, 6790, 'Fudêncio e Seus Amigos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95905, 6790, 'Fudêncio e Seus Amigos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95906, 6790, 'Fudêncio e Seus Amigos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95907, 6790, 'Fudêncio e Seus Amigos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95908, 6790, 'Fudêncio e Seus Amigos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95909, 6790, 'Fudêncio e Seus Amigos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95910, 6790, 'Fudêncio e Seus Amigos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95911, 6790, 'Fudêncio e Seus Amigos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95912, 6790, 'Fudêncio e Seus Amigos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95913, 6790, 'Fudêncio e Seus Amigos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95914, 6790, 'Fudêncio e Seus Amigos S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95915, 6790, 'Fudêncio e Seus Amigos S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95916, 6790, 'Fudêncio e Seus Amigos S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95917, 6790, 'Fudêncio e Seus Amigos S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/200241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95918, 6790, 'Fudêncio e Seus Amigos S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/200242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95919, 6790, 'Fudêncio e Seus Amigos S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/200243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95920, 6790, 'Fudêncio e Seus Amigos S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/200244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95921, 6790, 'Fudêncio e Seus Amigos S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/200245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95922, 6790, 'Fudêncio e Seus Amigos S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/200246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95923, 6790, 'Fudêncio e Seus Amigos S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/200247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95924, 6790, 'Fudêncio e Seus Amigos S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/200248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95925, 6790, 'Fudêncio e Seus Amigos S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/200249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95926, 6790, 'Fudêncio e Seus Amigos S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/200250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95927, 6790, 'Fudêncio e Seus Amigos S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/200251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95928, 6790, 'Fudêncio e Seus Amigos S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/200252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95929, 6790, 'Fudêncio e Seus Amigos S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/200253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95930, 6790, 'Fudêncio e Seus Amigos S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/200254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95931, 6790, 'Fudêncio e Seus Amigos S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/200255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95932, 6790, 'Fudêncio e Seus Amigos S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/200256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95933, 6790, 'Fudêncio e Seus Amigos S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/200257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95934, 6790, 'Fudêncio e Seus Amigos S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/200258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95935, 6790, 'Fudêncio e Seus Amigos S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/200259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95936, 6791, 'Fudêncio e Seus Amigos S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95937, 6791, 'Fudêncio e Seus Amigos S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95938, 6791, 'Fudêncio e Seus Amigos S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95939, 6791, 'Fudêncio e Seus Amigos S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95940, 6791, 'Fudêncio e Seus Amigos S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95941, 6791, 'Fudêncio e Seus Amigos S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95942, 6791, 'Fudêncio e Seus Amigos S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95943, 6791, 'Fudêncio e Seus Amigos S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95944, 6791, 'Fudêncio e Seus Amigos S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95945, 6791, 'Fudêncio e Seus Amigos S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95946, 6791, 'Fudêncio e Seus Amigos S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95947, 6791, 'Fudêncio e Seus Amigos S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95948, 6791, 'Fudêncio e Seus Amigos S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95949, 6791, 'Fudêncio e Seus Amigos S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/200273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95950, 6791, 'Fudêncio e Seus Amigos S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/200274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95951, 6791, 'Fudêncio e Seus Amigos S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/200275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95952, 6791, 'Fudêncio e Seus Amigos S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/200276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95953, 6791, 'Fudêncio e Seus Amigos S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/200277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95954, 6791, 'Fudêncio e Seus Amigos S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/200278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95955, 6791, 'Fudêncio e Seus Amigos S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/200279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95956, 6791, 'Fudêncio e Seus Amigos S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/200280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95957, 6791, 'Fudêncio e Seus Amigos S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/200281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95958, 6791, 'Fudêncio e Seus Amigos S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/200282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95959, 6791, 'Fudêncio e Seus Amigos S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/200283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95960, 6791, 'Fudêncio e Seus Amigos S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/200284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95961, 6791, 'Fudêncio e Seus Amigos S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/200285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95962, 6792, 'Fudêncio e Seus Amigos S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95963, 6792, 'Fudêncio e Seus Amigos S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95964, 6792, 'Fudêncio e Seus Amigos S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95965, 6792, 'Fudêncio e Seus Amigos S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95966, 6792, 'Fudêncio e Seus Amigos S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95967, 6792, 'Fudêncio e Seus Amigos S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95968, 6792, 'Fudêncio e Seus Amigos S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95969, 6792, 'Fudêncio e Seus Amigos S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95970, 6792, 'Fudêncio e Seus Amigos S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95971, 6792, 'Fudêncio e Seus Amigos S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95972, 6792, 'Fudêncio e Seus Amigos S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95973, 6792, 'Fudêncio e Seus Amigos S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95974, 6792, 'Fudêncio e Seus Amigos S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95975, 6792, 'Fudêncio e Seus Amigos S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/200299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95976, 6792, 'Fudêncio e Seus Amigos S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/200300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95977, 6792, 'Fudêncio e Seus Amigos S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/200301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95978, 6792, 'Fudêncio e Seus Amigos S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/200302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95979, 6792, 'Fudêncio e Seus Amigos S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/200303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95980, 6792, 'Fudêncio e Seus Amigos S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/200304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95981, 6792, 'Fudêncio e Seus Amigos S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/200305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95982, 6792, 'Fudêncio e Seus Amigos S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/200306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95983, 6792, 'Fudêncio e Seus Amigos S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/200307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95984, 6792, 'Fudêncio e Seus Amigos S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/200308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95985, 6792, 'Fudêncio e Seus Amigos S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/200309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95986, 6792, 'Fudêncio e Seus Amigos S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/200310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95987, 6792, 'Fudêncio e Seus Amigos S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/200311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95988, 6792, 'Fudêncio e Seus Amigos S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/200312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95989, 6792, 'Fudêncio e Seus Amigos S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/200313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95990, 6793, 'Fudêncio e Seus Amigos S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95991, 6793, 'Fudêncio e Seus Amigos S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95992, 6793, 'Fudêncio e Seus Amigos S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95993, 6793, 'Fudêncio e Seus Amigos S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95994, 6793, 'Fudêncio e Seus Amigos S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95995, 6793, 'Fudêncio e Seus Amigos S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95996, 6793, 'Fudêncio e Seus Amigos S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95997, 6793, 'Fudêncio e Seus Amigos S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95998, 6793, 'Fudêncio e Seus Amigos S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(95999, 6793, 'Fudêncio e Seus Amigos S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96000, 6793, 'Fudêncio e Seus Amigos S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96001, 6793, 'Fudêncio e Seus Amigos S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96002, 6793, 'Fudêncio e Seus Amigos S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96003, 6793, 'Fudêncio e Seus Amigos S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/200327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96004, 6793, 'Fudêncio e Seus Amigos S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/200328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96005, 6793, 'Fudêncio e Seus Amigos S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/200329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96006, 6793, 'Fudêncio e Seus Amigos S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/200330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96007, 6793, 'Fudêncio e Seus Amigos S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/200331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96008, 6793, 'Fudêncio e Seus Amigos S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/200332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96009, 6794, 'Fudêncio e Seus Amigos S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/200333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96010, 6794, 'Fudêncio e Seus Amigos S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/200334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96011, 6794, 'Fudêncio e Seus Amigos S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/200335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96012, 6794, 'Fudêncio e Seus Amigos S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/200336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96013, 6794, 'Fudêncio e Seus Amigos S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/200337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96014, 6794, 'Fudêncio e Seus Amigos S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/200338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96015, 6794, 'Fudêncio e Seus Amigos S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/200339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96016, 6794, 'Fudêncio e Seus Amigos S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/200340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96017, 6794, 'Fudêncio e Seus Amigos S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/200341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96018, 6794, 'Fudêncio e Seus Amigos S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/200342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96019, 6794, 'Fudêncio e Seus Amigos S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/200343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96020, 6794, 'Fudêncio e Seus Amigos S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/200344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96021, 6794, 'Fudêncio e Seus Amigos S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/200345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vKuKHm5Cxw8BlrDhUdMS3N4PNcQ.jpg'),
(96022, 6795, 'Gabriel Monteiro – Herói Fake S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6cxAH0ZnkpsblVs7YXVsMO3uMrU.jpg'),
(96023, 6795, 'Gabriel Monteiro – Herói Fake S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vZ1WeVFA9wk2Kn0UClP2LvXNaXr.jpg'),
(96024, 6795, 'Gabriel Monteiro – Herói Fake S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nykreJuvZFuWEuKEdgLqQQKbe72.jpg'),
(96025, 6795, 'Gabriel Monteiro – Herói Fake S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgA7xgFeHUjO0VyzvsnkiPcmCKv.jpg'),
(96026, 6796, 'Interligados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7pMZ6G2ncvg8O9sLAZ0RtRsZEuh.jpg'),
(96027, 6796, 'Interligados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kaz02qu5Ju08NF8lMf8BaVUdtue.jpg'),
(96028, 6796, 'Interligados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xVQB6h9Z4pRmMwuZklq8DdoURPD.jpg'),
(96029, 6796, 'Interligados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x1pYCnYHU4ym8imcyaj2jCx2BBL.jpg'),
(96030, 6797, 'Lookism S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/29GciXzxaRJqSSM1LJwj6qm7maQ.jpg'),
(96031, 6797, 'Lookism S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wpOM0gBk2E29Yhk1MklsTCOpkRk.jpg'),
(96032, 6797, 'Lookism S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/me8Lc1zONKjrKco9mXSXCgz1Hsz.jpg'),
(96033, 6797, 'Lookism S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hz2yyHEhd6UzeJO3UU6XlyuIWH6.jpg'),
(96034, 6797, 'Lookism S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5L36zta5Vwv0rnfiamjKk0oPDDB.jpg'),
(96035, 6797, 'Lookism S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sl9iQrkyoiangBBSwkk5IovLMD6.jpg'),
(96036, 6797, 'Lookism S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e8bKN87FbBzrJPlotBfNZ1PJEDp.jpg'),
(96037, 6797, 'Lookism S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/95zQgitZW29ZOknCZ0j4IMbwtzN.jpg'),
(96038, 6798, 'Love All Play S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jEy9bpHvphSEbGEOvhdcW3ZMdMI.jpg'),
(96039, 6798, 'Love All Play S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvUjfnpDZdxcKnImaA1nXnV13F1.jpg'),
(96040, 6798, 'Love All Play S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vT3iBvDWEIrg8lIzT2XOMAKluJE.jpg'),
(96041, 6798, 'Love All Play S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wncLs1N6G0ATaemj2zKEdPDdyZy.jpg'),
(96042, 6798, 'Love All Play S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eSOpYd0igW2LbIfvrfylWQm4jnp.jpg'),
(96043, 6798, 'Love All Play S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tHKLKu9XZkFTZ2qkFYWxfAIHxyg.jpg'),
(96044, 6798, 'Love All Play S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVKHsc45eLiCIDCw04FhkHcP1Ys.jpg'),
(96045, 6798, 'Love All Play S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nchUKIzQPjiPuNzQDOJSd0NBNjl.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(96046, 6798, 'Love All Play S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r5L3CptI0qwBWA283uo5qEDDniC.jpg'),
(96047, 6798, 'Love All Play S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5OtF0Dzzs5Xm3rqgs5BcsTd7xY7.jpg'),
(96048, 6798, 'Love All Play S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uvw8zsQHAUoHkgJHjhMwdgneu0X.jpg'),
(96049, 6798, 'Love All Play S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uQloRGjvD1TR3gQIf3rbCax8ae5.jpg'),
(96050, 6798, 'Love All Play S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7gwESy9vsS7jLQPhL9V65KZQYoT.jpg'),
(96051, 6798, 'Love All Play S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/204130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QuCjsiwnSjGVav8ELfVISvkI3h.jpg'),
(96052, 6798, 'Love All Play S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/204131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yXSphlAeaDb6THx9Zpetx6PegUt.jpg'),
(96053, 6798, 'Love All Play S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/204132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rVxVsqs28bHYkRCtr0PWYXLQpSo.jpg'),
(96054, 6799, 'O Paciente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ah5UsVE7r37z0d26XhBkvn2BX2d.jpg'),
(96055, 6799, 'O Paciente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oNH3SwTIR7vXfqPBBpY6phrvtli.jpg'),
(96056, 6799, 'O Paciente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/khrHomv6Y5Bgcefq5zaMHeW3cov.jpg'),
(96057, 6799, 'O Paciente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xabd6iCZD3WCeyAIs6PeVfCQy9B.jpg'),
(96058, 6799, 'O Paciente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AlXz2RVK5JUO7z9TaLok8bPu9x9.jpg'),
(96059, 6799, 'O Paciente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7nFnw31kEaooJkDSuuKj7Cun1Aj.jpg'),
(96060, 6799, 'O Paciente S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dh4u6LAn4gJm99NWzffRm42TNbS.jpg'),
(96061, 6799, 'O Paciente S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r598OaLzun7Ofi2JQmOg0wGHhAe.jpg'),
(96062, 6799, 'O Paciente S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mcMAuCMfvjAh5dgu8Z320rPfnJH.jpg'),
(96063, 6799, 'O Paciente S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2PcaO11WyD9g6lS1InFLbIuFft.jpg'),
(96064, 6800, 'Saber Marionette J S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/znWAaiaYdVXYsoZpvgzRDK9OTkY.jpg'),
(96065, 6800, 'Saber Marionette J S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nB9g83SE327BZA8chlyFoSqfII1.jpg'),
(96066, 6800, 'Saber Marionette J S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mVHMeGybar7vG4346e8UtxafTm9.jpg'),
(96067, 6800, 'Saber Marionette J S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vQ82tIaJhQiehHP4kPUPP5uHw0.jpg'),
(96068, 6800, 'Saber Marionette J S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ccixSkoCbLOC6CuzS3oZudfcJ72.jpg'),
(96069, 6800, 'Saber Marionette J S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/15A7wXPk5LZAngVATgpSfDBAdfE.jpg'),
(96070, 6800, 'Saber Marionette J S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vDAwDrLMBA3NEnGmu2pk8eAPbvR.jpg'),
(96071, 6800, 'Saber Marionette J S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/phxa3OPXdJRHUz8nWvuaoEbmOgV.jpg'),
(96072, 6800, 'Saber Marionette J S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUv4bF9CpRXgKe4OduGaCEOEvea.jpg'),
(96073, 6800, 'Saber Marionette J S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nPgnOUHxTH9at7wpZwsRERNviXa.jpg'),
(96074, 6800, 'Saber Marionette J S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xIs3JFJ2ORRAo6nYrQ8w8yrWUYI.jpg'),
(96075, 6800, 'Saber Marionette J S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r62SF2N8GI4nuPUOta5XAjJ57SS.jpg'),
(96076, 6800, 'Saber Marionette J S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zAR8shJ1aiRM8j2sDP2Ytk54EUV.jpg'),
(96077, 6800, 'Saber Marionette J S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/204095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8fmFtoXpaDr29rS59sk8UmBzDzJ.jpg'),
(96078, 6800, 'Saber Marionette J S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/204096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wit2LTVTq1lZ6C8lRVfrbmhQWEC.jpg'),
(96079, 6800, 'Saber Marionette J S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/204097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1TKFHmO4aAIN6bTVBEY0gUqWzfO.jpg'),
(96080, 6800, 'Saber Marionette J S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/204098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aazENznw3dqsIUA9LILg2fmaMKh.jpg'),
(96081, 6800, 'Saber Marionette J S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/204099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ezmVX4TqnQq0D1pO3FsZdmuGVw.jpg'),
(96082, 6800, 'Saber Marionette J S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/204100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6mNZ0SF66pajvfAqOmHYgOV9JpM.jpg'),
(96083, 6800, 'Saber Marionette J S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/204101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nvF2b3xfMF1kV4HO4dacjdEfaR7.jpg'),
(96084, 6800, 'Saber Marionette J S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/204102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v6LxZcTqwkq9e0v645vt5DsEq1n.jpg'),
(96085, 6800, 'Saber Marionette J S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/204103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l7l3hfucZQ5bmxPSxLsrh6dfgOS.jpg'),
(96086, 6800, 'Saber Marionette J S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/204104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u69ygyiQzJa0cHjrXJQigtEms7p.jpg'),
(96087, 6800, 'Saber Marionette J S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/204105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wNjj2dxWQQmq0s8FhZm3A6UHvUy.jpg'),
(96088, 6800, 'Saber Marionette J S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/204106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ivDBYXHJVU76GwL4jj000hDsTUM.jpg'),
(96089, 6801, 'Smiley S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5S5FQsRQ8jL1GWnSlA0mhkC6yrq.jpg'),
(96090, 6801, 'Smiley S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1QbVhwf5BN6jjJhtmuUmlYE3DU2.jpg'),
(96091, 6801, 'Smiley S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6a6vAkJOpdZq5iChTqH4ekwmfHT.jpg'),
(96092, 6801, 'Smiley S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xE6lOe1gMslh8UqA2F9PuZ85dov.jpg'),
(96093, 6801, 'Smiley S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f90cEDECxacwgd5hEDrGnyDl2t5.jpg'),
(96094, 6801, 'Smiley S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nXuOcPpHuzscNNyufWsrBXRudDE.jpg'),
(96095, 6801, 'Smiley S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j7Q0bxZAuPvyIiuHYij1zie650T.jpg'),
(96096, 6801, 'Smiley S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9WXN4CLUvtnpiXANU5iu82cfwF4.jpg'),
(96097, 6802, 'Sr. Meia-Noite: Cuidado com os Monstros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u8jD3oUtoEYMFat7BXEA61LEXjS.jpg'),
(96098, 6802, 'Sr. Meia-Noite: Cuidado com os Monstros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xRDm0812gK7OsXgPXfpX9Whne83.jpg'),
(96099, 6802, 'Sr. Meia-Noite: Cuidado com os Monstros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rs8t7JnCNSbxbTMJgMOG3EB9Gyg.jpg'),
(96100, 6802, 'Sr. Meia-Noite: Cuidado com os Monstros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4GPChBrfOSSumKc0rmplGVIwq9J.jpg'),
(96101, 6802, 'Sr. Meia-Noite: Cuidado com os Monstros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d0GLwYQR6BrqyluhzqjVJZktjwl.jpg'),
(96102, 6802, 'Sr. Meia-Noite: Cuidado com os Monstros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h5ydTsZPLYD5Vh4LY0qtttOv0nM.jpg'),
(96103, 6802, 'Sr. Meia-Noite: Cuidado com os Monstros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1vNQlGJEQQYPCwYO0ynIRL3nCg.jpg'),
(96104, 6802, 'Sr. Meia-Noite: Cuidado com os Monstros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yJfMgT5v4fmaeMmV4bqQzLxFfwD.jpg'),
(96105, 6802, 'Sr. Meia-Noite: Cuidado com os Monstros S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rZQC0gn75oDhZPqwALsrUTgY8QE.jpg'),
(96106, 6802, 'Sr. Meia-Noite: Cuidado com os Monstros S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vcFMcNkN4iHZy7HHR9KmxORJrKe.jpg'),
(96107, 6802, 'Sr. Meia-Noite: Cuidado com os Monstros S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i25btCOlSXw35OCPMKmC2f5XIn1.jpg'),
(96108, 6802, 'Sr. Meia-Noite: Cuidado com os Monstros S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s83byrCpgaBgFIHgPlWDBrJ6Slj.jpg'),
(96109, 6802, 'Sr. Meia-Noite: Cuidado com os Monstros S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rZLEUDzRqXAm9Y5891iwOB8ujDk.jpg'),
(96110, 6803, 'V: Os Extraterrestres no Planeta Terra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4qGSJbbtVViCUvqKifp2Wim4xpq.jpg'),
(96111, 6803, 'V: Os Extraterrestres no Planeta Terra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r8o2HV3Uwbp0X8ddDY5nfB4C0lp.jpg'),
(96112, 6803, 'V: Os Extraterrestres no Planeta Terra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rA1HnoDFkSPYO0oWVPB1JSea6qb.jpg'),
(96113, 6803, 'V: Os Extraterrestres no Planeta Terra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sQksmdNgsEHkpJoiGGdvKdA9cdj.jpg'),
(96114, 6803, 'V: Os Extraterrestres no Planeta Terra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFMBXwG68hFxspuFkpNYy8oYx6x.jpg'),
(96115, 6803, 'V: Os Extraterrestres no Planeta Terra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7PFuHHIR7gQQieyK2swj02XRyIs.jpg'),
(96116, 6803, 'V: Os Extraterrestres no Planeta Terra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cVOIWgHFU6CBX0EH3ite96O7zWD.jpg'),
(96117, 6803, 'V: Os Extraterrestres no Planeta Terra S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/axeiC7AtmFHZHLdcmjBAhpagO1o.jpg'),
(96118, 6803, 'V: Os Extraterrestres no Planeta Terra S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eGHQRNI8yKXxEODaF6UGiUieg7J.jpg'),
(96119, 6803, 'V: Os Extraterrestres no Planeta Terra S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2yn0pb6V9VuzGUuXOs6qOUvO9Ti.jpg'),
(96120, 6803, 'V: Os Extraterrestres no Planeta Terra S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMIerrl3mNerBsdfUd7flIHwLth.jpg'),
(96121, 6803, 'V: Os Extraterrestres no Planeta Terra S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lhn2HYhEIfhrmYxbhs68Ack6fYx.jpg'),
(96122, 6803, 'V: Os Extraterrestres no Planeta Terra S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhySyr9jBGDTqgPgiGvPgAlks4x.jpg'),
(96123, 6803, 'V: Os Extraterrestres no Planeta Terra S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/204055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2i07OWAVLvk65wuJoNMu4rhsqsw.jpg'),
(96124, 6803, 'V: Os Extraterrestres no Planeta Terra S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/204056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u9DRpvp63FOhbKwemJoPYfATO4v.jpg'),
(96125, 6803, 'V: Os Extraterrestres no Planeta Terra S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/204057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kgT5jDVRxZiwJXCa5GatIY9CjC8.jpg'),
(96126, 6803, 'V: Os Extraterrestres no Planeta Terra S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/204058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bdNVsEbQ3KLzn594LsOO7TFPEjv.jpg'),
(96127, 6803, 'V: Os Extraterrestres no Planeta Terra S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/204059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7MigZpzRP8xUbtFNCtGpHbXwVn.jpg'),
(96128, 6803, 'V: Os Extraterrestres no Planeta Terra S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/204060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gt8D5cfOamtguc7mdlE8zWLSSmf.jpg'),
(96129, 6804, '24 Horas pra Redecorar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96130, 6804, '24 Horas pra Redecorar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96131, 6804, '24 Horas pra Redecorar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96132, 6804, '24 Horas pra Redecorar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96133, 6804, '24 Horas pra Redecorar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96134, 6804, '24 Horas pra Redecorar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96135, 6804, '24 Horas pra Redecorar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96136, 6804, '24 Horas pra Redecorar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96137, 6804, '24 Horas pra Redecorar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96138, 6804, '24 Horas pra Redecorar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96139, 6804, '24 Horas pra Redecorar S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96140, 6804, '24 Horas pra Redecorar S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96141, 6804, '24 Horas pra Redecorar S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/232078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96142, 6804, '24 Horas pra Redecorar S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/232079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96143, 6804, '24 Horas pra Redecorar S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/232080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96144, 6804, '24 Horas pra Redecorar S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/232081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96145, 6805, '24 Horas pra Redecorar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96146, 6805, '24 Horas pra Redecorar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96147, 6805, '24 Horas pra Redecorar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96148, 6805, '24 Horas pra Redecorar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96149, 6805, '24 Horas pra Redecorar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96150, 6805, '24 Horas pra Redecorar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96151, 6805, '24 Horas pra Redecorar S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96152, 6805, '24 Horas pra Redecorar S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96153, 6806, '24 Horas pra Redecorar S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96154, 6806, '24 Horas pra Redecorar S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96155, 6806, '24 Horas pra Redecorar S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96156, 6806, '24 Horas pra Redecorar S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96157, 6806, '24 Horas pra Redecorar S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96158, 6806, '24 Horas pra Redecorar S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96159, 6806, '24 Horas pra Redecorar S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96160, 6806, '24 Horas pra Redecorar S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96161, 6807, '24 Horas pra Redecorar S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96162, 6807, '24 Horas pra Redecorar S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96163, 6807, '24 Horas pra Redecorar S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96164, 6807, '24 Horas pra Redecorar S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96165, 6807, '24 Horas pra Redecorar S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beZNVfw7J3sa4XZ69N8SnnV8anN.jpg'),
(96166, 6808, 'A Lenda do Tesouro Perdido: No Limiar da História S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ytYmudop7OZSw4Q5euBmlkFFrXH.jpg'),
(96167, 6808, 'A Lenda do Tesouro Perdido: No Limiar da História S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ycaknplb1Z6ioc2YsSRXRTmFjL0.jpg'),
(96168, 6808, 'A Lenda do Tesouro Perdido: No Limiar da História S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208197.mp4', 'http://image.tmdb.org/t/p/w1280/oUUKboxwLuXIk3FmTde0cCjaZiJ.jpg'),
(96169, 6808, 'A Lenda do Tesouro Perdido: No Limiar da História S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208198.mp4', 'http://image.tmdb.org/t/p/w1280/5uAhT8astSNrTwpcCkcsHqnWpjV.jpg'),
(96170, 6808, 'A Lenda do Tesouro Perdido: No Limiar da História S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208199.mp4', 'http://image.tmdb.org/t/p/w1280/zU3riyZbI1RIl5fvK1PUPjAUHWM.jpg'),
(96171, 6808, 'A Lenda do Tesouro Perdido: No Limiar da História S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208200.mp4', 'http://image.tmdb.org/t/p/w1280/zgvb3o2oeWfmGFvOqeI1b4JdHxx.jpg'),
(96172, 6808, 'A Lenda do Tesouro Perdido: No Limiar da História S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208201.mp4', 'http://image.tmdb.org/t/p/w1280/b2jo4nzzjmhVEkZTdDeMr0eKDMM.jpg'),
(96173, 6808, 'A Lenda do Tesouro Perdido: No Limiar da História S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208202.mp4', 'http://image.tmdb.org/t/p/w1280/lzVQcgMylIJERCAIJTQV7KgkcwA.jpg'),
(96174, 6808, 'A Lenda do Tesouro Perdido: No Limiar da História S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208203.mp4', 'http://image.tmdb.org/t/p/w1280/pZL1LBF9ACQYRNPosPyZt90XnyZ.jpg'),
(96175, 6808, 'A Lenda do Tesouro Perdido: No Limiar da História S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208204.mp4', 'http://image.tmdb.org/t/p/w1280/noOsbDSbwfABGhc3YRbVSkzIdTU.jpg'),
(96176, 6809, 'Cozinha em Conta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/myYYtb9BgpZIa7v8klNrScdffWv.jpg'),
(96177, 6809, 'Cozinha em Conta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n1M017dTUxsxjGxydvGarA7VNo7.jpg'),
(96178, 6809, 'Cozinha em Conta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a5BG5sBS7GLdXJb5Ymu84WTxk3V.jpg'),
(96179, 6809, 'Cozinha em Conta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bcZqcBGtV4OzNNzXot9GaUi6zOn.jpg'),
(96180, 6809, 'Cozinha em Conta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7w3Je2kET32y6opOvMPNCuhmAPK.jpg'),
(96181, 6809, 'Cozinha em Conta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iX7PHpdeftYgCZnJDxBD402VNLX.jpg'),
(96182, 6809, 'Cozinha em Conta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v1i4UhTpIQJe8Yn7vLjJxYVySbG.jpg'),
(96183, 6809, 'Cozinha em Conta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7pIU8gbqbeXUMkqpegbaxLN8OM.jpg'),
(96184, 6810, 'Do Jeito Delas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/QUL6EEA3RMwnCUeeTNsjLEJIta.jpg'),
(96185, 6810, 'Do Jeito Delas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/agoVsLBdYHIMiJKkC5woT4tMmO2.jpg'),
(96186, 6810, 'Do Jeito Delas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Zfd5LnLNlBBFOI7ekVf9pYaTa2.jpg'),
(96187, 6810, 'Do Jeito Delas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mX7st1ZhP7h2lDQPNu3dgYHfILy.jpg'),
(96188, 6810, 'Do Jeito Delas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/phzFMi5YTv7vfXjMukN1myQ4bwI.jpg'),
(96189, 6810, 'Do Jeito Delas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/An0Mx7mboZl4TK4ojSMqdooOcda.jpg'),
(96190, 6810, 'Do Jeito Delas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7qfpKebFNMiAfBolcLTyiMdrbnj.jpg'),
(96191, 6810, 'Do Jeito Delas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lhoh4U4pcozVYuS1vjOj5ZU7Efy.jpg'),
(96192, 6810, 'Do Jeito Delas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/203521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2XHHAzM3wk3irfujO1mjosKmAc8.jpg'),
(96193, 6810, 'Do Jeito Delas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/203522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFiOR4WnszRHmV8TzwftyRsIuM0.jpg'),
(96194, 6811, 'Harry e Meghan Escapando do Palacio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dgEhXdYQV7e55viL2HolOMmFKpI.jpg'),
(96195, 6811, 'Harry e Meghan Escapando do Palacio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bDumxPjwjTUCYGQzttsxBU7KQjC.jpg'),
(96196, 6811, 'Harry e Meghan Escapando do Palacio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tUHe8FCQnLfJ6vnEZZgGcFda4gZ.jpg'),
(96197, 6811, 'Harry e Meghan Escapando do Palacio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qkyGwwahKgKXbGOjZTvYuSX59AO.jpg'),
(96198, 6811, 'Harry e Meghan Escapando do Palacio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vApMS5kiO42WfphGlJLwE5jNTrx.jpg'),
(96199, 6811, 'Harry e Meghan Escapando do Palacio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jNbUdCYquYIQESVtqd2DHYFvJhr.jpg'),
(96200, 6812, 'Jogando com o Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ec6p6t2zKSganwT4ovbaXlP4z4.jpg'),
(96201, 6812, 'Jogando com o Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/triKarOD0hRsaquy5Eq3K9qZahC.jpg'),
(96202, 6812, 'Jogando com o Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/enWg6pLAQTl6HhVLPH3SQH1BjHH.jpg'),
(96203, 6812, 'Jogando com o Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vLmC1hFfgoeS2TWF7Gqvwv2HGC8.jpg'),
(96204, 6812, 'Jogando com o Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205509.mp4', 'http://image.tmdb.org/t/p/w1280/hxkuho6Ip1avoTIJi5rlCxl6EX1.jpg'),
(96205, 6812, 'Jogando com o Amor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sJYrefmYq7RBkqPBlvIQLvipAXA.jpg'),
(96206, 6812, 'Jogando com o Amor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qG6jUwiudpnwY9p0weyPt07JOtb.jpg'),
(96207, 6812, 'Jogando com o Amor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sdA1KSUvDWY2X3tCOehZLajnbpY.jpg'),
(96208, 6813, 'Longe Demais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gW1c0R2N32EE7CnibVgHekFS3Qn.jpg'),
(96209, 6813, 'Longe Demais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rlEKNyFNbzdkNoCrCZcqFu5KjMz.jpg'),
(96210, 6813, 'Longe Demais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2FFcUYCRe1JgFlAfPbFZh3T7l5h.jpg'),
(96211, 6813, 'Longe Demais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8zdafNKs6Kq1g5z6JyEmjaZn8N0.jpg'),
(96212, 6813, 'Longe Demais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9kdF0YX74YWNR5c4ixJz0fV2Sv5.jpg'),
(96213, 6814, 'Nevasca de Natal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zCIu1d5XmJ4GLx4QMmnNpEREb9P.jpg'),
(96214, 6814, 'Nevasca de Natal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gPi5nPPL7SXihKuvRMT40q4alZI.jpg'),
(96215, 6814, 'Nevasca de Natal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tKwStqv1YWHX7Bpss3arz6xsxgt.jpg'),
(96216, 6814, 'Nevasca de Natal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5bAppBKT108UXEAs8ZJrjsGX48i.jpg'),
(96217, 6814, 'Nevasca de Natal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tKoa5dr2FYPnSr0adVVgD3svLjD.jpg'),
(96218, 6814, 'Nevasca de Natal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pLTrmZzKahaTQIjY2YEmKI3Sxw7.jpg'),
(96219, 6815, 'O Vilão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/58TIVNOliKysAtPCOZOJsSmWQhu.jpg'),
(96220, 6815, 'O Vilão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ySzr6Pn9B2pYwG40kl6uewKPjMW.jpg'),
(96221, 6815, 'O Vilão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vlyKQ4YdMAwHrhtBlXSounyfXoO.jpg'),
(96222, 6815, 'O Vilão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/reLVrV9jOcg2vsJUsdNKaCKICZ1.jpg'),
(96223, 6815, 'O Vilão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t8yKrZ6zuYs9f6APO0Y3YmbS5AI.jpg'),
(96224, 6815, 'O Vilão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aaydcJLKvFOB9uYYwirrwCWSNQR.jpg'),
(96225, 6816, 'Os Caminhos de Jesus S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ndKhTdXTm6HKlI9G1eC75Oy7soJ.jpg'),
(96226, 6816, 'Os Caminhos de Jesus S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ndKhTdXTm6HKlI9G1eC75Oy7soJ.jpg'),
(96227, 6817, 'Recruta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/203480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aKZ1c1DtIudwJ7wpdEJWULBVk1m.jpg'),
(96228, 6817, 'Recruta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/203481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6oYnkgrOchxp1ZJMrsPsmgOksOP.jpg'),
(96229, 6817, 'Recruta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/203482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/htlaCKafgjWzgc0ywzNSVaDxP9Z.jpg'),
(96230, 6817, 'Recruta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/203483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dDxMKYAzx0lLV3YgWcLW67MFB1d.jpg'),
(96231, 6817, 'Recruta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/203484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n57QO00VykGvQYPNCLTspigI6aG.jpg'),
(96232, 6817, 'Recruta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/203485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p0FapI6zO5dk416zqbkNbMGp2hy.jpg'),
(96233, 6817, 'Recruta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/203486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBrnZYLANUsH2LKS4RgrsR65Mug.jpg'),
(96234, 6817, 'Recruta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/203487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lLZTCPYvuY5jUYKcBX3xNi2iW4n.jpg'),
(96235, 6818, 'Recruta S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/678398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kaFkswPMDoTDQ7Xt4gHMc8CDsVq.jpg'),
(96236, 6818, 'Recruta S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/678399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kaFkswPMDoTDQ7Xt4gHMc8CDsVq.jpg'),
(96237, 6818, 'Recruta S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/678400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kaFkswPMDoTDQ7Xt4gHMc8CDsVq.jpg'),
(96238, 6818, 'Recruta S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/678401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kaFkswPMDoTDQ7Xt4gHMc8CDsVq.jpg'),
(96239, 6818, 'Recruta S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/678402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kaFkswPMDoTDQ7Xt4gHMc8CDsVq.jpg'),
(96240, 6818, 'Recruta S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/678403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kaFkswPMDoTDQ7Xt4gHMc8CDsVq.jpg'),
(96241, 6819, 'Sonic Prime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uKEVjCiGsrBF1aOENUzW4knfSLv.jpg'),
(96242, 6819, 'Sonic Prime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fIwvsMYU3bwWYJwqu1C3K4fFplD.jpg'),
(96243, 6819, 'Sonic Prime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w1KRX35ZtvrNI0roZIOULkfa8Sr.jpg'),
(96244, 6819, 'Sonic Prime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/za21XjNoORXdCydJ3fjZ0mBPbW8.jpg'),
(96245, 6819, 'Sonic Prime S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cnIxaELYobEJrmaMI4hrHUXsD6f.jpg'),
(96246, 6819, 'Sonic Prime S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9jkQKujUHTnv5VKI9iFiv71pOmw.jpg'),
(96247, 6819, 'Sonic Prime S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/psVWNu8O4B2Sp1p1PUB7tVAkOGY.jpg'),
(96248, 6819, 'Sonic Prime S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cL2bBXUMU9L40p55hXbhoVgypG2.jpg'),
(96249, 6820, 'Sonic Prime S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6HOncffcJsiReTFQiym2u2kCqbu.jpg'),
(96250, 6820, 'Sonic Prime S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ipXGknR41gSR1qBcv1MqXVpQlwd.jpg'),
(96251, 6820, 'Sonic Prime S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iKNMq0GsOMwykQum4TA0OganYft.jpg'),
(96252, 6820, 'Sonic Prime S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgmIJcknNpp0f62yJCH5JyORkdQ.jpg'),
(96253, 6820, 'Sonic Prime S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a0iLRnBEY2j6wuqunPjHCJHuC09.jpg'),
(96254, 6820, 'Sonic Prime S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2UlDSrV2I9L0PxVHXRXVg3f2F39.jpg'),
(96255, 6820, 'Sonic Prime S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i0K6hT0VVXCMk2Zml22mpiCc4Ch.jpg'),
(96256, 6820, 'Sonic Prime S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s6dIBpp9FW0EgtTGzgkgtdXZEIT.jpg'),
(96257, 6821, 'Sonic Prime S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tWAc53xRpc1Sdqa1twm3PwHjSeV.jpg'),
(96258, 6821, 'Sonic Prime S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tWAc53xRpc1Sdqa1twm3PwHjSeV.jpg'),
(96259, 6821, 'Sonic Prime S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tWAc53xRpc1Sdqa1twm3PwHjSeV.jpg'),
(96260, 6821, 'Sonic Prime S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tWAc53xRpc1Sdqa1twm3PwHjSeV.jpg'),
(96261, 6821, 'Sonic Prime S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tWAc53xRpc1Sdqa1twm3PwHjSeV.jpg'),
(96262, 6821, 'Sonic Prime S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tWAc53xRpc1Sdqa1twm3PwHjSeV.jpg'),
(96263, 6821, 'Sonic Prime S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tWAc53xRpc1Sdqa1twm3PwHjSeV.jpg'),
(96264, 6822, 'The Nanny S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nk7BvW4OLmseRfuBJvRrX7WZtHp.jpg'),
(96265, 6822, 'The Nanny S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5dhCPTpD0tAl4Z4WJO5ZVLbW14.jpg'),
(96266, 6822, 'The Nanny S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kU4d6DOqI45Xks3Sj6upS9CCCmz.jpg'),
(96267, 6822, 'The Nanny S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rZImFTzP7tXSb1j4WyNJ6iLtgnj.jpg'),
(96268, 6822, 'The Nanny S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6SXIDsvmcgWKjbaAFXGmRqj8iCj.jpg'),
(96269, 6822, 'The Nanny S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ssUqB0RYs8fmUmDHjvmb8UWZL4.jpg'),
(96270, 6822, 'The Nanny S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qPIi1ZFnDzvq74jHJkhwf8Ro2Ci.jpg'),
(96271, 6822, 'The Nanny S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bNMrWvB1kg1AtNKipFGGpVl2Lvw.jpg'),
(96272, 6822, 'The Nanny S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ArCbZxB4tUrQWezCz58vNS224yU.jpg'),
(96273, 6822, 'The Nanny S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fxTrLJHzOoBH8bTEKtpuOAfmTXT.jpg'),
(96274, 6822, 'The Nanny S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jEYpRV3UrRPKsc7qDCExetV9nlu.jpg'),
(96275, 6822, 'The Nanny S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nE91j9cNAiHADlyhBjZXYIt93aB.jpg'),
(96276, 6822, 'The Nanny S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/202750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/DeMPipaY2xiEgQdfFBVdLS2nnI.jpg'),
(96277, 6822, 'The Nanny S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/202751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbJtDYy0bCTiLcAL6xg3jxpFMuA.jpg'),
(96278, 6822, 'The Nanny S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/202752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gYK7d6nuCT979XjjYiyIzFkrxad.jpg'),
(96279, 6822, 'The Nanny S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/202753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bncaeeJuElPAhvP8BmoWgnbOkdU.jpg'),
(96280, 6822, 'The Nanny S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/202754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fP0jEA57IqXnYLWTsVfyPbeuKlv.jpg'),
(96281, 6822, 'The Nanny S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/202755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ugKCiev7EZdm0wEdgfBY1jiOQez.jpg'),
(96282, 6822, 'The Nanny S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/202756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pIu53NBiSWR4uWGZyEOTBREykVX.jpg'),
(96283, 6822, 'The Nanny S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/202757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r4wKlwR3kNfWMLQ4E12YBkADBKf.jpg'),
(96284, 6822, 'The Nanny S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/202758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2nGwZphbvCnSJBAlw0AgO3oJV7i.jpg'),
(96285, 6822, 'The Nanny S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/202759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/syA4ax2ol5v5BiySmhurU9Iwu8Y.jpg'),
(96286, 6823, 'The Nanny S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rw8iAICL83nbkoSHsR2IpPHrEeG.jpg'),
(96287, 6823, 'The Nanny S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3XgiJe6waeXry57fP1ILU9ekRDk.jpg'),
(96288, 6823, 'The Nanny S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/isJlPrXgbt0PQSxV109cFwvcmxi.jpg'),
(96289, 6823, 'The Nanny S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8LhbegnS23x42MJleUhKUjKOj7L.jpg'),
(96290, 6823, 'The Nanny S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zOxc7MZHDvtb9Fw8JssdZdXEJNe.jpg'),
(96291, 6823, 'The Nanny S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iXHau2gBLmk6Cd7SAS7V6WfR6P3.jpg'),
(96292, 6823, 'The Nanny S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3PArgREiqVQLsf0MmsU98NvgkaO.jpg'),
(96293, 6823, 'The Nanny S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMlLJTGr20Q5jzDDOJ4vePHC9Yo.jpg'),
(96294, 6823, 'The Nanny S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p0tkIHB3EYz1gLT46hopBmxTMwn.jpg'),
(96295, 6823, 'The Nanny S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bC26zRqC7jC4W5fD5Wjh4QNC12J.jpg'),
(96296, 6823, 'The Nanny S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z4PcPmQqdN1CH7n4c0gqLweFiWH.jpg'),
(96297, 6823, 'The Nanny S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sY17qg65fiARYe3jzATzCF1fCMl.jpg'),
(96298, 6823, 'The Nanny S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/202772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iIZ9zmuuE3da97Rfi7qAl6Jju9X.jpg'),
(96299, 6823, 'The Nanny S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/202773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZ4Zc6d6qQe8jejrY1MYy2a8iB6.jpg'),
(96300, 6823, 'The Nanny S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/202774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m698803oHCn40bMWQhouKjxqs86.jpg'),
(96301, 6823, 'The Nanny S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/202775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7PehkjdrQ5EyIcBIt8RNeg5ncWe.jpg'),
(96302, 6824, 'The Nanny S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cV7ZfiqYmBKOaq3WoxN6gWSTS2l.jpg'),
(96303, 6824, 'The Nanny S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5LnQgkwHS0i89kkEzsKySMOhHBy.jpg'),
(96304, 6824, 'The Nanny S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3WoD6uXd0Gxtz8WiYZYWff6R0Md.jpg'),
(96305, 6824, 'The Nanny S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dTabJvyiekOYdETjWpAYTP5UoF9.jpg'),
(96306, 6824, 'The Nanny S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rQR2uPniePTi2fdC0mZrDg36izJ.jpg'),
(96307, 6824, 'The Nanny S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yywpRIeA1H8K1GOAjUAwhc2UQuU.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(96308, 6824, 'The Nanny S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mvwX6IGAg0uglVGE5fwfhvpszSY.jpg'),
(96309, 6824, 'The Nanny S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3gHG70mDpbtYXQCokOQ4tg3L1Q5.jpg'),
(96310, 6824, 'The Nanny S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7VLemNy7bPg6sgB9hA4KG68zwTF.jpg'),
(96311, 6824, 'The Nanny S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eWldeWTGbrh9RFhkYhofq4DOcds.jpg'),
(96312, 6824, 'The Nanny S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yD7dIMMcsHm2mUWiKLjKpQUaZLE.jpg'),
(96313, 6824, 'The Nanny S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1xWcKdkTE43NYiePVeVvX08T1n0.jpg'),
(96314, 6824, 'The Nanny S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/202788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qlUenCzr3fMJu3JvvBQgec5qeMJ.jpg'),
(96315, 6824, 'The Nanny S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/202789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1hbjWVsDL72LCdCe9w23wpMtmNC.jpg'),
(96316, 6824, 'The Nanny S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/202790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r8NCBqlfrT8WYaEg08pLtv7mqPB.jpg'),
(96317, 6824, 'The Nanny S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/202791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hWvPjbwql8URj6S4OiFOmsbpP0o.jpg'),
(96318, 6824, 'The Nanny S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/202792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xGa8S7A1uG53PnR5vZS3q4mI0aY.jpg'),
(96319, 6824, 'The Nanny S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/202793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2W5ZfxiwwN8lKDHVhDtBz48pa7T.jpg'),
(96320, 6824, 'The Nanny S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/202794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5KQMVyjrEKNxpBfxTe6oLJLW4ey.jpg'),
(96321, 6824, 'The Nanny S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/202795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ejRCJ1NySngwbCVWg90z9Or6QFO.jpg'),
(96322, 6824, 'The Nanny S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/202796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hPJVrM38TVVUi5JUCmiuI6qU6Nd.jpg'),
(96323, 6824, 'The Nanny S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/202797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nK2o6rN2JzFu5s0RCsJZ1LCO4R4.jpg'),
(96324, 6824, 'The Nanny S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/202798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/byfwgqMwOAGl5r5tWizQiNEnpkB.jpg'),
(96325, 6824, 'The Nanny S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/202799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hv9utXvKlz4Q4Zw1V75WzkeAQ4J.jpg'),
(96326, 6824, 'The Nanny S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/202800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xyOVkQxh4I4pPABhClE4LKlD2dw.jpg'),
(96327, 6824, 'The Nanny S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/202801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4tpTpTZbaxXu6Qs5kLPx0DIkev7.jpg'),
(96328, 6825, 'The Nanny S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nMNwKjxlXw3mukH1rNIaxVdM9Es.jpg'),
(96329, 6825, 'The Nanny S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iHrbKnJlLGjdn5mahlg7I9iMJ0F.jpg'),
(96330, 6825, 'The Nanny S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1A7YMX9p3p7RoEG4DIcRGSpbnXw.jpg'),
(96331, 6825, 'The Nanny S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A1V5jwogOCsahBSJnD0EO8r1VQZ.jpg'),
(96332, 6825, 'The Nanny S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pLxEGEDMDOhxzZWnwrLmbdjXF1A.jpg'),
(96333, 6825, 'The Nanny S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a87wu0eOJqkRP9V4p8mGLqEFDE3.jpg'),
(96334, 6825, 'The Nanny S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/abd3tlX3WZUesSZSJ0PGWqeBt5C.jpg'),
(96335, 6825, 'The Nanny S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o3V2K32U3L8ebhOZSnPQDDIQFKo.jpg'),
(96336, 6825, 'The Nanny S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cq7r8dMvdPB6bFyG1sWtq5E78C5.jpg'),
(96337, 6825, 'The Nanny S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bS6pUi2YqLd9xbr7cUbT0utB1VH.jpg'),
(96338, 6825, 'The Nanny S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jE3OFCXwdlIWD5xVeWstQHqekhe.jpg'),
(96339, 6825, 'The Nanny S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sVR3Z15WKZw3QrsMpENqdHMU38X.jpg'),
(96340, 6825, 'The Nanny S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/202814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/trl43ojb70E6s3M7fbmdArPxLh9.jpg'),
(96341, 6825, 'The Nanny S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/202815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5af8XYbmTLBqCp9gpmH0vqCu5xD.jpg'),
(96342, 6825, 'The Nanny S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/202816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0bbg9QtpivJmur8I8W6PRuvSDK.jpg'),
(96343, 6825, 'The Nanny S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/202817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nizWDBMMXS4AoiO5Zkg8qy253Jx.jpg'),
(96344, 6825, 'The Nanny S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/202818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s0QzJsE79ZoZVYp5wNnRlWWAex8.jpg'),
(96345, 6825, 'The Nanny S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/202819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mPDBNGOqoGw4vIbohCezbHPV0EK.jpg'),
(96346, 6825, 'The Nanny S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/202820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u2KBo7VHgo25NqxZ50hPGZS53cJ.jpg'),
(96347, 6825, 'The Nanny S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/202821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9NLoiXTX1qCeBtIaarO2OiccyK6.jpg'),
(96348, 6825, 'The Nanny S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/202822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/imPtxemXdIewPW3tcMTzv4rcsnv.jpg'),
(96349, 6825, 'The Nanny S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/202823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qey1m1UNBurIPaqbAoSsF1XbFsV.jpg'),
(96350, 6825, 'The Nanny S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/202824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f5fyNoqQQDeZVU6musLun8zIeuV.jpg'),
(96351, 6825, 'The Nanny S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/202825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AgsxARCOO5r1MOUDZeGrS0xesni.jpg'),
(96352, 6825, 'The Nanny S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/202826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/43QMtp7BPlZgNTPL46nhFLbFzL8.jpg'),
(96353, 6825, 'The Nanny S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/202827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3lXlNfR4w8T7LqpdfsfIVB9IMvv.jpg'),
(96354, 6826, 'The Nanny S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vWJWXaXuZXtNbvRQOnD8P00XowA.jpg'),
(96355, 6826, 'The Nanny S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkoFZmiH04kup3Gx59QWIyp8M1C.jpg'),
(96356, 6826, 'The Nanny S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3x5vnaWzcRm8uvSDOciliW46Yra.jpg'),
(96357, 6826, 'The Nanny S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fiqTosko2u55e3M3N9usJwgOZez.jpg'),
(96358, 6826, 'The Nanny S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2BEBf2dBqp314pJDQIVmvPE26c5.jpg'),
(96359, 6826, 'The Nanny S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4SDCVwFnjSDw8axpuG3fNh09aGw.jpg'),
(96360, 6826, 'The Nanny S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/akxwm2PdwUQDFY4XtPHDl6UHjDG.jpg'),
(96361, 6826, 'The Nanny S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tm5evzyODGIocZYPaHYN9U7mlEX.jpg'),
(96362, 6826, 'The Nanny S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7H6NxSUIjrDDevPTV3GG8OIxdYk.jpg'),
(96363, 6826, 'The Nanny S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5FA0Pla8Fl3EGzs0iB7Vy6uoGOA.jpg'),
(96364, 6826, 'The Nanny S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8TANMGpcylbIT2y7JSvj3qaRHqS.jpg'),
(96365, 6826, 'The Nanny S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEQCGQI9Mw5qfEul7dQanrn0bXq.jpg'),
(96366, 6826, 'The Nanny S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/202840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8BAchRtEO6pCG1AEYymo7jpfwcZ.jpg'),
(96367, 6826, 'The Nanny S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/202841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uLJD6SqfTwY1NTqe13JtEE6Syem.jpg'),
(96368, 6826, 'The Nanny S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/202842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/btTyMS72ifXemCg5bFKfO3VlBuF.jpg'),
(96369, 6826, 'The Nanny S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/202843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5SkJMdg3RUbK7ulb2QVdxDd3sjz.jpg'),
(96370, 6826, 'The Nanny S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/202844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p7WWsr76w87I2LOnyAunkkRTwxd.jpg'),
(96371, 6826, 'The Nanny S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/202845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rjXgsU6pgX28CtIyiMirRE60VBN.jpg'),
(96372, 6826, 'The Nanny S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/202846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kaLhE00KAxwvxkM1nIPsPQ5Ct15.jpg'),
(96373, 6826, 'The Nanny S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/202847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pg9EawScvbVSQrcBL52N6YICLVF.jpg'),
(96374, 6826, 'The Nanny S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/202848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l2t2t0OPY1PiEInJ0Wm7cGJun4f.jpg'),
(96375, 6826, 'The Nanny S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/202849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6zdg6hF4x2JFFmYlSXM0e2Taa2H.jpg'),
(96376, 6826, 'The Nanny S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/202850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iKK8q6KsUcxgL8qyvZnu2bHPVXz.jpg'),
(96377, 6827, 'The Nanny S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7vciM7Xr6UaIKBPm6UXQQYMAjLD.jpg'),
(96378, 6827, 'The Nanny S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tkXmEbNBUDaUbBIKlV5d5QPmJOy.jpg'),
(96379, 6827, 'The Nanny S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cdtjpm5FM386OhzLkxI8TXagTxE.jpg'),
(96380, 6827, 'The Nanny S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yj7fltKQS31xkBKN5Y8fT53PeCa.jpg'),
(96381, 6827, 'The Nanny S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xqvPISHSQ6GtqJGrVGHXkmQRLHc.jpg'),
(96382, 6827, 'The Nanny S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/68pUeGyRQCMXggAFLxb4u0Uqb56.jpg'),
(96383, 6827, 'The Nanny S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xnug83Qfjh09MSHR9Y5uJ4g5xmY.jpg'),
(96384, 6827, 'The Nanny S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/czMrHIJaObmYNCfCT9Di5g6YIPw.jpg'),
(96385, 6827, 'The Nanny S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vo5sr09AY7HKWigPHl9SIWx73Mx.jpg'),
(96386, 6827, 'The Nanny S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2IsV8PWUXFsgHqvJtgKG7IcRLlq.jpg'),
(96387, 6827, 'The Nanny S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wXmtQk5x4ILYBpdxXC9i2oCoki9.jpg'),
(96388, 6827, 'The Nanny S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3n7BRQfljejjJYVynitTwrQmSlO.jpg'),
(96389, 6827, 'The Nanny S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/202863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjK6g33jyKnjeZolkg2pemdxRFF.jpg'),
(96390, 6827, 'The Nanny S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/202864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6qSUvwZhLP0UtZGdYfjdq1NURSs.jpg'),
(96391, 6827, 'The Nanny S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/202865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nngQuHgGwmqlQbUHWUMK5KwvUfU.jpg'),
(96392, 6827, 'The Nanny S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/202866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qplqfAxZ1EgGuDO1aVNx4UlunQd.jpg'),
(96393, 6827, 'The Nanny S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/202867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xwSns6rPAflNsouBSWEYfaiNzwR.jpg'),
(96394, 6827, 'The Nanny S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/202868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/js5xeAuOl9qVan1UwowhiCw3QHn.jpg'),
(96395, 6827, 'The Nanny S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/202869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kuka4JSIAv3b56ljcSAYazilGH6.jpg'),
(96396, 6827, 'The Nanny S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/202870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ch7NUmvGBFiTrdZnvCdZoD5Xkx.jpg'),
(96397, 6827, 'The Nanny S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/202871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9mPNDyOhHjG2uBS249lX5qN4MpK.jpg'),
(96398, 6827, 'The Nanny S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/202872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDMnefR05MOxxZB8VDMRUIrTwRV.jpg'),
(96399, 6828, 'Tudo Aquilo Que Nunca Foi Dito S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gm2rsgFXP9upClA9n8bKf6bcCIV.jpg'),
(96400, 6828, 'Tudo Aquilo Que Nunca Foi Dito S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/29aLU81HimEXq7NkYVhXR6K8b7o.jpg'),
(96401, 6828, 'Tudo Aquilo Que Nunca Foi Dito S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5tIlhM0n6qvjCXDSfI0AudwXhn6.jpg'),
(96402, 6828, 'Tudo Aquilo Que Nunca Foi Dito S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/snLF46RsmMsQhc3nRT1QQy6xbTY.jpg'),
(96403, 6828, 'Tudo Aquilo Que Nunca Foi Dito S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4wp2jifFaOsf5M30VSOPQFCDOgM.jpg'),
(96404, 6828, 'Tudo Aquilo Que Nunca Foi Dito S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204432.mp4', 'http://image.tmdb.org/t/p/w1280/1sphwTB5mr98XCK6lbTS1d4MpNo.jpg'),
(96405, 6828, 'Tudo Aquilo Que Nunca Foi Dito S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204433.mp4', 'http://image.tmdb.org/t/p/w1280/bWX1BDK5FNioTs9qnQiCXUF0T9k.jpg'),
(96406, 6828, 'Tudo Aquilo Que Nunca Foi Dito S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204434.mp4', 'http://image.tmdb.org/t/p/w1280/kXIuvPUdSfwyjjFSsC6gpHhC5JO.jpg'),
(96407, 6828, 'Tudo Aquilo Que Nunca Foi Dito S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204435.mp4', 'http://image.tmdb.org/t/p/w1280/pKdHaP9rLM79mYnbLxlJ8H1ftWL.jpg'),
(96408, 6829, 'Congresso Brasil Paralelo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iXtAgKuFR2YupumXhcycYcGAlot.jpg'),
(96409, 6829, 'Congresso Brasil Paralelo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iXtAgKuFR2YupumXhcycYcGAlot.jpg'),
(96410, 6829, 'Congresso Brasil Paralelo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iXtAgKuFR2YupumXhcycYcGAlot.jpg'),
(96411, 6829, 'Congresso Brasil Paralelo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iXtAgKuFR2YupumXhcycYcGAlot.jpg'),
(96412, 6829, 'Congresso Brasil Paralelo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iXtAgKuFR2YupumXhcycYcGAlot.jpg'),
(96413, 6829, 'Congresso Brasil Paralelo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iXtAgKuFR2YupumXhcycYcGAlot.jpg'),
(96414, 6830, 'Alcatraz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A97bfgXNHR97WUTn52B4e8zsmn2.jpg'),
(96415, 6830, 'Alcatraz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nrGgXt4V411pfnZO5uiJXgUJlpM.jpg'),
(96416, 6830, 'Alcatraz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i2ml8SlxYfOrpK8dnGx1BKnt4wd.jpg'),
(96417, 6830, 'Alcatraz S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/G6aPf377VLypT1VQ9MKVPudAJD.jpg'),
(96418, 6830, 'Alcatraz S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oWpo0HfxEHFP4NDYBXt8gtqqqIl.jpg'),
(96419, 6830, 'Alcatraz S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/41hBbVrTiuc4Qy2a6JANOlJHNx7.jpg'),
(96420, 6830, 'Alcatraz S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wexLiLJDgVhrmh0TEg1F4ekXiPG.jpg'),
(96421, 6830, 'Alcatraz S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vv1zXxt4lA4Xh8qg4FlTLTlKJcB.jpg'),
(96422, 6830, 'Alcatraz S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tZGd3yLdrL5SZ1ZOk1rysJN72rY.jpg'),
(96423, 6830, 'Alcatraz S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nKZ5lSWC68HyjNUbLBnxq1lRc1I.jpg'),
(96424, 6830, 'Alcatraz S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ndyMWqSFOqSwuHIhDevFzMDBNt5.jpg'),
(96425, 6830, 'Alcatraz S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jLpzf8WDYHTZ7CfadjfXCTKoVm0.jpg'),
(96426, 6830, 'Alcatraz S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/202936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/is2MttNCBhK3R8sLT7Rod7mbxJn.jpg'),
(96427, 6831, 'Disney Entre Laços S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ruf6aDDuZ4nbg32gOZF43Om6tj5.jpg'),
(96428, 6831, 'Disney Entre Laços S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fs0xR9Ml6GlZDWAYYB9JU7m4uje.jpg'),
(96429, 6831, 'Disney Entre Laços S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/viyz9OIjNuVYUAtx0nX9CAeKX8W.jpg'),
(96430, 6831, 'Disney Entre Laços S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/enhV61VQjS7HOSh4MAPSpS7wHWR.jpg'),
(96431, 6831, 'Disney Entre Laços S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6rZkQqzib4LJIh7VweHESw3KXyn.jpg'),
(96432, 6831, 'Disney Entre Laços S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7hjKQvlCD9NGoNiIb2taFNCT9QE.jpg'),
(96433, 6831, 'Disney Entre Laços S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63tYgiX5R2eVAmJBTQL4F217XCs.jpg'),
(96434, 6831, 'Disney Entre Laços S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCBEdnWzPWFyTYQjVL3WqAlK1pn.jpg'),
(96435, 6831, 'Disney Entre Laços S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sMxyA64DrMJcfU0IiG3cP61YDN7.jpg'),
(96436, 6831, 'Disney Entre Laços S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4rszE5YXU2MsVFTar6d2LI69X1A.jpg'),
(96437, 6832, 'O Cangaceiro do Futuro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j0TdeK3G8FIsZ6rtY1G22UN5mKi.jpg'),
(96438, 6832, 'O Cangaceiro do Futuro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j0TdeK3G8FIsZ6rtY1G22UN5mKi.jpg'),
(96439, 6832, 'O Cangaceiro do Futuro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j0TdeK3G8FIsZ6rtY1G22UN5mKi.jpg'),
(96440, 6832, 'O Cangaceiro do Futuro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j0TdeK3G8FIsZ6rtY1G22UN5mKi.jpg'),
(96441, 6832, 'O Cangaceiro do Futuro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j0TdeK3G8FIsZ6rtY1G22UN5mKi.jpg'),
(96442, 6832, 'O Cangaceiro do Futuro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j0TdeK3G8FIsZ6rtY1G22UN5mKi.jpg'),
(96443, 6832, 'O Cangaceiro do Futuro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j0TdeK3G8FIsZ6rtY1G22UN5mKi.jpg'),
(96444, 6833, 'The Fabulous S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/apwwhO4jiWDf4g02vScWc6T17TV.jpg'),
(96445, 6833, 'The Fabulous S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/54lxcc2AJTxsEa8H6K0Tj1e9RnY.jpg'),
(96446, 6833, 'The Fabulous S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/64MHVGCsouwFPv6Y0TDlg0Qv7zy.jpg'),
(96447, 6833, 'The Fabulous S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dAMFVe6ZUKXihawUm8DxrqMiJj.jpg'),
(96448, 6833, 'The Fabulous S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9KMC3WZR4OUsgR7NDtaGrBvP2dt.jpg'),
(96449, 6833, 'The Fabulous S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xXjK9KQHiPT7NYhHgH9fqBhnJLQ.jpg'),
(96450, 6833, 'The Fabulous S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nU1QhAUZDR10bJqsC5MiX6j9k7L.jpg'),
(96451, 6833, 'The Fabulous S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zHDlKvwSC6HqWCN0WORWRswFpZ9.jpg'),
(96452, 6834, 'The Witcher: A Origem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kG0fRqGwdMwUR0lUrZfkkeVlI5R.jpg'),
(96453, 6834, 'The Witcher: A Origem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4h6HMMkj1gwMIbCrLEtOV3N7Ovj.jpg'),
(96454, 6834, 'The Witcher: A Origem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Z9Zz0ODpnZ3J0kzbeYWO0NB3c3.jpg'),
(96455, 6834, 'The Witcher: A Origem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wR6cBEsL1bWZM9wxhu1axeal53V.jpg'),
(96456, 6835, 'Tulsa King S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dOe72mwnTFg6ec4gX8szoNgafEr.jpg'),
(96457, 6835, 'Tulsa King S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2CpHeTMQQJjgIAWXE3VyPeUPmux.jpg'),
(96458, 6835, 'Tulsa King S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208126.mp4', 'http://image.tmdb.org/t/p/w1280/ntW59Upv7ihGxHgYLTQDNYu5y4b.jpg'),
(96459, 6835, 'Tulsa King S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208127.mp4', 'http://image.tmdb.org/t/p/w1280/jTesVrxg1CkdKYHeQsYDOYDAW2R.jpg'),
(96460, 6835, 'Tulsa King S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208128.mp4', 'http://image.tmdb.org/t/p/w1280/ef8FQKmaxMVyj19JubHl3mgOdIB.jpg'),
(96461, 6835, 'Tulsa King S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208129.mp4', 'http://image.tmdb.org/t/p/w1280/pvsWgF9Q8KEKq1AAFXqt3mx1YB3.jpg'),
(96462, 6835, 'Tulsa King S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208130.mp4', 'http://image.tmdb.org/t/p/w1280/bodFvKO9iKvtdzWG2E4MnBRtpRU.jpg'),
(96463, 6835, 'Tulsa King S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208131.mp4', 'http://image.tmdb.org/t/p/w1280/CgBMQy7ekyOzhhLO0ZoMv7htJW.jpg'),
(96464, 6835, 'Tulsa King S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208132.mp4', 'http://image.tmdb.org/t/p/w1280/5kme01g9nQhOwxaLs4corudfpoe.jpg'),
(96465, 6836, 'Tulsa King S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/454094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fwTv3RPRAIy0maOMns5eYRRwnDk.jpg'),
(96466, 6836, 'Tulsa King S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/458786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fwTv3RPRAIy0maOMns5eYRRwnDk.jpg'),
(96467, 6836, 'Tulsa King S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/466192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fwTv3RPRAIy0maOMns5eYRRwnDk.jpg'),
(96468, 6836, 'Tulsa King S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/471692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fwTv3RPRAIy0maOMns5eYRRwnDk.jpg'),
(96469, 6836, 'Tulsa King S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/484794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fwTv3RPRAIy0maOMns5eYRRwnDk.jpg'),
(96470, 6836, 'Tulsa King S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/487976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fwTv3RPRAIy0maOMns5eYRRwnDk.jpg'),
(96471, 6836, 'Tulsa King S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/493438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fwTv3RPRAIy0maOMns5eYRRwnDk.jpg'),
(96472, 6836, 'Tulsa King S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/496274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fwTv3RPRAIy0maOMns5eYRRwnDk.jpg'),
(96473, 6836, 'Tulsa King S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fwTv3RPRAIy0maOMns5eYRRwnDk.jpg'),
(96474, 6836, 'Tulsa King S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/507509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fwTv3RPRAIy0maOMns5eYRRwnDk.jpg'),
(96475, 6837, 'Tulsa King S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/885683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fwTv3RPRAIy0maOMns5eYRRwnDk.jpg'),
(96476, 6837, 'Tulsa King S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/887335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fwTv3RPRAIy0maOMns5eYRRwnDk.jpg'),
(96477, 6837, 'Tulsa King S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/887722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fwTv3RPRAIy0maOMns5eYRRwnDk.jpg'),
(96478, 6837, 'Tulsa King S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/888134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fwTv3RPRAIy0maOMns5eYRRwnDk.jpg'),
(96479, 6837, 'Tulsa King S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/889713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fwTv3RPRAIy0maOMns5eYRRwnDk.jpg'),
(96480, 6837, 'Tulsa King S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/890046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fwTv3RPRAIy0maOMns5eYRRwnDk.jpg'),
(96481, 6837, 'Tulsa King S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/890997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fwTv3RPRAIy0maOMns5eYRRwnDk.jpg'),
(96482, 6837, 'Tulsa King S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/892189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fwTv3RPRAIy0maOMns5eYRRwnDk.jpg'),
(96483, 6837, 'Tulsa King S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/892604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fwTv3RPRAIy0maOMns5eYRRwnDk.jpg'),
(96484, 6837, 'Tulsa King S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/893334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fwTv3RPRAIy0maOMns5eYRRwnDk.jpg'),
(96485, 6838, 'A Próxima Aposta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kooCUxnX3lPuRZRkgYu2AfT88V0.jpg'),
(96486, 6838, 'A Próxima Aposta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJjKM8fxRoUo9lmPP5DNHy9q7Ea.jpg'),
(96487, 6838, 'A Próxima Aposta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7C4993lWoopqNtsFQdk2OY7mx5I.jpg'),
(96488, 6838, 'A Próxima Aposta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208927.mp4', 'http://image.tmdb.org/t/p/w1280/biqNjLTqSZSNY5mmYxSvs2SFcGI.jpg'),
(96489, 6838, 'A Próxima Aposta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208928.mp4', 'http://image.tmdb.org/t/p/w1280/3sHfeXDlXHz138i4oMkzwreX8da.jpg'),
(96490, 6838, 'A Próxima Aposta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208929.mp4', 'http://image.tmdb.org/t/p/w1280/aGm0vMcRfuAbmOox5mmmMc6E1sc.jpg'),
(96491, 6838, 'A Próxima Aposta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208930.mp4', 'http://image.tmdb.org/t/p/w1280/ryYWROjZ1uqOWecFPe8sGzwFK6E.jpg'),
(96492, 6838, 'A Próxima Aposta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208931.mp4', 'http://image.tmdb.org/t/p/w1280/4kunPbkDhLIMHPlpTBzlLqRPhVv.jpg'),
(96493, 6839, 'A Próxima Aposta S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/st1bnHj0OPlMGTn5lNa0dylI5cW.jpg'),
(96494, 6839, 'A Próxima Aposta S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9cIB9EjJjJdUqNEoe31N0EVSNwM.jpg'),
(96495, 6839, 'A Próxima Aposta S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9OUZbkroBi2ormi3kwoFqMe83Hy.jpg'),
(96496, 6839, 'A Próxima Aposta S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208935.mp4', 'http://image.tmdb.org/t/p/w1280/k3TF6j8waZ2WfKYsmPePtRDhO3a.jpg'),
(96497, 6839, 'A Próxima Aposta S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208936.mp4', 'http://image.tmdb.org/t/p/w1280/nj6nZPLDi1hpBqqkUfF7LzoxmXN.jpg'),
(96498, 6839, 'A Próxima Aposta S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208937.mp4', 'http://image.tmdb.org/t/p/w1280/w4MI886PYY4eUa70cgELyWT93VH.jpg'),
(96499, 6839, 'A Próxima Aposta S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208938.mp4', 'http://image.tmdb.org/t/p/w1280/8q2YafNOyxep5z3zPjxK8dL7kck.jpg'),
(96500, 6839, 'A Próxima Aposta S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208939.mp4', 'http://image.tmdb.org/t/p/w1280/dVKBmwAzFsAJtHiRn73IDXtYtv2.jpg'),
(96501, 6840, 'A Vítima S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jLkdHtughKcUdjiwZjwykTLCvp3.jpg'),
(96502, 6840, 'A Vítima S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/66WrBHd7r05ZRxUKa0G89aVm3L3.jpg'),
(96503, 6840, 'A Vítima S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u8F70UcgzBW07H8wO8LgagkFx1G.jpg'),
(96504, 6840, 'A Vítima S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/XGmW2v6qAISUcLXZfyAGIGgVOf.jpg'),
(96505, 6841, 'Machos Alfa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zvLtQXzBAmOMMoWMlySXawu5txm.jpg'),
(96506, 6841, 'Machos Alfa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cEwEr29kN3EOXgez3i7rGh1P0C.jpg'),
(96507, 6841, 'Machos Alfa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/noQsz2XHcpIS2yJLDkA5TFN7OAl.jpg'),
(96508, 6841, 'Machos Alfa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qkPs4Fid80ZQE8LLGzqCqI1bapK.jpg'),
(96509, 6841, 'Machos Alfa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kp09yjVfHOBDKgCUrXgmW3W0y3T.jpg'),
(96510, 6841, 'Machos Alfa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bBkC9BzG0T3tXSgQ95GZa6Czig3.jpg'),
(96511, 6841, 'Machos Alfa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rSjjCpLpxogN9uoN8ia6Wv8bdD9.jpg'),
(96512, 6841, 'Machos Alfa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xCGx6ZbU1vi9xXmbYPp9RIxXTvj.jpg'),
(96513, 6841, 'Machos Alfa S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hZQrN7gkodPtrFS1LlS69Z3L11r.jpg'),
(96514, 6841, 'Machos Alfa S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9HJlXMoPXpQDRnK7PTY0gOUa0Sf.jpg'),
(96515, 6842, 'Machos Alfa S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/296345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gFUIwwEH8MBrQ3d2QpSGGDEZiKP.jpg'),
(96516, 6842, 'Machos Alfa S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/296346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gFUIwwEH8MBrQ3d2QpSGGDEZiKP.jpg'),
(96517, 6842, 'Machos Alfa S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/296347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gFUIwwEH8MBrQ3d2QpSGGDEZiKP.jpg'),
(96518, 6842, 'Machos Alfa S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/296348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gFUIwwEH8MBrQ3d2QpSGGDEZiKP.jpg'),
(96519, 6842, 'Machos Alfa S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/296349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gFUIwwEH8MBrQ3d2QpSGGDEZiKP.jpg'),
(96520, 6842, 'Machos Alfa S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/296350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gFUIwwEH8MBrQ3d2QpSGGDEZiKP.jpg'),
(96521, 6842, 'Machos Alfa S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/296351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gFUIwwEH8MBrQ3d2QpSGGDEZiKP.jpg'),
(96522, 6842, 'Machos Alfa S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/296352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gFUIwwEH8MBrQ3d2QpSGGDEZiKP.jpg'),
(96523, 6842, 'Machos Alfa S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/296353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gFUIwwEH8MBrQ3d2QpSGGDEZiKP.jpg'),
(96524, 6842, 'Machos Alfa S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/296354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gFUIwwEH8MBrQ3d2QpSGGDEZiKP.jpg'),
(96525, 6843, 'Machos Alfa S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/662196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gFUIwwEH8MBrQ3d2QpSGGDEZiKP.jpg'),
(96526, 6843, 'Machos Alfa S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/662197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gFUIwwEH8MBrQ3d2QpSGGDEZiKP.jpg'),
(96527, 6843, 'Machos Alfa S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/662198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gFUIwwEH8MBrQ3d2QpSGGDEZiKP.jpg'),
(96528, 6843, 'Machos Alfa S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/662199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gFUIwwEH8MBrQ3d2QpSGGDEZiKP.jpg'),
(96529, 6843, 'Machos Alfa S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/662200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gFUIwwEH8MBrQ3d2QpSGGDEZiKP.jpg'),
(96530, 6843, 'Machos Alfa S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/662201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gFUIwwEH8MBrQ3d2QpSGGDEZiKP.jpg'),
(96531, 6843, 'Machos Alfa S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/662202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gFUIwwEH8MBrQ3d2QpSGGDEZiKP.jpg'),
(96532, 6843, 'Machos Alfa S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/662203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gFUIwwEH8MBrQ3d2QpSGGDEZiKP.jpg'),
(96533, 6843, 'Machos Alfa S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/662204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gFUIwwEH8MBrQ3d2QpSGGDEZiKP.jpg'),
(96534, 6843, 'Machos Alfa S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/662205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gFUIwwEH8MBrQ3d2QpSGGDEZiKP.jpg'),
(96535, 6844, 'Alta Fidelidade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8CEDxn4FbunIeq0S68HUWExIul1.jpg'),
(96536, 6844, 'Alta Fidelidade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/txwni0lZ2Qo2CHXZgcI8pgyld6W.jpg'),
(96537, 6844, 'Alta Fidelidade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rqQlZvba7B3EYx2Qy15Zx4PE4Cs.jpg'),
(96538, 6844, 'Alta Fidelidade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLOclZzaa3lYyvnkXOX2LksxoBe.jpg'),
(96539, 6844, 'Alta Fidelidade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hRQkxFJiotrHxBehoeW909VLlFl.jpg'),
(96540, 6844, 'Alta Fidelidade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nRpnfIkMzQmF405ytJV7uhZhzX3.jpg'),
(96541, 6844, 'Alta Fidelidade S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dpKmP9tYRV630WKrgFvbzByMaJt.jpg'),
(96542, 6844, 'Alta Fidelidade S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h3FrWwcK72Mf5cUZ5haxVnJUzoL.jpg'),
(96543, 6844, 'Alta Fidelidade S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gDf8uOQntrLlyjTFfUAlHMXhld.jpg'),
(96544, 6844, 'Alta Fidelidade S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xo8EnX4vXJItBCm8uJFUQ8eyTqK.jpg'),
(96545, 6845, 'América Inexplorada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBgBWba6aVz1pql034hgijw9cw2.jpg'),
(96546, 6845, 'América Inexplorada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pVIzlTaHFblnwWniNAOiatrCbo1.jpg'),
(96547, 6845, 'América Inexplorada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pVIzlTaHFblnwWniNAOiatrCbo1.jpg'),
(96548, 6845, 'América Inexplorada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pVIzlTaHFblnwWniNAOiatrCbo1.jpg'),
(96549, 6845, 'América Inexplorada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pVIzlTaHFblnwWniNAOiatrCbo1.jpg'),
(96550, 6846, 'Amor e Trapaças S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7OSx2i4oPSt1x0FLnHs83fuvfe6.jpg'),
(96551, 6846, 'Amor e Trapaças S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/66L1HpyxtnCQJv3V6sb3xTfrka3.jpg'),
(96552, 6846, 'Amor e Trapaças S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pMSEkGSr2EP0YHHK2TRgPhiMtn4.jpg'),
(96553, 6846, 'Amor e Trapaças S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wA8wAq5tKgZjPYkUNgumUddfeSD.jpg'),
(96554, 6846, 'Amor e Trapaças S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2Nd2eqCaA7IYZ9kDw2fjuDyehH.jpg'),
(96555, 6846, 'Amor e Trapaças S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/piC83Cyre7uPDN8XHfd4gYYQjmw.jpg'),
(96556, 6846, 'Amor e Trapaças S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pEYYJnFQBgRCnbgKW3SCzrAYDhs.jpg'),
(96557, 6846, 'Amor e Trapaças S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uEWMlmINeRm5e9LifLjoyqoOTi2.jpg'),
(96558, 6846, 'Amor e Trapaças S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1hSzS6eTnUzRzCkw9TmJQhZEFb.jpg'),
(96559, 6846, 'Amor e Trapaças S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q6DxbM47mJViDdt1TDdb5sYousf.jpg'),
(96560, 6847, 'Amor e Trapaças S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7FxVVtHTZzCKwwbQAWuPmb5hYRF.jpg'),
(96561, 6847, 'Amor e Trapaças S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pKth5jGnz0cW4NNjVN62dmn94Ne.jpg'),
(96562, 6847, 'Amor e Trapaças S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sdnhtCNQbnQvVHyvOp35BpMpHOB.jpg'),
(96563, 6847, 'Amor e Trapaças S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oeZGslWGobda9dQ0F3vwy7jmfd9.jpg'),
(96564, 6847, 'Amor e Trapaças S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUoHbgNN1z7Sol55GAYoI5hYWQ2.jpg'),
(96565, 6847, 'Amor e Trapaças S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dX6XsMoGYW8RII6hzWZei0YE2jw.jpg'),
(96566, 6847, 'Amor e Trapaças S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4VwyHXKYACwj8s64d3RfQDYE0Kb.jpg'),
(96567, 6847, 'Amor e Trapaças S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/74KQsLzgF7WXLcwnT4805l45uc9.jpg'),
(96568, 6847, 'Amor e Trapaças S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w6L9qnCZTDjE3KN8HcS4t1Xd66x.jpg'),
(96569, 6847, 'Amor e Trapaças S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wsUpHtWBU6No80loEhrKHhkv4MN.jpg'),
(96570, 6848, 'Brinquedos que Mudaram o Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6sHcrwZ9LwBJn46pzoJindPOIP8.jpg'),
(96571, 6848, 'Brinquedos que Mudaram o Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3dkWaAVjarRxQJBV3o1zqGJ50wS.jpg'),
(96572, 6848, 'Brinquedos que Mudaram o Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jfB63PisimTq0VUzfzXzTxPVhGm.jpg'),
(96573, 6848, 'Brinquedos que Mudaram o Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s0SRKZDKnZSG5vZeEC4mbR36nWx.jpg'),
(96574, 6849, 'Brinquedos que Mudaram o Mundo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3LpXhboCuDfJik0HRCskwohptCU.jpg'),
(96575, 6849, 'Brinquedos que Mudaram o Mundo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3LpXhboCuDfJik0HRCskwohptCU.jpg'),
(96576, 6849, 'Brinquedos que Mudaram o Mundo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3LpXhboCuDfJik0HRCskwohptCU.jpg'),
(96577, 6849, 'Brinquedos que Mudaram o Mundo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3LpXhboCuDfJik0HRCskwohptCU.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(96578, 6849, 'Brinquedos que Mudaram o Mundo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3LpXhboCuDfJik0HRCskwohptCU.jpg'),
(96579, 6849, 'Brinquedos que Mudaram o Mundo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3LpXhboCuDfJik0HRCskwohptCU.jpg'),
(96580, 6849, 'Brinquedos que Mudaram o Mundo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3LpXhboCuDfJik0HRCskwohptCU.jpg'),
(96581, 6849, 'Brinquedos que Mudaram o Mundo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3LpXhboCuDfJik0HRCskwohptCU.jpg'),
(96582, 6849, 'Brinquedos que Mudaram o Mundo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3LpXhboCuDfJik0HRCskwohptCU.jpg'),
(96583, 6849, 'Brinquedos que Mudaram o Mundo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/245339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3LpXhboCuDfJik0HRCskwohptCU.jpg'),
(96584, 6850, 'Caleidoscópio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZ3tfrzbez85vAwouifzS5bwZvQ.jpg'),
(96585, 6850, 'Caleidoscópio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vbMndFzdFi7uZb21d9IF9ymcbVx.jpg'),
(96586, 6850, 'Caleidoscópio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bvBdt3tIiAMPC8PAoMyroNxx7py.jpg'),
(96587, 6850, 'Caleidoscópio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aw7mA5jduvXqZs4bGp0DeuEt2GR.jpg'),
(96588, 6850, 'Caleidoscópio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uWh1JmnG5lXO1sKVgAI5057fYSQ.jpg'),
(96589, 6850, 'Caleidoscópio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wb0Os1ELxulYYsQqykpeFBpXTSd.jpg'),
(96590, 6850, 'Caleidoscópio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u6sSbUgdJBOvrVu4ohugmckVrpV.jpg'),
(96591, 6850, 'Caleidoscópio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gx3fowcghPl8KacOVFF1QTXPa8M.jpg'),
(96592, 6850, 'Caleidoscópio S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/guwke4sAM5vjk5NGwFex53JdjqF.jpg'),
(96593, 6136, 'Mahoutsukai Reimeiki S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202668.mp4', 'http://timg.bdta.pro/images/512f78373cf34035dd345886a020ba4f.jpg'),
(96594, 6136, 'Mahoutsukai Reimeiki S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202669.mp4', 'http://timg.bdta.pro/images/34d317786cd7c18bc6fd39daf6ab9422.jpg'),
(96595, 6136, 'Mahoutsukai Reimeiki S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202670.mp4', 'http://timg.bdta.pro/images/2ecf38b98856a842aeca8413f18676b1.jpg'),
(96596, 6136, 'Mahoutsukai Reimeiki S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202671.mp4', 'http://timg.bdta.pro/images/ca78b40b493566b94f8ff4fda67686f1.jpg'),
(96597, 6136, 'Mahoutsukai Reimeiki S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202672.mp4', 'http://timg.bdta.pro/images/4e991867f3ea55b35cf0f7cf4d124fbc.jpg'),
(96598, 6136, 'Mahoutsukai Reimeiki S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202673.mp4', 'http://timg.bdta.pro/images/57fb155d08902e605257d564f17a4527.jpg'),
(96599, 6136, 'Mahoutsukai Reimeiki S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202674.mp4', 'http://timg.bdta.pro/images/7d8192daa203678eed47c7bd214d7192.jpg'),
(96600, 6136, 'Mahoutsukai Reimeiki S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202675.mp4', 'http://timg.bdta.pro/images/9d3c5ecf542e379ba7213274405b0522.jpg'),
(96601, 6136, 'Mahoutsukai Reimeiki S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202676.mp4', 'http://timg.bdta.pro/images/3b786e2606c9c202b04a53eaad23d660.jpg'),
(96602, 6136, 'Mahoutsukai Reimeiki S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202677.mp4', 'http://timg.bdta.pro/images/a4da0f8d56c3e4297df6b1f31991c614.jpg'),
(96603, 6136, 'Mahoutsukai Reimeiki S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202678.mp4', 'http://timg.bdta.pro/images/8dd1bc053a06bc5bc491a6338441d7e7.jpg'),
(96604, 6136, 'Mahoutsukai Reimeiki S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202679.mp4', 'http://timg.bdta.pro/images/d6a8a3df395f189643a9b7a59adb9f95.jpg'),
(96605, 6851, 'Olhar Indiscreto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2rlCpbqxErPGyi10bjGjgVLkkRB.jpg'),
(96606, 6851, 'Olhar Indiscreto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mH6GIQX5yUycAZciNqcG80B37EQ.jpg'),
(96607, 6851, 'Olhar Indiscreto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hgvxqb7zu8e8shOlybVs0dk4J4a.jpg'),
(96608, 6851, 'Olhar Indiscreto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tPre6E1JqZxGjAgJSvkaizWY6KP.jpg'),
(96609, 6851, 'Olhar Indiscreto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zOr2Fssz665MLS3UBYYTw0wo6MN.jpg'),
(96610, 6851, 'Olhar Indiscreto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b60rY9RBc5rCyBsT8McDo3ZGJCO.jpg'),
(96611, 6851, 'Olhar Indiscreto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/51PLvVaVu98uF9W39BMP0BGBnp7.jpg'),
(96612, 6851, 'Olhar Indiscreto S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eF1JsRZijC1YI4WHeyG8GBn5yEl.jpg'),
(96613, 6851, 'Olhar Indiscreto S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k2calvJSu8DctXkYvLpoayKoDPS.jpg'),
(96614, 6851, 'Olhar Indiscreto S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/edTLKYPctuHfzuecRjkZtph0jJg.jpg'),
(96615, 6852, 'Os Contatinhos de Lauren S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ml64AUZL5oxtAI5DP6ZvGp7inxS.jpg'),
(96616, 6852, 'Os Contatinhos de Lauren S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/korruAFIm3fVnO6wEDF8YWpxScP.jpg'),
(96617, 6852, 'Os Contatinhos de Lauren S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aygdvcQvXgXAVDAgJnL6nKa0U8h.jpg'),
(96618, 6852, 'Os Contatinhos de Lauren S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/skVT7yXJjq1q5HVOzmT3PjAK87I.jpg'),
(96619, 6852, 'Os Contatinhos de Lauren S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hzAxboPLgGdtrgZsOjRH3YtlKQH.jpg'),
(96620, 6852, 'Os Contatinhos de Lauren S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wMLAgKuzeDG21JGrf677VSwC9ip.jpg'),
(96621, 6852, 'Os Contatinhos de Lauren S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sU8Oqt22HlwvNoZT79C5kL03yQv.jpg'),
(96622, 6852, 'Os Contatinhos de Lauren S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rF0RWgS6uK1wEKkHaBfj4fvXaN5.jpg'),
(96623, 6853, 'Pequeno Problema S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2w28YYiqfPQpOitGsr2slTZyALb.jpg'),
(96624, 6853, 'Pequeno Problema S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iT0Qx0hTAcTLpDJHOKZZ1ZqLiFG.jpg'),
(96625, 6853, 'Pequeno Problema S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kM0YduOAlgagZh5BzOnninKQDBB.jpg'),
(96626, 6853, 'Pequeno Problema S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Ccldq1Sntd4Wl7KeQ1fyom8M6a.jpg'),
(96627, 6853, 'Pequeno Problema S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6JfWetiKdOx6vafuwtQVGFOpHiX.jpg'),
(96628, 6853, 'Pequeno Problema S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5biMKJf55HMdg6WbzjP8U4538Cp.jpg'),
(96629, 6853, 'Pequeno Problema S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kGPdAeEFeCc8ySfagWsToCMvUKd.jpg'),
(96630, 6853, 'Pequeno Problema S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vTUESYxzAacgDoE4bXni9YIhSOy.jpg'),
(96631, 6853, 'Pequeno Problema S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A2wDG3qxDyT8FpKSoXKBvMUpfKd.jpg'),
(96632, 6853, 'Pequeno Problema S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nMnQeNnBvrEe5OQMpvgLg0Aaucu.jpg'),
(96633, 6853, 'Pequeno Problema S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2nwszzHGLmIwbf2zKkVHSIMoXQH.jpg'),
(96634, 6853, 'Pequeno Problema S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fRiyQiJLBokKszD5rr2iKTKKkRV.jpg'),
(96635, 6853, 'Pequeno Problema S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/202636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1gd5fnkEACtG52AMUxVfkmIyEw0.jpg'),
(96636, 6853, 'Pequeno Problema S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/202637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Dbk0HNJi4n1L4IQl0QQdOFYvcz.jpg'),
(96637, 6853, 'Pequeno Problema S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/202638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3fMpGcx4atGp2thjgcfIf5x4EnV.jpg'),
(96638, 6853, 'Pequeno Problema S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/202639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eNrhc8RufHpa4khUkU2pfHRf7bZ.jpg'),
(96639, 6853, 'Pequeno Problema S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/202640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nQCsE3q8nAMVRwy4UiIndvxGo6R.jpg'),
(96640, 6853, 'Pequeno Problema S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/202641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hxCoC4mpshCM1hxl0CeTWO4cjv5.jpg'),
(96641, 6853, 'Pequeno Problema S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/202642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hTQjLaStSVGYgxkNa06Hgl7jPUf.jpg'),
(96642, 6853, 'Pequeno Problema S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/202643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/37P8U5B8IGtW004qivFoTLz1y95.jpg'),
(96643, 6853, 'Pequeno Problema S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/202644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfdgVJKarnHEwbMp3Z9EIbAnqT5.jpg'),
(96644, 6853, 'Pequeno Problema S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/202645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2HJkkmrFkX9PXRfZq46U92XhSE.jpg'),
(96645, 6853, 'Pequeno Problema S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/202646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mCbibGuBGp4o0jVnJHmYw3tlxLp.jpg'),
(96646, 6853, 'Pequeno Problema S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/202647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z3x7QreCYtvwxzUfjMeKfjsmvVz.jpg'),
(96647, 6853, 'Pequeno Problema S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/202648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ceGwpkPWQfubwvkFPzUTH3DIfNi.jpg'),
(96648, 6853, 'Pequeno Problema S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/202649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nIbE9joyZ2Rq3ONno1kU9AP3j4j.jpg'),
(96649, 6854, 'Retrospectiva 2022: Edição Globoplay S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gjnhPYQqefrKFMxZLw4ho2sYXbh.jpg'),
(96650, 6854, 'Retrospectiva 2022: Edição Globoplay S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7mYqOMqFJj0f3PF1wUSDlnUCLKJ.jpg'),
(96651, 6854, 'Retrospectiva 2022: Edição Globoplay S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1TdAFSUThUR4kkDy3Bfu8ReA15D.jpg'),
(96652, 6855, 'Show da Virada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fDQMQLHPrD4sHTmVYeFarXkJgSD.jpg'),
(96653, 6855, 'Show da Virada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fDQMQLHPrD4sHTmVYeFarXkJgSD.jpg'),
(96654, 6856, 'Traição S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nOYJZ6ecKBBEr56LJctJplvWf7F.jpg'),
(96655, 6856, 'Traição S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1QMgmOfccWVpPusorC74TSMAOD.jpg'),
(96656, 6856, 'Traição S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3os4mPj5U1qTaH6OUtLQ7nUF4w.jpg'),
(96657, 6856, 'Traição S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mmK8nfDYN43mry65DHgpJiL0068.jpg'),
(96658, 6856, 'Traição S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wF7Gidv3rombUDAMztsp283f4z9.jpg'),
(96659, 6857, 'Masha e o Urso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xbim2rRcOhlN2AkJCQuHa9VzSTs.jpg'),
(96660, 6857, 'Masha e o Urso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Hfp7S05mlRDGPbXeo1nWTnDb4e.jpg'),
(96661, 6857, 'Masha e o Urso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vxyxaZ29u7mMqQaRj6AKQLKRjWp.jpg'),
(96662, 6857, 'Masha e o Urso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9dyWzrRRaIQLrfbDuDs0D0ZpsVb.jpg'),
(96663, 6857, 'Masha e o Urso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xIaVqpayW0gGt9a1RZhZuAmi1kw.jpg'),
(96664, 6857, 'Masha e o Urso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jEdFUskFqpHbaDRcQ1p6i0Z5I6a.jpg'),
(96665, 6857, 'Masha e o Urso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6oAC9qNcV3VuvP9xGwY1vSQahWK.jpg'),
(96666, 6857, 'Masha e o Urso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lquPw6ixYP2P9RdaIA7K1c9Suf7.jpg'),
(96667, 6857, 'Masha e o Urso S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/syZhUvklz99ok5FbdDmGchwDmnN.jpg'),
(96668, 6858, 'Masha e o Urso S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Ebqs82SG7Py9xRUssd2WR4hKyX.jpg'),
(96669, 6858, 'Masha e o Urso S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jf5raDmvVUyf4eI6uQRFqMAsfUu.jpg'),
(96670, 6858, 'Masha e o Urso S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pq0Fwph4N1tUK2RVN41fxItqYyz.jpg'),
(96671, 6858, 'Masha e o Urso S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jXol8EefQBfglANuXGaqvqTXHOT.jpg'),
(96672, 6858, 'Masha e o Urso S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bYl45gSfyJ6nbO2BYP2hZ0u8BaQ.jpg'),
(96673, 6858, 'Masha e o Urso S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k7zwTuw8LsA0zMpjCndDWMTOvrc.jpg'),
(96674, 6858, 'Masha e o Urso S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dinSE3kRKDb09EeryQlNTwT96qn.jpg'),
(96675, 6858, 'Masha e o Urso S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vAohum9EtJZKtf17geJi8FEggNT.jpg'),
(96676, 6859, 'Masha e o Urso S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zMVlyAlF100rPz3t0TmyMZFf0DM.jpg'),
(96677, 6859, 'Masha e o Urso S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBd2A9ZCyacz0Ha8WuDBbhsaSWh.jpg'),
(96678, 6859, 'Masha e o Urso S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aVb71hqsRNDBuJoyZXsz1Y88iD7.jpg'),
(96679, 6859, 'Masha e o Urso S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmnDHU52JPSEgo6W07C6GLWm0qj.jpg'),
(96680, 6860, 'Masha e o Urso S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nvSi6WLJZ1PUyo20BSEXRhh632L.jpg'),
(96681, 6860, 'Masha e o Urso S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/erKCHmOOWfXQk4ZlsWcX1TGrbBR.jpg'),
(96682, 6860, 'Masha e o Urso S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5p8x9T1vQ0TuDsarttNzjXdCatU.jpg'),
(96683, 6860, 'Masha e o Urso S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4uFzvojwYK7heH0qLVEeLJyQHui.jpg'),
(96684, 6861, 'Masha e o Urso S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/baRE6Jpqs445m0WqVP7eoGn529p.jpg'),
(96685, 6861, 'Masha e o Urso S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/thkQ8kUgAAkI4czFqemCrTNd93Y.jpg'),
(96686, 6861, 'Masha e o Urso S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/48XA7ellCpEAfzjDTHpeh8FdOox.jpg'),
(96687, 6861, 'Masha e o Urso S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gczlHG4D5qsmH6UTB3e1uD1fsvY.jpg'),
(96688, 6862, 'MasterChef Junior S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qb8pXRmyNfOWQgJssz51bw9wATy.jpg'),
(96689, 6862, 'MasterChef Junior S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qb8pXRmyNfOWQgJssz51bw9wATy.jpg'),
(96690, 6862, 'MasterChef Junior S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qb8pXRmyNfOWQgJssz51bw9wATy.jpg'),
(96691, 6862, 'MasterChef Junior S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qb8pXRmyNfOWQgJssz51bw9wATy.jpg'),
(96692, 6862, 'MasterChef Junior S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qb8pXRmyNfOWQgJssz51bw9wATy.jpg'),
(96693, 6862, 'MasterChef Junior S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qb8pXRmyNfOWQgJssz51bw9wATy.jpg'),
(96694, 6862, 'MasterChef Junior S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qb8pXRmyNfOWQgJssz51bw9wATy.jpg'),
(96695, 6862, 'MasterChef Junior S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qb8pXRmyNfOWQgJssz51bw9wATy.jpg'),
(96696, 6862, 'MasterChef Junior S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qb8pXRmyNfOWQgJssz51bw9wATy.jpg'),
(96697, 6863, 'MasterChef Junior S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qb8pXRmyNfOWQgJssz51bw9wATy.jpg'),
(96698, 6863, 'MasterChef Junior S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qb8pXRmyNfOWQgJssz51bw9wATy.jpg'),
(96699, 6863, 'MasterChef Junior S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qb8pXRmyNfOWQgJssz51bw9wATy.jpg'),
(96700, 6863, 'MasterChef Junior S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qb8pXRmyNfOWQgJssz51bw9wATy.jpg'),
(96701, 6864, 'Vida de Escritório S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ve9TeBQd1laUriOGilkhEfAZeNo.jpg'),
(96702, 6864, 'Vida de Escritório S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/61KGIFQqkevznaYUOIwUPbEzwU4.jpg'),
(96703, 6864, 'Vida de Escritório S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AmnJCzXOQ1x3iV0O6V08GknQ8Ou.jpg'),
(96704, 6864, 'Vida de Escritório S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQkvJdoK5tfkVELqQoz8u2mOEK1.jpg'),
(96705, 6864, 'Vida de Escritório S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sMVjvaGeackBlES9tXLVlCl4ZIr.jpg'),
(96706, 6864, 'Vida de Escritório S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sRJAClTWubrVwk2q6nWq1GT9lOm.jpg'),
(96707, 6865, 'Vida de Escritório S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Yli4Lw9679YyuYAm0n7VNoZcPJ.jpg'),
(96708, 6865, 'Vida de Escritório S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pRh05SGuzHzSIZRNaWcjV8GjGLL.jpg'),
(96709, 6865, 'Vida de Escritório S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mEk5ZkdGGdKW2PUgM3XChU8K3rU.jpg'),
(96710, 6865, 'Vida de Escritório S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wLxlM3uqea3Ldhw4I2weEZd6lng.jpg'),
(96711, 6865, 'Vida de Escritório S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lMvRDCIJPOBoIyUxKr9xKluzrdQ.jpg'),
(96712, 6865, 'Vida de Escritório S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/as3TPWJJCEeL7kB54QqE4gH9AfA.jpg'),
(96713, 6865, 'Vida de Escritório S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5utO4udyvMV5AFY2oeBb0V7ECxf.jpg'),
(96714, 6865, 'Vida de Escritório S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x65icONgGtUT6VCStL9ZQJd5Cr7.jpg'),
(96715, 6865, 'Vida de Escritório S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6PzXH7sa1Jwx6aCUOqmjTgNg03P.jpg'),
(96716, 6865, 'Vida de Escritório S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cjD1kUGSQEjeR6W17XPnB4agrXp.jpg'),
(96717, 6865, 'Vida de Escritório S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aXPsdkYixMPLsRpAGEtGuazJ9n6.jpg'),
(96718, 6865, 'Vida de Escritório S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eisjsle9DzauHbrSPJpZfWAekho.jpg'),
(96719, 6865, 'Vida de Escritório S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/202247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4G0SWI93FaDbmmo1hD7vfCLIGf.jpg'),
(96720, 6865, 'Vida de Escritório S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/202248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/12YVvyKGS9CqXuX09mWtHBNA6Rc.jpg'),
(96721, 6865, 'Vida de Escritório S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/202249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A0Cjm5Wvou6VP5xeWF39xUaXTLY.jpg'),
(96722, 6865, 'Vida de Escritório S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/202250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLUOJmzT6gSLELbBUTOKN7Csrf.jpg'),
(96723, 6865, 'Vida de Escritório S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/202251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jCVOuVbuiGo2yHbTlmy1Ak82SML.jpg'),
(96724, 6865, 'Vida de Escritório S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/202252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mdKJkq4Z1Gw39Aa4wNzfPAhmyHv.jpg'),
(96725, 6865, 'Vida de Escritório S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/202253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9rpR7qGkCqHzFAQWNGWBhlET5jJ.jpg'),
(96726, 6865, 'Vida de Escritório S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/202254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e2JsVFkqtvJahNJHc42Xck86en2.jpg'),
(96727, 6865, 'Vida de Escritório S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/202255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oQjufULRy7SZCUkhwN6zjAmgTtl.jpg'),
(96728, 6865, 'Vida de Escritório S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/202256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bZcmyvX6oeQ0eceV292lse0bPQo.jpg'),
(96729, 6866, 'Vida de Escritório S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g93jcazYdNyf2PMebD4yixwTdE4.jpg'),
(96730, 6866, 'Vida de Escritório S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a2PI7yrGu0GIK2ayoKxc4LJZ13T.jpg'),
(96731, 6866, 'Vida de Escritório S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j9zrwoLX4JLGflFNfWCNFm0S0JN.jpg'),
(96732, 6866, 'Vida de Escritório S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rlOYq6pAqvox2wAEdvPCBUjxRER.jpg'),
(96733, 6866, 'Vida de Escritório S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pHYltDCFC2dj3G8wwX30Gj9wryY.jpg'),
(96734, 6866, 'Vida de Escritório S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mSPRenUgz0b5aBCZKMLBJYO2lqE.jpg'),
(96735, 6866, 'Vida de Escritório S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJiGrGPYr3sHA73jXPtU36ZxayA.jpg'),
(96736, 6866, 'Vida de Escritório S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/upFkJxkixNZpIQecRtRNppgzM8e.jpg'),
(96737, 6866, 'Vida de Escritório S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k4YPnaL4uVvx5HgT7tWtQ7bO420.jpg'),
(96738, 6866, 'Vida de Escritório S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bf88U7wP9dCr3y6MoMpW63t5w7P.jpg'),
(96739, 6866, 'Vida de Escritório S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9sFfgulQRyx6QUFg4NCtPP3oYGc.jpg'),
(96740, 6866, 'Vida de Escritório S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tcX5S2g51hqHd7cp2OMMKPEhzwt.jpg'),
(96741, 6866, 'Vida de Escritório S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/202269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6lwZDK2l05zpChVzl7l9fBU3V2.jpg'),
(96742, 6866, 'Vida de Escritório S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/202270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Are3Iz2bsskzM9wJL07T8sDTbFO.jpg'),
(96743, 6866, 'Vida de Escritório S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/202271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k4P9afguWJex9Qm8nZiLPNOHVn5.jpg'),
(96744, 6866, 'Vida de Escritório S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/202272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v5KhrOQ8WJPmV5KcxqOT9PqFoya.jpg'),
(96745, 6866, 'Vida de Escritório S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/202273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fXDugr6qOmyzSzI6UOSyOhg7hry.jpg'),
(96746, 6866, 'Vida de Escritório S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/202274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3VzPBJ6kanhdsVTWltReWPDJx9D.jpg'),
(96747, 6866, 'Vida de Escritório S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/202275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lvJZXFS2WUxbtNjUUKcErvxNaZ0.jpg'),
(96748, 6866, 'Vida de Escritório S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/202276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iHvrE0L2w033SpwC56I7SLhoQVm.jpg'),
(96749, 6866, 'Vida de Escritório S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/202277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ZLuHIS4XLWIS8tiIDoRsyq3XOk.jpg'),
(96750, 6866, 'Vida de Escritório S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/202278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k4XHC2EM0fGmAp0SDBq862nE9pG.jpg'),
(96751, 6866, 'Vida de Escritório S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/202279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCfz64QNR9U2ZYsvjb0iOJI6949.jpg'),
(96752, 6866, 'Vida de Escritório S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/202280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNZAJgcGVDxjv4PtJ2xU6MPZlHh.jpg'),
(96753, 6866, 'Vida de Escritório S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/202281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNZAJgcGVDxjv4PtJ2xU6MPZlHh.jpg'),
(96754, 6867, 'Vida de Escritório S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2c3SdXQBXnatA3ziIBFbcPgejK2.jpg'),
(96755, 6867, 'Vida de Escritório S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zDfzafh61erSFSemj0UDVHvsrJo.jpg'),
(96756, 6867, 'Vida de Escritório S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mEHitvfNEu6ieWgZFakygIAp4Qt.jpg'),
(96757, 6867, 'Vida de Escritório S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2HBPQyCbFq3tVQy6euj9gUoFiAQ.jpg'),
(96758, 6867, 'Vida de Escritório S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vStj5UHaOsMVeMKFIeSbWk4Ouwd.jpg'),
(96759, 6867, 'Vida de Escritório S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pgiNDIDUtPQpD2M5Wr3mfhgEHLW.jpg'),
(96760, 6867, 'Vida de Escritório S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9H6T1taKasivezrcT1MTdNTPWah.jpg'),
(96761, 6867, 'Vida de Escritório S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m47xL9t49XR4YgUn1BsSoQFWr3V.jpg'),
(96762, 6867, 'Vida de Escritório S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v0sGPOXYaUBAJtXcdgte5FANoSR.jpg'),
(96763, 6867, 'Vida de Escritório S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/otDNJG7cTAOnOzCCgCjtgi2PDI3.jpg'),
(96764, 6867, 'Vida de Escritório S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nSDerGIYvbSdAqTlsY2D3DpfIlp.jpg'),
(96765, 6867, 'Vida de Escritório S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ofWC4qb4QD4tQKMlAAo0ZdHaJp.jpg'),
(96766, 6867, 'Vida de Escritório S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/202294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/57v9TNarlMz9pf6ZStEmt7jpYMM.jpg'),
(96767, 6867, 'Vida de Escritório S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/202295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8TSgnLX0vRfQi8IZzVuQt0K41GY.jpg'),
(96768, 6867, 'Vida de Escritório S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/202296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wMDAHVlVc0SmnlbaCKbgSDkn52a.jpg'),
(96769, 6867, 'Vida de Escritório S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/202297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lKnvFZbzK1QXdeLn80YjmINfBOI.jpg'),
(96770, 6867, 'Vida de Escritório S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/202298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cOMfgSxm7DwjI74daeXUrhxbYIZ.jpg'),
(96771, 6867, 'Vida de Escritório S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/202299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uSMNDIewiFzE4d5PR1OcbGkxxJl.jpg'),
(96772, 6867, 'Vida de Escritório S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/202300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2BZM1FdPyLWeq9E7Rg0AEch3xjS.jpg'),
(96773, 6868, 'Vida de Escritório S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8mw057Hbn0HS3rBzfsFc35t2iR6.jpg'),
(96774, 6868, 'Vida de Escritório S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uHFPX3pK2jtcViZLED1esrKUZvj.jpg'),
(96775, 6868, 'Vida de Escritório S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4DX8TGWgUEOHGwyTvk9nIccEKOo.jpg'),
(96776, 6868, 'Vida de Escritório S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cbejmeN917TiKzQqrMM3dAXdyhA.jpg'),
(96777, 6868, 'Vida de Escritório S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLkVxENgm59zmhFgTYnLFQz9Jv6.jpg'),
(96778, 6868, 'Vida de Escritório S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/toJgBHy74SpFHwxO55b02BVvYLr.jpg'),
(96779, 6868, 'Vida de Escritório S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f374XAvIBxHMEF6nqIVkplyL1mP.jpg'),
(96780, 6868, 'Vida de Escritório S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/H2Lf4IZDDLqaSdTfa8qcvsS550.jpg'),
(96781, 6868, 'Vida de Escritório S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNONDn7SGP4k4gmAwn2lQfIotfu.jpg'),
(96782, 6868, 'Vida de Escritório S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2w8SRRHbHiGIf7Uxr56W6oxfftQ.jpg'),
(96783, 6868, 'Vida de Escritório S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Mfu31Ah9fyxLYLajdra9Pl4kKX.jpg'),
(96784, 6868, 'Vida de Escritório S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2kwJKmCJ07GIE2z2luqCI26qS1j.jpg'),
(96785, 6868, 'Vida de Escritório S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/202313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vOW6G304cwyT7Uh2d31y8IHR4IN.jpg'),
(96786, 6868, 'Vida de Escritório S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/202314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXzpQoTWv2a4OhNoOloDYQe8lhl.jpg'),
(96787, 6868, 'Vida de Escritório S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/202315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7fpiETDqoMLPkgiRr8IOAfHdogU.jpg'),
(96788, 6868, 'Vida de Escritório S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/202316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5RaXCvLqTV5ZOQSRWvCZTTRQfw.jpg'),
(96789, 6868, 'Vida de Escritório S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/202317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hjnpmrkdcgrEWtMDqOdQZYUOA4q.jpg'),
(96790, 6868, 'Vida de Escritório S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/202318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6xiGAjBUZDjx9sgefA9118l4sN1.jpg'),
(96791, 6868, 'Vida de Escritório S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/202319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9PJhRC5SMXQlThatNMTf5ou4NPx.jpg'),
(96792, 6868, 'Vida de Escritório S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/202320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jdTNwsxyR63FpEgSJ0LlmQTcOCM.jpg'),
(96793, 6868, 'Vida de Escritório S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/202321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/na2gN5eXk1MwNbBWDZmsJRLbtGX.jpg'),
(96794, 6868, 'Vida de Escritório S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/202322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lcUj8ZNGC3agExI7bjS0F6tN3Kz.jpg'),
(96795, 6868, 'Vida de Escritório S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/202323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOAVA3EHX9cJZWZpaDVkbZhBd9c.jpg'),
(96796, 6868, 'Vida de Escritório S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/202324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3FDbAunlvUBvmJa8b8dxAyk9Lin.jpg'),
(96797, 6868, 'Vida de Escritório S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/202325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bx0J1oSJNxtMVuYfdAUGfWzH1zk.jpg'),
(96798, 6868, 'Vida de Escritório S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/202326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zMpnRyb5DAnizp5UHmLT94Afru1.jpg'),
(96799, 6868, 'Vida de Escritório S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/202327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNZAJgcGVDxjv4PtJ2xU6MPZlHh.jpg'),
(96800, 6868, 'Vida de Escritório S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/202328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNZAJgcGVDxjv4PtJ2xU6MPZlHh.jpg'),
(96801, 6869, 'Vida de Escritório S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOrz8sRTp2VCLeHNa0Z984DDZqo.jpg'),
(96802, 6869, 'Vida de Escritório S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i6ShaUbd4F9sQqfKfs2zQuHXGmI.jpg'),
(96803, 6869, 'Vida de Escritório S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQcBZoTjrScKTeBshUcs5OFNyUu.jpg'),
(96804, 6869, 'Vida de Escritório S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dMRxj9BYrcmHMsvLwbC6IIoJ5QJ.jpg'),
(96805, 6869, 'Vida de Escritório S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2CQswyB2ULpcb53oCsZXJBYyKME.jpg'),
(96806, 6869, 'Vida de Escritório S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/haQudolF7pDPsUaYxcuUWJKOueM.jpg'),
(96807, 6869, 'Vida de Escritório S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7gem2WvuueQCSZToxHrCAJ3wne1.jpg'),
(96808, 6869, 'Vida de Escritório S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYnzCb3zfEg6tf5Z1fWI1UZws3V.jpg'),
(96809, 6869, 'Vida de Escritório S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c6splVKmX2f7JOSreqSgrn8N9an.jpg'),
(96810, 6869, 'Vida de Escritório S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dKyyCAdK3ynTa0V5GhGCDUZVpqu.jpg'),
(96811, 6869, 'Vida de Escritório S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MDPYQJtNYOhwrU4gf8eRwpUrka.jpg'),
(96812, 6869, 'Vida de Escritório S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oCpspjTl50bBvzAvAe7EcFyjm5k.jpg'),
(96813, 6869, 'Vida de Escritório S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/202341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/91UtqA3zap0dXyyYVQNnPiHSUfr.jpg'),
(96814, 6869, 'Vida de Escritório S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/202342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nisOv4RtbvTWFSsN12tKwfTndma.jpg'),
(96815, 6869, 'Vida de Escritório S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/202343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1nqkoBwzBQotglrTaVdfvRyStVV.jpg'),
(96816, 6869, 'Vida de Escritório S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/202344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rUeCQBiSKMiaEvB8fnoRDl8rtb4.jpg'),
(96817, 6869, 'Vida de Escritório S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/202345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0DrvhOk0dpaVXKn5nDVZcxQ1a9.jpg'),
(96818, 6869, 'Vida de Escritório S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/202346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xYOZnUU0q6z2sRTIxcHepA6Gas4.jpg'),
(96819, 6869, 'Vida de Escritório S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/202347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4wjZb7YyWTB1Ao9BjRx8e7UIl7z.jpg'),
(96820, 6869, 'Vida de Escritório S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/202348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/56hRdwaPs3rKIJUSEL8RJFA3SgA.jpg'),
(96821, 6869, 'Vida de Escritório S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/202349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3pJIfZOXxReM3zOoJTv253tRbb3.jpg'),
(96822, 6869, 'Vida de Escritório S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/202350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z2956xSFqY2te3F1dWcREzK0h78.jpg'),
(96823, 6869, 'Vida de Escritório S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/202351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cHGGrFJD8lyvWeqenTKLEcB1VqP.jpg'),
(96824, 6869, 'Vida de Escritório S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/202352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8RBNOu7JwQY8OBjquqnnYiVXMFk.jpg'),
(96825, 6869, 'Vida de Escritório S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/202353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nGdklnVWRdmXpuckdyZTpvjwvt2.jpg'),
(96826, 6869, 'Vida de Escritório S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/202354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ediO7Y2iJDcdmoTEFkHeS3HPTVp.jpg'),
(96827, 6870, 'Vida de Escritório S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pYQwCiNc9fFJ5k8HnSWgAstfnL0.jpg'),
(96828, 6870, 'Vida de Escritório S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zD85V6xL5uXGTaZ3KNGy3tARzq7.jpg'),
(96829, 6870, 'Vida de Escritório S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6dOLWVZ2A0LH8EXyNkigRw3xgLp.jpg'),
(96830, 6870, 'Vida de Escritório S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cTnT11ycmBXEufPdMSfikF6UUkn.jpg'),
(96831, 6870, 'Vida de Escritório S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iN7UPFwmTD4ZwMwPGMUZhdOnKIn.jpg'),
(96832, 6870, 'Vida de Escritório S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVP86c3XsmDJ049fQ2rXDwYaNkj.jpg'),
(96833, 6870, 'Vida de Escritório S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x83cMZMj61uJfPEX08I8rSr821V.jpg'),
(96834, 6870, 'Vida de Escritório S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q1SVOVyAXrK6rpWlsWvKnk6Dloc.jpg'),
(96835, 6870, 'Vida de Escritório S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jCSdonSzdZAtGnixclPvZKSNebj.jpg'),
(96836, 6870, 'Vida de Escritório S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDam3NabGFRxkNXIxmQQ404qQyw.jpg'),
(96837, 6870, 'Vida de Escritório S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/75EGbz4WbtF7B69XM5sqiT7yd1c.jpg'),
(96838, 6870, 'Vida de Escritório S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5GQLNkwHk6CDp1ca1FXziSQyq0y.jpg'),
(96839, 6870, 'Vida de Escritório S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/202367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aCHdu0UIK3gN2yYSUUxbUAbWZi3.jpg'),
(96840, 6870, 'Vida de Escritório S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/202368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/K2OD2lVAerQU9dZgj1ldYp7S3t.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(96841, 6870, 'Vida de Escritório S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/202369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5F7h0qUdYVUjvkwy4bZbGiVs6tR.jpg'),
(96842, 6870, 'Vida de Escritório S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/202370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vqSiR9RXYxUnTZpzwJxLeY5QNcy.jpg'),
(96843, 6870, 'Vida de Escritório S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/202371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/36Z8Z2jvkqE3Y7vUvyrxiC1dius.jpg'),
(96844, 6870, 'Vida de Escritório S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/202372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sd5tVOkHkN8WBMDZPeP0fE6MWx.jpg'),
(96845, 6870, 'Vida de Escritório S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/202373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yetKixYDsAZEPN482rylmvGfzEZ.jpg'),
(96846, 6870, 'Vida de Escritório S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/202374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tBdJz9IfjurFPH3ozwIMfAdFMCA.jpg'),
(96847, 6870, 'Vida de Escritório S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/202375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fHqE2jTn0vFaD790Mx2mXpz22GO.jpg'),
(96848, 6870, 'Vida de Escritório S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/202376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u9qju1KkTTdRBXN5ho0tIUFpIbi.jpg'),
(96849, 6870, 'Vida de Escritório S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/202377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/153lz8Qno5rhCVj9Wi8jTmiPwo6.jpg'),
(96850, 6870, 'Vida de Escritório S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/202378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x02spA1t1rLwl2XRrdRNKOLv10Q.jpg'),
(96851, 6870, 'Vida de Escritório S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/202379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nNKvtqHwK7KSpG38WeUgQZuAvZ.jpg'),
(96852, 6870, 'Vida de Escritório S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/202380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7dm0gZZzDpmW7k6LRqa15SITsZm.jpg'),
(96853, 6870, 'Vida de Escritório S07 E27', 'http://sinalprivado.info:80/series/1533784/1533784/202381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNZAJgcGVDxjv4PtJ2xU6MPZlHh.jpg'),
(96854, 6871, 'Vida de Escritório S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qwnrgo2fLNL3Zzuybj2UIzyBZ0Z.jpg'),
(96855, 6871, 'Vida de Escritório S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8z9AFNZllKXiP10LvZW0lIllJJ3.jpg'),
(96856, 6871, 'Vida de Escritório S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mnZZCEkc1cqolo1U60cB0NHBeU.jpg'),
(96857, 6871, 'Vida de Escritório S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5jKJcwsaNeiL5XhSQ8iASiFDWIx.jpg'),
(96858, 6871, 'Vida de Escritório S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/18Qb60pxBFaQDb7kCxhqwBPcTCK.jpg'),
(96859, 6871, 'Vida de Escritório S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6WFV9imS4TrLmmq2vTWSfchr1Hr.jpg'),
(96860, 6871, 'Vida de Escritório S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oITZxE31qxLZOvUIXXOJZNt3ZAJ.jpg'),
(96861, 6871, 'Vida de Escritório S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kNRo8guMolaaumtZssQch8ErP6F.jpg'),
(96862, 6871, 'Vida de Escritório S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kHxz6IFDzgNeo5KZt3JGElukbnH.jpg'),
(96863, 6871, 'Vida de Escritório S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uyVT1YaxJuNhYnrfDFNdWiu65yY.jpg'),
(96864, 6871, 'Vida de Escritório S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9o1nrhyZ9ytj9yMdsKp8h0BAqI7.jpg'),
(96865, 6871, 'Vida de Escritório S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cpyKfQa8IbewT9nKh5dxyvhHrpt.jpg'),
(96866, 6871, 'Vida de Escritório S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/202394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pO4AvKEd0jSDnoY3LUaGpMU75Ze.jpg'),
(96867, 6871, 'Vida de Escritório S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/202395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/81kHQLh0DUrJVlUINyX7cqmfSr5.jpg'),
(96868, 6871, 'Vida de Escritório S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/202396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u6PMTaqsZm9EttcpKhB31bYuJjO.jpg'),
(96869, 6871, 'Vida de Escritório S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/202397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tUtHjbWt5FUJqGYibVNJP43pImi.jpg'),
(96870, 6871, 'Vida de Escritório S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/202398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rsRMZlYLx9tBQVNfcZiWFQxEOFh.jpg'),
(96871, 6871, 'Vida de Escritório S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/202399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kRthYgk84trb5gGtS6kO0LhzvXS.jpg'),
(96872, 6871, 'Vida de Escritório S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/202400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1KofdnTIguy5r9QaiWM99PZkdem.jpg'),
(96873, 6871, 'Vida de Escritório S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/202401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wErz8dAPlc5WsFWJGBWOt19gXJY.jpg'),
(96874, 6871, 'Vida de Escritório S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/202402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7UQJtATSIwVIACG351CjFOMU9Y1.jpg'),
(96875, 6871, 'Vida de Escritório S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/202403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/baFG7yOX05mOgVfBaQ0Ifu5RsU0.jpg'),
(96876, 6871, 'Vida de Escritório S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/202404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iFV3oe7FO0IkRS5CfGrQ9ErTTWO.jpg'),
(96877, 6871, 'Vida de Escritório S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/202405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h2pkF8dBdUzMJDa7dOy0aI2FIL2.jpg'),
(96878, 6872, 'Vida de Escritório S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9XUFWn9fvuA1oo3DdAfb3A4ZEIo.jpg'),
(96879, 6872, 'Vida de Escritório S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f3eB97S8bG6YMppV6rJDU3jCbZ5.jpg'),
(96880, 6872, 'Vida de Escritório S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fhlA5VjRYpdz9Lz240rBHkzdith.jpg'),
(96881, 6872, 'Vida de Escritório S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xXbmG475A38gxP7DUXDCdup6iSE.jpg'),
(96882, 6872, 'Vida de Escritório S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rUEiF3dFXEH56LosjzJnCsQammN.jpg'),
(96883, 6872, 'Vida de Escritório S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1h3xA3zrcy2OVqPBY7tR3qgML2z.jpg'),
(96884, 6872, 'Vida de Escritório S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/80m3XUSqFfCMNw6GpWY2Q1KAesS.jpg'),
(96885, 6872, 'Vida de Escritório S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cjqRFwr2v91gq8qzfefil8egCPt.jpg'),
(96886, 6872, 'Vida de Escritório S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Mf0l59K2OQ0I7q1oR06cIqo5zT.jpg'),
(96887, 6872, 'Vida de Escritório S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dMcPzhH0rScvMSejNluYtFYxISg.jpg'),
(96888, 6872, 'Vida de Escritório S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gUtF2A9EfkdthCrlxTnqd0sXRpO.jpg'),
(96889, 6872, 'Vida de Escritório S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfOP5WZIkDNifAfXwQ7H84ZrqTv.jpg'),
(96890, 6872, 'Vida de Escritório S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/202418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y1RkiIw0eNhhH1wLzUyYYimlBVg.jpg'),
(96891, 6872, 'Vida de Escritório S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/202419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zy4NJR9kqEelJ5teHPlAINBNnpE.jpg'),
(96892, 6872, 'Vida de Escritório S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/202420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8KtuuZvOqAyHyIB7l0gxf2XfgYN.jpg'),
(96893, 6872, 'Vida de Escritório S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/202421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJoRCwptCOpTZVkYysHDBFdO4OR.jpg'),
(96894, 6872, 'Vida de Escritório S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/202422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rtTNNuGbkeLJxQ0XJegQ7J3TNma.jpg'),
(96895, 6872, 'Vida de Escritório S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/202423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aDdapd9idn06AAQsLVvaSDSrWlm.jpg'),
(96896, 6872, 'Vida de Escritório S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/202424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oAue77ie9C2MGFpwCbMIvoPvbNQ.jpg'),
(96897, 6872, 'Vida de Escritório S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/202425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ztEK1MtwwbG7D0jb95A59qxaS3G.jpg'),
(96898, 6872, 'Vida de Escritório S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/202426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/viBmFStZIZMOXq71YDrBgqZEhDD.jpg'),
(96899, 6872, 'Vida de Escritório S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/202427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m3Wcby9maE08RaH3mS7aAHw5hkM.jpg'),
(96900, 6872, 'Vida de Escritório S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/202428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1pJtFmAS3TJuWoCaUrY904pqNFE.jpg'),
(96901, 6872, 'Vida de Escritório S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/202429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNZAJgcGVDxjv4PtJ2xU6MPZlHh.jpg'),
(96902, 6872, 'Vida de Escritório S09 E25', 'http://sinalprivado.info:80/series/1533784/1533784/202430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNZAJgcGVDxjv4PtJ2xU6MPZlHh.jpg'),
(96903, 6872, 'Vida de Escritório S09 E26', 'http://sinalprivado.info:80/series/1533784/1533784/202431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNZAJgcGVDxjv4PtJ2xU6MPZlHh.jpg'),
(96904, 6872, 'Vida de Escritório S09 E27', 'http://sinalprivado.info:80/series/1533784/1533784/202432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNZAJgcGVDxjv4PtJ2xU6MPZlHh.jpg'),
(96905, 6873, 'Private Eyes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nRYlBik8ox5BGVzY1GkAtxbLRBq.jpg'),
(96906, 6873, 'Private Eyes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gLPK330yBzvI8MV0YpJ4R61oG8g.jpg'),
(96907, 6873, 'Private Eyes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7FlOntf6OoWryZFAjq0yZh8cygZ.jpg'),
(96908, 6873, 'Private Eyes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7rAL7HBbF8qenfYEufmXViZQfBN.jpg'),
(96909, 6873, 'Private Eyes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6VcXKwWYGqYz0xSv67l7zVHYrio.jpg'),
(96910, 6873, 'Private Eyes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDektl2pgiyxKZcklqqUDkuS5Ed.jpg'),
(96911, 6873, 'Private Eyes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j9824JkdSOI55OcTHvsTuQX16Zh.jpg'),
(96912, 6873, 'Private Eyes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d7wqAeIjE3mf4CERZDsLS1Ti9nY.jpg'),
(96913, 6873, 'Private Eyes S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hoQxpejY0tgBaza6olYI8Upfpxu.jpg'),
(96914, 6873, 'Private Eyes S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7IhMMQr32Wtza4B7p78C7mmBzeO.jpg'),
(96915, 6874, 'Private Eyes S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7JBMnHjnYvPL1g9V2ZnhWJku0Em.jpg'),
(96916, 6874, 'Private Eyes S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/daTXlcPuhytKZB1MOTeCwVv1LTi.jpg'),
(96917, 6874, 'Private Eyes S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vKrlxLvgB8zJnX42ETEptsHouPY.jpg'),
(96918, 6874, 'Private Eyes S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eYvfDrV0GeU5jmOI861fv8JVcf6.jpg'),
(96919, 6874, 'Private Eyes S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1LuSmHkN3jrHvICeRbi4FS4J47W.jpg'),
(96920, 6874, 'Private Eyes S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lpVkvvBe08TEYejy1NPfpJZMbSt.jpg'),
(96921, 6874, 'Private Eyes S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhlfQuQn5piHG5icpimLF6svyRY.jpg'),
(96922, 6874, 'Private Eyes S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vQMwQOD9Bmw98NPfGeHx4s2umP2.jpg'),
(96923, 6874, 'Private Eyes S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j07mqZDbCL4O6oi6nbpkqAzS0dA.jpg'),
(96924, 6874, 'Private Eyes S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vV45t7wiel61ovZLZl0YJc1xfeh.jpg'),
(96925, 6874, 'Private Eyes S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2SwkZzIaXQo3pFtSZM6Wh7DFA0A.jpg'),
(96926, 6874, 'Private Eyes S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kqoepq1uTxvZWWZszXTQQHamUzz.jpg'),
(96927, 6874, 'Private Eyes S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/202191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hXwapvjlcUspepFBG2HnRerl28Q.jpg'),
(96928, 6874, 'Private Eyes S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/202192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v9zoiRgjn1uobnUfhpdzsO5B7ZM.jpg'),
(96929, 6874, 'Private Eyes S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/202193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/scljtApxyFyTbEEa8NQZeC2xyxQ.jpg'),
(96930, 6874, 'Private Eyes S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/202194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZcQx86e6llLcqMryqUbVAJVD1s.jpg'),
(96931, 6874, 'Private Eyes S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/202195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Vdiuk4kXNdyLK0wogd6ZhiHkWy.jpg'),
(96932, 6874, 'Private Eyes S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/202196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCOsSdU6Fmxnl7i3caVUmjDukYB.jpg'),
(96933, 6875, 'Private Eyes S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aamG5MyMRRo0voN73FyDrXBB93g.jpg'),
(96934, 6875, 'Private Eyes S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/86cm3hBzwK4xqIZAvmPO9PLZG1h.jpg'),
(96935, 6875, 'Private Eyes S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dnp2Mfe5EJN4ZxOzej1YsH79jS3.jpg'),
(96936, 6875, 'Private Eyes S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yOQhdeND0eDQgWOK5FXGfrTuLry.jpg'),
(96937, 6875, 'Private Eyes S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fSkxL5GNqgqdVrqoiM9JLqkbXwE.jpg'),
(96938, 6875, 'Private Eyes S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lDrall77CeoDREchg398J6HfqAi.jpg'),
(96939, 6875, 'Private Eyes S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yql3IHSZZHWmBT9n6EhnC7KZ8Ii.jpg'),
(96940, 6875, 'Private Eyes S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dUeTqMqW0e4oviKzgIag20g7DBI.jpg'),
(96941, 6875, 'Private Eyes S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g854whv3rJd5gAn9wWdSkMyeC6T.jpg'),
(96942, 6875, 'Private Eyes S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fNjxo5uzvCz7wqxNHPmvig080JQ.jpg'),
(96943, 6875, 'Private Eyes S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tZH5yNXAYECQHZUjhqGuNzHsh1C.jpg'),
(96944, 6875, 'Private Eyes S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i5ccqiVrRzVGlME60bJIWoqS5l2.jpg'),
(96945, 6876, 'Private Eyes S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/obZOLDARdi8TNLnagzX0gopOLuh.jpg'),
(96946, 6876, 'Private Eyes S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6k1J3Ghf0J2OmfjhCuk4mi17sGc.jpg'),
(96947, 6876, 'Private Eyes S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vRKwmhZY6YU5OQnEgH7RTi9wlME.jpg'),
(96948, 6876, 'Private Eyes S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xqXtezwic8m2CEbB3j26Aby3GC7.jpg'),
(96949, 6876, 'Private Eyes S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lFHRvz78Y4WKUwFn2BO7BbNDN6Y.jpg'),
(96950, 6876, 'Private Eyes S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fD96bYreuAPF2IpTovKBPPAoYEg.jpg'),
(96951, 6876, 'Private Eyes S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYDMxJMMy6p1hz7EMZjpcdqW6MB.jpg'),
(96952, 6876, 'Private Eyes S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5WtzMOmBzJ7IpqbnxbxyNdva3xt.jpg'),
(96953, 6876, 'Private Eyes S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xWT3jutvs4xztc7fzttH6FX0a1T.jpg'),
(96954, 6876, 'Private Eyes S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/73Ki8lIr5BMJC43zNbGFluNn874.jpg'),
(96955, 6876, 'Private Eyes S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUIgNnbeIFDxD0K0Tae4z3DPMAp.jpg'),
(96956, 6876, 'Private Eyes S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zaBP0O27ShCCSbZdWXnhCRSHFqJ.jpg'),
(96957, 6877, 'Private Eyes S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l5EHmUmxXMygry1ykOV4QqOU3Bt.jpg'),
(96958, 6877, 'Private Eyes S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjqVHhScWMspZiiPZoIxlqogByc.jpg'),
(96959, 6877, 'Private Eyes S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oS4WjV2ulf5OrjmkTr29wXK8rz0.jpg'),
(96960, 6877, 'Private Eyes S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uR1Y2Gp5qllFRnLkidGjHqLBo2B.jpg'),
(96961, 6877, 'Private Eyes S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kWhMviISJSsmgMvlfyciThxnMbo.jpg'),
(96962, 6877, 'Private Eyes S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4H5gy11CKRrFWcT0dZ5ldGJNN47.jpg'),
(96963, 6877, 'Private Eyes S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bA1fmYUpKrltFv9afL4k6wtHd24.jpg'),
(96964, 6877, 'Private Eyes S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kmBmKC50OOe67lUTc4oDJmimpaj.jpg'),
(96965, 6878, 'A Mulher dos Mortos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vps6SbQOJTXQfpmX4myxcgU7uKY.jpg'),
(96966, 6878, 'A Mulher dos Mortos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mEewnqBljLA5bg8jneFVmb2QkG3.jpg'),
(96967, 6878, 'A Mulher dos Mortos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xduVQa8qmijNyPHAKhHnonRnpMY.jpg'),
(96968, 6878, 'A Mulher dos Mortos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4XLId2cbWem0aL00cS1KteajY5q.jpg'),
(96969, 6878, 'A Mulher dos Mortos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n2eB4ZGNYdQhlc3ViGMQUt1imoA.jpg'),
(96970, 6878, 'A Mulher dos Mortos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ceSHK5jGrFypY9JuMIpz4OgyONI.jpg'),
(96971, 6879, 'A Mulher dos Mortos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/731708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/weMoJHopM7SVGUy2AAgzHWvimRv.jpg'),
(96972, 6879, 'A Mulher dos Mortos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/731709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/weMoJHopM7SVGUy2AAgzHWvimRv.jpg'),
(96973, 6879, 'A Mulher dos Mortos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/731710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/weMoJHopM7SVGUy2AAgzHWvimRv.jpg'),
(96974, 6879, 'A Mulher dos Mortos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/731711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/weMoJHopM7SVGUy2AAgzHWvimRv.jpg'),
(96975, 6879, 'A Mulher dos Mortos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/731712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/weMoJHopM7SVGUy2AAgzHWvimRv.jpg'),
(96976, 6879, 'A Mulher dos Mortos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/731713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/weMoJHopM7SVGUy2AAgzHWvimRv.jpg'),
(96977, 6880, 'A Teia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uI8HWd0ksskaoypg5vE7zj3zTUe.jpg'),
(96978, 6880, 'A Teia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uI8HWd0ksskaoypg5vE7zj3zTUe.jpg'),
(96979, 6880, 'A Teia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uI8HWd0ksskaoypg5vE7zj3zTUe.jpg'),
(96980, 6880, 'A Teia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uI8HWd0ksskaoypg5vE7zj3zTUe.jpg'),
(96981, 6880, 'A Teia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uI8HWd0ksskaoypg5vE7zj3zTUe.jpg'),
(96982, 6880, 'A Teia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uI8HWd0ksskaoypg5vE7zj3zTUe.jpg'),
(96983, 6880, 'A Teia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uI8HWd0ksskaoypg5vE7zj3zTUe.jpg'),
(96984, 6880, 'A Teia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uI8HWd0ksskaoypg5vE7zj3zTUe.jpg'),
(96985, 6880, 'A Teia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uI8HWd0ksskaoypg5vE7zj3zTUe.jpg'),
(96986, 6880, 'A Teia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uI8HWd0ksskaoypg5vE7zj3zTUe.jpg'),
(96987, 6881, 'Vamos Curtir! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9lxGzfwTpk68UjkzkSl9b3KcrRY.jpg'),
(96988, 6881, 'Vamos Curtir! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9lxGzfwTpk68UjkzkSl9b3KcrRY.jpg'),
(96989, 6881, 'Vamos Curtir! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9lxGzfwTpk68UjkzkSl9b3KcrRY.jpg'),
(96990, 6881, 'Vamos Curtir! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9lxGzfwTpk68UjkzkSl9b3KcrRY.jpg'),
(96991, 6882, 'A Vida Mentirosa dos Adultos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sGZSWuhlmgeG8W1ICsEKntgnJP9.jpg'),
(96992, 6882, 'A Vida Mentirosa dos Adultos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lemUuiZ2XN2LSt9fuYMS5QoCxWl.jpg'),
(96993, 6882, 'A Vida Mentirosa dos Adultos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/esqYSQ11UCcJ2hepmNOhnxINfeX.jpg'),
(96994, 6882, 'A Vida Mentirosa dos Adultos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nrg49riHaSXiVbFmNG4YbiOZcAX.jpg'),
(96995, 6882, 'A Vida Mentirosa dos Adultos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JT5TdrKl51P4dl63AlGWZpJ9A2.jpg'),
(96996, 6882, 'A Vida Mentirosa dos Adultos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8GDWxMRBC146elUO9WMemFgzn5T.jpg'),
(96997, 6883, 'Akuyaku Reijou nanode Last Boss wo Kattemimashita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rshtlgNECveCJIgUNYJBlgbaKSH.jpg'),
(96998, 6883, 'Akuyaku Reijou nanode Last Boss wo Kattemimashita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hsSm79v0EA3DRxC5UeSvdFhx92c.jpg'),
(96999, 6883, 'Akuyaku Reijou nanode Last Boss wo Kattemimashita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rvb7qSIVOlwwjRJaJ88IrD1PXm.jpg'),
(97000, 6883, 'Akuyaku Reijou nanode Last Boss wo Kattemimashita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFQMVedqBKlN05VUZOV1XnoRhVN.jpg'),
(97001, 6883, 'Akuyaku Reijou nanode Last Boss wo Kattemimashita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ykOyV4rlfiVIye5kTT0ByfPWtCj.jpg'),
(97002, 6883, 'Akuyaku Reijou nanode Last Boss wo Kattemimashita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uzpdD8ka564PEbMLf8QjpxcPRsY.jpg'),
(97003, 6883, 'Akuyaku Reijou nanode Last Boss wo Kattemimashita S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zxN6IezzpOaBrQ8z3RGl5Equ74a.jpg'),
(97004, 6883, 'Akuyaku Reijou nanode Last Boss wo Kattemimashita S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ywzaT8jC5AbF4dcmg1Mothd33eB.jpg'),
(97005, 6883, 'Akuyaku Reijou nanode Last Boss wo Kattemimashita S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6l7tJ3NDoWVpjurVyGLhMzPgV5d.jpg'),
(97006, 6883, 'Akuyaku Reijou nanode Last Boss wo Kattemimashita S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sWBWFwNQQJcNkf5zWMoNZlu7Jki.jpg'),
(97007, 6883, 'Akuyaku Reijou nanode Last Boss wo Kattemimashita S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/202141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ObnltzfDWTWPLyrLWII804BqxR.jpg'),
(97008, 6883, 'Akuyaku Reijou nanode Last Boss wo Kattemimashita S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/202142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AdVKIn7lvJvlb35bhVIfdenoIMb.jpg'),
(97009, 6884, 'Chefs Sob Pressão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aa1MRZkH4UXbSiWM9vwFzzPb73C.jpg'),
(97010, 6884, 'Chefs Sob Pressão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eoAe7JwmsquXoexXdmijkFx2JUj.jpg'),
(97011, 6884, 'Chefs Sob Pressão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2cj9ZWgg8OfXXfMgCpOZm3IKEQ.jpg'),
(97012, 6884, 'Chefs Sob Pressão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/28UHNtFwWZ3KyEssmOKRpQNR95a.jpg'),
(97013, 6884, 'Chefs Sob Pressão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zTQw6b0DAqTlnQkipqlGggYqr5c.jpg'),
(97014, 6884, 'Chefs Sob Pressão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t8TLNDu6jTz0YsIAl5yN0yEUDGt.jpg'),
(97015, 6884, 'Chefs Sob Pressão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5o94ZGA1tNMIk1pSAKSVv6SPhGL.jpg'),
(97016, 6884, 'Chefs Sob Pressão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bJ7c1AUeajFSB5pe37OvJIUlwXB.jpg'),
(97017, 6885, 'Cidade Fantasma: Terror em Montana S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/17LrlTLoCAA13jU2TVeGdiXw8d0.jpg'),
(97018, 6885, 'Cidade Fantasma: Terror em Montana S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gEYXBhFxWA12BKOZDDveRaVYxmZ.jpg'),
(97019, 6885, 'Cidade Fantasma: Terror em Montana S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9uK16LRoYewg7SU4FxDbg1vTn2b.jpg'),
(97020, 6885, 'Cidade Fantasma: Terror em Montana S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pwMb19p9k0qUYaWkyx3ZVoFci3t.jpg'),
(97021, 6885, 'Cidade Fantasma: Terror em Montana S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/47D4F06cvmnJ0kN9puGXMfsfZYl.jpg'),
(97022, 6885, 'Cidade Fantasma: Terror em Montana S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rH2ZmIwFqC8zLOXkrcYVYzFxlnK.jpg'),
(97023, 6886, 'Depois do Julgamento S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzUDGLCjKCdVh11prYMwfCRBtuk.jpg'),
(97024, 6886, 'Depois do Julgamento S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1wSolTaMDcVdytgKMXhDNevojmD.jpg'),
(97025, 6886, 'Depois do Julgamento S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eb1RD2AKCCAeoo2ckoF8U92oqva.jpg'),
(97026, 6886, 'Depois do Julgamento S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eb1RD2AKCCAeoo2ckoF8U92oqva.jpg'),
(97027, 6886, 'Depois do Julgamento S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eb1RD2AKCCAeoo2ckoF8U92oqva.jpg'),
(97028, 6886, 'Depois do Julgamento S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eb1RD2AKCCAeoo2ckoF8U92oqva.jpg'),
(97029, 6887, 'Diários de Guerra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOTLwvze5t87Eo3RFO96YZ45aw8.jpg'),
(97030, 6887, 'Diários de Guerra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cUGhJMuvFEIiPrgO8Sg8HupoIIr.jpg'),
(97031, 6887, 'Diários de Guerra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qSozWEe1n95NGB9QJ32LDKFeIh2.jpg'),
(97032, 6887, 'Diários de Guerra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ngqfwBwN0MJowpoTaE3WJYmqtDP.jpg'),
(97033, 6887, 'Diários de Guerra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PbQN8VE8TjkGuAiZ63J6XVaBEy.jpg'),
(97034, 6888, 'Hotel Portofino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rVjaGJDM18m3cqZ0VQJgFai0sne.jpg'),
(97035, 6888, 'Hotel Portofino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1GlXy9ASrqYjARuWAsJdeCCqgvc.jpg'),
(97036, 6888, 'Hotel Portofino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b69xOZ9pO7UzcP9EdLSbc0kyJFH.jpg'),
(97037, 6888, 'Hotel Portofino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sVGeBnZxkPEs1s1YJLLGIyYBa30.jpg'),
(97038, 6888, 'Hotel Portofino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qs11HtD5rTH6xpblhS6wfefG5b7.jpg'),
(97039, 6889, 'Jovem Diaba S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u9pgjSUyHaij74PCLbT38HeNDxd.jpg'),
(97040, 6889, 'Jovem Diaba S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6GZLzuxUWMCi8ktmuQDJYzC3h1g.jpg'),
(97041, 6889, 'Jovem Diaba S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Wbdf0oB2Lcpi3fzytJFWKESdKK.jpg'),
(97042, 6889, 'Jovem Diaba S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2FajHXaE3AldMLvWGjGEMjVHiKE.jpg'),
(97043, 6889, 'Jovem Diaba S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gn62Nw2XOLwvm4wuEydonEC1rqo.jpg'),
(97044, 6889, 'Jovem Diaba S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xDH7oBH87dp68rFRaKNR9YQWLfT.jpg'),
(97045, 6889, 'Jovem Diaba S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzYJEK7oAIEZDwG3ntegpCiZfzf.jpg'),
(97046, 6889, 'Jovem Diaba S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wL8uZxtuepMF2diSHYlLy43caGM.jpg'),
(97047, 6889, 'Jovem Diaba S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ozCwQ5VlxSmGLGkcrDK8aAuWboR.jpg'),
(97048, 6889, 'Jovem Diaba S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t9bhPfv8V58TJKeMRVL5DZJVVHG.jpg'),
(97049, 6890, 'Mistério no Mar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gF55X6Rzg1yVOvoINhBe4edjiSe.jpg'),
(97050, 6890, 'Mistério no Mar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mfujg5jo1tYPRItXAeBtHtHspjy.jpg'),
(97051, 6890, 'Mistério no Mar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sPFfYBkxii3nPsa2MyrRSoLPPCb.jpg'),
(97052, 6890, 'Mistério no Mar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/siuwXmG7QmwgqOQPGMfZIh8VBjT.jpg'),
(97053, 6890, 'Mistério no Mar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mkHY1oZomtX4Rnpu2RrfRKaREDZ.jpg'),
(97054, 6890, 'Mistério no Mar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kPuOZ8eAIo4Vik9Uf4YsWdvVWpg.jpg'),
(97055, 6891, 'Mistério no Mar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/658968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gFcgB8v0cykud9tfIPmqGZC32z.jpg'),
(97056, 6891, 'Mistério no Mar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/658969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gFcgB8v0cykud9tfIPmqGZC32z.jpg'),
(97057, 6891, 'Mistério no Mar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/658970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gFcgB8v0cykud9tfIPmqGZC32z.jpg'),
(97058, 6891, 'Mistério no Mar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/658971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gFcgB8v0cykud9tfIPmqGZC32z.jpg'),
(97059, 6891, 'Mistério no Mar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/658972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gFcgB8v0cykud9tfIPmqGZC32z.jpg'),
(97060, 6891, 'Mistério no Mar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/658973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gFcgB8v0cykud9tfIPmqGZC32z.jpg'),
(97061, 6892, 'Sangue Azul S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2435QqVqVkZWdV7Cxe1JDjC7bb7.jpg'),
(97062, 6892, 'Sangue Azul S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mlJ0zE1rftaZ1vzW1Ydazpukip4.jpg'),
(97063, 6892, 'Sangue Azul S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vPdwxq9S5OAKlGVMrg9n6n5frCd.jpg'),
(97064, 6892, 'Sangue Azul S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1vBRaioBoB03ulZhm7DFA7RBYHQ.jpg'),
(97065, 6892, 'Sangue Azul S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1B9JdV2f8EpRnky3o0wsAtyriug.jpg'),
(97066, 6892, 'Sangue Azul S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mdv6JckAaZss3VfBRAQ9ZFdvbGC.jpg'),
(97067, 6892, 'Sangue Azul S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1bPvRhc6vrWQFGyYSVE3R5X1ybz.jpg'),
(97068, 6892, 'Sangue Azul S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y6b2DBeCam56RXmYvjPO30F9DtS.jpg'),
(97069, 6892, 'Sangue Azul S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v3tyxX1pi8UbpaAKYY1FNowC5s9.jpg'),
(97070, 6892, 'Sangue Azul S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2OLB3cN3rgLSU5xpV0dnimjGQQi.jpg'),
(97071, 6892, 'Sangue Azul S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pYc8gUpwkYvQPUn1cXfFFOGcg2D.jpg'),
(97072, 6892, 'Sangue Azul S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yJxuqB2zP3x0nChRdK5kP9ZEB5.jpg'),
(97073, 6892, 'Sangue Azul S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zOM9H9iOnHqb7pw3Ki2wu2nBXtz.jpg'),
(97074, 6892, 'Sangue Azul S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wU3sz1Y4LvyYbNre84NcMbM7QaM.jpg'),
(97075, 6892, 'Sangue Azul S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mk1y2CJxIdqDtQuUMXrcbXH1otr.jpg'),
(97076, 6892, 'Sangue Azul S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zaF2Jfj3vhssFQcsj3pEFxEYBvO.jpg'),
(97077, 6892, 'Sangue Azul S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6aRjnjwRUXUF8oX7fe3gAU58Ci.jpg'),
(97078, 6892, 'Sangue Azul S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/knSCL9cTQJJ5oG2MeUR0kv956pV.jpg'),
(97079, 6892, 'Sangue Azul S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j6vLPHSpOnt8IJH8eszsbRKu2p5.jpg'),
(97080, 6892, 'Sangue Azul S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWRtkfEjL8DEttGcDv8rQgBijG2.jpg'),
(97081, 6892, 'Sangue Azul S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vqkeyAqDYp7P6KsvyEEt7U2gsMe.jpg'),
(97082, 6892, 'Sangue Azul S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nbiu04liblYaylQ4YgLGjYBpody.jpg'),
(97083, 6893, 'Sangue Azul S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJ3KCd26M6RlbeVA0okvPY5lr9S.jpg'),
(97084, 6893, 'Sangue Azul S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yVTrlW7prN1Nq2DoCcFilzNrVYV.jpg'),
(97085, 6893, 'Sangue Azul S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7wfaKhQlqjBkyAKwkYMCXUv1Mt4.jpg'),
(97086, 6893, 'Sangue Azul S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zspsT3pMuLtF17ORtAgVHgy55zk.jpg'),
(97087, 6893, 'Sangue Azul S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wrRvoYXLbO9TmFdZYJ4Z3a33Col.jpg'),
(97088, 6893, 'Sangue Azul S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1CB2d4wRhWrbECPXfR54A8TlxB0.jpg'),
(97089, 6893, 'Sangue Azul S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8kPAj7HsOg2BTnmqyp5Ru56LZav.jpg'),
(97090, 6893, 'Sangue Azul S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1znXRSATmkuCDccTJVU7NI2rqTb.jpg'),
(97091, 6893, 'Sangue Azul S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qIaEtVgYGCfbKLekYvUYdNjzFev.jpg'),
(97092, 6893, 'Sangue Azul S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pZ0K1BOYIvl8oTAM2V9rvb1600F.jpg'),
(97093, 6893, 'Sangue Azul S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iQhe8mQstslSYWlxfSeI1LJdsVX.jpg'),
(97094, 6893, 'Sangue Azul S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eXyV1ecLwKXcUP8AylX23MsHW7c.jpg'),
(97095, 6893, 'Sangue Azul S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A2r1A0zckvd6RI4ydbWULe4TlLv.jpg'),
(97096, 6893, 'Sangue Azul S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/65ZUCBWDlgvPFgmU7fufHcOxkwT.jpg'),
(97097, 6893, 'Sangue Azul S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yaFBAIitTekch8OkCvlDx45egVc.jpg'),
(97098, 6893, 'Sangue Azul S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nELTv7ifv4fV2YdHQOWiSuJVOMd.jpg'),
(97099, 6893, 'Sangue Azul S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/IV0Kx5K3qoflei8fE2ziq6g3JS.jpg'),
(97100, 6893, 'Sangue Azul S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rj3EnZ7pScKJbiN11p4boeuYTY5.jpg'),
(97101, 6893, 'Sangue Azul S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lc8eWCGAh2BT9TuBhVSVCahHqnH.jpg'),
(97102, 6893, 'Sangue Azul S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cWjQLwGvSo1PzqK7r8ZwFhr2nYZ.jpg'),
(97103, 6893, 'Sangue Azul S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qTtP80tiDFeCOtX8DD8NVahXuOK.jpg'),
(97104, 6893, 'Sangue Azul S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOTDrQEjV8yHrSRtqeM36abYqQO.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(97105, 6894, 'Sangue Azul S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lsTgxB8EHOnDKW3gklEEJ54Nwpn.jpg'),
(97106, 6894, 'Sangue Azul S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5bDsjd8bh6fArokMa4GPmK3x3K4.jpg'),
(97107, 6894, 'Sangue Azul S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdzFBVgKVu8o9PTK1eecmwTVuy.jpg'),
(97108, 6894, 'Sangue Azul S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvbrhg4AM4IZcVC8Y9252gWJLF7.jpg'),
(97109, 6894, 'Sangue Azul S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5M2F2SvEoojXIHZWEIfNStclCqG.jpg'),
(97110, 6894, 'Sangue Azul S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AcZ46Q4P3OYXlTfXHiOToSD07sp.jpg'),
(97111, 6894, 'Sangue Azul S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tb861ZZeY8QzqBdLjt8eslA1TDs.jpg'),
(97112, 6894, 'Sangue Azul S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ikdrerM2EXDDiTlj60fY7p0lPr8.jpg'),
(97113, 6894, 'Sangue Azul S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cXZ9eR88stFPK9s4DJ5H0nyRikv.jpg'),
(97114, 6894, 'Sangue Azul S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r45HTHJGWZofnJLRGnHzjctfoG5.jpg'),
(97115, 6894, 'Sangue Azul S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l0sAa5DUKj5UadfzJM2WzRrmJVh.jpg'),
(97116, 6894, 'Sangue Azul S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yjDkhWnI4xDGsIE49c3kSQv4Mwi.jpg'),
(97117, 6894, 'Sangue Azul S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lheMDGu6cJnAwpNnGkKPWIdvrJ1.jpg'),
(97118, 6894, 'Sangue Azul S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mkkFVrUmh9kxZphTD4jAIrKTkCT.jpg'),
(97119, 6894, 'Sangue Azul S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ngzly35ffoMVDXVBOCbXOyalbeu.jpg'),
(97120, 6894, 'Sangue Azul S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uQRhE2RI7lhFgyOuQwgf8k2ZnxK.jpg'),
(97121, 6894, 'Sangue Azul S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ykYxWewwkv7o4TTlR3Fekjxte7c.jpg'),
(97122, 6894, 'Sangue Azul S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g5AHqzpntTTfeQSS3wf95PrunX7.jpg'),
(97123, 6894, 'Sangue Azul S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2FMIsdskaTeAKpAkxqPljsVARWW.jpg'),
(97124, 6894, 'Sangue Azul S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vI1hyrZNLaodZvRVFv4vycw9zvw.jpg'),
(97125, 6894, 'Sangue Azul S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tiUrt63SUZyJt13HZy4IFGWEkA1.jpg'),
(97126, 6894, 'Sangue Azul S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wkGMWmLCk3hlk3iWxLLJ5hbjrjD.jpg'),
(97127, 6894, 'Sangue Azul S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/260913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c5q5T71rmRMh0pxaTGvDJodSEp8.jpg'),
(97128, 6895, 'Sangue Azul S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zpzdheUmduYSu8lZzhbamCFsABO.jpg'),
(97129, 6895, 'Sangue Azul S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/994K0lx5uxkXhTFfv1328GIa7tF.jpg'),
(97130, 6895, 'Sangue Azul S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oj3xUtXA2t4CDM8l9gOaM1jMuJc.jpg'),
(97131, 6895, 'Sangue Azul S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yXl5m4t5yi2CY8j2HucklzvSRLu.jpg'),
(97132, 6895, 'Sangue Azul S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fbJoKvTeVpqmbi2IGVypc8gHaRQ.jpg'),
(97133, 6895, 'Sangue Azul S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sDbrf6XDRufzEzqLTtCQxfhbYrG.jpg'),
(97134, 6895, 'Sangue Azul S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rl4PT7RoTaduLuEK3oG5ZQ2n7aB.jpg'),
(97135, 6895, 'Sangue Azul S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oj2RfMLa6s7zeZv1sh90DGzzMo8.jpg'),
(97136, 6895, 'Sangue Azul S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mVOlefvgFETqFV0GRUUX8soNVcG.jpg'),
(97137, 6895, 'Sangue Azul S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lhn0p1EnPVwm97QevZJigwo1q3E.jpg'),
(97138, 6895, 'Sangue Azul S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3gR1DOmDTdfnHoDoGGeAvyOvemt.jpg'),
(97139, 6895, 'Sangue Azul S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jHtM40v6GiqvvUno6jcIC3p4qRt.jpg'),
(97140, 6895, 'Sangue Azul S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lW03dqEn1UmZzS07dgKdGvlV5qq.jpg'),
(97141, 6895, 'Sangue Azul S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vkALh1YzeKnicWU9yrbZB1vxhTK.jpg'),
(97142, 6895, 'Sangue Azul S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jQuCz5yy0eTNpl6VGz5ARvlUoAL.jpg'),
(97143, 6895, 'Sangue Azul S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/czAWvniUzFIjChFFJj63RfHYf7X.jpg'),
(97144, 6895, 'Sangue Azul S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w7rZF1NGzNbzEe2J0OY1iG93kAx.jpg'),
(97145, 6895, 'Sangue Azul S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kHD45bONsITISl6OGysj0iUBXyI.jpg'),
(97146, 6895, 'Sangue Azul S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCpqk6tYIAGsMlwd8vjwlWICX3L.jpg'),
(97147, 6895, 'Sangue Azul S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgimUNHXA5WbvCmgJwSq04o9W2U.jpg'),
(97148, 6895, 'Sangue Azul S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zTvSUKUOaYeSYVbSuQ4ew43cqUk.jpg'),
(97149, 6895, 'Sangue Azul S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aneAjDHgyhkNhts48q8qj3ocHCe.jpg'),
(97150, 6896, 'Sangue Azul S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vajcdwxVZL1zWqo7LQsU72SngbS.jpg'),
(97151, 6896, 'Sangue Azul S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A0pImYpatlZje3cgqKlpDuwX8KH.jpg'),
(97152, 6896, 'Sangue Azul S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1bntiF74JvVdLbhMj2oVC6mzXEs.jpg'),
(97153, 6896, 'Sangue Azul S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/egbAYQsMLlBLABPo9b2NEQSWw8X.jpg'),
(97154, 6896, 'Sangue Azul S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3oW3GD7hX733A6MGf74PLlrNIoD.jpg'),
(97155, 6896, 'Sangue Azul S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zaW5k6sJFpyd92WSLqvtcFBus96.jpg'),
(97156, 6896, 'Sangue Azul S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4IninY0gb5IWEpdXVQQFnKuTCfl.jpg'),
(97157, 6896, 'Sangue Azul S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4efDwscnDwD983z9Q2BdqN0BKnJ.jpg'),
(97158, 6896, 'Sangue Azul S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tbDcUUbijFBbu1BlJnoIEoBZiBz.jpg'),
(97159, 6896, 'Sangue Azul S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v63ts0jqP1REke4daPYLEBNn6v.jpg'),
(97160, 6896, 'Sangue Azul S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/16Pa9C5VsmL8KKhAYDoCAipePDC.jpg'),
(97161, 6896, 'Sangue Azul S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k5yYHQqTHuicPhKdUOdNxuMAmYC.jpg'),
(97162, 6896, 'Sangue Azul S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1cTOtbrctzj85wMXSxF4jJFhFrt.jpg'),
(97163, 6896, 'Sangue Azul S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bfvui9OgnB0Dk5EqYImKpUiaAzi.jpg'),
(97164, 6896, 'Sangue Azul S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/860UTGiTKTYHOZSXAr77QFrSahl.jpg'),
(97165, 6896, 'Sangue Azul S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4e4OcDjaup62YNFS9XhL2umuMzL.jpg'),
(97166, 6896, 'Sangue Azul S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c1HZCZjSTYwen7pKMggxszg6awx.jpg'),
(97167, 6896, 'Sangue Azul S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kttTGnrFQQCfgqVQJhExs8QVCJ6.jpg'),
(97168, 6896, 'Sangue Azul S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kFMWBSGYVKD7WuCApKarsA8bHuE.jpg'),
(97169, 6896, 'Sangue Azul S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dN1mToGlbEF6NFdQRDO9cQA9RWM.jpg'),
(97170, 6896, 'Sangue Azul S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xgaOSGWF2X7BQ4RyZWH6JjsYzzP.jpg'),
(97171, 6896, 'Sangue Azul S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qMgrhFqgQmSGFRjfCZdCzp7Jxvc.jpg'),
(97172, 6897, 'Sangue Azul S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9MCsj4Zd9UCRHhGkFHXFma4yYmi.jpg'),
(97173, 6897, 'Sangue Azul S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xK381zyjjii2pz6msA5cm3aAtVC.jpg'),
(97174, 6897, 'Sangue Azul S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bFItH7NGSf8HOAnIt7NJ5IpUl6S.jpg'),
(97175, 6897, 'Sangue Azul S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6uiUilRKaycJkgV1da17IrdiyXB.jpg'),
(97176, 6897, 'Sangue Azul S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k1d6gw28SziSVSjBzY8J6dP4rpR.jpg'),
(97177, 6897, 'Sangue Azul S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eVcEXrjnWZ3un6TmHRbeO5NT83b.jpg'),
(97178, 6897, 'Sangue Azul S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sM7WEg1OGzyboSnbwhAA5q9P5Oe.jpg'),
(97179, 6897, 'Sangue Azul S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3HXNAE4dYZLJWMDZ5j3oSpJokdO.jpg'),
(97180, 6897, 'Sangue Azul S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yzqgkNFHb3pgV22gTk7uSJttWFP.jpg'),
(97181, 6897, 'Sangue Azul S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/KDcSbMPH709AuTOlrhyr1Cs6R7.jpg'),
(97182, 6897, 'Sangue Azul S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pFgdG7EyrywCJ440Cj5vnqbwpji.jpg'),
(97183, 6897, 'Sangue Azul S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mhm019zu25PJ2EA1zubMxArx9Yg.jpg'),
(97184, 6897, 'Sangue Azul S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bnkFsyofpv9DQTG78a2lI2GJz7j.jpg'),
(97185, 6897, 'Sangue Azul S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLrQLDsN89c0qa4x9VHNqo0nTTS.jpg'),
(97186, 6897, 'Sangue Azul S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l4RzggvlFcxQt6fUbkgqgpTPOdZ.jpg'),
(97187, 6897, 'Sangue Azul S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBmdYi7x0q97ZkWxzxtxnSRlCR1.jpg'),
(97188, 6897, 'Sangue Azul S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9BVZL2uAuRBw7zGJ9ERxctgcXe8.jpg'),
(97189, 6897, 'Sangue Azul S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pRHFYHHFhb6yldm9N1LhJarebqc.jpg'),
(97190, 6897, 'Sangue Azul S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8GIEegkAX7ma8iMIUFt5CN7WcoI.jpg'),
(97191, 6897, 'Sangue Azul S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ldI5eLsiUj49N8dsRv98o7A8Nue.jpg'),
(97192, 6897, 'Sangue Azul S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wEDA3xGWkPGGrEG3PvxWaIZ8ESW.jpg'),
(97193, 6897, 'Sangue Azul S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hYLpo5Y1q48HwPCQN62gGt0M5Tl.jpg'),
(97194, 6898, 'Sangue Azul S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dhcC65PazEdRZqEfuJ9A4su7FHT.jpg'),
(97195, 6898, 'Sangue Azul S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qqzD2mpEHYY70G5DLQ3cvrSXlit.jpg'),
(97196, 6898, 'Sangue Azul S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pmJ9vfq5X3CBX13syV6IKgyLaCs.jpg'),
(97197, 6898, 'Sangue Azul S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pdt0M3R3sXOJyGX3EL7JHF1PLF7.jpg'),
(97198, 6898, 'Sangue Azul S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/as2PORjEyyYwbSLtBq1uRa2NnQQ.jpg'),
(97199, 6898, 'Sangue Azul S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gzmNtw2eLOcwg2ascZKSRKCPrha.jpg'),
(97200, 6898, 'Sangue Azul S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4fZdXfk67ulFqHtHHaD79LxFITn.jpg'),
(97201, 6898, 'Sangue Azul S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7WHbXz11y5BxssPtwnjBbL0nNNx.jpg'),
(97202, 6898, 'Sangue Azul S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9d1fG1A03vJZ7JS3dZ8lngK9IrW.jpg'),
(97203, 6898, 'Sangue Azul S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ohH0Kkel14Pmu66G8ZtC86wN5VX.jpg'),
(97204, 6898, 'Sangue Azul S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8XZe4vIJiAI4Fl13YmzChtk0L4.jpg'),
(97205, 6898, 'Sangue Azul S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dUyPW1HevMnSiIO0KtKYK0WmTNS.jpg'),
(97206, 6898, 'Sangue Azul S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/41wr6J35Ib71xffH3E3YUX3XGSQ.jpg'),
(97207, 6898, 'Sangue Azul S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A9AESIzRpZYOamHEekhuTulOnuf.jpg'),
(97208, 6898, 'Sangue Azul S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k4Fe5ckQdQufKnafsfVNoeOzows.jpg'),
(97209, 6898, 'Sangue Azul S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dCAOFSyqUocR2qOR9HmWSdbjD5G.jpg'),
(97210, 6898, 'Sangue Azul S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qVdcuSIYuR1WeOOZKIB9csZiJyt.jpg'),
(97211, 6898, 'Sangue Azul S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AjYPnTGrawRK1sZ3DmA5o7LVQHW.jpg'),
(97212, 6898, 'Sangue Azul S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6lPigpCd3FowvOLR9Z4w1kFNObc.jpg'),
(97213, 6898, 'Sangue Azul S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kJMJHOK9vEkBtNdaz8JtKFRXCIh.jpg'),
(97214, 6898, 'Sangue Azul S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/261000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xc3QzmZ4jS9JUBxxTSFhVdl8U7y.jpg'),
(97215, 6898, 'Sangue Azul S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/261001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBmliXok2aGayYjbOELe5jyKfUS.jpg'),
(97216, 6899, 'Sangue Azul S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iN9FWQRECWf9TYsCoFCB0mRC74g.jpg'),
(97217, 6899, 'Sangue Azul S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2v6gI9DVr2hiizwVPLMWekBPSmk.jpg'),
(97218, 6899, 'Sangue Azul S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pX8Li6bjsnVuRHyQ5k3v3wXIuxI.jpg'),
(97219, 6899, 'Sangue Azul S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cXgfJBh6F4CNdp41ijt7omqXYTW.jpg'),
(97220, 6899, 'Sangue Azul S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xV4ezEKaEi4EsVVkpaMJZkWLFgj.jpg'),
(97221, 6899, 'Sangue Azul S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5zK9DW7V6f8EKHMfVDQ0sQxTOh.jpg'),
(97222, 6899, 'Sangue Azul S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yOJC3ArZgD2hQNwltTLvShHtTbU.jpg'),
(97223, 6899, 'Sangue Azul S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rTYbylidRBGtCxZvA2gOTqfRHp.jpg'),
(97224, 6899, 'Sangue Azul S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8QrL9uLeM7eee7QRykIEoqJ0XZ.jpg'),
(97225, 6899, 'Sangue Azul S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gpgpqsn00kPB0DydAWSFnpEMNGL.jpg'),
(97226, 6899, 'Sangue Azul S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/261012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5xP5pzjB0tBGUnwXJffnoj8Sbu3.jpg'),
(97227, 6899, 'Sangue Azul S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/261013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sak8okMxYFqo0Og6l6Fg4FiZRir.jpg'),
(97228, 6899, 'Sangue Azul S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/261014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tqvvxhJ1tXeOdOGqjM5QPCKgbrE.jpg'),
(97229, 6899, 'Sangue Azul S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/261015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/il1XJImaFU79xpWdpcZG08AkmVX.jpg'),
(97230, 6899, 'Sangue Azul S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/261016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mWTDOd5T0dK36SgQsKBx0SUmDWM.jpg'),
(97231, 6899, 'Sangue Azul S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/261017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gqtJzw4bsIRyh7lHbhwnvpTSXCv.jpg'),
(97232, 6899, 'Sangue Azul S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/261018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jWP4QLl8xkWvbgRup835xQvKu83.jpg'),
(97233, 6899, 'Sangue Azul S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/261019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lg4uLl4Zwy03OcJeTbuVLXnSWbr.jpg'),
(97234, 6899, 'Sangue Azul S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/261020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rn5xsmlCYQNQjdxuqR5O0Ii2OaB.jpg'),
(97235, 6899, 'Sangue Azul S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/261021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2YIOuhASvYNZ1HoVDLlRcLaaHvU.jpg'),
(97236, 6899, 'Sangue Azul S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/261022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zmtAhBgJHVpLfd5NLF9HFBZHIP7.jpg'),
(97237, 6899, 'Sangue Azul S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/261023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cTTEXryOBnw6XCgC6IFK6bNEXTq.jpg'),
(97238, 6900, 'Sangue Azul S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/603WZjhSvrPbnBgGO0wuE7tafYD.jpg'),
(97239, 6900, 'Sangue Azul S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/12BMzDqLorHzFeMQHUtTMpKLxEK.jpg'),
(97240, 6900, 'Sangue Azul S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cYV4m70gbWxe2uTrqKOWxYyUGvS.jpg'),
(97241, 6900, 'Sangue Azul S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWnHtfee9Za6gtsl6mk1xDZLJgL.jpg'),
(97242, 6900, 'Sangue Azul S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1oxiYszpOxBkXGnrdfozWeN7qV0.jpg'),
(97243, 6900, 'Sangue Azul S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iY8UJGWnn0sGvATbuG2wEwXB5wG.jpg'),
(97244, 6900, 'Sangue Azul S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6S2BXOnU7iP1JQtcz6O7vw54CyA.jpg'),
(97245, 6900, 'Sangue Azul S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJgcrUXA2rjZT3fmxJ2HEDmqaDf.jpg'),
(97246, 6900, 'Sangue Azul S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shFcD334cszUhiq9phyZvXFo2y2.jpg'),
(97247, 6900, 'Sangue Azul S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ihFM5lGqkLybPSNCOzkEEMS8GV7.jpg'),
(97248, 6900, 'Sangue Azul S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/261034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bk4fodfnRpvQvm2hiPRLl7x5XFg.jpg'),
(97249, 6900, 'Sangue Azul S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/261035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3xTgtBFm7VTwyNZoQCShNuHnnwk.jpg'),
(97250, 6900, 'Sangue Azul S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/261036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6PaUu5Z7HorIHKThIwpfHxgtkB2.jpg'),
(97251, 6900, 'Sangue Azul S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/261037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n4WeW5HSATMDV0aJyUeylyqAY5E.jpg'),
(97252, 6900, 'Sangue Azul S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/261038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/azcixlVIKbOfWcaOa6JLPi6rSYh.jpg'),
(97253, 6900, 'Sangue Azul S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/261039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZJNBc2CqpXrMjphMO2nACzeFaH.jpg'),
(97254, 6900, 'Sangue Azul S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/261040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dl35rPxMsVo4UPsv7VHfptl6p8H.jpg'),
(97255, 6900, 'Sangue Azul S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/261041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oXlSn9VoJQZcZXw0qQyTsYIIXKt.jpg'),
(97256, 6900, 'Sangue Azul S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/261042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pZ5v2h5YHx6UzyVhZmfRnUeU5SW.jpg'),
(97257, 6900, 'Sangue Azul S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/261043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/maggNlvuzq6ReTYbUFeNYhV96bx.jpg'),
(97258, 6900, 'Sangue Azul S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/261044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/emJCe6mG8iVm4OZgyn78BsNkykI.jpg'),
(97259, 6900, 'Sangue Azul S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/261045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uIDQUYRQJNtmPno5PiTE6h9Yy70.jpg'),
(97260, 6901, 'Sangue Azul S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aEntxjHKU514fhaL5bcglFycNsK.jpg'),
(97261, 6901, 'Sangue Azul S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cG6Hep73SkWtFvzaehabwgsDoyK.jpg'),
(97262, 6901, 'Sangue Azul S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xrp8ITpUJWiYzHkBRG2oPeRUkrH.jpg'),
(97263, 6901, 'Sangue Azul S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8Y8AakdFJlpN2mctYLiq8I9Stm.jpg'),
(97264, 6901, 'Sangue Azul S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/prEA1nAH9DJtTZuRyMg7lvVf3og.jpg'),
(97265, 6901, 'Sangue Azul S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nYRTPWbQyKHu1msXO7SNAlVZLt.jpg'),
(97266, 6901, 'Sangue Azul S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQOy64kFbZl9cEEZiEiz9O4Yw4f.jpg'),
(97267, 6901, 'Sangue Azul S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/em4OPPTO0RJXaAAixTLoBWaHWdW.jpg'),
(97268, 6901, 'Sangue Azul S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBzMNEQjf0zZlYqQXhqAr1SG2io.jpg'),
(97269, 6901, 'Sangue Azul S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qd58zlzu8E90q9KseAvDLl8vFa6.jpg'),
(97270, 6901, 'Sangue Azul S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/261056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mcEcECNhGPiINabbF0Ux4wbWqdA.jpg'),
(97271, 6901, 'Sangue Azul S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/261057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4s3l9zFLJT6YmKE5rjeSF9Xxsi5.jpg'),
(97272, 6901, 'Sangue Azul S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/261058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2DDu4b9RFvcoSTGQupQ1z79v29.jpg'),
(97273, 6901, 'Sangue Azul S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/261059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u4GDFH7vjrfYUQ5ADs4OMD682JV.jpg'),
(97274, 6901, 'Sangue Azul S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/261060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o37aiATaJfDt6GZiHnzq0nUiTZb.jpg'),
(97275, 6901, 'Sangue Azul S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/261061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQzc7qY1H80xIGVFfFbvZLkVBI1.jpg'),
(97276, 6901, 'Sangue Azul S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/261062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7fAvGYIntqmcZGJ3dHhhLdUrwy.jpg'),
(97277, 6901, 'Sangue Azul S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/261063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vIkJhEI16iToKfAOFpAXoGudvK1.jpg'),
(97278, 6901, 'Sangue Azul S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/261064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9c65HXViVV5wD8LOYoB2Q76QnOs.jpg'),
(97279, 6902, 'Sangue Azul S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v32lmhl5HKO98XCemsYfJ3kNllv.jpg'),
(97280, 6902, 'Sangue Azul S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yT9mu7Jq6xs2gAW27SpzdInsuF6.jpg'),
(97281, 6902, 'Sangue Azul S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4DcfXjcpGbN5VDXCPcFbCz4dHHc.jpg'),
(97282, 6902, 'Sangue Azul S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4a4mdDszzNIIJMi9hcLxSpHGTA7.jpg'),
(97283, 6902, 'Sangue Azul S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/imtmhgdd0hBua2LW9KTCnvgQnHq.jpg'),
(97284, 6902, 'Sangue Azul S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kPiFkklyGMND6G1x6BvU5MBWX73.jpg'),
(97285, 6902, 'Sangue Azul S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7sLizgcbfAqKjVvym0jaZDOIkkN.jpg'),
(97286, 6902, 'Sangue Azul S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ibOwZWc5dpcviSucAFisLMzzLWI.jpg'),
(97287, 6902, 'Sangue Azul S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ax4ZF3S15kmUHSMaMLyxUfsgeB7.jpg'),
(97288, 6902, 'Sangue Azul S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261074.mp4', 'http://image.tmdb.org/t/p/w1280/wXmxVRTF1D4OvVqL4NPVJG4EFeo.jpg'),
(97289, 6902, 'Sangue Azul S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/261075.mp4', 'http://image.tmdb.org/t/p/w1280/luZ0xOMsKKoonhyspegesYanyuw.jpg'),
(97290, 6902, 'Sangue Azul S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/261076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97291, 6902, 'Sangue Azul S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/261077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97292, 6902, 'Sangue Azul S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/261078.mp4', 'http://image.tmdb.org/t/p/w1280/ork75WFXLPZrfTwnKbpzWXIKfLg.jpg'),
(97293, 6902, 'Sangue Azul S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/261079.mp4', 'http://image.tmdb.org/t/p/w1280/yK2JeJD4JdvX5QaDdIBFLVgRLlp.jpg'),
(97294, 6902, 'Sangue Azul S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/261080.mp4', 'http://image.tmdb.org/t/p/w1280/cYAH9H4zz2ofdB3rqKOZjxXfjj4.jpg'),
(97295, 6903, 'Sangue Azul S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261081.mp4', 'http://image.tmdb.org/t/p/w1280/kJZCqVoUx41OZqnBkWZ3LUsMYSx.jpg'),
(97296, 6903, 'Sangue Azul S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261082.mp4', 'http://image.tmdb.org/t/p/w1280/w1XyrzlwKLqzUgxApPY4amw8MVx.jpg'),
(97297, 6903, 'Sangue Azul S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261083.mp4', 'http://image.tmdb.org/t/p/w1280/jclOkjpg4FiYWMG97siQUnZCoLr.jpg'),
(97298, 6903, 'Sangue Azul S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261084.mp4', 'http://image.tmdb.org/t/p/w1280/gQyyUd2yQi3IrKuCVSQyXMZR9y0.jpg'),
(97299, 6903, 'Sangue Azul S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261085.mp4', 'http://image.tmdb.org/t/p/w1280/i1ZAMpySe44b1mkIfCq9EdyZQrs.jpg'),
(97300, 6903, 'Sangue Azul S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261086.mp4', 'http://image.tmdb.org/t/p/w1280/xypINU33xud5e1aXNs0BzsIOjGO.jpg'),
(97301, 6903, 'Sangue Azul S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261087.mp4', 'http://image.tmdb.org/t/p/w1280/qOFvUJlnZlbBEldcsMjKAYGpgL.jpg'),
(97302, 6903, 'Sangue Azul S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261088.mp4', 'http://image.tmdb.org/t/p/w1280/oYys4rMc50aNLvIpj0PjjPmcKig.jpg'),
(97303, 6903, 'Sangue Azul S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97304, 6903, 'Sangue Azul S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97305, 6903, 'Sangue Azul S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/261091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97306, 6903, 'Sangue Azul S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/261092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97307, 6903, 'Sangue Azul S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/261093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97308, 6903, 'Sangue Azul S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/261094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97309, 6903, 'Sangue Azul S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/261095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97310, 6903, 'Sangue Azul S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/261096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97311, 6903, 'Sangue Azul S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/261097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97312, 6903, 'Sangue Azul S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/261098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97313, 6903, 'Sangue Azul S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/261099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97314, 6903, 'Sangue Azul S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/261100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97315, 6904, 'Sangue Azul S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97316, 6904, 'Sangue Azul S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/297400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97317, 6904, 'Sangue Azul S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/297401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97318, 6904, 'Sangue Azul S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/297402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97319, 6904, 'Sangue Azul S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/297403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97320, 6904, 'Sangue Azul S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/297404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97321, 6904, 'Sangue Azul S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/297405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97322, 6904, 'Sangue Azul S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/297406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97323, 6904, 'Sangue Azul S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/312241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97324, 6904, 'Sangue Azul S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/312242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97325, 6904, 'Sangue Azul S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/320703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97326, 6904, 'Sangue Azul S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/320704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97327, 6904, 'Sangue Azul S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/332463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97328, 6904, 'Sangue Azul S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/332464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97329, 6904, 'Sangue Azul S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/337254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97330, 6904, 'Sangue Azul S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/343314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97331, 6904, 'Sangue Azul S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/354348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97332, 6904, 'Sangue Azul S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/354349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97333, 6904, 'Sangue Azul S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/362946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97334, 6904, 'Sangue Azul S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/379533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97335, 6904, 'Sangue Azul S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/379534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97336, 6905, 'Sangue Azul S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/441114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97337, 6905, 'Sangue Azul S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/441115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97338, 6905, 'Sangue Azul S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/441116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97339, 6905, 'Sangue Azul S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/450312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97340, 6905, 'Sangue Azul S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/454555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97341, 6905, 'Sangue Azul S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/459272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97342, 6905, 'Sangue Azul S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/466510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97343, 6905, 'Sangue Azul S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/472230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97344, 6905, 'Sangue Azul S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/485177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97345, 6905, 'Sangue Azul S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/488393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97346, 6905, 'Sangue Azul S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/737568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97347, 6905, 'Sangue Azul S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/750573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97348, 6905, 'Sangue Azul S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/758230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97349, 6905, 'Sangue Azul S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/763620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97350, 6905, 'Sangue Azul S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/772018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97351, 6905, 'Sangue Azul S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/784169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97352, 6905, 'Sangue Azul S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/793444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97353, 6905, 'Sangue Azul S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/797770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4HStHFznPtBef4hPU2y6JIJZHt4.jpg'),
(97354, 6906, 'South Side S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ac1qU3cIUld9rh6hrgtQ1BrtR20.jpg'),
(97355, 6906, 'South Side S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2R95WID0HNea4NYd6IZavCRknm.jpg'),
(97356, 6906, 'South Side S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hXjBMyWhGT9bj8QWtdMHZJ60YT.jpg'),
(97357, 6906, 'South Side S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1N001DStT9xSPvA0iuRE9qRuyLu.jpg'),
(97358, 6906, 'South Side S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4sSDUP0qa2pBffrpKFbFsuwZ21h.jpg'),
(97359, 6906, 'South Side S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A69nUIUQPiuYyM2na1JBsAeaYrN.jpg'),
(97360, 6906, 'South Side S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1MfTgYLC48ZYMRqHe3U7AO4Fk6r.jpg'),
(97361, 6906, 'South Side S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AvBPK3k2dKR96rYWVx8hWzh877e.jpg'),
(97362, 6906, 'South Side S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yVWgeZyUUw2uKh14w9aqMKlpHmK.jpg'),
(97363, 6906, 'South Side S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xKZ2r4FHuU1g81L2faML4Uo8KDG.jpg'),
(97364, 6907, 'South Side S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4O2zj44iYA8LE2CJnp8OXWRj8qw.jpg'),
(97365, 6907, 'South Side S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kPJhnusgvuBZ6Nz4HyLfHWWwDmb.jpg'),
(97366, 6907, 'South Side S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/urDc5uChzzIIoJCWoAhOazoWxPe.jpg'),
(97367, 6907, 'South Side S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rl5ZQS7NYMQozrkH7KcJtsykqh.jpg'),
(97368, 6907, 'South Side S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1di6x3T8xP2JOBLk1TeOtnFlghp.jpg'),
(97369, 6907, 'South Side S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tcCkQP7gn6nK6cQ29MjbsIZT3DP.jpg'),
(97370, 6907, 'South Side S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zZTIr6iSbOmpE3js0nBSQKyUgya.jpg'),
(97371, 6907, 'South Side S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9wf2jxUOiOYJJ7uz6Mg0yowGWWw.jpg'),
(97372, 6907, 'South Side S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/202085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nfTn2wt5f3OMdUnFyS8CZdmcCwk.jpg'),
(97373, 6907, 'South Side S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/202086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g2D6WVaKVdM8sztQLSXyFl9TChp.jpg'),
(97374, 6908, 'South Side S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/202087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fw2MqNhzKOJRuSH7hAlo5YSNDNu.jpg'),
(97375, 6908, 'South Side S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/202088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2rYvueikQGumVT8EX9BpDwjGiG5.jpg'),
(97376, 6908, 'South Side S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/202089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sq1ZVwb5kIbvNknW09UkbH2Al8b.jpg'),
(97377, 6908, 'South Side S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/202090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pTxq0Js93UY170JDOudqWu7T2Bo.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(97378, 6908, 'South Side S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/202091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3nUFddTEYfCNN5mf2oRI2rtZ4wS.jpg'),
(97379, 6908, 'South Side S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/202092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sjut25TZpkxT67Jx0yZqiG49g2G.jpg'),
(97380, 6908, 'South Side S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/202093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uv05bj2nhwlbU02Hst9qi0C5sW3.jpg'),
(97381, 6908, 'South Side S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/202094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u9JXF3AeSwHvKIomQ7P6ncqKOnT.jpg'),
(97382, 6909, 'Histórias Quase Verdadeiras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sr0yYbldpFPWrjKWQz6bhbUv8Z.jpg'),
(97383, 6909, 'Histórias Quase Verdadeiras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sr0yYbldpFPWrjKWQz6bhbUv8Z.jpg'),
(97384, 6909, 'Histórias Quase Verdadeiras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sr0yYbldpFPWrjKWQz6bhbUv8Z.jpg'),
(97385, 6909, 'Histórias Quase Verdadeiras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sr0yYbldpFPWrjKWQz6bhbUv8Z.jpg'),
(97386, 6910, 'A Volta ao Mundo em 80 Dias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8dN68dI23TGBA9xb6MZSQ4QQenH.jpg'),
(97387, 6910, 'A Volta ao Mundo em 80 Dias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sWZ0xcXTDtKa65kXZEOB6neYpgk.jpg'),
(97388, 6910, 'A Volta ao Mundo em 80 Dias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sDpccmuLJdTeUKPm3WalCpQW11o.jpg'),
(97389, 6910, 'A Volta ao Mundo em 80 Dias S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2FMKr4dhxe0yhnEwQwYbtbGzaUY.jpg'),
(97390, 6910, 'A Volta ao Mundo em 80 Dias S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3nkQ3Ovhc2jwbdrSQJfQ438SFmf.jpg'),
(97391, 6910, 'A Volta ao Mundo em 80 Dias S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aIkp7YbpIjDg5syErULzDjfgSiL.jpg'),
(97392, 6910, 'A Volta ao Mundo em 80 Dias S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmJXD0VVG3xQOBdyzJCWwOu0tQo.jpg'),
(97393, 6910, 'A Volta ao Mundo em 80 Dias S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/keM5jKv3Z1UkM2s0HCnQILzhVin.jpg'),
(97394, 6911, 'Alasca ao Extremo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f5SzMFV19xmuRF0aSiy4u7xw02s.jpg'),
(97395, 6911, 'Alasca ao Extremo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fQvuG7SedCpTRxWQwV2VPtmPQth.jpg'),
(97396, 6911, 'Alasca ao Extremo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jXIsIjSHUIcLNaJLyBzcxxLKMlB.jpg'),
(97397, 6911, 'Alasca ao Extremo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a8cmgwjRGBjlPCAmjGOlG6w7TKg.jpg'),
(97398, 6911, 'Alasca ao Extremo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tV3Vr3kg1zomaYUu5r339zkm5ec.jpg'),
(97399, 6911, 'Alasca ao Extremo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sejC1Q7IY8LpZYUTtKQrmUXVxOg.jpg'),
(97400, 6911, 'Alasca ao Extremo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yquzNNPEbFbBlLfeHt39LJnL1tG.jpg'),
(97401, 6911, 'Alasca ao Extremo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1PN3h8xFiHO4itiAOCg3jkeBC4C.jpg'),
(97402, 6912, 'Alasca ao Extremo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mNTbvfV3JVJTc9dPLqtWbglyIrU.jpg'),
(97403, 6912, 'Alasca ao Extremo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k6Hy4gpu8JeHxZ3l7pvVzdi0D05.jpg'),
(97404, 6912, 'Alasca ao Extremo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jtpa9mIAhLVUhSkid1TOtczYUiI.jpg'),
(97405, 6912, 'Alasca ao Extremo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9TUjZ95edwS35V2pIo5TyW80JyQ.jpg'),
(97406, 6912, 'Alasca ao Extremo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jIFqI77b7kjt9UrMWUihkNx14Bl.jpg'),
(97407, 6912, 'Alasca ao Extremo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rtuP8ussspDiv762mw2rv9YMGe.jpg'),
(97408, 6912, 'Alasca ao Extremo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1dhWULwaoskX7MjuR8tdb4gEot1.jpg'),
(97409, 6912, 'Alasca ao Extremo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dhHQL7IJAVb0ZSycPd8jzKiN8mX.jpg'),
(97410, 6913, 'Alasca ao Extremo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tURVe6hP3V2M5eSSY9ZQR0bgXtg.jpg'),
(97411, 6913, 'Alasca ao Extremo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJlEYvYqg604LwiWHIUdohI2v2x.jpg'),
(97412, 6913, 'Alasca ao Extremo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jHKXnuqyt4gZxL3nLA8jDXi22fj.jpg'),
(97413, 6913, 'Alasca ao Extremo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/96xANsohZAfi5IWqMAE2dxPnxhM.jpg'),
(97414, 6913, 'Alasca ao Extremo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Dp0ekObsvUGpEewcF18KS9Uwm9.jpg'),
(97415, 6913, 'Alasca ao Extremo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f5SzMFV19xmuRF0aSiy4u7xw02s.jpg'),
(97416, 6913, 'Alasca ao Extremo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f5SzMFV19xmuRF0aSiy4u7xw02s.jpg'),
(97417, 6913, 'Alasca ao Extremo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f5SzMFV19xmuRF0aSiy4u7xw02s.jpg'),
(97418, 6914, 'Alasca ao Extremo S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f5SzMFV19xmuRF0aSiy4u7xw02s.jpg'),
(97419, 6914, 'Alasca ao Extremo S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f5SzMFV19xmuRF0aSiy4u7xw02s.jpg'),
(97420, 6914, 'Alasca ao Extremo S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f5SzMFV19xmuRF0aSiy4u7xw02s.jpg'),
(97421, 6914, 'Alasca ao Extremo S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f5SzMFV19xmuRF0aSiy4u7xw02s.jpg'),
(97422, 6914, 'Alasca ao Extremo S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f5SzMFV19xmuRF0aSiy4u7xw02s.jpg'),
(97423, 6914, 'Alasca ao Extremo S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f5SzMFV19xmuRF0aSiy4u7xw02s.jpg'),
(97424, 6914, 'Alasca ao Extremo S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f5SzMFV19xmuRF0aSiy4u7xw02s.jpg'),
(97425, 6914, 'Alasca ao Extremo S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f5SzMFV19xmuRF0aSiy4u7xw02s.jpg'),
(97426, 6915, 'As Panteras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97427, 6915, 'As Panteras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97428, 6915, 'As Panteras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97429, 6915, 'As Panteras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97430, 6915, 'As Panteras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97431, 6915, 'As Panteras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97432, 6915, 'As Panteras S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97433, 6915, 'As Panteras S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97434, 6915, 'As Panteras S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97435, 6915, 'As Panteras S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97436, 6915, 'As Panteras S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97437, 6915, 'As Panteras S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97438, 6915, 'As Panteras S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97439, 6915, 'As Panteras S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/201807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97440, 6915, 'As Panteras S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/201808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97441, 6915, 'As Panteras S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/201809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97442, 6915, 'As Panteras S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/201810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97443, 6915, 'As Panteras S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/201811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97444, 6915, 'As Panteras S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/201812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97445, 6915, 'As Panteras S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/201813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97446, 6915, 'As Panteras S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/201814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97447, 6915, 'As Panteras S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/201815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97448, 6915, 'As Panteras S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/201816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97449, 6916, 'As Panteras S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97450, 6916, 'As Panteras S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97451, 6916, 'As Panteras S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97452, 6916, 'As Panteras S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97453, 6916, 'As Panteras S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97454, 6916, 'As Panteras S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97455, 6916, 'As Panteras S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97456, 6916, 'As Panteras S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97457, 6916, 'As Panteras S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97458, 6916, 'As Panteras S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97459, 6916, 'As Panteras S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97460, 6916, 'As Panteras S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97461, 6916, 'As Panteras S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97462, 6916, 'As Panteras S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/201830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97463, 6916, 'As Panteras S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/201831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97464, 6916, 'As Panteras S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/201832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97465, 6916, 'As Panteras S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/201833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97466, 6916, 'As Panteras S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/201834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97467, 6916, 'As Panteras S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/201835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97468, 6916, 'As Panteras S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/201836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97469, 6916, 'As Panteras S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/201837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97470, 6916, 'As Panteras S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/201838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97471, 6916, 'As Panteras S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/201839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97472, 6916, 'As Panteras S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/201840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97473, 6916, 'As Panteras S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/201841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97474, 6916, 'As Panteras S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/201842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97475, 6917, 'As Panteras S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97476, 6917, 'As Panteras S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97477, 6917, 'As Panteras S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97478, 6917, 'As Panteras S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97479, 6917, 'As Panteras S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97480, 6917, 'As Panteras S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97481, 6917, 'As Panteras S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97482, 6917, 'As Panteras S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97483, 6917, 'As Panteras S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97484, 6917, 'As Panteras S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97485, 6917, 'As Panteras S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97486, 6917, 'As Panteras S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97487, 6917, 'As Panteras S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97488, 6917, 'As Panteras S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/201856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97489, 6917, 'As Panteras S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/201857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97490, 6917, 'As Panteras S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/201858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97491, 6917, 'As Panteras S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/201859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97492, 6917, 'As Panteras S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/201860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97493, 6917, 'As Panteras S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/201861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97494, 6917, 'As Panteras S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/201862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97495, 6917, 'As Panteras S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/201863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97496, 6917, 'As Panteras S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/201864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97497, 6917, 'As Panteras S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/201865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97498, 6917, 'As Panteras S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/201866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97499, 6918, 'As Panteras S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97500, 6918, 'As Panteras S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97501, 6918, 'As Panteras S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97502, 6918, 'As Panteras S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97503, 6918, 'As Panteras S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97504, 6918, 'As Panteras S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97505, 6918, 'As Panteras S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97506, 6918, 'As Panteras S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97507, 6918, 'As Panteras S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97508, 6918, 'As Panteras S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97509, 6918, 'As Panteras S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97510, 6918, 'As Panteras S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/201878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97511, 6918, 'As Panteras S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/201879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97512, 6918, 'As Panteras S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/201880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97513, 6918, 'As Panteras S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/201881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97514, 6918, 'As Panteras S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/201882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97515, 6918, 'As Panteras S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/201883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97516, 6918, 'As Panteras S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/201884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97517, 6918, 'As Panteras S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/201885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97518, 6918, 'As Panteras S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/201886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97519, 6918, 'As Panteras S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/201887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97520, 6918, 'As Panteras S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/201888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97521, 6918, 'As Panteras S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/201889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97522, 6918, 'As Panteras S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/201890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97523, 6918, 'As Panteras S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/201891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97524, 6918, 'As Panteras S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/201892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UiQ46T777kvKJCx9F9DAI3HajP.jpg'),
(97525, 6919, 'Brasil Raiz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c9F6G7KijlalWM5ChQSIZqcIxi3.jpg'),
(97526, 6919, 'Brasil Raiz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yzve7YALKxzOgG9WpU5ZJNK0Ons.jpg'),
(97527, 6919, 'Brasil Raiz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t4PN2YRnJQvnbJGu6e9V3hu3NR9.jpg'),
(97528, 6919, 'Brasil Raiz S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tS1tW4SBpVLxN96OxLOV3q5q9oz.jpg'),
(97529, 6919, 'Brasil Raiz S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p7UV4uEszZM6R4uLXFjN43JewAs.jpg'),
(97530, 6920, 'Caçadores S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qYsbiQ9ZrzZbvyCiMWWSrT9c7aT.jpg'),
(97531, 6920, 'Caçadores S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iyYZnkIZH3OjvQEizD5iHnRdnt0.jpg'),
(97532, 6920, 'Caçadores S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iO6sueXsRzyy8qB0m8mywyRedUZ.jpg'),
(97533, 6920, 'Caçadores S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y5qSdTSwHYt72GfH3v8eT5uYzBY.jpg'),
(97534, 6920, 'Caçadores S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/35SwOvvKElHJcZBUdPvcqAWOLfV.jpg'),
(97535, 6920, 'Caçadores S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fR0e3xobs0v1fA6GoKaUBc32R1Q.jpg'),
(97536, 6920, 'Caçadores S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QeswJIhPibnTtONkcENiaxsukR.jpg'),
(97537, 6920, 'Caçadores S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dhgelRUQfB45tDTJC1TP8FI02EC.jpg'),
(97538, 6920, 'Caçadores S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/201778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7fGf5frLk04UAqekQhuhPAMSBpU.jpg'),
(97539, 6920, 'Caçadores S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/201779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Obm1GKIqrBCb2L3YFeMOLysdeh.jpg'),
(97540, 6920, 'Caçadores S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/201780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rbtgorwuTBoAu0Qm5IvZoQl75WU.jpg'),
(97541, 6921, 'Caçadores S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/201781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qn7CPBCA7RDzaWE3zvpZz3lCrTR.jpg'),
(97542, 6921, 'Caçadores S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/201782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2IHahU5nRwn4MleSvz3wiHc0FsF.jpg'),
(97543, 6921, 'Caçadores S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/201783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ZZTEQH9ThuRHnmJdVwAsQS4LhL.jpg'),
(97544, 6921, 'Caçadores S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/201784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/29aNKabqmMrpz305bM49sM2NAdX.jpg'),
(97545, 6921, 'Caçadores S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/201785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1erk3UGiwn9ZzcNBCeNbWypMXle.jpg'),
(97546, 6921, 'Caçadores S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/201786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xaVOcSNniOiwlRPRpmqMHh06V8A.jpg'),
(97547, 6921, 'Caçadores S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/201787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zpwyXpjRsBCZN3MAyshazJmaWIj.jpg'),
(97548, 6921, 'Caçadores S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/201788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eBt2UBr9qB8my2er8sumYGdp39H.jpg'),
(97549, 6922, 'extremistas.br S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ZBRxcspawIbwk5wlJgw2pZQ7OD.jpg'),
(97550, 6922, 'extremistas.br S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ri8lIlM07O8eNPzscm2Vxrlh01Z.jpg'),
(97551, 6922, 'extremistas.br S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/82i1ZPhEf4cjiZxacxQK5ytfaj.jpg'),
(97552, 6922, 'extremistas.br S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vNjH58A8MdFfLiUKXyVSXi7WlIq.jpg'),
(97553, 6922, 'extremistas.br S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9t0W96RuXbYMjVWFSMYkPNGad22.jpg'),
(97554, 6922, 'extremistas.br S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qF4jVApOIj8OcxrGHwgcUwv2GnI.jpg'),
(97555, 6922, 'extremistas.br S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v5qzZNkZXbuSCtEOZ5xrHaNeoO7.jpg'),
(97556, 6922, 'extremistas.br S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v5qzZNkZXbuSCtEOZ5xrHaNeoO7.jpg'),
(97557, 6923, 'Gary E Seus Demonios S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9N3OKsn5fNvyEiRb9aGHsHkYEal.jpg'),
(97558, 6923, 'Gary E Seus Demonios S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nhrD6Qqxy6yzYvuDXqbo3qIMaig.jpg'),
(97559, 6923, 'Gary E Seus Demonios S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qJtg9W2a2PlWLzzMwubMMLV8DCz.jpg'),
(97560, 6923, 'Gary E Seus Demonios S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jWsG5zJowSRSbyWwzhG4aUhVtI6.jpg'),
(97561, 6923, 'Gary E Seus Demonios S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xOdZ36x5yYaVlPPxcXmSi3Vu0z9.jpg'),
(97562, 6923, 'Gary E Seus Demonios S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/388itpEyZHiNDnhNcxYB4HRnfAT.jpg'),
(97563, 6923, 'Gary E Seus Demonios S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mrpmlMdg62l6lQrD1eb66aezcNS.jpg'),
(97564, 6923, 'Gary E Seus Demonios S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8zfoPlCgY7AvWxUvCZi8OqKYCCk.jpg'),
(97565, 6924, 'Gary E Seus Demonios S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN6EU9KJ2K8fwFASuwDPWrAXkTn.jpg'),
(97566, 6924, 'Gary E Seus Demonios S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN6EU9KJ2K8fwFASuwDPWrAXkTn.jpg'),
(97567, 6924, 'Gary E Seus Demonios S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN6EU9KJ2K8fwFASuwDPWrAXkTn.jpg'),
(97568, 6924, 'Gary E Seus Demonios S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN6EU9KJ2K8fwFASuwDPWrAXkTn.jpg'),
(97569, 6924, 'Gary E Seus Demonios S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN6EU9KJ2K8fwFASuwDPWrAXkTn.jpg'),
(97570, 6925, 'Gudetama: As Aventuras de um Ovinho Preguiçoso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3wYnwOM89t4PxXqdqSAatIg5gcZ.jpg'),
(97571, 6925, 'Gudetama: As Aventuras de um Ovinho Preguiçoso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f1urqgVFf2T0bJ7QnHRAJG6M0TQ.jpg'),
(97572, 6925, 'Gudetama: As Aventuras de um Ovinho Preguiçoso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sTMbalBZBqjrd6QWG0FO0jdLcqG.jpg'),
(97573, 6925, 'Gudetama: As Aventuras de um Ovinho Preguiçoso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/onDmM1d05crbAjqiAYEyyY9FAry.jpg'),
(97574, 6925, 'Gudetama: As Aventuras de um Ovinho Preguiçoso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sh6Eub79QOAjdR5rVVTpHFZC3ud.jpg'),
(97575, 6925, 'Gudetama: As Aventuras de um Ovinho Preguiçoso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yfO52Hev8RxRkspSTkpDwUNpjNc.jpg'),
(97576, 6925, 'Gudetama: As Aventuras de um Ovinho Preguiçoso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZd7WMkT2e8Tm57xtUvqoE5JRk6.jpg'),
(97577, 6925, 'Gudetama: As Aventuras de um Ovinho Preguiçoso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iXquQGhRrXCwDnK1x7PXeYtTMmp.jpg'),
(97578, 6925, 'Gudetama: As Aventuras de um Ovinho Preguiçoso S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qc6MMYQqFObfmeHebkzS7IIWQe8.jpg'),
(97579, 6925, 'Gudetama: As Aventuras de um Ovinho Preguiçoso S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5op0MXXY6nidRXyRNnjmtYPGaXt.jpg'),
(97580, 6926, 'Jamie Vs Britney: O Julgamento da Família Spears S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/krHczXgjn2p1yZpqIqyHq174jmf.jpg'),
(97581, 6926, 'Jamie Vs Britney: O Julgamento da Família Spears S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sch3MSNt3B0V72yP7znww0gbaRS.jpg'),
(97582, 6927, 'Koala Man S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yMG9hHbrG5v8oSXTc8mazuLj8PF.jpg'),
(97583, 6927, 'Koala Man S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9XcOqunO8zJZZUjAxtU2Ihks9nu.jpg'),
(97584, 6927, 'Koala Man S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cd7R7LJndcdwCJIkFlvJ6jiACsT.jpg'),
(97585, 6927, 'Koala Man S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bjhs1hb806TYX4o9QBbx276g7cP.jpg'),
(97586, 6927, 'Koala Man S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aXUmcarc1ED5YdV94mXW0ExI0DG.jpg'),
(97587, 6927, 'Koala Man S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dayNmYA52aZi2821roUUI5YZyik.jpg'),
(97588, 6927, 'Koala Man S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZtOG3OMXfNpU56dRk9GPdjYHFs.jpg'),
(97589, 6927, 'Koala Man S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q88Y6O77i4hiXfm9Be4At72ur4P.jpg'),
(97590, 6928, 'Makanai: Cozinhando para A Casa Maiko S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pqQgoasFCBVPQqtbykvoeK71XOE.jpg'),
(97591, 6928, 'Makanai: Cozinhando para A Casa Maiko S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7dAZVG4dgx8QiFeNR6ITct5C3Tn.jpg'),
(97592, 6928, 'Makanai: Cozinhando para A Casa Maiko S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xD1niLOxoXUSAZaUr1KpCk47ZXg.jpg'),
(97593, 6928, 'Makanai: Cozinhando para A Casa Maiko S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7fLlklbJE4DVFcDviDtfumvyr5v.jpg'),
(97594, 6928, 'Makanai: Cozinhando para A Casa Maiko S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xPvnDY8F99rBg7dpHdKV6Fd5sD3.jpg'),
(97595, 6928, 'Makanai: Cozinhando para A Casa Maiko S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mxM1Q3VAMhNF5MEito5ZxeRfBsQ.jpg'),
(97596, 6928, 'Makanai: Cozinhando para A Casa Maiko S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Ozy4cNu2g3E9iIMKM023bXi0jH.jpg'),
(97597, 6928, 'Makanai: Cozinhando para A Casa Maiko S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yi4au4r9rH6XFZHHVpJrNpp8owE.jpg'),
(97598, 6928, 'Makanai: Cozinhando para A Casa Maiko S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpc0Kh9isa528yiIRlbbrRlYkbd.jpg'),
(97599, 6929, 'Perdido pela Fama S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQLZtX4EyJEPXlPL9wmmAp5HSPC.jpg'),
(97600, 6929, 'Perdido pela Fama S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/seVrPOEAa8ZrSTtMR4ajWlQx8s9.jpg'),
(97601, 6929, 'Perdido pela Fama S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBzzArR12vvprSsyMML6tgKgPDP.jpg'),
(97602, 6929, 'Perdido pela Fama S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fXOYBx8MEAPUJAEK9ZStX6OssO8.jpg'),
(97603, 6929, 'Perdido pela Fama S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kQ2VFpKdiZ9ogADgPLUqtdHjmEa.jpg'),
(97604, 6929, 'Perdido pela Fama S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gq7GiDr1XAwyOQWgWOXfIplWlZ6.jpg'),
(97605, 6929, 'Perdido pela Fama S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iO43OCGKoovHfR28XAfP6Hel3uL.jpg'),
(97606, 6929, 'Perdido pela Fama S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/imBJRMp3mkJPoRnuvPWNhINEf2I.jpg'),
(97607, 6929, 'Perdido pela Fama S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/99Lba67QtOarIXI1NdbU9Gc45BY.jpg'),
(97608, 6929, 'Perdido pela Fama S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q24DD0EPYHjMUnf7QLVEOSxS0VI.jpg'),
(97609, 6930, 'Perseguindo Ondas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jiWaFzRiSEQi4hpfnqEOxdBgqh2.jpg'),
(97610, 6930, 'Perseguindo Ondas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDSoj1yWfla7cUCMQq31CgeFiS9.jpg'),
(97611, 6930, 'Perseguindo Ondas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8cOyTUf0SVsFlVIANfk5qeWDsZL.jpg'),
(97612, 6930, 'Perseguindo Ondas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Rws839vH0fg6yF06Tk7GSfJHVA.jpg'),
(97613, 6930, 'Perseguindo Ondas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1aLlpNHrNk3QCQZDlZmXhu9GaPJ.jpg'),
(97614, 6930, 'Perseguindo Ondas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pjjG7FqvlMjXYPbDxmrnHP7vMqE.jpg'),
(97615, 6930, 'Perseguindo Ondas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v42h2fMJ6KwtdvnftoCtPw1iwRG.jpg'),
(97616, 6930, 'Perseguindo Ondas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5kGgsvx902TPhcdN4BAgzWwQ85l.jpg'),
(97617, 6931, 'Seleção Argentina: A Série - Rumo a Catar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yrvtoeWRpXFk9fIoeA9DhorSlqj.jpg'),
(97618, 6931, 'Seleção Argentina: A Série - Rumo a Catar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gWqVRf3sEgJ6PCDYhqduulVxxKE.jpg'),
(97619, 6931, 'Seleção Argentina: A Série - Rumo a Catar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nyQbnoUHpbvYXVOEIBSya0x0AdS.jpg'),
(97620, 6931, 'Seleção Argentina: A Série - Rumo a Catar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hENgo7Bs0SAUmvK8kJEVxno8T7A.jpg'),
(97621, 6931, 'Seleção Argentina: A Série - Rumo a Catar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sWmR5vAaU5eCLUbQ8hcIL3msUu9.jpg'),
(97622, 6931, 'Seleção Argentina: A Série - Rumo a Catar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vdnXaTrSdBoFToAnXNBpLlT759V.jpg'),
(97623, 6932, 'Sou Corinthians S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/31IpXgBm166YCC9sVuoCXFiaWmA.jpg'),
(97624, 6932, 'Sou Corinthians S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/31IpXgBm166YCC9sVuoCXFiaWmA.jpg'),
(97625, 6932, 'Sou Corinthians S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/31IpXgBm166YCC9sVuoCXFiaWmA.jpg'),
(97626, 6932, 'Sou Corinthians S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/31IpXgBm166YCC9sVuoCXFiaWmA.jpg'),
(97627, 6933, 'O Bonde S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/of5ns2RAOy5S1k5qj9MOPoIHgTe.jpg'),
(97628, 6933, 'O Bonde S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/chV9Rb5WzmtrqIjucE3e86y369G.jpg'),
(97629, 6933, 'O Bonde S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m4UjXtw1me8MTgsxGQId8KeFhMG.jpg'),
(97630, 6933, 'O Bonde S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cETiblDO5tCGLewlORgiunwquYF.jpg'),
(97631, 6933, 'O Bonde S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wzCXXtwZ1xDVEdLgmVNjPy3fn3p.jpg'),
(97632, 6933, 'O Bonde S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eCyfPFqAUdfbr4DX9z61buX3vyr.jpg'),
(97633, 6933, 'O Bonde S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9jcVadBFivzXv24LjxYXaWqPJ8V.jpg'),
(97634, 6933, 'O Bonde S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A9c7TmaubRlIqInJjgl6FnkjB9y.jpg'),
(97635, 6933, 'O Bonde S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a2OsZM08LULnblEAIQPafLtTfEc.jpg'),
(97636, 6933, 'O Bonde S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t5JNPV8eeoyUJRjedcnd8mvqINm.jpg'),
(97637, 6933, 'O Bonde S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h7YwcT54jAKRra3vebRjAszfr7R.jpg'),
(97638, 6933, 'O Bonde S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oi6GIEUYErb5IK6YalwRdXQMGKd.jpg'),
(97639, 6933, 'O Bonde S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t5HOJOK2GWmr8bav3w2GQuGSYjH.jpg'),
(97640, 6933, 'O Bonde S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/207070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zUeItzPnrJwlXBvkje10qTJeZ0b.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(97641, 6933, 'O Bonde S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/207071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zS3gGkyks7JyR864nVy1AXdFibq.jpg'),
(97642, 6933, 'O Bonde S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/207072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/60QWZBgYXgPiirOvuXIo07ROey.jpg'),
(97643, 6934, 'Um Milagre S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qT8wTUrNVLPMVk1gklvKhyzXLIN.jpg'),
(97644, 6934, 'Um Milagre S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e0LV8Bwwf3gUdFvhG5v2ceI71dj.jpg'),
(97645, 6934, 'Um Milagre S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/leCW3TraVIGZAX6pxajRClzcrfy.jpg'),
(97646, 6934, 'Um Milagre S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ofsHtNOVdLsx5TY4uLvtntVOfn6.jpg'),
(97647, 6934, 'Um Milagre S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ggP8Q2KDnmwpbia4GB8WeA7KQwU.jpg'),
(97648, 6934, 'Um Milagre S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oUlorpIQKhIbvw3kmH6yCXiORMJ.jpg'),
(97649, 6934, 'Um Milagre S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hVZNVHbZWcjg1RW3qwKGlflC4fL.jpg'),
(97650, 6934, 'Um Milagre S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zSavkH1PQCfR8U07QDsYNp41dPE.jpg'),
(97651, 6934, 'Um Milagre S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/LJJnp7bIjCKUSKqWEzDjcgiFzl.jpg'),
(97652, 6934, 'Um Milagre S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wawJapb9JPPR36EojUXYKWZFeGn.jpg'),
(97653, 6934, 'Um Milagre S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vY4shTuaQbYTTXOGAglPZuLUPoh.jpg'),
(97654, 6934, 'Um Milagre S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7GMM9ZX2iFp980V2ApTTUodMtse.jpg'),
(97655, 6934, 'Um Milagre S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/59dMmrpdSJWLlnCz2e5U842pVvr.jpg'),
(97656, 6934, 'Um Milagre S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/205618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pP7ktYbXYAKAogcdoT4Jf3WDkwe.jpg'),
(97657, 6934, 'Um Milagre S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/205619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mS3SEwoaArSrtOl8H4gyHSlL61y.jpg'),
(97658, 6934, 'Um Milagre S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/205620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mVMjbXCUFcF0r2pbBBguVwWRCgT.jpg'),
(97659, 6934, 'Um Milagre S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/205621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3vryddpIYoNnA4KTxjc3ELMgamC.jpg'),
(97660, 6934, 'Um Milagre S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/205622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lBDsXuj4WxuliwjhlFnzuYodiv.jpg'),
(97661, 6934, 'Um Milagre S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/205623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nN8ilDiAcmgLf259BV00qLFFW6j.jpg'),
(97662, 6934, 'Um Milagre S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/205624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mQitsFdgKg65Fy6AZpYaQ91pFTO.jpg'),
(97663, 6934, 'Um Milagre S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/205625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8NHSspoApqcllhgAloNBNGhqBNJ.jpg'),
(97664, 6934, 'Um Milagre S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/205626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l6btHxPskN6sxVXSaP2Ch3aaLe0.jpg'),
(97665, 6934, 'Um Milagre S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/205627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4yka7SZgJhPUSkc5Yy639mv5bvQ.jpg'),
(97666, 6934, 'Um Milagre S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/205628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rsdF7hkKHwelagMkaFijmJeWLyB.jpg'),
(97667, 6934, 'Um Milagre S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/205629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jwIZimmSY8v84xr6Cj51cfKFwY1.jpg'),
(97668, 6934, 'Um Milagre S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/205630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cumrC80REZ0lJW7k99TsC3dRGsn.jpg'),
(97669, 6934, 'Um Milagre S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/205631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4L6FVkcbY1HJ1KqGIKqt3X2DAPP.jpg'),
(97670, 6934, 'Um Milagre S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/205632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ldTPkkUaB6ErmJbTThm1CcujJAE.jpg'),
(97671, 6934, 'Um Milagre S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/205633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rEcrOlX89cFbQQ0AV77HInfW04O.jpg'),
(97672, 6934, 'Um Milagre S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/205634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m4vxvHSPCW0Maf5E7sFcEaJhzSF.jpg'),
(97673, 6934, 'Um Milagre S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/205635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kZ9go08mGuIoGn50QEj4nI6so78.jpg'),
(97674, 6934, 'Um Milagre S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/205636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mV66ZxjEwsPLvryKwIn8ZFNAN82.jpg'),
(97675, 6934, 'Um Milagre S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/205637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hvTndTz31oi3c6m2Cy0rfw95LhQ.jpg'),
(97676, 6934, 'Um Milagre S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/205638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oNBvi66woCoZgfNk4E6rFqtkgLO.jpg'),
(97677, 6934, 'Um Milagre S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/205639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4wDgyy9FXB2Do4qyaQj6ldWYfrd.jpg'),
(97678, 6934, 'Um Milagre S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/205640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97679, 6934, 'Um Milagre S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/205641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97680, 6934, 'Um Milagre S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/205642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97681, 6934, 'Um Milagre S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/205643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97682, 6934, 'Um Milagre S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/205644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97683, 6934, 'Um Milagre S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/205645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97684, 6934, 'Um Milagre S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/205646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97685, 6934, 'Um Milagre S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/205647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97686, 6934, 'Um Milagre S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/205648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97687, 6934, 'Um Milagre S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/205649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97688, 6934, 'Um Milagre S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/205650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97689, 6934, 'Um Milagre S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/205651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97690, 6934, 'Um Milagre S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/205652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97691, 6934, 'Um Milagre S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/205653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97692, 6934, 'Um Milagre S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/205654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97693, 6934, 'Um Milagre S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/205655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97694, 6934, 'Um Milagre S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/205656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97695, 6934, 'Um Milagre S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/205657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97696, 6934, 'Um Milagre S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/205658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97697, 6934, 'Um Milagre S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/205659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97698, 6934, 'Um Milagre S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/205660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97699, 6934, 'Um Milagre S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/205661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97700, 6934, 'Um Milagre S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/205662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97701, 6934, 'Um Milagre S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/205663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97702, 6934, 'Um Milagre S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/205664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97703, 6934, 'Um Milagre S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/205665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97704, 6934, 'Um Milagre S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/205666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97705, 6934, 'Um Milagre S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/205667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97706, 6934, 'Um Milagre S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/205668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97707, 6934, 'Um Milagre S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/205669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97708, 6934, 'Um Milagre S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/205670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97709, 6934, 'Um Milagre S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/205671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97710, 6934, 'Um Milagre S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/205672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97711, 6934, 'Um Milagre S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/205673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97712, 6934, 'Um Milagre S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/205674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97713, 6934, 'Um Milagre S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/205675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97714, 6934, 'Um Milagre S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/205676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97715, 6934, 'Um Milagre S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/205677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97716, 6934, 'Um Milagre S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/205678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97717, 6934, 'Um Milagre S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/205679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97718, 6934, 'Um Milagre S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/205680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97719, 6934, 'Um Milagre S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/205681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97720, 6934, 'Um Milagre S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/205682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97721, 6934, 'Um Milagre S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/205683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97722, 6934, 'Um Milagre S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/205684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97723, 6934, 'Um Milagre S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/205685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97724, 6934, 'Um Milagre S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/205686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97725, 6934, 'Um Milagre S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/205687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97726, 6934, 'Um Milagre S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/205688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97727, 6934, 'Um Milagre S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/205689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97728, 6935, 'Um Milagre S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cieVnNVxtSEgBp8IZI5HK5llaU4.jpg'),
(97729, 6935, 'Um Milagre S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wxRtseBd5Yd3WSGUtFun0PAnJjw.jpg'),
(97730, 6935, 'Um Milagre S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9PH0umDh3PH9OKQg6yCAm0bYdWi.jpg'),
(97731, 6935, 'Um Milagre S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zyrnTVdOQV2IsuZpISENajMTcFn.jpg'),
(97732, 6935, 'Um Milagre S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eYCkyQ0EmreyHSgwmW17ljZ2jBs.jpg'),
(97733, 6935, 'Um Milagre S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bPsQE2gwRlVAMY8VQEZphkczK2P.jpg'),
(97734, 6935, 'Um Milagre S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ai5eIJ91YrDe9RRmo0ekxVwbocI.jpg'),
(97735, 6935, 'Um Milagre S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fkQ0pvOGKcdboxdmxBPm27ZFv6.jpg'),
(97736, 6935, 'Um Milagre S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o3D9VvAD5gCfTY7QfNHqrXTP7sr.jpg'),
(97737, 6935, 'Um Milagre S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4QZi4I5Iy9NaUuijGHBaD3MSR9O.jpg'),
(97738, 6935, 'Um Milagre S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6RFDftlCFUOjiEc1CJmUV0CxetB.jpg'),
(97739, 6935, 'Um Milagre S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kR2J5nZPILrHrZxSAWB2pcr5NGq.jpg'),
(97740, 6935, 'Um Milagre S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oEi1ds54akc3Hf36ergUea2IEQb.jpg'),
(97741, 6935, 'Um Milagre S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/205703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mriFmOIGNnSwUgpqGm11alrx6qq.jpg'),
(97742, 6935, 'Um Milagre S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/205704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nwCX4w4iCwkGRTi2mEJy4q8scPy.jpg'),
(97743, 6935, 'Um Milagre S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/205705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1cJ7mO2r9avnbLPF0oZ0oM2jWzG.jpg'),
(97744, 6935, 'Um Milagre S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/205706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wfkgYrKeDNkSsKJw6VoyNPR18Z8.jpg'),
(97745, 6935, 'Um Milagre S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/205707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tVrgXCBDknuOdOsp2LCO8MPqUV7.jpg'),
(97746, 6935, 'Um Milagre S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/205708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aB7v9gNWEHRnpnhy81ASiR4R6ta.jpg'),
(97747, 6935, 'Um Milagre S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/205709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mIoqBHvqllRLllQ6RrsBhlawjsN.jpg'),
(97748, 6935, 'Um Milagre S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/205710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Nh7HduFHnEMFVoeemesK9aGSSk.jpg'),
(97749, 6935, 'Um Milagre S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/205711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kncvYgvIDgxtSP4N0eNL7zqCyxS.jpg'),
(97750, 6935, 'Um Milagre S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/205712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w5ut8J0KLS8LEuRUKc3h5Kb4TXM.jpg'),
(97751, 6935, 'Um Milagre S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/205713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZrjJIIZwsKqEiRGPQU4jKBuMBC.jpg'),
(97752, 6935, 'Um Milagre S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/205714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5JC6sT27fbVr9f3fUKDYEad8xG.jpg'),
(97753, 6935, 'Um Milagre S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/205715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mDCFlM1GQ3FzkrRs4vy2dCjjM5i.jpg'),
(97754, 6935, 'Um Milagre S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/205716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6wNE8W67gUUN83hGsV3BFSSWppm.jpg'),
(97755, 6935, 'Um Milagre S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/205717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4wfc7TFdSa44s4sR1dGZYs97ILF.jpg'),
(97756, 6935, 'Um Milagre S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/205718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cbgcKsLDOwHNDjlH6fipbNqD626.jpg'),
(97757, 6935, 'Um Milagre S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/205719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h2iYfWYm3foTsZa6Ea76yqUx0Aj.jpg'),
(97758, 6935, 'Um Milagre S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/205720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ersUdF34E14a5wVG8rQhHzhHlG9.jpg'),
(97759, 6935, 'Um Milagre S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/205721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/71mbcKtTeL5O6UbZ1WQ4lwQf3UY.jpg'),
(97760, 6935, 'Um Milagre S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/205722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3vnuJgFOSr13blxB0zAlx6gsEwj.jpg'),
(97761, 6935, 'Um Milagre S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/205723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4z5wiDgibwuG2YONdIIDZUpGvs3.jpg'),
(97762, 6935, 'Um Milagre S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/205724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ib407PIknaUoxH0BIjWtcZY3pDP.jpg'),
(97763, 6935, 'Um Milagre S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/205725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uiaJLNJN2obyHVcy6WpJf7za3dz.jpg'),
(97764, 6935, 'Um Milagre S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/205726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97765, 6935, 'Um Milagre S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/205727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97766, 6935, 'Um Milagre S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/205728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97767, 6935, 'Um Milagre S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/205729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97768, 6935, 'Um Milagre S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/205730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97769, 6935, 'Um Milagre S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/205731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97770, 6935, 'Um Milagre S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/205732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97771, 6935, 'Um Milagre S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/205733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97772, 6935, 'Um Milagre S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/205734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97773, 6935, 'Um Milagre S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/205735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97774, 6935, 'Um Milagre S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/205736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97775, 6935, 'Um Milagre S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/205737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97776, 6935, 'Um Milagre S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/205738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97777, 6935, 'Um Milagre S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/205739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97778, 6935, 'Um Milagre S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/205740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97779, 6935, 'Um Milagre S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/205741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97780, 6935, 'Um Milagre S02 E53', 'http://sinalprivado.info:80/series/1533784/1533784/205742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97781, 6935, 'Um Milagre S02 E54', 'http://sinalprivado.info:80/series/1533784/1533784/205743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97782, 6935, 'Um Milagre S02 E55', 'http://sinalprivado.info:80/series/1533784/1533784/205744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97783, 6935, 'Um Milagre S02 E56', 'http://sinalprivado.info:80/series/1533784/1533784/205745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97784, 6935, 'Um Milagre S02 E57', 'http://sinalprivado.info:80/series/1533784/1533784/205746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97785, 6935, 'Um Milagre S02 E58', 'http://sinalprivado.info:80/series/1533784/1533784/205747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97786, 6935, 'Um Milagre S02 E59', 'http://sinalprivado.info:80/series/1533784/1533784/205748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97787, 6935, 'Um Milagre S02 E60', 'http://sinalprivado.info:80/series/1533784/1533784/205749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97788, 6935, 'Um Milagre S02 E61', 'http://sinalprivado.info:80/series/1533784/1533784/205750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97789, 6935, 'Um Milagre S02 E62', 'http://sinalprivado.info:80/series/1533784/1533784/205751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97790, 6935, 'Um Milagre S02 E63', 'http://sinalprivado.info:80/series/1533784/1533784/205752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97791, 6935, 'Um Milagre S02 E64', 'http://sinalprivado.info:80/series/1533784/1533784/205753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97792, 6935, 'Um Milagre S02 E65', 'http://sinalprivado.info:80/series/1533784/1533784/205754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97793, 6935, 'Um Milagre S02 E66', 'http://sinalprivado.info:80/series/1533784/1533784/205755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97794, 6935, 'Um Milagre S02 E67', 'http://sinalprivado.info:80/series/1533784/1533784/205756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97795, 6935, 'Um Milagre S02 E68', 'http://sinalprivado.info:80/series/1533784/1533784/205757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97796, 6935, 'Um Milagre S02 E69', 'http://sinalprivado.info:80/series/1533784/1533784/205758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97797, 6935, 'Um Milagre S02 E70', 'http://sinalprivado.info:80/series/1533784/1533784/205759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97798, 6935, 'Um Milagre S02 E71', 'http://sinalprivado.info:80/series/1533784/1533784/205760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97799, 6935, 'Um Milagre S02 E72', 'http://sinalprivado.info:80/series/1533784/1533784/205761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97800, 6935, 'Um Milagre S02 E73', 'http://sinalprivado.info:80/series/1533784/1533784/205762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97801, 6935, 'Um Milagre S02 E74', 'http://sinalprivado.info:80/series/1533784/1533784/205763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97802, 6935, 'Um Milagre S02 E75', 'http://sinalprivado.info:80/series/1533784/1533784/205764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97803, 6935, 'Um Milagre S02 E76', 'http://sinalprivado.info:80/series/1533784/1533784/205765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97804, 6935, 'Um Milagre S02 E77', 'http://sinalprivado.info:80/series/1533784/1533784/205766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97805, 6935, 'Um Milagre S02 E78', 'http://sinalprivado.info:80/series/1533784/1533784/205767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97806, 6935, 'Um Milagre S02 E79', 'http://sinalprivado.info:80/series/1533784/1533784/205768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97807, 6935, 'Um Milagre S02 E80', 'http://sinalprivado.info:80/series/1533784/1533784/205769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97808, 6935, 'Um Milagre S02 E81', 'http://sinalprivado.info:80/series/1533784/1533784/205770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97809, 6935, 'Um Milagre S02 E82', 'http://sinalprivado.info:80/series/1533784/1533784/205771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97810, 6935, 'Um Milagre S02 E83', 'http://sinalprivado.info:80/series/1533784/1533784/205772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97811, 6935, 'Um Milagre S02 E84', 'http://sinalprivado.info:80/series/1533784/1533784/205773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97812, 6935, 'Um Milagre S02 E85', 'http://sinalprivado.info:80/series/1533784/1533784/205774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97813, 6935, 'Um Milagre S02 E86', 'http://sinalprivado.info:80/series/1533784/1533784/205775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97814, 6935, 'Um Milagre S02 E87', 'http://sinalprivado.info:80/series/1533784/1533784/205776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97815, 6935, 'Um Milagre S02 E88', 'http://sinalprivado.info:80/series/1533784/1533784/205777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97816, 6935, 'Um Milagre S02 E89', 'http://sinalprivado.info:80/series/1533784/1533784/205778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97817, 6935, 'Um Milagre S02 E90', 'http://sinalprivado.info:80/series/1533784/1533784/205779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97818, 6935, 'Um Milagre S02 E91', 'http://sinalprivado.info:80/series/1533784/1533784/205780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97819, 6935, 'Um Milagre S02 E92', 'http://sinalprivado.info:80/series/1533784/1533784/205781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97820, 6935, 'Um Milagre S02 E93', 'http://sinalprivado.info:80/series/1533784/1533784/205782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97821, 6935, 'Um Milagre S02 E94', 'http://sinalprivado.info:80/series/1533784/1533784/205783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97822, 6935, 'Um Milagre S02 E95', 'http://sinalprivado.info:80/series/1533784/1533784/205784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97823, 6935, 'Um Milagre S02 E96', 'http://sinalprivado.info:80/series/1533784/1533784/205785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97824, 6935, 'Um Milagre S02 E97', 'http://sinalprivado.info:80/series/1533784/1533784/205786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97825, 6935, 'Um Milagre S02 E98', 'http://sinalprivado.info:80/series/1533784/1533784/205787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97826, 6935, 'Um Milagre S02 E99', 'http://sinalprivado.info:80/series/1533784/1533784/205788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97827, 6935, 'Um Milagre S02 E100', 'http://sinalprivado.info:80/series/1533784/1533784/205789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97828, 6935, 'Um Milagre S02 E101', 'http://sinalprivado.info:80/series/1533784/1533784/205790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97829, 6935, 'Um Milagre S02 E102', 'http://sinalprivado.info:80/series/1533784/1533784/205791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97830, 6935, 'Um Milagre S02 E103', 'http://sinalprivado.info:80/series/1533784/1533784/205792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97831, 6935, 'Um Milagre S02 E104', 'http://sinalprivado.info:80/series/1533784/1533784/205793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97832, 6935, 'Um Milagre S02 E105', 'http://sinalprivado.info:80/series/1533784/1533784/205794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97833, 6935, 'Um Milagre S02 E106', 'http://sinalprivado.info:80/series/1533784/1533784/205795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97834, 6935, 'Um Milagre S02 E107', 'http://sinalprivado.info:80/series/1533784/1533784/205796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97835, 6935, 'Um Milagre S02 E108', 'http://sinalprivado.info:80/series/1533784/1533784/205797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97836, 6935, 'Um Milagre S02 E109', 'http://sinalprivado.info:80/series/1533784/1533784/205798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97837, 6935, 'Um Milagre S02 E110', 'http://sinalprivado.info:80/series/1533784/1533784/205799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97838, 6935, 'Um Milagre S02 E111', 'http://sinalprivado.info:80/series/1533784/1533784/205800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97839, 6935, 'Um Milagre S02 E112', 'http://sinalprivado.info:80/series/1533784/1533784/205801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ABaZxWcO0tG9nxuwBJroNP4IFO.jpg'),
(97840, 6936, 'Malory Towers: Escola Para Meninas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mTRnqRHYuz4oVqiuMDWsPdofwbZ.jpg'),
(97841, 6936, 'Malory Towers: Escola Para Meninas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6XcPEmpb4VW468BX3VS6nVvoxjg.jpg'),
(97842, 6936, 'Malory Towers: Escola Para Meninas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t4M3KHiD7Km3pUwhzXA2QtgnsBi.jpg'),
(97843, 6936, 'Malory Towers: Escola Para Meninas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ph8s3qF9aRYEdzQOZ75VktNEedf.jpg'),
(97844, 6936, 'Malory Towers: Escola Para Meninas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/feiJnvEzyKdDqcIBv5Ux1nmsLHt.jpg'),
(97845, 6936, 'Malory Towers: Escola Para Meninas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e5W688lPQBYHEq8bYKF0pAeNSQW.jpg'),
(97846, 6936, 'Malory Towers: Escola Para Meninas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y49Th4wpBRHQGcsMhhE6FMeM9hD.jpg'),
(97847, 6936, 'Malory Towers: Escola Para Meninas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bdXNKbBHCQimzHlGGCw8pHMyiPz.jpg'),
(97848, 6936, 'Malory Towers: Escola Para Meninas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3QheHwJeJ2DgarKkkaKQzY1fo2b.jpg'),
(97849, 6936, 'Malory Towers: Escola Para Meninas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hX2rZM9hH9XI6WCBoEKXWD3clCZ.jpg'),
(97850, 6936, 'Malory Towers: Escola Para Meninas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tRvKsXjX9czVUu8kIiAhoB7TCOX.jpg'),
(97851, 6936, 'Malory Towers: Escola Para Meninas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eotTMeZKA8NuygeSGkyXu0D8DvV.jpg'),
(97852, 6936, 'Malory Towers: Escola Para Meninas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qx8x8bThyVOhUGK9kF3HUO9krRu.jpg'),
(97853, 6937, 'Malory Towers: Escola Para Meninas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tv5JcmRNDE47JOk00B0BNtlYrnE.jpg'),
(97854, 6937, 'Malory Towers: Escola Para Meninas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhPFrBSM2zne9geOw2k7tgik98F.jpg'),
(97855, 6937, 'Malory Towers: Escola Para Meninas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oKlYVWWcGNE0up6pgSMlNUmk0Wa.jpg'),
(97856, 6937, 'Malory Towers: Escola Para Meninas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOvUlxiusrAv6MRpGOkzDWD9Ap4.jpg'),
(97857, 6937, 'Malory Towers: Escola Para Meninas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/biZKWFpSBB5UiNNybssqccnZ0G1.jpg'),
(97858, 6937, 'Malory Towers: Escola Para Meninas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ac9s2Ps8fPJ4QOj9UNmUQ0CN8qr.jpg'),
(97859, 6937, 'Malory Towers: Escola Para Meninas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7KUcOu2Iix3DP62p1Uh234QQ4Qw.jpg'),
(97860, 6937, 'Malory Towers: Escola Para Meninas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vlqgVvGDv7GgeOPokbe53VigFjk.jpg'),
(97861, 6937, 'Malory Towers: Escola Para Meninas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1yIrU4SHOmcOosKLwClLnXPi9Qf.jpg'),
(97862, 6937, 'Malory Towers: Escola Para Meninas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tTklJ9nUq18NDjvKiAM3dcqBeKM.jpg'),
(97863, 6937, 'Malory Towers: Escola Para Meninas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aoFPN736QvW5QK3PF0NxRA3MX8l.jpg'),
(97864, 6937, 'Malory Towers: Escola Para Meninas S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pm91xsdoAO2HHu1nwRwLJM1C7gA.jpg'),
(97865, 6937, 'Malory Towers: Escola Para Meninas S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iTu1VjeDUXJkZU2MTYEIJ377r59.jpg'),
(97866, 6938, 'Velma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v46BcgA4XpRnALRGptLUcHVefqK.jpg'),
(97867, 6938, 'Velma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cyc0YfyQBe2uoBOPb1j2ALs2ANB.jpg'),
(97868, 6938, 'Velma S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208135.mp4', 'http://image.tmdb.org/t/p/w1280/uJsBcoTIjWjUUgG9MIJoB3AGUQb.jpg'),
(97869, 6938, 'Velma S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208136.mp4', 'http://image.tmdb.org/t/p/w1280/1EMtdSjzPBZGYCJ7OFWj4xxGO9m.jpg'),
(97870, 6938, 'Velma S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208137.mp4', 'http://image.tmdb.org/t/p/w1280/oaVyUEtYR4ykfLAq7IaKaS2wWXF.jpg'),
(97871, 6938, 'Velma S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208138.mp4', 'http://image.tmdb.org/t/p/w1280/vN3wMAMaHA1BGas3LcthWcEszBZ.jpg'),
(97872, 6938, 'Velma S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208139.mp4', 'http://image.tmdb.org/t/p/w1280/qyUtH1EeLawl0kMd4DJzujkV2jA.jpg'),
(97873, 6938, 'Velma S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208140.mp4', 'http://image.tmdb.org/t/p/w1280/fEFRHw9Qnn2XbincXw6XkIvov0L.jpg'),
(97874, 6938, 'Velma S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208141.mp4', 'http://image.tmdb.org/t/p/w1280/htIEsarYiATAK4G1YjjsePL34K8.jpg'),
(97875, 6938, 'Velma S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208142.mp4', 'http://image.tmdb.org/t/p/w1280/acmFRsSvNxL2WDyyqzN1ItXvw9Z.jpg'),
(97876, 6939, 'Velma S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/335207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5CdOTywSaR17hZygRDlg8xEa30.jpg'),
(97877, 6939, 'Velma S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/335208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5CdOTywSaR17hZygRDlg8xEa30.jpg'),
(97878, 6939, 'Velma S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/335209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5CdOTywSaR17hZygRDlg8xEa30.jpg'),
(97879, 6939, 'Velma S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/335210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5CdOTywSaR17hZygRDlg8xEa30.jpg'),
(97880, 6939, 'Velma S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/335211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5CdOTywSaR17hZygRDlg8xEa30.jpg'),
(97881, 6939, 'Velma S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/335212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5CdOTywSaR17hZygRDlg8xEa30.jpg'),
(97882, 6939, 'Velma S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/335213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5CdOTywSaR17hZygRDlg8xEa30.jpg'),
(97883, 6939, 'Velma S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/335214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5CdOTywSaR17hZygRDlg8xEa30.jpg'),
(97884, 6939, 'Velma S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/335215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5CdOTywSaR17hZygRDlg8xEa30.jpg'),
(97885, 6939, 'Velma S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/335216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5CdOTywSaR17hZygRDlg8xEa30.jpg'),
(97886, 6940, 'The Last of Us S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206204.mp4', 'http://image.tmdb.org/t/p/w1280/aRquEWm8wWF1dfa9uZ1TXLvVrKD.jpg'),
(97887, 6940, 'The Last of Us S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206205.mp4', 'http://image.tmdb.org/t/p/w1280/vGf7chl6XL7o3yYc8A5m3kjz8px.jpg'),
(97888, 6940, 'The Last of Us S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206206.mp4', 'http://image.tmdb.org/t/p/w1280/bzy4hAtkY3OOInY4q6MJigLmC1m.jpg'),
(97889, 6940, 'The Last of Us S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206207.mp4', 'http://image.tmdb.org/t/p/w1280/szQ95jxKNrYWnCAJx8VC51iws5d.jpg'),
(97890, 6940, 'The Last of Us S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206208.mp4', 'http://image.tmdb.org/t/p/w1280/cX2z8FO9lKqZmBBTVF2G2favQRE.jpg'),
(97891, 6940, 'The Last of Us S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206209.mp4', 'http://image.tmdb.org/t/p/w1280/zW9AIy0PVhYfmukqBcUvlvi4mKc.jpg'),
(97892, 6940, 'The Last of Us S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206210.mp4', 'http://image.tmdb.org/t/p/w1280/oNyC68bnOoVAiJnKVsRNY9YDbl6.jpg'),
(97893, 6940, 'The Last of Us S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206211.mp4', 'http://image.tmdb.org/t/p/w1280/6DHQgB85iKMcabcKvC9HSDH3UDo.jpg'),
(97894, 6940, 'The Last of Us S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206212.mp4', 'http://image.tmdb.org/t/p/w1280/qFouIBgN3Jgba7LnuRmkTAohh07.jpg'),
(97895, 6941, 'The Last of Us S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/763244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uKvVjHNqB5VmOrdxqAt2F7J78ED.jpg'),
(97896, 6941, 'The Last of Us S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/771668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uKvVjHNqB5VmOrdxqAt2F7J78ED.jpg'),
(97897, 6941, 'The Last of Us S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/783853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uKvVjHNqB5VmOrdxqAt2F7J78ED.jpg'),
(97898, 6941, 'The Last of Us S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/793139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uKvVjHNqB5VmOrdxqAt2F7J78ED.jpg'),
(97899, 6941, 'The Last of Us S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/797370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uKvVjHNqB5VmOrdxqAt2F7J78ED.jpg'),
(97900, 6941, 'The Last of Us S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/805162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uKvVjHNqB5VmOrdxqAt2F7J78ED.jpg'),
(97901, 6941, 'The Last of Us S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/816757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uKvVjHNqB5VmOrdxqAt2F7J78ED.jpg'),
(97902, 6942, '9mm: São Paulo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfLN1TUHSHKcRq2pEAVYITgYFfy.jpg'),
(97903, 6942, '9mm: São Paulo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfLN1TUHSHKcRq2pEAVYITgYFfy.jpg'),
(97904, 6942, '9mm: São Paulo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfLN1TUHSHKcRq2pEAVYITgYFfy.jpg'),
(97905, 6942, '9mm: São Paulo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfLN1TUHSHKcRq2pEAVYITgYFfy.jpg'),
(97906, 6942, '9mm: São Paulo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfLN1TUHSHKcRq2pEAVYITgYFfy.jpg'),
(97907, 6942, '9mm: São Paulo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfLN1TUHSHKcRq2pEAVYITgYFfy.jpg'),
(97908, 6942, '9mm: São Paulo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfLN1TUHSHKcRq2pEAVYITgYFfy.jpg'),
(97909, 6942, '9mm: São Paulo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfLN1TUHSHKcRq2pEAVYITgYFfy.jpg'),
(97910, 6942, '9mm: São Paulo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfLN1TUHSHKcRq2pEAVYITgYFfy.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(97911, 6942, '9mm: São Paulo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfLN1TUHSHKcRq2pEAVYITgYFfy.jpg'),
(97912, 6942, '9mm: São Paulo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfLN1TUHSHKcRq2pEAVYITgYFfy.jpg'),
(97913, 6942, '9mm: São Paulo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfLN1TUHSHKcRq2pEAVYITgYFfy.jpg'),
(97914, 6942, '9mm: São Paulo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfLN1TUHSHKcRq2pEAVYITgYFfy.jpg'),
(97915, 6943, '9mm: São Paulo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfLN1TUHSHKcRq2pEAVYITgYFfy.jpg'),
(97916, 6943, '9mm: São Paulo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfLN1TUHSHKcRq2pEAVYITgYFfy.jpg'),
(97917, 6943, '9mm: São Paulo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfLN1TUHSHKcRq2pEAVYITgYFfy.jpg'),
(97918, 6943, '9mm: São Paulo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfLN1TUHSHKcRq2pEAVYITgYFfy.jpg'),
(97919, 6943, '9mm: São Paulo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfLN1TUHSHKcRq2pEAVYITgYFfy.jpg'),
(97920, 6943, '9mm: São Paulo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfLN1TUHSHKcRq2pEAVYITgYFfy.jpg'),
(97921, 6943, '9mm: São Paulo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfLN1TUHSHKcRq2pEAVYITgYFfy.jpg'),
(97922, 6944, 'A Inglesa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfdz1ZD4bLZDeWgjHe7jn4RWTBv.jpg'),
(97923, 6944, 'A Inglesa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A1SOr8Ow0ZDtH1HET2eTirU2dOT.jpg'),
(97924, 6944, 'A Inglesa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aNjOchGpdxFP7EZhvu6rvj7Vn5.jpg'),
(97925, 6944, 'A Inglesa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZBZfZ5X99cxgCWoflhVk3gWrVR.jpg'),
(97926, 6944, 'A Inglesa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AldSLU0grmJQu0yiwu2AaSV0vYU.jpg'),
(97927, 6944, 'A Inglesa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJCeqQ1xRyr82Z5iqxG4QpxPTHm.jpg'),
(97928, 6945, 'A Lenda de Shahmaran S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sg3Sbhs4TM5woBQAYBGUMrmSDyw.jpg'),
(97929, 6945, 'A Lenda de Shahmaran S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n85nJwsVV6mU0sGOXzItxPtuNqv.jpg'),
(97930, 6945, 'A Lenda de Shahmaran S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/whinoRaca07LOQ2UMfjqJjGBdlR.jpg'),
(97931, 6945, 'A Lenda de Shahmaran S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lNicXVY4lzzMasnPDiGI1UfHtDR.jpg'),
(97932, 6945, 'A Lenda de Shahmaran S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mUA034fNnjIZMFIN3PtuzByJ4Li.jpg'),
(97933, 6945, 'A Lenda de Shahmaran S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Q9wZxwcyd4irlJuc1MAbLagHvI.jpg'),
(97934, 6945, 'A Lenda de Shahmaran S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mBKPM8NXbREdEZcg2QGuN1ayclK.jpg'),
(97935, 6945, 'A Lenda de Shahmaran S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qcGfpLciNO8yzvC6rLJw3O0w2l5.jpg'),
(97936, 6946, 'A Lenda de Shahmaran S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/432771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fKsga4dTxTRNFp1ktUWUa7P1Ib.jpg'),
(97937, 6946, 'A Lenda de Shahmaran S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/432772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fKsga4dTxTRNFp1ktUWUa7P1Ib.jpg'),
(97938, 6946, 'A Lenda de Shahmaran S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/432773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fKsga4dTxTRNFp1ktUWUa7P1Ib.jpg'),
(97939, 6946, 'A Lenda de Shahmaran S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/432774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fKsga4dTxTRNFp1ktUWUa7P1Ib.jpg'),
(97940, 6946, 'A Lenda de Shahmaran S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/432775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fKsga4dTxTRNFp1ktUWUa7P1Ib.jpg'),
(97941, 6946, 'A Lenda de Shahmaran S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/432776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fKsga4dTxTRNFp1ktUWUa7P1Ib.jpg'),
(97942, 6947, 'A Noiva do Antigo Mago: O Menino do Oeste e o Cavaleiro da Tempestade Azul S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/B9IfW7Q38ipjFtESBCpbikhMlR.jpg'),
(97943, 6947, 'A Noiva do Antigo Mago: O Menino do Oeste e o Cavaleiro da Tempestade Azul S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dTcjsyTAi2FUH4w1tRiZjAkqj8j.jpg'),
(97944, 6947, 'A Noiva do Antigo Mago: O Menino do Oeste e o Cavaleiro da Tempestade Azul S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qIEaG8mNMO8sZALs3sVEBGlrePl.jpg'),
(97945, 6948, 'A Noiva do Antigo Mago: O Menino do Oeste e o Cavaleiro da Tempestade Azul S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5lWXAxRx5gIV3aun3MvWaKeJQY.jpg'),
(97946, 6948, 'A Noiva do Antigo Mago: O Menino do Oeste e o Cavaleiro da Tempestade Azul S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5lWXAxRx5gIV3aun3MvWaKeJQY.jpg'),
(97947, 6948, 'A Noiva do Antigo Mago: O Menino do Oeste e o Cavaleiro da Tempestade Azul S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5lWXAxRx5gIV3aun3MvWaKeJQY.jpg'),
(97948, 6948, 'A Noiva do Antigo Mago: O Menino do Oeste e o Cavaleiro da Tempestade Azul S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5lWXAxRx5gIV3aun3MvWaKeJQY.jpg'),
(97949, 6948, 'A Noiva do Antigo Mago: O Menino do Oeste e o Cavaleiro da Tempestade Azul S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5lWXAxRx5gIV3aun3MvWaKeJQY.jpg'),
(97950, 6948, 'A Noiva do Antigo Mago: O Menino do Oeste e o Cavaleiro da Tempestade Azul S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5lWXAxRx5gIV3aun3MvWaKeJQY.jpg'),
(97951, 6948, 'A Noiva do Antigo Mago: O Menino do Oeste e o Cavaleiro da Tempestade Azul S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5lWXAxRx5gIV3aun3MvWaKeJQY.jpg'),
(97952, 6948, 'A Noiva do Antigo Mago: O Menino do Oeste e o Cavaleiro da Tempestade Azul S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5lWXAxRx5gIV3aun3MvWaKeJQY.jpg'),
(97953, 6948, 'A Noiva do Antigo Mago: O Menino do Oeste e o Cavaleiro da Tempestade Azul S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5lWXAxRx5gIV3aun3MvWaKeJQY.jpg'),
(97954, 6948, 'A Noiva do Antigo Mago: O Menino do Oeste e o Cavaleiro da Tempestade Azul S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5lWXAxRx5gIV3aun3MvWaKeJQY.jpg'),
(97955, 6948, 'A Noiva do Antigo Mago: O Menino do Oeste e o Cavaleiro da Tempestade Azul S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5lWXAxRx5gIV3aun3MvWaKeJQY.jpg'),
(97956, 6948, 'A Noiva do Antigo Mago: O Menino do Oeste e o Cavaleiro da Tempestade Azul S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5lWXAxRx5gIV3aun3MvWaKeJQY.jpg'),
(97957, 6949, 'Agência de Celebridades S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pGYeqor3OrJf2j0oVo4jT5lEGVZ.jpg'),
(97958, 6949, 'Agência de Celebridades S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9m4D1jJrBLywSBlMIJ0ANm0XJb.jpg'),
(97959, 6949, 'Agência de Celebridades S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lm14hrnbXBGHFiRiLj8dmYKod6n.jpg'),
(97960, 6949, 'Agência de Celebridades S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7rIMVyz4zsgJ2PvC9D5goHOEpA2.jpg'),
(97961, 6949, 'Agência de Celebridades S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kgSqM1fKil2GyucssJ7CMyX7JNH.jpg'),
(97962, 6949, 'Agência de Celebridades S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tKFo6C3am2K0RFzjD85LFIKMr4e.jpg'),
(97963, 6949, 'Agência de Celebridades S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i9c9jT1VEitrxfVWx5iG6sdSjRR.jpg'),
(97964, 6949, 'Agência de Celebridades S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wPP2rdNB25VwFA4yoO0X0nzVwh2.jpg'),
(97965, 6949, 'Agência de Celebridades S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fMXx89vZhbh3oHEQ7DVvim1T7Y7.jpg'),
(97966, 6949, 'Agência de Celebridades S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zW7VLFkG1lfkdsCD9tpZoSTmj6D.jpg'),
(97967, 6949, 'Agência de Celebridades S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AmHvaexP4dGwLICzs1DNStA35op.jpg'),
(97968, 6949, 'Agência de Celebridades S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iKe2sCmBKTrwHtpZBfgOrxjCKoN.jpg'),
(97969, 6950, 'Billy the Kid S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kf88vI6meL5sNadrLnItkqfNz2c.jpg'),
(97970, 6950, 'Billy the Kid S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AdcaUlQZwNWfodSa3nr6qQzUpBy.jpg'),
(97971, 6950, 'Billy the Kid S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dY5D2saqhlBEYFfIVp0Ymngf6tO.jpg'),
(97972, 6950, 'Billy the Kid S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xRvUEge7Z0eS3R40jhMBu4yZkxx.jpg'),
(97973, 6950, 'Billy the Kid S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qbljeKBxjPXQylgJL9cxNVD7a0L.jpg'),
(97974, 6950, 'Billy the Kid S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lu7cxFtgV3yFuMKKdtdQGtfKCin.jpg'),
(97975, 6950, 'Billy the Kid S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lUFHNoRhb3m5C3eGp0JGnHTT3jp.jpg'),
(97976, 6950, 'Billy the Kid S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jl2OP3GaWY0gQfwF2CR5uDmfo60.jpg'),
(97977, 6951, 'Billy the Kid S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/810313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JyuHbdVIhBoArxEtifLrzodUEM.jpg'),
(97978, 6951, 'Billy the Kid S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/810314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JyuHbdVIhBoArxEtifLrzodUEM.jpg'),
(97979, 6951, 'Billy the Kid S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/810315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JyuHbdVIhBoArxEtifLrzodUEM.jpg'),
(97980, 6951, 'Billy the Kid S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/810316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JyuHbdVIhBoArxEtifLrzodUEM.jpg'),
(97981, 6951, 'Billy the Kid S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/810317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JyuHbdVIhBoArxEtifLrzodUEM.jpg'),
(97982, 6951, 'Billy the Kid S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/810318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JyuHbdVIhBoArxEtifLrzodUEM.jpg'),
(97983, 6951, 'Billy the Kid S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/810319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JyuHbdVIhBoArxEtifLrzodUEM.jpg'),
(97984, 6951, 'Billy the Kid S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/810320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JyuHbdVIhBoArxEtifLrzodUEM.jpg'),
(97985, 6952, 'Billy the Kid S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/886269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JyuHbdVIhBoArxEtifLrzodUEM.jpg'),
(97986, 6952, 'Billy the Kid S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/887752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JyuHbdVIhBoArxEtifLrzodUEM.jpg'),
(97987, 6952, 'Billy the Kid S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/888234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JyuHbdVIhBoArxEtifLrzodUEM.jpg'),
(97988, 6952, 'Billy the Kid S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/889104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JyuHbdVIhBoArxEtifLrzodUEM.jpg'),
(97989, 6952, 'Billy the Kid S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/890158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JyuHbdVIhBoArxEtifLrzodUEM.jpg'),
(97990, 6952, 'Billy the Kid S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/892233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JyuHbdVIhBoArxEtifLrzodUEM.jpg'),
(97991, 6952, 'Billy the Kid S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/892672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JyuHbdVIhBoArxEtifLrzodUEM.jpg'),
(97992, 6952, 'Billy the Kid S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/893393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JyuHbdVIhBoArxEtifLrzodUEM.jpg'),
(97993, 6953, 'Chainsaw Man S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dDwTq0HNQGMCpEdVQQyksvJvUcP.jpg'),
(97994, 6953, 'Chainsaw Man S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sHT11G9NrSxYCTPLJn0Uo8UGVys.jpg'),
(97995, 6953, 'Chainsaw Man S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x20TB0bPovb6mcOoSWO3SNL7zhj.jpg'),
(97996, 6953, 'Chainsaw Man S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2CMeNnCTlwDV1bRH9pQ9AlqY2BJ.jpg'),
(97997, 6953, 'Chainsaw Man S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fqdQYCeYPb69cElikWLZRWssiwr.jpg'),
(97998, 6953, 'Chainsaw Man S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1gtFS9ch884GtW543RK4Ma0xAwW.jpg'),
(97999, 6953, 'Chainsaw Man S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iUCOrXRCuc17081EZb0i2OnNDtA.jpg'),
(98000, 6953, 'Chainsaw Man S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oMRTKYMYHQBlFVYvjNuUJWzLYz5.jpg'),
(98001, 6953, 'Chainsaw Man S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/azSm7pEl9LSAmEKZ1dbn1s9cHTG.jpg'),
(98002, 6953, 'Chainsaw Man S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/latU1KQwYICuYqpz3oNphvYG6DH.jpg'),
(98003, 6953, 'Chainsaw Man S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xT2COgjUXnnC5ho4El1epWFkwjt.jpg'),
(98004, 6953, 'Chainsaw Man S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xqxc5esGMw5alHcju87cmjyAkyy.jpg'),
(98005, 6954, 'Cidade do Caos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rX5U5lkgP5kYw1gPze0FH47uWj.jpg'),
(98006, 6954, 'Cidade do Caos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ssHLK4SEycDRZlbr4SN4CGqq6Gh.jpg'),
(98007, 6954, 'Cidade do Caos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2M73jfm88CNseXJXGPnxrts0Cqp.jpg'),
(98008, 6954, 'Cidade do Caos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5b0oLb54E2zEDqUVxpsczbwT1jo.jpg'),
(98009, 6954, 'Cidade do Caos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ktbK7DCiVlL0mI47YY8H01rat2s.jpg'),
(98010, 6954, 'Cidade do Caos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e9qkznOyx4JLwcCtlQ36XCSrN3v.jpg'),
(98011, 6955, 'Clube das Mães S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/crk6Xu1JOXsXgnbosfzVSVp8FOS.jpg'),
(98012, 6955, 'Clube das Mães S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6rcpWcFYGcemLY8gIzoVuUE2I6w.jpg'),
(98013, 6955, 'Clube das Mães S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z94BoANxiObibjF1ISY9mHpPzzz.jpg'),
(98014, 6955, 'Clube das Mães S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oMvQKCgTnX9xfUjtNoWsSRmqDkd.jpg'),
(98015, 6955, 'Clube das Mães S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qRj9ZGovs7wdOVQpuvh9To6bIh.jpg'),
(98016, 6955, 'Clube das Mães S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v39EJ9JNMIwLoiaSM8wbZlAYqKo.jpg'),
(98017, 6955, 'Clube das Mães S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3vGZdEXMnOgeOCLiAaTYBJe81TY.jpg'),
(98018, 6955, 'Clube das Mães S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oedCiMaGhkBuaKhR3FlRnz36Xc1.jpg'),
(98019, 6955, 'Clube das Mães S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1AgXULb70GmoUCZ40mD7vRFDwCR.jpg'),
(98020, 6955, 'Clube das Mães S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d37hyGjKlViH0czFcaGZKenwtVA.jpg'),
(98021, 6955, 'Clube das Mães S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nqHZ6mpA2Gekc2wLcaPenGNPr1u.jpg'),
(98022, 6955, 'Clube das Mães S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x7GufI9HbIB5i0RQurlsjLnR2ln.jpg'),
(98023, 6955, 'Clube das Mães S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jqt017SZpqGuzMD9Narrt7OaCHw.jpg'),
(98024, 6955, 'Clube das Mães S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/205287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dFiPWW2dNbbsjG1SsUq3svtlszq.jpg'),
(98025, 6955, 'Clube das Mães S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/205288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Y3BkEAZFcPJ4KCD3c8aMETnmds.jpg'),
(98026, 6955, 'Clube das Mães S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/205289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qCanTiaUn4nIcMfJ5al6BpKpvjI.jpg'),
(98027, 6956, 'Com a Permissão do Tribunal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qvvjHV2QUGiPPnqPbywzokeTf4j.jpg'),
(98028, 6956, 'Com a Permissão do Tribunal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2CE2mC1uL3p61bD0qqMYpolctEW.jpg'),
(98029, 6956, 'Com a Permissão do Tribunal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aihg00YYAuVxVnbkGsdVbWokBwd.jpg'),
(98030, 6956, 'Com a Permissão do Tribunal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5rFDzn5XIaC6Z3S3jfdq7UAQC0P.jpg'),
(98031, 6956, 'Com a Permissão do Tribunal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xvkeOVUcRtA9Qv4pCyVMTLRT1L9.jpg'),
(98032, 6956, 'Com a Permissão do Tribunal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0Gg06F8txmHMD5etCq1dHOgXkr.jpg'),
(98033, 6956, 'Com a Permissão do Tribunal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/csHo8SmYUB9KVklb3CNIraX4Tg0.jpg'),
(98034, 6956, 'Com a Permissão do Tribunal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yOStGqZZe0LzIMftVymVsV2rxGh.jpg'),
(98035, 6956, 'Com a Permissão do Tribunal S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f3tZge4LPSNHNqBDpHS3r2EeX5b.jpg'),
(98036, 6956, 'Com a Permissão do Tribunal S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ngQ6jsikCj5e3SqCbjQKMzf5GXP.jpg'),
(98037, 6956, 'Com a Permissão do Tribunal S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sgqGtijKuJ0KRiGTnZhpwM61HyM.jpg'),
(98038, 6956, 'Com a Permissão do Tribunal S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVydmFJrqffdgYwxztoB6FV98LP.jpg'),
(98039, 6957, 'Koibito Miman. S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qK4I9FVl79LESL0gku3t87Qa7y2.jpg'),
(98040, 6957, 'Koibito Miman. S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/CgG5Ki8ssmXhbMOcdoZR5GnXWR.jpg'),
(98041, 6957, 'Koibito Miman. S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dUzocBjNyf5bAGnX4gEtIYwhlZ7.jpg'),
(98042, 6957, 'Koibito Miman. S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cfYxuWA8WUZCnym7AL5SmyixfTu.jpg'),
(98043, 6957, 'Koibito Miman. S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnxiLOjSs0TnjrkDdM89vzwayPY.jpg'),
(98044, 6957, 'Koibito Miman. S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9vZmuconHqz3pdJTynFQszrbBNv.jpg'),
(98045, 6957, 'Koibito Miman. S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jDSPX9Yhy2zz93nS5PB9pmkgLpn.jpg'),
(98046, 6957, 'Koibito Miman. S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ctmjGhf3x3F6U5hVjFG119NvIeC.jpg'),
(98047, 6957, 'Koibito Miman. S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gcjdP9idXqpytrcUSwEX5j9fR1q.jpg'),
(98048, 6957, 'Koibito Miman. S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i1aLfNODPLmac3RGWSmvUXldu4r.jpg'),
(98049, 6957, 'Koibito Miman. S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w1AVJ7pjlfbHVcOVjNc6OOnM2xK.jpg'),
(98050, 6957, 'Koibito Miman. S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bqTckwJsi7HhRtvhBnQk9jH4Jrw.jpg'),
(98051, 6958, 'Guerreiras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gfBMLvJ7nNd30STYUpghCDFUT8J.jpg'),
(98052, 6958, 'Guerreiras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/74zGgFtZ6Va8C3LWKsPJ3D7wqIB.jpg'),
(98053, 6958, 'Guerreiras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2aoLDe4X9RIix5pWHz15ghxSJ7.jpg'),
(98054, 6958, 'Guerreiras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wz2n4LHgiDT54NIvBa0EuB3bs5m.jpg'),
(98055, 6958, 'Guerreiras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pF1TGmLj4nuYtbmOIaXVYMf4lAq.jpg'),
(98056, 6958, 'Guerreiras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rb1833PmgKdHmMxN5AI9qG7ThK3.jpg'),
(98057, 6958, 'Guerreiras S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hOAaXLS2oyGlbwlehZ3JT2UbAme.jpg'),
(98058, 6958, 'Guerreiras S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h3rR2ljbEvWOnpYPsMnkmsr6VOH.jpg'),
(98059, 6959, 'Hillsong: O Escândalo por Trás da Megaigreja S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ruhCTDXUR1r7hVV4z7dkOD0gH8R.jpg'),
(98060, 6959, 'Hillsong: O Escândalo por Trás da Megaigreja S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/krFEMXUYBYw3hyyXTxHcH6bzldl.jpg'),
(98061, 6959, 'Hillsong: O Escândalo por Trás da Megaigreja S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uTJVTb8AWtIjA75wKMi5i8GIIiY.jpg'),
(98062, 6959, 'Hillsong: O Escândalo por Trás da Megaigreja S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nxUZ5NTb3LiDAAvBPLFihWOS8T7.jpg'),
(98063, 6960, 'Ilha das Formas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8PbVHTRZUz186HtRmWldAZTMXu1.jpg'),
(98064, 6960, 'Ilha das Formas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ev4FYPqhpgDs6xnBIn0tv1cS3i8.jpg'),
(98065, 6960, 'Ilha das Formas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6eVfdJFqUeXUGp5gg80Kj5xWYml.jpg'),
(98066, 6960, 'Ilha das Formas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n12cICZ6O8MbhFqB6ddOtYpGVRt.jpg'),
(98067, 6960, 'Ilha das Formas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rG9UjkcqveIattHsidCZUzBz38w.jpg'),
(98068, 6960, 'Ilha das Formas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yk6fm2FEQlG0HzOObwmX8RME4Ge.jpg'),
(98069, 6960, 'Ilha das Formas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xPvmVI5arEhxy56JN4ivAERazpN.jpg'),
(98070, 6960, 'Ilha das Formas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pFZenHqRRTdiUiqeKN8DTnlQxGQ.jpg'),
(98071, 6960, 'Ilha das Formas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/882348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jjKXdP3ZgueaP1sut08GXIPqqCu.jpg'),
(98072, 6960, 'Ilha das Formas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/882349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jjKXdP3ZgueaP1sut08GXIPqqCu.jpg'),
(98073, 6961, 'Ilha das Formas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/882350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jjKXdP3ZgueaP1sut08GXIPqqCu.jpg'),
(98074, 6961, 'Ilha das Formas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/882351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jjKXdP3ZgueaP1sut08GXIPqqCu.jpg'),
(98075, 6961, 'Ilha das Formas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/882352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jjKXdP3ZgueaP1sut08GXIPqqCu.jpg'),
(98076, 6961, 'Ilha das Formas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/882353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jjKXdP3ZgueaP1sut08GXIPqqCu.jpg'),
(98077, 6961, 'Ilha das Formas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/882354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jjKXdP3ZgueaP1sut08GXIPqqCu.jpg'),
(98078, 6961, 'Ilha das Formas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/882355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jjKXdP3ZgueaP1sut08GXIPqqCu.jpg'),
(98079, 6961, 'Ilha das Formas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/882356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jjKXdP3ZgueaP1sut08GXIPqqCu.jpg'),
(98080, 6961, 'Ilha das Formas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/882357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jjKXdP3ZgueaP1sut08GXIPqqCu.jpg'),
(98081, 6962, 'Império da Ostentação: Nova York S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7HXj6KA0XtQn6t7em6LXGIPUpvO.jpg'),
(98082, 6962, 'Império da Ostentação: Nova York S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7HXj6KA0XtQn6t7em6LXGIPUpvO.jpg'),
(98083, 6962, 'Império da Ostentação: Nova York S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7HXj6KA0XtQn6t7em6LXGIPUpvO.jpg'),
(98084, 6962, 'Império da Ostentação: Nova York S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7HXj6KA0XtQn6t7em6LXGIPUpvO.jpg'),
(98085, 6962, 'Império da Ostentação: Nova York S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7HXj6KA0XtQn6t7em6LXGIPUpvO.jpg'),
(98086, 6962, 'Império da Ostentação: Nova York S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7HXj6KA0XtQn6t7em6LXGIPUpvO.jpg'),
(98087, 6962, 'Império da Ostentação: Nova York S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7HXj6KA0XtQn6t7em6LXGIPUpvO.jpg'),
(98088, 6962, 'Império da Ostentação: Nova York S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7HXj6KA0XtQn6t7em6LXGIPUpvO.jpg'),
(98089, 6963, 'Junji Ito: Histórias Macabras do Japão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDcquonO5c8S2g1MXU0qZYfFJoI.jpg'),
(98090, 6963, 'Junji Ito: Histórias Macabras do Japão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eh6P5Rcqofd8pHGYjysetJ15BQH.jpg'),
(98091, 6963, 'Junji Ito: Histórias Macabras do Japão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sIEByndWQecXcGmFMlCsVg1t8Wg.jpg'),
(98092, 6963, 'Junji Ito: Histórias Macabras do Japão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8GH5chw7MfJnR0czKGsWlRve3vp.jpg'),
(98093, 6963, 'Junji Ito: Histórias Macabras do Japão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l7Grpbn9OMTzxVt1K0ySDZGiS8y.jpg'),
(98094, 6963, 'Junji Ito: Histórias Macabras do Japão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kdaqF4oUg6LvYEPQgz8XBEBbZI3.jpg'),
(98095, 6963, 'Junji Ito: Histórias Macabras do Japão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fCNyPbm6mZCVFO5KpeqRyCEA2Zu.jpg'),
(98096, 6963, 'Junji Ito: Histórias Macabras do Japão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dal4HPUPmI2QGCUS2MEMssHyN7Z.jpg'),
(98097, 6963, 'Junji Ito: Histórias Macabras do Japão S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iRIamtAhjV59oHJcWP1imf59l0b.jpg'),
(98098, 6963, 'Junji Ito: Histórias Macabras do Japão S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ZBrUBQjVqCphSDOVYQUUEE5OUr.jpg'),
(98099, 6963, 'Junji Ito: Histórias Macabras do Japão S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ykv0Ou5kGRyCboAg03NHiNtHtkl.jpg'),
(98100, 6963, 'Junji Ito: Histórias Macabras do Japão S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cu6W7TxNeNwfxCv1kIpFPrcCEQ.jpg'),
(98101, 6964, 'Noites de Corrida em Bowman Gray S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4pqj9zRq7T1DX5gaGDVpQFqKwFu.jpg'),
(98102, 6964, 'Noites de Corrida em Bowman Gray S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4pqj9zRq7T1DX5gaGDVpQFqKwFu.jpg'),
(98103, 6964, 'Noites de Corrida em Bowman Gray S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4pqj9zRq7T1DX5gaGDVpQFqKwFu.jpg'),
(98104, 6964, 'Noites de Corrida em Bowman Gray S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4pqj9zRq7T1DX5gaGDVpQFqKwFu.jpg'),
(98105, 6964, 'Noites de Corrida em Bowman Gray S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4pqj9zRq7T1DX5gaGDVpQFqKwFu.jpg'),
(98106, 6964, 'Noites de Corrida em Bowman Gray S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4pqj9zRq7T1DX5gaGDVpQFqKwFu.jpg'),
(98107, 6964, 'Noites de Corrida em Bowman Gray S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4pqj9zRq7T1DX5gaGDVpQFqKwFu.jpg'),
(98108, 6964, 'Noites de Corrida em Bowman Gray S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4pqj9zRq7T1DX5gaGDVpQFqKwFu.jpg'),
(98109, 6965, 'Presidente por Acidente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sudfSFput3crgFDPV2gatuyiM74.jpg'),
(98110, 6965, 'Presidente por Acidente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/L8wSnr5QWV9jX7cdPW3ZfowQgQ.jpg'),
(98111, 6965, 'Presidente por Acidente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2BLO0oB7X4y1FuSadEzAfRyJWc.jpg'),
(98112, 6965, 'Presidente por Acidente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7Uy64svqUt9cKa9SF92fNMqDEc.jpg'),
(98113, 6965, 'Presidente por Acidente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ozaiYpHi83ucJod01isc8E69Qas.jpg'),
(98114, 6965, 'Presidente por Acidente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7kt6MWOozVxI8CBXo1DHE5IgSGF.jpg'),
(98115, 6966, 'Presidente por Acidente S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/443200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctc1hXhtXl986feByqbhBPbPshF.jpg'),
(98116, 6966, 'Presidente por Acidente S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/443201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctc1hXhtXl986feByqbhBPbPshF.jpg'),
(98117, 6966, 'Presidente por Acidente S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/443202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctc1hXhtXl986feByqbhBPbPshF.jpg'),
(98118, 6966, 'Presidente por Acidente S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/443203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctc1hXhtXl986feByqbhBPbPshF.jpg'),
(98119, 6966, 'Presidente por Acidente S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/443204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctc1hXhtXl986feByqbhBPbPshF.jpg'),
(98120, 6966, 'Presidente por Acidente S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctc1hXhtXl986feByqbhBPbPshF.jpg'),
(98121, 6967, 'Santiago dos Mares S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktvIQi6HRLLbCO5GbLUYyaT0w44.jpg'),
(98122, 6967, 'Santiago dos Mares S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktvIQi6HRLLbCO5GbLUYyaT0w44.jpg'),
(98123, 6967, 'Santiago dos Mares S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktvIQi6HRLLbCO5GbLUYyaT0w44.jpg'),
(98124, 6967, 'Santiago dos Mares S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktvIQi6HRLLbCO5GbLUYyaT0w44.jpg'),
(98125, 6967, 'Santiago dos Mares S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktvIQi6HRLLbCO5GbLUYyaT0w44.jpg'),
(98126, 6967, 'Santiago dos Mares S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktvIQi6HRLLbCO5GbLUYyaT0w44.jpg'),
(98127, 6967, 'Santiago dos Mares S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktvIQi6HRLLbCO5GbLUYyaT0w44.jpg'),
(98128, 6967, 'Santiago dos Mares S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktvIQi6HRLLbCO5GbLUYyaT0w44.jpg'),
(98129, 6967, 'Santiago dos Mares S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktvIQi6HRLLbCO5GbLUYyaT0w44.jpg'),
(98130, 6967, 'Santiago dos Mares S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktvIQi6HRLLbCO5GbLUYyaT0w44.jpg'),
(98131, 6967, 'Santiago dos Mares S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktvIQi6HRLLbCO5GbLUYyaT0w44.jpg'),
(98132, 6967, 'Santiago dos Mares S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktvIQi6HRLLbCO5GbLUYyaT0w44.jpg'),
(98133, 6967, 'Santiago dos Mares S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktvIQi6HRLLbCO5GbLUYyaT0w44.jpg'),
(98134, 6967, 'Santiago dos Mares S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/205189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktvIQi6HRLLbCO5GbLUYyaT0w44.jpg'),
(98135, 6967, 'Santiago dos Mares S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/205190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktvIQi6HRLLbCO5GbLUYyaT0w44.jpg'),
(98136, 6967, 'Santiago dos Mares S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/205191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktvIQi6HRLLbCO5GbLUYyaT0w44.jpg'),
(98137, 6967, 'Santiago dos Mares S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/205192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktvIQi6HRLLbCO5GbLUYyaT0w44.jpg'),
(98138, 6967, 'Santiago dos Mares S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/205193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktvIQi6HRLLbCO5GbLUYyaT0w44.jpg'),
(98139, 6967, 'Santiago dos Mares S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/205194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktvIQi6HRLLbCO5GbLUYyaT0w44.jpg'),
(98140, 6967, 'Santiago dos Mares S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/205195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktvIQi6HRLLbCO5GbLUYyaT0w44.jpg'),
(98141, 6968, 'Shinobi no Ittoki S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7OCsKy54TuZo3HuEZViwhOZ4niA.jpg'),
(98142, 6968, 'Shinobi no Ittoki S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/XKJh3g7QkJW6ItBmbydDXFyeP1.jpg'),
(98143, 6968, 'Shinobi no Ittoki S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6dwrUsFBqihV9KI1yEBcBIr2Lpt.jpg'),
(98144, 6968, 'Shinobi no Ittoki S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/soZtWXrJvcxFJ0jbKc1wL13N8EJ.jpg'),
(98145, 6968, 'Shinobi no Ittoki S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xE1V8L2d3YXz1rKxLxURVjusytP.jpg'),
(98146, 6968, 'Shinobi no Ittoki S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/O0cE9aqxzfjXygib5PmTDrBR7m.jpg'),
(98147, 6968, 'Shinobi no Ittoki S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/viEuU7CPgYNlRdThPEKUnfzj8Py.jpg'),
(98148, 6968, 'Shinobi no Ittoki S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qM6uGyvF5EQHxqhKiKIQjcPTwMo.jpg'),
(98149, 6968, 'Shinobi no Ittoki S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tDlpHTNau5mp5EWw8jzqAdheRJo.jpg'),
(98150, 6968, 'Shinobi no Ittoki S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lXnaM6JwI8dyrVmNq6Q0NVgSMJ9.jpg'),
(98151, 6968, 'Shinobi no Ittoki S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Lt5Hg9KXi0fgbdnTTE9DPs3Z2A.jpg'),
(98152, 6968, 'Shinobi no Ittoki S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Sdf3kMiZjgBdxnyxMnrMk23U64.jpg'),
(98153, 6969, 'That 90s Show S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9k8bIMWel1gQbwlRSEKnEqXYTvG.jpg'),
(98154, 6969, 'That 90s Show S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f8FBGRn3yTltQNPIPHrlWPooVPV.jpg'),
(98155, 6969, 'That 90s Show S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cFpv3XzTaPdfT8wibmUG53vcwUf.jpg'),
(98156, 6969, 'That 90s Show S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3hPFKjFWrfIecFzqb77XsT8K8RQ.jpg'),
(98157, 6969, 'That 90s Show S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3iNkz3SKv1ldm1aYbUOXHs1M4Kk.jpg'),
(98158, 6969, 'That 90s Show S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9gv8IwU1FThcsCWBe6i4LahT2rr.jpg'),
(98159, 6969, 'That 90s Show S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hhPSMy10Cg8gagf9X9cTxsF8Pjm.jpg'),
(98160, 6969, 'That 90s Show S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5QPMOZoLciIlp36yu3ChHT2TV7r.jpg'),
(98161, 6969, 'That 90s Show S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tQ1JhZnI1V38sjf4DruUIz9nmus.jpg'),
(98162, 6969, 'That 90s Show S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zMuXHxK0ziC3MPJaJkQCz8jtj69.jpg'),
(98163, 6970, 'That 90s Show S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/394092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nZcufEuqZqNYMx6mNjlh2rmjDqx.jpg'),
(98164, 6970, 'That 90s Show S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/394093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nZcufEuqZqNYMx6mNjlh2rmjDqx.jpg'),
(98165, 6970, 'That 90s Show S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/394094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nZcufEuqZqNYMx6mNjlh2rmjDqx.jpg'),
(98166, 6970, 'That 90s Show S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/394095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nZcufEuqZqNYMx6mNjlh2rmjDqx.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(98167, 6970, 'That 90s Show S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/394096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nZcufEuqZqNYMx6mNjlh2rmjDqx.jpg'),
(98168, 6970, 'That 90s Show S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/394097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nZcufEuqZqNYMx6mNjlh2rmjDqx.jpg'),
(98169, 6970, 'That 90s Show S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/394098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nZcufEuqZqNYMx6mNjlh2rmjDqx.jpg'),
(98170, 6970, 'That 90s Show S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/394099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nZcufEuqZqNYMx6mNjlh2rmjDqx.jpg'),
(98171, 6971, 'That 90s Show S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nZcufEuqZqNYMx6mNjlh2rmjDqx.jpg'),
(98172, 6971, 'That 90s Show S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nZcufEuqZqNYMx6mNjlh2rmjDqx.jpg'),
(98173, 6971, 'That 90s Show S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nZcufEuqZqNYMx6mNjlh2rmjDqx.jpg'),
(98174, 6971, 'That 90s Show S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nZcufEuqZqNYMx6mNjlh2rmjDqx.jpg'),
(98175, 6971, 'That 90s Show S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nZcufEuqZqNYMx6mNjlh2rmjDqx.jpg'),
(98176, 6971, 'That 90s Show S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nZcufEuqZqNYMx6mNjlh2rmjDqx.jpg'),
(98177, 6971, 'That 90s Show S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/438646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nZcufEuqZqNYMx6mNjlh2rmjDqx.jpg'),
(98178, 6971, 'That 90s Show S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/438647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nZcufEuqZqNYMx6mNjlh2rmjDqx.jpg'),
(98179, 6972, 'Uzaki-chan wa Asobitai! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1oQitjNTLrq8WtkLFotbrWZsClI.jpg'),
(98180, 6972, 'Uzaki-chan wa Asobitai! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Z6vpM5cqpP5dEL2F7T9aIOxhM6.jpg'),
(98181, 6972, 'Uzaki-chan wa Asobitai! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4gGkRbNIcdqEkcboTbxKSLcb7o7.jpg'),
(98182, 6972, 'Uzaki-chan wa Asobitai! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xRgrU15AskPJCn2lGMz5LamrbEW.jpg'),
(98183, 6972, 'Uzaki-chan wa Asobitai! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fyTwhDaxJSA3XlyqMFoaT2kRz0U.jpg'),
(98184, 6972, 'Uzaki-chan wa Asobitai! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6EMrWT6TfJiBJAXgu92S5XWT1AM.jpg'),
(98185, 6972, 'Uzaki-chan wa Asobitai! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sqDzsN8GhNxw4Uy9TnK5Gqfmjsl.jpg'),
(98186, 6972, 'Uzaki-chan wa Asobitai! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A9Ux2Ml4GM5roQT7tE7dpZJb24F.jpg'),
(98187, 6972, 'Uzaki-chan wa Asobitai! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fJcANlCKxUIEYI0WF64pRQX5xKc.jpg'),
(98188, 6972, 'Uzaki-chan wa Asobitai! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jVLeFwELHgkpLEssh4wMG4qWhhs.jpg'),
(98189, 6972, 'Uzaki-chan wa Asobitai! S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w5ge6cSuAtNH4PWVjtmCaxA0YTu.jpg'),
(98190, 6972, 'Uzaki-chan wa Asobitai! S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/53hcuFKcxjjVBTfAUUhMk7Zl36l.jpg'),
(98191, 6973, 'Uzaki-chan wa Asobitai! S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eFxeXlXfo32M8QqvacjcL8cMxO3.jpg'),
(98192, 6973, 'Uzaki-chan wa Asobitai! S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ialUvfyhR0cxbG4BxVvUmaRzpgO.jpg'),
(98193, 6973, 'Uzaki-chan wa Asobitai! S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yOtmn9940ygiK2zp45ziHGvUSAN.jpg'),
(98194, 6973, 'Uzaki-chan wa Asobitai! S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4pxAc1FcO8KlH2l5TwLkNZkdOMO.jpg'),
(98195, 6973, 'Uzaki-chan wa Asobitai! S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rHG9zhRhpa3NZgvJodmGC78Khiq.jpg'),
(98196, 6973, 'Uzaki-chan wa Asobitai! S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qnMuM6ODCfVaSe4JqzwNPpcjVhi.jpg'),
(98197, 6973, 'Uzaki-chan wa Asobitai! S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cf3rG35I4TlJNhT0kQisNAtMEAR.jpg'),
(98198, 6973, 'Uzaki-chan wa Asobitai! S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QAEUl624SV6EzdfpXinaK1Tw9Y.jpg'),
(98199, 6973, 'Uzaki-chan wa Asobitai! S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k8DSlT4b4I2ZkZxFHkPR34GwbnM.jpg'),
(98200, 6973, 'Uzaki-chan wa Asobitai! S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hwC81Fip2A5RbL5CWo20Azo1fEN.jpg'),
(98201, 6973, 'Uzaki-chan wa Asobitai! S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5UwTjTZ4O36oCvI6blG2TbTDYRu.jpg'),
(98202, 6973, 'Uzaki-chan wa Asobitai! S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7tcSbHNibrBiCdUnvLSXdbW8Juq.jpg'),
(98203, 6973, 'Uzaki-chan wa Asobitai! S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nVgzpXG4pspo8148tdAA6PaaeGr.jpg'),
(98204, 6974, 'A Lei e o Crime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2gslCIRbRC8wq5pnHzLWtqeubS.jpg'),
(98205, 6974, 'A Lei e o Crime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2gslCIRbRC8wq5pnHzLWtqeubS.jpg'),
(98206, 6974, 'A Lei e o Crime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2gslCIRbRC8wq5pnHzLWtqeubS.jpg'),
(98207, 6974, 'A Lei e o Crime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2gslCIRbRC8wq5pnHzLWtqeubS.jpg'),
(98208, 6974, 'A Lei e o Crime S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2gslCIRbRC8wq5pnHzLWtqeubS.jpg'),
(98209, 6974, 'A Lei e o Crime S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2gslCIRbRC8wq5pnHzLWtqeubS.jpg'),
(98210, 6974, 'A Lei e o Crime S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2gslCIRbRC8wq5pnHzLWtqeubS.jpg'),
(98211, 6974, 'A Lei e o Crime S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2gslCIRbRC8wq5pnHzLWtqeubS.jpg'),
(98212, 6974, 'A Lei e o Crime S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2gslCIRbRC8wq5pnHzLWtqeubS.jpg'),
(98213, 6974, 'A Lei e o Crime S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2gslCIRbRC8wq5pnHzLWtqeubS.jpg'),
(98214, 6974, 'A Lei e o Crime S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2gslCIRbRC8wq5pnHzLWtqeubS.jpg'),
(98215, 6974, 'A Lei e o Crime S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2gslCIRbRC8wq5pnHzLWtqeubS.jpg'),
(98216, 6974, 'A Lei e o Crime S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2gslCIRbRC8wq5pnHzLWtqeubS.jpg'),
(98217, 6974, 'A Lei e o Crime S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/205094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2gslCIRbRC8wq5pnHzLWtqeubS.jpg'),
(98218, 6974, 'A Lei e o Crime S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/205095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2gslCIRbRC8wq5pnHzLWtqeubS.jpg'),
(98219, 6974, 'A Lei e o Crime S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/205096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2gslCIRbRC8wq5pnHzLWtqeubS.jpg'),
(98220, 6974, 'A Lei e o Crime S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/205097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2gslCIRbRC8wq5pnHzLWtqeubS.jpg'),
(98221, 6974, 'A Lei e o Crime S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/205098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2gslCIRbRC8wq5pnHzLWtqeubS.jpg'),
(98222, 6974, 'A Lei e o Crime S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/205099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2gslCIRbRC8wq5pnHzLWtqeubS.jpg'),
(98223, 6974, 'A Lei e o Crime S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/205100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2gslCIRbRC8wq5pnHzLWtqeubS.jpg'),
(98224, 6974, 'A Lei e o Crime S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/205101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2gslCIRbRC8wq5pnHzLWtqeubS.jpg'),
(98225, 6975, 'Como Funciona o Universo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AjpAW65sgBpQK1fGfiS4MCmnjGY.jpg'),
(98226, 6975, 'Como Funciona o Universo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iAudzTxE1WMzfMmaG5vYTchdhkd.jpg'),
(98227, 6975, 'Como Funciona o Universo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5glr1kcbF8BmSqLXqAJmyeUSG1p.jpg'),
(98228, 6975, 'Como Funciona o Universo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aWFWvJrRwc2NbwTtoHcNmPxf63B.jpg'),
(98229, 6975, 'Como Funciona o Universo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9sk3fopdC7qKgzMT0bGbp79hTie.jpg'),
(98230, 6975, 'Como Funciona o Universo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mm7loEzEsSRVx3s8WWtsBkQJs0Z.jpg'),
(98231, 6975, 'Como Funciona o Universo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vfha5hZDkBw0hvnEMFHTd9bY647.jpg'),
(98232, 6975, 'Como Funciona o Universo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1UEGr1qIdehxYdVqARtmDWLZOnu.jpg'),
(98233, 6976, 'Como Funciona o Universo S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fxzA3KHl7YN2d0z32TorrXpTrfl.jpg'),
(98234, 6976, 'Como Funciona o Universo S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xu7uWujoJFrXxOOhYLLbSl4opQQ.jpg'),
(98235, 6976, 'Como Funciona o Universo S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4tob6fHcrZYgsSCC4zTxBeLbVVY.jpg'),
(98236, 6976, 'Como Funciona o Universo S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9YuQ4MVdtKbqzI2ZMtEHRHWcy8.jpg'),
(98237, 6976, 'Como Funciona o Universo S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ne15VGRuXVcQKA9pY4Z6sdzRry.jpg'),
(98238, 6976, 'Como Funciona o Universo S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgnuiJvjk1EgsPw7E3TGCVzW3Le.jpg'),
(98239, 6976, 'Como Funciona o Universo S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4r77DMObKsI2Ig3WJREFqr3t3pC.jpg'),
(98240, 6976, 'Como Funciona o Universo S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZiQ5dlGkPItJyDunk6qd3HSXIt.jpg'),
(98241, 6977, 'Como Funciona o Universo S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e24YuuiTkUa6C6NSLAxnJQ4SuvK.jpg'),
(98242, 6977, 'Como Funciona o Universo S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jlMUMol2sh1zwGJyUBhrQdtiaeD.jpg'),
(98243, 6977, 'Como Funciona o Universo S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9k8ZKE8lCTj4iFkpcUVtfgIQpDy.jpg'),
(98244, 6977, 'Como Funciona o Universo S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/90jaXeWGiHspmozsS8uDSCcJzPs.jpg'),
(98245, 6977, 'Como Funciona o Universo S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e5LiluR3FLIi5Ra9wihg9CvluCe.jpg'),
(98246, 6977, 'Como Funciona o Universo S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sTjbmbsRorlAbgx75Q08hufcl1W.jpg'),
(98247, 6977, 'Como Funciona o Universo S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nZYCdZbFvMHuRFJ19RBeMWymvpb.jpg'),
(98248, 6977, 'Como Funciona o Universo S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Asc0VbWwxGYv7kqbSGajssR2fKL.jpg'),
(98249, 6978, 'Como Funciona o Universo S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kH9UBi1kWJj3txfGhOCWf2cq14.jpg'),
(98250, 6978, 'Como Funciona o Universo S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3FTYQDPqG1iiTewdNwU81Yt8s5r.jpg'),
(98251, 6978, 'Como Funciona o Universo S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9FNgnhf9CbnvQXP86u1vKdg44Rg.jpg'),
(98252, 6978, 'Como Funciona o Universo S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1182Lv7nx1iCTgvbAIBKCpBwOrD.jpg'),
(98253, 6978, 'Como Funciona o Universo S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fV2AnG6KBGdUVoQYgbltUrLDcXp.jpg'),
(98254, 6978, 'Como Funciona o Universo S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rt99SwAYpQaROB2L1BJbVOGf3Um.jpg'),
(98255, 6979, 'Drop Dead Diva: Sob Medida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jMj2y1CxA6SCrnmW5CsyxD6OQtX.jpg'),
(98256, 6979, 'Drop Dead Diva: Sob Medida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eE1akYwc0VAkxTjwMSOeImaHUDb.jpg'),
(98257, 6979, 'Drop Dead Diva: Sob Medida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e20XxRknscZSXLf8hRpvvftxw1v.jpg'),
(98258, 6979, 'Drop Dead Diva: Sob Medida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gNnldf1yg5Ek0VhaoU3mxj8XhpG.jpg'),
(98259, 6979, 'Drop Dead Diva: Sob Medida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0UyauTuRfmgHslHpiNIXU038Cn.jpg'),
(98260, 6979, 'Drop Dead Diva: Sob Medida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j77ZmVhAxuRgmgnBP4cNdkXzh5c.jpg'),
(98261, 6979, 'Drop Dead Diva: Sob Medida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybQUAykiCzSlTjwaGaFqpOm3obw.jpg'),
(98262, 6979, 'Drop Dead Diva: Sob Medida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g0twis0ikchwy556x5hzBXiNt9X.jpg'),
(98263, 6979, 'Drop Dead Diva: Sob Medida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kysvm5TRb1JO6zVHyhnpqx0no79.jpg'),
(98264, 6979, 'Drop Dead Diva: Sob Medida S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ilZroSChPZz4Iur5PxQAX4Aonn7.jpg'),
(98265, 6979, 'Drop Dead Diva: Sob Medida S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3SKGxSsgzJvVz7VRjNySmg70gLM.jpg'),
(98266, 6979, 'Drop Dead Diva: Sob Medida S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h2Qf0aMUW0uyQkIZ3WB0E3MwTDL.jpg'),
(98267, 6979, 'Drop Dead Diva: Sob Medida S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fv06HH3j4VFW4mxIy02c5QSTUIu.jpg'),
(98268, 6980, 'Drop Dead Diva: Sob Medida S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mBsWoyGSJWr0PHFAHYHaMMcZUpw.jpg'),
(98269, 6980, 'Drop Dead Diva: Sob Medida S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kpHjR1kfgjbwLkjxBYPh7MJGbyO.jpg'),
(98270, 6980, 'Drop Dead Diva: Sob Medida S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u1TjjLWDik2LLPNfcRNhCPzO7Ic.jpg'),
(98271, 6980, 'Drop Dead Diva: Sob Medida S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cXnYICwYQPWua4nrQOhK6WhEwiq.jpg'),
(98272, 6980, 'Drop Dead Diva: Sob Medida S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cSmwO2AHCesSq4aW0N9RwLxbpYt.jpg'),
(98273, 6980, 'Drop Dead Diva: Sob Medida S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i7182gAp5yFiClixLmYii9qpHu.jpg'),
(98274, 6980, 'Drop Dead Diva: Sob Medida S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oyHGvc2nzpyx6sJXyilEx7mHRPu.jpg'),
(98275, 6980, 'Drop Dead Diva: Sob Medida S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7ICOf4crHTd84yyj9KSwKCpnSY.jpg'),
(98276, 6980, 'Drop Dead Diva: Sob Medida S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1kLIZAMmQsimxVLLvRKJDRwqOJW.jpg'),
(98277, 6980, 'Drop Dead Diva: Sob Medida S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZScn19YwKImG8k75ZnUw72AJLQ.jpg'),
(98278, 6980, 'Drop Dead Diva: Sob Medida S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oETGrve9Zji8Cj4T2X1EbdrONTm.jpg'),
(98279, 6980, 'Drop Dead Diva: Sob Medida S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8MAlr8paOYmhs4inLLTUoRbZqZ8.jpg'),
(98280, 6980, 'Drop Dead Diva: Sob Medida S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5y4ORf1QHHv8jw3eSifrpyEqxk7.jpg'),
(98281, 6981, 'Drop Dead Diva: Sob Medida S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vkl6eIocZzxtAEReei33CDd8fRq.jpg'),
(98282, 6981, 'Drop Dead Diva: Sob Medida S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tvv6TIBltX17xslkaLGZzkKmBRo.jpg'),
(98283, 6981, 'Drop Dead Diva: Sob Medida S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/MdnchFh3NvCTK3SoYNE0WGPlb3.jpg'),
(98284, 6981, 'Drop Dead Diva: Sob Medida S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rvohGALIAfa2T3z0irq6PHhtMk1.jpg'),
(98285, 6981, 'Drop Dead Diva: Sob Medida S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3ZZlBkZBij93nCQrU4RPCg8PBh.jpg'),
(98286, 6981, 'Drop Dead Diva: Sob Medida S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wT92hcJhz1KoxUfdKM1X8i0uHpi.jpg'),
(98287, 6981, 'Drop Dead Diva: Sob Medida S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ta0BLfY2zzsbWJLRNLdUDCtmseF.jpg'),
(98288, 6981, 'Drop Dead Diva: Sob Medida S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lPF0AI000MpTUBLwd86BUDO57Ef.jpg'),
(98289, 6981, 'Drop Dead Diva: Sob Medida S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uK7Nq5YpbYkkIwApHuY3GCP416p.jpg'),
(98290, 6981, 'Drop Dead Diva: Sob Medida S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTWBJQ8TfEsKPBVrM0gssKGWtXQ.jpg'),
(98291, 6981, 'Drop Dead Diva: Sob Medida S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJwbdbqEjWxiDWmrGPBo4fU2Cjm.jpg'),
(98292, 6981, 'Drop Dead Diva: Sob Medida S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6PC6YmnM4a4w5TuetobD0vffddL.jpg'),
(98293, 6981, 'Drop Dead Diva: Sob Medida S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lmuXk9DHue5qpgvqcqR3aDVMM6.jpg'),
(98294, 6982, 'Drop Dead Diva: Sob Medida S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t2QcbzpjLIzyhvAG4K56euGvaOe.jpg'),
(98295, 6982, 'Drop Dead Diva: Sob Medida S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a0D1thQ60sBFwZ2JAJ2VTUwEKHq.jpg'),
(98296, 6982, 'Drop Dead Diva: Sob Medida S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tgHc0wU2AIlzUGht4qpGZwU94CX.jpg'),
(98297, 6982, 'Drop Dead Diva: Sob Medida S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/54gYyLYFLjiZanUJxzYkAzE1UHY.jpg'),
(98298, 6982, 'Drop Dead Diva: Sob Medida S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vEgMPJGAGM75ZPbJHIeazRS5Wry.jpg'),
(98299, 6982, 'Drop Dead Diva: Sob Medida S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xwzbr0rnvwvvhJaAKtlFvMbptEL.jpg'),
(98300, 6982, 'Drop Dead Diva: Sob Medida S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rvMMYWV5jjXj7qZr4F9cvl1FtC.jpg'),
(98301, 6982, 'Drop Dead Diva: Sob Medida S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7I76Y4yXq9aD5qyusUeHuNPy2v4.jpg'),
(98302, 6982, 'Drop Dead Diva: Sob Medida S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qftFLJUShJgk4c5w3DI0v6bvhbT.jpg'),
(98303, 6982, 'Drop Dead Diva: Sob Medida S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nrEYGiXnxxuZIz3p9SAWpMj9Ghb.jpg'),
(98304, 6982, 'Drop Dead Diva: Sob Medida S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/132Gzyw5PCa9CTNCOlg3qFmuO1O.jpg'),
(98305, 6982, 'Drop Dead Diva: Sob Medida S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97OBNJZdCcVT38YwBwe789nXOag.jpg'),
(98306, 6982, 'Drop Dead Diva: Sob Medida S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lsDW6Fvw6q1AVxN7RISt6gYKuUV.jpg'),
(98307, 6983, 'Drop Dead Diva: Sob Medida S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3AQeFwhTMIJDsZ23DLBkmcRgf8T.jpg'),
(98308, 6983, 'Drop Dead Diva: Sob Medida S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/itNmCTqD2OJ8sMFOlPZ0pQSpVXJ.jpg'),
(98309, 6983, 'Drop Dead Diva: Sob Medida S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sD2IhGgnLScJjJiVgis38QKiymo.jpg'),
(98310, 6983, 'Drop Dead Diva: Sob Medida S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h5t7k24rXjw50afeonMiVduxJMF.jpg'),
(98311, 6983, 'Drop Dead Diva: Sob Medida S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mEZrZMJ5GfuS3ZdA5qqiLDbMP51.jpg'),
(98312, 6983, 'Drop Dead Diva: Sob Medida S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwBo4wrSlijZqTcGJTZeERCg6GP.jpg'),
(98313, 6983, 'Drop Dead Diva: Sob Medida S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/112f49TpnwYcKdoF51xGZtKRXjx.jpg'),
(98314, 6983, 'Drop Dead Diva: Sob Medida S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iqYmrv5qPcYNMaB5OPY4jnCgWlP.jpg'),
(98315, 6983, 'Drop Dead Diva: Sob Medida S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ceIe6AOAJiJTKbcTv0CRuQw1KE1.jpg'),
(98316, 6983, 'Drop Dead Diva: Sob Medida S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x8EYYzFOArBUxXJQboh7qg9njbd.jpg'),
(98317, 6983, 'Drop Dead Diva: Sob Medida S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8wcldvjUkZ9XSkuRWwvm5fxtpQl.jpg'),
(98318, 6983, 'Drop Dead Diva: Sob Medida S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mVROdhHtpU9hF8xc52XDGQE0r0T.jpg'),
(98319, 6983, 'Drop Dead Diva: Sob Medida S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1BRe0usunqZWPsNnjVEg9dF8XfH.jpg'),
(98320, 6984, 'Drop Dead Diva: Sob Medida S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7JjuXrOZCiyAI2nYvtfYS4VjrlV.jpg'),
(98321, 6984, 'Drop Dead Diva: Sob Medida S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vTfaPZNkwlcSZRjdnctUBiFr55u.jpg'),
(98322, 6984, 'Drop Dead Diva: Sob Medida S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pEbrwf0MDBb5J1NVHWZTzF8ALS8.jpg'),
(98323, 6984, 'Drop Dead Diva: Sob Medida S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ub4Uf4nj25YguOjLMQlH5dxLLTv.jpg'),
(98324, 6984, 'Drop Dead Diva: Sob Medida S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ol3yJEbUDZyGZ9OFDAnmsJI2dwi.jpg'),
(98325, 6984, 'Drop Dead Diva: Sob Medida S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/205073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ukG5Th56Qe6knEQVRF7IPumbRUe.jpg'),
(98326, 6984, 'Drop Dead Diva: Sob Medida S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/205074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f8ZSi5OXQI9LlMVFwMczLBzVWdY.jpg'),
(98327, 6984, 'Drop Dead Diva: Sob Medida S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/205075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/liTojp4Bpe24T4XITSuhebsdH61.jpg'),
(98328, 6984, 'Drop Dead Diva: Sob Medida S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/205076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vuSKtwPPktBSLFR0WjEukkfXu7b.jpg'),
(98329, 6984, 'Drop Dead Diva: Sob Medida S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/205077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/joOG5GLM1Mu6H3wam5KEMUD2GyL.jpg'),
(98330, 6984, 'Drop Dead Diva: Sob Medida S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/205078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l8mBeubxTdKR2YX0oQxvu9MvBM9.jpg'),
(98331, 6984, 'Drop Dead Diva: Sob Medida S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/205079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8AWX6t9p9oOr7Ez1bz42Ffx9rIJ.jpg'),
(98332, 6984, 'Drop Dead Diva: Sob Medida S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/205080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/neULfRoJVcjZjJX664gct4Gymhp.jpg'),
(98333, 6985, 'Shurato S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/30TokDC9rKNs4WYNqQ9wclipDkB.jpg'),
(98334, 6985, 'Shurato S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98335, 6985, 'Shurato S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98336, 6985, 'Shurato S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98337, 6985, 'Shurato S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98338, 6985, 'Shurato S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98339, 6985, 'Shurato S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98340, 6985, 'Shurato S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98341, 6985, 'Shurato S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98342, 6985, 'Shurato S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98343, 6985, 'Shurato S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98344, 6985, 'Shurato S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98345, 6985, 'Shurato S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98346, 6985, 'Shurato S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/204923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98347, 6985, 'Shurato S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/204924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98348, 6985, 'Shurato S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/204925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98349, 6985, 'Shurato S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/204926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98350, 6985, 'Shurato S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/204927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98351, 6985, 'Shurato S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/204928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98352, 6985, 'Shurato S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/204929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98353, 6985, 'Shurato S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/204930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98354, 6985, 'Shurato S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/204931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98355, 6985, 'Shurato S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/204932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98356, 6985, 'Shurato S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/204933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98357, 6985, 'Shurato S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/204934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98358, 6985, 'Shurato S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/204935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98359, 6985, 'Shurato S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/204936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98360, 6985, 'Shurato S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/204937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98361, 6985, 'Shurato S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/204938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98362, 6985, 'Shurato S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/204939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98363, 6985, 'Shurato S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/204940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98364, 6985, 'Shurato S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/204941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98365, 6985, 'Shurato S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/204942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98366, 6985, 'Shurato S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/204943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98367, 6985, 'Shurato S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/204944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98368, 6985, 'Shurato S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/204945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98369, 6985, 'Shurato S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/204946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98370, 6985, 'Shurato S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/204947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3BBGIYANf47wORfjbXzazKYGX6.jpg'),
(98371, 6986, 'Boate Kiss: A Tragédia de Santa Maria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dqg3VibnorhMPDDIIVEkFE2DhV6.jpg'),
(98372, 6986, 'Boate Kiss: A Tragédia de Santa Maria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dqg3VibnorhMPDDIIVEkFE2DhV6.jpg'),
(98373, 6986, 'Boate Kiss: A Tragédia de Santa Maria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dqg3VibnorhMPDDIIVEkFE2DhV6.jpg'),
(98374, 6986, 'Boate Kiss: A Tragédia de Santa Maria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dqg3VibnorhMPDDIIVEkFE2DhV6.jpg'),
(98375, 6986, 'Boate Kiss: A Tragédia de Santa Maria S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dqg3VibnorhMPDDIIVEkFE2DhV6.jpg'),
(98376, 6987, 'Todo Dia a Mesma Noite S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/seCcZIO2CJZkt6WMSwoy5mPQd2p.jpg'),
(98377, 6987, 'Todo Dia a Mesma Noite S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gKvLK4WGMbm1gFxq8UfbfMc5P28.jpg'),
(98378, 6987, 'Todo Dia a Mesma Noite S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Fu4TC6VEA9FH0l3WgZ5KQoeyDB.jpg'),
(98379, 6987, 'Todo Dia a Mesma Noite S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cTKsxW8bPnjy0a6FdeX8PDZygZ2.jpg'),
(98380, 6987, 'Todo Dia a Mesma Noite S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A6Rf5EjSzH2IiHdCvnPewN4udXs.jpg'),
(98381, 6988, 'A Garota na Fita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZbskseUjDyWqnBDMQKp9oSNJpk.jpg'),
(98382, 6988, 'A Garota na Fita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q1GKW7hIr9MLX9BoZpGjUQARhM9.jpg'),
(98383, 6988, 'A Garota na Fita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Rz0luvmWZNMiw7KomgqCDqXriT.jpg'),
(98384, 6988, 'A Garota na Fita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uzyB3ntTPQ50gTUK1o8HWQMDRaJ.jpg'),
(98385, 6988, 'A Garota na Fita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1uhfMznBmD2ZWjVmhPdxH07uXyd.jpg'),
(98386, 6988, 'A Garota na Fita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6hnRxZ16QUp25HqikiLpX7OLzxs.jpg'),
(98387, 6989, 'A Garota na Fita S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/681150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nD5QFEJspTGB3aiuQ2e1LmEK09x.jpg'),
(98388, 6989, 'A Garota na Fita S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/681151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nD5QFEJspTGB3aiuQ2e1LmEK09x.jpg'),
(98389, 6989, 'A Garota na Fita S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/681152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nD5QFEJspTGB3aiuQ2e1LmEK09x.jpg'),
(98390, 6989, 'A Garota na Fita S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/681153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nD5QFEJspTGB3aiuQ2e1LmEK09x.jpg'),
(98391, 6989, 'A Garota na Fita S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/681154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nD5QFEJspTGB3aiuQ2e1LmEK09x.jpg'),
(98392, 6989, 'A Garota na Fita S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/681155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nD5QFEJspTGB3aiuQ2e1LmEK09x.jpg'),
(98393, 6990, 'A Incrível Vida dos Nossos Bichinhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j0ANI3DDJVQoL7ZubTzKTwS0gCQ.jpg'),
(98394, 6990, 'A Incrível Vida dos Nossos Bichinhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4p4O3DDEyapqbtME3Shqd0xBU7j.jpg'),
(98395, 6990, 'A Incrível Vida dos Nossos Bichinhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gM9Fom2ezbvH3tK7SjPqb3gpRWw.jpg'),
(98396, 6990, 'A Incrível Vida dos Nossos Bichinhos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kswkMJsPmE6INPHT3v4PKOl6gEC.jpg'),
(98397, 6991, 'A Nova Vida de Toby S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dyQL1ZMlOxan7lhMtrKunWazjvz.jpg'),
(98398, 6991, 'A Nova Vida de Toby S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rTzEo6TNm6Dd3irIfYFPnHaMUPf.jpg'),
(98399, 6991, 'A Nova Vida de Toby S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/flWqUbWJyBs6ft6SJAoGDkVmp7C.jpg'),
(98400, 6991, 'A Nova Vida de Toby S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nsw3xl3hCURNp01aPt6y9keq7n2.jpg'),
(98401, 6991, 'A Nova Vida de Toby S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7SXwWWYxyKuTaaZuYVkk1sJ3c04.jpg'),
(98402, 6991, 'A Nova Vida de Toby S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207297.mp4', 'http://image.tmdb.org/t/p/w1280/vfw833Bsrpvpwflj20Dn52PdgT0.jpg'),
(98403, 6991, 'A Nova Vida de Toby S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207298.mp4', 'http://image.tmdb.org/t/p/w1280/eXKPII6EdvVpWxr1OwPHfpSZxpz.jpg'),
(98404, 6991, 'A Nova Vida de Toby S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207299.mp4', 'http://image.tmdb.org/t/p/w1280/eTQxTDKzHfv4dwKOKo66tjcTNnV.jpg'),
(98405, 6992, 'Cozinha Selvagem: O Duelo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p4xi3try65MTgua5tlF12ebwZe1.jpg'),
(98406, 6992, 'Cozinha Selvagem: O Duelo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6bLUAh3RHfmeuV7TdyhDWhyhy4U.jpg'),
(98407, 6992, 'Cozinha Selvagem: O Duelo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wYUevLQ8BYfMpPQ8cOPQsOUXAIw.jpg'),
(98408, 6992, 'Cozinha Selvagem: O Duelo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ctEbBRPPA2Ii630qocKQTsPaOT5.jpg'),
(98409, 6992, 'Cozinha Selvagem: O Duelo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9yl2xGf7NhkG6xKFbnYlLnLqGr.jpg'),
(98410, 6992, 'Cozinha Selvagem: O Duelo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZPACPJIU3biyvmOAUNDOxBIBFv.jpg'),
(98411, 6992, 'Cozinha Selvagem: O Duelo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xU2OCRA1Fz9IQ01ARRTPVcNnBKF.jpg'),
(98412, 6992, 'Cozinha Selvagem: O Duelo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zC8whdn8HZrcXvwDzO0WBZ6bvJd.jpg'),
(98413, 6993, 'Desejo de Vingança S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vffZG6qJq2q841rGWlW16rBgjz3.jpg'),
(98414, 6993, 'Desejo de Vingança S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4o1vEmgP31cidbGShZQW6P7eEBb.jpg'),
(98415, 6993, 'Desejo de Vingança S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3cjlBihzs5vi3PxAgcsi3v2ApQR.jpg'),
(98416, 6993, 'Desejo de Vingança S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/llf3KBOZBO0kjFP3fgcpYd79hSA.jpg'),
(98417, 6993, 'Desejo de Vingança S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cTpnBlMJrF6DsDMWgrFsgMRVXm7.jpg'),
(98418, 6993, 'Desejo de Vingança S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fjIAluKGJ4CjoE2De0Yk6W4pPbQ.jpg'),
(98419, 6993, 'Desejo de Vingança S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8CuSBjEPSFyF3hUKIBVhOGzyQt1.jpg'),
(98420, 6993, 'Desejo de Vingança S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gDhljXLR0iyybyQgrlpZInlKauJ.jpg'),
(98421, 6994, 'Extraordinária S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2m7S4Q3kc46GxpOsH5fWuFQ5gXe.jpg'),
(98422, 6994, 'Extraordinária S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uCwLQNTizbJizBKYcJ5FfyPTeHi.jpg'),
(98423, 6994, 'Extraordinária S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uD6mZLqOsp4Ha5n9GL1NTacIkP7.jpg'),
(98424, 6994, 'Extraordinária S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ttEVjS78yFdH8eeosaku3HrK0V.jpg'),
(98425, 6994, 'Extraordinária S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/17KLoVEXLua2nMhyPGMgsMbLzfR.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(98426, 6994, 'Extraordinária S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/92jwGmpa1K6TWHo8KwCcCc12u0L.jpg'),
(98427, 6994, 'Extraordinária S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ljPgPDdv3dZSkhprRCyki3VY5L.jpg'),
(98428, 6994, 'Extraordinária S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mOWTzUGaB3JGNUGXfzMMh21B7b.jpg'),
(98429, 6995, 'Extraordinária S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/296815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zoCIAB1iYOKOvNS0SjnUlJ9GfXQ.jpg'),
(98430, 6995, 'Extraordinária S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/296816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zoCIAB1iYOKOvNS0SjnUlJ9GfXQ.jpg'),
(98431, 6995, 'Extraordinária S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/296817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zoCIAB1iYOKOvNS0SjnUlJ9GfXQ.jpg'),
(98432, 6995, 'Extraordinária S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/296818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zoCIAB1iYOKOvNS0SjnUlJ9GfXQ.jpg'),
(98433, 6995, 'Extraordinária S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/296819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zoCIAB1iYOKOvNS0SjnUlJ9GfXQ.jpg'),
(98434, 6995, 'Extraordinária S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/296820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zoCIAB1iYOKOvNS0SjnUlJ9GfXQ.jpg'),
(98435, 6995, 'Extraordinária S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/296821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zoCIAB1iYOKOvNS0SjnUlJ9GfXQ.jpg'),
(98436, 6995, 'Extraordinária S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/296822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zoCIAB1iYOKOvNS0SjnUlJ9GfXQ.jpg'),
(98437, 6996, 'Falando a Real S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mIl6yUHc7F1KVCWbK0I5TOo7I93.jpg'),
(98438, 6996, 'Falando a Real S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wuTioL6Al1VMqBXmrG0yUcWFODK.jpg'),
(98439, 6996, 'Falando a Real S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208898.mp4', 'http://image.tmdb.org/t/p/w1280/3MkSfbHjRRwTsEaGQxWwxwLNThw.jpg'),
(98440, 6996, 'Falando a Real S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208899.mp4', 'http://image.tmdb.org/t/p/w1280/jLeO41uWVj0AK26a7i3lrPzcmMB.jpg'),
(98441, 6996, 'Falando a Real S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208900.mp4', 'http://image.tmdb.org/t/p/w1280/lLRi9NQrI2sXPDCoRgtO6bvqnUl.jpg'),
(98442, 6996, 'Falando a Real S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208901.mp4', 'http://image.tmdb.org/t/p/w1280/10XDAjenLiTlXWaY1644IIHZecf.jpg'),
(98443, 6996, 'Falando a Real S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208902.mp4', 'http://image.tmdb.org/t/p/w1280/2KEUNPwG1vMSoVyfelOUbZkKG4.jpg'),
(98444, 6996, 'Falando a Real S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208903.mp4', 'http://image.tmdb.org/t/p/w1280/oKdbvFmfbEgVA11HupqPeJfHsZb.jpg'),
(98445, 6996, 'Falando a Real S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208904.mp4', 'http://image.tmdb.org/t/p/w1280/2HeyqVqzBOr6xtANa78qkrujuW3.jpg'),
(98446, 6996, 'Falando a Real S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208905.mp4', 'http://image.tmdb.org/t/p/w1280/7Fgt8txB1aQy6f1MjTlE4ofAkYJ.jpg'),
(98447, 6997, 'Falando a Real S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/483199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hFm2BotenkhcLwrOXp8JlwcKw4O.jpg'),
(98448, 6997, 'Falando a Real S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/483200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hFm2BotenkhcLwrOXp8JlwcKw4O.jpg'),
(98449, 6997, 'Falando a Real S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/491311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hFm2BotenkhcLwrOXp8JlwcKw4O.jpg'),
(98450, 6997, 'Falando a Real S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/492852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hFm2BotenkhcLwrOXp8JlwcKw4O.jpg'),
(98451, 6997, 'Falando a Real S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hFm2BotenkhcLwrOXp8JlwcKw4O.jpg'),
(98452, 6997, 'Falando a Real S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/506156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hFm2BotenkhcLwrOXp8JlwcKw4O.jpg'),
(98453, 6997, 'Falando a Real S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/509577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hFm2BotenkhcLwrOXp8JlwcKw4O.jpg'),
(98454, 6997, 'Falando a Real S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/515679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hFm2BotenkhcLwrOXp8JlwcKw4O.jpg'),
(98455, 6997, 'Falando a Real S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/523521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hFm2BotenkhcLwrOXp8JlwcKw4O.jpg'),
(98456, 6997, 'Falando a Real S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/523522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hFm2BotenkhcLwrOXp8JlwcKw4O.jpg'),
(98457, 6997, 'Falando a Real S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/637337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hFm2BotenkhcLwrOXp8JlwcKw4O.jpg'),
(98458, 6997, 'Falando a Real S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/641067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hFm2BotenkhcLwrOXp8JlwcKw4O.jpg'),
(98459, 6998, 'Lockwood & Co. S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jyJHDBiknRrwEGRAvtFHU5IfFbK.jpg'),
(98460, 6998, 'Lockwood & Co. S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6xl5dl4sRd4T4LZjgehZCCvgenq.jpg'),
(98461, 6998, 'Lockwood & Co. S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wTZSzL94iMjPRYy1E5tfStZMaQ0.jpg'),
(98462, 6998, 'Lockwood & Co. S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5xMarz58RxwCFxw0q6Uey1DwCw8.jpg'),
(98463, 6998, 'Lockwood & Co. S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dRA0KYV4b1qX59s7cgMWFwrCPPM.jpg'),
(98464, 6998, 'Lockwood & Co. S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nIO034oq4pHRtXkyhQ1DtQOjbmm.jpg'),
(98465, 6998, 'Lockwood & Co. S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lizNGSr1YOkeO1h9teCbzhzU2en.jpg'),
(98466, 6998, 'Lockwood & Co. S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zPQIeXNFpFGD4dQmRt2p1Z8zq6F.jpg'),
(98467, 6999, 'Mila no Multiverso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qGgy8Qql7hcAYvTNaH2ZeyiDznl.jpg'),
(98468, 6999, 'Mila no Multiverso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9wRerJXfvCnEOxxGLc5NoTcoDIL.jpg'),
(98469, 6999, 'Mila no Multiverso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2BBEKZO2v6YLKfQgLaz4FdRoIZZ.jpg'),
(98470, 6999, 'Mila no Multiverso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xwvjrUYpaviUB0svtqdJRyS19XE.jpg'),
(98471, 6999, 'Mila no Multiverso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qjOH1WG34hcOhVv9H9GFhjoF4o.jpg'),
(98472, 6999, 'Mila no Multiverso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2jFlyE9MsEmVOEFipO0swdrc68r.jpg'),
(98473, 6999, 'Mila no Multiverso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dM309MW2mA1l4hbkHUlUXOr0kjV.jpg'),
(98474, 6999, 'Mila no Multiverso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nknxgE5ADpTLooS5A11auCfSAxA.jpg'),
(98475, 7000, 'Na Luta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ah5MrdsgMYhCnU8ubNNAMa5jyLV.jpg'),
(98476, 7000, 'Na Luta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Z01AD2ynEwS8AYsY1jtfJcaoBB.jpg'),
(98477, 7000, 'Na Luta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qkrcEHEtsKKnsGR6Vh2Thwue7JG.jpg'),
(98478, 7000, 'Na Luta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4oQF4MQNnw97eWos5syJWNFD6G3.jpg'),
(98479, 7000, 'Na Luta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tTCBYuue6STyZYpM81SQWWyTViG.jpg'),
(98480, 7000, 'Na Luta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4sWhvaOY6TxpwGoQ9mn9LC3e965.jpg'),
(98481, 7000, 'Na Luta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bsX3h0EAjHX6Iu2kXcb4yL5nyFJ.jpg'),
(98482, 7000, 'Na Luta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1NQFtJvpgQwsvwRcBPJWg3gu9dl.jpg'),
(98483, 7000, 'Na Luta S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3l29Sv6RJoRzASQ7TykfwpdseqV.jpg'),
(98484, 7000, 'Na Luta S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBbIjQxCuz53q0oS1OheEBMkl4w.jpg'),
(98485, 7001, 'Os Ricos Também Choram S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hkF5ZeqZa8uto9HAtytvbu4R5TC.jpg'),
(98486, 7001, 'Os Ricos Também Choram S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYqMQXPFB1R2P9QzekxKUWdiwh6.jpg'),
(98487, 7001, 'Os Ricos Também Choram S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wKjFukT0LP59xlWLgB7vh0XOYJo.jpg'),
(98488, 7001, 'Os Ricos Também Choram S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOtkjixjTbvLwOluCgtQHMbDvLf.jpg'),
(98489, 7001, 'Os Ricos Também Choram S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gOMmnOTIbStB2mq5XLHs7Kms35C.jpg'),
(98490, 7001, 'Os Ricos Também Choram S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eddKwvKJPuOJaShVDilFpEn4TDT.jpg'),
(98491, 7001, 'Os Ricos Também Choram S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7gfalxPK8Un62A96uZow9CLnxgV.jpg'),
(98492, 7001, 'Os Ricos Também Choram S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aaElelw3znEejMwYOBghjcBKt9U.jpg'),
(98493, 7001, 'Os Ricos Também Choram S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/felM7PCBShRngXkrh3jl2ZcNAxD.jpg'),
(98494, 7001, 'Os Ricos Também Choram S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/osY6ALYlDaWvqqF2WJZc9yQPWwn.jpg'),
(98495, 7001, 'Os Ricos Também Choram S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bfhvS2SFzsmmneVWa4KGbity7Nj.jpg'),
(98496, 7001, 'Os Ricos Também Choram S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8c9pupWrjkmc6SmiPTMj0Kq8LkR.jpg'),
(98497, 7001, 'Os Ricos Também Choram S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tsDUsm7BqwLrgMciK0BZxLQqSqR.jpg'),
(98498, 7001, 'Os Ricos Também Choram S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/204801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hebMrVgxRfkYjFosRQcyGElik9T.jpg'),
(98499, 7001, 'Os Ricos Também Choram S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/204802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCfAgy8nxs2Ow5OtaTFsKpIcUtf.jpg'),
(98500, 7001, 'Os Ricos Também Choram S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/204803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4WaAXQX10yI3WflMbckpnCPFZiH.jpg'),
(98501, 7001, 'Os Ricos Também Choram S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/204804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vItVIVsxkwt0R4zF9KzJ1JiSjdD.jpg'),
(98502, 7001, 'Os Ricos Também Choram S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/204805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t9FBl0auzOmmeBeB0tqDQuJFgcc.jpg'),
(98503, 7001, 'Os Ricos Também Choram S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/204806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o5Pi1PTxTlVY6WSqACSmK3fmJt5.jpg'),
(98504, 7001, 'Os Ricos Também Choram S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/204807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ohtEuTpIYSw54muTC5l2gCagGgb.jpg'),
(98505, 7001, 'Os Ricos Também Choram S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/204808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uYdnQv1btoh7a3UzWe2bznxYCtt.jpg'),
(98506, 7001, 'Os Ricos Também Choram S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/204809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/at2T7vj6Isp62VScvP61X7SYUDP.jpg'),
(98507, 7001, 'Os Ricos Também Choram S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/204810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jEs99fZYFdgS3bedSkP4QGPlBqt.jpg'),
(98508, 7001, 'Os Ricos Também Choram S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/204811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/HgkO9i4ee6WM4TT4XkejENT2tK.jpg'),
(98509, 7001, 'Os Ricos Também Choram S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/204812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9X9UvZ8qcdZxgiksTEbJAITewy3.jpg'),
(98510, 7001, 'Os Ricos Também Choram S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/204813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ya36gmwUdnqVJ9NN6RcxtOlzgcL.jpg'),
(98511, 7001, 'Os Ricos Também Choram S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/204814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tbNYf7LloVWGjSSSL1A3LKzELjc.jpg'),
(98512, 7001, 'Os Ricos Também Choram S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/204815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cj54ohvOVDRjFWZDQbtC1r1eVWL.jpg'),
(98513, 7001, 'Os Ricos Também Choram S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/204816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dzrVg4Efl9e4uqMb5c1Rn2T00WJ.jpg'),
(98514, 7001, 'Os Ricos Também Choram S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/204817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eCnxdVbbqnKeM6vRw1UZP5cRBft.jpg'),
(98515, 7001, 'Os Ricos Também Choram S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/204818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dvjJ47iDDM8lQu4BZYpr5BcwXP5.jpg'),
(98516, 7001, 'Os Ricos Também Choram S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/204819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pEXNnLYW2rGB73AKviEP4A5LPhB.jpg'),
(98517, 7001, 'Os Ricos Também Choram S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/204820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v6eG00m7tcIayGyMetCEB7YFZtq.jpg'),
(98518, 7001, 'Os Ricos Também Choram S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/204821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zdeIsmgw6ZEcGYB1iqyqv7d7uxz.jpg'),
(98519, 7001, 'Os Ricos Também Choram S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/204822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mU7TopTZ5vtCZokE3N2R3IlZElU.jpg'),
(98520, 7001, 'Os Ricos Também Choram S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/204823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dh8O4b0AiDyIM7M2kYCiUGDMhuh.jpg'),
(98521, 7001, 'Os Ricos Também Choram S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/204824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/26BpjaV7IHkOfa53RWJoVom3BqV.jpg'),
(98522, 7001, 'Os Ricos Também Choram S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/204825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hUSBYNeWkodjFcwHSV1cv2YfGww.jpg'),
(98523, 7001, 'Os Ricos Também Choram S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/204826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eBfjpgqILJnzLg4FxlPKEFDyCBv.jpg'),
(98524, 7001, 'Os Ricos Também Choram S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/204827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xzQEYtG8ZTImdePBloyUIOTr379.jpg'),
(98525, 7001, 'Os Ricos Também Choram S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/204828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mH5mveV9aNIvD5DT43UgcSu2nDb.jpg'),
(98526, 7001, 'Os Ricos Também Choram S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/204829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7D66ZyYCGHs4AYgjdmhpazEX2zd.jpg'),
(98527, 7001, 'Os Ricos Também Choram S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/204830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lJHfAVjVHVgBUJqUNJupQxmThbi.jpg'),
(98528, 7001, 'Os Ricos Também Choram S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/204831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0ZH37vajl2DuXJLGPOaCjZFGJZ.jpg'),
(98529, 7001, 'Os Ricos Também Choram S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/204832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wI0pduQa8AEnxoYd8EriyQpLqm5.jpg'),
(98530, 7001, 'Os Ricos Também Choram S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/204833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wI0pduQa8AEnxoYd8EriyQpLqm5.jpg'),
(98531, 7001, 'Os Ricos Também Choram S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/204834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wI0pduQa8AEnxoYd8EriyQpLqm5.jpg'),
(98532, 7001, 'Os Ricos Também Choram S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/204835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wI0pduQa8AEnxoYd8EriyQpLqm5.jpg'),
(98533, 7001, 'Os Ricos Também Choram S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/204836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wI0pduQa8AEnxoYd8EriyQpLqm5.jpg'),
(98534, 7001, 'Os Ricos Também Choram S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/204837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wI0pduQa8AEnxoYd8EriyQpLqm5.jpg'),
(98535, 7001, 'Os Ricos Também Choram S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/204838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wI0pduQa8AEnxoYd8EriyQpLqm5.jpg'),
(98536, 7001, 'Os Ricos Também Choram S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/204839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wI0pduQa8AEnxoYd8EriyQpLqm5.jpg'),
(98537, 7001, 'Os Ricos Também Choram S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/204840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wI0pduQa8AEnxoYd8EriyQpLqm5.jpg'),
(98538, 7001, 'Os Ricos Também Choram S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/204841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wI0pduQa8AEnxoYd8EriyQpLqm5.jpg'),
(98539, 7001, 'Os Ricos Também Choram S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/204842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wI0pduQa8AEnxoYd8EriyQpLqm5.jpg'),
(98540, 7001, 'Os Ricos Também Choram S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/204843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wI0pduQa8AEnxoYd8EriyQpLqm5.jpg'),
(98541, 7001, 'Os Ricos Também Choram S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/204844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wI0pduQa8AEnxoYd8EriyQpLqm5.jpg'),
(98542, 7001, 'Os Ricos Também Choram S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/204845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wI0pduQa8AEnxoYd8EriyQpLqm5.jpg'),
(98543, 7001, 'Os Ricos Também Choram S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/204846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wI0pduQa8AEnxoYd8EriyQpLqm5.jpg'),
(98544, 7001, 'Os Ricos Também Choram S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/204847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wI0pduQa8AEnxoYd8EriyQpLqm5.jpg'),
(98545, 7002, 'O Novo Show do Pica-Pau S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lM7kiO20DQenpXg7xMQBrlQt38D.jpg'),
(98546, 7002, 'O Novo Show do Pica-Pau S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98547, 7002, 'O Novo Show do Pica-Pau S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98548, 7002, 'O Novo Show do Pica-Pau S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4yeqzAmbP3NZ2PTT6PyFTzNeVkI.jpg'),
(98549, 7002, 'O Novo Show do Pica-Pau S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98550, 7002, 'O Novo Show do Pica-Pau S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98551, 7002, 'O Novo Show do Pica-Pau S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ftdkl0gm47qB2z6NG4tyWFf11b0.jpg'),
(98552, 7002, 'O Novo Show do Pica-Pau S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98553, 7002, 'O Novo Show do Pica-Pau S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98554, 7002, 'O Novo Show do Pica-Pau S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/513orWy4226FRFYChu03zUfC7vc.jpg'),
(98555, 7002, 'O Novo Show do Pica-Pau S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98556, 7002, 'O Novo Show do Pica-Pau S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98557, 7002, 'O Novo Show do Pica-Pau S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98558, 7002, 'O Novo Show do Pica-Pau S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/204689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98559, 7002, 'O Novo Show do Pica-Pau S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/204690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98560, 7002, 'O Novo Show do Pica-Pau S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/204691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98561, 7002, 'O Novo Show do Pica-Pau S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/204692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98562, 7002, 'O Novo Show do Pica-Pau S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/204693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98563, 7002, 'O Novo Show do Pica-Pau S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/204694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98564, 7002, 'O Novo Show do Pica-Pau S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/204695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98565, 7002, 'O Novo Show do Pica-Pau S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/204696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98566, 7002, 'O Novo Show do Pica-Pau S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/204697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98567, 7002, 'O Novo Show do Pica-Pau S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/204698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98568, 7002, 'O Novo Show do Pica-Pau S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/204699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98569, 7002, 'O Novo Show do Pica-Pau S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/204700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98570, 7002, 'O Novo Show do Pica-Pau S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/204701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98571, 7003, 'O Novo Show do Pica-Pau S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98572, 7003, 'O Novo Show do Pica-Pau S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98573, 7003, 'O Novo Show do Pica-Pau S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98574, 7003, 'O Novo Show do Pica-Pau S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98575, 7003, 'O Novo Show do Pica-Pau S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98576, 7003, 'O Novo Show do Pica-Pau S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98577, 7003, 'O Novo Show do Pica-Pau S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98578, 7003, 'O Novo Show do Pica-Pau S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98579, 7003, 'O Novo Show do Pica-Pau S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98580, 7003, 'O Novo Show do Pica-Pau S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98581, 7003, 'O Novo Show do Pica-Pau S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98582, 7003, 'O Novo Show do Pica-Pau S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98583, 7003, 'O Novo Show do Pica-Pau S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98584, 7003, 'O Novo Show do Pica-Pau S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/204715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98585, 7003, 'O Novo Show do Pica-Pau S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/204716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98586, 7003, 'O Novo Show do Pica-Pau S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/204717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98587, 7003, 'O Novo Show do Pica-Pau S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/204718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98588, 7003, 'O Novo Show do Pica-Pau S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/204719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98589, 7003, 'O Novo Show do Pica-Pau S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/204720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98590, 7003, 'O Novo Show do Pica-Pau S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/204721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98591, 7003, 'O Novo Show do Pica-Pau S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/204722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98592, 7003, 'O Novo Show do Pica-Pau S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/204723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98593, 7003, 'O Novo Show do Pica-Pau S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/204724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98594, 7003, 'O Novo Show do Pica-Pau S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/204725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98595, 7003, 'O Novo Show do Pica-Pau S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/204726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98596, 7003, 'O Novo Show do Pica-Pau S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/204727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98597, 7004, 'O Novo Show do Pica-Pau S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98598, 7004, 'O Novo Show do Pica-Pau S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98599, 7004, 'O Novo Show do Pica-Pau S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98600, 7004, 'O Novo Show do Pica-Pau S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98601, 7004, 'O Novo Show do Pica-Pau S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98602, 7004, 'O Novo Show do Pica-Pau S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98603, 7004, 'O Novo Show do Pica-Pau S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98604, 7004, 'O Novo Show do Pica-Pau S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98605, 7004, 'O Novo Show do Pica-Pau S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98606, 7004, 'O Novo Show do Pica-Pau S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98607, 7004, 'O Novo Show do Pica-Pau S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98608, 7004, 'O Novo Show do Pica-Pau S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98609, 7004, 'O Novo Show do Pica-Pau S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98610, 7004, 'O Novo Show do Pica-Pau S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/204741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98611, 7004, 'O Novo Show do Pica-Pau S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/204742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98612, 7004, 'O Novo Show do Pica-Pau S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/204743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98613, 7004, 'O Novo Show do Pica-Pau S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/204744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98614, 7004, 'O Novo Show do Pica-Pau S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/204745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98615, 7004, 'O Novo Show do Pica-Pau S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/204746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98616, 7004, 'O Novo Show do Pica-Pau S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/204747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98617, 7004, 'O Novo Show do Pica-Pau S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/204748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98618, 7004, 'O Novo Show do Pica-Pau S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/204749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98619, 7004, 'O Novo Show do Pica-Pau S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/204750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98620, 7004, 'O Novo Show do Pica-Pau S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/204751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98621, 7004, 'O Novo Show do Pica-Pau S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/204752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98622, 7004, 'O Novo Show do Pica-Pau S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/204753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98623, 7005, 'O Novo Show do Pica-Pau S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98624, 7005, 'O Novo Show do Pica-Pau S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98625, 7005, 'O Novo Show do Pica-Pau S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98626, 7005, 'O Novo Show do Pica-Pau S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98627, 7005, 'O Novo Show do Pica-Pau S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98628, 7005, 'O Novo Show do Pica-Pau S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98629, 7005, 'O Novo Show do Pica-Pau S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98630, 7005, 'O Novo Show do Pica-Pau S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98631, 7005, 'O Novo Show do Pica-Pau S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98632, 7005, 'O Novo Show do Pica-Pau S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98633, 7005, 'O Novo Show do Pica-Pau S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98634, 7005, 'O Novo Show do Pica-Pau S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98635, 7005, 'O Novo Show do Pica-Pau S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98636, 7006, 'O Novo Show do Pica-Pau S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98637, 7006, 'O Novo Show do Pica-Pau S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98638, 7006, 'O Novo Show do Pica-Pau S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98639, 7006, 'O Novo Show do Pica-Pau S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98640, 7006, 'O Novo Show do Pica-Pau S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98641, 7006, 'O Novo Show do Pica-Pau S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98642, 7006, 'O Novo Show do Pica-Pau S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98643, 7006, 'O Novo Show do Pica-Pau S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98644, 7006, 'O Novo Show do Pica-Pau S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98645, 7006, 'O Novo Show do Pica-Pau S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98646, 7006, 'O Novo Show do Pica-Pau S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98647, 7006, 'O Novo Show do Pica-Pau S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98648, 7006, 'O Novo Show do Pica-Pau S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98649, 7006, 'O Novo Show do Pica-Pau S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/204780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98650, 7006, 'O Novo Show do Pica-Pau S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/204781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98651, 7006, 'O Novo Show do Pica-Pau S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/204782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98652, 7006, 'O Novo Show do Pica-Pau S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/204783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98653, 7006, 'O Novo Show do Pica-Pau S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/204784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98654, 7006, 'O Novo Show do Pica-Pau S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/204785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98655, 7006, 'O Novo Show do Pica-Pau S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/204786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98656, 7006, 'O Novo Show do Pica-Pau S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/204787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWdXYcVwl6oqwS1ILG3MuyrU0b8.jpg'),
(98657, 7007, 'o Fantasminha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgWknDZhuLNB6S28CcPZA77vLz2.jpg'),
(98658, 7007, 'o Fantasminha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgWknDZhuLNB6S28CcPZA77vLz2.jpg'),
(98659, 7007, 'o Fantasminha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgWknDZhuLNB6S28CcPZA77vLz2.jpg'),
(98660, 7008, 'Reis de Joanesburgo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vlc3X5l280rpAWKqpVYsBqW0JdG.jpg'),
(98661, 7008, 'Reis de Joanesburgo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rDCIFaBTMHtogGsgA6XAgu30S55.jpg'),
(98662, 7008, 'Reis de Joanesburgo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q11j87vwKvrMd9KMu6r2Cixm1kH.jpg'),
(98663, 7008, 'Reis de Joanesburgo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p7Ebla06wfu4BLFHsGvuGJ1xgX.jpg'),
(98664, 7008, 'Reis de Joanesburgo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vBlkYEV9UFNup5PZUMo07xdtjUU.jpg'),
(98665, 7008, 'Reis de Joanesburgo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4nMjTvdI8wZdlczIuuiEcIjRd1j.jpg'),
(98666, 7009, 'Reis de Joanesburgo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gKF9i1fTQjmSXH0cC767HVmHLiU.jpg'),
(98667, 7009, 'Reis de Joanesburgo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xHExxIBedrjPLMqaGppvbU7i0ug.jpg'),
(98668, 7009, 'Reis de Joanesburgo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Qdazqu343vL5qU6q2gEeyogFHM.jpg'),
(98669, 7009, 'Reis de Joanesburgo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i3ZThXQmZPAZuyMFhuYJy6wCp0c.jpg'),
(98670, 7009, 'Reis de Joanesburgo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gkCR86tu1Fms9JZMm7JRvObkswG.jpg'),
(98671, 7009, 'Reis de Joanesburgo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/re77HW86tl1WJ8ahF7PFXVdK6lJ.jpg'),
(98672, 7009, 'Reis de Joanesburgo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d72hr2FG3XHSjXPNlCBKo5day9a.jpg'),
(98673, 7009, 'Reis de Joanesburgo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ALMdnI8pRlYh4RD7p0f9ZRJPGp.jpg'),
(98674, 7010, 'Reis de Joanesburgo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/835222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vSM1FB86gr3QNelkk0jDovN5228.jpg'),
(98675, 7010, 'Reis de Joanesburgo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/835223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vSM1FB86gr3QNelkk0jDovN5228.jpg'),
(98676, 7010, 'Reis de Joanesburgo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/835224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vSM1FB86gr3QNelkk0jDovN5228.jpg'),
(98677, 7010, 'Reis de Joanesburgo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/835225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vSM1FB86gr3QNelkk0jDovN5228.jpg'),
(98678, 7010, 'Reis de Joanesburgo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/835226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vSM1FB86gr3QNelkk0jDovN5228.jpg'),
(98679, 7010, 'Reis de Joanesburgo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/835227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vSM1FB86gr3QNelkk0jDovN5228.jpg'),
(98680, 7010, 'Reis de Joanesburgo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/835228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vSM1FB86gr3QNelkk0jDovN5228.jpg'),
(98681, 3952, 'Resident Evil: No Escuro Absoluto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1CJpsDtQd8bMq8UpJJwKFCSIuDS.jpg'),
(98682, 3952, 'Resident Evil: No Escuro Absoluto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3PvVpA4VKqBhSihDkjAYEMJeXuq.jpg'),
(98683, 3952, 'Resident Evil: No Escuro Absoluto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pQCZCk8QoS9qsZavz00gW4mLkj5.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(98684, 3952, 'Resident Evil: No Escuro Absoluto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5SMRWdZXrQyn5QqukXSy13z2AYi.jpg'),
(98685, 7011, 'Wolf Pack S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tCc8VLRlSBmHPX7m6i9JVP5JfCp.jpg'),
(98686, 7011, 'Wolf Pack S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209617.mp4', 'http://image.tmdb.org/t/p/w1280/k95irTmtbX7pgXU3DbQZMxnTHHK.jpg'),
(98687, 7011, 'Wolf Pack S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209618.mp4', 'http://image.tmdb.org/t/p/w1280/kT0JuTZTuudSaEajvQ67NQyPy62.jpg'),
(98688, 7011, 'Wolf Pack S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209619.mp4', 'http://image.tmdb.org/t/p/w1280/23v8T5T113I1LIctuEdpMaMZFJ5.jpg'),
(98689, 7011, 'Wolf Pack S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209620.mp4', 'http://image.tmdb.org/t/p/w1280/owBXskTZ29LC6wYH1Z9qTJVRHFz.jpg'),
(98690, 7011, 'Wolf Pack S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209621.mp4', 'http://image.tmdb.org/t/p/w1280/aYtF9lmzQxMsq0jRJpLNAWvTil3.jpg'),
(98691, 7011, 'Wolf Pack S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209622.mp4', 'http://image.tmdb.org/t/p/w1280/tBkJrhhqswGy8MXohnqkKYs8qcz.jpg'),
(98692, 7011, 'Wolf Pack S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209623.mp4', 'http://image.tmdb.org/t/p/w1280/964CaxCyKiOig3aQDzB3nevjUPA.jpg'),
(98693, 7012, 'Saikyoushu no Nekomimi Shoujo to Deau S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vKZShDchgLgXQp9dEHOWNc3iOv3.jpg'),
(98694, 7012, 'Saikyoushu no Nekomimi Shoujo to Deau S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oT1w4go5NscHtSygx7hp0sBwtvf.jpg'),
(98695, 7012, 'Saikyoushu no Nekomimi Shoujo to Deau S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ePr7CkbnN4V1r9kNUxxvWXzQ6T1.jpg'),
(98696, 7012, 'Saikyoushu no Nekomimi Shoujo to Deau S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Jnwl7eyy1JYYLDFd5be1dDVyCg.jpg'),
(98697, 7012, 'Saikyoushu no Nekomimi Shoujo to Deau S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oNtTjirfRf0c8L9C4EDsXiKBOeV.jpg'),
(98698, 7012, 'Saikyoushu no Nekomimi Shoujo to Deau S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p7fYvaQhcl9uDEAem6ou4in4CjQ.jpg'),
(98699, 7012, 'Saikyoushu no Nekomimi Shoujo to Deau S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qtNTtiTI2PZbLpsxTUsmwV21onv.jpg'),
(98700, 7012, 'Saikyoushu no Nekomimi Shoujo to Deau S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2hOqowBUV1eBDM42DHGKSnXYcq.jpg'),
(98701, 7012, 'Saikyoushu no Nekomimi Shoujo to Deau S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6yT3NJ9a1vYXPL0mqSb3inBvGV2.jpg'),
(98702, 7012, 'Saikyoushu no Nekomimi Shoujo to Deau S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOPgL6t3OXfioY50ODl6e0OnyuZ.jpg'),
(98703, 7012, 'Saikyoushu no Nekomimi Shoujo to Deau S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1TpTDPQHCni39aWEyw7dqtx4Xsf.jpg'),
(98704, 7012, 'Saikyoushu no Nekomimi Shoujo to Deau S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfDirWa1whJt0jEYI3UBDsjshas.jpg'),
(98705, 7012, 'Saikyoushu no Nekomimi Shoujo to Deau S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9taaaoCApsD3pZxYorby88502kC.jpg'),
(98706, 7013, 'Mãe S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e92NkNKHfCuZCUkRcUAxqXp8R0S.jpg'),
(98707, 7013, 'Mãe S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/56x76RwxhdjcxObgrT6C8wQNdNm.jpg'),
(98708, 7013, 'Mãe S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w4gZX7jOIDHIFJTqBmhvojneaKD.jpg'),
(98709, 7013, 'Mãe S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/MC9tGXKWhP2mlJlsf37enb6DCB.jpg'),
(98710, 7013, 'Mãe S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFiZbSP0KPnruJkMiSwim8NffpX.jpg'),
(98711, 7013, 'Mãe S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6M4Jkk1ZObz9Dre8aCgdhSbGEca.jpg'),
(98712, 7013, 'Mãe S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a7hgJwVpdVk87SxGKuLalMjtuTi.jpg'),
(98713, 7013, 'Mãe S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4wR0O07LioDAXxGTsuzazKyFTvk.jpg'),
(98714, 7013, 'Mãe S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3jZMmbq2FZQYiTFa0IGsYvwFHm.jpg'),
(98715, 7013, 'Mãe S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aq33Hgh7ELqPeAysuCcNGSqX21a.jpg'),
(98716, 7013, 'Mãe S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tkgcp1rE4RhjUy0NttlIp9XNZLi.jpg'),
(98717, 7013, 'Mãe S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKsk2FsPatUz89AJb8zGFS3WfyP.jpg'),
(98718, 7013, 'Mãe S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/208051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2S8v3gpmpCnjDFPzZF7sasBf9Zm.jpg'),
(98719, 7013, 'Mãe S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/208052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zi4LbLfASE8Tn8XanULPOM1KOqp.jpg'),
(98720, 7013, 'Mãe S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/208053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4nt18oX1jghG4JikrStzXboF7UP.jpg'),
(98721, 7013, 'Mãe S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/208054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t6MTAtzMbZXSl0wmv2dSkf610nA.jpg'),
(98722, 7013, 'Mãe S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/208055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/78NSm8yNcPzWdtYpRK21lhI2hqk.jpg'),
(98723, 7013, 'Mãe S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/208056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q9Oak06gcLEYOSHAAHRdBlx7mhc.jpg'),
(98724, 7013, 'Mãe S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/208057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lIrfvJpemaO0PJJflsCawUtSo8z.jpg'),
(98725, 7013, 'Mãe S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/208058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yZdkNED9x9sXRhs4tpXh0LmHcCo.jpg'),
(98726, 7013, 'Mãe S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/208059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ofRubI7YXWX4x5vUa2uSjh9TpyK.jpg'),
(98727, 7013, 'Mãe S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/208060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJq46PLyzztCPNER18Fe41tss51.jpg'),
(98728, 7013, 'Mãe S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/208061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1edOJP8isBGRv1OukZBGuma1VsG.jpg'),
(98729, 7013, 'Mãe S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/208062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3Xn6EYO2wgiRv4WfWbu8uoBj3m.jpg'),
(98730, 7013, 'Mãe S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/208063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/flPWLQUap35Kl4q8HRnYO4cEOEU.jpg'),
(98731, 7013, 'Mãe S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/208064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4OKCAOZhUrFXBE5k2uhPL8wyPZq.jpg'),
(98732, 7013, 'Mãe S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/208065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n8v3KQQODTKHzeidaRJ7bVwbxpi.jpg'),
(98733, 7013, 'Mãe S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/208066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bZHKoozs1IqmORCgfXHNGOAU1pB.jpg'),
(98734, 7013, 'Mãe S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/208067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b2KratD7fGHBm55apqb8Lm9mshG.jpg'),
(98735, 7013, 'Mãe S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/208068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bAts7oyLrquZMw52SwR0agNy9vc.jpg'),
(98736, 7013, 'Mãe S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/208069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2074xTHmkbZtODLZOA6AqI6rnJG.jpg'),
(98737, 7013, 'Mãe S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/208070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dfOXcRJ9DUtMyDdOoxqM4xDsh7i.jpg'),
(98738, 7013, 'Mãe S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/208071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jfrU479XWwtOmKT0n61AjudiOSH.jpg'),
(98739, 7013, 'Mãe S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/208072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98740, 7013, 'Mãe S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/208073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98741, 7013, 'Mãe S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/208074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98742, 7013, 'Mãe S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/208075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98743, 7013, 'Mãe S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/208076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98744, 7013, 'Mãe S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/208077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98745, 7013, 'Mãe S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/208078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98746, 7013, 'Mãe S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/208079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98747, 7013, 'Mãe S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/208080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98748, 7013, 'Mãe S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/208081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98749, 7013, 'Mãe S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/208082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98750, 7013, 'Mãe S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/208083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98751, 7013, 'Mãe S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/208084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98752, 7013, 'Mãe S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/208085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98753, 7013, 'Mãe S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/208086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98754, 7013, 'Mãe S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/208087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98755, 7013, 'Mãe S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/208088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98756, 7013, 'Mãe S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/208089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98757, 7013, 'Mãe S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/208090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98758, 7013, 'Mãe S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/208091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98759, 7013, 'Mãe S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/208092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98760, 7013, 'Mãe S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/208093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98761, 7013, 'Mãe S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/208094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98762, 7013, 'Mãe S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/208095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98763, 7013, 'Mãe S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/208096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98764, 7013, 'Mãe S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/208097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98765, 7013, 'Mãe S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/208098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98766, 7013, 'Mãe S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/208099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98767, 7013, 'Mãe S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/208100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98768, 7013, 'Mãe S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/208101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98769, 7013, 'Mãe S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/208102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98770, 7013, 'Mãe S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/208103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98771, 7013, 'Mãe S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/208104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98772, 7013, 'Mãe S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/208105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98773, 7013, 'Mãe S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/208106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98774, 7013, 'Mãe S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/208107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98775, 7013, 'Mãe S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/208108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98776, 7013, 'Mãe S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/208109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98777, 7013, 'Mãe S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/208110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98778, 7013, 'Mãe S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/208111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98779, 7013, 'Mãe S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/208112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98780, 7013, 'Mãe S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/208113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98781, 7013, 'Mãe S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/208114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98782, 7013, 'Mãe S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/208115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98783, 7013, 'Mãe S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/208116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98784, 7013, 'Mãe S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/208117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98785, 7013, 'Mãe S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/208118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98786, 7013, 'Mãe S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/208119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98787, 7013, 'Mãe S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/208120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98788, 7013, 'Mãe S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/208121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98789, 7013, 'Mãe S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/208122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98790, 7013, 'Mãe S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/208123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pvNFpOdhOQoIZVywgwDReJsCTc.jpg'),
(98791, 7014, '1923 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/At324Ks3Ao0I7t8oSy5VrTYdXj3.jpg'),
(98792, 7014, '1923 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208917.mp4', 'http://image.tmdb.org/t/p/w1280/kk5DofIu197Y2omyQJsRO1d3wP4.jpg'),
(98793, 7014, '1923 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208918.mp4', 'http://image.tmdb.org/t/p/w1280/g3cURFZ9ORF1Qh1mQk60pAW1tdN.jpg'),
(98794, 7014, '1923 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208919.mp4', 'http://image.tmdb.org/t/p/w1280/dksanHPkfHJli3Vzp9QPpg1a3aW.jpg'),
(98795, 7014, '1923 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208920.mp4', 'http://image.tmdb.org/t/p/w1280/vOlEhurZdvkEy4eJ9yjSaXMQYTh.jpg'),
(98796, 7014, '1923 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208921.mp4', 'http://image.tmdb.org/t/p/w1280/lYoICloKZuO3BU4JrRgPRartN2c.jpg'),
(98797, 7014, '1923 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208922.mp4', 'http://image.tmdb.org/t/p/w1280/enL17WRdAjgWOw9zZr3xxHrCGus.jpg'),
(98798, 7014, '1923 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208923.mp4', 'http://image.tmdb.org/t/p/w1280/4aEaJuk8bhhDKNimlRvQj8RUVrW.jpg'),
(98799, 7015, '1923 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/707678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zgZRJZvZn5cpsWAB0zMUdad3iZd.jpg'),
(98800, 7015, '1923 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/712196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zgZRJZvZn5cpsWAB0zMUdad3iZd.jpg'),
(98801, 7015, '1923 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/722488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zgZRJZvZn5cpsWAB0zMUdad3iZd.jpg'),
(98802, 7015, '1923 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/729490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zgZRJZvZn5cpsWAB0zMUdad3iZd.jpg'),
(98803, 7015, '1923 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/739482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zgZRJZvZn5cpsWAB0zMUdad3iZd.jpg'),
(98804, 7015, '1923 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/743427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zgZRJZvZn5cpsWAB0zMUdad3iZd.jpg'),
(98805, 7015, '1923 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/761960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zgZRJZvZn5cpsWAB0zMUdad3iZd.jpg'),
(98806, 7016, 'Amor: Verdade ou Consequência – Polônia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p1AgA3v4Iz80phP0NLhffhX9R1J.jpg'),
(98807, 7016, 'Amor: Verdade ou Consequência – Polônia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mi3tiAW9ERrxn08wsgnNutQJzhB.jpg'),
(98808, 7016, 'Amor: Verdade ou Consequência – Polônia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yUv1TyodxaCDaTMQyeFi5tPGE1x.jpg'),
(98809, 7016, 'Amor: Verdade ou Consequência – Polônia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m3Kjk61NH4soEIoku3JR1wB9cp6.jpg'),
(98810, 7016, 'Amor: Verdade ou Consequência – Polônia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oGk70cm9oZtjTWvjCL2NKTC6Dpk.jpg'),
(98811, 7016, 'Amor: Verdade ou Consequência – Polônia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o20vczIgbHnW1IckD5XQ4Zisser.jpg'),
(98812, 7016, 'Amor: Verdade ou Consequência – Polônia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHRaCE9cqRBk3QN4wpnFnCkB4KV.jpg'),
(98813, 7017, 'Catfish UK S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/joNtE8ALCvovfxquBAx5eKZzZUb.jpg'),
(98814, 7017, 'Catfish UK S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aSUOcQlaMz71UldmH4JHoAmfxyg.jpg'),
(98815, 7017, 'Catfish UK S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aSUOcQlaMz71UldmH4JHoAmfxyg.jpg'),
(98816, 7017, 'Catfish UK S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aSUOcQlaMz71UldmH4JHoAmfxyg.jpg'),
(98817, 7018, 'Classes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAc6LUOz3CqaPbYgtxAlWjDXOY2.jpg'),
(98818, 7018, 'Classes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nrezFKr2oNapCutYvTv1EKbnxUq.jpg'),
(98819, 7018, 'Classes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iO5qh12gTVbcPJnQtfMIOG1yF1s.jpg'),
(98820, 7018, 'Classes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/XEfs5LMw5gS3waY9CtKvAF7Uga.jpg'),
(98821, 7018, 'Classes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pul1hSY9lcHxMWjDyDIiW7WKlrZ.jpg'),
(98822, 7018, 'Classes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8JPbXFJRPDYkccMJJhNeeh4g3Ay.jpg'),
(98823, 7018, 'Classes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uH9fCSDymq6DcbRNp6kG7mxJvPv.jpg'),
(98824, 7018, 'Classes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1OPM8Bd9LdjREjYVxZCdaAPHbzp.jpg'),
(98825, 7019, 'Click BBB S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98826, 7019, 'Click BBB S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98827, 7019, 'Click BBB S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98828, 7019, 'Click BBB S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98829, 7019, 'Click BBB S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98830, 7019, 'Click BBB S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98831, 7019, 'Click BBB S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98832, 7019, 'Click BBB S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98833, 7019, 'Click BBB S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98834, 7019, 'Click BBB S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98835, 7019, 'Click BBB S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/258289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98836, 7019, 'Click BBB S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/258290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98837, 7019, 'Click BBB S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/258291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98838, 7019, 'Click BBB S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/258292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98839, 7019, 'Click BBB S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/258293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98840, 7019, 'Click BBB S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/258294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98841, 7019, 'Click BBB S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/258295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98842, 7019, 'Click BBB S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/258296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98843, 7019, 'Click BBB S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/258297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98844, 7019, 'Click BBB S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/258298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98845, 7019, 'Click BBB S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/258299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98846, 7019, 'Click BBB S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/258300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98847, 7019, 'Click BBB S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/258301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98848, 7019, 'Click BBB S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/258302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98849, 7019, 'Click BBB S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/258303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98850, 7019, 'Click BBB S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/258304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98851, 7019, 'Click BBB S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/258305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98852, 7019, 'Click BBB S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/258306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98853, 7019, 'Click BBB S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/258307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98854, 7019, 'Click BBB S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/258308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98855, 7019, 'Click BBB S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/258309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98856, 7019, 'Click BBB S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/258310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98857, 7019, 'Click BBB S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/258311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98858, 7019, 'Click BBB S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/258312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98859, 7019, 'Click BBB S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/258313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98860, 7019, 'Click BBB S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/258314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98861, 7019, 'Click BBB S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/258315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98862, 7019, 'Click BBB S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/258316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98863, 7019, 'Click BBB S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/258317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98864, 7019, 'Click BBB S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/258318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98865, 7019, 'Click BBB S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/258319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98866, 7019, 'Click BBB S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/258320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98867, 7019, 'Click BBB S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/258321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98868, 7019, 'Click BBB S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/258322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98869, 7019, 'Click BBB S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/258323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98870, 7019, 'Click BBB S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/258324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98871, 7019, 'Click BBB S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/258325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98872, 7019, 'Click BBB S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/258326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98873, 7019, 'Click BBB S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/258327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98874, 7019, 'Click BBB S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/258328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98875, 7019, 'Click BBB S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/258329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98876, 7019, 'Click BBB S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/258330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98877, 7019, 'Click BBB S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/258331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98878, 7019, 'Click BBB S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/258332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98879, 7019, 'Click BBB S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/258333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98880, 7019, 'Click BBB S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/258334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98881, 7019, 'Click BBB S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/258335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98882, 7019, 'Click BBB S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/258336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98883, 7019, 'Click BBB S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/258337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98884, 7019, 'Click BBB S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/258338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98885, 7019, 'Click BBB S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/258339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98886, 7019, 'Click BBB S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/258340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98887, 7019, 'Click BBB S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/258341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98888, 7019, 'Click BBB S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/258342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98889, 7019, 'Click BBB S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/258343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98890, 7019, 'Click BBB S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/258344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98891, 7019, 'Click BBB S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/258345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98892, 7019, 'Click BBB S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/258346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98893, 7019, 'Click BBB S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/258347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98894, 7019, 'Click BBB S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/258348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98895, 7019, 'Click BBB S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/258349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98896, 7019, 'Click BBB S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/258350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98897, 7019, 'Click BBB S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/258351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98898, 7019, 'Click BBB S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/258352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98899, 7019, 'Click BBB S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/258353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98900, 7019, 'Click BBB S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/258354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98901, 7019, 'Click BBB S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/258355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98902, 7019, 'Click BBB S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/258356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98903, 7019, 'Click BBB S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/258357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98904, 7019, 'Click BBB S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/258358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98905, 7019, 'Click BBB S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/258359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98906, 7019, 'Click BBB S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/258360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98907, 7019, 'Click BBB S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/258361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98908, 7019, 'Click BBB S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/258362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98909, 7019, 'Click BBB S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/258363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98910, 7019, 'Click BBB S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/258364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98911, 7019, 'Click BBB S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/258365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98912, 7019, 'Click BBB S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/258366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98913, 7019, 'Click BBB S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/258367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98914, 7019, 'Click BBB S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/258368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98915, 7019, 'Click BBB S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/258369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98916, 7019, 'Click BBB S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/258370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98917, 7019, 'Click BBB S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/258371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98918, 7019, 'Click BBB S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/258372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98919, 7019, 'Click BBB S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/258373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98920, 7019, 'Click BBB S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/258374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98921, 7019, 'Click BBB S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/258375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98922, 7019, 'Click BBB S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/258376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98923, 7019, 'Click BBB S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/258377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98924, 7019, 'Click BBB S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/258378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98925, 7019, 'Click BBB S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/258379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98926, 7019, 'Click BBB S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/258380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98927, 7019, 'Click BBB S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/258381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98928, 7019, 'Click BBB S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/258382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98929, 7019, 'Click BBB S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/258383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98930, 7019, 'Click BBB S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/258384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98931, 7019, 'Click BBB S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/258385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98932, 7019, 'Click BBB S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/258386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98933, 7019, 'Click BBB S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/258387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98934, 7019, 'Click BBB S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/258388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98935, 7019, 'Click BBB S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/258389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98936, 7019, 'Click BBB S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/258390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98937, 7019, 'Click BBB S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/258391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98938, 7019, 'Click BBB S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/258392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98939, 7019, 'Click BBB S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/258393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98940, 7019, 'Click BBB S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/258394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98941, 7019, 'Click BBB S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/258395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98942, 7019, 'Click BBB S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/258396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98943, 7019, 'Click BBB S01 E119', 'http://sinalprivado.info:80/series/1533784/1533784/258397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98944, 7019, 'Click BBB S01 E120', 'http://sinalprivado.info:80/series/1533784/1533784/258398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98945, 7019, 'Click BBB S01 E121', 'http://sinalprivado.info:80/series/1533784/1533784/258399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98946, 7019, 'Click BBB S01 E122', 'http://sinalprivado.info:80/series/1533784/1533784/258400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98947, 7019, 'Click BBB S01 E123', 'http://sinalprivado.info:80/series/1533784/1533784/258401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98948, 7019, 'Click BBB S01 E124', 'http://sinalprivado.info:80/series/1533784/1533784/258402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98949, 7019, 'Click BBB S01 E125', 'http://sinalprivado.info:80/series/1533784/1533784/258403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98950, 7019, 'Click BBB S01 E126', 'http://sinalprivado.info:80/series/1533784/1533784/258404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98951, 7019, 'Click BBB S01 E127', 'http://sinalprivado.info:80/series/1533784/1533784/258405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98952, 7019, 'Click BBB S01 E128', 'http://sinalprivado.info:80/series/1533784/1533784/258406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98953, 7019, 'Click BBB S01 E129', 'http://sinalprivado.info:80/series/1533784/1533784/258407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98954, 7019, 'Click BBB S01 E130', 'http://sinalprivado.info:80/series/1533784/1533784/258408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98955, 7019, 'Click BBB S01 E131', 'http://sinalprivado.info:80/series/1533784/1533784/258409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98956, 7019, 'Click BBB S01 E132', 'http://sinalprivado.info:80/series/1533784/1533784/258410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98957, 7019, 'Click BBB S01 E133', 'http://sinalprivado.info:80/series/1533784/1533784/258411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(98958, 7019, 'Click BBB S01 E134', 'http://sinalprivado.info:80/series/1533784/1533784/258412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98959, 7019, 'Click BBB S01 E135', 'http://sinalprivado.info:80/series/1533784/1533784/258413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98960, 7019, 'Click BBB S01 E136', 'http://sinalprivado.info:80/series/1533784/1533784/258414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98961, 7019, 'Click BBB S01 E137', 'http://sinalprivado.info:80/series/1533784/1533784/258415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98962, 7019, 'Click BBB S01 E138', 'http://sinalprivado.info:80/series/1533784/1533784/258416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98963, 7019, 'Click BBB S01 E139', 'http://sinalprivado.info:80/series/1533784/1533784/258417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98964, 7019, 'Click BBB S01 E140', 'http://sinalprivado.info:80/series/1533784/1533784/258418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98965, 7019, 'Click BBB S01 E141', 'http://sinalprivado.info:80/series/1533784/1533784/258419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98966, 7019, 'Click BBB S01 E142', 'http://sinalprivado.info:80/series/1533784/1533784/258420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98967, 7019, 'Click BBB S01 E143', 'http://sinalprivado.info:80/series/1533784/1533784/258421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98968, 7019, 'Click BBB S01 E144', 'http://sinalprivado.info:80/series/1533784/1533784/258422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98969, 7019, 'Click BBB S01 E145', 'http://sinalprivado.info:80/series/1533784/1533784/258423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98970, 7019, 'Click BBB S01 E146', 'http://sinalprivado.info:80/series/1533784/1533784/258424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98971, 7019, 'Click BBB S01 E147', 'http://sinalprivado.info:80/series/1533784/1533784/258425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98972, 7019, 'Click BBB S01 E148', 'http://sinalprivado.info:80/series/1533784/1533784/258426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98973, 7019, 'Click BBB S01 E149', 'http://sinalprivado.info:80/series/1533784/1533784/258427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98974, 7019, 'Click BBB S01 E150', 'http://sinalprivado.info:80/series/1533784/1533784/258428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98975, 7019, 'Click BBB S01 E151', 'http://sinalprivado.info:80/series/1533784/1533784/258429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98976, 7019, 'Click BBB S01 E152', 'http://sinalprivado.info:80/series/1533784/1533784/258430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98977, 7019, 'Click BBB S01 E153', 'http://sinalprivado.info:80/series/1533784/1533784/258431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98978, 7019, 'Click BBB S01 E154', 'http://sinalprivado.info:80/series/1533784/1533784/258432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98979, 7019, 'Click BBB S01 E155', 'http://sinalprivado.info:80/series/1533784/1533784/258433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98980, 7019, 'Click BBB S01 E156', 'http://sinalprivado.info:80/series/1533784/1533784/258434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98981, 7019, 'Click BBB S01 E157', 'http://sinalprivado.info:80/series/1533784/1533784/258435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98982, 7019, 'Click BBB S01 E158', 'http://sinalprivado.info:80/series/1533784/1533784/258436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98983, 7019, 'Click BBB S01 E159', 'http://sinalprivado.info:80/series/1533784/1533784/258437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98984, 7019, 'Click BBB S01 E160', 'http://sinalprivado.info:80/series/1533784/1533784/258438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98985, 7019, 'Click BBB S01 E161', 'http://sinalprivado.info:80/series/1533784/1533784/258439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98986, 7019, 'Click BBB S01 E162', 'http://sinalprivado.info:80/series/1533784/1533784/258440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98987, 7019, 'Click BBB S01 E163', 'http://sinalprivado.info:80/series/1533784/1533784/258441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98988, 7019, 'Click BBB S01 E164', 'http://sinalprivado.info:80/series/1533784/1533784/258442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98989, 7019, 'Click BBB S01 E165', 'http://sinalprivado.info:80/series/1533784/1533784/258443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98990, 7019, 'Click BBB S01 E166', 'http://sinalprivado.info:80/series/1533784/1533784/258444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98991, 7019, 'Click BBB S01 E167', 'http://sinalprivado.info:80/series/1533784/1533784/258445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98992, 7019, 'Click BBB S01 E168', 'http://sinalprivado.info:80/series/1533784/1533784/258446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98993, 7019, 'Click BBB S01 E169', 'http://sinalprivado.info:80/series/1533784/1533784/258447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98994, 7019, 'Click BBB S01 E170', 'http://sinalprivado.info:80/series/1533784/1533784/258448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98995, 7019, 'Click BBB S01 E171', 'http://sinalprivado.info:80/series/1533784/1533784/258449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98996, 7019, 'Click BBB S01 E172', 'http://sinalprivado.info:80/series/1533784/1533784/258450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98997, 7019, 'Click BBB S01 E173', 'http://sinalprivado.info:80/series/1533784/1533784/258451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98998, 7019, 'Click BBB S01 E174', 'http://sinalprivado.info:80/series/1533784/1533784/258452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(98999, 7019, 'Click BBB S01 E175', 'http://sinalprivado.info:80/series/1533784/1533784/258453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99000, 7019, 'Click BBB S01 E176', 'http://sinalprivado.info:80/series/1533784/1533784/258454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99001, 7019, 'Click BBB S01 E177', 'http://sinalprivado.info:80/series/1533784/1533784/258455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99002, 7019, 'Click BBB S01 E178', 'http://sinalprivado.info:80/series/1533784/1533784/258456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99003, 7019, 'Click BBB S01 E179', 'http://sinalprivado.info:80/series/1533784/1533784/258457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99004, 7019, 'Click BBB S01 E180', 'http://sinalprivado.info:80/series/1533784/1533784/258458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99005, 7019, 'Click BBB S01 E181', 'http://sinalprivado.info:80/series/1533784/1533784/258459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99006, 7019, 'Click BBB S01 E182', 'http://sinalprivado.info:80/series/1533784/1533784/258460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99007, 7019, 'Click BBB S01 E183', 'http://sinalprivado.info:80/series/1533784/1533784/258461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99008, 7019, 'Click BBB S01 E184', 'http://sinalprivado.info:80/series/1533784/1533784/258462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99009, 7019, 'Click BBB S01 E185', 'http://sinalprivado.info:80/series/1533784/1533784/258463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99010, 7019, 'Click BBB S01 E186', 'http://sinalprivado.info:80/series/1533784/1533784/258464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99011, 7019, 'Click BBB S01 E187', 'http://sinalprivado.info:80/series/1533784/1533784/258465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99012, 7019, 'Click BBB S01 E188', 'http://sinalprivado.info:80/series/1533784/1533784/258466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99013, 7019, 'Click BBB S01 E189', 'http://sinalprivado.info:80/series/1533784/1533784/258467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99014, 7019, 'Click BBB S01 E190', 'http://sinalprivado.info:80/series/1533784/1533784/258468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99015, 7019, 'Click BBB S01 E191', 'http://sinalprivado.info:80/series/1533784/1533784/258469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99016, 7019, 'Click BBB S01 E192', 'http://sinalprivado.info:80/series/1533784/1533784/258470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99017, 7019, 'Click BBB S01 E193', 'http://sinalprivado.info:80/series/1533784/1533784/258471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99018, 7019, 'Click BBB S01 E194', 'http://sinalprivado.info:80/series/1533784/1533784/258472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99019, 7019, 'Click BBB S01 E195', 'http://sinalprivado.info:80/series/1533784/1533784/258473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99020, 7019, 'Click BBB S01 E196', 'http://sinalprivado.info:80/series/1533784/1533784/258474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99021, 7019, 'Click BBB S01 E197', 'http://sinalprivado.info:80/series/1533784/1533784/258475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99022, 7019, 'Click BBB S01 E198', 'http://sinalprivado.info:80/series/1533784/1533784/258476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99023, 7019, 'Click BBB S01 E199', 'http://sinalprivado.info:80/series/1533784/1533784/258477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99024, 7019, 'Click BBB S01 E200', 'http://sinalprivado.info:80/series/1533784/1533784/258478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99025, 7019, 'Click BBB S01 E201', 'http://sinalprivado.info:80/series/1533784/1533784/258479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99026, 7019, 'Click BBB S01 E202', 'http://sinalprivado.info:80/series/1533784/1533784/258480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99027, 7019, 'Click BBB S01 E203', 'http://sinalprivado.info:80/series/1533784/1533784/258481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99028, 7019, 'Click BBB S01 E204', 'http://sinalprivado.info:80/series/1533784/1533784/258482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99029, 7019, 'Click BBB S01 E205', 'http://sinalprivado.info:80/series/1533784/1533784/258483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99030, 7019, 'Click BBB S01 E206', 'http://sinalprivado.info:80/series/1533784/1533784/258484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99031, 7019, 'Click BBB S01 E207', 'http://sinalprivado.info:80/series/1533784/1533784/258485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99032, 7019, 'Click BBB S01 E208', 'http://sinalprivado.info:80/series/1533784/1533784/258486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99033, 7019, 'Click BBB S01 E209', 'http://sinalprivado.info:80/series/1533784/1533784/258487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99034, 7019, 'Click BBB S01 E210', 'http://sinalprivado.info:80/series/1533784/1533784/258488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99035, 7019, 'Click BBB S01 E211', 'http://sinalprivado.info:80/series/1533784/1533784/258489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99036, 7019, 'Click BBB S01 E212', 'http://sinalprivado.info:80/series/1533784/1533784/258490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99037, 7019, 'Click BBB S01 E213', 'http://sinalprivado.info:80/series/1533784/1533784/258491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99038, 7019, 'Click BBB S01 E214', 'http://sinalprivado.info:80/series/1533784/1533784/258492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99039, 7019, 'Click BBB S01 E215', 'http://sinalprivado.info:80/series/1533784/1533784/258493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99040, 7019, 'Click BBB S01 E216', 'http://sinalprivado.info:80/series/1533784/1533784/258494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99041, 7019, 'Click BBB S01 E217', 'http://sinalprivado.info:80/series/1533784/1533784/258495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99042, 7019, 'Click BBB S01 E218', 'http://sinalprivado.info:80/series/1533784/1533784/258496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99043, 7019, 'Click BBB S01 E219', 'http://sinalprivado.info:80/series/1533784/1533784/258497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99044, 7019, 'Click BBB S01 E220', 'http://sinalprivado.info:80/series/1533784/1533784/258498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99045, 7019, 'Click BBB S01 E221', 'http://sinalprivado.info:80/series/1533784/1533784/258499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99046, 7019, 'Click BBB S01 E222', 'http://sinalprivado.info:80/series/1533784/1533784/258500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99047, 7019, 'Click BBB S01 E223', 'http://sinalprivado.info:80/series/1533784/1533784/258501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99048, 7019, 'Click BBB S01 E224', 'http://sinalprivado.info:80/series/1533784/1533784/258502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99049, 7019, 'Click BBB S01 E225', 'http://sinalprivado.info:80/series/1533784/1533784/258503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99050, 7019, 'Click BBB S01 E226', 'http://sinalprivado.info:80/series/1533784/1533784/258504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99051, 7019, 'Click BBB S01 E227', 'http://sinalprivado.info:80/series/1533784/1533784/258505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99052, 7019, 'Click BBB S01 E228', 'http://sinalprivado.info:80/series/1533784/1533784/258506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99053, 7019, 'Click BBB S01 E229', 'http://sinalprivado.info:80/series/1533784/1533784/258507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99054, 7019, 'Click BBB S01 E230', 'http://sinalprivado.info:80/series/1533784/1533784/258508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99055, 7019, 'Click BBB S01 E231', 'http://sinalprivado.info:80/series/1533784/1533784/258509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99056, 7019, 'Click BBB S01 E232', 'http://sinalprivado.info:80/series/1533784/1533784/258510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99057, 7019, 'Click BBB S01 E233', 'http://sinalprivado.info:80/series/1533784/1533784/258511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99058, 7019, 'Click BBB S01 E234', 'http://sinalprivado.info:80/series/1533784/1533784/258512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99059, 7019, 'Click BBB S01 E235', 'http://sinalprivado.info:80/series/1533784/1533784/258513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99060, 7019, 'Click BBB S01 E236', 'http://sinalprivado.info:80/series/1533784/1533784/258514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99061, 7019, 'Click BBB S01 E237', 'http://sinalprivado.info:80/series/1533784/1533784/258515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99062, 7019, 'Click BBB S01 E238', 'http://sinalprivado.info:80/series/1533784/1533784/258516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99063, 7019, 'Click BBB S01 E239', 'http://sinalprivado.info:80/series/1533784/1533784/258517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99064, 7019, 'Click BBB S01 E240', 'http://sinalprivado.info:80/series/1533784/1533784/258518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99065, 7019, 'Click BBB S01 E241', 'http://sinalprivado.info:80/series/1533784/1533784/258519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99066, 7019, 'Click BBB S01 E242', 'http://sinalprivado.info:80/series/1533784/1533784/258520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99067, 7019, 'Click BBB S01 E243', 'http://sinalprivado.info:80/series/1533784/1533784/258521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99068, 7019, 'Click BBB S01 E244', 'http://sinalprivado.info:80/series/1533784/1533784/258522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99069, 7019, 'Click BBB S01 E245', 'http://sinalprivado.info:80/series/1533784/1533784/258523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99070, 7019, 'Click BBB S01 E246', 'http://sinalprivado.info:80/series/1533784/1533784/258524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99071, 7019, 'Click BBB S01 E247', 'http://sinalprivado.info:80/series/1533784/1533784/258525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99072, 7019, 'Click BBB S01 E248', 'http://sinalprivado.info:80/series/1533784/1533784/258526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99073, 7019, 'Click BBB S01 E249', 'http://sinalprivado.info:80/series/1533784/1533784/258527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99074, 7019, 'Click BBB S01 E250', 'http://sinalprivado.info:80/series/1533784/1533784/258528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99075, 7019, 'Click BBB S01 E251', 'http://sinalprivado.info:80/series/1533784/1533784/258529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99076, 7019, 'Click BBB S01 E252', 'http://sinalprivado.info:80/series/1533784/1533784/258530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99077, 7019, 'Click BBB S01 E253', 'http://sinalprivado.info:80/series/1533784/1533784/258531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99078, 7019, 'Click BBB S01 E254', 'http://sinalprivado.info:80/series/1533784/1533784/258532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99079, 7019, 'Click BBB S01 E255', 'http://sinalprivado.info:80/series/1533784/1533784/258533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99080, 7019, 'Click BBB S01 E256', 'http://sinalprivado.info:80/series/1533784/1533784/258534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99081, 7019, 'Click BBB S01 E257', 'http://sinalprivado.info:80/series/1533784/1533784/258535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99082, 7019, 'Click BBB S01 E258', 'http://sinalprivado.info:80/series/1533784/1533784/258536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99083, 7019, 'Click BBB S01 E259', 'http://sinalprivado.info:80/series/1533784/1533784/258537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99084, 7019, 'Click BBB S01 E260', 'http://sinalprivado.info:80/series/1533784/1533784/258538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99085, 7019, 'Click BBB S01 E261', 'http://sinalprivado.info:80/series/1533784/1533784/258539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99086, 7019, 'Click BBB S01 E262', 'http://sinalprivado.info:80/series/1533784/1533784/258540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99087, 7019, 'Click BBB S01 E263', 'http://sinalprivado.info:80/series/1533784/1533784/258541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99088, 7019, 'Click BBB S01 E264', 'http://sinalprivado.info:80/series/1533784/1533784/258542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99089, 7019, 'Click BBB S01 E265', 'http://sinalprivado.info:80/series/1533784/1533784/258543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99090, 7019, 'Click BBB S01 E266', 'http://sinalprivado.info:80/series/1533784/1533784/258544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99091, 7019, 'Click BBB S01 E267', 'http://sinalprivado.info:80/series/1533784/1533784/258545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99092, 7019, 'Click BBB S01 E268', 'http://sinalprivado.info:80/series/1533784/1533784/258546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99093, 7019, 'Click BBB S01 E269', 'http://sinalprivado.info:80/series/1533784/1533784/258547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99094, 7019, 'Click BBB S01 E270', 'http://sinalprivado.info:80/series/1533784/1533784/258548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99095, 7019, 'Click BBB S01 E271', 'http://sinalprivado.info:80/series/1533784/1533784/258549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99096, 7019, 'Click BBB S01 E272', 'http://sinalprivado.info:80/series/1533784/1533784/258550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99097, 7019, 'Click BBB S01 E273', 'http://sinalprivado.info:80/series/1533784/1533784/258551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99098, 7019, 'Click BBB S01 E274', 'http://sinalprivado.info:80/series/1533784/1533784/258552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99099, 7019, 'Click BBB S01 E275', 'http://sinalprivado.info:80/series/1533784/1533784/258553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99100, 7019, 'Click BBB S01 E276', 'http://sinalprivado.info:80/series/1533784/1533784/258554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99101, 7019, 'Click BBB S01 E277', 'http://sinalprivado.info:80/series/1533784/1533784/258555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99102, 7019, 'Click BBB S01 E278', 'http://sinalprivado.info:80/series/1533784/1533784/258556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99103, 7019, 'Click BBB S01 E279', 'http://sinalprivado.info:80/series/1533784/1533784/258557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99104, 7019, 'Click BBB S01 E280', 'http://sinalprivado.info:80/series/1533784/1533784/258558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99105, 7019, 'Click BBB S01 E281', 'http://sinalprivado.info:80/series/1533784/1533784/258559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99106, 7019, 'Click BBB S01 E282', 'http://sinalprivado.info:80/series/1533784/1533784/258560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99107, 7019, 'Click BBB S01 E283', 'http://sinalprivado.info:80/series/1533784/1533784/258561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99108, 7019, 'Click BBB S01 E284', 'http://sinalprivado.info:80/series/1533784/1533784/258562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99109, 7019, 'Click BBB S01 E285', 'http://sinalprivado.info:80/series/1533784/1533784/258563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99110, 7019, 'Click BBB S01 E286', 'http://sinalprivado.info:80/series/1533784/1533784/258564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99111, 7019, 'Click BBB S01 E287', 'http://sinalprivado.info:80/series/1533784/1533784/258565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99112, 7019, 'Click BBB S01 E288', 'http://sinalprivado.info:80/series/1533784/1533784/258566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99113, 7019, 'Click BBB S01 E289', 'http://sinalprivado.info:80/series/1533784/1533784/258567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99114, 7019, 'Click BBB S01 E290', 'http://sinalprivado.info:80/series/1533784/1533784/258568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99115, 7019, 'Click BBB S01 E291', 'http://sinalprivado.info:80/series/1533784/1533784/258569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99116, 7019, 'Click BBB S01 E292', 'http://sinalprivado.info:80/series/1533784/1533784/258570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99117, 7019, 'Click BBB S01 E293', 'http://sinalprivado.info:80/series/1533784/1533784/258571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99118, 7019, 'Click BBB S01 E294', 'http://sinalprivado.info:80/series/1533784/1533784/258572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99119, 7019, 'Click BBB S01 E295', 'http://sinalprivado.info:80/series/1533784/1533784/258573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99120, 7020, 'Click BBB S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99121, 7020, 'Click BBB S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99122, 7020, 'Click BBB S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99123, 7020, 'Click BBB S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99124, 7020, 'Click BBB S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99125, 7020, 'Click BBB S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99126, 7020, 'Click BBB S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99127, 7020, 'Click BBB S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99128, 7020, 'Click BBB S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99129, 7020, 'Click BBB S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99130, 7020, 'Click BBB S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/258584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99131, 7020, 'Click BBB S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/258585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99132, 7020, 'Click BBB S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/258586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99133, 7020, 'Click BBB S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/258587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99134, 7020, 'Click BBB S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/258588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99135, 7020, 'Click BBB S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/258589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99136, 7020, 'Click BBB S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/258590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99137, 7020, 'Click BBB S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/258591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99138, 7020, 'Click BBB S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/258592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99139, 7020, 'Click BBB S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/258593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99140, 7020, 'Click BBB S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/258594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99141, 7020, 'Click BBB S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/258595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99142, 7020, 'Click BBB S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/258596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99143, 7020, 'Click BBB S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/258597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99144, 7020, 'Click BBB S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/258598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s21uxE8G3N8g6jCLHDc9OePhVEv.jpg'),
(99145, 7021, 'Freeridge S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xATD0DPCHVhsVlaYqnSfsFaKCOj.jpg'),
(99146, 7021, 'Freeridge S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vwH74wV4NyPCQFZYb1o7T5kmRtF.jpg'),
(99147, 7021, 'Freeridge S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QYYb2UKSGCQYWQ37GaXiagRo3h.jpg'),
(99148, 7021, 'Freeridge S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/njrfatZZCLx5KmZdpecM1Iap8bt.jpg'),
(99149, 7021, 'Freeridge S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a0Z9YdxbJ1tpDdSnK3ySaUgAooB.jpg'),
(99150, 7021, 'Freeridge S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ocUR9mCsLdo4YfNoEGN2dIxsgeG.jpg'),
(99151, 7021, 'Freeridge S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lZfR4Xe6C1NUGZqhNKVV1rHhjkH.jpg'),
(99152, 7021, 'Freeridge S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u4a5WFNGshcnF8Nt6ybA9Vxjx3h.jpg'),
(99153, 7022, 'Gunther: O Cachorro Milionário S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qrnoHNmsWzVXJsYotXP6ZgMRXqe.jpg'),
(99154, 7022, 'Gunther: O Cachorro Milionário S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5VamgGmYhK2YqF5ARs54DclKnTo.jpg'),
(99155, 7022, 'Gunther: O Cachorro Milionário S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lfdY5Np7HGUkUDWpgBxAyNwZQY8.jpg'),
(99156, 7022, 'Gunther: O Cachorro Milionário S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqeEUaYWv60dde9ujbVsijHbDa5.jpg'),
(99157, 7023, 'MAKE MY DAY S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1iRxrYE5QB3XF5zhMMKxt5NiGWv.jpg'),
(99158, 7023, 'MAKE MY DAY S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fKPOzTwyRWajMfhIo0nzQYNAWzy.jpg'),
(99159, 7023, 'MAKE MY DAY S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Eo4PM2fmvki02j0UXuOXFCxjB5.jpg'),
(99160, 7023, 'MAKE MY DAY S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xW6vHMBTWiWxXaEZxbamden61zL.jpg'),
(99161, 7023, 'MAKE MY DAY S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4s3A9pNErorKPHTwJRcaVzYIu9w.jpg'),
(99162, 7023, 'MAKE MY DAY S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUjlhOrmWmlVIyo32cEZVRbCNZG.jpg'),
(99163, 7023, 'MAKE MY DAY S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/abtCKmTrCVsR6impfCOST8Pwpzx.jpg'),
(99164, 7023, 'MAKE MY DAY S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5cKjtIb9zpAptSUKZ1v4L3ZrFPp.jpg'),
(99165, 7024, 'Minha Mãe Cozinha Melhor Que a Sua S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qHSui0RxB5p1LUaScaE7VWEhMQn.jpg'),
(99166, 7024, 'Minha Mãe Cozinha Melhor Que a Sua S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qHSui0RxB5p1LUaScaE7VWEhMQn.jpg'),
(99167, 7024, 'Minha Mãe Cozinha Melhor Que a Sua S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qHSui0RxB5p1LUaScaE7VWEhMQn.jpg'),
(99168, 7024, 'Minha Mãe Cozinha Melhor Que a Sua S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qHSui0RxB5p1LUaScaE7VWEhMQn.jpg'),
(99169, 7024, 'Minha Mãe Cozinha Melhor Que a Sua S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qHSui0RxB5p1LUaScaE7VWEhMQn.jpg'),
(99170, 7024, 'Minha Mãe Cozinha Melhor Que a Sua S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qHSui0RxB5p1LUaScaE7VWEhMQn.jpg'),
(99171, 7024, 'Minha Mãe Cozinha Melhor Que a Sua S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qHSui0RxB5p1LUaScaE7VWEhMQn.jpg'),
(99172, 7024, 'Minha Mãe Cozinha Melhor Que a Sua S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qHSui0RxB5p1LUaScaE7VWEhMQn.jpg'),
(99173, 7024, 'Minha Mãe Cozinha Melhor Que a Sua S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qHSui0RxB5p1LUaScaE7VWEhMQn.jpg'),
(99174, 7024, 'Minha Mãe Cozinha Melhor Que a Sua S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212167.mp4', 'http://image.tmdb.org/t/p/w1280/p7HtRF7d4Yve7jAgK9GhlX3D2RQ.jpg'),
(99175, 7025, 'Sua Esposa e a Canoa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mIxdZ9P7sbnJxoyyNzHFgjzAz05.jpg'),
(99176, 7025, 'Sua Esposa e a Canoa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAXpGGltSVzAeoj1yGOd1NjcDyg.jpg'),
(99177, 7025, 'Sua Esposa e a Canoa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2UzaQ94slAiVg0FEI5NLbSVLcsN.jpg'),
(99178, 7025, 'Sua Esposa e a Canoa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/soTPsGfcAmFjBzSB4h2w1vWnHwF.jpg'),
(99179, 7026, 'Querido Edward S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g43Hvc3RiIrtVPTx8bzacSDl0PM.jpg'),
(99180, 7026, 'Querido Edward S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/roQUUROFC5Y3S65sQjtXEn4Mi41.jpg'),
(99181, 7026, 'Querido Edward S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qjaQjVpcRS0AANZCud9gQBzOCNo.jpg'),
(99182, 7026, 'Querido Edward S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208828.mp4', 'http://image.tmdb.org/t/p/w1280/phYnxapVaYAcDnwWq3AccQujRtP.jpg'),
(99183, 7026, 'Querido Edward S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208829.mp4', 'http://image.tmdb.org/t/p/w1280/kg3ZIKn6CSNffNj7ELTDOt65nZe.jpg'),
(99184, 7026, 'Querido Edward S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208830.mp4', 'http://image.tmdb.org/t/p/w1280/wcbZPYuxmnTgnblt77V4zUvryt8.jpg'),
(99185, 7026, 'Querido Edward S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208831.mp4', 'http://image.tmdb.org/t/p/w1280/tUD6AnLSATcYE1gtsk987zru0qd.jpg'),
(99186, 7026, 'Querido Edward S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208832.mp4', 'http://image.tmdb.org/t/p/w1280/4jysp3pRZyYcCwqs9YvWQHt23ee.jpg'),
(99187, 7026, 'Querido Edward S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208833.mp4', 'http://image.tmdb.org/t/p/w1280/asWlOwT3leLwYZokypA4G2ZDrKN.jpg'),
(99188, 7026, 'Querido Edward S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208834.mp4', 'http://image.tmdb.org/t/p/w1280/lglxIdBwtutrNl7FBPBJJo7Lsel.jpg'),
(99189, 7027, 'The Teacher S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wRNxjIa5FlcygMQALIBEqKHIc9Z.jpg'),
(99190, 7027, 'The Teacher S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kGlnCPQ73UL9vfbnn58mi4XudkN.jpg'),
(99191, 7027, 'The Teacher S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ibdNxtFLpLb5OppdzZ0vM6FnW7C.jpg'),
(99192, 7027, 'The Teacher S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jkIswXXnUAQ2PcDddmfbGvtsHAP.jpg'),
(99193, 7028, 'O Clube das Coisas Mágicas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uboWa4fXkSTo3T51uwNBFT0SiyG.jpg'),
(99194, 7028, 'O Clube das Coisas Mágicas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/28vnkC6fEYegZFdgZRbDJmUEpvx.jpg'),
(99195, 7028, 'O Clube das Coisas Mágicas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a5NGXwlR0GHWPtJFmhwWNcblbSY.jpg'),
(99196, 7028, 'O Clube das Coisas Mágicas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hVgOqTkvdeo3up0zY0ZEu4hSFLI.jpg'),
(99197, 7028, 'O Clube das Coisas Mágicas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wljHIH4h8wExe3fszPcchA9Jy2e.jpg'),
(99198, 7028, 'O Clube das Coisas Mágicas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QmECPAYr4CLhSXQQQ5A6M1vV5k.jpg'),
(99199, 7028, 'O Clube das Coisas Mágicas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2gZqVT2Yyi9XtpMS3qGg1zaSsST.jpg'),
(99200, 7028, 'O Clube das Coisas Mágicas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jAhHc7kFbbWZrGQsScU63qXHBWj.jpg'),
(99201, 7028, 'O Clube das Coisas Mágicas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9XRRzIUDF1EYcxvHGGirVoiWI79.jpg'),
(99202, 7028, 'O Clube das Coisas Mágicas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8wh8ToHBLSV1oJpxKezMjdswWcR.jpg'),
(99203, 7028, 'O Clube das Coisas Mágicas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gfoYGs7GnIpQOIL3En1f0JG313g.jpg'),
(99204, 7028, 'O Clube das Coisas Mágicas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/khLjQq9E8H47QTm6O28hLqYZXgS.jpg'),
(99205, 7028, 'O Clube das Coisas Mágicas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2VdXvNawwAeyo31U5oNUfcAApH.jpg'),
(99206, 7028, 'O Clube das Coisas Mágicas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/204222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dsSlGODJyzbzp5I6lkDD07IZFc2.jpg'),
(99207, 7028, 'O Clube das Coisas Mágicas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/204223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wp7UlZmv0xHmdWvFSARwx4WvzAa.jpg'),
(99208, 7028, 'O Clube das Coisas Mágicas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/204224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ckxcNeMQ5Sj6WJrc1OqbneWqmKd.jpg'),
(99209, 7028, 'O Clube das Coisas Mágicas S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/204225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gaWHnokP9qBhKLCVtFLNurwzKtc.jpg'),
(99210, 7028, 'O Clube das Coisas Mágicas S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/204226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kkMfSLO6VyEda2YLSSe6uvoR5.jpg'),
(99211, 7028, 'O Clube das Coisas Mágicas S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/204227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOlcuWREt4sbyUpuR0NSKvMfpey.jpg'),
(99212, 7028, 'O Clube das Coisas Mágicas S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/204228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x43fYe0uxGb6Kn4aSkWjAM6eRJ1.jpg'),
(99213, 7029, 'O Clube das Coisas Mágicas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1BdlI12tEZCf6gy1cUA5OQBD183.jpg'),
(99214, 7029, 'O Clube das Coisas Mágicas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zTdVMRky5TV1p1miIOC8hSwSRop.jpg'),
(99215, 7029, 'O Clube das Coisas Mágicas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wJRU1do0dTWaj8nWK6EAbQDBz4P.jpg'),
(99216, 7029, 'O Clube das Coisas Mágicas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sKmu2KMfKTZO0EAHxajJUACgnSV.jpg'),
(99217, 7029, 'O Clube das Coisas Mágicas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dECA0E0DCz3ssmhCzXS7iEz4hy4.jpg'),
(99218, 7029, 'O Clube das Coisas Mágicas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/91CqOKoIVhe9zVLmU4KxfbJoiOa.jpg'),
(99219, 7029, 'O Clube das Coisas Mágicas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bYqMR9ZY6KcWJv767KoJ6YcHlRP.jpg'),
(99220, 7029, 'O Clube das Coisas Mágicas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5nJTLHmeg2v6cTJNCd1iHU6uUc0.jpg'),
(99221, 7029, 'O Clube das Coisas Mágicas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iREWMricIGaWofOfbzo2RdMEUmi.jpg'),
(99222, 7029, 'O Clube das Coisas Mágicas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oRGP3xjCYnd1BzIobRfo3bSLZuC.jpg'),
(99223, 7029, 'O Clube das Coisas Mágicas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nRiUkWCzL50M5FmjTzOpqZmTzgT.jpg'),
(99224, 7029, 'O Clube das Coisas Mágicas S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q47pwnXWRVVo7JImqkVEshudm9R.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(99225, 7029, 'O Clube das Coisas Mágicas S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cWtvP788wRgTZeJMp9IehnKddf9.jpg'),
(99226, 7029, 'O Clube das Coisas Mágicas S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/347088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dl5GFhHjC4NM8kY9HaMnZxLjosq.jpg'),
(99227, 7029, 'O Clube das Coisas Mágicas S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/347089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o0FNmANgOcmHrx7JprRa4dwOWbz.jpg'),
(99228, 7029, 'O Clube das Coisas Mágicas S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/347090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8OVPQsRWrLvjizgn7NDHOICq7L.jpg'),
(99229, 7029, 'O Clube das Coisas Mágicas S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/347091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oGz1A2zvvp9l2eeJ6zmx7YjHqLD.jpg'),
(99230, 7029, 'O Clube das Coisas Mágicas S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/347092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b4yQOVBBx5naqAvI6iEreCOmZPI.jpg'),
(99231, 7029, 'O Clube das Coisas Mágicas S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/347093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5jHU5RSDuQQs667IVkLMJ88yMwk.jpg'),
(99232, 7029, 'O Clube das Coisas Mágicas S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/347094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g3X0HQbu20EOP8YFwyx0Lqr8QWN.jpg'),
(99233, 7030, 'A Rainha do Tráfico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/204146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2uDeyXAUQAo21kVVJmG6yRq0ddn.jpg'),
(99234, 7030, 'A Rainha do Tráfico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/204147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nARf2Vz1Or5rxC4M5KxpQhWaxE7.jpg'),
(99235, 7030, 'A Rainha do Tráfico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/204148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/chtbnVSBvv5OoJ2ZYcrVls62yMP.jpg'),
(99236, 7030, 'A Rainha do Tráfico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/204149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sibCLOwKDWtpb0v2oDZVUmTIKDg.jpg'),
(99237, 7030, 'A Rainha do Tráfico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/204150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xM3nmxCjlEyYt36BhMrgHDjggkU.jpg'),
(99238, 7030, 'A Rainha do Tráfico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/204151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qJvzkUqEAmSZJxpdL4lmLbSNBFX.jpg'),
(99239, 7030, 'A Rainha do Tráfico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/204152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/htdsXnlnyRGMPO7WheXOvKt4Mc.jpg'),
(99240, 7030, 'A Rainha do Tráfico S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/204153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1YBEhw6mvasyX7lmN8sYkCuGbHC.jpg'),
(99241, 7030, 'A Rainha do Tráfico S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/204154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cjj6MdPX3mr5G5HCif9IlnZi8IT.jpg'),
(99242, 7030, 'A Rainha do Tráfico S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/204155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qjK48PzNuE1ftOKQSjsO6JkGVgc.jpg'),
(99243, 7030, 'A Rainha do Tráfico S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/204156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q6WcFye4r7VMEksMmdPF43yACKX.jpg'),
(99244, 7030, 'A Rainha do Tráfico S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/204157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oFzmIjk6ZjkN5KBWsuuJUQaN2RS.jpg'),
(99245, 7030, 'A Rainha do Tráfico S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/204158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s7OTZ85qZWyNeZWX1T719meP1hb.jpg'),
(99246, 7030, 'A Rainha do Tráfico S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/204159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQDb2qjSWqYQDm8zaIH8V8gwGHS.jpg'),
(99247, 7030, 'A Rainha do Tráfico S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/204160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/508RyxK7csaRtIjAtJ1FPCo3Eg8.jpg'),
(99248, 7030, 'A Rainha do Tráfico S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/204161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b3loLdOXRvHqb3ig8HFeISA0VfD.jpg'),
(99249, 7030, 'A Rainha do Tráfico S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/204162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jFGIzTuqdcZSR2kYOgnH4C8AdNC.jpg'),
(99250, 7030, 'A Rainha do Tráfico S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/204163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oaKIFtoYAYHQ1EMqWJAqQw0I8Hr.jpg'),
(99251, 7030, 'A Rainha do Tráfico S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/204164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q5MkzzG4koHnzGQj7EHmJ77U3XC.jpg'),
(99252, 7030, 'A Rainha do Tráfico S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/204165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oFn8C8s5E0bMPMbopMjXYA7dePY.jpg'),
(99253, 7030, 'A Rainha do Tráfico S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/204166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6HcdbiS9ckyCRauMWfYlS8NlMK1.jpg'),
(99254, 7030, 'A Rainha do Tráfico S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/204167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/atRzstR5MYyoPTl5P6qQafVSPzC.jpg'),
(99255, 7030, 'A Rainha do Tráfico S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/204168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJ6sWZInQHUNVkI4LKEVhqbdZu9.jpg'),
(99256, 7030, 'A Rainha do Tráfico S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/204169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cVXXwZnQZIdwmE9ETThagFK0MIb.jpg'),
(99257, 7030, 'A Rainha do Tráfico S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/204170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gvy1zhPhpwOmkutFuy6ku1HC4yv.jpg'),
(99258, 7030, 'A Rainha do Tráfico S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/204171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mndPEKCNlFdcK0IgKYmuQjBnMZb.jpg'),
(99259, 7030, 'A Rainha do Tráfico S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/204172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sJUKOe1ECxHqu02eyz40YH0wlLQ.jpg'),
(99260, 7030, 'A Rainha do Tráfico S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/204173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pf3MURALsbsmtc5TWhG5MfqeiuS.jpg'),
(99261, 7030, 'A Rainha do Tráfico S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/204174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7wAGddngnX9z7kXUCjEsPrA66ge.jpg'),
(99262, 7030, 'A Rainha do Tráfico S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/204175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iFNkZTPe1j9SL3Q4KSZA2NwDTHo.jpg'),
(99263, 7030, 'A Rainha do Tráfico S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/204176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24dwquFuq51bgHhjxNM38fZ6AdZ.jpg'),
(99264, 7030, 'A Rainha do Tráfico S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/204177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hToCniXIjWXLE53HyoP8woRtLjd.jpg'),
(99265, 7030, 'A Rainha do Tráfico S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/204178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jNVvLC4e15L30xT2j67EmQesHMz.jpg'),
(99266, 7030, 'A Rainha do Tráfico S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/204179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kyvk9MwGOnVVTLCzpCGkD3XkfLs.jpg'),
(99267, 7030, 'A Rainha do Tráfico S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/204180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mLGjRt6Wsem6OJuY9p1Fplge3HY.jpg'),
(99268, 7030, 'A Rainha do Tráfico S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/204181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pB4qolG1IrgN93X5rAQBOk3uYnQ.jpg'),
(99269, 7030, 'A Rainha do Tráfico S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/204182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zIDdOL0VUaOR9J2y6tZf8A3OF6T.jpg'),
(99270, 7030, 'A Rainha do Tráfico S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/204183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Vmta4R1niHoBdzgcfZMDUIbW8c.jpg'),
(99271, 7030, 'A Rainha do Tráfico S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/204184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/VPQAJmWVj0Rr1nAhW5ngdfJxSy.jpg'),
(99272, 7030, 'A Rainha do Tráfico S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/204185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4oCA9zfH1KzeMtJi6dsn7iIRpZN.jpg'),
(99273, 7030, 'A Rainha do Tráfico S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/204186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sR3wTUKDT4cLe7oVt3kxeXt0QFw.jpg'),
(99274, 7030, 'A Rainha do Tráfico S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/204187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k3zAK9PQa79EggC5bN0ClZVXsBg.jpg'),
(99275, 7030, 'A Rainha do Tráfico S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/204188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lOZifZqHdzE1lFckfv4O0fT5WLm.jpg'),
(99276, 7030, 'A Rainha do Tráfico S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/204189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fTtoe96U4f2nSTn0sT8pUB0x3cl.jpg'),
(99277, 7030, 'A Rainha do Tráfico S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/204190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oIH0REBB0KNaHFZI1bjJslatzWB.jpg'),
(99278, 7030, 'A Rainha do Tráfico S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/204191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5RpvEFf6d6ObsrXaqKgNlCZLfxG.jpg'),
(99279, 7030, 'A Rainha do Tráfico S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/204192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zAp99hOwHlv4IJtgQbn422XAVcF.jpg'),
(99280, 7030, 'A Rainha do Tráfico S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/204193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nABmOtXPAZH1YdN76WMfoFFWbPA.jpg'),
(99281, 7030, 'A Rainha do Tráfico S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/204194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/243QtTKfa0hsRxyImiV5B0rt7Fh.jpg'),
(99282, 7030, 'A Rainha do Tráfico S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/204195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qowflzGYMaHFAs8GhHJdjfySPbQ.jpg'),
(99283, 7030, 'A Rainha do Tráfico S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/204196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z5a7lCdORE3jHSxfxPZHpAvWFsf.jpg'),
(99284, 7030, 'A Rainha do Tráfico S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/204197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iZqsP6Y0aOIdmOdLU8OLi6MFFcB.jpg'),
(99285, 7030, 'A Rainha do Tráfico S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/204198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uvwXfJRl78Nv3H8KnSKqWc2Reaq.jpg'),
(99286, 7030, 'A Rainha do Tráfico S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/204199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q5T3biCguvfy2VNzxuKAAdj0Bdf.jpg'),
(99287, 7030, 'A Rainha do Tráfico S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/204200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uI3L6jw15WttdhRUhdHlD4BWFr7.jpg'),
(99288, 7030, 'A Rainha do Tráfico S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/204201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nqQTIr3KZMLkUHR6HqDhMo9oai8.jpg'),
(99289, 7030, 'A Rainha do Tráfico S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/204202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4vyzKY2ZsiufGIPQhAHu3cizFpm.jpg'),
(99290, 7030, 'A Rainha do Tráfico S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/204203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pPJ65UKYYzsz41RML17TWaVjiA9.jpg'),
(99291, 7030, 'A Rainha do Tráfico S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/204204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wuJ7ULbuzzwKTVubk0CKNLlDCB4.jpg'),
(99292, 7030, 'A Rainha do Tráfico S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/204205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lS3s2k01HsY4oU166A2SdCK8MVg.jpg'),
(99293, 7030, 'A Rainha do Tráfico S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/204206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7oWEWulzXIuahzsWIFqwIN0n5vb.jpg'),
(99294, 7030, 'A Rainha do Tráfico S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/204207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jPqX4jMjn5m7Hv3f9CvRUExEtFJ.jpg'),
(99295, 7030, 'A Rainha do Tráfico S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/204208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xgM2sf9dvBuWw3OfLGupDSACCry.jpg'),
(99296, 7031, 'A Batalha dos 100 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7hVRn45I1X7IzieKB9jyTNhz8N.jpg'),
(99297, 7031, 'A Batalha dos 100 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4iUo01fThexeFcy9c980eh8BaVr.jpg'),
(99298, 7031, 'A Batalha dos 100 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2XGLUjDbm7WHzBzKHf2h57aAMc3.jpg'),
(99299, 7031, 'A Batalha dos 100 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gUFSrFeRUoIA4CejpNKLmCOAGe5.jpg'),
(99300, 7031, 'A Batalha dos 100 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q3YasTJs5jaoF5OZLcMo7vsKRjn.jpg'),
(99301, 7031, 'A Batalha dos 100 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rwZbZ97U719kcwVZ6BWdS1Gjhaw.jpg'),
(99302, 7031, 'A Batalha dos 100 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zphFucKY6E3OQTYo55R7gVn88VA.jpg'),
(99303, 7031, 'A Batalha dos 100 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u4vEzXGSHFKavZtOmt7sj3J3Wtt.jpg'),
(99304, 7031, 'A Batalha dos 100 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7dlexSecBodFJ4HWsTboa9ZIFby.jpg'),
(99305, 7032, 'A Batalha dos 100 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/305634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x5zev4oAG1KeQwtN6SIQOHlHQ7.jpg'),
(99306, 7032, 'A Batalha dos 100 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/305635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x5zev4oAG1KeQwtN6SIQOHlHQ7.jpg'),
(99307, 7032, 'A Batalha dos 100 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/305636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x5zev4oAG1KeQwtN6SIQOHlHQ7.jpg'),
(99308, 7032, 'A Batalha dos 100 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/305637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x5zev4oAG1KeQwtN6SIQOHlHQ7.jpg'),
(99309, 7032, 'A Batalha dos 100 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/311065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x5zev4oAG1KeQwtN6SIQOHlHQ7.jpg'),
(99310, 7032, 'A Batalha dos 100 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/311066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x5zev4oAG1KeQwtN6SIQOHlHQ7.jpg'),
(99311, 7032, 'A Batalha dos 100 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/311067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x5zev4oAG1KeQwtN6SIQOHlHQ7.jpg'),
(99312, 7032, 'A Batalha dos 100 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/320024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x5zev4oAG1KeQwtN6SIQOHlHQ7.jpg'),
(99313, 7032, 'A Batalha dos 100 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/320025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x5zev4oAG1KeQwtN6SIQOHlHQ7.jpg'),
(99314, 7033, 'Bill Russell: Lenda da NBA S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pAKtegB0T9CW4Rt2T6eu1Hx7frl.jpg'),
(99315, 7033, 'Bill Russell: Lenda da NBA S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/GXOniixwpAbpn9kCkwwQdjf3kp.jpg'),
(99316, 7034, 'Girlsquad S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2uIiYBfxAXYPzy15E50h2GVJLyX.jpg'),
(99317, 7034, 'Girlsquad S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2uIiYBfxAXYPzy15E50h2GVJLyX.jpg'),
(99318, 7034, 'Girlsquad S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2uIiYBfxAXYPzy15E50h2GVJLyX.jpg'),
(99319, 7034, 'Girlsquad S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2uIiYBfxAXYPzy15E50h2GVJLyX.jpg'),
(99320, 7034, 'Girlsquad S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2uIiYBfxAXYPzy15E50h2GVJLyX.jpg'),
(99321, 7034, 'Girlsquad S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2uIiYBfxAXYPzy15E50h2GVJLyX.jpg'),
(99322, 7034, 'Girlsquad S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2uIiYBfxAXYPzy15E50h2GVJLyX.jpg'),
(99323, 7034, 'Girlsquad S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2uIiYBfxAXYPzy15E50h2GVJLyX.jpg'),
(99324, 7034, 'Girlsquad S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2uIiYBfxAXYPzy15E50h2GVJLyX.jpg'),
(99325, 7034, 'Girlsquad S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2uIiYBfxAXYPzy15E50h2GVJLyX.jpg'),
(99326, 7035, 'Nagatoro-san S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gPHmaJaPjum8p0EQJUEAODCocSU.jpg'),
(99327, 7035, 'Nagatoro-san S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGUUwTuO421vefYBHHAk25r6QNA.jpg'),
(99328, 7035, 'Nagatoro-san S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6JcFHxIYzPR9Tm3w6SOvGSdRbK.jpg'),
(99329, 7035, 'Nagatoro-san S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMfl56ApbnjWVJnG88L2cNJZcox.jpg'),
(99330, 7035, 'Nagatoro-san S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/47NkwjIufJlpvwoIMWutY6ouYQY.jpg'),
(99331, 7035, 'Nagatoro-san S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fNcqar5vwNnm4UTARcocf5VpX8i.jpg'),
(99332, 7035, 'Nagatoro-san S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yV7mud2kHcHwHdYMefXcjfY1hMF.jpg'),
(99333, 7035, 'Nagatoro-san S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b6F3yTWXHgPFtIZ1uNIDEHu9XsA.jpg'),
(99334, 7035, 'Nagatoro-san S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rnACjMCqIePsuIxUVSHYsp8RLvH.jpg'),
(99335, 7035, 'Nagatoro-san S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4dtTGRJknmac8LCJD5DcA3kye6o.jpg'),
(99336, 7035, 'Nagatoro-san S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/foge2rHwne6PGSgmzBt7j8OKbe9.jpg'),
(99337, 7035, 'Nagatoro-san S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lJYv3eVHRJ8zBH8BGg5J2z6DdrQ.jpg'),
(99338, 7036, 'Nagatoro-san S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jWypcc7ZMNcH9TFl88KNpLDJ2d8.jpg'),
(99339, 7036, 'Nagatoro-san S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yaXWS97at25m06yeSGBlqRuYJ8L.jpg'),
(99340, 7036, 'Nagatoro-san S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLXkxzXcbp3AuA8x1my1WWOn8RM.jpg'),
(99341, 7036, 'Nagatoro-san S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gVwPMjvcd4lPGtTzPhfbs4nJLa2.jpg'),
(99342, 7036, 'Nagatoro-san S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9iMtyMmkduGYqlnmYP2xePLJqbd.jpg'),
(99343, 7036, 'Nagatoro-san S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gYFpIJD9oyCX3aQlH6e7BJ5k5Up.jpg'),
(99344, 7036, 'Nagatoro-san S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oneM2iL4GllhdGpUszAmGj9gyvd.jpg'),
(99345, 7036, 'Nagatoro-san S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/leaLqOwQFyGbJNUU3OLrUSeYJDq.jpg'),
(99346, 7036, 'Nagatoro-san S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdgtg2a88ZvVDmWIIz9v8Bme7Is.jpg'),
(99347, 7036, 'Nagatoro-san S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mAbFPhB3dw5CON2NIj23xwrd9pI.jpg'),
(99348, 7036, 'Nagatoro-san S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7deWd7sn8UL0MEAiSRabTZLZTm5.jpg'),
(99349, 7036, 'Nagatoro-san S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQecmambs9IRLO3XVJbeqoQjxzo.jpg'),
(99350, 7037, 'Investimento de Risco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mmJ2eKiFMsUYtLc9BAZFUkKTCCQ.jpg'),
(99351, 7037, 'Investimento de Risco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6t7iPJTpRhLEeMQOd0lb5mjnkHC.jpg'),
(99352, 7037, 'Investimento de Risco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mJlj2m9j2ktompNAplkvAxqBZhi.jpg'),
(99353, 7037, 'Investimento de Risco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qu5pKma2caaE0JICzniZHZKZAhF.jpg'),
(99354, 7037, 'Investimento de Risco S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uii2cH1jxwyWm7vAyBmUICZWBB2.jpg'),
(99355, 7037, 'Investimento de Risco S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sSBlNVNyzD0C2Vyuk0bRQRGHvOK.jpg'),
(99356, 7037, 'Investimento de Risco S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209687.mp4', 'http://image.tmdb.org/t/p/w1280/9J3lY7E5ylxVlbg4Y5uAdxQtiZE.jpg'),
(99357, 7037, 'Investimento de Risco S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209688.mp4', 'http://image.tmdb.org/t/p/w1280/qi2CsRHG2Ysc848MKCkTm2azLC0.jpg'),
(99358, 7037, 'Investimento de Risco S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209689.mp4', 'http://image.tmdb.org/t/p/w1280/xKLEmXCpa2TymfGa5AIFvkpNWeK.jpg'),
(99359, 7037, 'Investimento de Risco S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209690.mp4', 'http://image.tmdb.org/t/p/w1280/co7Vu0LesSknrLjr0YBw4JSX0Nz.jpg'),
(99360, 7037, 'Investimento de Risco S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/209691.mp4', 'http://image.tmdb.org/t/p/w1280/fmVN39BokJIrzrIythiwMY4834H.jpg'),
(99361, 7037, 'Investimento de Risco S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/209692.mp4', 'http://image.tmdb.org/t/p/w1280/fzNpkDkJnrjQ7xE9MybVqeOk5Ja.jpg'),
(99362, 7037, 'Investimento de Risco S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/209693.mp4', 'http://image.tmdb.org/t/p/w1280/lJJw4oWikCG1i1mhUt9T8FkwON4.jpg'),
(99363, 7037, 'Investimento de Risco S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/209694.mp4', 'http://image.tmdb.org/t/p/w1280/iQWd7dqn9nhVcebFQAMqKCClniB.jpg'),
(99364, 7037, 'Investimento de Risco S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/209695.mp4', 'http://image.tmdb.org/t/p/w1280/awgmSs7M97Lol1sHhq3H9NX4P69.jpg'),
(99365, 7037, 'Investimento de Risco S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/209696.mp4', 'http://image.tmdb.org/t/p/w1280/z7BAXWbOVqbqa5toh6lDRxsJ8vD.jpg'),
(99366, 7038, 'James May - O Mestre-Cuca! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m6KSbbJtRpX7KURPq0sp18woo2W.jpg'),
(99367, 7038, 'James May - O Mestre-Cuca! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zab7UPpoNsSDAcpZH3CONGYkCan.jpg'),
(99368, 7038, 'James May - O Mestre-Cuca! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ndsORlTRP1ghWjhWYaL2JGqtGdw.jpg'),
(99369, 7038, 'James May - O Mestre-Cuca! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oWBTXFtZwCrPaYctbLIopMXWEye.jpg'),
(99370, 7038, 'James May - O Mestre-Cuca! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/813QlMUqm5jaVna63OzpgyQdUZG.jpg'),
(99371, 7038, 'James May - O Mestre-Cuca! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/scdm1KmeDJOp9Szyvv6gTJHEbHq.jpg'),
(99372, 7038, 'James May - O Mestre-Cuca! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uMhhFM1rFWEVdxVs5H1WxYMSg3W.jpg'),
(99373, 7039, 'Kindred: Segredos e Raízes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ocLxB2I7eVqgKw5t1qRq0ZCbE8N.jpg'),
(99374, 7039, 'Kindred: Segredos e Raízes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rk31IozyAozKbybSoTnIZV6KdsH.jpg'),
(99375, 7039, 'Kindred: Segredos e Raízes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vVCygSZZEnhZqus0XKiWGnsUehf.jpg'),
(99376, 7039, 'Kindred: Segredos e Raízes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7tvoqptPglq44U1pSOiJIq6t7lF.jpg'),
(99377, 7039, 'Kindred: Segredos e Raízes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gsuAPlnCuB0ZWw3Y2Vb0uBXTJzb.jpg'),
(99378, 7039, 'Kindred: Segredos e Raízes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5KUCCo6GM8z8aP9IgQdt3LwKDkp.jpg'),
(99379, 7039, 'Kindred: Segredos e Raízes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJ9kDjJ2Ix77hSdySOPKQOuWkoh.jpg'),
(99380, 7039, 'Kindred: Segredos e Raízes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6jE3CABF3P9Xmh7IpVhDun6JllQ.jpg'),
(99381, 7040, 'Não Estou Morta! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNK5NcnSWnoeRw4xrDAzBlqxf2i.jpg'),
(99382, 7040, 'Não Estou Morta! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/685z8vyLxkWHA7pnW2vgkbFaU5o.jpg'),
(99383, 7040, 'Não Estou Morta! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213805.mp4', 'http://image.tmdb.org/t/p/w1280/cVRvSbks4xxlE3PNJ6WYqWaePzr.jpg'),
(99384, 7040, 'Não Estou Morta! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213806.mp4', 'http://image.tmdb.org/t/p/w1280/hwt6PU0ZXetPjOkM0xcXNTL9GVs.jpg'),
(99385, 7040, 'Não Estou Morta! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213807.mp4', 'http://image.tmdb.org/t/p/w1280/2yggMFNHXmTkxRTw7Lqw06vbY1b.jpg'),
(99386, 7040, 'Não Estou Morta! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213808.mp4', 'http://image.tmdb.org/t/p/w1280/1STHORnhCFWWRNinlpxrJcc5sWu.jpg'),
(99387, 7040, 'Não Estou Morta! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hLy3yJEdTykW2V8TC3gqBopkuml.jpg'),
(99388, 7040, 'Não Estou Morta! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fsVR8878gmSAHVRmSG4oMjN9Mn9.jpg'),
(99389, 7040, 'Não Estou Morta! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fRuXxajHFdae5SK0FNwJyEys4FF.jpg'),
(99390, 7040, 'Não Estou Morta! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pCYWK141Yu0TmC9aV4Q1AtVLnIt.jpg'),
(99391, 7040, 'Não Estou Morta! S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/213813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dygNu1ipn2EcHD9h9vhdog8z0gr.jpg'),
(99392, 7040, 'Não Estou Morta! S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/213814.mp4', 'http://image.tmdb.org/t/p/w1280/vxeoghXQIjhSR2mk58FabV6fMDe.jpg'),
(99393, 7040, 'Não Estou Morta! S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/213815.mp4', 'http://image.tmdb.org/t/p/w1280/gtRBjaepKEK4EJLlT7PMsAH8jD0.jpg'),
(99394, 7041, 'Não Estou Morta! S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/351612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dygNu1ipn2EcHD9h9vhdog8z0gr.jpg'),
(99395, 7041, 'Não Estou Morta! S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/367490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dygNu1ipn2EcHD9h9vhdog8z0gr.jpg'),
(99396, 7041, 'Não Estou Morta! S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/351613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dygNu1ipn2EcHD9h9vhdog8z0gr.jpg'),
(99397, 7041, 'Não Estou Morta! S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/351614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dygNu1ipn2EcHD9h9vhdog8z0gr.jpg'),
(99398, 7041, 'Não Estou Morta! S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/351615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dygNu1ipn2EcHD9h9vhdog8z0gr.jpg'),
(99399, 7041, 'Não Estou Morta! S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/367494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dygNu1ipn2EcHD9h9vhdog8z0gr.jpg'),
(99400, 7041, 'Não Estou Morta! S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/367495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dygNu1ipn2EcHD9h9vhdog8z0gr.jpg'),
(99401, 7041, 'Não Estou Morta! S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/373475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dygNu1ipn2EcHD9h9vhdog8z0gr.jpg'),
(99402, 7041, 'Não Estou Morta! S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/395936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dygNu1ipn2EcHD9h9vhdog8z0gr.jpg'),
(99403, 7041, 'Não Estou Morta! S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/395937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dygNu1ipn2EcHD9h9vhdog8z0gr.jpg'),
(99404, 6651, 'O Beijo do Destino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJZJZ90WvQ2i6nqfqn4hvnQJyFO.jpg'),
(99405, 6651, 'O Beijo do Destino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/efg6TqhP8V6SVmO7y0YEk2HzUjO.jpg'),
(99406, 6651, 'O Beijo do Destino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eOyQfD4MB9rTn7laygu1kAk9g7W.jpg'),
(99407, 6651, 'O Beijo do Destino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7SsXnubMCTqTaLFIizZMxopk1MQ.jpg'),
(99408, 6651, 'O Beijo do Destino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uCxjCOTnpiBg4IzJqnkh9Gcs2TE.jpg'),
(99409, 6651, 'O Beijo do Destino S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AdaW7sLyfQGzALaOcjULTwlDsdS.jpg'),
(99410, 6651, 'O Beijo do Destino S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZ5y54b0QzHGQYix52fxkXFwlxA.jpg'),
(99411, 6651, 'O Beijo do Destino S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kEY2oGnO1YwvbzqSjEP2WbS0z0u.jpg'),
(99412, 6651, 'O Beijo do Destino S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u2huUZJ0ILuAPoWI8DIJSdX67N4.jpg'),
(99413, 6651, 'O Beijo do Destino S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nn8LASYheNxcPsKYK7Ez0UU6QFv.jpg'),
(99414, 6651, 'O Beijo do Destino S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJMGsxvjVvTCs5zpNIWeCjIO6gn.jpg'),
(99415, 6651, 'O Beijo do Destino S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/VN01puCKAXK6lkou3GBLp3q8ng.jpg'),
(99416, 7042, 'O Degelo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dtqjvDSLAWPRMrknCfLtVdPYVav.jpg'),
(99417, 7042, 'O Degelo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qb9TKob3LY5Hcam259tJZNtqUWu.jpg'),
(99418, 7042, 'O Degelo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/drLKp55ZxibSY3528HEJadUL2aX.jpg'),
(99419, 7042, 'O Degelo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8138cFViNGesJwMHg1XFbkMKBCL.jpg'),
(99420, 7042, 'O Degelo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u3b49szZcBMcoB0pqss6lpEmAIU.jpg'),
(99421, 7042, 'O Degelo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4qywjMk6qOOMcF73g3Rqw5sUudG.jpg'),
(99422, 7043, 'O Degelo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/473907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sK1LSksdYxmQ3V3MOzqvCCeZd1M.jpg'),
(99423, 7043, 'O Degelo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/473908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sK1LSksdYxmQ3V3MOzqvCCeZd1M.jpg'),
(99424, 7043, 'O Degelo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/473909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sK1LSksdYxmQ3V3MOzqvCCeZd1M.jpg'),
(99425, 7043, 'O Degelo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/473910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sK1LSksdYxmQ3V3MOzqvCCeZd1M.jpg'),
(99426, 7043, 'O Degelo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/473911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sK1LSksdYxmQ3V3MOzqvCCeZd1M.jpg'),
(99427, 7043, 'O Degelo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/473912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sK1LSksdYxmQ3V3MOzqvCCeZd1M.jpg'),
(99428, 7044, 'O Meu Pai é um Caçador de Recompensas! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bOrFKH5OStSy8BKHCCxTgEyX84W.jpg'),
(99429, 7044, 'O Meu Pai é um Caçador de Recompensas! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5JyQN34ELX9dx62A8YIBbq1ip1v.jpg'),
(99430, 7044, 'O Meu Pai é um Caçador de Recompensas! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xjZU3XOqRTTE1SsNZxi3dgyd2RP.jpg'),
(99431, 7044, 'O Meu Pai é um Caçador de Recompensas! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1DjaexeoK90guZQxec52dKlSAWI.jpg'),
(99432, 7044, 'O Meu Pai é um Caçador de Recompensas! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AtVhIQUoFvYijZ3NHRz1BqIlw0G.jpg'),
(99433, 7044, 'O Meu Pai é um Caçador de Recompensas! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ruObbuBhFRtfZ7DiQQwEdLbNaw.jpg'),
(99434, 7044, 'O Meu Pai é um Caçador de Recompensas! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5vXVEFkDhYCZLJDXxnfUizY2Rk0.jpg'),
(99435, 7044, 'O Meu Pai é um Caçador de Recompensas! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nd8s0iOjnsUjosN71u9dYrbcvUm.jpg'),
(99436, 7044, 'O Meu Pai é um Caçador de Recompensas! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aRVhMywmvujqNTPzSLgR3EJnpwQ.jpg'),
(99437, 7044, 'O Meu Pai é um Caçador de Recompensas! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tgqhBjyVLMldGBS3hJwCsyhX3u3.jpg'),
(99438, 7045, 'O Meu Pai é um Caçador de Recompensas! S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pPmU70k8GxrQ2Oa2JeFbkZp2sta.jpg'),
(99439, 7045, 'O Meu Pai é um Caçador de Recompensas! S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rQOtPUa51Forv1f4rvKbebrGyEZ.jpg'),
(99440, 7045, 'O Meu Pai é um Caçador de Recompensas! S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fzTRiBftMvbJzHiPNwjHQe0bVrK.jpg'),
(99441, 7045, 'O Meu Pai é um Caçador de Recompensas! S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1x8Gj9Zf1t2z5tYsYn8Q3lMJXPQ.jpg'),
(99442, 7045, 'O Meu Pai é um Caçador de Recompensas! S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shAs1BUvpAarIIg44rdQ5DzdIg1.jpg'),
(99443, 7045, 'O Meu Pai é um Caçador de Recompensas! S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7QLEqHLeWzu9UVJjRO4O1jYJ0wz.jpg'),
(99444, 7045, 'O Meu Pai é um Caçador de Recompensas! S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yawivw4pvrF0gAxKgBBSR6hxoFW.jpg'),
(99445, 7045, 'O Meu Pai é um Caçador de Recompensas! S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o1wNbYM9hTXavfxwjSWuafXfUMF.jpg'),
(99446, 7046, 'Operação Maré Negra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208254.mp4', 'http://timg.bdta.pro/images/763eca7e49ebb48bd5dd889675454929.jpg'),
(99447, 7046, 'Operação Maré Negra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208255.mp4', 'http://timg.bdta.pro/images/a43d6b02d2d6bfb6e692ae84d38ca4aa.jpg'),
(99448, 7046, 'Operação Maré Negra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208256.mp4', 'http://timg.bdta.pro/images/7963e02728b6466d3d6f9289d9f2888d.jpg'),
(99449, 7046, 'Operação Maré Negra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208257.mp4', 'http://timg.bdta.pro/images/2d1e5810a3c53095438d89f1bbd6eee4.jpg'),
(99450, 7047, 'Operação Maré Negra S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/90KuUkL7BxlwGMQ3SbFy2T99aGm.jpg'),
(99451, 7047, 'Operação Maré Negra S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gg95zwOC0zCdsPc7J2dfMNPElK4.jpg'),
(99452, 7047, 'Operação Maré Negra S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hy7kbXqPPxwS7EHltxNYn3MJYhp.jpg'),
(99453, 7047, 'Operação Maré Negra S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hYOY6QriGXqPopeydkzNbU7pf8C.jpg'),
(99454, 7047, 'Operação Maré Negra S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bnji0n8eUNhfMaf5E06cxsAeZJO.jpg'),
(99455, 7048, 'Prisioneira do Profeta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oYjejeSDOQNVo8E5uMHnlfoDyO0.jpg'),
(99456, 7048, 'Prisioneira do Profeta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/stR96mLJwkxbYNdkYcXaB9M1mAO.jpg'),
(99457, 7048, 'Prisioneira do Profeta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fHl2mUvJuyMZ9AbGMv5RoSWNHgB.jpg'),
(99458, 7049, 'Rainhas da Bolsa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/giTLNNbq97PN2aWFULF0DwxH1Ir.jpg'),
(99459, 7049, 'Rainhas da Bolsa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nE4zk9R90WqZ6Zbp1p7HwatpfXK.jpg'),
(99460, 7049, 'Rainhas da Bolsa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qFadKyJzcc7hkBKYhEI3Cv69Qd1.jpg'),
(99461, 7049, 'Rainhas da Bolsa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2wwMIFNTW0lZAXcx8fUAePFz8lF.jpg'),
(99462, 7049, 'Rainhas da Bolsa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/afKvKWkuNFhB9IYXUihO68oGHcC.jpg'),
(99463, 7049, 'Rainhas da Bolsa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8RX7wfJh6BKX203ngUZIb6vr7Ao.jpg'),
(99464, 7050, 'Rainhas da Bolsa S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/697545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eQAF2WyM25KCAQhsPepMUMCOvSQ.jpg'),
(99465, 7050, 'Rainhas da Bolsa S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/697546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eQAF2WyM25KCAQhsPepMUMCOvSQ.jpg'),
(99466, 7050, 'Rainhas da Bolsa S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/697547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eQAF2WyM25KCAQhsPepMUMCOvSQ.jpg'),
(99467, 7050, 'Rainhas da Bolsa S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/697548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eQAF2WyM25KCAQhsPepMUMCOvSQ.jpg'),
(99468, 7050, 'Rainhas da Bolsa S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/697549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eQAF2WyM25KCAQhsPepMUMCOvSQ.jpg'),
(99469, 7050, 'Rainhas da Bolsa S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/697550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eQAF2WyM25KCAQhsPepMUMCOvSQ.jpg'),
(99470, 7051, 'Santo Maldito S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eNPSsRDjqpHdBMlGUG7Q0yJrJIv.jpg'),
(99471, 7051, 'Santo Maldito S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c2ITOLHKb21gIkKZ5LOQYREUR8t.jpg'),
(99472, 7051, 'Santo Maldito S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xHFh0niIrc00C5raUSdxiBJvebZ.jpg'),
(99473, 7051, 'Santo Maldito S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l4pmyVfVN4CUsXc0Y1dUFOdS1eg.jpg'),
(99474, 7051, 'Santo Maldito S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4WZ4Asu2NOc3lVhUhT4uZvOhCVX.jpg'),
(99475, 7051, 'Santo Maldito S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tmgKyFEXihA5irRGdGtZnrjtXZX.jpg'),
(99476, 7051, 'Santo Maldito S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h44me1nV2L9nXpb3w2RONg4vw9P.jpg'),
(99477, 7051, 'Santo Maldito S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1PizLiRbmp8M8EjzeRjJikBXGZ0.jpg'),
(99478, 7052, 'Intensivão de Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/564762.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AvrJ1jzyb22AmwhxpBQF1dyZwDp.jpg'),
(99479, 7052, 'Intensivão de Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/564763.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j6DwfGLB2h1yVl4yrz3rzzxGecg.jpg'),
(99480, 7052, 'Intensivão de Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/564764.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tPyK2RIqyd5puJ4wl4mbOvK0q2B.jpg'),
(99481, 7052, 'Intensivão de Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/564765.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/doD5Xpv8Zrw9pL2eeIuzzfY2tCh.jpg'),
(99482, 7052, 'Intensivão de Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/564766.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jTQogeMhf0gIqz4R45oqOZqoR5I.jpg'),
(99483, 7052, 'Intensivão de Amor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/564767.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wHQjjpYtgWpSiCObNM6mYbpdvc1.jpg'),
(99484, 7052, 'Intensivão de Amor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/564768.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7Ar2hQ3reXGrFw9k6G64ANCpLdB.jpg'),
(99485, 7052, 'Intensivão de Amor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/564769.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t9TUwrqc2ifQWjg32RdVXDXsyDV.jpg'),
(99486, 7052, 'Intensivão de Amor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/564770.mp4', 'http://image.tmdb.org//t/p/w1280/fe3G4Bi7hVY2EjjPkJmKlPbzTDZ.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(99487, 7052, 'Intensivão de Amor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/564771.mp4', 'http://image.tmdb.org//t/p/w1280/8uDFaV57hf7louVP3jTB064npdV.jpg'),
(99488, 7052, 'Intensivão de Amor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/564772.mp4', 'http://image.tmdb.org//t/p/w1280/xGFlIsLZVWfeM0CVReoBZc4ibZV.jpg'),
(99489, 7052, 'Intensivão de Amor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/564773.mp4', 'http://image.tmdb.org//t/p/w1280/6whzpaBM1iEly3PlQt2L5yKPT20.jpg'),
(99490, 7052, 'Intensivão de Amor S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/564774.mp4', 'http://image.tmdb.org//t/p/w1280/5fNZTMpYv8a5mN7IkF3PyfF9fh.jpg'),
(99491, 7052, 'Intensivão de Amor S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/564775.mp4', 'http://image.tmdb.org//t/p/w1280/5PYdKsXlwqJFjKWhrnlsacAd9Bj.jpg'),
(99492, 7052, 'Intensivão de Amor S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/564776.mp4', 'http://image.tmdb.org//t/p/w1280/lpGtMYx7TeWNcm2sAm4k0VR0Fnd.jpg'),
(99493, 7052, 'Intensivão de Amor S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/564777.mp4', 'http://image.tmdb.org//t/p/w1280/uzkQftHlkCU3NHftcoTwp7zZ1DW.jpg'),
(99494, 7053, 'New Girl S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tRT6I3fyex5Ft41F2ZQnk8s25nC.jpg'),
(99495, 7053, 'New Girl S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c23098HaZnczNYHI0LD2nuSeGKU.jpg'),
(99496, 7053, 'New Girl S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hasIrlgkoTHAWtUk8xcB5ETqjs6.jpg'),
(99497, 7053, 'New Girl S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b006ZAXbvnWGPRJUWmsSBnFVZM6.jpg'),
(99498, 7053, 'New Girl S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/crwWepZXgVx44Bs6L5cu58tnElI.jpg'),
(99499, 7053, 'New Girl S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jEcvFFGV3d5BeFrFWUoitUxTRaz.jpg'),
(99500, 7053, 'New Girl S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eRWvYgQnHLZW4X1lVF1DV8l0ibi.jpg'),
(99501, 7053, 'New Girl S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wiBJ3flxrV6Vt5EFwco1zZTxQTi.jpg'),
(99502, 7053, 'New Girl S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mFXynHZNZLKbFLUhvaYMBEB9dqb.jpg'),
(99503, 7053, 'New Girl S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jDP1zlDgFy4maKrR38DtAqVxQfT.jpg'),
(99504, 7053, 'New Girl S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4kGZIfYEYyhmarb0HsMzWrZpeTX.jpg'),
(99505, 7053, 'New Girl S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/veNVSNkmMiJB4NXLzI4TP51k9Vl.jpg'),
(99506, 7053, 'New Girl S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sxtol10fWOWa4QHVg6UsEi1aGBD.jpg'),
(99507, 7053, 'New Girl S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/207906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9iJlZJLYU2xObajrCcHVlL0Qswv.jpg'),
(99508, 7053, 'New Girl S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/207907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rSPfB3A6K5L8lYw9newsDWe7tFM.jpg'),
(99509, 7053, 'New Girl S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/207908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/orOpIRFNXNtrj6OM3i8fYG71Gqb.jpg'),
(99510, 7053, 'New Girl S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/207909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wWb0f5WyjjHX1xqCaSZgNoWYH6J.jpg'),
(99511, 7053, 'New Girl S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/207910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oal7iAPiL9r0SA5mWAdpO0xcST6.jpg'),
(99512, 7053, 'New Girl S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/207911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y5n69IV7XKKvFvcKUMHojotL8FZ.jpg'),
(99513, 7053, 'New Girl S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/207912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ge1ge7poMjCe82bkFJrK8nBgH3.jpg'),
(99514, 7053, 'New Girl S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/207913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dOxQDoZytJf37vWIWI8A5oQCWCA.jpg'),
(99515, 7053, 'New Girl S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/207914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dScTkcXzTZ4fQ5MBM9mJgScXTuS.jpg'),
(99516, 7053, 'New Girl S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/207915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xs6B6sjmjnqyPy1a94wR8G0r3fj.jpg'),
(99517, 7053, 'New Girl S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/207916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cgbUEe1oi5zpZ93BeVZp0HIhXHt.jpg'),
(99518, 7054, 'New Girl S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/79pYzi2MtKmCORbdylkLSmsRWn1.jpg'),
(99519, 7054, 'New Girl S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ajHOouRdpu1Dp8xCoOwcAEkhoAv.jpg'),
(99520, 7054, 'New Girl S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/go5WEegWU1cyaNLbQxp2d1UzyZH.jpg'),
(99521, 7054, 'New Girl S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MoKRp3gaoBylJ4OlGOoktlNZk7.jpg'),
(99522, 7054, 'New Girl S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/deg98rsBTDxK4iWLhwtN8W4YWJb.jpg'),
(99523, 7054, 'New Girl S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h2oGh0pQ3tMJWyE3OAKvSQKsqJf.jpg'),
(99524, 7054, 'New Girl S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bOaTU2CELHmkV3XgwPUq891gdkv.jpg'),
(99525, 7054, 'New Girl S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6IS3oRnXlAUJJAddTjC4fdsPFDv.jpg'),
(99526, 7054, 'New Girl S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/upW8YEeamwUV7UmeOGB7AgdUtRT.jpg'),
(99527, 7054, 'New Girl S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xacsMlKtUZYdMwxOD9EyBZnhGF6.jpg'),
(99528, 7054, 'New Girl S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/subZXFFKGemHfZRb28iWtthckp3.jpg'),
(99529, 7054, 'New Girl S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uVzV5uvA8vXzs4Ckvycl3jYZk6a.jpg'),
(99530, 7054, 'New Girl S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h42hxu6UwMC0JdORxxfvObFPHin.jpg'),
(99531, 7054, 'New Girl S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/207930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mFUEQRcKrcgXRRpHIIltb2gFHgZ.jpg'),
(99532, 7054, 'New Girl S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/207931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1tJbvC0ZaLm6AVWBbUUQZhz8qxP.jpg'),
(99533, 7054, 'New Girl S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/207932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5KIES1RL0JHxOlSwYHCPcKSm1le.jpg'),
(99534, 7054, 'New Girl S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/207933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h4vK6oekqa66YhK3ASR7q9I7QuZ.jpg'),
(99535, 7054, 'New Girl S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/207934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4DWDu22s3BOebgOTVTNPU0fKJGU.jpg'),
(99536, 7054, 'New Girl S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/207935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9u0n5C4WFaOjCxByzbL3D48oly.jpg'),
(99537, 7054, 'New Girl S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/207936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/klcE1NWPSDViwUaeSw1bfxSKzXt.jpg'),
(99538, 7054, 'New Girl S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/207937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yKOwUy27zJfhNG8kg1jbK48RHwG.jpg'),
(99539, 7054, 'New Girl S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/207938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9kXahg8wRAJH8RjwAEfVU6fypQf.jpg'),
(99540, 7054, 'New Girl S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/207939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m1mG2HJOlEnxvFXzMMcSKLKJWLi.jpg'),
(99541, 7054, 'New Girl S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/207940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g2AFnP5nHsyyZaoRwLjHL9tQiYw.jpg'),
(99542, 7054, 'New Girl S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/207941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nnI7jf5vNkPG8JepXFBkLlwUE6x.jpg'),
(99543, 7055, 'New Girl S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hDeJxmCqEdOiXcz3sgPgMch7ywt.jpg'),
(99544, 7055, 'New Girl S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vnS63IiV2qpeMy4V8UMcIR8FAon.jpg'),
(99545, 7055, 'New Girl S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t8WzoByxhep5Y2aHbuVohHU0Vel.jpg'),
(99546, 7055, 'New Girl S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6TxcOXhwJyuWp8c77mTbrTM9rT.jpg'),
(99547, 7055, 'New Girl S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/52UOI5gYntprm2HcNrRbh4d1zSd.jpg'),
(99548, 7055, 'New Girl S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCY7GDX858ejAX4lRvMcInbaFNI.jpg'),
(99549, 7055, 'New Girl S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/66h7qyETsnVv7s9RjFUD5XD2CXN.jpg'),
(99550, 7055, 'New Girl S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9CtgUgiGMuEY7mfVQlbsvqtjLn5.jpg'),
(99551, 7055, 'New Girl S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tXpZN3XZcjZ1q3Vg85GVU8BrUvJ.jpg'),
(99552, 7055, 'New Girl S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4sH9VH8ci8ZcTweaShvRqokvgyz.jpg'),
(99553, 7055, 'New Girl S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wM6Jfs73Dooc2gaTHlwBiV8xrPq.jpg'),
(99554, 7055, 'New Girl S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w9ruXbhBS6PRj0OJ0OODkcCC4wG.jpg'),
(99555, 7055, 'New Girl S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cPORFKpGbqr8iJN7VLakuL6jdXE.jpg'),
(99556, 7055, 'New Girl S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/207955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rVXupctlx7clpzWbG4rASRW5NHE.jpg'),
(99557, 7055, 'New Girl S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/207956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eHg6Uysq5wAfHe3QKmzSZYVjTFj.jpg'),
(99558, 7055, 'New Girl S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/207957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yCrzqVewHWlb9MP9JxBYrvMu3uN.jpg'),
(99559, 7055, 'New Girl S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/207958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tuNJM7hrkbAu89fuOm7N8UkINpH.jpg'),
(99560, 7055, 'New Girl S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/207959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cuSzYeXJBsaJsp7lH0SSI3UNesH.jpg'),
(99561, 7055, 'New Girl S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/207960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sTZHe00HWQAJwBBYUlvuyfAz4l8.jpg'),
(99562, 7055, 'New Girl S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/207961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a2jmjkB87InEgUBK3GPVC0xZkiX.jpg'),
(99563, 7055, 'New Girl S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/207962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q4kz5F33FVxJo7hCAd95zyZWryq.jpg'),
(99564, 7055, 'New Girl S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/207963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wDblpb9zacgtzmHQletUoznjkR4.jpg'),
(99565, 7055, 'New Girl S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/207964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mH07vFiFj9dhn75jFP3Sl4uwLin.jpg'),
(99566, 7056, 'New Girl S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gEOqg7NI18KDNP59TYYcqWcXJHs.jpg'),
(99567, 7056, 'New Girl S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qvwAF8afPjMVh7IFkmo6yopn1JY.jpg'),
(99568, 7056, 'New Girl S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/je924wT85sKWnQqZ7bLAQWhbUkR.jpg'),
(99569, 7056, 'New Girl S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hhqE1mrKEck9D8Jis7WHMjdm3e7.jpg'),
(99570, 7056, 'New Girl S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1bee5jqw2pPMnot45bGXuPeQI3j.jpg'),
(99571, 7056, 'New Girl S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s6kvzLqn4eYO35oUiVZyGMMLNGK.jpg'),
(99572, 7056, 'New Girl S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2OtqLtM0SJbbQ3BqNim0oGSrJrs.jpg'),
(99573, 7056, 'New Girl S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cIJCKWsnBDUkS8ym7z8b2t3vCz5.jpg'),
(99574, 7056, 'New Girl S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jIPGUyADOU2jDZNDLgPuA0V38vE.jpg'),
(99575, 7056, 'New Girl S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ubzhP0fM9AvVi70ECyBMaITH3U6.jpg'),
(99576, 7056, 'New Girl S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rszrAe3KoHMdqMji3xbIJrYDJAK.jpg'),
(99577, 7056, 'New Girl S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/idz8058qt65dhqjuDGi7w6egQeR.jpg'),
(99578, 7056, 'New Girl S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iC12LXgN2BMtkIUX95Eb3gQBWvA.jpg'),
(99579, 7056, 'New Girl S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/207978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1BJH8K0znp52aw5Eak13nXjyu1c.jpg'),
(99580, 7056, 'New Girl S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/207979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vLg23YV3VpB7BTiXKqdaLAR8M7e.jpg'),
(99581, 7056, 'New Girl S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/207980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4H6D4T4Po8Zhz0b7TngyKNLy6Mi.jpg'),
(99582, 7056, 'New Girl S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/207981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVSrSyfgbpuCL1Xfygrh1hYJ22z.jpg'),
(99583, 7056, 'New Girl S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/207982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lSaeZoscT3HSZRwreuf5XXlHZAR.jpg'),
(99584, 7056, 'New Girl S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/207983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lHSqrqHw2FGjFEWe5W03wEMsq3P.jpg'),
(99585, 7056, 'New Girl S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/207984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vn9C7bv6f64DAbM2WLQ18hzelSS.jpg'),
(99586, 7056, 'New Girl S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/207985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/81o9RE1BJKvkbyyJEOW1x9ykGMF.jpg'),
(99587, 7056, 'New Girl S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/207986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h3eAvTO3NyOWLxP1Mlk7R61cyRM.jpg'),
(99588, 7057, 'New Girl S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zY1bkkACo1pWTc2iYN1Bgi7fKeV.jpg'),
(99589, 7057, 'New Girl S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n1g4eManmmvIIGROtsYTqfd13aS.jpg'),
(99590, 7057, 'New Girl S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4AoykMWnEzMX8ctwG9JaTYpXyv3.jpg'),
(99591, 7057, 'New Girl S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/37jJruF1e5RM0VVV8x9cf1NSfH.jpg'),
(99592, 7057, 'New Girl S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/40ev9K52cBys99NMRSrcmY1qIkO.jpg'),
(99593, 7057, 'New Girl S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4nuzs3NxCYAImsMb3gFq5jpNK4G.jpg'),
(99594, 7057, 'New Girl S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u0jeqoWhAGd7aALaDfm43CGv0tu.jpg'),
(99595, 7057, 'New Girl S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tvizzzTaQQC00AibMagAqgOEqhC.jpg'),
(99596, 7057, 'New Girl S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zJoQzedn3WhAHS560yosp9VxUw8.jpg'),
(99597, 7057, 'New Girl S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8bfpP6fBgwIDH70ROj9sEyVfpoi.jpg'),
(99598, 7057, 'New Girl S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZOp3JROs0T6Fscske2qJN8dHeI.jpg'),
(99599, 7057, 'New Girl S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c9dOAgHNCfUuxP2rWb9Rb1GAECD.jpg'),
(99600, 7057, 'New Girl S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vqnYavF8DtFNeegueO62Ikdgofo.jpg'),
(99601, 7057, 'New Girl S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/208000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7iNZWJlGIdkSi5ZVCkwbIDqkYpQ.jpg'),
(99602, 7057, 'New Girl S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/208001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r09cifaFVNlVqePVz9lsVBiNDNC.jpg'),
(99603, 7057, 'New Girl S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/208002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/415ySKgcxL9VR6Lvx57wpFfexYe.jpg'),
(99604, 7057, 'New Girl S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/208003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8H7r3oaa7LA7ny17mclXfYfHDNW.jpg'),
(99605, 7057, 'New Girl S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/208004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2J8WSlVDkzsFPqL8suqb3VFvjv2.jpg'),
(99606, 7057, 'New Girl S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/208005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vkm1PBL3bHkMGfPozBdbvCWS21d.jpg'),
(99607, 7057, 'New Girl S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/208006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ssn1mW3EtmB9qc6Jx9aFwAUzP3i.jpg'),
(99608, 7057, 'New Girl S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/208007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8KkXXAW5sXQbCZQkeHHRkmRem6W.jpg'),
(99609, 7057, 'New Girl S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/208008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4BVKr25HBHQfDdzuJrt8L9kohfk.jpg'),
(99610, 7058, 'New Girl S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tLWBL6ecgatdmPOc5xjLlPFEIzh.jpg'),
(99611, 7058, 'New Girl S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w9cBwq8xAP5kAaB0DupCqCvEusf.jpg'),
(99612, 7058, 'New Girl S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jNinLng3MzZ2CspYi3H81gqSvHe.jpg'),
(99613, 7058, 'New Girl S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sPxO1sblRu6gE64siu0k5qsWhL3.jpg'),
(99614, 7058, 'New Girl S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dolCEXUFnbsoP1pOhL29tYO4kT8.jpg'),
(99615, 7058, 'New Girl S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1VY91qXxA0iIvagE4mSOH5fCTNg.jpg'),
(99616, 7058, 'New Girl S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sjwZQeORKiwUP7tynW6ioGnbqv3.jpg'),
(99617, 7058, 'New Girl S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eg4lw7144kryb1vdKkvtwjptTJJ.jpg'),
(99618, 7058, 'New Girl S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ssSPkzDSwKPdZ7iDG0slSDpUToc.jpg'),
(99619, 7058, 'New Girl S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ztC8Ti6vLndxsA1s35r10MVna0v.jpg'),
(99620, 7058, 'New Girl S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/92WiHbVMfdDZilSTNQjlye35BRg.jpg'),
(99621, 7058, 'New Girl S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A5ohkImhoyn4y6WKF0NnQrxFhSf.jpg'),
(99622, 7058, 'New Girl S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/208021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mapwFoqdDpHcj6XpEjADCSkpGj3.jpg'),
(99623, 7058, 'New Girl S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/208022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2l8ufo6GtERsDooUbFaTRRo6wY0.jpg'),
(99624, 7058, 'New Girl S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/208023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/swSMFJHPdMFhaXM7Z5EPJtrfCJx.jpg'),
(99625, 7058, 'New Girl S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/208024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vi22afnmczCskHDSpGBh5XIJDHW.jpg'),
(99626, 7058, 'New Girl S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/208025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n8UZDhyHjIJNn4az8YA4kt4cRqh.jpg'),
(99627, 7058, 'New Girl S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/208026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fN7xceNHO5xwDWzkMyvvQ5NTUz3.jpg'),
(99628, 7058, 'New Girl S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/208027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dC0ZACbA7jbrXbGN0Ye13LJGTZA.jpg'),
(99629, 7058, 'New Girl S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/208028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aHRn3iVsjF10jntKdsl6wTRcnGX.jpg'),
(99630, 7058, 'New Girl S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/208029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nzVJjYDgInRZQ03T8XwLbuYfcbq.jpg'),
(99631, 7058, 'New Girl S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/208030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/quBdxrE1FZwkC43lVJOkLzVH7PC.jpg'),
(99632, 7059, 'New Girl S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9SGDuMoLXDQ4Ui8f8vQ4qp9Nc8v.jpg'),
(99633, 7059, 'New Girl S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tqDRIxvTd4AQxs4fYq4stzR9OnC.jpg'),
(99634, 7059, 'New Girl S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o9uZftTtmp2cXn4fv9ztd2Lh1UP.jpg'),
(99635, 7059, 'New Girl S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNrrrUR7Arqikfyx5cZsJht1w8h.jpg'),
(99636, 7059, 'New Girl S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zjIsq3aeBKFR3oRAE7TZXzhjnCZ.jpg'),
(99637, 7059, 'New Girl S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xzijgJvBp40E9fRWBFfNivsokkH.jpg'),
(99638, 7059, 'New Girl S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kPoEYlKhBoFXBhcO74Gx9HB2k7L.jpg'),
(99639, 7059, 'New Girl S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/46RACqQypJIBAetJWZJksssrkIF.jpg'),
(99640, 7060, 'A Guerra do Vietnã S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m40fQyePc15Xvw5d2efvYcf6Arw.jpg'),
(99641, 7060, 'A Guerra do Vietnã S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/etkWElmpR8swAgLFKFv0Xq1zA6h.jpg'),
(99642, 7060, 'A Guerra do Vietnã S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dK2fjWI9HL4yEFtRolLlodKXQpG.jpg'),
(99643, 7060, 'A Guerra do Vietnã S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bo22XKBWt67yIHKGfPCuayLqvKc.jpg'),
(99644, 7060, 'A Guerra do Vietnã S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yaDK6si5Lrwvalqz9dA15jV8ysP.jpg'),
(99645, 7060, 'A Guerra do Vietnã S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yAJ9yoLrugJ0xkvAEKtKkQFe2tW.jpg'),
(99646, 7060, 'A Guerra do Vietnã S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sePoiBQih5V7A7hSpja8eeLHGkx.jpg'),
(99647, 7060, 'A Guerra do Vietnã S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3lLHdOcsqI3Qm3XcCGXA5uYQwSd.jpg'),
(99648, 7060, 'A Guerra do Vietnã S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lv5QhfEVklXFO4cjaGpPWIxzSSy.jpg'),
(99649, 7060, 'A Guerra do Vietnã S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w9XUbr3U5gZABFTwlzdd2GqAwoB.jpg'),
(99650, 7061, 'A Cabeça de Joaquín Murrieta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jQgAPTOqhv2T4lHWB9dZ9xwYaSG.jpg'),
(99651, 7061, 'A Cabeça de Joaquín Murrieta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lg425mHPxNihNCQzTu6La8gXVek.jpg'),
(99652, 7061, 'A Cabeça de Joaquín Murrieta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jUXtMgmJNHGCo8ZPqwrEbo3MScy.jpg'),
(99653, 7061, 'A Cabeça de Joaquín Murrieta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dlSgLdETnmenz7VEa021dbR73Yv.jpg'),
(99654, 7061, 'A Cabeça de Joaquín Murrieta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d7LYfYdlqGY0oZT2mxmaGBsJxcv.jpg'),
(99655, 7061, 'A Cabeça de Joaquín Murrieta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8dUigEMkTKvCQNbBTuwD4BIuBEP.jpg'),
(99656, 7061, 'A Cabeça de Joaquín Murrieta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1kme1TDnZRT6Tk0rqAM3S5SsSW7.jpg'),
(99657, 7061, 'A Cabeça de Joaquín Murrieta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q4lQKXhkagm0oeoJjIDmgumykuq.jpg'),
(99658, 7062, 'A Primeira Vez S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mwfHvGl6cELhY1QICfv9sUSTuIn.jpg'),
(99659, 7062, 'A Primeira Vez S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aHACjFfMA4oC0XJAUdVweqVGX4C.jpg'),
(99660, 7062, 'A Primeira Vez S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jSXyMOOJCS6eqUPOqZiMpudMcEw.jpg'),
(99661, 7062, 'A Primeira Vez S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sw3Coh7xWzsNh20V8rurNnuUqWy.jpg'),
(99662, 7062, 'A Primeira Vez S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Nth1wHt5phSAEWkI8i3zq0GmZJ.jpg'),
(99663, 7062, 'A Primeira Vez S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5A3UPTesW5kGRF3wXnZYl8UgOhx.jpg'),
(99664, 7062, 'A Primeira Vez S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tFwbE89IaViNBroo87GXHMSkDbS.jpg'),
(99665, 7062, 'A Primeira Vez S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/78ovHlaxC3aNYsMMOaryxTpF30i.jpg'),
(99666, 7062, 'A Primeira Vez S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kG0MtLaze63iQe6DxUsio4h7hBN.jpg'),
(99667, 7062, 'A Primeira Vez S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbMix9iXmN945mhcd3XIqwX76jJ.jpg'),
(99668, 7062, 'A Primeira Vez S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uGEA7tQM3vo6GhZNOMvRDiQVJfN.jpg'),
(99669, 7062, 'A Primeira Vez S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eoqchWwvJr5gX9S4o0QApUYQ27x.jpg'),
(99670, 7062, 'A Primeira Vez S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t1ip2vpb7dNWxiVxkj45hfjPLrM.jpg'),
(99671, 7063, 'A Primeira Vez S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FejGO0gViXmrTcKP6KtbdkYlXI.jpg'),
(99672, 7063, 'A Primeira Vez S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FejGO0gViXmrTcKP6KtbdkYlXI.jpg'),
(99673, 7063, 'A Primeira Vez S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/405444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FejGO0gViXmrTcKP6KtbdkYlXI.jpg'),
(99674, 7063, 'A Primeira Vez S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/405445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FejGO0gViXmrTcKP6KtbdkYlXI.jpg'),
(99675, 7063, 'A Primeira Vez S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/405446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FejGO0gViXmrTcKP6KtbdkYlXI.jpg'),
(99676, 7063, 'A Primeira Vez S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/405447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FejGO0gViXmrTcKP6KtbdkYlXI.jpg'),
(99677, 7063, 'A Primeira Vez S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/405448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FejGO0gViXmrTcKP6KtbdkYlXI.jpg'),
(99678, 7063, 'A Primeira Vez S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/405449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FejGO0gViXmrTcKP6KtbdkYlXI.jpg'),
(99679, 7063, 'A Primeira Vez S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/405450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FejGO0gViXmrTcKP6KtbdkYlXI.jpg'),
(99680, 7063, 'A Primeira Vez S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/405451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FejGO0gViXmrTcKP6KtbdkYlXI.jpg'),
(99681, 7064, 'A Primeira Vez S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/828229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FejGO0gViXmrTcKP6KtbdkYlXI.jpg'),
(99682, 7064, 'A Primeira Vez S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/828230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FejGO0gViXmrTcKP6KtbdkYlXI.jpg'),
(99683, 7064, 'A Primeira Vez S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/828231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FejGO0gViXmrTcKP6KtbdkYlXI.jpg'),
(99684, 7064, 'A Primeira Vez S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/828232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FejGO0gViXmrTcKP6KtbdkYlXI.jpg'),
(99685, 7064, 'A Primeira Vez S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/828233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FejGO0gViXmrTcKP6KtbdkYlXI.jpg'),
(99686, 7064, 'A Primeira Vez S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/828234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FejGO0gViXmrTcKP6KtbdkYlXI.jpg'),
(99687, 7064, 'A Primeira Vez S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/828235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FejGO0gViXmrTcKP6KtbdkYlXI.jpg'),
(99688, 7064, 'A Primeira Vez S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/828236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FejGO0gViXmrTcKP6KtbdkYlXI.jpg'),
(99689, 7064, 'A Primeira Vez S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/828237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FejGO0gViXmrTcKP6KtbdkYlXI.jpg'),
(99690, 7064, 'A Primeira Vez S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/828238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FejGO0gViXmrTcKP6KtbdkYlXI.jpg'),
(99691, 7065, 'Apaixonados Outra Vez S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aiUWgGcZ2wryrLyjIjdA92IuS42.jpg'),
(99692, 7065, 'Apaixonados Outra Vez S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aCQAnq1BCgXh46IuKzYr4O5OEb8.jpg'),
(99693, 7065, 'Apaixonados Outra Vez S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s56HV6ZD11ynbev8mayOmKRwk8g.jpg'),
(99694, 7065, 'Apaixonados Outra Vez S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yuHaux2kMAyB0Gg7cPd2K1mxnQv.jpg'),
(99695, 7065, 'Apaixonados Outra Vez S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wCCQAzurT0AsQ4gCnliwMfvJF1P.jpg'),
(99696, 7065, 'Apaixonados Outra Vez S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ioVIIGZjXhwNZZHZiIEyhCaX2CK.jpg'),
(99697, 7065, 'Apaixonados Outra Vez S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qf35WDodzyjTcWh5BRWPRiZvYqN.jpg'),
(99698, 7065, 'Apaixonados Outra Vez S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/boK3TVudTa6To2Uwp1uuiPERRrR.jpg'),
(99699, 7066, 'As Leis de Lidia Poët S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFYXs00vnigXigCE3rPqRwuPDIY.jpg'),
(99700, 7066, 'As Leis de Lidia Poët S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zK4CDPavC03xr8UI7CHcmeJSc8k.jpg'),
(99701, 7066, 'As Leis de Lidia Poët S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ga39yxHAaoYdLSKgagpovO7NzwA.jpg'),
(99702, 7066, 'As Leis de Lidia Poët S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/50JSIrnLNtgUX88PZvXCyXD3fhi.jpg'),
(99703, 7066, 'As Leis de Lidia Poët S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ck6nq87BepxminJHL3016XUObBA.jpg'),
(99704, 7066, 'As Leis de Lidia Poët S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s7y72B5NvM3L9G3PGeaXxEEirQx.jpg'),
(99705, 7067, 'As Leis de Lidia Poët S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/497683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAg30nMxfBDa3JpPDheJSG43uqC.jpg'),
(99706, 7067, 'As Leis de Lidia Poët S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/497684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAg30nMxfBDa3JpPDheJSG43uqC.jpg'),
(99707, 7067, 'As Leis de Lidia Poët S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/497685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAg30nMxfBDa3JpPDheJSG43uqC.jpg'),
(99708, 7067, 'As Leis de Lidia Poët S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/497686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAg30nMxfBDa3JpPDheJSG43uqC.jpg'),
(99709, 7067, 'As Leis de Lidia Poët S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/497687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAg30nMxfBDa3JpPDheJSG43uqC.jpg'),
(99710, 7067, 'As Leis de Lidia Poët S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/497688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAg30nMxfBDa3JpPDheJSG43uqC.jpg'),
(99711, 7068, 'Coração Inimigo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/huCCCwviih7Eq7ATpd6mcg4ZQeU.jpg'),
(99712, 7068, 'Coração Inimigo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jC0lQiG7H2oosTJaQaiDbPLXKtQ.jpg'),
(99713, 7068, 'Coração Inimigo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/emzCrvuzTIvZrezdfv0ano9Ze4V.jpg'),
(99714, 7068, 'Coração Inimigo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sN3bll7eIuOcFfK97r7MBsilJMr.jpg'),
(99715, 7068, 'Coração Inimigo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/selLPWPuU4TPfJvVgqY82lfGSKY.jpg'),
(99716, 7068, 'Coração Inimigo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vEy5b64JrHxOSAmXiyipmk5tUSt.jpg'),
(99717, 7068, 'Coração Inimigo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kqpFRtSk8FC4rWHddm3VTHyii6F.jpg'),
(99718, 7068, 'Coração Inimigo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kErLgPLtFEbnF2lwO51YGhW1Iyh.jpg'),
(99719, 7068, 'Coração Inimigo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wpPYXsMf81fqbDSbO8ZMDG6QmhX.jpg'),
(99720, 7068, 'Coração Inimigo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/788GklsemKOu7ymIHuOlWlzvx60.jpg'),
(99721, 7068, 'Coração Inimigo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tynmzugqo9RnzkZ4ME857FHbdjN.jpg'),
(99722, 7068, 'Coração Inimigo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o1JrejzNRb8XGiWd4z6ZJhjCjFt.jpg'),
(99723, 7068, 'Coração Inimigo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jWBrJDjiSmRjI5HbYawhTTsuQAA.jpg'),
(99724, 7068, 'Coração Inimigo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/207391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AhhKdEEYkoBg9r37X5KmWNLCBvx.jpg'),
(99725, 7068, 'Coração Inimigo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/207392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zbZYLkJsrN0zqc3K7FiGYkhKwXa.jpg'),
(99726, 7068, 'Coração Inimigo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/207393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Z4C825koxhd3bJuFCPOTJEVWlt.jpg'),
(99727, 7069, 'Dias de Golfe S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9B3BgLTEf8nfSO6QWgPfu112TYz.jpg'),
(99728, 7069, 'Dias de Golfe S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gMca9lR86OFG8M5IZdnfpFwjFfT.jpg'),
(99729, 7069, 'Dias de Golfe S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z4GW7u6y62qWgnwvvz4XqXEyqZM.jpg'),
(99730, 7069, 'Dias de Golfe S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7QL1NP4hRWY82TRYAgtX9Z8Hkp9.jpg'),
(99731, 7069, 'Dias de Golfe S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tSCVGdF8el6bivhlx46UwCBneOb.jpg'),
(99732, 7069, 'Dias de Golfe S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i1kNVUHgIZTF5MzImAUaLqiARlX.jpg'),
(99733, 7069, 'Dias de Golfe S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aVjVmpzj6IG0YH4Iv62xQDvpWUP.jpg'),
(99734, 7069, 'Dias de Golfe S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zjket8FJkSvtivYDpAP0gtMuvRT.jpg'),
(99735, 7070, 'Dias de Golfe S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0OFkkvygjCax7h0u4ko8GzixBk.jpg'),
(99736, 7070, 'Dias de Golfe S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0OFkkvygjCax7h0u4ko8GzixBk.jpg'),
(99737, 7070, 'Dias de Golfe S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0OFkkvygjCax7h0u4ko8GzixBk.jpg'),
(99738, 7070, 'Dias de Golfe S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0OFkkvygjCax7h0u4ko8GzixBk.jpg'),
(99739, 7070, 'Dias de Golfe S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0OFkkvygjCax7h0u4ko8GzixBk.jpg'),
(99740, 7070, 'Dias de Golfe S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0OFkkvygjCax7h0u4ko8GzixBk.jpg'),
(99741, 7070, 'Dias de Golfe S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0OFkkvygjCax7h0u4ko8GzixBk.jpg'),
(99742, 7070, 'Dias de Golfe S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0OFkkvygjCax7h0u4ko8GzixBk.jpg'),
(99743, 7071, 'Fakes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7YG4IHXbT2WdSTciAKOKDyvxMEA.jpg'),
(99744, 7071, 'Fakes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uXketH7QzzZLCd5QtGx3Newdec6.jpg'),
(99745, 7071, 'Fakes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hVaVxBTxVi9KkZNqDRvM7EdTdJu.jpg'),
(99746, 7071, 'Fakes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3UGF1rLKZrP77FM6Gv8XRp2OCb0.jpg'),
(99747, 7071, 'Fakes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h6oSTKXZQ4ikXLQGfv0Lw4KQLuf.jpg'),
(99748, 7071, 'Fakes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ydtbocjEl3UJxz6ZN4n6Uaz6heW.jpg'),
(99749, 7071, 'Fakes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hrPqN4qnIuFgmtvamvpb7MI2jd9.jpg'),
(99750, 7071, 'Fakes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c9bNHNLW6e6RVfhynO7nkTX4LQj.jpg'),
(99751, 7072, 'Horário Nobre S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7tI5RLK4GzTjHH9aDiTLQlsCcOD.jpg'),
(99752, 7072, 'Horário Nobre S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pegfln6fOMgQepMwqEIB1jXPfbS.jpg'),
(99753, 7072, 'Horário Nobre S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lv5nzpV1TROrv9EVuPBXeCuuoHJ.jpg'),
(99754, 7072, 'Horário Nobre S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9quxkmXOcA7qUvbcGNoPuRSyLMB.jpg'),
(99755, 7072, 'Horário Nobre S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/33jCYhklEj2lR7Xhsr5y1ROKoT9.jpg'),
(99756, 7072, 'Horário Nobre S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wmEj2QpwvhraLO8w1sXu8yGEzbN.jpg'),
(99757, 7072, 'Horário Nobre S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ncKMBXX7CeLdljVqtpXCBw7FLOF.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(99758, 7072, 'Horário Nobre S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZCV38phv2L8iGHpM3l0Wh2rFTt.jpg'),
(99759, 7072, 'Horário Nobre S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AffgQ4RNVem8NIuLZuVOm6XGsHG.jpg'),
(99760, 7072, 'Horário Nobre S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4XLMGYv5haVvTabhYk1yBjKKskm.jpg'),
(99761, 6796, 'Interligados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7pMZ6G2ncvg8O9sLAZ0RtRsZEuh.jpg'),
(99762, 6796, 'Interligados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kaz02qu5Ju08NF8lMf8BaVUdtue.jpg'),
(99763, 6796, 'Interligados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xVQB6h9Z4pRmMwuZklq8DdoURPD.jpg'),
(99764, 6796, 'Interligados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x1pYCnYHU4ym8imcyaj2jCx2BBL.jpg'),
(99765, 6796, 'Interligados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m7QFmiXQhBW4lEel1xVR06mUk9S.jpg'),
(99766, 6796, 'Interligados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hKl9tsYkJm2fSNo1ecHz5HQaoq7.jpg'),
(99767, 7073, 'Love to Hate You S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eSWsTJkLqdnx0BgQ3u3TsgAopHh.jpg'),
(99768, 7073, 'Love to Hate You S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cN5sm6K26B2UvK4BdcepX6gwpBi.jpg'),
(99769, 7073, 'Love to Hate You S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/erKVfe5H5hBmsZU28HDyTa0lSQ7.jpg'),
(99770, 7073, 'Love to Hate You S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFsxL2oZL9sLqGicFKKgu4VZh6o.jpg'),
(99771, 7073, 'Love to Hate You S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lqhWh4sgLXYPdTqW1WG20Jt4hXh.jpg'),
(99772, 7073, 'Love to Hate You S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dsFRLwn8EeP1NwCkvkYxZKSpYyj.jpg'),
(99773, 7073, 'Love to Hate You S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mXA9JVJKlFc73Ulx8mmwB08XgRV.jpg'),
(99774, 7073, 'Love to Hate You S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jtVJaRokEKREcR5DnPZnPawgb2C.jpg'),
(99775, 7073, 'Love to Hate You S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFpRhUApA2V0C7HRVwsILghS9rs.jpg'),
(99776, 7073, 'Love to Hate You S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d9g65WJCNIE3IHLlmAcdfLqpAlA.jpg'),
(99777, 7074, 'Meu Namorado Astronauta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e8ZjYUwhy8uBA9ruWAvCVcolXHC.jpg'),
(99778, 7074, 'Meu Namorado Astronauta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v0YbexP8gNQvkK83EMNkCI0yCf0.jpg'),
(99779, 7074, 'Meu Namorado Astronauta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aq1FcgWCfr1G4pAZTRcmwHEcCgQ.jpg'),
(99780, 7074, 'Meu Namorado Astronauta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4CY49KoQNnQzn63sB1Me1PmWXEU.jpg'),
(99781, 7074, 'Meu Namorado Astronauta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ZSJs345GOxXOmclKYg7i0u7EVI.jpg'),
(99782, 7074, 'Meu Namorado Astronauta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/obqASRgJeS9KJXOcQNKsPnSDvZK.jpg'),
(99783, 7075, 'Amanhã! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7qE33gav9n09juCs49qhiPaaBt7.jpg'),
(99784, 7075, 'Amanhã! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rvTFq3ioih6lryoFAvehcQ3g9Gs.jpg'),
(99785, 7075, 'Amanhã! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7iZev1vpkWIuI0RKQyRkX8KRwsK.jpg'),
(99786, 7075, 'Amanhã! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212818.mp4', 'http://image.tmdb.org/t/p/w1280/4mGR5Y1XHJDjcgQlYsQyKzTR865.jpg'),
(99787, 7075, 'Amanhã! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212819.mp4', 'http://image.tmdb.org/t/p/w1280/g1ky1ixSnzd08DEMdUc82gRbzbJ.jpg'),
(99788, 7075, 'Amanhã! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212820.mp4', 'http://image.tmdb.org/t/p/w1280/aLSqv1xvvg3py89UQM3owXLob0Q.jpg'),
(99789, 7075, 'Amanhã! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212821.mp4', 'http://image.tmdb.org/t/p/w1280/lanKoG2mEAs0iL9Q6qsl8fm1bQE.jpg'),
(99790, 7075, 'Amanhã! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212822.mp4', 'http://image.tmdb.org/t/p/w1280/gnRPYd1QIRF8rH0BDBBZbcysbfH.jpg'),
(99791, 7075, 'Amanhã! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212823.mp4', 'http://image.tmdb.org/t/p/w1280/5Y7RJN8XkOq2P7zsSE2chZODrEd.jpg'),
(99792, 7075, 'Amanhã! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212824.mp4', 'http://image.tmdb.org/t/p/w1280/2491O3lcN6wNqNTDFmW1j5F2gKi.jpg'),
(99793, 7076, 'Rainhas Africanas: Nzinga S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kQz4YIdzGPkpOJwgE92JemqJdKk.jpg'),
(99794, 7076, 'Rainhas Africanas: Nzinga S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lOfkF3Kpc5Fnwqd9NmLPoeSdTdw.jpg'),
(99795, 7076, 'Rainhas Africanas: Nzinga S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aeyRpI36JT2E1b9fSGTnnZrkHUO.jpg'),
(99796, 7076, 'Rainhas Africanas: Nzinga S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cbt5PyD5e8DCtJtK7iNf66ROwYT.jpg'),
(99797, 7077, 'Red Rose S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iyRwQ2H43u5F3w07khfSnssq6l7.jpg'),
(99798, 7077, 'Red Rose S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r1nh8ctfM86HHv8XCrIRYQtmOM9.jpg'),
(99799, 7077, 'Red Rose S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lF402mUgBAmZnS8oV4ShY7KjmjP.jpg'),
(99800, 7077, 'Red Rose S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/meORqBdWbdu8KFK4g27ceyOjzAg.jpg'),
(99801, 7077, 'Red Rose S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oUqsq3wN85OBXni60q18R3Iy5LV.jpg'),
(99802, 7077, 'Red Rose S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3cpbRVGSZENPFExX7g07B6G4Y95.jpg'),
(99803, 7077, 'Red Rose S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/omu7Z3XUPTLSxu4GAcoCviOxBis.jpg'),
(99804, 7077, 'Red Rose S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hed4J6nyhCljkRILUskGtIMMCy2.jpg'),
(99805, 7078, 'Sem Filtro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/usv72OffOmqNCDEgtgB3AtCrYdS.jpg'),
(99806, 7078, 'Sem Filtro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2j8klUEohweYzEKvojCIiRP04GC.jpg'),
(99807, 7078, 'Sem Filtro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xKleXkxZ4ISvcaTim786DACaSrd.jpg'),
(99808, 7078, 'Sem Filtro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uUUOnOhjhIJsKlSLNipragHN9CN.jpg'),
(99809, 7078, 'Sem Filtro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/snMaBzx4LIBPc5JCMlexB6P6VbJ.jpg'),
(99810, 7078, 'Sem Filtro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2o2s9wzx8UZH7MZbUYTRq4iVM7w.jpg'),
(99811, 7078, 'Sem Filtro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jx77VVd3CrGiGHrMrNslQRwnJvG.jpg'),
(99812, 7078, 'Sem Filtro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8PYEyfCpjo96LKiwp4FjXaYfuz.jpg'),
(99813, 7078, 'Sem Filtro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zwQnygIgPv7cYrwk8wiPQDCYQs3.jpg'),
(99814, 7078, 'Sem Filtro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1GAAuuR2L0vGQhh6V6oX0riKx0D.jpg'),
(99815, 7079, 'A Menina Invisível S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3eek2ywUlGhexJ5TdSyZgaZYnNb.jpg'),
(99816, 7079, 'A Menina Invisível S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s0fegZV6QC5Djm5BMk9LL4NWZxC.jpg'),
(99817, 7079, 'A Menina Invisível S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8YjwzIQ8j73Coy679Ovrxq4EZvE.jpg'),
(99818, 7079, 'A Menina Invisível S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZJ6Audr5yAoJVTPmFUR6eoLdo7.jpg'),
(99819, 7079, 'A Menina Invisível S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vqQaN1y9wcJVTM63Bl9eSOcsoS6.jpg'),
(99820, 7079, 'A Menina Invisível S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s6L0f8SP6coyN9bLpC9vT6d5dyR.jpg'),
(99821, 7079, 'A Menina Invisível S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j2erImJiE6MJsA6eLmji0JohvCO.jpg'),
(99822, 7079, 'A Menina Invisível S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gnf9mAcxOgzhAcbXFoQSCtmVcKn.jpg'),
(99823, 7080, 'Canto ao Tempo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f0oOT88cZmRhymy2djcDQpr3qeu.jpg'),
(99824, 7080, 'Canto ao Tempo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f0oOT88cZmRhymy2djcDQpr3qeu.jpg'),
(99825, 7080, 'Canto ao Tempo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f0oOT88cZmRhymy2djcDQpr3qeu.jpg'),
(99826, 7080, 'Canto ao Tempo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f0oOT88cZmRhymy2djcDQpr3qeu.jpg'),
(99827, 7080, 'Canto ao Tempo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f0oOT88cZmRhymy2djcDQpr3qeu.jpg'),
(99828, 7081, 'Carnaval RJ (2023) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207275.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99829, 7081, 'Carnaval RJ (2023) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207276.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99830, 7081, 'Carnaval RJ (2023) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207277.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99831, 7081, 'Carnaval RJ (2023) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207278.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99832, 7081, 'Carnaval RJ (2023) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207279.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99833, 7081, 'Carnaval RJ (2023) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207280.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99834, 7082, 'Carnaval RJ (2023) S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207281.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99835, 7082, 'Carnaval RJ (2023) S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207282.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99836, 7082, 'Carnaval RJ (2023) S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207283.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99837, 7082, 'Carnaval RJ (2023) S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207284.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99838, 7082, 'Carnaval RJ (2023) S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207285.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99839, 7082, 'Carnaval RJ (2023) S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207286.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99840, 7083, 'Carnaval SP (2023) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207261.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99841, 7083, 'Carnaval SP (2023) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207262.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99842, 7083, 'Carnaval SP (2023) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207263.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99843, 7083, 'Carnaval SP (2023) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207264.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99844, 7083, 'Carnaval SP (2023) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207265.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99845, 7083, 'Carnaval SP (2023) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207266.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99846, 7083, 'Carnaval SP (2023) S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207267.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99847, 7084, 'Carnaval SP (2023) S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207268.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99848, 7084, 'Carnaval SP (2023) S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207269.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99849, 7084, 'Carnaval SP (2023) S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207270.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99850, 7084, 'Carnaval SP (2023) S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207271.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99851, 7084, 'Carnaval SP (2023) S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207272.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99852, 7084, 'Carnaval SP (2023) S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207273.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99853, 7084, 'Carnaval SP (2023) S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207274.mp4', 'https://i.bj-share.info/f71c246cbc3a49aaa4298367294a1a56.png'),
(99854, 7085, 'Conexões S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r80Y6YffNTMsvWhrjWANY1Gtqbe.jpg'),
(99855, 7085, 'Conexões S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208541.mp4', 'http://image.tmdb.org/t/p/w1280/vt9LYPLMFJuFNb8N9UlaPSaKgl2.jpg'),
(99856, 7085, 'Conexões S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208542.mp4', 'http://image.tmdb.org/t/p/w1280/CBv3Em1q6RPiofstZJpb0AXkeS.jpg'),
(99857, 7085, 'Conexões S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208543.mp4', 'http://image.tmdb.org/t/p/w1280/emXNVlRUgXWbKNvgfeCEQl1R53.jpg'),
(99858, 7085, 'Conexões S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208544.mp4', 'http://image.tmdb.org/t/p/w1280/rQZaaZjlGLbJWHwczdo7i1tAEz1.jpg'),
(99859, 7085, 'Conexões S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208545.mp4', 'http://image.tmdb.org/t/p/w1280/kQwyxyhjDzBJmWF5qaldINWvV8s.jpg'),
(99860, 7085, 'Conexões S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/893604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jzsQauqfn15vPrZvCGjzqDltbhn.jpg'),
(99861, 7085, 'Conexões S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/893605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jzsQauqfn15vPrZvCGjzqDltbhn.jpg'),
(99862, 7086, 'Conte Tudo Para Mim S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pIYqAAQOwT4OOjXyAePkEf3zAKI.jpg'),
(99863, 7086, 'Conte Tudo Para Mim S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3My8i8cD1YwLKtH7jhYIsIdjNmG.jpg'),
(99864, 7086, 'Conte Tudo Para Mim S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tOzo6BLHHHKe4TkgQXmizLkOoge.jpg'),
(99865, 7086, 'Conte Tudo Para Mim S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m6pNrweamN8C91bUxNqwNonT6zk.jpg'),
(99866, 7086, 'Conte Tudo Para Mim S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ghVPGljQ8FGIkAqGrntIRMHD4gE.jpg'),
(99867, 7086, 'Conte Tudo Para Mim S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/48i89hZXtyl0TIC2cU8HKYusTcp.jpg'),
(99868, 7087, 'Divisão Palermo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ydYOVROJKjk5v6Na0rdNGouaZ5d.jpg'),
(99869, 7087, 'Divisão Palermo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zpvEillocQwyxtwaaAlt6K91hC9.jpg'),
(99870, 7087, 'Divisão Palermo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i0MY750F6U4iPoHxtzsINFnnLp8.jpg'),
(99871, 7087, 'Divisão Palermo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iBoo46VoxPglpKd4qJAGgcl0sIR.jpg'),
(99872, 7087, 'Divisão Palermo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bcW3BqhgYHn5ZImPeFwX8YDSut4.jpg'),
(99873, 7087, 'Divisão Palermo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hKJfGWNTQJ84KmGM2LWmObq1A64.jpg'),
(99874, 7087, 'Divisão Palermo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qs1P9Kg5iXdkTL5pjOcdUSI9Lsi.jpg'),
(99875, 7087, 'Divisão Palermo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cVQLCiPSMTpSq76JlBYIX52aSOz.jpg'),
(99876, 7088, 'Divisão Palermo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/870812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m7NDfGuTBslh3ClkYMeBx665fhO.jpg'),
(99877, 7088, 'Divisão Palermo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/870813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m7NDfGuTBslh3ClkYMeBx665fhO.jpg'),
(99878, 7088, 'Divisão Palermo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/870814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m7NDfGuTBslh3ClkYMeBx665fhO.jpg'),
(99879, 7088, 'Divisão Palermo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/870815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m7NDfGuTBslh3ClkYMeBx665fhO.jpg'),
(99880, 7088, 'Divisão Palermo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/870816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m7NDfGuTBslh3ClkYMeBx665fhO.jpg'),
(99881, 7088, 'Divisão Palermo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/870817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m7NDfGuTBslh3ClkYMeBx665fhO.jpg'),
(99882, 7089, 'Escândalos e Assassinatos na Família Murdaugh S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nRVvLigr9cbndpTOSJ2QkVd48qm.jpg'),
(99883, 7089, 'Escândalos e Assassinatos na Família Murdaugh S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sK7KOwut0yGjcdDTARIoGJZamWG.jpg'),
(99884, 7089, 'Escândalos e Assassinatos na Família Murdaugh S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8iASk7zLfzsBTpmE1IXdANS3Ral.jpg'),
(99885, 7090, 'Last Light S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hGw57q8yJyft9f0aZbZ9XuEe8fb.jpg'),
(99886, 7090, 'Last Light S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209418.mp4', 'http://image.tmdb.org/t/p/w1280/eYN81xCjUacMTwvU6Uw2sRdrh1f.jpg'),
(99887, 7090, 'Last Light S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209419.mp4', 'http://image.tmdb.org/t/p/w1280/519SZxVHAv1b7trXjEw6yl99Z5O.jpg'),
(99888, 7090, 'Last Light S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209420.mp4', 'http://image.tmdb.org/t/p/w1280/dTi1U59jRE7tzr6uIwCrYypo5h2.jpg'),
(99889, 7090, 'Last Light S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209421.mp4', 'http://image.tmdb.org/t/p/w1280/cM4EiRbGOTlFmgCyGGnDX4ASpH8.jpg'),
(99890, 7091, 'Lycoris Recoil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iauquKZXghgLhPBL2zESoNWhsqN.jpg'),
(99891, 7091, 'Lycoris Recoil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rEeiYfRuUZCcfxIGdokF4Itzpjg.jpg'),
(99892, 7091, 'Lycoris Recoil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lkRbBRT6FFMPMTDtE8eRrb2DYvQ.jpg'),
(99893, 7091, 'Lycoris Recoil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ic4g6NQoiawBVzTFXusGLl0XuY.jpg'),
(99894, 7091, 'Lycoris Recoil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oUdCd4rqNsRObv45FNvA6bsil6M.jpg'),
(99895, 7091, 'Lycoris Recoil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mFOT8g8xVsDB0IzDb19qKdt06ao.jpg'),
(99896, 7091, 'Lycoris Recoil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cVyWZHaKQQ4Ex0Z4q5EoKzkK2EV.jpg'),
(99897, 7091, 'Lycoris Recoil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5pvnNkF1y7yUEBdq7N0kyddN2.jpg'),
(99898, 7091, 'Lycoris Recoil S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ElzWAOVcHOG81yzEY75BkU7rnb.jpg'),
(99899, 7091, 'Lycoris Recoil S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hexq93q1fSacTRI6VrjXdRSbIYo.jpg'),
(99900, 7091, 'Lycoris Recoil S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3K3eoIbOvU7Yeads7mFH4NU90xx.jpg'),
(99901, 7091, 'Lycoris Recoil S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6mqulquTDkeWhSzsNf3hRvPj18B.jpg'),
(99902, 7091, 'Lycoris Recoil S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n19LJPswIzi8d1aAktw9ai4Vyh0.jpg'),
(99903, 7092, 'O Clube dos Graves S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o4sAjqJhUcRx6Y0xCIWsMvaGSrl.jpg'),
(99904, 7092, 'O Clube dos Graves S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2eoTaMC3Kr39aTWmpwU2fSTeLQH.jpg'),
(99905, 7092, 'O Clube dos Graves S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g74Y4AIbhcedLUi0BuSZZMJ5CU7.jpg'),
(99906, 7092, 'O Clube dos Graves S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bd4oz5IzHJ3BXZ2TfCofROYmkkw.jpg'),
(99907, 7092, 'O Clube dos Graves S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jqdbu1wrSjFE3VdohXqHBv9czei.jpg'),
(99908, 7092, 'O Clube dos Graves S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gu3c2NYVb374FpKd5VBZ5dPRjP4.jpg'),
(99909, 7092, 'O Clube dos Graves S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cOludXGLZBP31LJRyPA3p9rVpoW.jpg'),
(99910, 7092, 'O Clube dos Graves S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJDYMaAJszA0IGDEc6hPMd7YHgH.jpg'),
(99911, 7092, 'O Clube dos Graves S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b4nS93cFUDiG0gDgyY2Zvujt8Xi.jpg'),
(99912, 7092, 'O Clube dos Graves S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mrdjv0bsbXsmsoHb9PngGK6tyyR.jpg'),
(99913, 7093, 'O Consultor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lrFzvTMeAKcdQ7fxDuLzV4yUNec.jpg'),
(99914, 7093, 'O Consultor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vj5fJ6so9L9rkQoO4T3TNvcAnJU.jpg'),
(99915, 7093, 'O Consultor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xAW0UdadNOZ2GZ5e96zrlKOPFHK.jpg'),
(99916, 7093, 'O Consultor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lSdZnEt7rKpYuTrCvHwsqZjL0iw.jpg'),
(99917, 7093, 'O Consultor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFG1BVdPrk5S1fEduGnBRD0F33E.jpg'),
(99918, 7093, 'O Consultor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/af1U89hh7ruAtiJ4bc7k8opPGcy.jpg'),
(99919, 7093, 'O Consultor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3SFw629HshnLxAMidaVbAbMr7XV.jpg'),
(99920, 7093, 'O Consultor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bSeVCUTV1QH7AKpk3llzApTQm43.jpg'),
(99921, 7094, 'Pobre Diabo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xWLKMJDCGIrvjyPtO8OGGJAmsti.jpg'),
(99922, 7094, 'Pobre Diabo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hl3q91yH7cOBnT7hqmJJwYa7GwZ.jpg'),
(99923, 7094, 'Pobre Diabo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/69yZuW2T9vjyrgjmXe6gx1LWxdR.jpg'),
(99924, 7094, 'Pobre Diabo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ktH4Y5mBQWyXh7izHMagrZIkspn.jpg'),
(99925, 7094, 'Pobre Diabo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/grJNlEcGqalxQO64XBpli4j4AKc.jpg'),
(99926, 7094, 'Pobre Diabo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/58pTg78q67oXZKylGmVTCu96UA1.jpg'),
(99927, 7094, 'Pobre Diabo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kTuqaOat2aEKyiP2tGuJ5UuIsUV.jpg'),
(99928, 7094, 'Pobre Diabo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3RpMh1LmlveiXzDsMD7CuKmL0gK.jpg'),
(99929, 7095, 'Queer Eye: Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kOyOvnXvKLgFAqbajIZplAEAQ0.jpg'),
(99930, 7095, 'Queer Eye: Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kOyOvnXvKLgFAqbajIZplAEAQ0.jpg'),
(99931, 7095, 'Queer Eye: Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kOyOvnXvKLgFAqbajIZplAEAQ0.jpg'),
(99932, 7095, 'Queer Eye: Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kOyOvnXvKLgFAqbajIZplAEAQ0.jpg'),
(99933, 7095, 'Queer Eye: Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kOyOvnXvKLgFAqbajIZplAEAQ0.jpg'),
(99934, 7095, 'Queer Eye: Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kOyOvnXvKLgFAqbajIZplAEAQ0.jpg'),
(99935, 7096, 'Reforma em Familia: O Desafio de Mina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ampnbKuW9tsVZZaECY9ejNECrc3.jpg'),
(99936, 7096, 'Reforma em Familia: O Desafio de Mina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ampnbKuW9tsVZZaECY9ejNECrc3.jpg'),
(99937, 7096, 'Reforma em Familia: O Desafio de Mina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ampnbKuW9tsVZZaECY9ejNECrc3.jpg'),
(99938, 7096, 'Reforma em Familia: O Desafio de Mina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ampnbKuW9tsVZZaECY9ejNECrc3.jpg'),
(99939, 7096, 'Reforma em Familia: O Desafio de Mina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ampnbKuW9tsVZZaECY9ejNECrc3.jpg'),
(99940, 7096, 'Reforma em Familia: O Desafio de Mina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ampnbKuW9tsVZZaECY9ejNECrc3.jpg'),
(99941, 7097, 'Três Vidas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eHBKAQnw8qU99p2F6255w3i6WnJ.jpg'),
(99942, 7097, 'Três Vidas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hBEmct5pzPWxwR6NOfQKTXwbhKV.jpg'),
(99943, 7097, 'Três Vidas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Ixr5J9rjpLxLS6Cq6I2pYlmOaw.jpg'),
(99944, 7097, 'Três Vidas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFydx4BaPQaB6PziFAfUhuZ4GEc.jpg'),
(99945, 7097, 'Três Vidas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dqXKd5YBJHOjfmwxeF1LbxcX5sb.jpg'),
(99946, 7097, 'Três Vidas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wYkCUVee5a05AT00xIH4dS1CClV.jpg'),
(99947, 7097, 'Três Vidas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4DYqA1f0itokdl6r32FF7FJbILJ.jpg'),
(99948, 7097, 'Três Vidas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hWzEvo1ZER8zRLRdEircDrecYS6.jpg'),
(99949, 7098, 'Viagra: A Pílula que Mudou o Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rjQKMjKqrUhZMGzmbuhX1dGa5eT.jpg'),
(99950, 7098, 'Viagra: A Pílula que Mudou o Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rjQKMjKqrUhZMGzmbuhX1dGa5eT.jpg'),
(99951, 7098, 'Viagra: A Pílula que Mudou o Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rjQKMjKqrUhZMGzmbuhX1dGa5eT.jpg'),
(99952, 7099, 'Uma Odisséia Coreana S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/avsFNcBxrzFyFzMpYcSFhOvZaRM.jpg'),
(99953, 7099, 'Uma Odisséia Coreana S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4DuSsBaMV4fVO3m5xTliiAefgtC.jpg'),
(99954, 7099, 'Uma Odisséia Coreana S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xyBgiKzJkDlEfoegD98Z4oE9eZV.jpg'),
(99955, 7099, 'Uma Odisséia Coreana S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wpvgq8kLQRsVPm8rPomU1kbrcHH.jpg'),
(99956, 7099, 'Uma Odisséia Coreana S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yKgDxwm2heXRHoDTtR090T97we3.jpg'),
(99957, 7099, 'Uma Odisséia Coreana S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h7rrhWDr9tMZzHBYbaKOfdnGtzv.jpg'),
(99958, 7099, 'Uma Odisséia Coreana S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7I9aqFvRMsgQwc5fGkrNRxyv1t7.jpg'),
(99959, 7099, 'Uma Odisséia Coreana S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bcy5CbYBqA8ne32MU6weuBKMEQK.jpg'),
(99960, 7099, 'Uma Odisséia Coreana S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wEndIvxWWCjULd7VJUSQton7LQq.jpg'),
(99961, 7099, 'Uma Odisséia Coreana S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s8NLmdYKa2IfxdVgOpUBFs73sbv.jpg'),
(99962, 7099, 'Uma Odisséia Coreana S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yhrQXxCqD7XBmBsQbmE32TdsmfK.jpg'),
(99963, 7099, 'Uma Odisséia Coreana S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m8BVHdxY7K7G98ZF12gLZOSSRZ1.jpg'),
(99964, 7099, 'Uma Odisséia Coreana S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/207049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d3ccDdvVkMnw1AKttJmWUvriyec.jpg'),
(99965, 7099, 'Uma Odisséia Coreana S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/207050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/30Z4SknZQlWOl5IQ6XrQWWELMbi.jpg'),
(99966, 7099, 'Uma Odisséia Coreana S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/207051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fRP7FElBy4Dgt0ykCRm8yf5kU0H.jpg'),
(99967, 7099, 'Uma Odisséia Coreana S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/207052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/olf1zuL2Rlqb9WV0vCz0ZeStJut.jpg'),
(99968, 7099, 'Uma Odisséia Coreana S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/207053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i94Pc8JJDXVV36zeTYFen9D2SQk.jpg'),
(99969, 7099, 'Uma Odisséia Coreana S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/207054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nGhJ6QYdGF5UM5nM1jbkMBvYRSb.jpg'),
(99970, 7099, 'Uma Odisséia Coreana S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/207055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h2IxJxxb5utHkOEF5qBmUhiEyVZ.jpg'),
(99971, 7099, 'Uma Odisséia Coreana S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/207056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tvf5nQBiP6QfxUgE2rZ6ykRICFd.jpg'),
(99972, 7100, 'Big Time Rush S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5FCIznZENbPuZDpp3NQ7TMI9WIh.jpg'),
(99973, 7100, 'Big Time Rush S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1qKkYOqvTvHgbr1ZrztwWuKF7Am.jpg'),
(99974, 7100, 'Big Time Rush S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sleI7RlKdUvLGNgJ0JJnjzHaqV4.jpg'),
(99975, 7100, 'Big Time Rush S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rWovuzi2X79E0O8VusejkABPx7p.jpg'),
(99976, 7100, 'Big Time Rush S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzheAuGmHvyiQf09ZHgFHBNgNod.jpg'),
(99977, 7100, 'Big Time Rush S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nHDdvSrSfSHV6MKX7BZTOF7EtVU.jpg'),
(99978, 7100, 'Big Time Rush S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o8TTgP2RpY1O4EBcbci4plapGFN.jpg'),
(99979, 7100, 'Big Time Rush S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/el4amgrQEdStz3BeIW3y4u7Zrpz.jpg'),
(99980, 7100, 'Big Time Rush S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iHxHa2KIo5OxeohkgoE5NHYAGiH.jpg'),
(99981, 7100, 'Big Time Rush S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iFAhDgdSHOAcWOH6ceaHj5Jzmnu.jpg'),
(99982, 7100, 'Big Time Rush S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mD9KoJpLRFpuXHXVahWV13HKVCO.jpg'),
(99983, 7100, 'Big Time Rush S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9EKMXL1KTCzJwjNMQloOXhz8WYz.jpg'),
(99984, 7100, 'Big Time Rush S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nVajmT7jRSx0p6VPVpxCNTeVxIJ.jpg'),
(99985, 7100, 'Big Time Rush S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aSGjpV85HoRV7YJLxWAqdhvbE5M.jpg'),
(99986, 7100, 'Big Time Rush S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wJXmha7bsrewyrw60OrYf4bJKP8.jpg'),
(99987, 7100, 'Big Time Rush S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qQ5u8zFlnNXtRv1UkPbzpAKRWAQ.jpg'),
(99988, 7100, 'Big Time Rush S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/206984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5VNE3au8Aw87cmbQbVNwkVdwrV2.jpg'),
(99989, 7100, 'Big Time Rush S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/206985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ecm3bBvpLzUmSHOKa1H8uFZOyi0.jpg'),
(99990, 7101, 'Big Time Rush S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1b987Bi7vrGFRVA346wRuY3FzKB.jpg'),
(99991, 7101, 'Big Time Rush S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/junYFuhmage6L6OZXw15xsCevIV.jpg'),
(99992, 7101, 'Big Time Rush S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Og6NG49HVOHBgy9RFQK2DujuZu.jpg'),
(99993, 7101, 'Big Time Rush S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gEx9VzyQiQ8CrOeTcxTvJd63BEH.jpg'),
(99994, 7101, 'Big Time Rush S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cjxcse3msLLP6CQ8Lxm9CJrlXTO.jpg'),
(99995, 7101, 'Big Time Rush S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tU6pG1vOk14I2d6mELN7WHIdXOY.jpg'),
(99996, 7101, 'Big Time Rush S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4jkkSDfZcQ7K5t88cgWBAPwNuYz.jpg'),
(99997, 7101, 'Big Time Rush S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ljTLzJvjjNt2XswIFNFNIt5NfLz.jpg'),
(99998, 7101, 'Big Time Rush S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qV1NCcIJO0FCSNdDj0RvHH8WAkV.jpg'),
(99999, 7101, 'Big Time Rush S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kQz770KqVdUEooaS25HcVk3c8FZ.jpg'),
(100000, 7101, 'Big Time Rush S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qDoaY1gcme4bfEFd128dLmKF3Sq.jpg'),
(100001, 7101, 'Big Time Rush S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lWTOHsYMecJ9XDGFF8DktNDS3NB.jpg'),
(100002, 7101, 'Big Time Rush S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ev7svbdz2dm51CDK45FfenZIhyX.jpg'),
(100003, 7101, 'Big Time Rush S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gOUbyDZztDqxojsJidjmCFJ8Krk.jpg'),
(100004, 7101, 'Big Time Rush S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/207000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qNSNEYayBBBmYYUZA1Icr7KvWhn.jpg'),
(100005, 7101, 'Big Time Rush S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/207001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ps2sRbD3UL76L4e62pXvcz2gUdC.jpg'),
(100006, 7101, 'Big Time Rush S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/207002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bSFxXj610KQL8uX7DqH9Y7tVgKp.jpg'),
(100007, 7101, 'Big Time Rush S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/207003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nZlcdX1kB2rgRseWqZpAJhcaGjl.jpg'),
(100008, 7101, 'Big Time Rush S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/207004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xcG1YRWZzRiRg8awpmqNa6XbktU.jpg'),
(100009, 7101, 'Big Time Rush S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/207005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/OPRpOqNzQlfOFuyExB7StVyNXu.jpg'),
(100010, 7101, 'Big Time Rush S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/207006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/soUosyVJ3MU7L9KQU2M93gNAwQ5.jpg'),
(100011, 7101, 'Big Time Rush S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/207007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/liQCsrjjU7BhxONckxjlfm4AXNK.jpg'),
(100012, 7101, 'Big Time Rush S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/207008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hIIcQkFame2Z7w8qODhsf2Ib9qD.jpg'),
(100013, 7101, 'Big Time Rush S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/207009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmdQPknorgRncLoesa1rJRD8JaQ.jpg'),
(100014, 7101, 'Big Time Rush S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/207010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8CMb41sY1JWP7sTfpYWK7kjOgQ.jpg'),
(100015, 7101, 'Big Time Rush S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/207011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r5WJIDykO3pv9jUU3Bws0W7F7N1.jpg'),
(100016, 7101, 'Big Time Rush S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/207012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6UZd4MLIfWbp69B8rDBDtMVXFeF.jpg'),
(100017, 7102, 'Big Time Rush S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gaCucpANykRjKNkXVWZYPFdqXWT.jpg'),
(100018, 7102, 'Big Time Rush S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTibUDWnTzavzCez1Om8BytmCvx.jpg'),
(100019, 7102, 'Big Time Rush S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jPVaiy3Xo4dBqvLMCeXWPmamZ5q.jpg'),
(100020, 7102, 'Big Time Rush S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s1XqfemIRNdcGxVUxCPkL8Az39H.jpg'),
(100021, 7102, 'Big Time Rush S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2c86RVbXpT5lYdbgK9vjioaGgLf.jpg'),
(100022, 7102, 'Big Time Rush S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i3F4RRHXNSyuezr1ZmsyFwBW1rm.jpg'),
(100023, 7102, 'Big Time Rush S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7OnSQ1DhF5AmamUcaPgLDeKCRQi.jpg'),
(100024, 7102, 'Big Time Rush S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ELMh4q0mNHVdJGQNA9Sq95WS3T.jpg'),
(100025, 7102, 'Big Time Rush S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nzoo7AD7YT0legeGjZfqILhotVr.jpg'),
(100026, 7102, 'Big Time Rush S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hGQyubCjGuqbjb9dFpppAzuE7d0.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(100027, 7102, 'Big Time Rush S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qXfUjorDqLtKUKHViyx0CQhw3OW.jpg'),
(100028, 7102, 'Big Time Rush S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cfubOi3e7SfzB9oddmI7619BWZW.jpg'),
(100029, 7103, 'Big Time Rush S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/207025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u6HAfndHeZheRkzaA7zX1gqFmPg.jpg'),
(100030, 7103, 'Big Time Rush S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/207026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oLRIPsGWVADLFWA6wjgaUD2TwKy.jpg'),
(100031, 7103, 'Big Time Rush S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/207027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hK2YtNSUe929ivmndAfuxTXy4it.jpg'),
(100032, 7103, 'Big Time Rush S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/207028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3tn5RQrosp3aKwmOghBCc1kEDqH.jpg'),
(100033, 7103, 'Big Time Rush S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/207029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mYt86a2aD4WkIURR7JROlNGuk1a.jpg'),
(100034, 7103, 'Big Time Rush S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/207030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJi6Bte0hXR82Zg6UyJ2ImDnqYW.jpg'),
(100035, 7103, 'Big Time Rush S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/207031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rNF5byfEEpvI4xd1ua8FqGuv7OR.jpg'),
(100036, 7103, 'Big Time Rush S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/207032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/slpZyJGU0C88kMCrls12moN7LEU.jpg'),
(100037, 7103, 'Big Time Rush S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/207033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tnjCk0RC9rFgCXL1olBPc7NAimR.jpg'),
(100038, 7103, 'Big Time Rush S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/207034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tPTBBYMEKxAgLSQRuL1NMujNGSV.jpg'),
(100039, 7103, 'Big Time Rush S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/207035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9TDQvYaxHMH2tVg7baucbiorlrq.jpg'),
(100040, 7103, 'Big Time Rush S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/207036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zJ1YlSt3GNNH7W7AGmi624NLMSp.jpg'),
(100041, 7104, 'Clínica Animal com Dr. Pol S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZbRnigYWhXZVzzVdzIwNnME0si.jpg'),
(100042, 7104, 'Clínica Animal com Dr. Pol S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i58YuuFIk3qMjmvDvUkE6zKsTJF.jpg'),
(100043, 7104, 'Clínica Animal com Dr. Pol S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7iP2sBrtHqppwC2BQQz69HfbOBI.jpg'),
(100044, 7104, 'Clínica Animal com Dr. Pol S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8CcPU3ApqJ5GEJr9ILSNjCMVVS4.jpg'),
(100045, 7105, 'Clínica Animal com Dr. Pol S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fuE3ROilLwA4XV2q2rOFO3Kkvxe.jpg'),
(100046, 7105, 'Clínica Animal com Dr. Pol S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fvpXlxU3pANN89GgFIslCwKJkFF.jpg'),
(100047, 7105, 'Clínica Animal com Dr. Pol S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pekdvKKB0SHX05LePsqOZ7jawoY.jpg'),
(100048, 7105, 'Clínica Animal com Dr. Pol S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jQIvW7QIvjNuU3PvZ52yf5Jp7e3.jpg'),
(100049, 7105, 'Clínica Animal com Dr. Pol S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zrz11BxU3qH14TVEWocpxZSphIf.jpg'),
(100050, 7105, 'Clínica Animal com Dr. Pol S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7QAQCLuICpBypXQgp4mJRuNFpcS.jpg'),
(100051, 7105, 'Clínica Animal com Dr. Pol S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8JInj5s4adwhcxLxFn8zZrok8Lb.jpg'),
(100052, 7105, 'Clínica Animal com Dr. Pol S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Z5szU7l3sTn4RXQVTWewVYgGXe.jpg'),
(100053, 7105, 'Clínica Animal com Dr. Pol S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rdovX92GncqRm6A7GbDyelLeJgp.jpg'),
(100054, 7105, 'Clínica Animal com Dr. Pol S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ox3ey2hJMUwuX7yrmfCxKvg5Fr.jpg'),
(100055, 7105, 'Clínica Animal com Dr. Pol S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nHJXWoIihrqAdSaqELf2Ixb1O1p.jpg'),
(100056, 7105, 'Clínica Animal com Dr. Pol S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i7TSo6uyaL2uTEhxCTnQhu0gNXh.jpg'),
(100057, 7105, 'Clínica Animal com Dr. Pol S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2qmPK66Uloo7uDY7wcZ6No8wko.jpg'),
(100058, 7105, 'Clínica Animal com Dr. Pol S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1Y9Q388WSaPJ7vPxIZKpsimy5i.jpg'),
(100059, 7105, 'Clínica Animal com Dr. Pol S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l8HqS9a2gY08lGgj0Z9tz1dTnZB.jpg'),
(100060, 7105, 'Clínica Animal com Dr. Pol S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtcMoDQzJGbR9bUNyfLRaIlLG8k.jpg'),
(100061, 7106, 'Clínica Animal com Dr. Pol S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4y5fOV0T8UObnOJ0wqiux9dSAu6.jpg'),
(100062, 7106, 'Clínica Animal com Dr. Pol S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ylqkX8Pl7DUPOvd0V3aIbgSJis2.jpg'),
(100063, 7106, 'Clínica Animal com Dr. Pol S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xzS4of3HqqBWoU5KpBrUzJZgnOc.jpg'),
(100064, 7106, 'Clínica Animal com Dr. Pol S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Bo6wCh12ZhTM0jPzNCt9lnSgpL.jpg'),
(100065, 7106, 'Clínica Animal com Dr. Pol S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l2ZgGhZEUNT9Sl3jThj2rrJhaod.jpg'),
(100066, 7106, 'Clínica Animal com Dr. Pol S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhGoRiwVJn13vT9VWkrqn0IOYxT.jpg'),
(100067, 7107, 'Clínica Animal com Dr. Pol S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u1G3YFoHAsE6RyeS8oJFt3TFb8H.jpg'),
(100068, 7107, 'Clínica Animal com Dr. Pol S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qA8lT6PhEd73jEgYe9uAnUmN00H.jpg'),
(100069, 7107, 'Clínica Animal com Dr. Pol S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glyruKA32pI8HEfOit45RLq9kgS.jpg'),
(100070, 7107, 'Clínica Animal com Dr. Pol S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mxMpZiSTU9kKFJnIifrljAlXYWG.jpg'),
(100071, 7107, 'Clínica Animal com Dr. Pol S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zibLGYsdVphncGAtXWWXX6H7NQe.jpg'),
(100072, 7107, 'Clínica Animal com Dr. Pol S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1MsGztSZH51rtRDb4pVxsvS9OmV.jpg'),
(100073, 7107, 'Clínica Animal com Dr. Pol S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jxHS1B8G587cv9wDMvM2pxvzbin.jpg'),
(100074, 7107, 'Clínica Animal com Dr. Pol S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rV9r8nNwjvehcZlovJIhe7jyHK9.jpg'),
(100075, 7107, 'Clínica Animal com Dr. Pol S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iXZqlgmWKWaCbYJwF63XdrsfMsF.jpg'),
(100076, 7107, 'Clínica Animal com Dr. Pol S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jXcxqsecQlxDQakkdrQreJkO5xe.jpg'),
(100077, 7108, 'Clínica Animal com Dr. Pol S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yz1nEv9CxU95KiihNNQMdSzDT1a.jpg'),
(100078, 7108, 'Clínica Animal com Dr. Pol S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8fCuNP8WgfZ8uWeK3vX2EDdskG7.jpg'),
(100079, 7108, 'Clínica Animal com Dr. Pol S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l3PZFs2XDrHi6GVMU9OTcU1Y7p0.jpg'),
(100080, 7108, 'Clínica Animal com Dr. Pol S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jj4wc2VzIofRvnbZiDwxtY4zie4.jpg'),
(100081, 7108, 'Clínica Animal com Dr. Pol S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mEXOkzi6eNIYkClZLE74mxuCZqE.jpg'),
(100082, 7108, 'Clínica Animal com Dr. Pol S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBQDvRVv4NOMwBfhqzWWtPxx6n1.jpg'),
(100083, 7108, 'Clínica Animal com Dr. Pol S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n1KhIgXLkM1d4fEDapaewpau6yV.jpg'),
(100084, 7108, 'Clínica Animal com Dr. Pol S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gusGSGnKujCPRI92HlCKR0ZZmvg.jpg'),
(100085, 7108, 'Clínica Animal com Dr. Pol S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8lwMIlXLlwp74x1xXFgMEEu17Qa.jpg'),
(100086, 7108, 'Clínica Animal com Dr. Pol S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c2dn5XPPaMcvzA2bEc29RlYDJ2o.jpg'),
(100087, 7109, 'Clínica Animal com Dr. Pol S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6HkFIXUGzTs5p2duVxetIkN1Yhr.jpg'),
(100088, 7109, 'Clínica Animal com Dr. Pol S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9WR7BIYeOH7Xm0lx8X8lqOvh2Ni.jpg'),
(100089, 7109, 'Clínica Animal com Dr. Pol S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3TqccBMUSVnY7w2DJn6tU1Z7PeK.jpg'),
(100090, 7109, 'Clínica Animal com Dr. Pol S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tilfzVukpukruUwI9g4qiKIgXu8.jpg'),
(100091, 7109, 'Clínica Animal com Dr. Pol S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aat4SMAcQJwU3bcOvQazFj9zckL.jpg'),
(100092, 7109, 'Clínica Animal com Dr. Pol S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z568tKluI24MK5zX692LTrRNY2r.jpg'),
(100093, 7109, 'Clínica Animal com Dr. Pol S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c0ZUMFMtDpC47kSiyVq18qJQOHJ.jpg'),
(100094, 7109, 'Clínica Animal com Dr. Pol S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c1D52ToeHqrVqxmvLPww2xTTGDN.jpg'),
(100095, 7109, 'Clínica Animal com Dr. Pol S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yBLjiE7FQPyf33xlHtskgfTidcA.jpg'),
(100096, 7109, 'Clínica Animal com Dr. Pol S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7yZe3vmKEYJ3sf0PTRFEIxPlxFs.jpg'),
(100097, 7110, 'Clínica Animal com Dr. Pol S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8JInj5s4adwhcxLxFn8zZrok8Lb.jpg'),
(100098, 7110, 'Clínica Animal com Dr. Pol S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8JInj5s4adwhcxLxFn8zZrok8Lb.jpg'),
(100099, 7110, 'Clínica Animal com Dr. Pol S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8JInj5s4adwhcxLxFn8zZrok8Lb.jpg'),
(100100, 7110, 'Clínica Animal com Dr. Pol S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8JInj5s4adwhcxLxFn8zZrok8Lb.jpg'),
(100101, 7110, 'Clínica Animal com Dr. Pol S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8JInj5s4adwhcxLxFn8zZrok8Lb.jpg'),
(100102, 7110, 'Clínica Animal com Dr. Pol S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8JInj5s4adwhcxLxFn8zZrok8Lb.jpg'),
(100103, 7110, 'Clínica Animal com Dr. Pol S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8JInj5s4adwhcxLxFn8zZrok8Lb.jpg'),
(100104, 7110, 'Clínica Animal com Dr. Pol S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8JInj5s4adwhcxLxFn8zZrok8Lb.jpg'),
(100105, 7110, 'Clínica Animal com Dr. Pol S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8JInj5s4adwhcxLxFn8zZrok8Lb.jpg'),
(100106, 7110, 'Clínica Animal com Dr. Pol S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8JInj5s4adwhcxLxFn8zZrok8Lb.jpg'),
(100107, 7111, 'George & Tammy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7awJ4Jnjnmw0IMeFXzIWfd7RY1Z.jpg'),
(100108, 7111, 'George & Tammy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJewFBCJuK5e7VbMWnw7XGN2Lqh.jpg'),
(100109, 7111, 'George & Tammy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A9plpmTK09y5EIbp6D1K5xuazpZ.jpg'),
(100110, 7111, 'George & Tammy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/srlnPtOVY7a1FV2vuBP44AjJyls.jpg'),
(100111, 7111, 'George & Tammy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qeoL0m92BDvNvxGUeEEsBoa5raZ.jpg'),
(100112, 7111, 'George & Tammy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3FVTGQ3sqdSpb6xSEBvxawMX6Ye.jpg'),
(100113, 7112, 'Match Perfeito S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lIzPtm8KBfhxXN1vVf1D01xHIFX.jpg'),
(100114, 7112, 'Match Perfeito S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fWnmjK1vjsU1Yj62b9DQj32iFuj.jpg'),
(100115, 7112, 'Match Perfeito S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/83bzir5ERI6OdEid0N76OujTfCn.jpg'),
(100116, 7112, 'Match Perfeito S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cQfEDvgLihyHKbNKciWl5f5NFmY.jpg'),
(100117, 7112, 'Match Perfeito S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lTIHjXfQoxoBRXrRXlmbk8RuOro.jpg'),
(100118, 7112, 'Match Perfeito S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sYV00tmrW8cUn1aaIxVbYPaQAJ1.jpg'),
(100119, 7112, 'Match Perfeito S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wdKvAGsHvQXzYZY1lm2NpQtlHEc.jpg'),
(100120, 7112, 'Match Perfeito S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ZMNDsir1Y9zgKLQSxoYVU9lIlf.jpg'),
(100121, 7112, 'Match Perfeito S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dPOzyS0GJtS0ZgEUV8mWVvSe8AK.jpg'),
(100122, 7112, 'Match Perfeito S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ex8JOdHQt219ylaoSW2ytePi1bk.jpg'),
(100123, 7112, 'Match Perfeito S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/saElz1bn35n7cwjHekAwZyEwXuy.jpg'),
(100124, 7112, 'Match Perfeito S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/YpYQYdYXWGPBnSEOO4UQsSioj7.jpg'),
(100125, 7113, 'Match Perfeito S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/879407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtctDhrPDCYLDF3NA5LrNp9Z1ML.jpg'),
(100126, 7113, 'Match Perfeito S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/879408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtctDhrPDCYLDF3NA5LrNp9Z1ML.jpg'),
(100127, 7113, 'Match Perfeito S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/879409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtctDhrPDCYLDF3NA5LrNp9Z1ML.jpg'),
(100128, 7113, 'Match Perfeito S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/879410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtctDhrPDCYLDF3NA5LrNp9Z1ML.jpg'),
(100129, 7113, 'Match Perfeito S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/879411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtctDhrPDCYLDF3NA5LrNp9Z1ML.jpg'),
(100130, 7113, 'Match Perfeito S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/879412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtctDhrPDCYLDF3NA5LrNp9Z1ML.jpg'),
(100131, 7113, 'Match Perfeito S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/879413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtctDhrPDCYLDF3NA5LrNp9Z1ML.jpg'),
(100132, 7113, 'Match Perfeito S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/879414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtctDhrPDCYLDF3NA5LrNp9Z1ML.jpg'),
(100133, 7113, 'Match Perfeito S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/879415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtctDhrPDCYLDF3NA5LrNp9Z1ML.jpg'),
(100134, 7113, 'Match Perfeito S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/879416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtctDhrPDCYLDF3NA5LrNp9Z1ML.jpg'),
(100135, 7114, 'Match Perfeito S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/879417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtctDhrPDCYLDF3NA5LrNp9Z1ML.jpg'),
(100136, 7114, 'Match Perfeito S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/879418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtctDhrPDCYLDF3NA5LrNp9Z1ML.jpg'),
(100137, 7114, 'Match Perfeito S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/879419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtctDhrPDCYLDF3NA5LrNp9Z1ML.jpg'),
(100138, 7114, 'Match Perfeito S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/879420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtctDhrPDCYLDF3NA5LrNp9Z1ML.jpg'),
(100139, 7114, 'Match Perfeito S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/879421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtctDhrPDCYLDF3NA5LrNp9Z1ML.jpg'),
(100140, 7114, 'Match Perfeito S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/879422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtctDhrPDCYLDF3NA5LrNp9Z1ML.jpg'),
(100141, 7114, 'Match Perfeito S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/880580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtctDhrPDCYLDF3NA5LrNp9Z1ML.jpg'),
(100142, 7114, 'Match Perfeito S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/880581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtctDhrPDCYLDF3NA5LrNp9Z1ML.jpg'),
(100143, 7114, 'Match Perfeito S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/880582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtctDhrPDCYLDF3NA5LrNp9Z1ML.jpg'),
(100144, 7114, 'Match Perfeito S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/880583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtctDhrPDCYLDF3NA5LrNp9Z1ML.jpg'),
(100145, 7115, 'Ninguém Pode Ouvir Seu Grito S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pxQomyS7T6rOhNzMS2YEH0dbJVA.jpg'),
(100146, 7115, 'Ninguém Pode Ouvir Seu Grito S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208470.mp4', 'http://image.tmdb.org/t/p/w1280/krWZF0ZQCqgWHYyYRPlCenQ8ecE.jpg'),
(100147, 7115, 'Ninguém Pode Ouvir Seu Grito S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208471.mp4', 'http://image.tmdb.org/t/p/w1280/ghAMixb7nAqfUSHVS857OFfYIKF.jpg'),
(100148, 7115, 'Ninguém Pode Ouvir Seu Grito S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208472.mp4', 'http://image.tmdb.org/t/p/w1280/z3riUZS2MCX1mWPPjp9qCbw2c76.jpg'),
(100149, 7115, 'Ninguém Pode Ouvir Seu Grito S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208473.mp4', 'http://image.tmdb.org/t/p/w1280/wNJ2rtgi0ZDzxWW4aKHAXOKnleS.jpg'),
(100150, 7115, 'Ninguém Pode Ouvir Seu Grito S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208474.mp4', 'http://image.tmdb.org/t/p/w1280/4BcXn7dLsabOeWpqHq8dphCADys.jpg'),
(100151, 7116, 'O Cafetão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sB11qYVwVAERvtcOrsv6AIUoqqN.jpg'),
(100152, 7116, 'O Cafetão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/22KQqjbIUO1G4G145jxKniwLkl6.jpg'),
(100153, 7116, 'O Cafetão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rDgaCWm8gADiM8QCigrWC0EN0BC.jpg'),
(100154, 7116, 'O Cafetão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qSIeg8aS349iIBXg3RncumSKRFD.jpg'),
(100155, 7116, 'O Cafetão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wurhqEtycy7gEgmEa7Feqoz21Pw.jpg'),
(100156, 7116, 'O Cafetão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AuG32GQDHMJIaOR6vEzqVqbUBZz.jpg'),
(100157, 7117, 'Quantum Leap: Contratempos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6vnLrduCbMsw0AhF8NQtVLdKYZA.jpg'),
(100158, 7117, 'Quantum Leap: Contratempos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1GScVhn68dq03tvq3ZXxpJFKMca.jpg'),
(100159, 7117, 'Quantum Leap: Contratempos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u2nqncSynC7LiZWVgtSy29GZVSh.jpg'),
(100160, 7117, 'Quantum Leap: Contratempos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kUn0OmSTCVc15s4HnIw54JdhrSL.jpg'),
(100161, 7117, 'Quantum Leap: Contratempos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wEmUtw1pjdjU5mERj2WFxxZd3SV.jpg'),
(100162, 7117, 'Quantum Leap: Contratempos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFTy6asrv3bEnOhJ5WeBQdwIRDu.jpg'),
(100163, 7117, 'Quantum Leap: Contratempos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zYuwBORkqFZqq6yn3F48wuxEsVY.jpg'),
(100164, 7117, 'Quantum Leap: Contratempos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/30pVOQJGr7rPAU8mA87Q2cU0aSR.jpg'),
(100165, 7117, 'Quantum Leap: Contratempos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7nK01kwKWbEyED1ll7n6E3hi7UB.jpg'),
(100166, 7117, 'Quantum Leap: Contratempos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jeJYG5vUMpBokkzF3IIMoq3KHbQ.jpg'),
(100167, 7117, 'Quantum Leap: Contratempos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6LvpbQLu8yJuBTT6vGyykBXEDkX.jpg'),
(100168, 7117, 'Quantum Leap: Contratempos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6bg29QLvhFSEdLwb0OPvRSrYzDm.jpg'),
(100169, 7117, 'Quantum Leap: Contratempos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c7BwEZ6TexiOj95svk6NYErAUlA.jpg'),
(100170, 7117, 'Quantum Leap: Contratempos S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/217675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pmnwMSmstJyRuQJeQjMhEbdFErF.jpg'),
(100171, 7117, 'Quantum Leap: Contratempos S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/217676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/joKdouD9xEfXwwv2A9uX9pFZFmR.jpg'),
(100172, 7117, 'Quantum Leap: Contratempos S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/217677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xctDMPiVnLQr19ehG9gmdEy9qhF.jpg'),
(100173, 7117, 'Quantum Leap: Contratempos S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/217678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bhgmKJkGFP1cK2oIfaRtVXsQQ4H.jpg'),
(100174, 7117, 'Quantum Leap: Contratempos S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/217679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cWr6Xb0LUiw3FwgaC54SQ78pDgc.jpg'),
(100175, 7118, 'Quantum Leap: Contratempos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/423273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uEy8VdTqtfnLGvgCkooow7btLf.jpg'),
(100176, 7118, 'Quantum Leap: Contratempos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/423274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uEy8VdTqtfnLGvgCkooow7btLf.jpg'),
(100177, 7118, 'Quantum Leap: Contratempos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/423275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uEy8VdTqtfnLGvgCkooow7btLf.jpg'),
(100178, 7118, 'Quantum Leap: Contratempos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/423276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uEy8VdTqtfnLGvgCkooow7btLf.jpg'),
(100179, 7118, 'Quantum Leap: Contratempos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/423277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uEy8VdTqtfnLGvgCkooow7btLf.jpg'),
(100180, 7118, 'Quantum Leap: Contratempos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/423278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uEy8VdTqtfnLGvgCkooow7btLf.jpg'),
(100181, 7118, 'Quantum Leap: Contratempos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/423279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uEy8VdTqtfnLGvgCkooow7btLf.jpg'),
(100182, 7118, 'Quantum Leap: Contratempos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/423280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uEy8VdTqtfnLGvgCkooow7btLf.jpg'),
(100183, 7118, 'Quantum Leap: Contratempos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/423281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uEy8VdTqtfnLGvgCkooow7btLf.jpg'),
(100184, 7118, 'Quantum Leap: Contratempos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/423282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uEy8VdTqtfnLGvgCkooow7btLf.jpg'),
(100185, 7118, 'Quantum Leap: Contratempos S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/423283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uEy8VdTqtfnLGvgCkooow7btLf.jpg'),
(100186, 7118, 'Quantum Leap: Contratempos S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/423284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uEy8VdTqtfnLGvgCkooow7btLf.jpg'),
(100187, 7118, 'Quantum Leap: Contratempos S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/423285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uEy8VdTqtfnLGvgCkooow7btLf.jpg'),
(100188, 7119, 'Robô Sapiens S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e3zzxoeqnOeSqV44C83ozB8bjAR.jpg'),
(100189, 7119, 'Robô Sapiens S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e3zzxoeqnOeSqV44C83ozB8bjAR.jpg'),
(100190, 7119, 'Robô Sapiens S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e3zzxoeqnOeSqV44C83ozB8bjAR.jpg'),
(100191, 7119, 'Robô Sapiens S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e3zzxoeqnOeSqV44C83ozB8bjAR.jpg'),
(100192, 7119, 'Robô Sapiens S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e3zzxoeqnOeSqV44C83ozB8bjAR.jpg'),
(100193, 7119, 'Robô Sapiens S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e3zzxoeqnOeSqV44C83ozB8bjAR.jpg'),
(100194, 7119, 'Robô Sapiens S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e3zzxoeqnOeSqV44C83ozB8bjAR.jpg'),
(100195, 7120, 'Three Pines S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kUZDYOEtv6O2Hg4ObQJi0WwkblE.jpg'),
(100196, 7120, 'Three Pines S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8uABlge3Bwl7FNnYsgIvGWv8AtF.jpg'),
(100197, 7120, 'Three Pines S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4kGY5t6GclShDrFP1SgIj0cflYV.jpg'),
(100198, 7120, 'Three Pines S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AuHnHJr5gSfADc61AxphuHA3OHJ.jpg'),
(100199, 7120, 'Three Pines S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/R3ldSFqS3nAMlviv7iQzJ2E1h5.jpg'),
(100200, 7120, 'Three Pines S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5OraelgNFyWnwpR2ETi8wNV0YyA.jpg'),
(100201, 7120, 'Three Pines S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4U4vAl1huBKdxiDOOP30h0Jvti.jpg'),
(100202, 7120, 'Three Pines S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qfGaTtbHTyzvtPOijwgo5Y7Cddn.jpg'),
(100203, 7121, 'Ursinhos em Curso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aMHx7FahXQ1yQHIk5YR3hLq6htl.jpg'),
(100204, 7121, 'Ursinhos em Curso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqsv95zjehPEBIZPpyQuL4apo3r.jpg'),
(100205, 7121, 'Ursinhos em Curso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2NLDqKvJKWlwfmNoiLflzOxUYNL.jpg'),
(100206, 7121, 'Ursinhos em Curso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lG49PemmJ6tLeE5YKT93F8baTG.jpg'),
(100207, 7121, 'Ursinhos em Curso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hG6PUK1Vk0ZPsDeqYErZWB9Zx7L.jpg'),
(100208, 7121, 'Ursinhos em Curso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/abobcVGXKewB4Iw8cUnf4gUe2L8.jpg'),
(100209, 7121, 'Ursinhos em Curso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xlic0HX8e0QsgpKLaLgQD5O2Kf9.jpg'),
(100210, 7121, 'Ursinhos em Curso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qyn8Vfn2nJ1d6fE8IwKaIg4gkUg.jpg'),
(100211, 7121, 'Ursinhos em Curso S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xm7qt9iAu83RLZ98BR2UWBYCDdA.jpg'),
(100212, 7121, 'Ursinhos em Curso S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zG49eYJd1pUVNHEoWu4oCmVrGwt.jpg'),
(100213, 7121, 'Ursinhos em Curso S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8TzLv9vRcBtbJthjO7CoKs0kfBd.jpg'),
(100214, 7121, 'Ursinhos em Curso S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2u8cM4uPrepOP3jnKsOUXUwC2SE.jpg'),
(100215, 7121, 'Ursinhos em Curso S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1C2wmdD33DNOkdfZ9aPlomt83Gn.jpg'),
(100216, 7121, 'Ursinhos em Curso S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aqotg50tPERx0RRGWrf2dVRfzTj.jpg'),
(100217, 7121, 'Ursinhos em Curso S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iGpfdnjIAeNDszKwhPsBjYXw0o1.jpg'),
(100218, 7121, 'Ursinhos em Curso S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzhJIDTOCkhppJ3yGU60zkZQR8M.jpg'),
(100219, 7121, 'Ursinhos em Curso S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/206848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rFr0KUWS4OaERW4RGEJ2QtmbB0A.jpg'),
(100220, 7121, 'Ursinhos em Curso S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/206849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pCE0grCyEElOKtHurUV4kvxI511.jpg'),
(100221, 7121, 'Ursinhos em Curso S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/206850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/neWyW2wmIYcGmwWUsCf7FEBOEpz.jpg'),
(100222, 7121, 'Ursinhos em Curso S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/206851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y1gJrOQeMS126w7XhczbofxydOD.jpg'),
(100223, 7121, 'Ursinhos em Curso S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/206852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fiuAaYI5zZ06fTUdBF0oBqgrrwi.jpg'),
(100224, 7121, 'Ursinhos em Curso S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/206853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aupoitU5osFupo46FFPQ8j4enPO.jpg'),
(100225, 7121, 'Ursinhos em Curso S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/206854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5cyQo3WVw2Uqr455PGPYWWm5Cbq.jpg'),
(100226, 7121, 'Ursinhos em Curso S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/206855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9kPZNiwgDORh5hA0TCZKbAbFFCZ.jpg'),
(100227, 7121, 'Ursinhos em Curso S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/206856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hiFebRkSjJ2h3g1F3WzHweM9QWJ.jpg'),
(100228, 7121, 'Ursinhos em Curso S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/206857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7EvdFe6x78VH6fLGv2w45n0xZL.jpg'),
(100229, 7121, 'Ursinhos em Curso S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/206858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uSwvuuCRWM7AYvHtZCbSrmTJmD9.jpg'),
(100230, 7121, 'Ursinhos em Curso S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/206859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pePAQg9PhYthlhXnSlq2GthqB3u.jpg'),
(100231, 7121, 'Ursinhos em Curso S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/206860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e2cB28UlHswfNTfAnYGaRJQYflO.jpg'),
(100232, 7121, 'Ursinhos em Curso S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/206861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ltej9DP0zGOzEeERsdokSr6R54F.jpg'),
(100233, 7121, 'Ursinhos em Curso S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/206862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/euPMhmUAP5ovyKOvWwCTICAUn57.jpg'),
(100234, 7121, 'Ursinhos em Curso S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/206863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7B60b2M9r9ds2ILnRS32P6gmBNm.jpg'),
(100235, 7121, 'Ursinhos em Curso S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/206864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2Xasys5AQf0uiIVWOg29RJuuQB.jpg'),
(100236, 7121, 'Ursinhos em Curso S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/206865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jDC0WgI4wsr5pNoRs3Tnx1hanqH.jpg'),
(100237, 7121, 'Ursinhos em Curso S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/206866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5DyhT6n4HS6Z1aaMGmTdXsbaevr.jpg'),
(100238, 7121, 'Ursinhos em Curso S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/206867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dqHIDimgHRqxJZLoyrxsAFwgxRq.jpg'),
(100239, 7121, 'Ursinhos em Curso S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/206868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yqdUTL8qBO2oqRHldMixQAzxU8H.jpg'),
(100240, 7121, 'Ursinhos em Curso S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/206869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1lfsnpdxTOeJGgVesqJBVt7zzR.jpg'),
(100241, 7122, 'Will Trent: Agente Especial S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v2fvaiSeVejCtciYjaCldwBZ4bq.jpg'),
(100242, 7122, 'Will Trent: Agente Especial S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219175.mp4', 'http://image.tmdb.org/t/p/w1280/5iczZOCmBmwphl6rTzWKKBB5Exz.jpg'),
(100243, 7122, 'Will Trent: Agente Especial S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219176.mp4', 'http://image.tmdb.org/t/p/w1280/bkRXlWIBhUk5IDBt9LjCqsuI5YY.jpg'),
(100244, 7122, 'Will Trent: Agente Especial S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4orG6eEy9HUs7p729XTClOUfWat.jpg'),
(100245, 7122, 'Will Trent: Agente Especial S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6100vg8A7PmG3GF0liK3aIsMkHf.jpg'),
(100246, 7122, 'Will Trent: Agente Especial S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jpJcJ3GpUhVpoFRK1BiSoOCgcZA.jpg'),
(100247, 7122, 'Will Trent: Agente Especial S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219180.mp4', 'http://image.tmdb.org/t/p/w1280/r9fwQZ8CYdT49dGT8bSJFTodqqH.jpg'),
(100248, 7122, 'Will Trent: Agente Especial S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219181.mp4', 'http://image.tmdb.org/t/p/w1280/5rvrMTvadtMCmyEPQXg8OL8owIy.jpg'),
(100249, 7122, 'Will Trent: Agente Especial S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219182.mp4', 'http://image.tmdb.org/t/p/w1280/fqsShUnwLHHgdcWgXbfPpmUVq7l.jpg'),
(100250, 7122, 'Will Trent: Agente Especial S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219183.mp4', 'http://image.tmdb.org/t/p/w1280/7QCdOVlyfoP7nsUYeur0SianswI.jpg'),
(100251, 7122, 'Will Trent: Agente Especial S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219184.mp4', 'http://image.tmdb.org/t/p/w1280/uFyoijHofEAKxOHhVmP6bQ5FWdu.jpg'),
(100252, 7122, 'Will Trent: Agente Especial S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219185.mp4', 'http://image.tmdb.org/t/p/w1280/c0tCSvo2HGylV8nO6QI1nYRvyFM.jpg'),
(100253, 7122, 'Will Trent: Agente Especial S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219186.mp4', 'http://image.tmdb.org/t/p/w1280/ytFKmZT5xRItelMns3bYMqfEwPv.jpg'),
(100254, 7123, 'Will Trent: Agente Especial S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/609040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100255, 7123, 'Will Trent: Agente Especial S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/609041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100256, 7123, 'Will Trent: Agente Especial S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/609042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100257, 7123, 'Will Trent: Agente Especial S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/609043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100258, 7123, 'Will Trent: Agente Especial S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/609044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100259, 7123, 'Will Trent: Agente Especial S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/609045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100260, 7123, 'Will Trent: Agente Especial S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/372694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100261, 7123, 'Will Trent: Agente Especial S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/372695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100262, 7123, 'Will Trent: Agente Especial S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/383783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100263, 7123, 'Will Trent: Agente Especial S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/393903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100264, 7124, 'Will Trent: Agente Especial S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/708192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100265, 7124, 'Will Trent: Agente Especial S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/708193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100266, 7124, 'Will Trent: Agente Especial S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/708194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100267, 7124, 'Will Trent: Agente Especial S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/708195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100268, 7124, 'Will Trent: Agente Especial S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/708196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100269, 7124, 'Will Trent: Agente Especial S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/708197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100270, 7124, 'Will Trent: Agente Especial S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/728292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100271, 7124, 'Will Trent: Agente Especial S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/752394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100272, 7124, 'Will Trent: Agente Especial S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/763016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100273, 7124, 'Will Trent: Agente Especial S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/777129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100274, 7124, 'Will Trent: Agente Especial S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/778353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100275, 7124, 'Will Trent: Agente Especial S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/795626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100276, 7124, 'Will Trent: Agente Especial S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/795627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100277, 7124, 'Will Trent: Agente Especial S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/820156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100278, 7124, 'Will Trent: Agente Especial S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/834740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100279, 7124, 'Will Trent: Agente Especial S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/849633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100280, 7124, 'Will Trent: Agente Especial S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/849634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100281, 7124, 'Will Trent: Agente Especial S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/849635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(100282, 7125, 'Brincando com Fogo: Alemanha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mG8kNvNX3bgAp1FUwpA3vx2ctK7.jpg'),
(100283, 7125, 'Brincando com Fogo: Alemanha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6eUi8atxs3fmNQAQVJirhLe0oN5.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(100284, 7125, 'Brincando com Fogo: Alemanha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vZtp0QcPwiPHGnNsFzEWIqWJ7kl.jpg'),
(100285, 7125, 'Brincando com Fogo: Alemanha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ww7G9a3vKa4ryS3xOXxta7gns09.jpg'),
(100286, 7125, 'Brincando com Fogo: Alemanha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2dsEIZ2gu2IHyVUSxizxJwrwepk.jpg'),
(100287, 7125, 'Brincando com Fogo: Alemanha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Axz1Ww1KxnzUhbZW6A74b1Qobf.jpg'),
(100288, 7125, 'Brincando com Fogo: Alemanha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fJoby9KIlSnYPduUEVPGBqCQsqO.jpg'),
(100289, 7125, 'Brincando com Fogo: Alemanha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jQ0XNh4rYbyTdPHndEo5a7YeYG9.jpg'),
(100290, 7125, 'Brincando com Fogo: Alemanha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sUJKUKQjVH1MW7NpHnFPc71kBV4.jpg'),
(100291, 7125, 'Brincando com Fogo: Alemanha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uhfqvcbDfgx9jQ5cIn19U1w1JHl.jpg'),
(100292, 7126, 'Brincando com Fogo: Alemanha S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/702138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5R1TUuMrf8AConXBbWac9SuYghO.jpg'),
(100293, 7126, 'Brincando com Fogo: Alemanha S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/702139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5R1TUuMrf8AConXBbWac9SuYghO.jpg'),
(100294, 7126, 'Brincando com Fogo: Alemanha S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/702140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5R1TUuMrf8AConXBbWac9SuYghO.jpg'),
(100295, 7126, 'Brincando com Fogo: Alemanha S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/702141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5R1TUuMrf8AConXBbWac9SuYghO.jpg'),
(100296, 7126, 'Brincando com Fogo: Alemanha S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/702142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5R1TUuMrf8AConXBbWac9SuYghO.jpg'),
(100297, 7126, 'Brincando com Fogo: Alemanha S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/702143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5R1TUuMrf8AConXBbWac9SuYghO.jpg'),
(100298, 7126, 'Brincando com Fogo: Alemanha S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/702144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5R1TUuMrf8AConXBbWac9SuYghO.jpg'),
(100299, 7126, 'Brincando com Fogo: Alemanha S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/702145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5R1TUuMrf8AConXBbWac9SuYghO.jpg'),
(100300, 7127, 'Break Point S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rj4VIrI8pABKtnUCZmpNMsIaKvk.jpg'),
(100301, 7127, 'Break Point S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ljKkMbT2KOtpopjE3kLLGrf4C0Y.jpg'),
(100302, 7127, 'Break Point S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ezKon4EvZOuZYYg4EsbmI2KzOTt.jpg'),
(100303, 7127, 'Break Point S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eF6cfCwsJTygC3lSXFRGnVLKRZ8.jpg'),
(100304, 7127, 'Break Point S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vKgHw7fScMJ3OqB0vc0qnGWedd.jpg'),
(100305, 7128, 'Break Point S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3QNnzim79NqtIjzBKQRIQqY9YJ0.jpg'),
(100306, 7128, 'Break Point S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3QNnzim79NqtIjzBKQRIQqY9YJ0.jpg'),
(100307, 7128, 'Break Point S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3QNnzim79NqtIjzBKQRIQqY9YJ0.jpg'),
(100308, 7128, 'Break Point S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3QNnzim79NqtIjzBKQRIQqY9YJ0.jpg'),
(100309, 7128, 'Break Point S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3QNnzim79NqtIjzBKQRIQqY9YJ0.jpg'),
(100310, 7128, 'Break Point S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3QNnzim79NqtIjzBKQRIQqY9YJ0.jpg'),
(100311, 7129, 'Carnaval da Sabrina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100312, 7129, 'Carnaval da Sabrina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100313, 7129, 'Carnaval da Sabrina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100314, 7129, 'Carnaval da Sabrina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100315, 7130, 'Carnaval da Sabrina S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100316, 7130, 'Carnaval da Sabrina S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100317, 7130, 'Carnaval da Sabrina S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100318, 7130, 'Carnaval da Sabrina S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100319, 7130, 'Carnaval da Sabrina S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100320, 7130, 'Carnaval da Sabrina S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100321, 7131, 'Carnaval da Sabrina S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100322, 7131, 'Carnaval da Sabrina S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100323, 7131, 'Carnaval da Sabrina S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100324, 7131, 'Carnaval da Sabrina S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/271658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100325, 7131, 'Carnaval da Sabrina S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/276748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100326, 7131, 'Carnaval da Sabrina S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/279112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100327, 7132, 'Carnaval da Sabrina S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/731573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100328, 7132, 'Carnaval da Sabrina S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/731574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100329, 7132, 'Carnaval da Sabrina S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/731575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100330, 7132, 'Carnaval da Sabrina S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/731576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100331, 7132, 'Carnaval da Sabrina S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/731577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100332, 7132, 'Carnaval da Sabrina S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/731578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4r7XvKWo3nmjqYMt1a6Ztx9CBUC.jpg'),
(100333, 7133, 'Chef Alex Contra Todos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2EmPoQvgct7dFuHl8dLSEyFfq5V.jpg'),
(100334, 7133, 'Chef Alex Contra Todos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2EmPoQvgct7dFuHl8dLSEyFfq5V.jpg'),
(100335, 7133, 'Chef Alex Contra Todos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2EmPoQvgct7dFuHl8dLSEyFfq5V.jpg'),
(100336, 7133, 'Chef Alex Contra Todos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2EmPoQvgct7dFuHl8dLSEyFfq5V.jpg'),
(100337, 7133, 'Chef Alex Contra Todos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2EmPoQvgct7dFuHl8dLSEyFfq5V.jpg'),
(100338, 7134, 'Chef Alex Contra Todos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2EmPoQvgct7dFuHl8dLSEyFfq5V.jpg'),
(100339, 7134, 'Chef Alex Contra Todos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2EmPoQvgct7dFuHl8dLSEyFfq5V.jpg'),
(100340, 7134, 'Chef Alex Contra Todos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2EmPoQvgct7dFuHl8dLSEyFfq5V.jpg'),
(100341, 7134, 'Chef Alex Contra Todos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2EmPoQvgct7dFuHl8dLSEyFfq5V.jpg'),
(100342, 7134, 'Chef Alex Contra Todos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2EmPoQvgct7dFuHl8dLSEyFfq5V.jpg'),
(100343, 7134, 'Chef Alex Contra Todos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2EmPoQvgct7dFuHl8dLSEyFfq5V.jpg'),
(100344, 7134, 'Chef Alex Contra Todos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2EmPoQvgct7dFuHl8dLSEyFfq5V.jpg'),
(100345, 7134, 'Chef Alex Contra Todos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2EmPoQvgct7dFuHl8dLSEyFfq5V.jpg'),
(100346, 7135, 'Daisy Jones & The Six S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2oaW0hL7xjbVD32gk09j2a0SOl1.jpg'),
(100347, 7135, 'Daisy Jones & The Six S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9A6GzLCEftKRqhOYWAqQB7zhDVu.jpg'),
(100348, 7135, 'Daisy Jones & The Six S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tDAyNK5gQu91DrTw39ZKG2MHxzA.jpg'),
(100349, 7135, 'Daisy Jones & The Six S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208909.mp4', 'http://image.tmdb.org/t/p/w1280/nVDQXAT7yZl5pRISd5BGA6xy4wk.jpg'),
(100350, 7135, 'Daisy Jones & The Six S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208910.mp4', 'http://image.tmdb.org/t/p/w1280/tALvYIo7wiryaPhhZ1rp3ykm4up.jpg'),
(100351, 7135, 'Daisy Jones & The Six S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208911.mp4', 'http://image.tmdb.org/t/p/w1280/7M9saOhtIapvAySbo3QVURpT6qx.jpg'),
(100352, 7135, 'Daisy Jones & The Six S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208912.mp4', 'http://image.tmdb.org/t/p/w1280/pbGhtsNFMiQ77emRGJIJdbYEci9.jpg'),
(100353, 7135, 'Daisy Jones & The Six S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208913.mp4', 'http://image.tmdb.org/t/p/w1280/crXGFibGnKiKWCPbvJpRsFNOJ3g.jpg'),
(100354, 7135, 'Daisy Jones & The Six S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208914.mp4', 'http://image.tmdb.org/t/p/w1280/4kIbmrLPVcbseaHH0vmSPqg0KbY.jpg'),
(100355, 7135, 'Daisy Jones & The Six S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208915.mp4', 'http://image.tmdb.org/t/p/w1280/5vW43JgWjegLtPNn6N7oMgUXf0M.jpg'),
(100356, 7136, 'Em Nome da Fé: Uma Traição Sagrada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7RD226RxOPEZGdOOgRpuMk56TBe.jpg'),
(100357, 7136, 'Em Nome da Fé: Uma Traição Sagrada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/opH5bZLyfs8bIvZAiC5Bt1MN9Fs.jpg'),
(100358, 7136, 'Em Nome da Fé: Uma Traição Sagrada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Xyk9aaPzgBrmK2F7Hza1eqEeeQ.jpg'),
(100359, 7136, 'Em Nome da Fé: Uma Traição Sagrada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5SGmvmqngUpFqEoH0OGRzIDPdUg.jpg'),
(100360, 7136, 'Em Nome da Fé: Uma Traição Sagrada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wqmmseGDf3xrf85VRnef6alXL5L.jpg'),
(100361, 7136, 'Em Nome da Fé: Uma Traição Sagrada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0F61oZRZnICpsR4jYMNf2epsVB.jpg'),
(100362, 7136, 'Em Nome da Fé: Uma Traição Sagrada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iZ7T2r11OWENrFrSNz8jQkRMC5v.jpg'),
(100363, 7136, 'Em Nome da Fé: Uma Traição Sagrada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rhuxpmPe2MxYv7qaJbBlGG0ONlO.jpg'),
(100364, 7137, 'Histórias de Superação S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gx8uJHoaZNLpB7VT0KLWMHTdNRp.jpg'),
(100365, 7137, 'Histórias de Superação S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gx8uJHoaZNLpB7VT0KLWMHTdNRp.jpg'),
(100366, 7137, 'Histórias de Superação S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gx8uJHoaZNLpB7VT0KLWMHTdNRp.jpg'),
(100367, 7137, 'Histórias de Superação S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gx8uJHoaZNLpB7VT0KLWMHTdNRp.jpg'),
(100368, 7137, 'Histórias de Superação S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gx8uJHoaZNLpB7VT0KLWMHTdNRp.jpg'),
(100369, 7137, 'Histórias de Superação S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gx8uJHoaZNLpB7VT0KLWMHTdNRp.jpg'),
(100370, 7138, 'Nacho S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211837.mp4', 'http://image.tmdb.org/t/p/w1280/hJNUNQtKvi8qr08xnxwzC3ItsF9.jpg'),
(100371, 7138, 'Nacho S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211838.mp4', 'http://image.tmdb.org/t/p/w1280/qu1YZtu7nfPqufJabjR6UdfZOmM.jpg'),
(100372, 7138, 'Nacho S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211839.mp4', 'http://image.tmdb.org/t/p/w1280/e3x73ZwLVARuJbrXFTDWKLiShg.jpg'),
(100373, 7138, 'Nacho S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211840.mp4', 'http://image.tmdb.org/t/p/w1280/h4fl9pbFMtWm9hOCwvtDjhcr6JD.jpg'),
(100374, 7138, 'Nacho S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211841.mp4', 'http://image.tmdb.org/t/p/w1280/5ZAbF7FGb2sTJfuLICsh7MiQMsp.jpg'),
(100375, 7138, 'Nacho S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211842.mp4', 'http://image.tmdb.org/t/p/w1280/k9quOggR9geTwLQwn0e3vhFUHKl.jpg'),
(100376, 7138, 'Nacho S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211843.mp4', 'http://image.tmdb.org/t/p/w1280/qYKkiB7in0ct2frIdoqH0jPxwMc.jpg'),
(100377, 7138, 'Nacho S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211844.mp4', 'http://image.tmdb.org/t/p/w1280/9czN87TMLpJvlCGKelj03Mfa6uB.jpg'),
(100378, 7139, 'Será Isso Amor? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/waj8Yxbq0mStUGDH6hiOIQ1XQsu.jpg'),
(100379, 7139, 'Será Isso Amor? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A5gUCUJwUUTPO84vxbutH27Eg2n.jpg'),
(100380, 7139, 'Será Isso Amor? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vYVi4tQolfGPeyTzoIhUxzNTaG6.jpg'),
(100381, 7139, 'Será Isso Amor? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZAaWUpRBxOXWJmCVYzTAihYxBt.jpg'),
(100382, 7139, 'Será Isso Amor? S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3GvXyxlikWWRzDtGnTLGB3pKZam.jpg'),
(100383, 7139, 'Será Isso Amor? S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k7GSAJGMZDlY7v1NDYabi3zyYon.jpg'),
(100384, 7139, 'Será Isso Amor? S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vPrpPsqNklHk5yvcejdeuGqvwVq.jpg'),
(100385, 7139, 'Será Isso Amor? S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ejeweUdFws6P9WEx568w3tdYqtt.jpg'),
(100386, 7139, 'Será Isso Amor? S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kHDgb07zVH2xOqvFj1f38EmSjb5.jpg'),
(100387, 7139, 'Será Isso Amor? S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sCBSrnHAz2eHIU6wh3J31RRjgXk.jpg'),
(100388, 7139, 'Será Isso Amor? S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w4Gi4iM3MEGhiKUHP1HYclExJRk.jpg'),
(100389, 7139, 'Será Isso Amor? S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ffcWFwe2OwES1hZzWgZq5oyf1YG.jpg'),
(100390, 7139, 'Será Isso Amor? S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b2bYzcoPiYVUxbT33dDlNcPthKz.jpg'),
(100391, 7139, 'Será Isso Amor? S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Xx8ixoIzCTgjfjqEZ4Hc3ttHH3.jpg'),
(100392, 7139, 'Será Isso Amor? S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mYTnsXh4mXhWKRMLmT27jeuofX0.jpg'),
(100393, 7139, 'Será Isso Amor? S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1L4rahPYwolK0bAvFZvIGZZuWA4.jpg'),
(100394, 7139, 'Será Isso Amor? S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/206620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/anF0FFDtI9MGfGNNvqYtHRHCjQQ.jpg'),
(100395, 7139, 'Será Isso Amor? S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/206621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUc2PEzeWnkx8negPc6WDKLG8SJ.jpg'),
(100396, 7139, 'Será Isso Amor? S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/206622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pftcLx8x2InNC53XfuZMF1fWHhx.jpg'),
(100397, 7139, 'Será Isso Amor? S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/206623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/78WUa8WuX8h1fNcPniSr0at3i8O.jpg'),
(100398, 7139, 'Será Isso Amor? S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/206624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3mUcoQprw3sMYljgNj38lSB8Ht1.jpg'),
(100399, 7139, 'Será Isso Amor? S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/206625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dzuZYWSeQ4H2B80HiS7eIx4zE11.jpg'),
(100400, 7139, 'Será Isso Amor? S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/206626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oE5LsN8KayyUTKQqwkbL1wMdAZM.jpg'),
(100401, 7139, 'Será Isso Amor? S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/206627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ao26QEhEn9OrKFNi4oh68vLtwKV.jpg'),
(100402, 7139, 'Será Isso Amor? S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/206628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fZYENWXF9k5sW3W18HDYiWY0Jye.jpg'),
(100403, 7139, 'Será Isso Amor? S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/206629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mlZsBxues0oUn1abOgHDJuZ1WPO.jpg'),
(100404, 7139, 'Será Isso Amor? S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/206630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bMkQ8fypFuUdBlT1XmbuVomaZ59.jpg'),
(100405, 7139, 'Será Isso Amor? S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/206631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8PVT56VPkpXWyHXF4Di0CnzDRrp.jpg'),
(100406, 7139, 'Será Isso Amor? S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/206632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e9Q4AMvGBq4s1Xm0m4hVX6E7TxF.jpg'),
(100407, 7139, 'Será Isso Amor? S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/206633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhed6hrhyxt8L2bV39JauMHM7f7.jpg'),
(100408, 7139, 'Será Isso Amor? S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/206634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dvDP7L9joudU9uydgyO4jF43695.jpg'),
(100409, 7139, 'Será Isso Amor? S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/206635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vU2LjlLAn9csdPXtV7myRGOy8Mi.jpg'),
(100410, 7139, 'Será Isso Amor? S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/206636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2fO4nOOxORHbobTCMcmzEz5QsXK.jpg'),
(100411, 7139, 'Será Isso Amor? S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/206637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ixjFan2jrL6PGvrkiT2ZXWfeQny.jpg'),
(100412, 7139, 'Será Isso Amor? S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/206638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eVm0CesFr7y8Hpq4Bls6bYmPE4W.jpg'),
(100413, 7139, 'Será Isso Amor? S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/206639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wpTfysRaWpkncOeDQsKTm7eDsg1.jpg'),
(100414, 7139, 'Será Isso Amor? S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/206640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j5WIyfp7pKzaO9waYJziARlnSIk.jpg'),
(100415, 7139, 'Será Isso Amor? S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/206641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bIVptDnqKHwHAWqmkpK2OAvOKXO.jpg'),
(100416, 7139, 'Será Isso Amor? S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/206642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nk5RRaVE0WLZunqrdaCdDJ6vk63.jpg'),
(100417, 7139, 'Será Isso Amor? S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/206643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100418, 7139, 'Será Isso Amor? S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/206644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100419, 7139, 'Será Isso Amor? S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/206645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100420, 7139, 'Será Isso Amor? S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/206646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100421, 7139, 'Será Isso Amor? S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/206647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100422, 7139, 'Será Isso Amor? S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/206648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100423, 7139, 'Será Isso Amor? S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/206649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100424, 7139, 'Será Isso Amor? S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/206650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100425, 7139, 'Será Isso Amor? S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/206651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100426, 7139, 'Será Isso Amor? S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/206652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100427, 7139, 'Será Isso Amor? S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/206653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100428, 7139, 'Será Isso Amor? S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/206654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100429, 7139, 'Será Isso Amor? S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/206655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100430, 7139, 'Será Isso Amor? S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/206656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100431, 7139, 'Será Isso Amor? S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/206657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100432, 7139, 'Será Isso Amor? S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/206658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100433, 7139, 'Será Isso Amor? S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/206659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100434, 7139, 'Será Isso Amor? S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/206660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100435, 7139, 'Será Isso Amor? S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/206661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100436, 7139, 'Será Isso Amor? S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/206662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100437, 7139, 'Será Isso Amor? S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/206663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100438, 7139, 'Será Isso Amor? S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/206664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100439, 7139, 'Será Isso Amor? S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/206665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100440, 7139, 'Será Isso Amor? S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/206666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100441, 7139, 'Será Isso Amor? S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/206667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100442, 7139, 'Será Isso Amor? S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/206668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100443, 7139, 'Será Isso Amor? S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/206669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100444, 7139, 'Será Isso Amor? S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/206670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100445, 7139, 'Será Isso Amor? S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/206671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100446, 7139, 'Será Isso Amor? S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/206672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100447, 7139, 'Será Isso Amor? S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/206673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100448, 7139, 'Será Isso Amor? S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/206674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100449, 7139, 'Será Isso Amor? S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/206675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100450, 7139, 'Será Isso Amor? S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/206676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100451, 7139, 'Será Isso Amor? S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/206677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100452, 7139, 'Será Isso Amor? S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/206678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100453, 7139, 'Será Isso Amor? S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/206679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100454, 7139, 'Será Isso Amor? S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/206680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100455, 7139, 'Será Isso Amor? S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/206681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100456, 7139, 'Será Isso Amor? S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/206682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100457, 7139, 'Será Isso Amor? S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/206683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100458, 7139, 'Será Isso Amor? S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/206684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100459, 7139, 'Será Isso Amor? S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/206685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100460, 7139, 'Será Isso Amor? S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/206686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100461, 7139, 'Será Isso Amor? S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/206687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100462, 7139, 'Será Isso Amor? S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/206688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100463, 7139, 'Será Isso Amor? S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/206689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100464, 7139, 'Será Isso Amor? S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/206690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100465, 7139, 'Será Isso Amor? S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/206691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100466, 7139, 'Será Isso Amor? S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/206692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100467, 7139, 'Será Isso Amor? S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/206693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100468, 7139, 'Será Isso Amor? S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/206694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100469, 7139, 'Será Isso Amor? S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/206695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100470, 7139, 'Será Isso Amor? S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/206696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100471, 7139, 'Será Isso Amor? S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/206697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100472, 7139, 'Será Isso Amor? S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/206698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100473, 7139, 'Será Isso Amor? S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/206699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100474, 7139, 'Será Isso Amor? S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/206700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100475, 7139, 'Será Isso Amor? S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/206701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100476, 7139, 'Será Isso Amor? S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/206702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100477, 7139, 'Será Isso Amor? S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/206703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100478, 7139, 'Será Isso Amor? S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/206704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100479, 7139, 'Será Isso Amor? S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/206705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100480, 7139, 'Será Isso Amor? S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/206706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100481, 7139, 'Será Isso Amor? S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/206707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100482, 7139, 'Será Isso Amor? S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/206708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100483, 7139, 'Será Isso Amor? S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/206709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100484, 7139, 'Será Isso Amor? S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/206710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100485, 7139, 'Será Isso Amor? S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/206711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100486, 7139, 'Será Isso Amor? S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/206712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100487, 7139, 'Será Isso Amor? S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/206713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100488, 7139, 'Será Isso Amor? S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/206714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100489, 7139, 'Será Isso Amor? S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/206715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100490, 7139, 'Será Isso Amor? S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/206716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100491, 7139, 'Será Isso Amor? S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/206717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100492, 7139, 'Será Isso Amor? S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/206718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100493, 7139, 'Será Isso Amor? S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/206719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100494, 7139, 'Será Isso Amor? S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/206720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100495, 7139, 'Será Isso Amor? S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/206721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100496, 7139, 'Será Isso Amor? S01 E119', 'http://sinalprivado.info:80/series/1533784/1533784/206722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100497, 7139, 'Será Isso Amor? S01 E120', 'http://sinalprivado.info:80/series/1533784/1533784/206723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100498, 7139, 'Será Isso Amor? S01 E121', 'http://sinalprivado.info:80/series/1533784/1533784/206724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100499, 7140, 'Será Isso Amor? S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aJMTDkPIc3tFnSBNvms4BoBimtI.jpg'),
(100500, 7140, 'Será Isso Amor? S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8N5nRbyvI1k6Wgj3gRai8wEsiY1.jpg'),
(100501, 7140, 'Será Isso Amor? S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uDeYC4lTsMcS1JsyEoOQ0YXRFb8.jpg'),
(100502, 7140, 'Será Isso Amor? S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4mH2Dq59ZWSNYfZGR9pfeMobI3y.jpg'),
(100503, 7140, 'Será Isso Amor? S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fZQG286HAWkhCWbkzkv2kcWMvul.jpg'),
(100504, 7140, 'Será Isso Amor? S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6fnKwjhK2Miqs72zRjyOpTykRED.jpg'),
(100505, 7140, 'Será Isso Amor? S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2yi7UY7NwBQOkQDHJHMTQ0guwFb.jpg'),
(100506, 7140, 'Será Isso Amor? S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cTZjJqNzYW18HfdvJm6MvXnJy8H.jpg'),
(100507, 7140, 'Será Isso Amor? S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qCxXxtHgraEPM8kOJnOuW2bEjbE.jpg'),
(100508, 7140, 'Será Isso Amor? S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3GWwTl9rCP93wpeC7gCM2L2mWA2.jpg'),
(100509, 7140, 'Será Isso Amor? S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zI9cDrCUIpIgxAi20xuW0ChBKtA.jpg'),
(100510, 7140, 'Será Isso Amor? S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i71XoZbfi8V2QwxITTKMkasQFFW.jpg'),
(100511, 7140, 'Será Isso Amor? S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4nDJrZSileOHG2uVKynRnnUHBLi.jpg'),
(100512, 7140, 'Será Isso Amor? S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100513, 7140, 'Será Isso Amor? S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100514, 7140, 'Será Isso Amor? S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100515, 7140, 'Será Isso Amor? S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/206741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100516, 7140, 'Será Isso Amor? S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/206742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100517, 7140, 'Será Isso Amor? S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/206743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100518, 7140, 'Será Isso Amor? S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/206744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100519, 7140, 'Será Isso Amor? S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/206745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100520, 7140, 'Será Isso Amor? S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/206746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100521, 7140, 'Será Isso Amor? S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/206747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100522, 7140, 'Será Isso Amor? S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/206748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100523, 7140, 'Será Isso Amor? S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/206749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100524, 7140, 'Será Isso Amor? S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/206750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100525, 7140, 'Será Isso Amor? S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/206751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100526, 7140, 'Será Isso Amor? S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/206752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100527, 7140, 'Será Isso Amor? S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/206753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100528, 7140, 'Será Isso Amor? S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/206754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100529, 7140, 'Será Isso Amor? S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/206755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100530, 7140, 'Será Isso Amor? S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/206756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100531, 7140, 'Será Isso Amor? S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/206757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100532, 7140, 'Será Isso Amor? S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/206758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100533, 7140, 'Será Isso Amor? S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/206759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100534, 7140, 'Será Isso Amor? S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/206760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100535, 7140, 'Será Isso Amor? S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/206761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100536, 7140, 'Será Isso Amor? S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/206762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100537, 7140, 'Será Isso Amor? S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/206763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100538, 7140, 'Será Isso Amor? S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/206764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cccW8YiPphlbcbOzj84imtDSPZN.jpg'),
(100539, 7141, 'Xou da Xuxa - Edição Especial S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUpo5M4u3kupyQCqBMFVGDtlZ09.jpg'),
(100540, 7141, 'Xou da Xuxa - Edição Especial S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUpo5M4u3kupyQCqBMFVGDtlZ09.jpg'),
(100541, 7141, 'Xou da Xuxa - Edição Especial S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUpo5M4u3kupyQCqBMFVGDtlZ09.jpg'),
(100542, 7141, 'Xou da Xuxa - Edição Especial S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUpo5M4u3kupyQCqBMFVGDtlZ09.jpg'),
(100543, 7141, 'Xou da Xuxa - Edição Especial S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUpo5M4u3kupyQCqBMFVGDtlZ09.jpg'),
(100544, 7141, 'Xou da Xuxa - Edição Especial S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUpo5M4u3kupyQCqBMFVGDtlZ09.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(100545, 7141, 'Xou da Xuxa - Edição Especial S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUpo5M4u3kupyQCqBMFVGDtlZ09.jpg'),
(100546, 7141, 'Xou da Xuxa - Edição Especial S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUpo5M4u3kupyQCqBMFVGDtlZ09.jpg'),
(100547, 7141, 'Xou da Xuxa - Edição Especial S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUpo5M4u3kupyQCqBMFVGDtlZ09.jpg'),
(100548, 7141, 'Xou da Xuxa - Edição Especial S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUpo5M4u3kupyQCqBMFVGDtlZ09.jpg'),
(100549, 7141, 'Xou da Xuxa - Edição Especial S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUpo5M4u3kupyQCqBMFVGDtlZ09.jpg'),
(100550, 7141, 'Xou da Xuxa - Edição Especial S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUpo5M4u3kupyQCqBMFVGDtlZ09.jpg'),
(100551, 7141, 'Xou da Xuxa - Edição Especial S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUpo5M4u3kupyQCqBMFVGDtlZ09.jpg'),
(100552, 7141, 'Xou da Xuxa - Edição Especial S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/219954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUpo5M4u3kupyQCqBMFVGDtlZ09.jpg'),
(100553, 7141, 'Xou da Xuxa - Edição Especial S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/219955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUpo5M4u3kupyQCqBMFVGDtlZ09.jpg'),
(100554, 7141, 'Xou da Xuxa - Edição Especial S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/219956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUpo5M4u3kupyQCqBMFVGDtlZ09.jpg'),
(100555, 7141, 'Xou da Xuxa - Edição Especial S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/219957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUpo5M4u3kupyQCqBMFVGDtlZ09.jpg'),
(100556, 7142, 'A História do Mundo: Parte 2 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fsiW9LgKcnT2xPh4j0NVOyRf5JU.jpg'),
(100557, 7142, 'A História do Mundo: Parte 2 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jpBUAq8xxdxWNHlMcQuiUCaL2jt.jpg'),
(100558, 7142, 'A História do Mundo: Parte 2 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3r087nWP85SyfMK9gscPt7E3aXA.jpg'),
(100559, 7142, 'A História do Mundo: Parte 2 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kgreWx1Ui3vhSjFo2c9HsVDhqxI.jpg'),
(100560, 7142, 'A História do Mundo: Parte 2 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/edfiqOaF6k9mI7CuCGIJkoIh4av.jpg'),
(100561, 7142, 'A História do Mundo: Parte 2 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m0uvPevxFV0yVCDLd6IFfMTfxhM.jpg'),
(100562, 7142, 'A História do Mundo: Parte 2 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzVqD8DcJgVAujwe2M2sC9C1csp.jpg'),
(100563, 7142, 'A História do Mundo: Parte 2 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/izWqVh8bseaLsXfUTbWOMif5w8g.jpg'),
(100564, 7143, 'A Lição S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8vebt8XTfCwS26Lw83dX6GpXIMB.jpg'),
(100565, 7143, 'A Lição S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d230QyQTJEv1ieh9kfDAucsR5Cz.jpg'),
(100566, 7143, 'A Lição S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nhKJdtVT6Ly0PDLJSYi6mS51Wta.jpg'),
(100567, 7143, 'A Lição S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kUVG5bEXR1z13zsPeyR6Pri2S2t.jpg'),
(100568, 7143, 'A Lição S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3nE47kB0JYOAlUvE0XZF8BUCbjl.jpg'),
(100569, 7143, 'A Lição S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ao5JuwGbzyAY0VBfUDmZb9QYQU1.jpg'),
(100570, 7143, 'A Lição S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x6rVyCAvvr0yprytwRRQhKw2l9e.jpg'),
(100571, 7143, 'A Lição S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dpYzykWnRjBIuh08THe6N4z5Asf.jpg'),
(100572, 7143, 'A Lição S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kZJCJNLdcOTp2DUdTfVv8wDAvsY.jpg'),
(100573, 7143, 'A Lição S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o6cDOOwyO3eIAUvdNdSUcfXKNsm.jpg'),
(100574, 7143, 'A Lição S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1uikg2xGusosqeiQDu4OkrSsu44.jpg'),
(100575, 7143, 'A Lição S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bxosyqzCCmVS95BSh6jItNXtK0q.jpg'),
(100576, 7143, 'A Lição S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nkIbPu8tKvNXGXcNk1JBqw595I1.jpg'),
(100577, 7143, 'A Lição S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/erTVkebZ1q65ZnF2nScddCg7jFi.jpg'),
(100578, 7143, 'A Lição S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nHq2nZRFSgEMhjErgclGnfAas4Y.jpg'),
(100579, 7143, 'A Lição S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXiQ1AdWxzgHMROuxlVCcoWxBLN.jpg'),
(100580, 7144, 'Arrested Development S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yLwaP7Y7O3Wyrht9lPmTDk7LSuG.jpg'),
(100581, 7144, 'Arrested Development S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yhL1JBnTDK30BtPbr8gZ5ZXCASL.jpg'),
(100582, 7144, 'Arrested Development S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d9F2x01XNhi65GTXwQjrdDJKgqm.jpg'),
(100583, 7144, 'Arrested Development S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9q62zw89SJiRD3kjNuhUIswWHTa.jpg'),
(100584, 7144, 'Arrested Development S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uIztge10KNlRU4KUFNXWPGCiG8e.jpg'),
(100585, 7144, 'Arrested Development S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2I7WgvRwnYDNjbiztvbOAldYGde.jpg'),
(100586, 7144, 'Arrested Development S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AlIchjeADYvNkaXwLdIyDK7t4iw.jpg'),
(100587, 7144, 'Arrested Development S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nR2lh17PdojUL7ZYPhxi3JbSuIK.jpg'),
(100588, 7144, 'Arrested Development S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZaAZ8CpRwJUI9OguIvQi06GUQd.jpg'),
(100589, 7144, 'Arrested Development S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jwaP6vINHpVpvhr058jd0bDJIuk.jpg'),
(100590, 7144, 'Arrested Development S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZJPWCSAUSteliEvgpWT45AxC7m.jpg'),
(100591, 7144, 'Arrested Development S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rVlifHGAGNgslKRnW9AtPHfjvqy.jpg'),
(100592, 7144, 'Arrested Development S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bi25fDy2697b1MvbYFP8CzdBq9y.jpg'),
(100593, 7144, 'Arrested Development S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5osKFeoZupELgtn4SBCoFRvJdz6.jpg'),
(100594, 7144, 'Arrested Development S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rS2bDqNUt4qntcGwOHzTM8cJNsS.jpg'),
(100595, 7144, 'Arrested Development S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCI3S3jRf098NRQYRrsQHgQJbpY.jpg'),
(100596, 7144, 'Arrested Development S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/206471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9kp641W0JZMIheltYIWoFGr9tRX.jpg'),
(100597, 7144, 'Arrested Development S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/206472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/130DECQ7HnTlLPQPwfE4zBsXYaS.jpg'),
(100598, 7144, 'Arrested Development S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/206473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pDh4F7cu5bVqBO51evafcotoZit.jpg'),
(100599, 7144, 'Arrested Development S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/206474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ubLZRlOvfQdLg7UMSaTRfvTrBaR.jpg'),
(100600, 7144, 'Arrested Development S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/206475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vt4OTHzjnRzZb1dsRSrK0XP21HU.jpg'),
(100601, 7144, 'Arrested Development S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/206476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Zpb1EYr2bsSKh0ExSRBxYX1yEa.jpg'),
(100602, 7145, 'Arrested Development S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xivLvUm9OqunW7RBvphKtAqrclG.jpg'),
(100603, 7145, 'Arrested Development S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fFlJ5D7zoKaGazfeu3uaXdwXAAz.jpg'),
(100604, 7145, 'Arrested Development S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yB0DU66y7zyQLZQY9RjMY9kZLIu.jpg'),
(100605, 7145, 'Arrested Development S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jcjbLXIkg1l9IwI7tpfgr4tYPYt.jpg'),
(100606, 7145, 'Arrested Development S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5p9oGkHPLp8KwECbvrDoa0d2Yvd.jpg'),
(100607, 7145, 'Arrested Development S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gtRGpCoV7HiipfQNNkgSkku28Hi.jpg'),
(100608, 7145, 'Arrested Development S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zlpCslcepR6PQnE3qe8qU8eSrRs.jpg'),
(100609, 7145, 'Arrested Development S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h7fNyHPosZVPwP5TYGNz6vscY8P.jpg'),
(100610, 7145, 'Arrested Development S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQJPdzUy9HDLeSYc6ZBnOumlsxL.jpg'),
(100611, 7145, 'Arrested Development S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbkFSEnAPa6xvYb1m1gNdzhqdPZ.jpg'),
(100612, 7145, 'Arrested Development S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/534oHXZgJqweCzoSzFFUSOFmLgl.jpg'),
(100613, 7145, 'Arrested Development S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jVgvq8FJwH5ArToZHZ8PtyHGtFF.jpg'),
(100614, 7145, 'Arrested Development S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97p9Fptu8sW7Cx8UDWmrBBRj4BQ.jpg'),
(100615, 7145, 'Arrested Development S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k22D8T832IObtHLnxM1Q1Mlhi2m.jpg'),
(100616, 7145, 'Arrested Development S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yMHFMO4LZ0XC7VYNyw2crfQ6ObX.jpg'),
(100617, 7145, 'Arrested Development S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJyIRuy545lOVajO5p6cOv1PtMM.jpg'),
(100618, 7145, 'Arrested Development S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/206493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nk2PEn03g4paGManYksvPTG7G8j.jpg'),
(100619, 7145, 'Arrested Development S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/206494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/15dU6cu0VtgSVR6mDofjfBkCdXb.jpg'),
(100620, 7146, 'Arrested Development S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3HmZa4gJF38uRektAObXrrVQcSA.jpg'),
(100621, 7146, 'Arrested Development S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSDxSPeKTnWdUe6ws8rEAtfwdqZ.jpg'),
(100622, 7146, 'Arrested Development S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1bQIlLDib9h2AJAdBqRZXPLfqey.jpg'),
(100623, 7146, 'Arrested Development S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iUn6JZe6NJOfpyOHzeejzrlBI1w.jpg'),
(100624, 7146, 'Arrested Development S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iNxbxGcT1HavkZHWBqO4mW4QlkS.jpg'),
(100625, 7146, 'Arrested Development S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sUu7uFJHAlLoabOHNGGkF8LDSBx.jpg'),
(100626, 7146, 'Arrested Development S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yRieWnv4zrLVOqvCy04PdHquaf3.jpg'),
(100627, 7146, 'Arrested Development S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b1wd8A1Vu6yKEM7howLMd0DgOCL.jpg'),
(100628, 7146, 'Arrested Development S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2WyMmIagPMMFKTxacaVnAHjX7AK.jpg'),
(100629, 7146, 'Arrested Development S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhKISC5nlZ2O7BCkVShDFrspl6U.jpg'),
(100630, 7146, 'Arrested Development S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eH4hQipN3jNAXJaYV8SD8q629ab.jpg'),
(100631, 7146, 'Arrested Development S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/93QeZW1tlhrfZEYprsxH2gMNDje.jpg'),
(100632, 7146, 'Arrested Development S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wCtlA5f4woKGsmmizA6wGkDu8p0.jpg'),
(100633, 7147, 'Arrested Development S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qYggoekpFVsu133g8XUA0zck0O1.jpg'),
(100634, 7147, 'Arrested Development S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUZMUePHv9hFLzmEKnjKtKfzjgO.jpg'),
(100635, 7147, 'Arrested Development S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n5mvUsD0Y4IiSFbge91SqfX0br1.jpg'),
(100636, 7147, 'Arrested Development S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bF9ZCZzZyo2lV6OpvfIu8LdTvjf.jpg'),
(100637, 7147, 'Arrested Development S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c0uu8lZslXSkoBWmWiNKtboROMo.jpg'),
(100638, 7147, 'Arrested Development S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4VaOcQVwyL2FKc3y6xOWp2JbKP7.jpg'),
(100639, 7147, 'Arrested Development S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ZZSygOvkOvRfslorCHWCIM6LSP.jpg'),
(100640, 7147, 'Arrested Development S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pUGz8KoGpgMTRPrD3JjehT6jGaF.jpg'),
(100641, 7147, 'Arrested Development S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tiXR12JcNAE6RSj8M1BvzLotodS.jpg'),
(100642, 7147, 'Arrested Development S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yLJjYBBW1nFNAYWdYtlBQKlF05A.jpg'),
(100643, 7147, 'Arrested Development S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/20pMwHSFZxvhJ1Vn9LtTLWoFnYe.jpg'),
(100644, 7147, 'Arrested Development S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iFdzNhasbDql7WW7wh8US8YIeHf.jpg'),
(100645, 7147, 'Arrested Development S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qD2vB7yXMKtqbybtHhImixaMeTJ.jpg'),
(100646, 7147, 'Arrested Development S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bUsEL459L4WrUJsCaca9ptfFBD6.jpg'),
(100647, 7147, 'Arrested Development S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dfKkXJeeElkTEFHw6zUOIxwvg85.jpg'),
(100648, 7147, 'Arrested Development S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2N238rhCY1V29DkjmyMocBjAQzw.jpg'),
(100649, 7147, 'Arrested Development S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/206524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2N238rhCY1V29DkjmyMocBjAQzw.jpg'),
(100650, 7147, 'Arrested Development S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/206525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2N238rhCY1V29DkjmyMocBjAQzw.jpg'),
(100651, 7147, 'Arrested Development S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/206526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2N238rhCY1V29DkjmyMocBjAQzw.jpg'),
(100652, 7147, 'Arrested Development S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/206527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2N238rhCY1V29DkjmyMocBjAQzw.jpg'),
(100653, 7147, 'Arrested Development S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/206528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2N238rhCY1V29DkjmyMocBjAQzw.jpg'),
(100654, 7147, 'Arrested Development S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/206529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2N238rhCY1V29DkjmyMocBjAQzw.jpg'),
(100655, 7148, 'Arrested Development S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wugy4bB3410QWQxYopMjqC6kOmc.jpg'),
(100656, 7148, 'Arrested Development S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uahRU9SkvCTIMGuw6443ibPjF1m.jpg'),
(100657, 7148, 'Arrested Development S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v9KQkbsYgYR5BRQ3qUbBeujllpV.jpg'),
(100658, 7148, 'Arrested Development S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rS1lPj5odHDiqyk8Z3FcU9DOuJY.jpg'),
(100659, 7148, 'Arrested Development S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xLLVsqrISVpkMxkVxNivlcZJOt4.jpg'),
(100660, 7148, 'Arrested Development S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tVengBPMHSZiIin1aXFlkZ4SOoA.jpg'),
(100661, 7148, 'Arrested Development S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ekvG4EU7wg1iwAiYv2CPuMrIsZi.jpg'),
(100662, 7148, 'Arrested Development S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9br2OVmDDFrXHw0ttLTQOsv1uXn.jpg'),
(100663, 7148, 'Arrested Development S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vRlwzfUjMJ47dN7hb2xX6LgPdV4.jpg'),
(100664, 7148, 'Arrested Development S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ZxauF1NjFLROIGYfgSeByoPnrM.jpg'),
(100665, 7148, 'Arrested Development S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8EwgirvVLsspcuprLXoZmcdSd0D.jpg'),
(100666, 7148, 'Arrested Development S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/abZbU8VdImTrdq0fAnzjsxnWzhS.jpg'),
(100667, 7148, 'Arrested Development S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jfS1FmYRL1sR8X44s8Yq5a08Qfh.jpg'),
(100668, 7148, 'Arrested Development S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s89UQNTg59WXWrOzOdfyoMdgPY0.jpg'),
(100669, 7148, 'Arrested Development S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lTxbuSjgqMcLG8LDn57bxjDUREk.jpg'),
(100670, 7148, 'Arrested Development S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cRzx1gePrrvuoJeLrZ0zgmRFG99.jpg'),
(100671, 5791, 'Clima do Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206439.mp4', 'http://timg.bdta.pro/images/23ec428f10aa90b275f9283cf8f2c717.jpg'),
(100672, 5791, 'Clima do Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206440.mp4', 'http://timg.bdta.pro/images/ba5fc9128eb21b3e6ddf165b3f13c628.jpg'),
(100673, 5791, 'Clima do Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206441.mp4', 'http://timg.bdta.pro/images/6130e01ac6816f33fe67c4e97a2cc93b.jpg'),
(100674, 5791, 'Clima do Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206442.mp4', 'http://timg.bdta.pro/images/2aa8e2fdc975d8f78fc6cd18bf9849c1.jpg'),
(100675, 5791, 'Clima do Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206443.mp4', 'http://timg.bdta.pro/images/23cc6ade2424e6d03db6450d431d2800.jpg'),
(100676, 5791, 'Clima do Amor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206444.mp4', 'http://timg.bdta.pro/images/fdac29d2fee5475c96b6397dcdf4ad68.jpg'),
(100677, 5791, 'Clima do Amor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206445.mp4', 'http://timg.bdta.pro/images/91f49681e7bec14fd0739a6734b73239.jpg'),
(100678, 5791, 'Clima do Amor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206446.mp4', 'http://timg.bdta.pro/images/278d10d76028e2be0335c21905430dfe.jpg'),
(100679, 5791, 'Clima do Amor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206447.mp4', 'http://timg.bdta.pro/images/029792056113a6535de1f48ea58af49a.jpg'),
(100680, 5791, 'Clima do Amor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206448.mp4', 'http://timg.bdta.pro/images/614a31da05cf816f4536997b659a7467.jpg'),
(100681, 5791, 'Clima do Amor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206449.mp4', 'http://timg.bdta.pro/images/5066bd2d707ea3c332b827a1d0c83551.jpg'),
(100682, 5791, 'Clima do Amor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206450.mp4', 'http://timg.bdta.pro/images/fa7c67b03a5af29834af97ba7753b678.jpg'),
(100683, 5791, 'Clima do Amor S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206451.mp4', 'http://timg.bdta.pro/images/3bc49b6cb7506d4c7a7182bc8dd6295e.jpg'),
(100684, 5791, 'Clima do Amor S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/206452.mp4', 'http://timg.bdta.pro/images/9c183b38c88624aea2b12f280404b8b9.jpg'),
(100685, 5791, 'Clima do Amor S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/206453.mp4', 'http://timg.bdta.pro/images/ee616dd61071cf0256e6c330f45f8a39.jpg'),
(100686, 5791, 'Clima do Amor S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/206454.mp4', 'http://timg.bdta.pro/images/23b04933119ae9fcd40a9b5f975a7f51.jpg'),
(100687, 7149, 'Dra. Joya: Dermatologista Animal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4dVcqWXXgaafU2cB0L4MCE1u7zW.jpg'),
(100688, 7149, 'Dra. Joya: Dermatologista Animal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cVdt76h1XaVzpy9Idql9KuWn7Nb.jpg'),
(100689, 7149, 'Dra. Joya: Dermatologista Animal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yLHjGTixlVeGfRr6L10P3vzqKrn.jpg'),
(100690, 7149, 'Dra. Joya: Dermatologista Animal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9r4cnTUq9FMOGSdP3GwyueORq4s.jpg'),
(100691, 7149, 'Dra. Joya: Dermatologista Animal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cTmQKxzRyQbMXqvTB6T8bawwEEH.jpg'),
(100692, 7149, 'Dra. Joya: Dermatologista Animal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dNoPPIEf4DsVMGgsDRPqelYoORm.jpg'),
(100693, 7149, 'Dra. Joya: Dermatologista Animal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zZVT9OYkWzioSNIdWv4QZq1uuVo.jpg'),
(100694, 7149, 'Dra. Joya: Dermatologista Animal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/weFFw0gSg0WJL5lqeGSKxHl6aUG.jpg'),
(100695, 7150, 'Fora da Prisão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k45J8gmRlpdtn34Hd35vQjAujtA.jpg'),
(100696, 7150, 'Fora da Prisão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cepVbdY8eNsQlFh2w14X4foV1gS.jpg'),
(100697, 7150, 'Fora da Prisão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xsKiK134nGfnHZ6otoBup5FGlIb.jpg'),
(100698, 7150, 'Fora da Prisão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k4uhky2CIC9bg3G6uSzhVseXvm9.jpg'),
(100699, 7150, 'Fora da Prisão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/41hMPVPbTphHOOTfhv26hIHYIs.jpg'),
(100700, 7150, 'Fora da Prisão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wx6Hmqk2tp5KUyQlkcTtDWNkW7P.jpg'),
(100701, 7150, 'Fora da Prisão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c1CDCbYmNQOa4pJJ8tfZIvku6NU.jpg'),
(100702, 7150, 'Fora da Prisão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6yhWX5qvoENOIKsPB00RUvul4HQ.jpg'),
(100703, 7151, 'Histórias (Im)possíveis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6T3keIbszfr1PSbPOhbHekRS2MM.jpg'),
(100704, 7151, 'Histórias (Im)possíveis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/turVvoei5UZCOAD4xb2z2mBQycJ.jpg'),
(100705, 7152, 'Histórias de Terror S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/50CKQvJWbf5YFaVSfrq5imwZs1q.jpg'),
(100706, 7152, 'Histórias de Terror S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LEAI056kA38MvY4qzCWvvIATrt.jpg'),
(100707, 7152, 'Histórias de Terror S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1DtLWohynR3RNgfRUQczt9uATY.jpg'),
(100708, 7152, 'Histórias de Terror S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cgxnLU4BKSRnZLKj7BhRbWzuxQp.jpg'),
(100709, 7152, 'Histórias de Terror S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bAwugUknyAE3EnCYRfscg7aHo5v.jpg'),
(100710, 7152, 'Histórias de Terror S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jqUQ8JbzfaMJnbnHbqA84D8V6Sd.jpg'),
(100711, 7152, 'Histórias de Terror S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qgzbR35agVG1pB4VSDBdk3ZBf6.jpg'),
(100712, 7152, 'Histórias de Terror S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4QyRI3nUKB5hWuC81bEvqEbxiNx.jpg'),
(100713, 7153, 'Justiça por Uphaar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z3qGY8q4qqMjMWCX4Dlm91RMro4.jpg'),
(100714, 7153, 'Justiça por Uphaar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ONhFjVSR885Qrr5HNvX08Gixos.jpg'),
(100715, 7153, 'Justiça por Uphaar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1by3GbjUysJm3Nlyz3bZ2ZZCpN6.jpg'),
(100716, 7153, 'Justiça por Uphaar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/upv1jF1MydllVXGcponOW4QtSe9.jpg'),
(100717, 7153, 'Justiça por Uphaar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fg8X3NmtKfuo9joDxWfGCdpMcwO.jpg'),
(100718, 7153, 'Justiça por Uphaar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nrGeSTaRtXcnY9pAtlDST1GG5y7.jpg'),
(100719, 7153, 'Justiça por Uphaar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xc1V4kV7JwS8oIt8n1iimE8mQwe.jpg'),
(100720, 7154, 'Morte no Deserto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6LL5xjsg3pON3btrpZCXpAYYRRZ.jpg'),
(100721, 7154, 'Morte no Deserto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOiFqlEOBZA3amfxaBtCXQhdjzE.jpg'),
(100722, 7154, 'Morte no Deserto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1dlr2AsJ1zflwu9zQ08yPVKP3d8.jpg'),
(100723, 7154, 'Morte no Deserto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cyueRHW7KyxEIZup3K9XQL569u4.jpg'),
(100724, 7154, 'Morte no Deserto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mrWDzATINVRx3kEMpVbwlrsDhWH.jpg'),
(100725, 7154, 'Morte no Deserto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/14e3M8ptemysCth7efu3xY3dr4w.jpg'),
(100726, 7154, 'Morte no Deserto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/npnAow5rlunHpDT7mj4pvQtEYL1.jpg'),
(100727, 7155, 'O Grito das Mariposas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yk1lIqJ0SG9URKjg0m0DHGV5gWg.jpg'),
(100728, 7155, 'O Grito das Mariposas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4qKWmqjVGpXLAHgJs5kiHfXdf2.jpg'),
(100729, 7155, 'O Grito das Mariposas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/23wSAVRLEZojDPkhxLp6JRSAfU9.jpg'),
(100730, 7155, 'O Grito das Mariposas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJTc1i8fCta0lWwgigaWn7XS0Br.jpg'),
(100731, 7155, 'O Grito das Mariposas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Wlf8AFxZXqZPBclatWGQp4lHAK.jpg'),
(100732, 7155, 'O Grito das Mariposas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cGvsqpZZIXlrOqm9WeQzwzl1SR8.jpg'),
(100733, 7155, 'O Grito das Mariposas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uysxLtzASLkZ1mkZTOsib1TsDix.jpg'),
(100734, 7155, 'O Grito das Mariposas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEWC1B2NFnyc4Vmkb8UWVX5rwgn.jpg'),
(100735, 7155, 'O Grito das Mariposas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3KSpByeGc0tVDZSBWSLrB4OI9LY.jpg'),
(100736, 7155, 'O Grito das Mariposas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/C2cIOR2wEUhVntnZm3O7e5yztQ.jpg'),
(100737, 7155, 'O Grito das Mariposas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sROJW7jJ3lzheujdTr6h7mAq8DW.jpg'),
(100738, 7155, 'O Grito das Mariposas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1o74QLNXKkchWibBqyQquSs3JsX.jpg'),
(100739, 7155, 'O Grito das Mariposas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/206400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ohbfMwxCkHiueraCk8dWqQVB5DH.jpg'),
(100740, 7156, 'O Repórter do Poder S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/larKtYorbszC5q6gll3KCSTtrdG.jpg'),
(100741, 7156, 'O Repórter do Poder S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/larKtYorbszC5q6gll3KCSTtrdG.jpg'),
(100742, 7156, 'O Repórter do Poder S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/larKtYorbszC5q6gll3KCSTtrdG.jpg'),
(100743, 7156, 'O Repórter do Poder S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/larKtYorbszC5q6gll3KCSTtrdG.jpg'),
(100744, 7157, 'Os Segredos do Zoológico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4XQqAGpdecls9HPiiiWmF5yUvtn.jpg'),
(100745, 7157, 'Os Segredos do Zoológico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4RVmoaUKo10Zr2nZJS79rTsByoV.jpg'),
(100746, 7157, 'Os Segredos do Zoológico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ak8K7NGzJc8omArGs7lWJAi1zpU.jpg'),
(100747, 7157, 'Os Segredos do Zoológico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/30mrYDDjo5yhfYCk7xObwOn1WiC.jpg'),
(100748, 7157, 'Os Segredos do Zoológico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5QTi2BdPDqQaL9q77aJJocTS2wI.jpg'),
(100749, 7157, 'Os Segredos do Zoológico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3kdWQlPE7FgUZoWU7pjV09cADmL.jpg'),
(100750, 7158, 'Sobreviventes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2E54yb8X7Fr4u5wIAWe8Vf9VgTV.jpg'),
(100751, 7158, 'Sobreviventes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8dQbWHngb2x5unfVjrcKgSYJZtb.jpg'),
(100752, 7158, 'Sobreviventes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eke9k9ZMQMzxKWzCaixPdNsk5Vz.jpg'),
(100753, 7158, 'Sobreviventes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sX81MQhr7v2dzUstX5f7QCPJCoE.jpg'),
(100754, 7158, 'Sobreviventes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/spwXDK3cwQeNTu5UeT3pv3w0sht.jpg'),
(100755, 7158, 'Sobreviventes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/86MXRqddus2izHRdcH7v611WZXb.jpg'),
(100756, 7158, 'Sobreviventes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/muM8mubeepkeR6JgPRWecutcRc5.jpg'),
(100757, 7158, 'Sobreviventes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dK44adOEcduIivKy3xoEDA2I9iV.jpg'),
(100758, 7159, 'PoderM S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/631Gi2occyVaJDU1Pg0Up6FeBJb.jpg'),
(100759, 7159, 'PoderM S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhEKeC1DEQurSTjYbymqXcaLhqA.jpg'),
(100760, 7159, 'PoderM S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tZdhIgNIoTMGJxzEVeSw2p2nbb6.jpg'),
(100761, 7159, 'PoderM S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uWooLKWW0D9L2Flj4oHk3l7ELnN.jpg'),
(100762, 7160, 'Que Bicho te Mordeu? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/VcvaJ2HbNgQAB5Y6EqA9KZRvO3.jpg'),
(100763, 7160, 'Que Bicho te Mordeu? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/unpM2yBe5blM300eLdcQ1PIr1AH.jpg'),
(100764, 7160, 'Que Bicho te Mordeu? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/unpM2yBe5blM300eLdcQ1PIr1AH.jpg'),
(100765, 7160, 'Que Bicho te Mordeu? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206357.mp4', 'http://gstaticontent.com/images/9e2b1e0a77bc1c5ff127b6dfc8afd273.jpg'),
(100766, 7160, 'Que Bicho te Mordeu? S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206358.mp4', 'http://gstaticontent.com/images/9e2b1e0a77bc1c5ff127b6dfc8afd273.jpg'),
(100767, 7160, 'Que Bicho te Mordeu? S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206359.mp4', 'http://gstaticontent.com/images/9e2b1e0a77bc1c5ff127b6dfc8afd273.jpg'),
(100768, 7160, 'Que Bicho te Mordeu? S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206360.mp4', 'http://gstaticontent.com/images/9e2b1e0a77bc1c5ff127b6dfc8afd273.jpg'),
(100769, 7160, 'Que Bicho te Mordeu? S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206361.mp4', 'http://gstaticontent.com/images/9e2b1e0a77bc1c5ff127b6dfc8afd273.jpg'),
(100770, 7160, 'Que Bicho te Mordeu? S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206362.mp4', 'http://gstaticontent.com/images/9e2b1e0a77bc1c5ff127b6dfc8afd273.jpg'),
(100771, 7160, 'Que Bicho te Mordeu? S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206363.mp4', 'http://gstaticontent.com/images/9e2b1e0a77bc1c5ff127b6dfc8afd273.jpg'),
(100772, 7160, 'Que Bicho te Mordeu? S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/206364.mp4', 'http://gstaticontent.com/images/9e2b1e0a77bc1c5ff127b6dfc8afd273.jpg'),
(100773, 7160, 'Que Bicho te Mordeu? S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/206365.mp4', 'http://gstaticontent.com/images/9e2b1e0a77bc1c5ff127b6dfc8afd273.jpg'),
(100774, 7161, 'Rain Dogs S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yykn7VcvjVeiJ1jJtUi3ZMaTD8a.jpg'),
(100775, 7161, 'Rain Dogs S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210888.mp4', 'http://image.tmdb.org/t/p/w1280/tLmWDyVz51beXi8YtV9TirWute2.jpg'),
(100776, 7161, 'Rain Dogs S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210889.mp4', 'http://image.tmdb.org/t/p/w1280/qpHX1gcvUXwlmG3PzMadm9ZheTk.jpg'),
(100777, 7161, 'Rain Dogs S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210890.mp4', 'http://image.tmdb.org/t/p/w1280/lwMZPupCWFf1EMr6gd5bV5lCUp5.jpg'),
(100778, 7161, 'Rain Dogs S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210891.mp4', 'http://image.tmdb.org/t/p/w1280/yyrxdFnfnE6ZYeoDBfdfQKiS4ou.jpg'),
(100779, 7161, 'Rain Dogs S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210892.mp4', 'http://image.tmdb.org/t/p/w1280/hKP1gpWe7AVlsPV73PwvpsNZgAC.jpg'),
(100780, 7161, 'Rain Dogs S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210893.mp4', 'http://image.tmdb.org/t/p/w1280/qxUdBusWxrlFjtFQS8fIzF5LBcQ.jpg'),
(100781, 7161, 'Rain Dogs S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210894.mp4', 'http://image.tmdb.org/t/p/w1280/v2Stg0exMvbwEDzQoL9d0054xgZ.jpg'),
(100782, 7162, 'Sem Bloqueio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cliutOXUWDam06VHwH5pbi8VCBH.jpg'),
(100783, 7162, 'Sem Bloqueio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cliutOXUWDam06VHwH5pbi8VCBH.jpg'),
(100784, 7162, 'Sem Bloqueio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cliutOXUWDam06VHwH5pbi8VCBH.jpg'),
(100785, 7162, 'Sem Bloqueio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cliutOXUWDam06VHwH5pbi8VCBH.jpg'),
(100786, 7162, 'Sem Bloqueio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cliutOXUWDam06VHwH5pbi8VCBH.jpg'),
(100787, 7163, 'The Challenge: Campeonato Mundial S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9AwRDnwvpMEvC85ipEGM271j8Me.jpg'),
(100788, 7163, 'The Challenge: Campeonato Mundial S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9oxEFcF8Qvtb0Jl3J3dYVmrqBay.jpg'),
(100789, 7163, 'The Challenge: Campeonato Mundial S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213248.mp4', 'http://image.tmdb.org/t/p/w1280/pXXgaoSN2prCTFbW87F59275FYx.jpg'),
(100790, 7163, 'The Challenge: Campeonato Mundial S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zinFp4mOzxN1NTj8f2W1BWsQxhR.jpg'),
(100791, 7163, 'The Challenge: Campeonato Mundial S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zinFp4mOzxN1NTj8f2W1BWsQxhR.jpg'),
(100792, 7163, 'The Challenge: Campeonato Mundial S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zinFp4mOzxN1NTj8f2W1BWsQxhR.jpg'),
(100793, 7163, 'The Challenge: Campeonato Mundial S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zinFp4mOzxN1NTj8f2W1BWsQxhR.jpg'),
(100794, 7163, 'The Challenge: Campeonato Mundial S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zinFp4mOzxN1NTj8f2W1BWsQxhR.jpg'),
(100795, 7163, 'The Challenge: Campeonato Mundial S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zinFp4mOzxN1NTj8f2W1BWsQxhR.jpg'),
(100796, 7163, 'The Challenge: Campeonato Mundial S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zinFp4mOzxN1NTj8f2W1BWsQxhR.jpg'),
(100797, 7163, 'The Challenge: Campeonato Mundial S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/213256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zinFp4mOzxN1NTj8f2W1BWsQxhR.jpg'),
(100798, 7163, 'The Challenge: Campeonato Mundial S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/213257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zinFp4mOzxN1NTj8f2W1BWsQxhR.jpg'),
(100799, 7164, 'The Endgame: Um Conto de Vingança S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aeRjq3efHxacsoZLDGByyhPHWjV.jpg'),
(100800, 7164, 'The Endgame: Um Conto de Vingança S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yZpGMpLVnFbXCj3W2wkHNjBn3xd.jpg'),
(100801, 7164, 'The Endgame: Um Conto de Vingança S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1THT864jiYj8xz3nM34SChMF0zX.jpg'),
(100802, 7164, 'The Endgame: Um Conto de Vingança S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/206342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7gwgOM2zX7PlOihO15uh4yU2Hcl.jpg'),
(100803, 7164, 'The Endgame: Um Conto de Vingança S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/206343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yP0q556ujTQnraor6ybFWXWHI5L.jpg'),
(100804, 7164, 'The Endgame: Um Conto de Vingança S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/206344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xYk8O0G3rEH3gJSWs8HWtsaANWl.jpg'),
(100805, 7164, 'The Endgame: Um Conto de Vingança S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/206345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDmLqOHrCUdT9UjSJQakL8NMp3c.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(100806, 7164, 'The Endgame: Um Conto de Vingança S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/206346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kuOU6DJBSjePCjiAK4e64bOKrXl.jpg'),
(100807, 7164, 'The Endgame: Um Conto de Vingança S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/206347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3EBz4ZT0ZyKs2fGVaHhoyX1iDde.jpg'),
(100808, 7164, 'The Endgame: Um Conto de Vingança S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/206348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sLsUwXI9IwbQbEHNTA1qdvjwDle.jpg'),
(100809, 7165, 'Voo 370: O Avião que Desapareceu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/206336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vx9Ylro3BDDzAUBxbFdHgNmtEH7.jpg'),
(100810, 7165, 'Voo 370: O Avião que Desapareceu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/206337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fuWV3F7XNVrurq2lRFJSMrHVS3Y.jpg'),
(100811, 7165, 'Voo 370: O Avião que Desapareceu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/206338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fSVpbTb2TbsSx5qoxYJ0VCzyXiv.jpg'),
(100812, 7166, 'Amorteamo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/205920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fCnGe5lE97HyQ80aFvSNWZ4xuEu.jpg'),
(100813, 7166, 'Amorteamo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/205921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fCnGe5lE97HyQ80aFvSNWZ4xuEu.jpg'),
(100814, 7166, 'Amorteamo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/205922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fCnGe5lE97HyQ80aFvSNWZ4xuEu.jpg'),
(100815, 7166, 'Amorteamo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/205923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fCnGe5lE97HyQ80aFvSNWZ4xuEu.jpg'),
(100816, 7166, 'Amorteamo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/205924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fCnGe5lE97HyQ80aFvSNWZ4xuEu.jpg'),
(100817, 7167, 'A Direita no Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hDyGKTuEd4qWl6m3MUN3V9bLYtc.jpg'),
(100818, 7167, 'A Direita no Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hDyGKTuEd4qWl6m3MUN3V9bLYtc.jpg'),
(100819, 7167, 'A Direita no Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hDyGKTuEd4qWl6m3MUN3V9bLYtc.jpg'),
(100820, 7168, 'A Guerra dos Bolos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rgChD0wBedAWM4lBQ9WdNwJNLD1.jpg'),
(100821, 7168, 'A Guerra dos Bolos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6EdtB1V8fFZTjtmbtuglIs7TX1e.jpg'),
(100822, 7168, 'A Guerra dos Bolos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/itNCosTSI63k13F74QL9G8Ss5Jy.jpg'),
(100823, 7168, 'A Guerra dos Bolos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pLL2U6abau0htx5UOqtBenOnywR.jpg'),
(100824, 7168, 'A Guerra dos Bolos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o0cq8T2Ps8xaFf6m4yf7EVxUNJK.jpg'),
(100825, 7168, 'A Guerra dos Bolos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rHIp50tDJxuaVsZ9w68jhmuEJ0y.jpg'),
(100826, 7168, 'A Guerra dos Bolos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/skxKyI3zKUSQjbxgwrGDjPXxscb.jpg'),
(100827, 7168, 'A Guerra dos Bolos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmRnbbAuonOUTrA6cqQdJqvdVbQ.jpg'),
(100828, 7169, 'A Guerra dos Bolos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/82MR8wDtA6y0T5UoRpSbabDq6Po.jpg'),
(100829, 7169, 'A Guerra dos Bolos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cfNj1ZldSNyR04Z2BNQtGEVVz16.jpg'),
(100830, 7169, 'A Guerra dos Bolos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gPdkF9gR08htPeVmYGRpZ3s4zT3.jpg'),
(100831, 7169, 'A Guerra dos Bolos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i1QYCpnXA0Ln53CdBk1Zjhk4CNC.jpg'),
(100832, 7169, 'A Guerra dos Bolos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dzBo1nV000uhKS5GcaLVNelAgft.jpg'),
(100833, 7169, 'A Guerra dos Bolos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kG8hdUxkNIT4SI6QJb1ZKnkRvbf.jpg'),
(100834, 7169, 'A Guerra dos Bolos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5XxkyA3iWSaJz7H6uVpYPiXz5X4.jpg'),
(100835, 7169, 'A Guerra dos Bolos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jdNatCGkCWFRo8mSU6awRXfbNIN.jpg'),
(100836, 7169, 'A Guerra dos Bolos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rraXnebUvcJKG9Z1BK9EeIkCodG.jpg'),
(100837, 7169, 'A Guerra dos Bolos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3myYe86cJvB8qwXLvxHIGffkabL.jpg'),
(100838, 7169, 'A Guerra dos Bolos S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/209817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ai4RZcHRqUyWDIw08rXBFFepNd.jpg'),
(100839, 7169, 'A Guerra dos Bolos S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/209818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3C0oM0AHxVw4m0keajWdp31p454.jpg'),
(100840, 7169, 'A Guerra dos Bolos S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/209819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/po3BVLlUouwjtZj1eqGnLN1eQN5.jpg'),
(100841, 7170, 'A Guerra dos Bolos S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o4C6Z655DNyqHlCuIOcG8UGgFbY.jpg'),
(100842, 7170, 'A Guerra dos Bolos S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7tbgAU9ruum0algdfPi5WDke23A.jpg'),
(100843, 7170, 'A Guerra dos Bolos S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zgDf70SMTGF02KvPaaaVLNrHhuc.jpg'),
(100844, 7170, 'A Guerra dos Bolos S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o1T3uHg4tdd4Ajpc9jRotylk8Vp.jpg'),
(100845, 7170, 'A Guerra dos Bolos S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bGVBqrfenMT1datN5wCYZFJifxM.jpg'),
(100846, 7170, 'A Guerra dos Bolos S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aNeJCvI7rHdwk9Uq0gK8Ln3y2Bk.jpg'),
(100847, 7170, 'A Guerra dos Bolos S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bPs51k1dGsAd1FGykNUiBqLxHSC.jpg'),
(100848, 7170, 'A Guerra dos Bolos S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gucSJV7YUxXmWMIShoZKrqx7vuy.jpg'),
(100849, 7170, 'A Guerra dos Bolos S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lpaD4uqIxWC91RIXUxM086sgwoC.jpg'),
(100850, 7170, 'A Guerra dos Bolos S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3G9Xa6OXpzyilDniCttWl1h4lX8.jpg'),
(100851, 7170, 'A Guerra dos Bolos S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/209830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cbmk6o0inbZXJlv0gTQvRrkFmkv.jpg'),
(100852, 7170, 'A Guerra dos Bolos S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/209831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFbeQlyoxXlFcmuBR1A3iqLzo5B.jpg'),
(100853, 7170, 'A Guerra dos Bolos S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/209832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kiJCfyWABHxNMP98KNW8iv1krBT.jpg'),
(100854, 7171, 'A Guerra dos Bolos S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l992C036WtCq21uGL26l1thefbx.jpg'),
(100855, 7171, 'A Guerra dos Bolos S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shEwzRn12SroSThGOu2eXyrAuCc.jpg'),
(100856, 7171, 'A Guerra dos Bolos S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wH3APUGrnMdHjnPYnGpSG4w02s0.jpg'),
(100857, 7171, 'A Guerra dos Bolos S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eZb7t0OQGlC1FEpJKmVGGSokYEH.jpg'),
(100858, 7171, 'A Guerra dos Bolos S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/djICEw4RR9FHGX4EdhvCJBPyFFL.jpg'),
(100859, 7171, 'A Guerra dos Bolos S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBMsE0RVqcMT8HbGklnFoFXzIrr.jpg'),
(100860, 7171, 'A Guerra dos Bolos S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hwiNtSTsTGGDbnwwLvV35yIqUTd.jpg'),
(100861, 7171, 'A Guerra dos Bolos S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jtXZSzAv2a39UgxfYEBCb7FRfZF.jpg'),
(100862, 7171, 'A Guerra dos Bolos S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/FKqNqpsxkAmh2l8vNFAo7D6qJN.jpg'),
(100863, 7171, 'A Guerra dos Bolos S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5mnY6xl6hDEf2JD24yG1MmkoUOg.jpg'),
(100864, 7171, 'A Guerra dos Bolos S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/209843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wp5tjQDMHQClN37hWn97hxTIind.jpg'),
(100865, 7171, 'A Guerra dos Bolos S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/209844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZlszOHoYpoutV91SSrqsXRBQcn.jpg'),
(100866, 7171, 'A Guerra dos Bolos S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/209845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odONxIpeiTxkBtM7xFRsUq8irxF.jpg'),
(100867, 7172, 'A Guerra dos Bolos S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vhEL2ou40xtWibUUNHXC9nS9dh8.jpg'),
(100868, 7172, 'A Guerra dos Bolos S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vhEL2ou40xtWibUUNHXC9nS9dh8.jpg'),
(100869, 7172, 'A Guerra dos Bolos S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vhEL2ou40xtWibUUNHXC9nS9dh8.jpg'),
(100870, 7172, 'A Guerra dos Bolos S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vhEL2ou40xtWibUUNHXC9nS9dh8.jpg'),
(100871, 7172, 'A Guerra dos Bolos S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vhEL2ou40xtWibUUNHXC9nS9dh8.jpg'),
(100872, 7172, 'A Guerra dos Bolos S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vhEL2ou40xtWibUUNHXC9nS9dh8.jpg'),
(100873, 7173, 'Agente Elvis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ltfGjELQlqwYmSZA4Mm0sA5sjxj.jpg'),
(100874, 7173, 'Agente Elvis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Q4pqf8g31WD3UzH9skPlEfKJCR.jpg'),
(100875, 7173, 'Agente Elvis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cgL9ALDKGWWrZIbAiGw5yHwIX93.jpg'),
(100876, 7173, 'Agente Elvis S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lnd0OQQIkVu4uCk8anSy6XvESGa.jpg'),
(100877, 7173, 'Agente Elvis S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3TYmmvajGwrQKGHW4uT47UKdGBz.jpg'),
(100878, 7173, 'Agente Elvis S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t5zzdnSbjlaTKZoINerbaMB5Ow5.jpg'),
(100879, 7173, 'Agente Elvis S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8MfYDCGkJr3BdMobb8PBWv8RqL3.jpg'),
(100880, 7173, 'Agente Elvis S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qxITfOR1auqX1ZDKnz5dHlmEJRp.jpg'),
(100881, 7173, 'Agente Elvis S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5gvZE8kbwfPQBteE055xm7uYTVJ.jpg'),
(100882, 7173, 'Agente Elvis S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p28CeJLZs4wDBEiTbpkzz3Qugya.jpg'),
(100883, 7174, 'As Leis da Selva S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7FWksls0XpiuzkoOF69duqdtFwA.jpg'),
(100884, 7174, 'As Leis da Selva S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8oAOCNawKTMnc6qYhpwyTV1UNGY.jpg'),
(100885, 7174, 'As Leis da Selva S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZsctdJzgq1c3BgVTsCNdYlJx63.jpg'),
(100886, 7174, 'As Leis da Selva S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2PN5uIFiN2AzW5UElyybGUAGAzm.jpg'),
(100887, 7174, 'As Leis da Selva S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hi49TKGVBvNSi19vKRoXeDBA6Fo.jpg'),
(100888, 7174, 'As Leis da Selva S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/obppW01jpgYvMUrKcK5j0IecFV.jpg'),
(100889, 7174, 'As Leis da Selva S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eOSkhgIDIUv9s0QHFuM9e8EGBbZ.jpg'),
(100890, 7174, 'As Leis da Selva S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6V2D00XFpr2jLxA6WJgZS1wH83G.jpg'),
(100891, 7175, 'Até o Céu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4QxmchkYq8a9OzksDaFcnPWF80P.jpg'),
(100892, 7175, 'Até o Céu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sox4gTEa6nAmy5MxQMktlJqZGHB.jpg'),
(100893, 7175, 'Até o Céu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svI0Ro3auZP2AVhruq6X4L0Cecq.jpg'),
(100894, 7175, 'Até o Céu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aiNvXDHzlj8dKpiMg5rzneFmfbM.jpg'),
(100895, 7175, 'Até o Céu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2KtzWNPtHgs25koD6adZLJ0Zoyi.jpg'),
(100896, 7175, 'Até o Céu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2RA3XvDF0mWUEr8HSRSaC9i8bqb.jpg'),
(100897, 7175, 'Até o Céu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fqdAXYI1RKgnH3Tk9lrwd7gXV31.jpg'),
(100898, 7176, 'Casamento Arranjado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iaZHTDEJv1x8GiuAeRSabC5YNGK.jpg'),
(100899, 7176, 'Casamento Arranjado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/djpv98aSWPw5fRINGWAykVjVWjD.jpg'),
(100900, 7176, 'Casamento Arranjado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ERvQa5HYdAqQW7oylvfnqagiQK.jpg'),
(100901, 7176, 'Casamento Arranjado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g5M3rSYz8JlxWkdoecjNvPxdXfm.jpg'),
(100902, 7176, 'Casamento Arranjado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNpINryF3rAJPpm7oWcPcWTA0W4.jpg'),
(100903, 7176, 'Casamento Arranjado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pnfyntV2P9hM7tJdhZARJQowGNw.jpg'),
(100904, 7176, 'Casamento Arranjado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xMpLeBEgizHPTTx3momVOHdxAcc.jpg'),
(100905, 7176, 'Casamento Arranjado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5A2mUEeSwBgbHkdd5us7KOx0fvw.jpg'),
(100906, 7176, 'Casamento Arranjado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ubqxVQMSIaTqCkBFSeR8bNR34uq.jpg'),
(100907, 7176, 'Casamento Arranjado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n2xVBrmors5ZD8M4XnUvGTnleVZ.jpg'),
(100908, 7177, 'Dance 100 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qwHddkj3NWzTfkE6R543F3b2reZ.jpg'),
(100909, 7177, 'Dance 100 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mGi5AAAVsUs3ZMFDIojAuV52fE1.jpg'),
(100910, 7177, 'Dance 100 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3uzWliJOEu5mI8uG3nFNsGrjdyv.jpg'),
(100911, 7177, 'Dance 100 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJO4dlkBkJ1n1gHWRpUXHyqkHS3.jpg'),
(100912, 7177, 'Dance 100 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q4TWG82JJKjfzqCAHt9NUNjF4TF.jpg'),
(100913, 7177, 'Dance 100 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nH7Qw0cLBBsQ4PKtDu87ONxd9AB.jpg'),
(100914, 7178, 'a Menina das Estrelas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j8tWORzmlam7H6cBKA1o4vfzLET.jpg'),
(100915, 7178, 'a Menina das Estrelas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j8tWORzmlam7H6cBKA1o4vfzLET.jpg'),
(100916, 7178, 'a Menina das Estrelas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j8tWORzmlam7H6cBKA1o4vfzLET.jpg'),
(100917, 7178, 'a Menina das Estrelas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j8tWORzmlam7H6cBKA1o4vfzLET.jpg'),
(100918, 7178, 'a Menina das Estrelas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j8tWORzmlam7H6cBKA1o4vfzLET.jpg'),
(100919, 7178, 'a Menina das Estrelas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j8tWORzmlam7H6cBKA1o4vfzLET.jpg'),
(100920, 7178, 'a Menina das Estrelas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j8tWORzmlam7H6cBKA1o4vfzLET.jpg'),
(100921, 7178, 'a Menina das Estrelas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j8tWORzmlam7H6cBKA1o4vfzLET.jpg'),
(100922, 7178, 'a Menina das Estrelas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j8tWORzmlam7H6cBKA1o4vfzLET.jpg'),
(100923, 7178, 'a Menina das Estrelas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j8tWORzmlam7H6cBKA1o4vfzLET.jpg'),
(100924, 7178, 'a Menina das Estrelas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/209755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j8tWORzmlam7H6cBKA1o4vfzLET.jpg'),
(100925, 7178, 'a Menina das Estrelas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/209756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j8tWORzmlam7H6cBKA1o4vfzLET.jpg'),
(100926, 7178, 'a Menina das Estrelas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/209757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j8tWORzmlam7H6cBKA1o4vfzLET.jpg'),
(100927, 7179, 'Enxame S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dRju9um8AspLX0oohDihEE8aZX5.jpg'),
(100928, 7179, 'Enxame S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jDDcSLQ5oW8iZFBbiEsKYawSILU.jpg'),
(100929, 7179, 'Enxame S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ort93fef2hay9CsDik1eYJck1Z.jpg'),
(100930, 7179, 'Enxame S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6M9DJ4XrZXk2H0sXI1oGNjS5lIM.jpg'),
(100931, 7179, 'Enxame S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7EZ5p9r8NvJ2V9MqRcMO6iEnPMy.jpg'),
(100932, 7179, 'Enxame S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/10IxTC1KG8SuJfzgsJjd4FzJlus.jpg'),
(100933, 7179, 'Enxame S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mVWUBoxf92KTDMaLdxQKm2FEKJF.jpg'),
(100934, 7180, 'Extrapolations - Um Futuro Inquietante S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oooiUsDQXP9F7JuFtVP4CarRSJx.jpg'),
(100935, 7180, 'Extrapolations - Um Futuro Inquietante S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tUYmZfNMYddzaosScxCvIkGT692.jpg'),
(100936, 7180, 'Extrapolations - Um Futuro Inquietante S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xYpvdGwaHgbG1RKF6rXld4HITnw.jpg'),
(100937, 7180, 'Extrapolations - Um Futuro Inquietante S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211850.mp4', 'http://image.tmdb.org/t/p/w1280/fRIyw8IKQWUsuhrpVx3gfAN5Sq.jpg'),
(100938, 7180, 'Extrapolations - Um Futuro Inquietante S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211851.mp4', 'http://image.tmdb.org/t/p/w1280/hBUI4smZ8olFLHpdLt6UXxxNeP7.jpg'),
(100939, 7180, 'Extrapolations - Um Futuro Inquietante S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211852.mp4', 'http://image.tmdb.org/t/p/w1280/brOX5z288EdPTFChnYHYuPT2Ke1.jpg'),
(100940, 7180, 'Extrapolations - Um Futuro Inquietante S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211853.mp4', 'http://image.tmdb.org/t/p/w1280/LyKMy1NrR6TIqmIIMI3fNGZRCJ.jpg'),
(100941, 7180, 'Extrapolations - Um Futuro Inquietante S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211854.mp4', 'http://image.tmdb.org/t/p/w1280/mwsYvVz3dg458O0TK27qRU2kZx2.jpg'),
(100942, 7181, 'O Maestro e o Mar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yxCgqq8K8Ga3Pw2b6Oj5Pv5LQba.jpg'),
(100943, 7181, 'O Maestro e o Mar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEnbGzCCl5oRb88RCin66yxnDVu.jpg'),
(100944, 7181, 'O Maestro e o Mar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6GLLIIPiD1jQlvOBAOLVyVUaJZ3.jpg'),
(100945, 7181, 'O Maestro e o Mar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eWF5DLddZuhkifMiMMpvP9CyxYz.jpg'),
(100946, 7181, 'O Maestro e o Mar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/LwCM4FZd8gsXHjCuAs9gzRJ38l.jpg'),
(100947, 7181, 'O Maestro e o Mar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d4MPuWGB6d6NXuPHdbeCFFl1mMF.jpg'),
(100948, 7181, 'O Maestro e o Mar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dbgsLCSsZqk8TjK7CddsjhBZTIE.jpg'),
(100949, 7181, 'O Maestro e o Mar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lO8Lpm9HXBOogav9HJblwlyEurl.jpg'),
(100950, 7181, 'O Maestro e o Mar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lLMZvjbqZYPSEGkHdoj4NDzQ2oA.jpg'),
(100951, 7182, 'O Maestro e o Mar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/356109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6lacPlstK6mcdu3tYAj5GXmJJZR.jpg'),
(100952, 7182, 'O Maestro e o Mar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/356110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6lacPlstK6mcdu3tYAj5GXmJJZR.jpg'),
(100953, 7182, 'O Maestro e o Mar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/356111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6lacPlstK6mcdu3tYAj5GXmJJZR.jpg'),
(100954, 7182, 'O Maestro e o Mar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/356112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6lacPlstK6mcdu3tYAj5GXmJJZR.jpg'),
(100955, 7182, 'O Maestro e o Mar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/356113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6lacPlstK6mcdu3tYAj5GXmJJZR.jpg'),
(100956, 7182, 'O Maestro e o Mar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/356114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6lacPlstK6mcdu3tYAj5GXmJJZR.jpg'),
(100957, 7183, 'O Maestro e o Mar S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/658948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6lacPlstK6mcdu3tYAj5GXmJJZR.jpg'),
(100958, 7183, 'O Maestro e o Mar S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/658949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6lacPlstK6mcdu3tYAj5GXmJJZR.jpg'),
(100959, 7183, 'O Maestro e o Mar S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/658950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6lacPlstK6mcdu3tYAj5GXmJJZR.jpg'),
(100960, 7183, 'O Maestro e o Mar S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/658951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6lacPlstK6mcdu3tYAj5GXmJJZR.jpg'),
(100961, 7184, 'Sem Rastros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/peYmFIMwAcMX9fJ8PjWyWg2XenD.jpg'),
(100962, 7184, 'Sem Rastros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5YYbFG1buRK1kdm9WlWhsxPdzE2.jpg'),
(100963, 7184, 'Sem Rastros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4EYN2cPzJutb3SLlBNVmowHFdP5.jpg'),
(100964, 7184, 'Sem Rastros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9215i40l2zi5ge7Cs2S9i0QtxfZ.jpg'),
(100965, 7184, 'Sem Rastros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A8P6bNd3YIvcjdMOSQIsPPSuNIL.jpg'),
(100966, 7184, 'Sem Rastros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fJgahL7brsJOwBAgW5ZZk0daL6E.jpg'),
(100967, 7184, 'Sem Rastros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzPE5Dy8NJkJ38WNqZZkpzOJY9.jpg'),
(100968, 7184, 'Sem Rastros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gkdOn5LACsAZdktgCZ2DBvnLSvb.jpg'),
(100969, 7185, 'Teto Para Dois S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bcFGWmhj1Fzobx1mtYBwQx7lT2U.jpg'),
(100970, 7185, 'Teto Para Dois S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bcFGWmhj1Fzobx1mtYBwQx7lT2U.jpg'),
(100971, 7185, 'Teto Para Dois S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bcFGWmhj1Fzobx1mtYBwQx7lT2U.jpg'),
(100972, 7185, 'Teto Para Dois S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bcFGWmhj1Fzobx1mtYBwQx7lT2U.jpg'),
(100973, 7185, 'Teto Para Dois S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bcFGWmhj1Fzobx1mtYBwQx7lT2U.jpg'),
(100974, 7185, 'Teto Para Dois S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bcFGWmhj1Fzobx1mtYBwQx7lT2U.jpg'),
(100975, 7186, 'Amor e Honra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7WMhfX56ZW0bkTF4DsGn007MF6I.jpg'),
(100976, 7186, 'Amor e Honra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tt5kdqXMKpKzmoPVp42t4ouOYgu.jpg'),
(100977, 7186, 'Amor e Honra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qmFdwfO0Yc97rHhrKUQK9Htf4ey.jpg'),
(100978, 7186, 'Amor e Honra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aM6Vy42TGeb3144SWC7qeib8MPF.jpg'),
(100979, 7186, 'Amor e Honra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vZOvSlIjLR470DaBLk28mDdy3hY.jpg'),
(100980, 7186, 'Amor e Honra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v8ufHEcGGugumrj3DjilpKp9Ahx.jpg'),
(100981, 7186, 'Amor e Honra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jwAjIBUExppNFZTnpq376F7FgPb.jpg'),
(100982, 7186, 'Amor e Honra S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hbCkdmiLzfQ55WENMHGL9uQERvl.jpg'),
(100983, 7186, 'Amor e Honra S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/95GHCif2VYnMlY7Cedfw8RusdCX.jpg'),
(100984, 7186, 'Amor e Honra S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVl5QlioeaZirB7WCbnWrEri7S5.jpg'),
(100985, 7186, 'Amor e Honra S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVl5QlioeaZirB7WCbnWrEri7S5.jpg'),
(100986, 7186, 'Amor e Honra S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVl5QlioeaZirB7WCbnWrEri7S5.jpg'),
(100987, 7186, 'Amor e Honra S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVl5QlioeaZirB7WCbnWrEri7S5.jpg'),
(100988, 7186, 'Amor e Honra S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVl5QlioeaZirB7WCbnWrEri7S5.jpg'),
(100989, 7186, 'Amor e Honra S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVl5QlioeaZirB7WCbnWrEri7S5.jpg'),
(100990, 7186, 'Amor e Honra S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVl5QlioeaZirB7WCbnWrEri7S5.jpg'),
(100991, 7186, 'Amor e Honra S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVl5QlioeaZirB7WCbnWrEri7S5.jpg'),
(100992, 7186, 'Amor e Honra S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVl5QlioeaZirB7WCbnWrEri7S5.jpg'),
(100993, 7186, 'Amor e Honra S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVl5QlioeaZirB7WCbnWrEri7S5.jpg'),
(100994, 7186, 'Amor e Honra S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVl5QlioeaZirB7WCbnWrEri7S5.jpg'),
(100995, 7186, 'Amor e Honra S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVl5QlioeaZirB7WCbnWrEri7S5.jpg'),
(100996, 7186, 'Amor e Honra S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVl5QlioeaZirB7WCbnWrEri7S5.jpg'),
(100997, 7186, 'Amor e Honra S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/212781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVl5QlioeaZirB7WCbnWrEri7S5.jpg'),
(100998, 7186, 'Amor e Honra S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/212782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVl5QlioeaZirB7WCbnWrEri7S5.jpg'),
(100999, 7186, 'Amor e Honra S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/212783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVl5QlioeaZirB7WCbnWrEri7S5.jpg'),
(101000, 7186, 'Amor e Honra S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/212784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVl5QlioeaZirB7WCbnWrEri7S5.jpg'),
(101001, 7186, 'Amor e Honra S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/212785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVl5QlioeaZirB7WCbnWrEri7S5.jpg'),
(101002, 7186, 'Amor e Honra S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/212786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVl5QlioeaZirB7WCbnWrEri7S5.jpg'),
(101003, 7186, 'Amor e Honra S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/212787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVl5QlioeaZirB7WCbnWrEri7S5.jpg'),
(101004, 7186, 'Amor e Honra S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/212788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jVl5QlioeaZirB7WCbnWrEri7S5.jpg'),
(101005, 7187, 'Go! Viva do seu jeito S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svEmRZN5Tg3G36wYpbpqxPDUSUs.jpg'),
(101006, 7187, 'Go! Viva do seu jeito S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ATWXyeXT1uoKSTd0YyrNXdYuSW.jpg'),
(101007, 7187, 'Go! Viva do seu jeito S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dF4xKmjk514HAo4yrlgkXoMuFaK.jpg'),
(101008, 7187, 'Go! Viva do seu jeito S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qv7DzTwIwOAVeUIvyWaNX5ioIuQ.jpg'),
(101009, 7187, 'Go! Viva do seu jeito S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a5gGFvXP7ARXG5eIVYwZbyQpWRe.jpg'),
(101010, 7187, 'Go! Viva do seu jeito S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pTaaJRUKHHnPVUFCnvvp2diO1VW.jpg'),
(101011, 7187, 'Go! Viva do seu jeito S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnzDHjc22c8Z3jAYJZX1fzEkiF1.jpg'),
(101012, 7187, 'Go! Viva do seu jeito S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vcojDQ92BPtpwGYmwPUkxIElSYl.jpg'),
(101013, 7187, 'Go! Viva do seu jeito S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ab2kmInoDrSW7oE3wDHfXbOgQSy.jpg'),
(101014, 7187, 'Go! Viva do seu jeito S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3hIMVxCJtcD9oqCPbkJqRAfVoy9.jpg'),
(101015, 7187, 'Go! Viva do seu jeito S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/209356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/18OCtRTMnRdVk6rKavFxBELt2Zy.jpg'),
(101016, 7187, 'Go! Viva do seu jeito S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/209357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZe4hSo5UnyYhkNRNMWRbLgAe7c.jpg'),
(101017, 7187, 'Go! Viva do seu jeito S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/209358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nxOQtdQUcUlX2oCHdVePSOyzlOc.jpg'),
(101018, 7187, 'Go! Viva do seu jeito S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/209359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a2JaaCm1l61aq4NSYVb46Udw5ao.jpg'),
(101019, 7187, 'Go! Viva do seu jeito S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/209360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/twsXYlOal6SX6VVNVhoBIJiyavn.jpg'),
(101020, 7188, 'Go! Viva do seu jeito S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmTgIJhMT5Hc7pzmRUQmRNa09GA.jpg'),
(101021, 7188, 'Go! Viva do seu jeito S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmTgIJhMT5Hc7pzmRUQmRNa09GA.jpg'),
(101022, 7188, 'Go! Viva do seu jeito S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmTgIJhMT5Hc7pzmRUQmRNa09GA.jpg'),
(101023, 7188, 'Go! Viva do seu jeito S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmTgIJhMT5Hc7pzmRUQmRNa09GA.jpg'),
(101024, 7188, 'Go! Viva do seu jeito S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmTgIJhMT5Hc7pzmRUQmRNa09GA.jpg'),
(101025, 7188, 'Go! Viva do seu jeito S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmTgIJhMT5Hc7pzmRUQmRNa09GA.jpg'),
(101026, 7188, 'Go! Viva do seu jeito S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmTgIJhMT5Hc7pzmRUQmRNa09GA.jpg'),
(101027, 7188, 'Go! Viva do seu jeito S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmTgIJhMT5Hc7pzmRUQmRNa09GA.jpg'),
(101028, 7188, 'Go! Viva do seu jeito S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmTgIJhMT5Hc7pzmRUQmRNa09GA.jpg'),
(101029, 7188, 'Go! Viva do seu jeito S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmTgIJhMT5Hc7pzmRUQmRNa09GA.jpg'),
(101030, 7188, 'Go! Viva do seu jeito S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/209371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmTgIJhMT5Hc7pzmRUQmRNa09GA.jpg'),
(101031, 7188, 'Go! Viva do seu jeito S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/209372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmTgIJhMT5Hc7pzmRUQmRNa09GA.jpg'),
(101032, 7188, 'Go! Viva do seu jeito S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/209373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmTgIJhMT5Hc7pzmRUQmRNa09GA.jpg'),
(101033, 7188, 'Go! Viva do seu jeito S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/209374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmTgIJhMT5Hc7pzmRUQmRNa09GA.jpg'),
(101034, 7188, 'Go! Viva do seu jeito S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/209375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmTgIJhMT5Hc7pzmRUQmRNa09GA.jpg'),
(101035, 7188, 'Go! Viva do seu jeito S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/209376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmTgIJhMT5Hc7pzmRUQmRNa09GA.jpg'),
(101036, 7189, 'Amores Roubados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/97szk7pLswdSAIn0fRL7y6SzglH.jpg'),
(101037, 7189, 'Amores Roubados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/97szk7pLswdSAIn0fRL7y6SzglH.jpg'),
(101038, 7189, 'Amores Roubados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/97szk7pLswdSAIn0fRL7y6SzglH.jpg'),
(101039, 7189, 'Amores Roubados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/97szk7pLswdSAIn0fRL7y6SzglH.jpg'),
(101040, 7189, 'Amores Roubados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/97szk7pLswdSAIn0fRL7y6SzglH.jpg'),
(101041, 7189, 'Amores Roubados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/97szk7pLswdSAIn0fRL7y6SzglH.jpg'),
(101042, 7189, 'Amores Roubados S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/97szk7pLswdSAIn0fRL7y6SzglH.jpg'),
(101043, 7189, 'Amores Roubados S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/97szk7pLswdSAIn0fRL7y6SzglH.jpg'),
(101044, 7189, 'Amores Roubados S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/97szk7pLswdSAIn0fRL7y6SzglH.jpg'),
(101045, 7189, 'Amores Roubados S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/97szk7pLswdSAIn0fRL7y6SzglH.jpg'),
(101046, 7190, 'A Casa da Raven S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zT3UpbiAliXxw7kmtVpEC0klCK1.jpg'),
(101047, 7190, 'A Casa da Raven S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fxBtdlLTe6F6WCAvhUQdeyekx8g.jpg'),
(101048, 7190, 'A Casa da Raven S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/avmhnRb1cWQfLoFKD0DrtxoxsM7.jpg'),
(101049, 7190, 'A Casa da Raven S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9r4cVEpHI7AMeyLSlsnCetMfzkm.jpg'),
(101050, 7190, 'A Casa da Raven S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/efz4ixIx5jctYnFjpibsYJY9B2I.jpg'),
(101051, 7190, 'A Casa da Raven S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/isNPiSgl4KUOzpRt3p8V7BQjB6C.jpg'),
(101052, 7190, 'A Casa da Raven S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p99ZmqSBWQmVMumQmWo9E4plgHF.jpg'),
(101053, 7190, 'A Casa da Raven S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zAIaqijCXiQUuc8Da3wqnpqCTMz.jpg'),
(101054, 7190, 'A Casa da Raven S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rPOGQ4wR3eVcum5ouFnWbeVlwSG.jpg'),
(101055, 7190, 'A Casa da Raven S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p0IuNHWbVk6n5kPw4fuVQQxSjhf.jpg'),
(101056, 7190, 'A Casa da Raven S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/moBi5b1VrhfiaYRzkenS459vyNA.jpg'),
(101057, 7190, 'A Casa da Raven S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s8OYFzNCYfySjFlybOMVmx3kskv.jpg'),
(101058, 7190, 'A Casa da Raven S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/246735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mXpRjMItyF60sQ4UDGdmwoh6Y92.jpg'),
(101059, 7191, 'A Casa da Raven S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9gFz4mLUGpWAtph1eQnLfHIX2yB.jpg'),
(101060, 7191, 'A Casa da Raven S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/llP4YaVqvzJG9pyq7oXkEx4mT73.jpg'),
(101061, 7191, 'A Casa da Raven S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bTCP3yxgJybZnpbuLeym9Hw5R3N.jpg'),
(101062, 7191, 'A Casa da Raven S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AjAJ2Qoy9YBxQl56iCRvDdTpze9.jpg'),
(101063, 7191, 'A Casa da Raven S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l1NFkB1HG3lTlo8SvxwNQtzBhDM.jpg'),
(101064, 7191, 'A Casa da Raven S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oYenOv6JEl8KJ7pXUqtFuMAyfQB.jpg'),
(101065, 7191, 'A Casa da Raven S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2QZegAZ7ILF8nkGMhR3T1qcNIe.jpg'),
(101066, 7191, 'A Casa da Raven S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ML3zrTJeFB7jV2fz9Wx1XQNaKu.jpg'),
(101067, 7191, 'A Casa da Raven S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qLF2QUUit0vk1fEr0IZexEedUs0.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(101068, 7191, 'A Casa da Raven S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8mmjpvLIbWlGvBGwguSeWmIK5hy.jpg'),
(101069, 7191, 'A Casa da Raven S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmhsPiVeuAPYOfXVIaP5eisYsYe.jpg'),
(101070, 7191, 'A Casa da Raven S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ale64TRlhNv5C8HoNZdqoxMRSaR.jpg'),
(101071, 7191, 'A Casa da Raven S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/246748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/orngw7E4CQU2R4tHvSIm7cbdu5x.jpg'),
(101072, 7191, 'A Casa da Raven S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/246749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j1fRZFcRBV5jVXeYIbveMV3REmi.jpg'),
(101073, 7191, 'A Casa da Raven S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/246750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lN8ImfgPe5pBtUnDv0mbC60hpN7.jpg'),
(101074, 7191, 'A Casa da Raven S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/246751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/27h49n7lLmY3egrSx3debeVwuLF.jpg'),
(101075, 7191, 'A Casa da Raven S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/246752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8BbQcJDxU7lExDnKHNrpjt50cPj.jpg'),
(101076, 7191, 'A Casa da Raven S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/246753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x6UB6oswpthhfkcQA2JLcEzOy84.jpg'),
(101077, 7191, 'A Casa da Raven S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/246754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qkfGwe2W9K4GK11gxkPZReAF7mm.jpg'),
(101078, 7191, 'A Casa da Raven S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/246755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/92ZERwLuXX9kkwcrRKus1C7lzML.jpg'),
(101079, 7191, 'A Casa da Raven S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/246756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJfzfDoxMiI6uQqDCsWig97Zp45.jpg'),
(101080, 7192, 'A Casa da Raven S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Q82chDk6sT6UzsLa21Qz1rQGvz.jpg'),
(101081, 7192, 'A Casa da Raven S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o4erecJTuyZX96juEa6YB0hiQ8g.jpg'),
(101082, 7192, 'A Casa da Raven S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8im1dKEISaXxQDlBrdpaOadOdpv.jpg'),
(101083, 7192, 'A Casa da Raven S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ePDtaJ8RgebeYx08uttLp2zE2j3.jpg'),
(101084, 7192, 'A Casa da Raven S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbwoiFbz4V8KCXBuyV8IZuJALiq.jpg'),
(101085, 7192, 'A Casa da Raven S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2FqFHRh23Yid2F0CeMh8QWOqOSM.jpg'),
(101086, 7192, 'A Casa da Raven S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g0B9qXTg9qAjK24Syt7VRfnvqGI.jpg'),
(101087, 7192, 'A Casa da Raven S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7u3t1FBvx2wLhjbWFmqd7STbvUC.jpg'),
(101088, 7192, 'A Casa da Raven S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tZShE2aahu0eijhxwW1HhLnkYST.jpg'),
(101089, 7192, 'A Casa da Raven S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lx0CgqK2AxYRs4q8QKkyDy9VRuZ.jpg'),
(101090, 7192, 'A Casa da Raven S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTRPUGAsxfBYUArVaL7gBzxRBuz.jpg'),
(101091, 7192, 'A Casa da Raven S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rRvtHlHL7Wo7IqE02SROmp351lv.jpg'),
(101092, 7192, 'A Casa da Raven S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/246769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7yYVGAYqq1040oiUfagHLGRDLwE.jpg'),
(101093, 7192, 'A Casa da Raven S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/246770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/co27zhwod7bARB34nnqxJrdVir7.jpg'),
(101094, 7192, 'A Casa da Raven S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/246771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3g1vYEYSrNMoQXbh6bqqwPXvnwB.jpg'),
(101095, 7192, 'A Casa da Raven S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/246772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ohBXsuGE4RlJPSfZ6voFrw5urmy.jpg'),
(101096, 7192, 'A Casa da Raven S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/246773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6HNzBzJ1fWAxe1xeSjjirhdf3W8.jpg'),
(101097, 7192, 'A Casa da Raven S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/246774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s8JkEHHwPEstfT87C4iEY8A1lLP.jpg'),
(101098, 7192, 'A Casa da Raven S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/246775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bkcBWKVVWV5AZoS87tsOl6XgxZE.jpg'),
(101099, 7192, 'A Casa da Raven S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/246776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pytsVItwAYYmsfeoEwNF4eiO28c.jpg'),
(101100, 7192, 'A Casa da Raven S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/246777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dye5bfr4V5jfWE26E0tTtOgblpm.jpg'),
(101101, 7192, 'A Casa da Raven S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/246778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wxttItttz1E3iljkYdQrtv5PZrL.jpg'),
(101102, 7192, 'A Casa da Raven S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/246779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hnn0bmYyJc3GqhFwqJAd5b4fmVV.jpg'),
(101103, 7192, 'A Casa da Raven S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/246780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/60n1bXavwhTIdYOWIYKnAwiLXjp.jpg'),
(101104, 7192, 'A Casa da Raven S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/246781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgWH1Y7hgzfQ0E7hbE2JgIOW7vl.jpg'),
(101105, 7192, 'A Casa da Raven S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/246782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Wt5ErQB85KU2X2fJdl0CkZ6UHe.jpg'),
(101106, 7193, 'A Casa da Raven S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tSRRuPs63mvXzbKjIqWZrYLm0GZ.jpg'),
(101107, 7193, 'A Casa da Raven S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/932yKSNM9Ms6nhXQ88wAZVAStp5.jpg'),
(101108, 7193, 'A Casa da Raven S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gLGKz4X8yWmWPF49eFSAvhJC56b.jpg'),
(101109, 7193, 'A Casa da Raven S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvDkKk86CFFSo2h7pD0eiq4kqB7.jpg'),
(101110, 7193, 'A Casa da Raven S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c4ZmOzncXVUCSFXbmg24lo1U1LO.jpg'),
(101111, 7193, 'A Casa da Raven S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/43hsUx5gF7dMZW7CmfxpPuqGmmz.jpg'),
(101112, 7193, 'A Casa da Raven S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x1bkXj3O2zAFV07eLPiZ23oGKqr.jpg'),
(101113, 7193, 'A Casa da Raven S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m4TNSHzug98I031XNJrmLQ1QbVg.jpg'),
(101114, 7193, 'A Casa da Raven S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9lsIYXu27hmGl5APnz8XFbMyIlc.jpg'),
(101115, 7193, 'A Casa da Raven S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y3Q8BihDx1KXLNlzL8xaKSIDGKs.jpg'),
(101116, 7193, 'A Casa da Raven S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZdkSp20pQewfxL2inDhHzcvBIH.jpg'),
(101117, 7193, 'A Casa da Raven S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fcA8MsxRboVzxMQdIGmLNkBMkDQ.jpg'),
(101118, 7193, 'A Casa da Raven S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/246795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tZho2q2ItgJJYsXsr8jG7qGgdHm.jpg'),
(101119, 7193, 'A Casa da Raven S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/246796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7OekJEMakUEkxjqwjd7xKpRVxac.jpg'),
(101120, 7193, 'A Casa da Raven S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/246797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eeQEm8SzDqmbcjhNQLZZc2xTzv9.jpg'),
(101121, 7193, 'A Casa da Raven S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/246798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Q4Wt3NJ0Qifpeks6IyiBU9a8u0.jpg'),
(101122, 7193, 'A Casa da Raven S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/246799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b6DE0ofBvnpFspMocWEefb4Up7N.jpg'),
(101123, 7193, 'A Casa da Raven S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/246800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ylJALdHtcr0JawxAH0FXjrpgVhh.jpg'),
(101124, 7193, 'A Casa da Raven S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/246801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r3Ecnvm0rjif5Flpiq63LBTMES9.jpg'),
(101125, 7193, 'A Casa da Raven S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/246802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t7oI80nEez9xWoY1NBbTixPc41o.jpg'),
(101126, 7194, 'A Casa da Raven S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9LjgGoo84DT5C3THehAsUO0OZkC.jpg'),
(101127, 7194, 'A Casa da Raven S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bxyeyTh1BRUsUfYkfQx1ddss0D1.jpg'),
(101128, 7194, 'A Casa da Raven S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Ke5WXKCL6qvMz4JcAIth61YyOE.jpg'),
(101129, 7194, 'A Casa da Raven S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wybqUWAZtXXJtNA7TnxXnprT2wl.jpg'),
(101130, 7194, 'A Casa da Raven S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dMToQUmXD4YVBCO4HzmMsS1iC4W.jpg'),
(101131, 7194, 'A Casa da Raven S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xgjFme9qt9UahEg7pzUJlvBgAVi.jpg'),
(101132, 7194, 'A Casa da Raven S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iw6mkoeFltIOs97cvVjiFqZynax.jpg'),
(101133, 7194, 'A Casa da Raven S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/39iRh3Qsf7GR0odxofbceIBpHY3.jpg'),
(101134, 7194, 'A Casa da Raven S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t7oI80nEez9xWoY1NBbTixPc41o.jpg'),
(101135, 7194, 'A Casa da Raven S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t7oI80nEez9xWoY1NBbTixPc41o.jpg'),
(101136, 7194, 'A Casa da Raven S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t7oI80nEez9xWoY1NBbTixPc41o.jpg'),
(101137, 7194, 'A Casa da Raven S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t7oI80nEez9xWoY1NBbTixPc41o.jpg'),
(101138, 7194, 'A Casa da Raven S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/246815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t7oI80nEez9xWoY1NBbTixPc41o.jpg'),
(101139, 7194, 'A Casa da Raven S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/246816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2iR9LOLJhRg4rAKWrn0AEHDRiUA.jpg'),
(101140, 7194, 'A Casa da Raven S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/246817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9mpvaPtKBnNb6LQaAECyk0CQsPc.jpg'),
(101141, 7194, 'A Casa da Raven S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/246818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/chveSMu1eSs2ZAVUYeQT2Yp23Ml.jpg'),
(101142, 7194, 'A Casa da Raven S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/246819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yIiKY4oqYcuJ9eMwngHrEmcm1eU.jpg'),
(101143, 7194, 'A Casa da Raven S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/246820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kyGGvoSzZaEFSriBMmBSwpZWgm8.jpg'),
(101144, 7194, 'A Casa da Raven S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/246821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v1hJ8tQYc9WvR7cmzWHnrYb54Zv.jpg'),
(101145, 7194, 'A Casa da Raven S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/246822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t6FZSzT7TBqhkFb0ImHp4bTkLJb.jpg'),
(101146, 7194, 'A Casa da Raven S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/246823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zGw9mQ7G4k2wUEuHFBmM0O2TyIY.jpg'),
(101147, 7194, 'A Casa da Raven S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/246824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rzzKxFlPHIdk5tFsiFUWND8VGNy.jpg'),
(101148, 7194, 'A Casa da Raven S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/246825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/huUBE2mtDZealrTcXVOX6sA8SHp.jpg'),
(101149, 7194, 'A Casa da Raven S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/246826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t7oI80nEez9xWoY1NBbTixPc41o.jpg'),
(101150, 7194, 'A Casa da Raven S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/246827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t7oI80nEez9xWoY1NBbTixPc41o.jpg'),
(101151, 7195, 'A Casa da Raven S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kKw2vZfDseXyklzmupDbsN8JyPu.jpg'),
(101152, 7195, 'A Casa da Raven S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wip7HHtckbRux7ZIHPvTzjmOULt.jpg'),
(101153, 7195, 'A Casa da Raven S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pczAoeArpo9O4sNOMb8ddPLo5W8.jpg'),
(101154, 7195, 'A Casa da Raven S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sNufoQFIGMot6a3BAeOvffMwbq.jpg'),
(101155, 7195, 'A Casa da Raven S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7nH8IupnVm5OkACMpGbsCcC9zO.jpg'),
(101156, 7195, 'A Casa da Raven S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t7oI80nEez9xWoY1NBbTixPc41o.jpg'),
(101157, 7195, 'A Casa da Raven S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t7oI80nEez9xWoY1NBbTixPc41o.jpg'),
(101158, 7195, 'A Casa da Raven S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3tNnPtbsMNGI1vlZ4II4raVufpO.jpg'),
(101159, 7195, 'A Casa da Raven S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iKYrn6vlNcHNs9QcPKRZxtPdLow.jpg'),
(101160, 7195, 'A Casa da Raven S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xX6W9hDfG9KtBEUCX2ArMC3KmGp.jpg'),
(101161, 7195, 'A Casa da Raven S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6YD37GqjtGqi54gyXag089w7NT5.jpg'),
(101162, 7195, 'A Casa da Raven S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3U5DJ6eHF4ObmcRkjfbs0Nwkl4l.jpg'),
(101163, 7195, 'A Casa da Raven S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/246840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1zNqT61s9jaYDzFqvKzBOTl7n6I.jpg'),
(101164, 7195, 'A Casa da Raven S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/246841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yg6JevZIQTEciNIxfLmKEMvOk5j.jpg'),
(101165, 7195, 'A Casa da Raven S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/246842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t7oI80nEez9xWoY1NBbTixPc41o.jpg'),
(101166, 7195, 'A Casa da Raven S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/246843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t7oI80nEez9xWoY1NBbTixPc41o.jpg'),
(101167, 7195, 'A Casa da Raven S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/246844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t7oI80nEez9xWoY1NBbTixPc41o.jpg'),
(101168, 7195, 'A Casa da Raven S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/246845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t7oI80nEez9xWoY1NBbTixPc41o.jpg'),
(101169, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209017.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101170, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209018.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101171, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209019.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101172, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209020.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101173, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209021.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101174, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209022.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101175, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209023.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101176, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209024.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101177, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209025.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101178, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209026.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101179, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/209027.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101180, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/209028.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101181, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/209029.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101182, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/209030.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101183, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/209031.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101184, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/209032.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101185, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/209033.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101186, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/209034.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101187, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/209035.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101188, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/209036.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101189, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/209037.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101190, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/209038.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101191, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/209039.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101192, 7196, 'A Vida Interior Com o Padre Paulo Ricardo S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/209040.mp4', 'https://i.bj-share.info/ad4128dae1dbafea48dac0a3724ab9eb.png'),
(101193, 7197, 'Amor nas Alturas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g4tKZWpwovuO1A09siEy9iiCgAn.jpg'),
(101194, 7197, 'Amor nas Alturas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hHBk2b9Dknx0dt1vranurbFaK0Z.jpg'),
(101195, 7197, 'Amor nas Alturas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBCHm1dJTKA8CBg4uHHGTGaxrMR.jpg'),
(101196, 7197, 'Amor nas Alturas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/adgoAdRLiL8AI3ISg6wcIhabIkn.jpg'),
(101197, 7197, 'Amor nas Alturas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4U0o8PIB0La722nH3sB9uL6V4sX.jpg'),
(101198, 7197, 'Amor nas Alturas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kF12nu1ZwYsZe2yJRrzgtmZ8Ao9.jpg'),
(101199, 7197, 'Amor nas Alturas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/chqHlZ90JZscHxqpmrBj5BzPcg6.jpg'),
(101200, 7197, 'Amor nas Alturas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/209016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ua754dRm0qIhre8bW6fJgEIniAQ.jpg'),
(101201, 7198, 'Até o Céu: A Série S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/209002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4QxmchkYq8a9OzksDaFcnPWF80P.jpg'),
(101202, 7198, 'Até o Céu: A Série S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/209003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sox4gTEa6nAmy5MxQMktlJqZGHB.jpg'),
(101203, 7198, 'Até o Céu: A Série S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/209004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svI0Ro3auZP2AVhruq6X4L0Cecq.jpg'),
(101204, 7198, 'Até o Céu: A Série S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/209005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aiNvXDHzlj8dKpiMg5rzneFmfbM.jpg'),
(101205, 7198, 'Até o Céu: A Série S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/209006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2KtzWNPtHgs25koD6adZLJ0Zoyi.jpg'),
(101206, 7198, 'Até o Céu: A Série S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/209007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2RA3XvDF0mWUEr8HSRSaC9i8bqb.jpg'),
(101207, 7198, 'Até o Céu: A Série S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/209008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fqdAXYI1RKgnH3Tk9lrwd7gXV31.jpg'),
(101208, 7199, 'BBB Tá On S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dFAzVMwHq2NlU0J9XknRfzobeOi.jpg'),
(101209, 7199, 'BBB Tá On S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dFAzVMwHq2NlU0J9XknRfzobeOi.jpg'),
(101210, 7199, 'BBB Tá On S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dFAzVMwHq2NlU0J9XknRfzobeOi.jpg'),
(101211, 7199, 'BBB Tá On S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dFAzVMwHq2NlU0J9XknRfzobeOi.jpg'),
(101212, 7199, 'BBB Tá On S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dFAzVMwHq2NlU0J9XknRfzobeOi.jpg'),
(101213, 7199, 'BBB Tá On S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dFAzVMwHq2NlU0J9XknRfzobeOi.jpg'),
(101214, 7199, 'BBB Tá On S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dFAzVMwHq2NlU0J9XknRfzobeOi.jpg'),
(101215, 7199, 'BBB Tá On S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dFAzVMwHq2NlU0J9XknRfzobeOi.jpg'),
(101216, 7199, 'BBB Tá On S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/209000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dFAzVMwHq2NlU0J9XknRfzobeOi.jpg'),
(101217, 7199, 'BBB Tá On S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/209001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dFAzVMwHq2NlU0J9XknRfzobeOi.jpg'),
(101218, 7200, 'Chuva Negra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mNFZpuZIrQBUp5hTKKvXaJy9Fy.jpg'),
(101219, 7200, 'Chuva Negra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mNFZpuZIrQBUp5hTKKvXaJy9Fy.jpg'),
(101220, 7200, 'Chuva Negra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mNFZpuZIrQBUp5hTKKvXaJy9Fy.jpg'),
(101221, 7200, 'Chuva Negra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mNFZpuZIrQBUp5hTKKvXaJy9Fy.jpg'),
(101222, 7200, 'Chuva Negra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mNFZpuZIrQBUp5hTKKvXaJy9Fy.jpg'),
(101223, 7200, 'Chuva Negra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mNFZpuZIrQBUp5hTKKvXaJy9Fy.jpg'),
(101224, 7200, 'Chuva Negra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mNFZpuZIrQBUp5hTKKvXaJy9Fy.jpg'),
(101225, 7200, 'Chuva Negra S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mNFZpuZIrQBUp5hTKKvXaJy9Fy.jpg'),
(101226, 7200, 'Chuva Negra S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mNFZpuZIrQBUp5hTKKvXaJy9Fy.jpg'),
(101227, 7201, 'Corridas Proibidas: Reis das Pistas: G-8 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/VrCnDV3EIm2rnakytyLi0l6yEe.jpg'),
(101228, 7201, 'Corridas Proibidas: Reis das Pistas: G-8 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e29hotgqW8GhfV3nUpwaR7xigbt.jpg'),
(101229, 7201, 'Corridas Proibidas: Reis das Pistas: G-8 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220570.mp4', 'http://image.tmdb.org/t/p/w1280/xnajnUgGVl8Jq1k6GVcXDTLXjlY.jpg'),
(101230, 7201, 'Corridas Proibidas: Reis das Pistas: G-8 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220571.mp4', 'http://image.tmdb.org/t/p/w1280/6bLGABeXYGSdMMwiYQKb0mnTDYg.jpg'),
(101231, 7201, 'Corridas Proibidas: Reis das Pistas: G-8 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220572.mp4', 'http://image.tmdb.org/t/p/w1280/kul1yMgbvKJdBj225ktZqTlAdKr.jpg'),
(101232, 7201, 'Corridas Proibidas: Reis das Pistas: G-8 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jMF3BDLDGKO1wPUG3Epd6Tze5Yn.jpg'),
(101233, 7201, 'Corridas Proibidas: Reis das Pistas: G-8 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sRAXCDiiTL0bne3M6dMMVmV1WZD.jpg'),
(101234, 7201, 'Corridas Proibidas: Reis das Pistas: G-8 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/61iL8tZIBKDizeRiJEv1gpqdavv.jpg'),
(101235, 7201, 'Corridas Proibidas: Reis das Pistas: G-8 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24MtKxzE4hd3IJc7JfmPqDbmCn8.jpg'),
(101236, 7201, 'Corridas Proibidas: Reis das Pistas: G-8 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220577.mp4', 'http://image.tmdb.org/t/p/w1280/3qqqo8I3CdCTusk9moN9ANQlJ6j.jpg'),
(101237, 7201, 'Corridas Proibidas: Reis das Pistas: G-8 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220578.mp4', 'http://image.tmdb.org/t/p/w1280/aV1m5iWXXQxhqSFBlYyHvcRhYbz.jpg'),
(101238, 7201, 'Corridas Proibidas: Reis das Pistas: G-8 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220579.mp4', 'http://image.tmdb.org/t/p/w1280/p7axQd9rUkPTMXNGeCiL6Bu7v5R.jpg'),
(101239, 7201, 'Corridas Proibidas: Reis das Pistas: G-8 S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a1tUQPhX1lx3ESgkBcU4cxftsg.jpg'),
(101240, 7201, 'Corridas Proibidas: Reis das Pistas: G-8 S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/220581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a1tUQPhX1lx3ESgkBcU4cxftsg.jpg'),
(101241, 7202, 'De Quem Estamos Fugindo? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hnkkJnQleHLQRctR5RxRmLfioP1.jpg'),
(101242, 7202, 'De Quem Estamos Fugindo? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d0XyG7HrI0KzKIyrmgeE7eGR2pQ.jpg'),
(101243, 7202, 'De Quem Estamos Fugindo? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ra4jZsIKKA72rMgQ0TeyMaZLB9L.jpg'),
(101244, 7202, 'De Quem Estamos Fugindo? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vAfqZ28ntBQCDR3QtVkGyUNAxiz.jpg'),
(101245, 7202, 'De Quem Estamos Fugindo? S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7uAJA9KQunoZSuWmVNf7EJlCQey.jpg'),
(101246, 7202, 'De Quem Estamos Fugindo? S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oip6LvWn5NVfZJ1HVyces9mzm7x.jpg'),
(101247, 7202, 'De Quem Estamos Fugindo? S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJ9DrokpUE0kwrlnOeKzXRSfvky.jpg'),
(101248, 7203, 'Destiladores S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d9EVPPkR6dWAKhJMnewyZcyAGVZ.jpg'),
(101249, 7203, 'Destiladores S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/auFF1zYUG9yP9Xq1hr4qjnzXVEG.jpg'),
(101250, 7203, 'Destiladores S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ppW3ldGioeKSRyOKeArRmELbJC.jpg'),
(101251, 7203, 'Destiladores S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tL93bLXbWARhWZVahj16D2D7weh.jpg'),
(101252, 7203, 'Destiladores S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8FXc5MeKUutKOs9HXr9U6ExoWZ5.jpg'),
(101253, 7203, 'Destiladores S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fva5C3EcZHEHLJ44j4dOT1eSYZ3.jpg'),
(101254, 7203, 'Destiladores S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qvBWQd6XTdsudoclNx9jt0ufU3m.jpg'),
(101255, 7203, 'Destiladores S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6P1fAqNBnedfCiFa8kqs678ry9D.jpg'),
(101256, 7203, 'Destiladores S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cxfBk7U6E75qiTcMyrAPpgvaR1m.jpg'),
(101257, 7203, 'Destiladores S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iQAJF1rJRq3uosu4AQYgybzC37Z.jpg'),
(101258, 7203, 'Destiladores S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ospKGDSX7lGYaXfbndDEOVLRWeW.jpg'),
(101259, 7203, 'Destiladores S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kw8wFD8ni4vNrHiCwx5Up5BtrFs.jpg'),
(101260, 7203, 'Destiladores S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z8WgiSpBqCKbB8AfQOlzxC6sME4.jpg'),
(101261, 7203, 'Destiladores S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5hnKK69x0VIHvUhwKH5zDr1gVPX.jpg'),
(101262, 7204, 'Destiladores S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tQbUYwkRcm3ihkcmAvvdgEkIqKI.jpg'),
(101263, 7204, 'Destiladores S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpmzKRVMoFdK6RTmmQyPM2wQZ82.jpg'),
(101264, 7204, 'Destiladores S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1f0lJTrqOrCvG6UsXNwBMtbGHww.jpg'),
(101265, 7204, 'Destiladores S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rcq4wwpzgb6dmeH8urjzEsv5Fxf.jpg'),
(101266, 7204, 'Destiladores S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f3bTf1D2KIMscPO3tncWvA6sbkQ.jpg'),
(101267, 7204, 'Destiladores S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13v1ewgEv1L3bh06ynNzDdU7xnk.jpg'),
(101268, 7204, 'Destiladores S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vlLutNiEAfKP35hZFipQyrLhWvz.jpg'),
(101269, 7204, 'Destiladores S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gzwyEX591cKUdKRIXa0RvfoFnyF.jpg'),
(101270, 7204, 'Destiladores S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eeq4QfUz3dVkiPUuqwx7fLnV2R8.jpg'),
(101271, 7204, 'Destiladores S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vg47O4GrHPrFWptZ3gcLyrBshY8.jpg'),
(101272, 7204, 'Destiladores S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9xswIffuehaQvcPbzEK24KdQBQh.jpg'),
(101273, 7204, 'Destiladores S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qj52R9WHbLoSHHOrneQ1f56jixL.jpg'),
(101274, 7204, 'Destiladores S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qoWX3p4KgKF7aJZ6r2ykeSxNRPf.jpg'),
(101275, 7204, 'Destiladores S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/366POXJxklrUp50oayAiYK6sdWT.jpg'),
(101276, 7204, 'Destiladores S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uyYplwqf4YfRvqhGnd2RiD1fZ7B.jpg'),
(101277, 7204, 'Destiladores S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g0OL09yiibl4MJYlmFt1RpBuYLd.jpg'),
(101278, 7205, 'Destiladores S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ttcA816zKgBpz0Z9GJwMGubuiUS.jpg'),
(101279, 7205, 'Destiladores S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wxHeUnn47P2CImkBAnLxFxXyD26.jpg'),
(101280, 7205, 'Destiladores S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNLP7Tkg7iWfVoXjv6vmtWAQI4X.jpg'),
(101281, 7205, 'Destiladores S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cWigoLfgGZo6p3aChxBLNXQvkPo.jpg'),
(101282, 7205, 'Destiladores S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7v9g34ODY1th5e5pMKS8Q6gtcKz.jpg'),
(101283, 7205, 'Destiladores S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101284, 7205, 'Destiladores S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nVfVarPkva0ZdCPl9BmE8cLGMsC.jpg'),
(101285, 7205, 'Destiladores S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tSnO6lJNJa8CHe4Bcm0ZoIBKkpV.jpg'),
(101286, 7205, 'Destiladores S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j2gUlGeTs2OsOY1EFW7PyZjmVh6.jpg'),
(101287, 7205, 'Destiladores S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vR5axIDU2k6Lqs7HJqguhesdCux.jpg'),
(101288, 7205, 'Destiladores S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bU5iu5GyltiqqGfmHJI6ZUtAb46.jpg'),
(101289, 7205, 'Destiladores S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lB3eo3d7tJEQmKlYYZjOhJfXSgD.jpg'),
(101290, 7205, 'Destiladores S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t9cTzQeaJz8bLwogMGerr4CG8xe.jpg'),
(101291, 7205, 'Destiladores S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqZXj6AYAddWgDR9HFsMXxnKDeo.jpg'),
(101292, 7205, 'Destiladores S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gRc5MvhjL27VEQYaCQHRNsBpPJH.jpg'),
(101293, 7205, 'Destiladores S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJiPDlSm9HLH3RLUt6JDTuYzORS.jpg'),
(101294, 7205, 'Destiladores S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101295, 7205, 'Destiladores S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/234379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101296, 7205, 'Destiladores S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/234380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101297, 7205, 'Destiladores S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/234381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101298, 7205, 'Destiladores S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/234382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101299, 7205, 'Destiladores S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/234383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101300, 7206, 'Destiladores S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bUVXQnYynWWrGMT0diMQaCzZMm6.jpg'),
(101301, 7206, 'Destiladores S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/byIV909CzhhXHKdVCHkKQoPFfVX.jpg'),
(101302, 7206, 'Destiladores S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zaCLJNZdkAoANI9gIbE69dTuBFY.jpg'),
(101303, 7206, 'Destiladores S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUeuRYaFRls7nlIkGPkbaJOpavf.jpg'),
(101304, 7206, 'Destiladores S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m82z8JGwcQO5MCqE45naaCJNIEt.jpg'),
(101305, 7206, 'Destiladores S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6jPq78jJ8KW7vd53JeqThV5mEZZ.jpg'),
(101306, 7206, 'Destiladores S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wfScn5uXf7jY5budkHbed3dXVa9.jpg'),
(101307, 7206, 'Destiladores S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b3laWxHEA0vh4Bq7aN4itpV19Zq.jpg'),
(101308, 7206, 'Destiladores S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/12TTyG2hm1DyArvlsRT4eLqhunk.jpg'),
(101309, 7206, 'Destiladores S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tSUVZKQLvluI0oYMscxPB7MLVfU.jpg'),
(101310, 7206, 'Destiladores S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tlWMp76TAXNt9Q0NvPfnyx1Celj.jpg'),
(101311, 7206, 'Destiladores S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AqFnJe1pz9SABGXWDSlWt9CQG5e.jpg'),
(101312, 7206, 'Destiladores S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQO4OMJhsBqXVWk6xIjYlAkiTK7.jpg'),
(101313, 7206, 'Destiladores S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lE0LIgwBtuJNkktZSApVQ656q39.jpg'),
(101314, 7206, 'Destiladores S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f7bo2wMiZNWfBMDG95pYErTkez4.jpg'),
(101315, 7206, 'Destiladores S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hN4oYE8KlZUDGwMj7Ge7VrUKBOH.jpg'),
(101316, 7206, 'Destiladores S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0LLt8CzD8YvQFBOeXsg3CtHHI9.jpg'),
(101317, 7206, 'Destiladores S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/234401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xPcghRaUTpyVJjblfZxOJyy4Ajy.jpg'),
(101318, 7206, 'Destiladores S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/234402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101319, 7206, 'Destiladores S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/234403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101320, 7206, 'Destiladores S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/234404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101321, 7206, 'Destiladores S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/234405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101322, 7206, 'Destiladores S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/234406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101323, 7207, 'Destiladores S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101324, 7207, 'Destiladores S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101325, 7207, 'Destiladores S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101326, 7207, 'Destiladores S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101327, 7207, 'Destiladores S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101328, 7207, 'Destiladores S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101329, 7207, 'Destiladores S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101330, 7207, 'Destiladores S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(101331, 7207, 'Destiladores S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101332, 7207, 'Destiladores S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101333, 7207, 'Destiladores S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101334, 7207, 'Destiladores S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101335, 7207, 'Destiladores S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101336, 7207, 'Destiladores S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101337, 7207, 'Destiladores S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101338, 7207, 'Destiladores S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101339, 7207, 'Destiladores S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101340, 7207, 'Destiladores S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/234424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101341, 7207, 'Destiladores S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/234425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101342, 7207, 'Destiladores S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/234426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101343, 7207, 'Destiladores S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/234427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101344, 7207, 'Destiladores S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/234428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101345, 7207, 'Destiladores S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/234429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101346, 7207, 'Destiladores S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/234430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101347, 7207, 'Destiladores S08 E25', 'http://sinalprivado.info:80/series/1533784/1533784/234431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101348, 7208, 'Destiladores S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101349, 7208, 'Destiladores S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101350, 7208, 'Destiladores S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101351, 7208, 'Destiladores S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101352, 7208, 'Destiladores S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101353, 7208, 'Destiladores S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101354, 7208, 'Destiladores S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101355, 7208, 'Destiladores S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101356, 7208, 'Destiladores S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101357, 7208, 'Destiladores S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101358, 7208, 'Destiladores S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101359, 7208, 'Destiladores S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101360, 7208, 'Destiladores S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101361, 7208, 'Destiladores S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101362, 7208, 'Destiladores S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101363, 7208, 'Destiladores S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101364, 7208, 'Destiladores S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101365, 7208, 'Destiladores S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/234449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101366, 7208, 'Destiladores S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/234450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101367, 7209, 'Destiladores S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101368, 7209, 'Destiladores S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101369, 7209, 'Destiladores S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101370, 7209, 'Destiladores S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101371, 7209, 'Destiladores S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101372, 7209, 'Destiladores S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101373, 7209, 'Destiladores S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101374, 7209, 'Destiladores S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101375, 7209, 'Destiladores S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101376, 7209, 'Destiladores S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101377, 7209, 'Destiladores S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101378, 7209, 'Destiladores S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101379, 7209, 'Destiladores S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101380, 7209, 'Destiladores S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101381, 7209, 'Destiladores S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101382, 7209, 'Destiladores S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101383, 7209, 'Destiladores S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101384, 7209, 'Destiladores S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/234468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101385, 7209, 'Destiladores S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/234469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101386, 7209, 'Destiladores S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/234470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101387, 7209, 'Destiladores S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/234471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101388, 7209, 'Destiladores S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/234472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101389, 7209, 'Destiladores S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/234473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101390, 7210, 'Destiladores S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101391, 7210, 'Destiladores S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101392, 7210, 'Destiladores S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101393, 7210, 'Destiladores S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101394, 7210, 'Destiladores S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101395, 7210, 'Destiladores S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101396, 7210, 'Destiladores S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101397, 7210, 'Destiladores S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101398, 7210, 'Destiladores S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101399, 7210, 'Destiladores S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101400, 7210, 'Destiladores S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101401, 7210, 'Destiladores S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101402, 7210, 'Destiladores S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101403, 7210, 'Destiladores S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101404, 7210, 'Destiladores S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101405, 7210, 'Destiladores S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101406, 7210, 'Destiladores S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101407, 7210, 'Destiladores S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/234491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101408, 7210, 'Destiladores S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/234492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101409, 7210, 'Destiladores S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/234493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101410, 7210, 'Destiladores S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/234494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101411, 7211, 'Destiladores S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101412, 7211, 'Destiladores S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101413, 7211, 'Destiladores S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101414, 7211, 'Destiladores S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101415, 7211, 'Destiladores S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101416, 7211, 'Destiladores S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101417, 7211, 'Destiladores S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101418, 7211, 'Destiladores S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101419, 7211, 'Destiladores S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101420, 7211, 'Destiladores S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101421, 7211, 'Destiladores S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101422, 7211, 'Destiladores S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101423, 7211, 'Destiladores S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101424, 7211, 'Destiladores S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101425, 7211, 'Destiladores S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101426, 7211, 'Destiladores S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101427, 7211, 'Destiladores S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101428, 7211, 'Destiladores S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/234512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101429, 7211, 'Destiladores S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/234513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101430, 7211, 'Destiladores S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/234514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101431, 7212, 'Destiladores S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/642045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101432, 7212, 'Destiladores S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/642046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101433, 7212, 'Destiladores S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/642047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101434, 7212, 'Destiladores S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/642048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101435, 7212, 'Destiladores S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/642049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101436, 7212, 'Destiladores S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/642050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101437, 7212, 'Destiladores S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/642051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101438, 7212, 'Destiladores S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/642052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101439, 7212, 'Destiladores S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/690847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101440, 7212, 'Destiladores S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/690848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101441, 7212, 'Destiladores S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/706611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101442, 7212, 'Destiladores S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/706612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101443, 7212, 'Destiladores S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/709285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101444, 7212, 'Destiladores S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/710667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101445, 7212, 'Destiladores S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/725120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101446, 7212, 'Destiladores S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/734793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nds4ONB4qbTyo7rmY7bDemB8lLs.jpg'),
(101447, 7213, 'Destiladores: Clássicos Americanos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fK8ywY9y2tNiQnw7uWAlDZrbU0l.jpg'),
(101448, 7213, 'Destiladores: Clássicos Americanos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fK8ywY9y2tNiQnw7uWAlDZrbU0l.jpg'),
(101449, 7213, 'Destiladores: Clássicos Americanos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fK8ywY9y2tNiQnw7uWAlDZrbU0l.jpg'),
(101450, 7213, 'Destiladores: Clássicos Americanos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fK8ywY9y2tNiQnw7uWAlDZrbU0l.jpg'),
(101451, 7213, 'Destiladores: Clássicos Americanos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fK8ywY9y2tNiQnw7uWAlDZrbU0l.jpg'),
(101452, 7214, 'Destino Paranormal: Chamados do Lar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A73mzA5PMbDIYXGnyxDEt3iYdLp.jpg'),
(101453, 7214, 'Destino Paranormal: Chamados do Lar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9fWLjEA1nGQxgrK9XwoKQCi127c.jpg'),
(101454, 7214, 'Destino Paranormal: Chamados do Lar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63qjBhIl5fvTAzEuPIz68YBR6Hw.jpg'),
(101455, 7214, 'Destino Paranormal: Chamados do Lar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/saRLAJyRZNJSjAZMWD7wEgXrTa9.jpg'),
(101456, 7214, 'Destino Paranormal: Chamados do Lar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212188.mp4', 'http://image.tmdb.org/t/p/w1280/40CxagNgvaiVguULS645TShDBqm.jpg'),
(101457, 7214, 'Destino Paranormal: Chamados do Lar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212189.mp4', 'http://image.tmdb.org/t/p/w1280/7JfktMlsXpzSTLqfXoxEh6Rodrh.jpg'),
(101458, 7214, 'Destino Paranormal: Chamados do Lar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212190.mp4', 'http://image.tmdb.org/t/p/w1280/WUUjj7ydvWGyR47Hgrjdd8Gugk.jpg'),
(101459, 7215, 'Doutor Advogado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xLR3NrTUblw238tsGfta4qHqphP.jpg'),
(101460, 7215, 'Doutor Advogado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qa47dUapFY6m7LeMy98bO3EdJSf.jpg'),
(101461, 7215, 'Doutor Advogado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6wry5ukelMBRdSoCDrFhvdVHAlL.jpg'),
(101462, 7215, 'Doutor Advogado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cqNHsmEALuxsyMhSVLgQ8vn0lCy.jpg'),
(101463, 7215, 'Doutor Advogado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tdkIluu9LrzqYan8n4jT0SKSAtz.jpg'),
(101464, 7215, 'Doutor Advogado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pQGhBI7l9YuEMBKv9QnxsS9VFT3.jpg'),
(101465, 7215, 'Doutor Advogado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vTPMMgxfMnT1PD9d5EOunk6I8kL.jpg'),
(101466, 7215, 'Doutor Advogado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Kadw0SmQOTFnCd5C881qmIS0M2.jpg'),
(101467, 7215, 'Doutor Advogado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/syAu23iZHRQ8dxMAF8HDvCyAIlq.jpg'),
(101468, 7215, 'Doutor Advogado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iyHtYcF36N2jlY0pFhv2w9qYOf0.jpg'),
(101469, 7215, 'Doutor Advogado S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMjLxWi2hUJ8WOrGQmt8hx4wkz3.jpg'),
(101470, 7215, 'Doutor Advogado S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jDErMeFgo3D4NiLSU09fa2Q0Yoj.jpg'),
(101471, 7215, 'Doutor Advogado S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/208669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cMfT2Ep3D21l7b8BpT1s1SI3NM9.jpg'),
(101472, 7215, 'Doutor Advogado S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/208670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3HXvd3Uxo9dXJ77sp9KHiSJcJ1L.jpg'),
(101473, 7215, 'Doutor Advogado S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/208671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNHfEBku6pJ62wFIka8xwKsO5cl.jpg'),
(101474, 7215, 'Doutor Advogado S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/208672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n5o8OTu8efa7f5rFBqvkdEsXpZK.jpg'),
(101475, 7216, 'Largados Pelados e Congelados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7f8cGu4v0WL8BGIpKGHs3YCvuL.jpg'),
(101476, 7216, 'Largados Pelados e Congelados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210912.mp4', 'http://image.tmdb.org/t/p/w1280/fGh71o5EiNZZa6Z6mZfLiRBtHU2.jpg'),
(101477, 7216, 'Largados Pelados e Congelados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210913.mp4', 'http://image.tmdb.org/t/p/w1280/w9icTucaQ2LV87obxoRBuKbXSJL.jpg'),
(101478, 7216, 'Largados Pelados e Congelados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210914.mp4', 'http://image.tmdb.org/t/p/w1280/d4LMek3vMDYcbz1FioBtbcC7VkO.jpg'),
(101479, 7216, 'Largados Pelados e Congelados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210915.mp4', 'http://image.tmdb.org/t/p/w1280/xyndKjxf6mjx7iUJWziBmFsOPgD.jpg'),
(101480, 7216, 'Largados Pelados e Congelados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210916.mp4', 'http://image.tmdb.org/t/p/w1280/x5RWVPcY71T5Iuco4YAigMHnUth.jpg'),
(101481, 7217, 'Monarch: O Legado do Country S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b2TbsLXQTir7CvwQ3wOPy8luD94.jpg'),
(101482, 7217, 'Monarch: O Legado do Country S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y7pnWMLvSEp2lM8A4ae7j62wWGC.jpg'),
(101483, 7217, 'Monarch: O Legado do Country S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6nKbzX5xnFO9BvQKjAErXsfmWMk.jpg'),
(101484, 7217, 'Monarch: O Legado do Country S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ifnvRB8DZNtWZnVtYgcpwrFDmRV.jpg'),
(101485, 7217, 'Monarch: O Legado do Country S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ITafLbULaN8GRPMMKY115aVJ4d.jpg'),
(101486, 7217, 'Monarch: O Legado do Country S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bAmZaWwKXrYh02wPLbeVCp6cHIQ.jpg'),
(101487, 7217, 'Monarch: O Legado do Country S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aA1DSWsNG4oaGKecCRYefxZMKM2.jpg'),
(101488, 7217, 'Monarch: O Legado do Country S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tDgPi9ROVS9cBycR3vUiqjJKk5O.jpg'),
(101489, 7217, 'Monarch: O Legado do Country S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kn5qMshAcGIUZcpRUhNvoTu4jbm.jpg'),
(101490, 7217, 'Monarch: O Legado do Country S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5rvOv90sXx3zTflHptYNGGCM1g.jpg'),
(101491, 7217, 'Monarch: O Legado do Country S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ATswPNpPfvOpXuK30obq1dUppB.jpg'),
(101492, 7218, 'O Agente Noturno S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hgSV1g5vuM7arbzvPkSuTHWMbR0.jpg'),
(101493, 7218, 'O Agente Noturno S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gSJQ3KkwUT32etT0oVncI02kAFc.jpg'),
(101494, 7218, 'O Agente Noturno S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMdJo228BLPGWi2UgNcW1MtfZdN.jpg'),
(101495, 7218, 'O Agente Noturno S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9wNFHCEzH5N0bW6fGNJy7oruKJH.jpg'),
(101496, 7218, 'O Agente Noturno S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mniPEXFfrnCwl5R0TciiSsorTVk.jpg'),
(101497, 7218, 'O Agente Noturno S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xGaD0Q7cyU10jKz9VeOQo6ps4cr.jpg'),
(101498, 7218, 'O Agente Noturno S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wsYGWSDNcvHC2ZyZSd2sK1wk5TQ.jpg'),
(101499, 7218, 'O Agente Noturno S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qfIJhEMZR5wBPRpCz0sUjS0bWrg.jpg'),
(101500, 7218, 'O Agente Noturno S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vPCESeXOQG69HV1beYXZvJXMSWp.jpg'),
(101501, 7218, 'O Agente Noturno S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uNA1lmV2OoMyszEp55HasXQkfwX.jpg'),
(101502, 7219, 'O Agente Noturno S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/672360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQ0v0paXyjdackKDt5Mxkzttezq.jpg'),
(101503, 7219, 'O Agente Noturno S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/672362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQ0v0paXyjdackKDt5Mxkzttezq.jpg'),
(101504, 7219, 'O Agente Noturno S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/672364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQ0v0paXyjdackKDt5Mxkzttezq.jpg'),
(101505, 7219, 'O Agente Noturno S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/672366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQ0v0paXyjdackKDt5Mxkzttezq.jpg'),
(101506, 7219, 'O Agente Noturno S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/672368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQ0v0paXyjdackKDt5Mxkzttezq.jpg'),
(101507, 7219, 'O Agente Noturno S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/672370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQ0v0paXyjdackKDt5Mxkzttezq.jpg'),
(101508, 7219, 'O Agente Noturno S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/672372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQ0v0paXyjdackKDt5Mxkzttezq.jpg'),
(101509, 7219, 'O Agente Noturno S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/672373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQ0v0paXyjdackKDt5Mxkzttezq.jpg'),
(101510, 7219, 'O Agente Noturno S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/672374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQ0v0paXyjdackKDt5Mxkzttezq.jpg'),
(101511, 7219, 'O Agente Noturno S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/672375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQ0v0paXyjdackKDt5Mxkzttezq.jpg'),
(101512, 7220, 'O Cerco de Waco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s9REqDdsAWak6VRQS7iKYxqfQf1.jpg'),
(101513, 7220, 'O Cerco de Waco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tagqiooQUg3vKAkTQCVJre90QpI.jpg'),
(101514, 7220, 'O Cerco de Waco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qgKoprznCzvCBvQGtAUlxRFO81M.jpg'),
(101515, 7221, 'Origem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248629.mp4', 'http://timg.bdta.pro/images/226152ecc6e88062076d2459edd7908b.jpg'),
(101516, 7221, 'Origem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248630.mp4', 'http://timg.bdta.pro/images/496fcce8ac498890924514d02d5d70a1.jpg'),
(101517, 7221, 'Origem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248631.mp4', 'http://timg.bdta.pro/images/ab4dbaa505477f1b98b98d8abbceb3c7.jpg'),
(101518, 7221, 'Origem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248632.mp4', 'http://timg.bdta.pro/images/279e6b35a42980dd4294e78153455430.jpg'),
(101519, 7221, 'Origem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248633.mp4', 'http://timg.bdta.pro/images/cbcbf4d3ba6a2244a5d47fc989e13508.jpg'),
(101520, 7221, 'Origem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248634.mp4', 'http://timg.bdta.pro/images/3ff8e16a7c6e60d7a3d651fe988cdcf4.jpg'),
(101521, 7221, 'Origem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248635.mp4', 'http://timg.bdta.pro/images/4ff7be471edcbdc5a0949fd4a616eed1.jpg'),
(101522, 7221, 'Origem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248636.mp4', 'http://timg.bdta.pro/images/138e026dbe26d547d155d0b92b25502c.jpg'),
(101523, 7221, 'Origem S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248637.mp4', 'http://timg.bdta.pro/images/c3dd66daf6bf721f47820f9797237296.jpg'),
(101524, 7221, 'Origem S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248638.mp4', 'http://timg.bdta.pro/images/2e6057e2bed10cf70897b7ad1548eeb9.jpg'),
(101525, 7222, 'Origem S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(101526, 7222, 'Origem S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(101527, 7222, 'Origem S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(101528, 7222, 'Origem S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(101529, 7222, 'Origem S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(101530, 7222, 'Origem S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(101531, 7222, 'Origem S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(101532, 7222, 'Origem S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(101533, 7222, 'Origem S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(101534, 7222, 'Origem S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(101535, 7223, 'Origem S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/694901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(101536, 7223, 'Origem S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/694902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(101537, 7223, 'Origem S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/694903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(101538, 7223, 'Origem S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/694904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(101539, 7223, 'Origem S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/694905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(101540, 7223, 'Origem S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/694906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(101541, 7223, 'Origem S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/694907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(101542, 7223, 'Origem S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/694908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(101543, 7223, 'Origem S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/694909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(101544, 7223, 'Origem S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/694910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(101545, 7224, 'Rabbit Hole: Jogo de Mentiras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/57nPZ72N9wLenZK2O8bdroQVOfq.jpg'),
(101546, 7224, 'Rabbit Hole: Jogo de Mentiras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lpTm8zck4NCOqopbRlB0uI4omqb.jpg'),
(101547, 7224, 'Rabbit Hole: Jogo de Mentiras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210344.mp4', 'http://image.tmdb.org/t/p/w1280/nmKWqEWHgtAnb9P8ZMJjwhfHPFa.jpg'),
(101548, 7224, 'Rabbit Hole: Jogo de Mentiras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6grfM92yBGXt40v7rGlJxjV1nNU.jpg'),
(101549, 7224, 'Rabbit Hole: Jogo de Mentiras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bKpFzCkpHMExteYnt5nlwVRXEsl.jpg'),
(101550, 7224, 'Rabbit Hole: Jogo de Mentiras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210347.mp4', 'http://image.tmdb.org/t/p/w1280/aAfYYMs8kqfeN9qVGXUov6VjTHQ.jpg'),
(101551, 7224, 'Rabbit Hole: Jogo de Mentiras S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210348.mp4', 'http://image.tmdb.org/t/p/w1280/lJzd6JZUl3HRVftlzprmSVifecW.jpg'),
(101552, 7224, 'Rabbit Hole: Jogo de Mentiras S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210349.mp4', 'http://image.tmdb.org/t/p/w1280/wbcRD6mvNCWzjMDgVB4OSg8f1Xy.jpg'),
(101553, 7225, 'Reforma com \"R\" Maiúsculo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qIGnVfD7Eeb9ZObk1nkgwnnJEGZ.jpg'),
(101554, 7225, 'Reforma com \"R\" Maiúsculo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qIGnVfD7Eeb9ZObk1nkgwnnJEGZ.jpg'),
(101555, 7225, 'Reforma com \"R\" Maiúsculo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qIGnVfD7Eeb9ZObk1nkgwnnJEGZ.jpg'),
(101556, 7225, 'Reforma com \"R\" Maiúsculo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qIGnVfD7Eeb9ZObk1nkgwnnJEGZ.jpg'),
(101557, 7225, 'Reforma com \"R\" Maiúsculo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qIGnVfD7Eeb9ZObk1nkgwnnJEGZ.jpg'),
(101558, 7225, 'Reforma com \"R\" Maiúsculo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qIGnVfD7Eeb9ZObk1nkgwnnJEGZ.jpg'),
(101559, 7226, 'Nunca! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kSYZZYGV3mPJrzvMLjlXskzoH9a.jpg'),
(101560, 7226, 'Nunca! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kSYZZYGV3mPJrzvMLjlXskzoH9a.jpg'),
(101561, 7226, 'Nunca! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kSYZZYGV3mPJrzvMLjlXskzoH9a.jpg'),
(101562, 7226, 'Nunca! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kSYZZYGV3mPJrzvMLjlXskzoH9a.jpg'),
(101563, 7227, 'Ringo. Glória e Morte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mPOiw1d5zBqc2zIcPZL7BG0GCQ2.jpg'),
(101564, 7227, 'Ringo. Glória e Morte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/38CHyuUW8mFx3c5Np7KPvtwN8x5.jpg'),
(101565, 7227, 'Ringo. Glória e Morte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1MihvPL1n4hz2xf2hIDqUjE2mB.jpg'),
(101566, 7227, 'Ringo. Glória e Morte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nvHUxkz9NisUDlqt1cvXhoCYpcE.jpg'),
(101567, 7227, 'Ringo. Glória e Morte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uJdgnJJG4ZqpK0GG6l5a1hky6Et.jpg'),
(101568, 7227, 'Ringo. Glória e Morte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0wWJTiiEtz8CoF5Z67tsimgLIb.jpg'),
(101569, 7227, 'Ringo. Glória e Morte S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6SqV3IvWjSu8mEjidlD5vYHpERw.jpg'),
(101570, 7228, 'Se Vira Com Pouco A Batalha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1bEIPRxUztuEvhaGEwK32pkIza5.jpg'),
(101571, 7228, 'Se Vira Com Pouco A Batalha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1bEIPRxUztuEvhaGEwK32pkIza5.jpg'),
(101572, 7228, 'Se Vira Com Pouco A Batalha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1bEIPRxUztuEvhaGEwK32pkIza5.jpg'),
(101573, 7228, 'Se Vira Com Pouco A Batalha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1bEIPRxUztuEvhaGEwK32pkIza5.jpg'),
(101574, 7228, 'Se Vira Com Pouco A Batalha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1bEIPRxUztuEvhaGEwK32pkIza5.jpg'),
(101575, 7228, 'Se Vira Com Pouco A Batalha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1bEIPRxUztuEvhaGEwK32pkIza5.jpg'),
(101576, 7229, 'Sam e Cat S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oZ6CWYOrBarDKcoMNnVgx5YFEkA.jpg'),
(101577, 7229, 'Sam e Cat S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kJLK0jbzYM0ETwWV5rHlWzBcOQg.jpg'),
(101578, 7229, 'Sam e Cat S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ucNwHL1SVfKcZm9UQS9ulEXkgK.jpg'),
(101579, 7229, 'Sam e Cat S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lqDKzNCGFvcC0VzhvibM6BoKrEx.jpg'),
(101580, 7229, 'Sam e Cat S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8eyeeF0iwsHHxODWl5U8t79hjr.jpg'),
(101581, 7229, 'Sam e Cat S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jtFGiDzQHfKvnZD5sLLeIkSZ0oL.jpg'),
(101582, 7229, 'Sam e Cat S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t2MNJLa5ksf8aach4RAA6iGLmbE.jpg'),
(101583, 7229, 'Sam e Cat S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uP2ji97J53LEQq4JzFgQOoD4vaY.jpg'),
(101584, 7229, 'Sam e Cat S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPBe86FzBGzTneP4nsKhAqOVxeD.jpg'),
(101585, 7229, 'Sam e Cat S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qhyjJnN9H7GxfcHvDQg5WRzLUxM.jpg'),
(101586, 7229, 'Sam e Cat S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iK6gMDP3RyyPfGqKBiVADocsuZ0.jpg'),
(101587, 7229, 'Sam e Cat S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wxvxfMBA8AvZQVhJuTpvPZreviY.jpg'),
(101588, 7229, 'Sam e Cat S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/208761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1oEdkXwaLbU7V1qhiWaKbaaUxFT.jpg'),
(101589, 7229, 'Sam e Cat S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/208762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ry1LeOtN08YOiPxdQemoZ21xqNC.jpg'),
(101590, 7229, 'Sam e Cat S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/208763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kiclDq9b6CPJeqW6xhZ3boLQ0iC.jpg'),
(101591, 7229, 'Sam e Cat S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/208764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pUmBnNIKY6DVZ0eRR7Iyspg2pXt.jpg'),
(101592, 7229, 'Sam e Cat S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/208765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9UAi0ouib8L5Q9GSz559AUDjUTh.jpg'),
(101593, 7229, 'Sam e Cat S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/208766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Hmh2UUJaAuMfTVSSVPUzGj0pB4.jpg'),
(101594, 7230, 'Sam e Cat S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eBYDJlWtVM7JVDhN8pRDuITNDKC.jpg'),
(101595, 7230, 'Sam e Cat S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eBYDJlWtVM7JVDhN8pRDuITNDKC.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(101596, 7230, 'Sam e Cat S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eBYDJlWtVM7JVDhN8pRDuITNDKC.jpg'),
(101597, 7230, 'Sam e Cat S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eBYDJlWtVM7JVDhN8pRDuITNDKC.jpg'),
(101598, 7230, 'Sam e Cat S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eBYDJlWtVM7JVDhN8pRDuITNDKC.jpg'),
(101599, 7230, 'Sam e Cat S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eBYDJlWtVM7JVDhN8pRDuITNDKC.jpg'),
(101600, 7230, 'Sam e Cat S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eBYDJlWtVM7JVDhN8pRDuITNDKC.jpg'),
(101601, 7230, 'Sam e Cat S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eBYDJlWtVM7JVDhN8pRDuITNDKC.jpg'),
(101602, 7230, 'Sam e Cat S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eBYDJlWtVM7JVDhN8pRDuITNDKC.jpg'),
(101603, 7230, 'Sam e Cat S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eBYDJlWtVM7JVDhN8pRDuITNDKC.jpg'),
(101604, 7230, 'Sam e Cat S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eBYDJlWtVM7JVDhN8pRDuITNDKC.jpg'),
(101605, 7230, 'Sam e Cat S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eBYDJlWtVM7JVDhN8pRDuITNDKC.jpg'),
(101606, 7230, 'Sam e Cat S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/208779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eBYDJlWtVM7JVDhN8pRDuITNDKC.jpg'),
(101607, 7230, 'Sam e Cat S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/208780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eBYDJlWtVM7JVDhN8pRDuITNDKC.jpg'),
(101608, 7230, 'Sam e Cat S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/208781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eBYDJlWtVM7JVDhN8pRDuITNDKC.jpg'),
(101609, 7230, 'Sam e Cat S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/208782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eBYDJlWtVM7JVDhN8pRDuITNDKC.jpg'),
(101610, 7230, 'Sam e Cat S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/208783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eBYDJlWtVM7JVDhN8pRDuITNDKC.jpg'),
(101611, 7230, 'Sam e Cat S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/208784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eBYDJlWtVM7JVDhN8pRDuITNDKC.jpg'),
(101612, 7231, '90 Dias Para Casar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBfWy0JIBCUPBydMiF865oTVpZE.jpg'),
(101613, 7231, '90 Dias Para Casar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b082stMyvfvYa0RO3xv4q19aa9.jpg'),
(101614, 7231, '90 Dias Para Casar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sVZQ5qxKGwEVNjUMHkBQYDqH3rT.jpg'),
(101615, 7231, '90 Dias Para Casar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/luF3RDX8L4HCpj9aMneIjTT3sBu.jpg'),
(101616, 7231, '90 Dias Para Casar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvycgC7p5i39JdPFeeZ9jFT9G0f.jpg'),
(101617, 7231, '90 Dias Para Casar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jRGDOociVms8zGojjmmxEAldM7V.jpg'),
(101618, 7232, '90 Dias Para Casar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGa7xwhKGdFuX8vPhs3RNouMP0p.jpg'),
(101619, 7232, '90 Dias Para Casar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUZ6thqz3XER0ARBjNWfqe1opdK.jpg'),
(101620, 7232, '90 Dias Para Casar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ipmbgZ0kWzWjgkzFnzdeUgOwLw8.jpg'),
(101621, 7232, '90 Dias Para Casar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/47vXoFpZzA4IQn2oO44h8g7Qbuq.jpg'),
(101622, 7232, '90 Dias Para Casar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sSa7pLpv03bdV139O9NMryUik32.jpg'),
(101623, 7232, '90 Dias Para Casar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bueWws9sNSsNRAieOeG7mAfXVcK.jpg'),
(101624, 7232, '90 Dias Para Casar S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pFxBFOtjSmp1OtYBLys0fRhrhAa.jpg'),
(101625, 7232, '90 Dias Para Casar S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2E7y5bXWM7XujjAzHMcuS5qX8qs.jpg'),
(101626, 7232, '90 Dias Para Casar S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6aOaQIm1QDlmUWOjSlgnKD6dMk0.jpg'),
(101627, 7232, '90 Dias Para Casar S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2U1Mef4Ro9Tjj9dAPo4OCpdOR4Q.jpg'),
(101628, 7232, '90 Dias Para Casar S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nZCCDycbi7BoiVRuLX4Li6iZzh0.jpg'),
(101629, 7232, '90 Dias Para Casar S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101630, 7233, '90 Dias Para Casar S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gfst8vTwksLIb73YfAM8d34ZNXb.jpg'),
(101631, 7233, '90 Dias Para Casar S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AszV6uf0UaZgb5WnVw5NT5mCzN5.jpg'),
(101632, 7233, '90 Dias Para Casar S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/68iXGj0f8vBBQeRdiLHQCQIvLsM.jpg'),
(101633, 7233, '90 Dias Para Casar S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/20gwFE2Y8bK3TruwAuacRuX3Bn8.jpg'),
(101634, 7233, '90 Dias Para Casar S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z0UZEyiGooQaNsaEvlRenpPGYwl.jpg'),
(101635, 7233, '90 Dias Para Casar S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6PHChwQXpnWZQEYijbMoeOgoIfv.jpg'),
(101636, 7233, '90 Dias Para Casar S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/94wKhHrGVxgXzUZSvtJHUkmTCpF.jpg'),
(101637, 7233, '90 Dias Para Casar S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yC75AwmlyD68uutYmzVP8xOb0oI.jpg'),
(101638, 7233, '90 Dias Para Casar S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vkgwQSBy9XnbOVWwSs9uvhqdqXm.jpg'),
(101639, 7233, '90 Dias Para Casar S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1CjNXS2tyhi8PVHHamkoKOq7EK.jpg'),
(101640, 7233, '90 Dias Para Casar S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDq4F8vMLkSGB1fPukVBZnky65G.jpg'),
(101641, 7233, '90 Dias Para Casar S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101642, 7234, '90 Dias Para Casar S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1CeCBaaYH6vsggiCsTrOQTsOzFw.jpg'),
(101643, 7234, '90 Dias Para Casar S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uSdxiYi69z9cRDOElPH2mm7XUWj.jpg'),
(101644, 7234, '90 Dias Para Casar S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bBKqLKGTjESW0K5vUy9vbNpIul.jpg'),
(101645, 7234, '90 Dias Para Casar S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mxeIO7jc76yi3hPS3AFi6xJvyfb.jpg'),
(101646, 7234, '90 Dias Para Casar S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4lcAMuCtckwPS27IdKm66Fzehwq.jpg'),
(101647, 7234, '90 Dias Para Casar S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kPod3WKdACXY5W8UeZuSmn0nnO6.jpg'),
(101648, 7234, '90 Dias Para Casar S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3HwoEqAqK8T1P8lIivibFzG2nah.jpg'),
(101649, 7234, '90 Dias Para Casar S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bOLTQC1KmV94OuZXfK3Qq2Uhdad.jpg'),
(101650, 7234, '90 Dias Para Casar S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7chQ53js3mwkD3gxc0gcVcrT0YH.jpg'),
(101651, 7234, '90 Dias Para Casar S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oaC9QFXwzokX7MLbU4JvadnSceZ.jpg'),
(101652, 7234, '90 Dias Para Casar S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p76Ra2Yuv0Tb82EnfdepU2VpbhK.jpg'),
(101653, 7234, '90 Dias Para Casar S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l9j9hBRuD8AP18flhuEEHSfRMSs.jpg'),
(101654, 7234, '90 Dias Para Casar S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ogeisCSxg5yPrC2DWIc2AHQDGSD.jpg'),
(101655, 7234, '90 Dias Para Casar S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jwHgsVUNnVYs4AjseDKSYruyXqo.jpg'),
(101656, 7235, '90 Dias Para Casar S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ky0N6V2FVrvEKHKs2In2hRcwGg.jpg'),
(101657, 7235, '90 Dias Para Casar S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1hBcRIt9c2j1AZgfHAdLk8FZNwM.jpg'),
(101658, 7235, '90 Dias Para Casar S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wf38CXntfOKGERFG5z7AjW5zo1G.jpg'),
(101659, 7235, '90 Dias Para Casar S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqn1ZFaLAwmUjyy3i43UGFSpJ0D.jpg'),
(101660, 7235, '90 Dias Para Casar S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2v7icuxUdjimBD4u7VP7zxJzMN8.jpg'),
(101661, 7235, '90 Dias Para Casar S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gpyoMpQLbHdbURIoAyTZbyNJPnr.jpg'),
(101662, 7235, '90 Dias Para Casar S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wcybwowB1vkmlZ7RgEOoGvmjytQ.jpg'),
(101663, 7235, '90 Dias Para Casar S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ixBe6r6wINEoVBZh5GfYYzqVQC.jpg'),
(101664, 7235, '90 Dias Para Casar S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aDhvTD0t2z7UHCxEiwNudT6RW3P.jpg'),
(101665, 7235, '90 Dias Para Casar S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sN8l8W1sAgnqD9OBk5v4K97cavJ.jpg'),
(101666, 7235, '90 Dias Para Casar S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1vB7TqFt3aV2mM7G7s8wH51gkRb.jpg'),
(101667, 7235, '90 Dias Para Casar S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8F6LtyYpLAxeZRd71iOAKt18wMr.jpg'),
(101668, 7235, '90 Dias Para Casar S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qnTLwGwMsSEU9g1Ni2iaIyzbvQK.jpg'),
(101669, 7235, '90 Dias Para Casar S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101670, 7236, '90 Dias Para Casar S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101671, 7236, '90 Dias Para Casar S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101672, 7236, '90 Dias Para Casar S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101673, 7236, '90 Dias Para Casar S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101674, 7236, '90 Dias Para Casar S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101675, 7236, '90 Dias Para Casar S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101676, 7236, '90 Dias Para Casar S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101677, 7236, '90 Dias Para Casar S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101678, 7236, '90 Dias Para Casar S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101679, 7236, '90 Dias Para Casar S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101680, 7236, '90 Dias Para Casar S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101681, 7236, '90 Dias Para Casar S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101682, 7236, '90 Dias Para Casar S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101683, 7236, '90 Dias Para Casar S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101684, 7236, '90 Dias Para Casar S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101685, 7237, '90 Dias Para Casar S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101686, 7237, '90 Dias Para Casar S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101687, 7237, '90 Dias Para Casar S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101688, 7237, '90 Dias Para Casar S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101689, 7237, '90 Dias Para Casar S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101690, 7237, '90 Dias Para Casar S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101691, 7237, '90 Dias Para Casar S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101692, 7237, '90 Dias Para Casar S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101693, 7237, '90 Dias Para Casar S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101694, 7237, '90 Dias Para Casar S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101695, 7237, '90 Dias Para Casar S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101696, 7237, '90 Dias Para Casar S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101697, 7237, '90 Dias Para Casar S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101698, 7237, '90 Dias Para Casar S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101699, 7237, '90 Dias Para Casar S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101700, 7238, '90 Dias Para Casar S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101701, 7238, '90 Dias Para Casar S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101702, 7238, '90 Dias Para Casar S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101703, 7238, '90 Dias Para Casar S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101704, 7238, '90 Dias Para Casar S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101705, 7238, '90 Dias Para Casar S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101706, 7238, '90 Dias Para Casar S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101707, 7238, '90 Dias Para Casar S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101708, 7238, '90 Dias Para Casar S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqoqZkcoszNS2kVGmSygpuw9EEn.jpg'),
(101709, 7238, '90 Dias Para Casar S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r4ZkyWFLUHvElGY75ETyRNagz2C.jpg'),
(101710, 7238, '90 Dias Para Casar S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/izkVWgJH1L4HjZefo5wJZEeAtaZ.jpg'),
(101711, 7238, '90 Dias Para Casar S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101712, 7238, '90 Dias Para Casar S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101713, 7238, '90 Dias Para Casar S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101714, 7238, '90 Dias Para Casar S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101715, 7238, '90 Dias Para Casar S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/228470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101716, 7238, '90 Dias Para Casar S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/228471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101717, 7238, '90 Dias Para Casar S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/228472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101718, 7238, '90 Dias Para Casar S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/228473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101719, 7239, '90 Dias Para Casar S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/umRFB95En8yxjmuDjNu13Uwxd7L.jpg'),
(101720, 7239, '90 Dias Para Casar S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uWOtlY2s6XVhb8unXZ77TeUZdVI.jpg'),
(101721, 7239, '90 Dias Para Casar S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qT2XaCKiOczdkgB61F7qKOpQnwy.jpg'),
(101722, 7239, '90 Dias Para Casar S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fqjWRppqVFDPlMDSbeeK9zCotGq.jpg'),
(101723, 7239, '90 Dias Para Casar S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aRy8hkQ9GtkRlwr82YVddxmN4Cu.jpg'),
(101724, 7239, '90 Dias Para Casar S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1JxHbhru85HTstrMCR6gXU5lzoG.jpg'),
(101725, 7239, '90 Dias Para Casar S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k927puWFkxstjDziT02PST0IXY2.jpg'),
(101726, 7239, '90 Dias Para Casar S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wpIdhMcPXOfYC1exy74C5Hfd41C.jpg'),
(101727, 7239, '90 Dias Para Casar S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mM4I9z1GLUwRftpgfAXvoC2JI1d.jpg'),
(101728, 7239, '90 Dias Para Casar S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/az8XeTaRn5zkXsiihf3qoN9A2I7.jpg'),
(101729, 7239, '90 Dias Para Casar S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qTGIZeyiG3RuyQEkSomU0e3gcDb.jpg'),
(101730, 7239, '90 Dias Para Casar S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fO5xN0ncaLJHlIgRMGPU9Wqx34C.jpg'),
(101731, 7239, '90 Dias Para Casar S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uFSpFF5tiCCkq3fKfTNH4ZYhwd7.jpg'),
(101732, 7239, '90 Dias Para Casar S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2jkYGiYCKmDDEJhlQJO1x3jl5HD.jpg'),
(101733, 7239, '90 Dias Para Casar S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c6ickGRJF3kBfjdp4AM87HtaY2o.jpg'),
(101734, 7239, '90 Dias Para Casar S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/228489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iGvcpfqEAB4vmMXVj59rhxbUNRz.jpg'),
(101735, 7239, '90 Dias Para Casar S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/228490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ebgkChJ5gWvm4ymgMmYv4sKRaav.jpg'),
(101736, 7239, '90 Dias Para Casar S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/228491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s8o3fCZU2ZAnNoyoEhFLkuxH4PQ.jpg'),
(101737, 7239, '90 Dias Para Casar S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/228492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l94Gh14o0YuoOjQqzeqGga4AeLX.jpg'),
(101738, 7240, '90 Dias Para Casar S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101739, 7240, '90 Dias Para Casar S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101740, 7240, '90 Dias Para Casar S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101741, 7240, '90 Dias Para Casar S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101742, 7240, '90 Dias Para Casar S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101743, 7240, '90 Dias Para Casar S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101744, 7240, '90 Dias Para Casar S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101745, 7240, '90 Dias Para Casar S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101746, 7240, '90 Dias Para Casar S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/486311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101747, 7240, '90 Dias Para Casar S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/486312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101748, 7240, '90 Dias Para Casar S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/486313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101749, 7240, '90 Dias Para Casar S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/486314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101750, 7240, '90 Dias Para Casar S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/486315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101751, 7240, '90 Dias Para Casar S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/486316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101752, 7240, '90 Dias Para Casar S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/494254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101753, 7240, '90 Dias Para Casar S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/497506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101754, 7240, '90 Dias Para Casar S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/503684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101755, 7240, '90 Dias Para Casar S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/508452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101756, 7240, '90 Dias Para Casar S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/516492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101757, 7240, '90 Dias Para Casar S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/656984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wiD5YeBSudlsrmknhZgYPATn5zE.jpg'),
(101758, 7241, 'A Máquina do Destino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oWSbONFyyQuPPyicCNWmjYu9O2u.jpg'),
(101759, 7241, 'A Máquina do Destino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/egY2gBOS9uDywSVwR2NDYMcRHUs.jpg'),
(101760, 7241, 'A Máquina do Destino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1EWcm0BSaPWixMmdDs0ZETHMS2.jpg'),
(101761, 7241, 'A Máquina do Destino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213296.mp4', 'http://image.tmdb.org/t/p/w1280/8DaMjUoxlbQuI8sS2V7WorfVbJz.jpg'),
(101762, 7241, 'A Máquina do Destino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213297.mp4', 'http://image.tmdb.org/t/p/w1280/toLm24gtkDwAoUEgXgY4hgtJKsu.jpg'),
(101763, 7241, 'A Máquina do Destino S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213298.mp4', 'http://image.tmdb.org/t/p/w1280/4E32Eb29KXnLHtdtfAk7klqHpDX.jpg'),
(101764, 7241, 'A Máquina do Destino S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213299.mp4', 'http://image.tmdb.org/t/p/w1280/6723v8OHB1SrykF50QK76gb0J2X.jpg'),
(101765, 7241, 'A Máquina do Destino S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213300.mp4', 'http://image.tmdb.org/t/p/w1280/wRiDgDKU3y6mealNbIkc6yGfGhw.jpg'),
(101766, 7241, 'A Máquina do Destino S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213301.mp4', 'http://image.tmdb.org/t/p/w1280/4CXA0btWUHE7isycMNl0dylmriT.jpg'),
(101767, 7241, 'A Máquina do Destino S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213302.mp4', 'http://image.tmdb.org/t/p/w1280/aAxCO0KorgjQCSjTEMqEbhOEuj4.jpg'),
(101768, 7242, 'A Máquina do Destino S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/334034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6FUUEVENu0w5Cv01N9lBzsoPOY.jpg'),
(101769, 7242, 'A Máquina do Destino S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/334035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6FUUEVENu0w5Cv01N9lBzsoPOY.jpg'),
(101770, 7242, 'A Máquina do Destino S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/334036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6FUUEVENu0w5Cv01N9lBzsoPOY.jpg'),
(101771, 7242, 'A Máquina do Destino S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/341912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6FUUEVENu0w5Cv01N9lBzsoPOY.jpg'),
(101772, 7242, 'A Máquina do Destino S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6FUUEVENu0w5Cv01N9lBzsoPOY.jpg'),
(101773, 7242, 'A Máquina do Destino S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6FUUEVENu0w5Cv01N9lBzsoPOY.jpg'),
(101774, 7242, 'A Máquina do Destino S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/360466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6FUUEVENu0w5Cv01N9lBzsoPOY.jpg'),
(101775, 7242, 'A Máquina do Destino S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/369774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6FUUEVENu0w5Cv01N9lBzsoPOY.jpg'),
(101776, 7242, 'A Máquina do Destino S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/375503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6FUUEVENu0w5Cv01N9lBzsoPOY.jpg'),
(101777, 7242, 'A Máquina do Destino S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/383457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6FUUEVENu0w5Cv01N9lBzsoPOY.jpg'),
(101778, 7243, 'Cuba Libre [PT-PT] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cvkiJkZtyOqoS3FOdlXzzr7d6Ks.jpg'),
(101779, 7243, 'Cuba Libre [PT-PT] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cvkiJkZtyOqoS3FOdlXzzr7d6Ks.jpg'),
(101780, 7243, 'Cuba Libre [PT-PT] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cvkiJkZtyOqoS3FOdlXzzr7d6Ks.jpg'),
(101781, 7243, 'Cuba Libre [PT-PT] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cvkiJkZtyOqoS3FOdlXzzr7d6Ks.jpg'),
(101782, 7243, 'Cuba Libre [PT-PT] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cvkiJkZtyOqoS3FOdlXzzr7d6Ks.jpg'),
(101783, 7243, 'Cuba Libre [PT-PT] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cvkiJkZtyOqoS3FOdlXzzr7d6Ks.jpg'),
(101784, 7244, 'Despercebida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5O80FUkR8q0igcJMHvvDWCLtFLC.jpg'),
(101785, 7244, 'Despercebida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oZVQ4DrybgaiiB5znk1d3Q9RsF7.jpg'),
(101786, 7244, 'Despercebida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cBJKHqqnMjv4VZIc8c3KZDKzQH5.jpg'),
(101787, 7244, 'Despercebida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fs5NsTIC5THeiYIC6fuOyczfUwb.jpg'),
(101788, 7244, 'Despercebida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgE2bbSYN5QC8AiZ6OFjuh7cL0W.jpg'),
(101789, 7244, 'Despercebida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eF3Vlb2sNrx4mzqtY5ZGGLzmIdG.jpg'),
(101790, 7245, 'Despercebida S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/795081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xdua55TZuk0pAQebhTWwjDJ22st.jpg'),
(101791, 7245, 'Despercebida S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/795082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xdua55TZuk0pAQebhTWwjDJ22st.jpg'),
(101792, 7245, 'Despercebida S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/795083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xdua55TZuk0pAQebhTWwjDJ22st.jpg'),
(101793, 7245, 'Despercebida S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/795084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xdua55TZuk0pAQebhTWwjDJ22st.jpg'),
(101794, 7245, 'Despercebida S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/795085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xdua55TZuk0pAQebhTWwjDJ22st.jpg'),
(101795, 7245, 'Despercebida S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/795086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xdua55TZuk0pAQebhTWwjDJ22st.jpg'),
(101796, 7246, 'Destiladores - Mestre Destilador S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pf3GHVjCCYwOXUZDkMgDgfovgzA.jpg'),
(101797, 7246, 'Destiladores - Mestre Destilador S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zByFQSPSx4aUql95tzV3wbBlEqK.jpg'),
(101798, 7246, 'Destiladores - Mestre Destilador S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lgRgPphJmP0tm12Z1rdwOip2hyx.jpg'),
(101799, 7246, 'Destiladores - Mestre Destilador S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uj8BeplHPFM5WXQAPWNm99lFcwq.jpg'),
(101800, 7246, 'Destiladores - Mestre Destilador S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zExYBgdni3COJZ4qGZXOfyBTA3D.jpg'),
(101801, 7247, 'Destiladores - Mestre Destilador S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zTmWrdts5Ep9BPDsum7wciAegvv.jpg'),
(101802, 7247, 'Destiladores - Mestre Destilador S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mV5bs56ojVZpwnVBNN9cx1bNVDm.jpg'),
(101803, 7247, 'Destiladores - Mestre Destilador S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eOhPNOlCN8LFZrmdWbpTyQG0DbE.jpg'),
(101804, 7247, 'Destiladores - Mestre Destilador S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8OCYKUlwQJYjMIAHVAjFRTeJSX0.jpg'),
(101805, 7247, 'Destiladores - Mestre Destilador S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/71Rh6RoPUwxfSd1WClySBByFSa.jpg'),
(101806, 7247, 'Destiladores - Mestre Destilador S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kJVWjt1ZNdmbgBVJc8rG9coiJcr.jpg'),
(101807, 7247, 'Destiladores - Mestre Destilador S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jfzASIOKI52l6SP7KawnnGPFjWn.jpg'),
(101808, 7247, 'Destiladores - Mestre Destilador S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xyJP0t44D3OTcjT7tTNWsCYZtvJ.jpg'),
(101809, 7247, 'Destiladores - Mestre Destilador S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hy34H4lNbKIQjJfVKQiXRnbRWgG.jpg'),
(101810, 7247, 'Destiladores - Mestre Destilador S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7jKI76eFKsooYPXSKMnovoIVqUO.jpg'),
(101811, 7248, 'Destiladores - Mestre Destilador S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FS00Tr01v0bXBqBtlMq4alC63v.jpg'),
(101812, 7248, 'Destiladores - Mestre Destilador S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6R5gRwdbsHJpVgALHYeZeTk42Ux.jpg'),
(101813, 7248, 'Destiladores - Mestre Destilador S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/whkeMPHh1Jlb3nDj0ayxDfsRYEz.jpg'),
(101814, 7248, 'Destiladores - Mestre Destilador S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zX18b4iNY3CQIfcxq0p7LX3t7yu.jpg'),
(101815, 7248, 'Destiladores - Mestre Destilador S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ptu2mJZcXE28XRnfVDQp9dmUtIk.jpg'),
(101816, 7248, 'Destiladores - Mestre Destilador S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lnhUm0wCzRPrZypBsQyF6bTc5Zi.jpg'),
(101817, 7248, 'Destiladores - Mestre Destilador S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dodJ64iSJGouqbrnzxkWu8gErt6.jpg'),
(101818, 7248, 'Destiladores - Mestre Destilador S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t5i6DpDsPK7TZCu3SWPCoL3O9pC.jpg'),
(101819, 7248, 'Destiladores - Mestre Destilador S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7ndHHH9mOqsSJGvjNa9pSEVLFz.jpg'),
(101820, 7248, 'Destiladores - Mestre Destilador S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xt4xoo2Aw6zQqAZ4pp1pj8fPAzp.jpg'),
(101821, 7248, 'Destiladores - Mestre Destilador S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rVw3bUZQnXy1qlmusbyN7RHcgp.jpg'),
(101822, 7248, 'Destiladores - Mestre Destilador S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7ndHHH9mOqsSJGvjNa9pSEVLFz.jpg'),
(101823, 7248, 'Destiladores - Mestre Destilador S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/208720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2hFMgyB2rHUzATJJHYIBEgxJB13.jpg'),
(101824, 7248, 'Destiladores - Mestre Destilador S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/208721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7ndHHH9mOqsSJGvjNa9pSEVLFz.jpg'),
(101825, 7248, 'Destiladores - Mestre Destilador S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/208722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7ndHHH9mOqsSJGvjNa9pSEVLFz.jpg'),
(101826, 7248, 'Destiladores - Mestre Destilador S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/208723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7ndHHH9mOqsSJGvjNa9pSEVLFz.jpg'),
(101827, 7248, 'Destiladores - Mestre Destilador S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/208724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7ndHHH9mOqsSJGvjNa9pSEVLFz.jpg'),
(101828, 7248, 'Destiladores - Mestre Destilador S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/208725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7ndHHH9mOqsSJGvjNa9pSEVLFz.jpg'),
(101829, 7248, 'Destiladores - Mestre Destilador S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/208726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7ndHHH9mOqsSJGvjNa9pSEVLFz.jpg'),
(101830, 7248, 'Destiladores - Mestre Destilador S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/208727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7ndHHH9mOqsSJGvjNa9pSEVLFz.jpg'),
(101831, 7248, 'Destiladores - Mestre Destilador S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/208728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7ndHHH9mOqsSJGvjNa9pSEVLFz.jpg'),
(101832, 7248, 'Destiladores - Mestre Destilador S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/208729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7ndHHH9mOqsSJGvjNa9pSEVLFz.jpg'),
(101833, 7248, 'Destiladores - Mestre Destilador S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/208730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7ndHHH9mOqsSJGvjNa9pSEVLFz.jpg'),
(101834, 7248, 'Destiladores - Mestre Destilador S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/208731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7ndHHH9mOqsSJGvjNa9pSEVLFz.jpg'),
(101835, 7248, 'Destiladores - Mestre Destilador S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/208732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7ndHHH9mOqsSJGvjNa9pSEVLFz.jpg'),
(101836, 7249, 'Destiladores - Mestre Destilador S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7ndHHH9mOqsSJGvjNa9pSEVLFz.jpg'),
(101837, 7249, 'Destiladores - Mestre Destilador S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7ndHHH9mOqsSJGvjNa9pSEVLFz.jpg'),
(101838, 7249, 'Destiladores - Mestre Destilador S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7ndHHH9mOqsSJGvjNa9pSEVLFz.jpg'),
(101839, 7249, 'Destiladores - Mestre Destilador S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7ndHHH9mOqsSJGvjNa9pSEVLFz.jpg'),
(101840, 7250, 'Emergência: Nova York S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3vFbIHVpb0vLtf06Ujgx8xbMHfX.jpg'),
(101841, 7250, 'Emergência: Nova York S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nCJSv9ZrQiLuarr33sXupvuWQN.jpg'),
(101842, 7250, 'Emergência: Nova York S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q601gsefpjSRxsW9sVP0YAuf3NW.jpg'),
(101843, 7250, 'Emergência: Nova York S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nKFawWxAIYxbQpJ8uuA67iJuw9G.jpg'),
(101844, 7250, 'Emergência: Nova York S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cje6seYRUEFo5Cv7btpBuLCqYTs.jpg'),
(101845, 7250, 'Emergência: Nova York S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wwQVTmfaqkgFHNqjZGW5ZSd6v4c.jpg'),
(101846, 7250, 'Emergência: Nova York S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dSlnUnAfXc2KVbr2dxMH4lkPaP7.jpg'),
(101847, 7250, 'Emergência: Nova York S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tqRlbX9i7T4OeUXgHKu1RApPkhr.jpg'),
(101848, 7150, 'Fora da Prisão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k45J8gmRlpdtn34Hd35vQjAujtA.jpg'),
(101849, 7150, 'Fora da Prisão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cepVbdY8eNsQlFh2w14X4foV1gS.jpg'),
(101850, 7150, 'Fora da Prisão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xsKiK134nGfnHZ6otoBup5FGlIb.jpg'),
(101851, 7150, 'Fora da Prisão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k4uhky2CIC9bg3G6uSzhVseXvm9.jpg'),
(101852, 7150, 'Fora da Prisão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/41hMPVPbTphHOOTfhv26hIHYIs.jpg'),
(101853, 7150, 'Fora da Prisão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wx6Hmqk2tp5KUyQlkcTtDWNkW7P.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(101854, 7150, 'Fora da Prisão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c1CDCbYmNQOa4pJJ8tfZIvku6NU.jpg'),
(101855, 7150, 'Fora da Prisão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6yhWX5qvoENOIKsPB00RUvul4HQ.jpg'),
(101856, 7251, 'Girls Dorm S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oACiI6NHQ24YsYJH6WOUwXa71gt.jpg'),
(101857, 7251, 'Girls Dorm S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rnd268c5HbvfyhEXPX4qJC4FNkd.jpg'),
(101858, 7251, 'Girls Dorm S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lOvqhOufDN05izYlfAvmtkwSG6H.jpg'),
(101859, 7251, 'Girls Dorm S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Hyipl8b7x2qQ9mdV3mRhKDcXn0.jpg'),
(101860, 7251, 'Girls Dorm S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yOh0onytDTpIu1KwcaCFQ15MZou.jpg'),
(101861, 7251, 'Girls Dorm S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wXZR8EYBXJ1LDUYf5dYv2vhrgq6.jpg'),
(101862, 7251, 'Girls Dorm S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jbyMWsoT26BottqxciC5pF1ccbP.jpg'),
(101863, 7251, 'Girls Dorm S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gwBXlYseGV5Qvq4zQurt15j0A4U.jpg'),
(101864, 7252, 'Girls Dorm S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuRvvdiHT3iyiPowdKDZhKarhkj.jpg'),
(101865, 7252, 'Girls Dorm S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuRvvdiHT3iyiPowdKDZhKarhkj.jpg'),
(101866, 7252, 'Girls Dorm S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuRvvdiHT3iyiPowdKDZhKarhkj.jpg'),
(101867, 7252, 'Girls Dorm S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuRvvdiHT3iyiPowdKDZhKarhkj.jpg'),
(101868, 7252, 'Girls Dorm S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuRvvdiHT3iyiPowdKDZhKarhkj.jpg'),
(101869, 7252, 'Girls Dorm S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuRvvdiHT3iyiPowdKDZhKarhkj.jpg'),
(101870, 7252, 'Girls Dorm S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuRvvdiHT3iyiPowdKDZhKarhkj.jpg'),
(101871, 7252, 'Girls Dorm S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuRvvdiHT3iyiPowdKDZhKarhkj.jpg'),
(101872, 7253, 'Girls Dorm S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuRvvdiHT3iyiPowdKDZhKarhkj.jpg'),
(101873, 7253, 'Girls Dorm S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuRvvdiHT3iyiPowdKDZhKarhkj.jpg'),
(101874, 7253, 'Girls Dorm S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuRvvdiHT3iyiPowdKDZhKarhkj.jpg'),
(101875, 7253, 'Girls Dorm S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuRvvdiHT3iyiPowdKDZhKarhkj.jpg'),
(101876, 7253, 'Girls Dorm S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuRvvdiHT3iyiPowdKDZhKarhkj.jpg'),
(101877, 7253, 'Girls Dorm S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuRvvdiHT3iyiPowdKDZhKarhkj.jpg'),
(101878, 7253, 'Girls Dorm S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuRvvdiHT3iyiPowdKDZhKarhkj.jpg'),
(101879, 7253, 'Girls Dorm S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wuRvvdiHT3iyiPowdKDZhKarhkj.jpg'),
(101880, 7254, 'Instável S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWtJD6K0dZ0jsKZ4iUsTK5000qf.jpg'),
(101881, 7254, 'Instável S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMeV6pPeNHK10QxdxXEF20MlJxo.jpg'),
(101882, 7254, 'Instável S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Vf8dGP6nx2lgLTlge98BlbGpBD.jpg'),
(101883, 7254, 'Instável S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sGiaFACyOQANCoxVC5rCZm53zD3.jpg'),
(101884, 7254, 'Instável S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qwOWmJxYDmCUW9dNAZ60gMGSSS5.jpg'),
(101885, 7254, 'Instável S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/af9gVPig3M2Jfd7DiZHroRcxbW4.jpg'),
(101886, 7254, 'Instável S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4FnVLgVD4w40grK2lQyHY434u6q.jpg'),
(101887, 7254, 'Instável S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Arl7eotQOnJarxf0neemYYEnEHU.jpg'),
(101888, 7255, 'Instável S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/424737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sjVChg9VpKcH0MuLbS747J5x7V.jpg'),
(101889, 7255, 'Instável S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/424738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sjVChg9VpKcH0MuLbS747J5x7V.jpg'),
(101890, 7255, 'Instável S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/424739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sjVChg9VpKcH0MuLbS747J5x7V.jpg'),
(101891, 7255, 'Instável S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/424740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sjVChg9VpKcH0MuLbS747J5x7V.jpg'),
(101892, 7255, 'Instável S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/424741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sjVChg9VpKcH0MuLbS747J5x7V.jpg'),
(101893, 7255, 'Instável S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/424742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sjVChg9VpKcH0MuLbS747J5x7V.jpg'),
(101894, 7255, 'Instável S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/424743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sjVChg9VpKcH0MuLbS747J5x7V.jpg'),
(101895, 7255, 'Instável S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/424744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sjVChg9VpKcH0MuLbS747J5x7V.jpg'),
(101896, 7256, 'Jessie e Colombo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pmMVmYaqLzLaur5H1hqQA1RBeWV.jpg'),
(101897, 7256, 'Jessie e Colombo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fuXLTcCceMVMZtkhhMrvJNS0gr1.jpg'),
(101898, 7256, 'Jessie e Colombo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wDXmvBlCsUHaAI2FR6dEnrBFpTT.jpg'),
(101899, 7256, 'Jessie e Colombo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJFnMPIYddhkU1LqFi5fO6ym4uh.jpg'),
(101900, 7257, 'O Assassino Midiático S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/50DI9lyvuqnAmJqocrKEICOSRTo.jpg'),
(101901, 7257, 'O Assassino Midiático S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jMpGTTZCtgzYR7iG3OlZD4AAqIw.jpg'),
(101902, 7257, 'O Assassino Midiático S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ljkxBrCHngli3LH9Af1uOK086V2.jpg'),
(101903, 7257, 'O Assassino Midiático S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zJjE2nTr4FIt5ses94Ykk4UZD2p.jpg'),
(101904, 7257, 'O Assassino Midiático S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AfDLaVzQnxIWdhQKWDRctemPi3E.jpg'),
(101905, 7257, 'O Assassino Midiático S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kYcFXPG2kMHwmMDDID9nxSFcXz9.jpg'),
(101906, 7257, 'O Assassino Midiático S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yM7mI9hc9gjZeHMrp0G9xoLsXO6.jpg'),
(101907, 7257, 'O Assassino Midiático S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n5HqsZvbjMSkF18EbxdZZtkFAon.jpg'),
(101908, 7257, 'O Assassino Midiático S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQ9EIuepFvIto9OwaEc0vPT53qz.jpg'),
(101909, 7257, 'O Assassino Midiático S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gK5QEtJ2avrs9WsTJO7UGDqywVg.jpg'),
(101910, 7258, 'O Crime do Padre Amaro [PT-PT] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6KfIt8Ri0awx4RSz4ru7mtccKwY.jpg'),
(101911, 7258, 'O Crime do Padre Amaro [PT-PT] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8geJcNuGjLe1SL8hZj7PKbXaMtt.jpg'),
(101912, 7258, 'O Crime do Padre Amaro [PT-PT] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oVS6MKP7hyNAvcS7NQjE9IZSZPj.jpg'),
(101913, 7258, 'O Crime do Padre Amaro [PT-PT] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv43vLXlENKnUJdLkNE8ObgnyES.jpg'),
(101914, 7258, 'O Crime do Padre Amaro [PT-PT] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv43vLXlENKnUJdLkNE8ObgnyES.jpg'),
(101915, 7258, 'O Crime do Padre Amaro [PT-PT] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv43vLXlENKnUJdLkNE8ObgnyES.jpg'),
(101916, 7259, 'O Poder S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ofK3ckjVLLt376OG5Bwcu8N3xXg.jpg'),
(101917, 7259, 'O Poder S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xLSMxkTsIXQhSbJ26IQCckI5wdq.jpg'),
(101918, 7259, 'O Poder S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w2sy16lTjZNU47kfFuEAjDgz6wb.jpg'),
(101919, 7259, 'O Poder S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213785.mp4', 'http://image.tmdb.org/t/p/w1280/9lt8cbIPfHL2kza0sSmqwxKXXdJ.jpg'),
(101920, 7259, 'O Poder S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213786.mp4', 'http://image.tmdb.org/t/p/w1280/uwBW77hTdXcRw0oMXgRdyszR7Gv.jpg'),
(101921, 7259, 'O Poder S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213787.mp4', 'http://image.tmdb.org/t/p/w1280/5Ja1qinmXi7U86q48SVP99VlPiD.jpg'),
(101922, 7259, 'O Poder S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213788.mp4', 'http://image.tmdb.org/t/p/w1280/y0s8xZGtXZjp4OWNT8hP77hlP48.jpg'),
(101923, 7259, 'O Poder S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213789.mp4', 'http://image.tmdb.org/t/p/w1280/bgcGQxxuvwrVOJCjN0vUEa8jD0t.jpg'),
(101924, 7259, 'O Poder S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213790.mp4', 'http://image.tmdb.org/t/p/w1280/fd7BYEbJCPKSv4hN1a59BD947HL.jpg'),
(101925, 7260, 'O Tio de Outro Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g43YADFYJJ80Y2QmeRQPlPfCbXO.jpg'),
(101926, 7260, 'O Tio de Outro Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/moBxjSLSdabLvxJgjOm8ECstnoo.jpg'),
(101927, 7260, 'O Tio de Outro Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2eRlV6JwH2MUEWU7TmCO2QcgBCb.jpg'),
(101928, 7260, 'O Tio de Outro Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfs0A6VKyqFijKEodzAbYLz9Lj9.jpg'),
(101929, 7260, 'O Tio de Outro Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c4hXPibZnVvJKwMij7SqejRfiQi.jpg'),
(101930, 7260, 'O Tio de Outro Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zPmNqVLRcLj7Rx56xcedOUXoKVw.jpg'),
(101931, 7260, 'O Tio de Outro Mundo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4rQ4TyEHK0lCEIM9Le4SREalTuv.jpg'),
(101932, 7260, 'O Tio de Outro Mundo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/usDOduWgbdYkrzPqDGPIOxO17KT.jpg'),
(101933, 7260, 'O Tio de Outro Mundo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fuwjsEZNXmSgoddR3bC09RxrYhZ.jpg'),
(101934, 7260, 'O Tio de Outro Mundo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4fUOdY4rfJf5aOMm2ERGILj0mYm.jpg'),
(101935, 7260, 'O Tio de Outro Mundo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hV9GgtOHxmKMtFFS8KJZcqmALSw.jpg'),
(101936, 7260, 'O Tio de Outro Mundo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/95C54tzaJYdayMgO8qJl47qOZsM.jpg'),
(101937, 7260, 'O Tio de Outro Mundo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/208588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qmm9KfMVQAYoIykTn593hzdFhjP.jpg'),
(101938, 7261, 'Olhos Atentos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dwQdiOqCCueFss3XBy7ZssnBFiY.jpg'),
(101939, 7261, 'Olhos Atentos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOL5xA387QJn3VM6SVTTPX11k4R.jpg'),
(101940, 7261, 'Olhos Atentos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bM1gfRXBVW7EE4PYxTKfBEBV6k7.jpg'),
(101941, 7261, 'Olhos Atentos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bazdHdVbOVUDi3cS5thduLw5CFr.jpg'),
(101942, 7261, 'Olhos Atentos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Ek53PzopexhOeQ7jPO12hfAFOl.jpg'),
(101943, 7261, 'Olhos Atentos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cpvOUHl6UmBcy9WsOOrJ3ufJ9Cm.jpg'),
(101944, 7261, 'Olhos Atentos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eAgeKuKAjInTbkjD58Yat25Q8lp.jpg'),
(101945, 7261, 'Olhos Atentos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wfs7w1dSAgubjhOOaARdarlwsc1.jpg'),
(101946, 7261, 'Olhos Atentos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ytQTgwnhnyjr4DKHZOSGiQEdC2x.jpg'),
(101947, 7261, 'Olhos Atentos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hENSWA5wpvuPI5PcCzBG7oDFzwx.jpg'),
(101948, 7262, 'Que Chegue a Você: Kimi ni Todoke S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ao9k3tYeXC24hveuidbSadRrahe.jpg'),
(101949, 7262, 'Que Chegue a Você: Kimi ni Todoke S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h9oJaQ3NTdimcEOKdkrBmyz4SNe.jpg'),
(101950, 7262, 'Que Chegue a Você: Kimi ni Todoke S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pcH2kVyqUEYDhLdJWj9Gg0R4lBk.jpg'),
(101951, 7262, 'Que Chegue a Você: Kimi ni Todoke S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b59fpkHmO3u9IawDhU0rstLkdxw.jpg'),
(101952, 7262, 'Que Chegue a Você: Kimi ni Todoke S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4aA8Of9BUkWHMtSn2t8uHZpx8GP.jpg'),
(101953, 7262, 'Que Chegue a Você: Kimi ni Todoke S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFKQnKvM6fQAdN6N8CpLP4l1ar1.jpg'),
(101954, 7262, 'Que Chegue a Você: Kimi ni Todoke S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/efWDjc7Rqmgw9unakGqSeepv7EW.jpg'),
(101955, 7262, 'Que Chegue a Você: Kimi ni Todoke S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nN9BFxYo0MBp5zYBEwtJHhlqyUi.jpg'),
(101956, 7262, 'Que Chegue a Você: Kimi ni Todoke S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/84oEpbHwX6xR2szzAklcC076Mes.jpg'),
(101957, 7262, 'Que Chegue a Você: Kimi ni Todoke S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dyJl5k9FQaSYNv8p2mncWsjy4oJ.jpg'),
(101958, 7262, 'Que Chegue a Você: Kimi ni Todoke S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/208564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v4BsLAmySb7XPIrq19100ovkfUC.jpg'),
(101959, 7262, 'Que Chegue a Você: Kimi ni Todoke S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/208565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qWytkX79GHcd4Kx6j60UgL7nHUz.jpg'),
(101960, 7263, 'Wellmania S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zSOSwtoNejCIx5QmHmnreFBZ0h0.jpg'),
(101961, 7263, 'Wellmania S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v3045U41WhT7hJYdyB3dGx7YOiy.jpg'),
(101962, 7263, 'Wellmania S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ktb1vWMD89ZuInkTX5YUSgqnRRD.jpg'),
(101963, 7263, 'Wellmania S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4LbpFcaHMjefnmF9iKTUD4vE6t0.jpg'),
(101964, 7263, 'Wellmania S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/MHKPSugQOnoBLMvTOlPTh7xYJk.jpg'),
(101965, 7263, 'Wellmania S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vsfOHhBNBsTXLNb549b6rofQpXc.jpg'),
(101966, 7263, 'Wellmania S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/npP4rX0AKM7ZFxKlWJNJtaWJyqZ.jpg'),
(101967, 7263, 'Wellmania S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tlf4dNbDuj6cb2j4F7YtfHqCzX6.jpg'),
(101968, 7264, 'Marinheiro de Guerra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tCN8LRiPbQP5Oh2b3Idai4a4w8U.jpg'),
(101969, 7264, 'Marinheiro de Guerra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aRsc5kAfaE1Exmj8KdimaPKSXdq.jpg'),
(101970, 7264, 'Marinheiro de Guerra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/86CzjdibOji6cvcxs06JlumY2OU.jpg'),
(101971, 7265, 'O Farejador S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9CXeNmNOaGL2clYLodbgB1carQ5.jpg'),
(101972, 7265, 'O Farejador S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cICABNXcFIqnySklWFX4HQvdEgz.jpg'),
(101973, 7265, 'O Farejador S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/niOZVhiSrOfcwJOjOPrL5ul0QPG.jpg'),
(101974, 7265, 'O Farejador S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tOb3NQEC0YMkwv1NKmxBpEsE5rv.jpg'),
(101975, 7265, 'O Farejador S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pm2KGDY9dvay6ennEUS4Adpq9mK.jpg'),
(101976, 7265, 'O Farejador S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/deW4QrOzsZLAqh9UvSpSkYxyQFs.jpg'),
(101977, 7265, 'O Farejador S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gpgu35ZnORjHxJCoB6nYWenSuJK.jpg'),
(101978, 7265, 'O Farejador S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/350k9QXnfaJAalo5vE1R0KraIbz.jpg'),
(101979, 7266, 'O Farejador S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pBJ37ooaXzZYdkwTV0KPUjFGIHR.jpg'),
(101980, 7266, 'O Farejador S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gTZCuDKnf6Q6vR96ZTsDKtHHNHe.jpg'),
(101981, 7266, 'O Farejador S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVE859UmLZEGxF5ptHGRMUmyR0e.jpg'),
(101982, 7266, 'O Farejador S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kCw7bElCAzNmjJmCaGGFQAV1Wi4.jpg'),
(101983, 7266, 'O Farejador S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jWhhLi3o0IIdUsRLje8OULtBfIu.jpg'),
(101984, 7266, 'O Farejador S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/26DJS4pyWwKAYIC9W7ZzeaXs4lO.jpg'),
(101985, 7266, 'O Farejador S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6l02zq6O4PIiO3NrzPWyRKVqscj.jpg'),
(101986, 7266, 'O Farejador S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cFxa2OwmBOxI2dz1qTNF2pgmIHM.jpg'),
(101987, 7267, 'O Farejador S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fvCpBT60kMdkDIKxMNx8l6DYq2f.jpg'),
(101988, 7267, 'O Farejador S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2nctUkd7BM9v81XPJaBzQntw6dH.jpg'),
(101989, 7267, 'O Farejador S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rM9p6pRz6JdE26W7eQ5epYJbGg.jpg'),
(101990, 7267, 'O Farejador S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wW6y16OKrqZjcJxjdplUwQZKa7L.jpg'),
(101991, 7267, 'O Farejador S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mibrhg4aaTIRclhDDKxvZhyedKU.jpg'),
(101992, 7267, 'O Farejador S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eQd6LYX5Ljf52tOw8gR1FmhPlv5.jpg'),
(101993, 7267, 'O Farejador S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hycQFFMwXRouvKMY83aX8vpjjmf.jpg'),
(101994, 7267, 'O Farejador S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rAfAHPQ2nEjmiM9g8syYNjiCigl.jpg'),
(101995, 7268, 'O Farejador S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l8tBYnNfGVm6lmEEIfGJwXvmUd4.jpg'),
(101996, 7268, 'O Farejador S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aksTMW3sgGco8GX6w7e9rNSByEo.jpg'),
(101997, 7268, 'O Farejador S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gKmhx33EtbzIoSdlHatDx0TiCAd.jpg'),
(101998, 7268, 'O Farejador S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzhYjlbCwPVFWIhb2IjO7pEcwEC.jpg'),
(101999, 7268, 'O Farejador S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wdj7R7nZiljvmRuYT2tm23BXwqG.jpg'),
(102000, 7268, 'O Farejador S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bQWutnx7uZiWQwQtCuUFq8KbIIu.jpg'),
(102001, 7268, 'O Farejador S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vMyeyrrZBuJog9T1fYgWXrTDFQo.jpg'),
(102002, 7268, 'O Farejador S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZJ7ThWxIqmSySqNUzjcccsERpD.jpg'),
(102003, 7269, 'Amor na Real S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/208309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sphhkNFKoviCTUDBValbHgz1NBD.jpg'),
(102004, 7269, 'Amor na Real S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/208310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sphhkNFKoviCTUDBValbHgz1NBD.jpg'),
(102005, 7269, 'Amor na Real S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/208311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sphhkNFKoviCTUDBValbHgz1NBD.jpg'),
(102006, 7269, 'Amor na Real S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/208312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sphhkNFKoviCTUDBValbHgz1NBD.jpg'),
(102007, 7269, 'Amor na Real S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/208313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sphhkNFKoviCTUDBValbHgz1NBD.jpg'),
(102008, 7269, 'Amor na Real S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/208314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sphhkNFKoviCTUDBValbHgz1NBD.jpg'),
(102009, 7269, 'Amor na Real S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/208315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sphhkNFKoviCTUDBValbHgz1NBD.jpg'),
(102010, 7269, 'Amor na Real S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/208316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sphhkNFKoviCTUDBValbHgz1NBD.jpg'),
(102011, 7269, 'Amor na Real S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/208317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sphhkNFKoviCTUDBValbHgz1NBD.jpg'),
(102012, 7269, 'Amor na Real S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/208318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sphhkNFKoviCTUDBValbHgz1NBD.jpg'),
(102013, 7270, 'As Pequenas Coisas da Vida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m6gDrSq8grmaY8TPQPKf8PCaxLC.jpg'),
(102014, 7270, 'As Pequenas Coisas da Vida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kHmqoeOrQj9v9Zvw8QQqjFCPpaw.jpg'),
(102015, 7270, 'As Pequenas Coisas da Vida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gK9bcv7nqIEYSiMqG8gyIycPLe3.jpg'),
(102016, 7270, 'As Pequenas Coisas da Vida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gkcOhSQcH98aAaXurUmbXsu7Vuu.jpg'),
(102017, 7270, 'As Pequenas Coisas da Vida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQErfy5QuP5iQi0zCvAvM99rnbz.jpg'),
(102018, 7270, 'As Pequenas Coisas da Vida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vWUzHOadJ3SiKDkWQjXsVhURWfX.jpg'),
(102019, 7270, 'As Pequenas Coisas da Vida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vizvR51nvLkGIhVKSzINgUUPly8.jpg'),
(102020, 7270, 'As Pequenas Coisas da Vida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e2kugRzI8PRiFy2UHOFtu6PzGF1.jpg'),
(102021, 7271, 'Confeiteiros em Acao Desafios de Pascoa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213077.mp4', 'https://i.bj-share.info/b2762a8db1f232c429b2acb023361fc6.jpg'),
(102022, 7271, 'Confeiteiros em Acao Desafios de Pascoa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213078.mp4', 'https://i.bj-share.info/b2762a8db1f232c429b2acb023361fc6.jpg'),
(102023, 7271, 'Confeiteiros em Acao Desafios de Pascoa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213079.mp4', 'https://i.bj-share.info/b2762a8db1f232c429b2acb023361fc6.jpg'),
(102024, 7271, 'Confeiteiros em Acao Desafios de Pascoa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213080.mp4', 'https://i.bj-share.info/b2762a8db1f232c429b2acb023361fc6.jpg'),
(102025, 7271, 'Confeiteiros em Acao Desafios de Pascoa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213081.mp4', 'https://i.bj-share.info/b2762a8db1f232c429b2acb023361fc6.jpg'),
(102026, 7272, 'Crossover S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2oaV11MqGmwsOTLAE97XguiuJAy.jpg'),
(102027, 7272, 'Crossover S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gN75poeCUN74OO040wmMsutJrRQ.jpg'),
(102028, 7272, 'Crossover S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o8AtiRpZgetuATGK0kZSOxiRg3T.jpg'),
(102029, 7272, 'Crossover S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/run2K3RIEgGzg7m8di9FXxRMI4T.jpg'),
(102030, 7272, 'Crossover S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6x12Pxi8YHFqGCF71iKAblf0iiE.jpg'),
(102031, 7272, 'Crossover S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/39wu52iMkDuhhbPU8exD6CgnyJF.jpg'),
(102032, 7272, 'Crossover S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oiEsYy9kjnJhK5w47YtS1Onmrki.jpg'),
(102033, 7272, 'Crossover S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lujqFrN90QdPhfgGLYAtEpFCE3I.jpg'),
(102034, 7273, 'Despertar Mortal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213067.mp4', 'https://i.bj-share.info/4f379355fbc088f1104fcea7b3952ad9.jpg'),
(102035, 7273, 'Despertar Mortal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213068.mp4', 'https://i.bj-share.info/4f379355fbc088f1104fcea7b3952ad9.jpg'),
(102036, 7274, 'Em Má Companhia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dMRakMNZ8zUOg2qiFGLU4fJZGrs.jpg'),
(102037, 7274, 'Em Má Companhia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJz8qfZ2SKkLe7RJ13xvhGJBk2N.jpg'),
(102038, 7274, 'Em Má Companhia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215453.mp4', 'http://image.tmdb.org/t/p/w1280/EhdsMiEHK2ErAfV3yecbSvuP55.jpg'),
(102039, 7274, 'Em Má Companhia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215454.mp4', 'http://image.tmdb.org/t/p/w1280/cOUySxuohNWi1qZXJD47qCdSffJ.jpg'),
(102040, 7274, 'Em Má Companhia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215455.mp4', 'http://image.tmdb.org/t/p/w1280/oeVkGkJzKtqsYkCEI3n0qThsX0u.jpg'),
(102041, 7274, 'Em Má Companhia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215456.mp4', 'http://image.tmdb.org/t/p/w1280/7PX9Pn1N6BEJXHMfqokcfwNIsJd.jpg'),
(102042, 7274, 'Em Má Companhia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215457.mp4', 'http://image.tmdb.org/t/p/w1280/yyN8kZidTXlFLAQEVUqT8zR3ven.jpg'),
(102043, 7274, 'Em Má Companhia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215458.mp4', 'http://image.tmdb.org/t/p/w1280/pCdazwuavZFpvIpKj9FRwjMG3WT.jpg'),
(102044, 7274, 'Em Má Companhia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215459.mp4', 'http://image.tmdb.org/t/p/w1280/79Ip5J6q6q9PXexEU3Valv2XXQo.jpg'),
(102045, 7274, 'Em Má Companhia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k4NA0vNW3KfYM3mim4gIoejWSqe.jpg'),
(102046, 7275, 'Família em Primeiro Lugar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8KNn3HdBcZkOsl61OJgFOfdFzrh.jpg'),
(102047, 7275, 'Família em Primeiro Lugar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lmm73ePxKMo9cdA0ziStHv5ZUlJ.jpg'),
(102048, 7275, 'Família em Primeiro Lugar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLQW5RojkMrbTRiVieNarwfgl4g.jpg'),
(102049, 7275, 'Família em Primeiro Lugar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cbpF6BrSMO9tGz05tvoTigvlrBd.jpg'),
(102050, 7275, 'Família em Primeiro Lugar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zULm4IJLKTgvdn7SR64MKaDXGdk.jpg'),
(102051, 7275, 'Família em Primeiro Lugar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nb1ciX2IDBpgk4kf4fTGxLGZGuU.jpg'),
(102052, 7275, 'Família em Primeiro Lugar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7mifx8vLe7OJRGnv2omLGG4o74d.jpg'),
(102053, 7275, 'Família em Primeiro Lugar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Qwl743EcPQemsDyoZcxqeFOIaD.jpg'),
(102054, 7276, 'Gotham Knights: A Série S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qoqZmiDR3rgxvNzYf7sA6jvILdO.jpg'),
(102055, 7276, 'Gotham Knights: A Série S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zlcAbxHDMI3rn8P152uXxr839Tc.jpg'),
(102056, 7276, 'Gotham Knights: A Série S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8hgVFxw5TuiVXYI08og7XQ7odlP.jpg'),
(102057, 7276, 'Gotham Knights: A Série S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224178.mp4', 'http://image.tmdb.org/t/p/w1280/edJCvTkvn4iPsgbY6uEXoOFlIJK.jpg'),
(102058, 7276, 'Gotham Knights: A Série S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224179.mp4', 'http://image.tmdb.org/t/p/w1280/rAMFOw9JnZ2OfN6Krf9BvpNkrzD.jpg'),
(102059, 7276, 'Gotham Knights: A Série S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224180.mp4', 'http://image.tmdb.org/t/p/w1280/rbQQhdjNDFn1nYFZUgXkVLvVXqn.jpg'),
(102060, 7276, 'Gotham Knights: A Série S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224181.mp4', 'http://image.tmdb.org/t/p/w1280/yyLe8ZB48HkFD0M1JiRIH5Nr3J6.jpg'),
(102061, 7276, 'Gotham Knights: A Série S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224182.mp4', 'http://image.tmdb.org/t/p/w1280/frMw9aDmDCZ5MTQ0GKsqWUD9Sp2.jpg'),
(102062, 7276, 'Gotham Knights: A Série S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224183.mp4', 'http://image.tmdb.org/t/p/w1280/qWD9zRhV35c9janoOlvvcNi98ke.jpg'),
(102063, 7276, 'Gotham Knights: A Série S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224184.mp4', 'http://image.tmdb.org/t/p/w1280/fOrxLHSx62ps1bx1HKpyZkP7aCe.jpg'),
(102064, 7276, 'Gotham Knights: A Série S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kShT1yzQlqRZtlW6S9ByXfqeF5R.jpg'),
(102065, 7276, 'Gotham Knights: A Série S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224186.mp4', 'http://image.tmdb.org/t/p/w1280/4c5wrpkuzqnRCKd7tnRAFGydqGV.jpg'),
(102066, 7276, 'Gotham Knights: A Série S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224187.mp4', 'http://image.tmdb.org/t/p/w1280/l0sw4xRTI6qrB8WEa7YBIKKvPHi.jpg'),
(102067, 7277, 'Grease: Rise of the Pink Ladies S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mQHdDB9lX0dm75qlyDPBiSVrVMG.jpg'),
(102068, 7277, 'Grease: Rise of the Pink Ladies S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5xnyG8727c88maqmzf6e2kqFezg.jpg'),
(102069, 7277, 'Grease: Rise of the Pink Ladies S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216955.mp4', 'http://image.tmdb.org/t/p/w1280/rz3ONWDpjCCzilRpv5drRdKyyoh.jpg'),
(102070, 7277, 'Grease: Rise of the Pink Ladies S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216956.mp4', 'http://image.tmdb.org/t/p/w1280/1DggFQGBewpzNYfPXgf3JenAg22.jpg'),
(102071, 7277, 'Grease: Rise of the Pink Ladies S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216957.mp4', 'http://image.tmdb.org/t/p/w1280/a8LzeJBlO6IFiC9J5Lk11PBAww8.jpg'),
(102072, 7277, 'Grease: Rise of the Pink Ladies S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216958.mp4', 'http://image.tmdb.org/t/p/w1280/67TqOTBivK6g5g2abmDLtzW0Rqz.jpg'),
(102073, 7277, 'Grease: Rise of the Pink Ladies S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216959.mp4', 'http://image.tmdb.org/t/p/w1280/qYYlFfuujXfoSmEi8AL1CVoj4q5.jpg'),
(102074, 7277, 'Grease: Rise of the Pink Ladies S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216960.mp4', 'http://image.tmdb.org/t/p/w1280/65Zq7XWyLJ5mnm0L7zhULc4llQZ.jpg'),
(102075, 7277, 'Grease: Rise of the Pink Ladies S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216961.mp4', 'http://image.tmdb.org/t/p/w1280/1gR2McogPUAqHksjOANGSO6njsd.jpg'),
(102076, 7277, 'Grease: Rise of the Pink Ladies S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216962.mp4', 'http://image.tmdb.org/t/p/w1280/5JMgcaY1SiEByckMtrZuqe6Vtf5.jpg'),
(102077, 7278, 'Jubileu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wEQO0qcC9QmBFM0tGu68o3CtbdS.jpg'),
(102078, 7278, 'Jubileu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lojB9pexEXh96q1Pl0nN31Aysj3.jpg'),
(102079, 7278, 'Jubileu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4w37JxUXL7HACtHsE4BUwM010xD.jpg'),
(102080, 7278, 'Jubileu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gAaQ5tZn5hK9tw9hKWbwjqi8ypD.jpg'),
(102081, 7278, 'Jubileu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwB0M9xhlLh9gHxLBVCLpyaWPxz.jpg'),
(102082, 7279, 'Louco por Você S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bfBTlo4fDoSDHNOZhhi72CsnqaV.jpg'),
(102083, 7279, 'Louco por Você S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ft1HFjShjZqgcDA9hQWg08HCLm7.jpg'),
(102084, 7279, 'Louco por Você S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l5DEYWrdn0EhyDeTm6jJgRnFPct.jpg'),
(102085, 7279, 'Louco por Você S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wxE9Prs7WQYZuguRBEUVUHqb4Rb.jpg'),
(102086, 7279, 'Louco por Você S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zC32oiL7zOHEXyNC8BVEod8VfJu.jpg'),
(102087, 7279, 'Louco por Você S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kdQK0IfGBZY4mc99rgczA3Pbtcd.jpg'),
(102088, 7279, 'Louco por Você S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oN1175moIYRos0FchczZVeEqtfC.jpg'),
(102089, 7279, 'Louco por Você S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xssB5iNiDKkMXUL0jVD5oxcfXuD.jpg'),
(102090, 7279, 'Louco por Você S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lmLdE7o2R1iGjPNVg1a15QmfMlV.jpg'),
(102091, 7279, 'Louco por Você S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mPE2lm5csLBhwtDjwvm8j19inIi.jpg'),
(102092, 7279, 'Louco por Você S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/DvUQigl6g8i8M00khFW4IISOqQ.jpg'),
(102093, 7279, 'Louco por Você S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jWNAIiwgyyeBFkuIvz9wizQWqNA.jpg'),
(102094, 7279, 'Louco por Você S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/coXdzCzB4NQ2v8LubSwxpl32w0n.jpg'),
(102095, 7279, 'Louco por Você S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i8PSFbabhRwF2Pp3gO5sR62gK5N.jpg'),
(102096, 7279, 'Louco por Você S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mWDNuNaniKZR0a0mRpAurNUxpFG.jpg'),
(102097, 7279, 'Louco por Você S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/emE00RSQHbhF14Q7eRTbJjstOxF.jpg'),
(102098, 7279, 'Louco por Você S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0mrkY89daYG1oWWndYsu1018SJ.jpg'),
(102099, 7279, 'Louco por Você S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vR2jV1HJ7WfZdeeQbexrsDB5eTo.jpg'),
(102100, 7279, 'Louco por Você S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/83Q2YM2UGz6LieD3xzMkdROSIrS.jpg'),
(102101, 7279, 'Louco por Você S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jlwBa9gSb0xvKbBbmiKuqyRhZ8F.jpg'),
(102102, 7279, 'Louco por Você S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zlf3Sx0qaHgyIH8NkOgdLxMzWsl.jpg'),
(102103, 7279, 'Louco por Você S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5FRD9XTs1ANn1ChMchIZV8KbOW7.jpg'),
(102104, 7280, 'Louco por Você S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/22pQyIEpITx3ABNSuZDEP23QHeB.jpg'),
(102105, 7280, 'Louco por Você S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cyTRghyaV6FeLMQiXUsmOZGC4nw.jpg'),
(102106, 7280, 'Louco por Você S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBnYajgDcK5DvOnwL4QfAvsySet.jpg'),
(102107, 7280, 'Louco por Você S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oUuP3cCuzaKz9SryrZoTB2yRI2I.jpg'),
(102108, 7280, 'Louco por Você S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iiEHyrrOmyqc2eoRBXNxk4JgWGz.jpg'),
(102109, 7280, 'Louco por Você S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pA9U4zABM6WqkvKDiVnA6FBoipy.jpg'),
(102110, 7280, 'Louco por Você S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nQivLZ13zJQDJsjoJjXCptwEmr1.jpg'),
(102111, 7280, 'Louco por Você S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/OgQ1qjQMO7wut3Ntgcd5fVJIYE.jpg'),
(102112, 7280, 'Louco por Você S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sXxWqGLwp5SQXlF3tuCgYoqjIw2.jpg'),
(102113, 7280, 'Louco por Você S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7nhVNtcdsceWWH9lUbQg6FPEkLQ.jpg'),
(102114, 7280, 'Louco por Você S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Rsbn41Xmmfw9SjDY7lW2Rlgzpr.jpg'),
(102115, 7280, 'Louco por Você S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uGI2eFx7sXgS4hrPRD4BV8YSNtG.jpg'),
(102116, 7280, 'Louco por Você S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jfpeEkOyGoobMVBiiqIxWmDDsgn.jpg'),
(102117, 7280, 'Louco por Você S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aGkZtHysv8RLiNQu9REFPoRW5W0.jpg'),
(102118, 7280, 'Louco por Você S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ujCoKYOFhYTKj3Hk3Pk7hVcdHoV.jpg'),
(102119, 7280, 'Louco por Você S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gRSUhbKqEuQrssftWomOJu1SdwT.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(102120, 7280, 'Louco por Você S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9WSmB0FNKeixfkgRidbRgikZNmn.jpg'),
(102121, 7280, 'Louco por Você S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mx1OpPd6YFCf51dsdcyEctrGcC8.jpg'),
(102122, 7280, 'Louco por Você S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bKWJ5pTlDrsQMUIHhu3RdgBrzML.jpg'),
(102123, 7280, 'Louco por Você S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xpwf9Zi6ECO8OwTb2rdc0fbXnWV.jpg'),
(102124, 7280, 'Louco por Você S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zSC8OZiL1BfrwNMaLzYXZQ2O8Bs.jpg'),
(102125, 7280, 'Louco por Você S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1LsWgLlYiV0vcyPgewxou319CMV.jpg'),
(102126, 7280, 'Louco por Você S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/212934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gjrsnCxXppFJ2sWXMknOaMcE33e.jpg'),
(102127, 7280, 'Louco por Você S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/212935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y2rCYAFLWtW23FBg8EEadYT45BW.jpg'),
(102128, 7280, 'Louco por Você S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/212936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oTfIuILjO9cmwLO49LyEYY8hYLb.jpg'),
(102129, 7281, 'Louco por Você S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0PuPXAKdiPsGDuStQeQ9xA6OLk.jpg'),
(102130, 7281, 'Louco por Você S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZQJ3A1ksycM9zAsKnGhNHEwlZt.jpg'),
(102131, 7281, 'Louco por Você S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAq15heT4hj6noHz1Qpb3e2IqEb.jpg'),
(102132, 7281, 'Louco por Você S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u313sxLZK7sD1uVKCiGLV9hVkdY.jpg'),
(102133, 7281, 'Louco por Você S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLGgPYF6lfFIGmlg9RFVEEpC94f.jpg'),
(102134, 7281, 'Louco por Você S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6cdCv7bmIGYMXCz8l17mfaYQSQx.jpg'),
(102135, 7281, 'Louco por Você S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ac3ExArN6Q54xrX1gTgGlxVocKU.jpg'),
(102136, 7281, 'Louco por Você S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3jZ0dGr0hjWbPhiggMW4FLDs9id.jpg'),
(102137, 7281, 'Louco por Você S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ynDM6PDzrvmRqsSgwXjIULchkBl.jpg'),
(102138, 7281, 'Louco por Você S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g6n0yzt8WOo66USpEJBZhZ0ccuf.jpg'),
(102139, 7281, 'Louco por Você S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rS8VvZMJfvWNhtQn0QynApiE5ez.jpg'),
(102140, 7281, 'Louco por Você S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dc0lf2olZYOHwBU7nvZlbv2ubvn.jpg'),
(102141, 7281, 'Louco por Você S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7jLjgeAXTo5RrggoWGcDNcvqrJm.jpg'),
(102142, 7281, 'Louco por Você S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/KJ8SS0TPtWdbdw6bKDZQdcjM7D.jpg'),
(102143, 7281, 'Louco por Você S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2uVXRJ07rvlfdldYkWMQq6rmhgx.jpg'),
(102144, 7281, 'Louco por Você S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pcXD40WGoBQiM87AcD0M3ofCFK1.jpg'),
(102145, 7281, 'Louco por Você S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4AC5wwqqHcTPnCUENyDJ4HpRQSG.jpg'),
(102146, 7281, 'Louco por Você S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rAeTfZukd4QqtHEtJWTYgRh9tSM.jpg'),
(102147, 7281, 'Louco por Você S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9GJqd9Ix4fY0EM2eBGx6poL4b4T.jpg'),
(102148, 7281, 'Louco por Você S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h8BVuwHJ5zb1ideyJVbP6LBj8wd.jpg'),
(102149, 7281, 'Louco por Você S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/klDr6alqldL0XmyhupkIYiSPmbe.jpg'),
(102150, 7281, 'Louco por Você S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vZF9ukGSJ2dBAQBkeXXUmIguDzK.jpg'),
(102151, 7281, 'Louco por Você S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/212959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fzOFdgWIlN3i6TYmPOWxSXjToVa.jpg'),
(102152, 7281, 'Louco por Você S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/212960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ke9PxMzTmA1VGNjBtlKevYqLbKi.jpg'),
(102153, 7282, 'Louco por Você S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/twtYHsmHbj1sn5MxIBX820uXh1J.jpg'),
(102154, 7282, 'Louco por Você S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f3ZuaRmlEa7sLMneivT42oNjY7j.jpg'),
(102155, 7282, 'Louco por Você S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7tVR1DATOEtsWswdmZkhkCiEsA3.jpg'),
(102156, 7282, 'Louco por Você S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wETEaitk8M5xWVmPZYCb5qvhEQc.jpg'),
(102157, 7282, 'Louco por Você S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cqQ0DuJSlO3f0vJ2lnLtr2R0o6Q.jpg'),
(102158, 7282, 'Louco por Você S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mp0o0PjMs0sj24hZYDWrOzM04Mp.jpg'),
(102159, 7282, 'Louco por Você S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iPsSIbfaKzJUa34xYsKzfxzxFlS.jpg'),
(102160, 7282, 'Louco por Você S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y7fUrq33bmVJk4u91YjWpNePv3c.jpg'),
(102161, 7282, 'Louco por Você S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xC2m7aTwUrsdmPTBcCSf0g9ww55.jpg'),
(102162, 7282, 'Louco por Você S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6PdKnJUrpknlD33V8BtqUlogM6h.jpg'),
(102163, 7282, 'Louco por Você S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ak8ZstHEIp0vKAer3BDvUzGKhno.jpg'),
(102164, 7282, 'Louco por Você S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AkGUp56N6LxOqK3XdPCE6JqWITM.jpg'),
(102165, 7282, 'Louco por Você S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8323Dnf9t9BuJjoI9fImnOPFDLC.jpg'),
(102166, 7282, 'Louco por Você S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/64uZ5E6XhSm1DqTBgTfbDaDwalK.jpg'),
(102167, 7282, 'Louco por Você S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qp6EFBgt2xA9pTZwbh5zmDh7RCi.jpg'),
(102168, 7282, 'Louco por Você S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lhRa8inZvRgRkRfC6eBpJ5owxsQ.jpg'),
(102169, 7282, 'Louco por Você S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ir8WKhV77CIyepM9A5QugAIGk40.jpg'),
(102170, 7282, 'Louco por Você S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i1AfJw5bb5vgtrejFIhmpKwU1Dp.jpg'),
(102171, 7282, 'Louco por Você S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o7iRY9wjgvxyZW8oGorT8tF5Mif.jpg'),
(102172, 7282, 'Louco por Você S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zcAGC673gFG5M2Q9AVWaRT6c8ud.jpg'),
(102173, 7282, 'Louco por Você S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wA0hQw3p5W4auoJzW02YAoP3rWI.jpg'),
(102174, 7282, 'Louco por Você S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tiC0EHGEZ5KuuzSWDQ8xtAhrxRn.jpg'),
(102175, 7282, 'Louco por Você S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/212983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6lOjuHKgP58TRJslInullNRSx0x.jpg'),
(102176, 7282, 'Louco por Você S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/212984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gKqfeKNkVFSASRm1cP5YI8QthVE.jpg'),
(102177, 7283, 'Louco por Você S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3saJxppDBkSWNhJnMKjsyWjJBYE.jpg'),
(102178, 7283, 'Louco por Você S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lu5wqDTrhvrxCZM20ot4a3p0bmy.jpg'),
(102179, 7283, 'Louco por Você S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uLA0T2BPxzogVhK0n3JGswXI9Fm.jpg'),
(102180, 7283, 'Louco por Você S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8f14CtYtxcGob3DTvOHawqPhBFV.jpg'),
(102181, 7283, 'Louco por Você S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iiry68oGN5Qc1Dj4xwGezwCKTSP.jpg'),
(102182, 7283, 'Louco por Você S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMM6k7j3D4hCdknapv0QEaBHWfj.jpg'),
(102183, 7283, 'Louco por Você S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p9NgKJUXan3zPYeUv62FXsWRHfU.jpg'),
(102184, 7283, 'Louco por Você S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pAnz2KPhF1QdcxVhrneclc8JZkf.jpg'),
(102185, 7283, 'Louco por Você S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tAdiU1R1L6riQjsm5vsskLXvmKI.jpg'),
(102186, 7283, 'Louco por Você S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uu3NBYAJVr9HLkjLzULdET3vMwE.jpg'),
(102187, 7283, 'Louco por Você S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jdeI3mvjdFGejWinHvRkoLo3aWF.jpg'),
(102188, 7283, 'Louco por Você S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7NXjjF0uxFsJZwZr74EdildtCYo.jpg'),
(102189, 7283, 'Louco por Você S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Fwx0qS911OzTuVxohlakDPSqlS.jpg'),
(102190, 7283, 'Louco por Você S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gLBkPUiEILTP91YZcTpVLpeIX11.jpg'),
(102191, 7283, 'Louco por Você S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Cqff7u1rLAS8Fybt2dozDOntJb.jpg'),
(102192, 7283, 'Louco por Você S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/213000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/WmepMHV0xtgySBjsRbo0bNmptk.jpg'),
(102193, 7283, 'Louco por Você S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/213001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rUZe2agpVRdan5IMvfcDgeTWFXl.jpg'),
(102194, 7283, 'Louco por Você S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/213002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/us7K0ibn8EPbIs75kttqWaQBH7X.jpg'),
(102195, 7283, 'Louco por Você S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/213003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2rkGA26Ld7kt2mm9fBwqhZ6mt85.jpg'),
(102196, 7283, 'Louco por Você S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/213004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3g2rC9eJntFKdSRr5MFHtZSiyjG.jpg'),
(102197, 7283, 'Louco por Você S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/213005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3iw67AMPXzEiCqYXh8rDc35FMaK.jpg'),
(102198, 7283, 'Louco por Você S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/213006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/MpSh5yJUk7hX1BKLja7wJ6rCyV.jpg'),
(102199, 7283, 'Louco por Você S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/213007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9O955K3vDDkmuVg1fCVIjidGaEJ.jpg'),
(102200, 7283, 'Louco por Você S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/213008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dsWxKK2FAC4xEk8nLGhX4tIf8Cd.jpg'),
(102201, 7284, 'Louco por Você S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vxYBipWNiK9FGKQkj0SUOT4QxZj.jpg'),
(102202, 7284, 'Louco por Você S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kdHt7pAlUsCsaGf50jKXsiPPffi.jpg'),
(102203, 7284, 'Louco por Você S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6b3NMQJNwZzqD9dh58DP5ODHpqw.jpg'),
(102204, 7284, 'Louco por Você S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FzizFdAAo2KP9wsNIt90nBll8u.jpg'),
(102205, 7284, 'Louco por Você S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4lcdGcnHwg8oU6C7g2Fk6iotAEg.jpg'),
(102206, 7284, 'Louco por Você S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h5RF9ojtnoIswxnfSolfQmLcsE5.jpg'),
(102207, 7284, 'Louco por Você S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ixqYZASwthaNKSBvoKeTznEqPYk.jpg'),
(102208, 7284, 'Louco por Você S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9kshvs9mqqqYSq9eeOXIskR1fyK.jpg'),
(102209, 7284, 'Louco por Você S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8EY16ZuegUOHFzITa7gkuW10fx.jpg'),
(102210, 7284, 'Louco por Você S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o46qJVELVeJ0tdwLqZEhU1gZqXi.jpg'),
(102211, 7284, 'Louco por Você S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/213019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u3n6NuXTStckyLBS2lhMu8MQUQ6.jpg'),
(102212, 7284, 'Louco por Você S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/213020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tWd4QCsRGClsmYs3IiScGtmTu4X.jpg'),
(102213, 7284, 'Louco por Você S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/213021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uR3a0bMOUbfeeeyBJXSXzSPTbO4.jpg'),
(102214, 7284, 'Louco por Você S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/213022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bofv5yTtVVN3Qw61aq5v9szt5ZP.jpg'),
(102215, 7284, 'Louco por Você S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/213023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/YjykOMqJ5vKnA6ELOw8Jlagi8w.jpg'),
(102216, 7284, 'Louco por Você S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/213024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lHvdAWWS56siCbdGVrB0XHagbRp.jpg'),
(102217, 7284, 'Louco por Você S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/213025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qgLEl6dnE0c8TKzazW6bMuJZLSJ.jpg'),
(102218, 7284, 'Louco por Você S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/213026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AgJadOY7fCKtLW0h5fQbpHSbdHo.jpg'),
(102219, 7284, 'Louco por Você S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/213027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v5ZgRxRvCQEXRxdHOF8fipBUgJS.jpg'),
(102220, 7284, 'Louco por Você S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/213028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aYyVQrqZ25vXiTG6jkFmqUCh6IR.jpg'),
(102221, 7284, 'Louco por Você S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/213029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9PejM0AWMKLC1XRiL9clYAgmTov.jpg'),
(102222, 7284, 'Louco por Você S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/213030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bX1Y9ioRYTgngvArLExJ3j7QsN1.jpg'),
(102223, 7284, 'Louco por Você S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/213031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rg0D44iNcqY49uxdXhNpb0oDEGz.jpg'),
(102224, 7285, 'Louco por Você S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9syqdpplURUHeU78ecTrmicDNN2.jpg'),
(102225, 7285, 'Louco por Você S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wYh3aP3c8oY8LhEUUJ7uEMvsULE.jpg'),
(102226, 7285, 'Louco por Você S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yN0aUzAejfHPfO6enPsTu5gD7H9.jpg'),
(102227, 7285, 'Louco por Você S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eNJk1wNSQsNBwNnsbxgkhGNNnJX.jpg'),
(102228, 7285, 'Louco por Você S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b4yDNgYRzP3eM9KKCBRvPamditk.jpg'),
(102229, 7285, 'Louco por Você S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6a0D07G30OZgXwtxwkoZEH1ffPe.jpg'),
(102230, 7285, 'Louco por Você S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kFRwwI6Di6ciDGqW4hiijHwVJpS.jpg'),
(102231, 7285, 'Louco por Você S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2gNbPw5CF2pz2bFaSmkUuw0oO3.jpg'),
(102232, 7285, 'Louco por Você S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r6gySaBqvYm1A1SZssC4oEjXajO.jpg'),
(102233, 7285, 'Louco por Você S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wcvR57xnXTLCrAqT7OjEJyaU9dz.jpg'),
(102234, 7285, 'Louco por Você S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/213042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lJwoCQL3f3ln1roWPTsVT8DsByu.jpg'),
(102235, 7285, 'Louco por Você S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/213043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oKLlnAXtzgGOy55Ze8yLsIKXQIY.jpg'),
(102236, 7285, 'Louco por Você S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/213044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xYafoxzox0kNhjqYYiwXWQMWwqW.jpg'),
(102237, 7285, 'Louco por Você S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/213045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1mLFzpsieFM7EB4pVmyjrJ5t01Q.jpg'),
(102238, 7285, 'Louco por Você S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/213046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3cOmJn5IrVgi1HGV91D80Z3Yk43.jpg'),
(102239, 7285, 'Louco por Você S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/213047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/86wkzY0pXpBGDvpQfbqKPCdrkS9.jpg'),
(102240, 7285, 'Louco por Você S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/213048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/60sjTKwbntuJqM4RdWb5AfnAvBK.jpg'),
(102241, 7285, 'Louco por Você S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/213049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cdxpJmTctphDSQnS2oodJHZeUX2.jpg'),
(102242, 7285, 'Louco por Você S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/213050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p48nCO4XgGC34lFPYx12elYbKIU.jpg'),
(102243, 7285, 'Louco por Você S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/213051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gnjbOZKdZCkF1wDnDRpaS4xePQp.jpg'),
(102244, 7285, 'Louco por Você S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/213052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cjeTWcMs0OUF93c489G3xIx6jFd.jpg'),
(102245, 7285, 'Louco por Você S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/213053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hehy0i2eUD494QErzcrsmjLVnUL.jpg'),
(102246, 7286, 'Mães da Máfia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1B0rHzBKEAJYJx0DyNwaiLzCVVP.jpg'),
(102247, 7286, 'Mães da Máfia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6XLqUBW44J6bsC368Y7CJdAoiP.jpg'),
(102248, 7286, 'Mães da Máfia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lWXxKX2odkFgAwdhjJovHFQEdsi.jpg'),
(102249, 7286, 'Mães da Máfia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wCzfzKdB6PksSY5BaCc3T0qbHBM.jpg'),
(102250, 7286, 'Mães da Máfia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qDs7mvqg2NsdIWtfmaY3s1nzrhP.jpg'),
(102251, 7286, 'Mães da Máfia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dE8XdE1HGJXRpN04c5qtoRyKfsr.jpg'),
(102252, 7287, 'Mariachis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Sgrqr77JdttVjmOTQoTFKuzW83.jpg'),
(102253, 7287, 'Mariachis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6azkO6LDJrPXc7NGfVmIHLHOTot.jpg'),
(102254, 7287, 'Mariachis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bMbT3kz4X5lGRh8B0PuKINbhXm0.jpg'),
(102255, 7287, 'Mariachis S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jkduxKcbBDKjAJNMw4YzVjuV1oX.jpg'),
(102256, 7287, 'Mariachis S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9i71ZlBZgbRb9LzACbnIflhVZcn.jpg'),
(102257, 7287, 'Mariachis S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvxTbH7NqRpqh9jCDxa5OPakFSb.jpg'),
(102258, 7287, 'Mariachis S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b45MsfBpu1fruqz8Yf8dJDte5FQ.jpg'),
(102259, 7287, 'Mariachis S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nmWNGnb2GFbQyW0KcBBGKfT7xMh.jpg'),
(102260, 7288, 'O Advogado de Divórcio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wpzW3lVWD7NcLgcIQJjqDDOtXys.jpg'),
(102261, 7288, 'O Advogado de Divórcio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9Hiyanxlk5lG2dG0XSfb1Z79n4.jpg'),
(102262, 7288, 'O Advogado de Divórcio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213793.mp4', 'http://image.tmdb.org/t/p/w1280/edEHjsi4W1MMJTtMMgoX42rOa9e.jpg'),
(102263, 7288, 'O Advogado de Divórcio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213794.mp4', 'http://image.tmdb.org/t/p/w1280/323rjyY7QWgAcCSnQYNN1XxaTBr.jpg'),
(102264, 7288, 'O Advogado de Divórcio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213795.mp4', 'http://image.tmdb.org/t/p/w1280/kRI1aFKW1ohV84HyH7hOfd4XLzO.jpg'),
(102265, 7288, 'O Advogado de Divórcio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213796.mp4', 'http://image.tmdb.org/t/p/w1280/4dmCgHzBgfpOY4cLIgts7HFttPx.jpg'),
(102266, 7288, 'O Advogado de Divórcio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213797.mp4', 'http://image.tmdb.org/t/p/w1280/f3BMVOrKe5o0Wcp80qqRIkB1DNJ.jpg'),
(102267, 7288, 'O Advogado de Divórcio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213798.mp4', 'http://image.tmdb.org/t/p/w1280/6jjlAwg9KKhdFZqoQHtWA9YnCNX.jpg'),
(102268, 7288, 'O Advogado de Divórcio S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213799.mp4', 'http://image.tmdb.org/t/p/w1280/6YLijf8hoN8jfBGVmhlvbGBVact.jpg'),
(102269, 7288, 'O Advogado de Divórcio S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213800.mp4', 'http://image.tmdb.org/t/p/w1280/aPOA3vItJ7K7DBVVJ0mywawz108.jpg'),
(102270, 7288, 'O Advogado de Divórcio S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/213801.mp4', 'http://image.tmdb.org/t/p/w1280/zwwemB70skC5qMcb28PRN6W95F.jpg'),
(102271, 7288, 'O Advogado de Divórcio S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/213802.mp4', 'http://image.tmdb.org/t/p/w1280/me5Yx9a8B67TSVUSSXg8K4DvzRa.jpg'),
(102272, 7289, 'O Menino Maluquinho S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102273, 7289, 'O Menino Maluquinho S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102274, 7289, 'O Menino Maluquinho S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102275, 7289, 'O Menino Maluquinho S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102276, 7289, 'O Menino Maluquinho S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102277, 7289, 'O Menino Maluquinho S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102278, 7289, 'O Menino Maluquinho S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102279, 7289, 'O Menino Maluquinho S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102280, 7289, 'O Menino Maluquinho S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102281, 7289, 'O Menino Maluquinho S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102282, 7289, 'O Menino Maluquinho S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102283, 7289, 'O Menino Maluquinho S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102284, 7289, 'O Menino Maluquinho S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102285, 7289, 'O Menino Maluquinho S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102286, 7289, 'O Menino Maluquinho S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102287, 7289, 'O Menino Maluquinho S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102288, 7289, 'O Menino Maluquinho S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102289, 7289, 'O Menino Maluquinho S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102290, 7289, 'O Menino Maluquinho S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102291, 7289, 'O Menino Maluquinho S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102292, 7289, 'O Menino Maluquinho S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102293, 7289, 'O Menino Maluquinho S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102294, 7289, 'O Menino Maluquinho S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/212872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102295, 7289, 'O Menino Maluquinho S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/212873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102296, 7289, 'O Menino Maluquinho S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/212874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102297, 7289, 'O Menino Maluquinho S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/212875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/37aj7Vuci28GJz1AXiESAb74tGM.jpg'),
(102298, 7290, 'Transatlântico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9CvJgI0kwRWVFTgHKz5KqDLTSpF.jpg'),
(102299, 7290, 'Transatlântico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ixRZkUwyRv4yJUd4B2ParqHzzJU.jpg'),
(102300, 7290, 'Transatlântico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zkUbCOAJ8qtzYFDbVv9naFPqT3l.jpg'),
(102301, 7290, 'Transatlântico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5yicTZ6uNtQcf753zek1GDRKT7C.jpg'),
(102302, 7290, 'Transatlântico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mQqKw0oLVKRjZH4IiyZueztSwYU.jpg'),
(102303, 7290, 'Transatlântico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s7Vj8g3UY6N85jrmUe46cRQARib.jpg'),
(102304, 7290, 'Transatlântico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5i3UgTKPrMD1EGVmRjbJ5aeE66Q.jpg'),
(102305, 7291, 'Treta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jFTsOVTqatG4NsdWkUM4XMyhhrg.jpg'),
(102306, 7291, 'Treta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aGyahEgRAe4Wn1rTd5xklidgA8b.jpg'),
(102307, 7291, 'Treta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCK91yZDH06muZ2CmyY9RFyZdAy.jpg'),
(102308, 7291, 'Treta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hv3GDBq0e4CVRtQ6tNbEmgERjPk.jpg'),
(102309, 7291, 'Treta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c4oNWU5RFH9AmZnBeSQCWvyNiHm.jpg'),
(102310, 7291, 'Treta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/88bxKGbJntnCqF2TcfMY8SZUQTm.jpg'),
(102311, 7291, 'Treta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSEgDFh1Mt7zbxDGv40cddTIFR3.jpg'),
(102312, 7291, 'Treta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q2vb8sPF9rJJBalpGWCfnpqKsoy.jpg'),
(102313, 7291, 'Treta S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r6KrvoZUUinKnfP1I4pPZfSit1t.jpg'),
(102314, 7291, 'Treta S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXVwKEWWLnRJuh96T6bdEr3oP62.jpg'),
(102315, 7292, 'Viagem ao Centro da Terra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHe5cxwbmB52D76whIFZo9z9ml7.jpg'),
(102316, 7292, 'Viagem ao Centro da Terra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Gtp2xpmIYV7VTL5ZRScKlaNLrP.jpg'),
(102317, 7292, 'Viagem ao Centro da Terra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cfcH7Z7lkU1OApyAh0FSMKAFFPS.jpg'),
(102318, 7292, 'Viagem ao Centro da Terra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6NzH6IKzIaKFa17kAFTNwyyQmBC.jpg'),
(102319, 7292, 'Viagem ao Centro da Terra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nPdlJMxfRG8Y5bymArmjqmbC5Vl.jpg'),
(102320, 7292, 'Viagem ao Centro da Terra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/reO9yna7sPMO7d4kvK9kdsargk1.jpg'),
(102321, 7292, 'Viagem ao Centro da Terra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ozmEY2pNl8ndrRPH3Elg5BY4sEs.jpg'),
(102322, 7292, 'Viagem ao Centro da Terra S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qlKQUl69PuI6QckrKLBKUR6f8Bh.jpg'),
(102323, 7293, 'A Ilha das Sombras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uecRTBZhqwFuI6Z5vLNQ4bdKkXv.jpg'),
(102324, 7293, 'A Ilha das Sombras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qh35OCNANzjUajTtqj0wQkwl9tj.jpg'),
(102325, 7293, 'A Ilha das Sombras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEnYJUGzQk4gPVhAsWwmTqwRJrg.jpg'),
(102326, 7293, 'A Ilha das Sombras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ez3HnvCXgqxcx1xe1CO1VogGlJM.jpg'),
(102327, 7293, 'A Ilha das Sombras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6sqKxUthp9cPHH3POJbaaOBbOJV.jpg'),
(102328, 7293, 'A Ilha das Sombras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qIHdpsKuaFrz2bqxKz3hrcRFFOz.jpg'),
(102329, 7293, 'A Ilha das Sombras S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rAdIdJr3UvDvN5HNImrQiVrOVON.jpg'),
(102330, 7293, 'A Ilha das Sombras S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nrd9cgfzx558mhHcYbB3KEHnUuv.jpg'),
(102331, 7293, 'A Ilha das Sombras S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7VXyaFg3eBZoHBLva19hfIg9AaN.jpg'),
(102332, 7293, 'A Ilha das Sombras S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gnV6CZFm5HY9BX57fWqF8oNQZQf.jpg'),
(102333, 7293, 'A Ilha das Sombras S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vQ1t2uOIQDzvNUmP8rzC3vwkfs8.jpg'),
(102334, 7293, 'A Ilha das Sombras S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wbZRYlIiEjxBPN01TNB1bzd31ZF.jpg'),
(102335, 7293, 'A Ilha das Sombras S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tHILrZERamkHV9DW0jMxwTEuRQ.jpg'),
(102336, 7293, 'A Ilha das Sombras S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gBfmDiP2J6xcVXbynaMv1cAQILI.jpg'),
(102337, 7293, 'A Ilha das Sombras S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ovt972DZTdBudl8J00c9x3wIgwo.jpg'),
(102338, 7293, 'A Ilha das Sombras S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m6LoVAwK9AQsOA7Mhye6olVgNPU.jpg'),
(102339, 7293, 'A Ilha das Sombras S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJo1rWZ3jpWqVUBnb3ZPBVXgoej.jpg'),
(102340, 7293, 'A Ilha das Sombras S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qsnP5mQks2KPdOscC8CI08iDQIJ.jpg'),
(102341, 7293, 'A Ilha das Sombras S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oYlvDLYoiG0ZIzEDRlRuiLihY67.jpg'),
(102342, 7293, 'A Ilha das Sombras S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yj2ytWA9fhIA4QCzVmrn7cEgRna.jpg'),
(102343, 7293, 'A Ilha das Sombras S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n2gaUG665rQBUMdAxuwbQmhAxgv.jpg'),
(102344, 7293, 'A Ilha das Sombras S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y0o1f1sgHcEKY7V3H5shUDTs7DV.jpg'),
(102345, 7293, 'A Ilha das Sombras S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/212338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wYCEImkZ3Ed40TThZvSTy9v6vi9.jpg'),
(102346, 7293, 'A Ilha das Sombras S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/212339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zmeX60phHFAZnhHQJVjdkbotNhZ.jpg'),
(102347, 7293, 'A Ilha das Sombras S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/212340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dte47isGfQJnjVyjZRMjwSdE6JX.jpg'),
(102348, 7294, 'A Última Coisa Que Ele Me Falou S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Iz3oGNFtO474Xo06YETe3uEplG.jpg'),
(102349, 7294, 'A Última Coisa Que Ele Me Falou S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eVmImnccYzViKw4Yj3xTuFAcvLT.jpg'),
(102350, 7294, 'A Última Coisa Que Ele Me Falou S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213288.mp4', 'http://image.tmdb.org/t/p/w1280/cW2rnE27vnf4yvL8ofqeIAwFkVC.jpg'),
(102351, 7294, 'A Última Coisa Que Ele Me Falou S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213289.mp4', 'http://image.tmdb.org/t/p/w1280/646E0Dky8Cfda9ObMDNt1EaLJ53.jpg'),
(102352, 7294, 'A Última Coisa Que Ele Me Falou S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213290.mp4', 'http://image.tmdb.org/t/p/w1280/3AaQrrDjmupDEAONm8ppHPtvOCF.jpg'),
(102353, 7294, 'A Última Coisa Que Ele Me Falou S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213291.mp4', 'http://image.tmdb.org/t/p/w1280/vpURuoPKZMdKHA8F23OrDN7aU7B.jpg'),
(102354, 7294, 'A Última Coisa Que Ele Me Falou S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213292.mp4', 'http://image.tmdb.org/t/p/w1280/jQFCkwo4PKaDB91MSm9tCpTkpKv.jpg'),
(102355, 7295, 'Blue Lock S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ejH2YmotIR43Ly3rg4sFyRDpgTW.jpg'),
(102356, 7295, 'Blue Lock S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aky840u8pGRK7PwmuX9WBos5hDs.jpg'),
(102357, 7295, 'Blue Lock S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fqRdy7JwdDz7prYdSPRgkIh9VAe.jpg'),
(102358, 7295, 'Blue Lock S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jkmFcejcBcE9q2IudDbHD6Qs3sG.jpg'),
(102359, 7295, 'Blue Lock S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3eKzBqE54oJjhRcZNUU3ZOBLbPn.jpg'),
(102360, 7295, 'Blue Lock S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1kPac9sUuxdUsZjOVQtG3Diyd5t.jpg'),
(102361, 7295, 'Blue Lock S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ekRguJhtzJ75J8RC2IoluPHvZXr.jpg'),
(102362, 7295, 'Blue Lock S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jGx7T6LLxzGY4YukGTA9cYCPot8.jpg'),
(102363, 7295, 'Blue Lock S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0fZZIY5XKjd6GZma9CMJJwwOeo.jpg'),
(102364, 7295, 'Blue Lock S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzkoANEfoiQRkhFqvABVl1BrOt6.jpg'),
(102365, 7295, 'Blue Lock S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9hWWOSjsB2ee0D8zfCK9fNnf3W0.jpg'),
(102366, 7295, 'Blue Lock S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5A6KYN6G1LlmGz31LpYxrWrfepF.jpg'),
(102367, 7295, 'Blue Lock S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3YLyFoHiNHKwxS0Ecu0HIK0pee.jpg'),
(102368, 7295, 'Blue Lock S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hgjHD9fF6BCvHuY0A9net0cn6qU.jpg'),
(102369, 7295, 'Blue Lock S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jz8mJfx1CFKNrQrl7VmPyUXEnq9.jpg'),
(102370, 7295, 'Blue Lock S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vfJ0TI25jRCLzjeWfQr1EqZC0JK.jpg'),
(102371, 7295, 'Blue Lock S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7oiLxFCYUHt1EvnD6aKrKZB9eRF.jpg'),
(102372, 7295, 'Blue Lock S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xtA0MjO9kxNMDnFtMXQp1wy7Y36.jpg'),
(102373, 7295, 'Blue Lock S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1cE38jeGcVEoV8OzIHfTjC9boO5.jpg'),
(102374, 7295, 'Blue Lock S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iDAUma1z37LEegD66tNFEgH8v0y.jpg'),
(102375, 7295, 'Blue Lock S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6sWjg3ANtiZb9i2CdZidDesWGMo.jpg'),
(102376, 7295, 'Blue Lock S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lW6B2udjVzh4E9WLSWCAbP6jvEk.jpg'),
(102377, 7295, 'Blue Lock S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/212314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/buytu8R9oVv4QIAA0FW9swSGBTB.jpg'),
(102378, 7295, 'Blue Lock S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/212315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kCufxxbyqEwOjxlQ1B1Zztc7gPp.jpg'),
(102379, 7296, 'Blue Lock S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/660769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cmEkoiUbktAhV1Rw9GgZEDpOOA.jpg'),
(102380, 7296, 'Blue Lock S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/660770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cmEkoiUbktAhV1Rw9GgZEDpOOA.jpg'),
(102381, 7296, 'Blue Lock S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/660771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cmEkoiUbktAhV1Rw9GgZEDpOOA.jpg'),
(102382, 7296, 'Blue Lock S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/660772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cmEkoiUbktAhV1Rw9GgZEDpOOA.jpg'),
(102383, 7296, 'Blue Lock S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/660773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cmEkoiUbktAhV1Rw9GgZEDpOOA.jpg'),
(102384, 7296, 'Blue Lock S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/660774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cmEkoiUbktAhV1Rw9GgZEDpOOA.jpg'),
(102385, 7296, 'Blue Lock S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/660775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cmEkoiUbktAhV1Rw9GgZEDpOOA.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(102386, 7296, 'Blue Lock S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/660776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cmEkoiUbktAhV1Rw9GgZEDpOOA.jpg'),
(102387, 7296, 'Blue Lock S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/660777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cmEkoiUbktAhV1Rw9GgZEDpOOA.jpg'),
(102388, 7296, 'Blue Lock S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/660778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cmEkoiUbktAhV1Rw9GgZEDpOOA.jpg'),
(102389, 7296, 'Blue Lock S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/660779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cmEkoiUbktAhV1Rw9GgZEDpOOA.jpg'),
(102390, 7296, 'Blue Lock S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/660780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cmEkoiUbktAhV1Rw9GgZEDpOOA.jpg'),
(102391, 7296, 'Blue Lock S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/669907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cmEkoiUbktAhV1Rw9GgZEDpOOA.jpg'),
(102392, 7296, 'Blue Lock S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/669908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cmEkoiUbktAhV1Rw9GgZEDpOOA.jpg'),
(102393, 7297, 'Desejo Obsessivo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/miNNU7NqOAei7GeyqsCz6yMUANt.jpg'),
(102394, 7297, 'Desejo Obsessivo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t3Hm7rcyg2E8OsofGoM96105fhJ.jpg'),
(102395, 7297, 'Desejo Obsessivo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nm4CpQ2QncBFBPDJq3v4gkXQeF6.jpg'),
(102396, 7297, 'Desejo Obsessivo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZ8NebtIVho5T4iMSqiXPVKvu8e.jpg'),
(102397, 7298, 'Yonder S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vg6gJwIgvZYn3utdW09XBFZoSvM.jpg'),
(102398, 7298, 'Yonder S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6yVpbYsetPdI7forSKCo42KPx8T.jpg'),
(102399, 7298, 'Yonder S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pqwKBz5X6XvWJw4M530wUSGkoDf.jpg'),
(102400, 7298, 'Yonder S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/maty5sQ0xMg5E7NK0EyEK84q4vZ.jpg'),
(102401, 7298, 'Yonder S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fnqEposKEc9Eq1AWceN7eTKMglL.jpg'),
(102402, 7298, 'Yonder S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1tOiUOP82mXjNu1pvgt9wu9BHSe.jpg'),
(102403, 7299, 'Wreck S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lA2rA2pO8sJCsqKQeT57Ay2lTDM.jpg'),
(102404, 7299, 'Wreck S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213241.mp4', 'http://image.tmdb.org/t/p/w1280/y4bIovDwTQ37LUNmrNQO9lltjUG.jpg'),
(102405, 7299, 'Wreck S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213242.mp4', 'http://image.tmdb.org/t/p/w1280/tpQlChMh5yycZm8PkCbH03OepC7.jpg'),
(102406, 7299, 'Wreck S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213243.mp4', 'http://image.tmdb.org/t/p/w1280/ranEas5FWNKlVfOTMrnp1L68gGD.jpg'),
(102407, 7299, 'Wreck S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213244.mp4', 'http://image.tmdb.org/t/p/w1280/hNJJKWVpvVX47wD5r472nzzrf32.jpg'),
(102408, 7299, 'Wreck S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213245.mp4', 'http://image.tmdb.org/t/p/w1280/beKiUeQGiJd6a2JK0NBD0YOmdiB.jpg'),
(102409, 7300, 'Estrelas da Música S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mcQJL6jRX7QRLJH9TGopgyRnVy3.jpg'),
(102410, 7300, 'Estrelas da Música S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sAUNl5aUS0xjdLuDAVO7HDTk77C.jpg'),
(102411, 7300, 'Estrelas da Música S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mdNeitr9ALqkTdk5YeXZ3P61xOM.jpg'),
(102412, 7300, 'Estrelas da Música S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jSh4k1ALmdBEmba2VIf2RX9J1b2.jpg'),
(102413, 7300, 'Estrelas da Música S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u2nesyn85vQM7by1NLwFTAygurl.jpg'),
(102414, 7300, 'Estrelas da Música S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yoKfcvXy84cdNO7DUf9LlMJXQNb.jpg'),
(102415, 7300, 'Estrelas da Música S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yoKfcvXy84cdNO7DUf9LlMJXQNb.jpg'),
(102416, 7300, 'Estrelas da Música S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yoKfcvXy84cdNO7DUf9LlMJXQNb.jpg'),
(102417, 7278, 'Jubileu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wEQO0qcC9QmBFM0tGu68o3CtbdS.jpg'),
(102418, 7278, 'Jubileu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lojB9pexEXh96q1Pl0nN31Aysj3.jpg'),
(102419, 7278, 'Jubileu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4w37JxUXL7HACtHsE4BUwM010xD.jpg'),
(102420, 7278, 'Jubileu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gAaQ5tZn5hK9tw9hKWbwjqi8ypD.jpg'),
(102421, 7278, 'Jubileu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwB0M9xhlLh9gHxLBVCLpyaWPxz.jpg'),
(102422, 7278, 'Jubileu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cV6gnOo3TayG2qWEaswGsWRj3NX.jpg'),
(102423, 7278, 'Jubileu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i7Bstlw8IsvwdEXMESlhXOQp44S.jpg'),
(102424, 7278, 'Jubileu S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kEBeIOruZjWKtuPZZDWqdIJhnRH.jpg'),
(102425, 7278, 'Jubileu S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZJBHCYJMTg4QRJqazvMTisgVPF.jpg'),
(102426, 7278, 'Jubileu S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ky9hA6QFOh7culwBRbHICbxHgW.jpg'),
(102427, 7301, 'Meio-heróis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xeUjXmXUHD1XesmZGRT4HVndoYO.jpg'),
(102428, 7301, 'Meio-heróis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/adMro57tcijjuHFxPrzzH8tJptI.jpg'),
(102429, 7301, 'Meio-heróis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ezxN2xkurVMVfjZU9FfC2OYHTD.jpg'),
(102430, 7301, 'Meio-heróis S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bF5dWBuDlJsG3KkjE50cSjoZCLH.jpg'),
(102431, 7301, 'Meio-heróis S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kjjiNcP9vDU6QlJE57tWJW23Xi1.jpg'),
(102432, 7301, 'Meio-heróis S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3gh7DxXZaSEFggvFL0QBqQIthDf.jpg'),
(102433, 7301, 'Meio-heróis S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/neC77oRjRyGvdhXJhRjkelrdlHD.jpg'),
(102434, 7301, 'Meio-heróis S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oAo9cxHb2nVNcCWykZwxoaV0P8D.jpg'),
(102435, 7301, 'Meio-heróis S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wxlDmjlmlNyJWhgEinh9qaL1ofD.jpg'),
(102436, 7301, 'Meio-heróis S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m0zXim7WEqe9ly4zw0WH3pM5UWl.jpg'),
(102437, 7301, 'Meio-heróis S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/OWDHpVB1pKiF69dfaBFfcIEhEU.jpg'),
(102438, 7301, 'Meio-heróis S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kV1bEz4C3zrl1sCmG3xtPy0J68q.jpg'),
(102439, 7301, 'Meio-heróis S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i1kyjfOtpe4WPW1IGd8JMuErikX.jpg'),
(102440, 7302, 'Morte no Vale do Silício S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pZHX8sKyPHl9mjwDJ6v4zdxHzXb.jpg'),
(102441, 7302, 'Morte no Vale do Silício S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zt1kWKfQqkBFHdkoXI9332fVnj1.jpg'),
(102442, 7302, 'Morte no Vale do Silício S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fBjRobxn4H8ufv1WKCT0oXzmilW.jpg'),
(102443, 7303, 'Playboy: Fama e Morte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/99cCJqHGwusMwxAvZayDuRfgnQq.jpg'),
(102444, 7303, 'Playboy: Fama e Morte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217681.mp4', 'http://image.tmdb.org/t/p/w1280/pXAXeiWQ4quuPZ9OptomIIHofZU.jpg'),
(102445, 7303, 'Playboy: Fama e Morte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217682.mp4', 'http://image.tmdb.org/t/p/w1280/6Eydc7nFNF6nKD3ixWv4tQwc4KJ.jpg'),
(102446, 7303, 'Playboy: Fama e Morte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217683.mp4', 'http://image.tmdb.org/t/p/w1280/4KABkofN00s6ynKWfeEA1UfRFXJ.jpg'),
(102447, 7303, 'Playboy: Fama e Morte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217684.mp4', 'http://image.tmdb.org/t/p/w1280/QqR982GB64pD6GKWGAOVHu4b6m.jpg'),
(102448, 7303, 'Playboy: Fama e Morte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217685.mp4', 'http://image.tmdb.org/t/p/w1280/4bg3qUyVQ0ArhoHmLWob1TwMibm.jpg'),
(102449, 7304, 'Playboy: Fama e Morte S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/348513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3j1shjHg0PDwMHaMzEa1QKxxJm3.jpg'),
(102450, 7304, 'Playboy: Fama e Morte S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/618156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3j1shjHg0PDwMHaMzEa1QKxxJm3.jpg'),
(102451, 7304, 'Playboy: Fama e Morte S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3j1shjHg0PDwMHaMzEa1QKxxJm3.jpg'),
(102452, 7304, 'Playboy: Fama e Morte S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3j1shjHg0PDwMHaMzEa1QKxxJm3.jpg'),
(102453, 7304, 'Playboy: Fama e Morte S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3j1shjHg0PDwMHaMzEa1QKxxJm3.jpg'),
(102454, 7304, 'Playboy: Fama e Morte S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/441595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3j1shjHg0PDwMHaMzEa1QKxxJm3.jpg'),
(102455, 7304, 'Playboy: Fama e Morte S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/451353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3j1shjHg0PDwMHaMzEa1QKxxJm3.jpg'),
(102456, 7305, 'Playboy: Fama e Morte S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/880371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3j1shjHg0PDwMHaMzEa1QKxxJm3.jpg'),
(102457, 7305, 'Playboy: Fama e Morte S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/880372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3j1shjHg0PDwMHaMzEa1QKxxJm3.jpg'),
(102458, 7305, 'Playboy: Fama e Morte S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/880373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3j1shjHg0PDwMHaMzEa1QKxxJm3.jpg'),
(102459, 7305, 'Playboy: Fama e Morte S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/880374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3j1shjHg0PDwMHaMzEa1QKxxJm3.jpg'),
(102460, 7305, 'Playboy: Fama e Morte S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/880375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3j1shjHg0PDwMHaMzEa1QKxxJm3.jpg'),
(102461, 7305, 'Playboy: Fama e Morte S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/880376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3j1shjHg0PDwMHaMzEa1QKxxJm3.jpg'),
(102462, 7306, 'Procurados - EUA: O Atentado à Maratona de Boston S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yaApwA0RMDO1mx3aJVRxJOIvd7d.jpg'),
(102463, 7306, 'Procurados - EUA: O Atentado à Maratona de Boston S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uVYLooKXFV1GLEJVJwyymZjo5mH.jpg'),
(102464, 7306, 'Procurados - EUA: O Atentado à Maratona de Boston S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pPQr2XtwIy2OWBKjh8ggffHJMaN.jpg'),
(102465, 7307, 'Queenmaker S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iahdpxRDcLFqnxatRRi9TDktmYd.jpg'),
(102466, 7307, 'Queenmaker S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mAxwNpF3reOcB95HlbbF23xnU5w.jpg'),
(102467, 7307, 'Queenmaker S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/foCPyzj9BdFGcjGbz5FdJhjb1Uc.jpg'),
(102468, 7307, 'Queenmaker S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9NZbp3XFvBXvfkJRPkTCbQxVMnH.jpg'),
(102469, 7307, 'Queenmaker S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6nnuaIFpiAdaSB6vNpAd5TJu23h.jpg'),
(102470, 7307, 'Queenmaker S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZaAhdmI0x2eMKk1cuBp7mBd9Mj.jpg'),
(102471, 7307, 'Queenmaker S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybNK24M2qipRfaL8q9jDMftJMzJ.jpg'),
(102472, 7307, 'Queenmaker S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AbnFBquCsroMXmzRolIUKeRN7AU.jpg'),
(102473, 7307, 'Queenmaker S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lmo5kVtGDVVkVAhdrQKiWzI0CFs.jpg'),
(102474, 7307, 'Queenmaker S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wMN9yVU4Ro1nC0WCwAcJx2wzJ6U.jpg'),
(102475, 7307, 'Queenmaker S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uSMvZrPCgiBoBmiCZ3V2aiGLM9g.jpg'),
(102476, 7308, 'Caravana das Drags S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m6T9XRWzzQT502DanRkcIHekqiu.jpg'),
(102477, 7308, 'Caravana das Drags S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m6T9XRWzzQT502DanRkcIHekqiu.jpg'),
(102478, 7308, 'Caravana das Drags S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m6T9XRWzzQT502DanRkcIHekqiu.jpg'),
(102479, 7308, 'Caravana das Drags S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m6T9XRWzzQT502DanRkcIHekqiu.jpg'),
(102480, 7308, 'Caravana das Drags S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m6T9XRWzzQT502DanRkcIHekqiu.jpg'),
(102481, 7308, 'Caravana das Drags S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m6T9XRWzzQT502DanRkcIHekqiu.jpg'),
(102482, 7308, 'Caravana das Drags S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m6T9XRWzzQT502DanRkcIHekqiu.jpg'),
(102483, 7308, 'Caravana das Drags S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m6T9XRWzzQT502DanRkcIHekqiu.jpg'),
(102484, 7308, 'Caravana das Drags S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m6T9XRWzzQT502DanRkcIHekqiu.jpg'),
(102485, 7309, 'Tá Tudo Certo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3l4XhQDyNj5tXqeNdK1DmhBMOY.jpg'),
(102486, 7309, 'Tá Tudo Certo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oAmlkKrWJHHByXUog7w2Gs6u7MG.jpg'),
(102487, 7309, 'Tá Tudo Certo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rMIIpf01k0mjp68R9mY8MNzAm6S.jpg'),
(102488, 7309, 'Tá Tudo Certo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6W1piz8ritNHN3NxvIFJfks2vkV.jpg'),
(102489, 7310, 'Trigun Stampede S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aN5hAxpjwSXczzHjaueONn8eS7G.jpg'),
(102490, 7310, 'Trigun Stampede S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q2T2pdmYtfhdkZFvLkq1nZHeQtv.jpg'),
(102491, 7310, 'Trigun Stampede S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tLw38Xk9YZBEAYJQXAq1aca4vwP.jpg'),
(102492, 7310, 'Trigun Stampede S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8UI6gDi6QDzwXtQNzwUdg9TfAyw.jpg'),
(102493, 7310, 'Trigun Stampede S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gn2x4ozxa5sZRVigKGq2s1VH9Rb.jpg'),
(102494, 7310, 'Trigun Stampede S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JRdLSjcGrC0hl33lxRNpcSjbxN.jpg'),
(102495, 7310, 'Trigun Stampede S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i7VRMw4i0zI1kVPhgcvCBxPxLnd.jpg'),
(102496, 7310, 'Trigun Stampede S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dPTMT3RuQqx8G8G80JeqRbBwdrW.jpg'),
(102497, 7310, 'Trigun Stampede S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ajNQHBkBWzSJtvPp5U0U37NXjzF.jpg'),
(102498, 7310, 'Trigun Stampede S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ddO1NYKO6GkdG9SAov3E3JDoLXj.jpg'),
(102499, 7310, 'Trigun Stampede S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kZ22uJgKh5hiWaY78j08m6iJUQJ.jpg'),
(102500, 7310, 'Trigun Stampede S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mqvaj0a74JZkvCc4w1J2ePchl.jpg'),
(102501, 7311, 'Um Homem da Flórida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/scvRzAwpc81wc8lTVTS3Nzn2YaW.jpg'),
(102502, 7311, 'Um Homem da Flórida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s9yc1yTVWNiECGpZOBjIqfkVOS5.jpg'),
(102503, 7311, 'Um Homem da Flórida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8qb2nBOzlSe2w3OBnSpiQ2zhEp.jpg'),
(102504, 7311, 'Um Homem da Flórida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w0c1V640ReUu48kovmoKny9FD3X.jpg'),
(102505, 7311, 'Um Homem da Flórida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xGoMrFZl2BfatQn2YugHzzw0wGi.jpg'),
(102506, 7311, 'Um Homem da Flórida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xLS8UoH2w9zivbCz4OwCyS99EKW.jpg'),
(102507, 7311, 'Um Homem da Flórida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hWF0vQDVtMycdMGo31bhtboBHsI.jpg'),
(102508, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oCJJp5MiJocuxbX9q2Z79sQuWhu.jpg'),
(102509, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fMWhSjgJJoIiuCVPFiYwNFwpxYk.jpg'),
(102510, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5zZwIr7Uy3KOGPKPl2UcUbwTVfD.jpg'),
(102511, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f6aWGAiVMAPy85IBxSNm09FgIjp.jpg'),
(102512, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/otJWLyBYZ92bNOkUrHoOS5jUCPl.jpg'),
(102513, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4JChVgmbqNXooxSfs1zOfPfO0vM.jpg'),
(102514, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xHqbeLPbDKkjTIZyoJLC3FRSHVp.jpg'),
(102515, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zQWQajB1uVmgKf5QBLD6mdciUoc.jpg'),
(102516, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xT1uSRawfoeUDK4bqdyuFfnULVw.jpg'),
(102517, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3yxza4eCptLlX9wAKRZ3tBxwSKt.jpg'),
(102518, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iQ8o0Wg8RJ2Agcb4cdTIfzyqrnp.jpg'),
(102519, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/deXW9BmI3mz2aliD6aylQDAEihp.jpg'),
(102520, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCeA9CiziQev5IdTUBW7eLFh2hw.jpg'),
(102521, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jeoFIvTe8kxfgSEaUbTF4kWPUOU.jpg'),
(102522, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xL0sHg9PUuAvDHcz2K0APk1p8E3.jpg'),
(102523, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ZzRPRh2SGBkpmiKjbYub8EVowt.jpg'),
(102524, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z0E1h5ZvEO30KfcDYCLyo5TpXo8.jpg'),
(102525, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aIdtJYgdCWghnXmAyIe7T9yZcIu.jpg'),
(102526, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e2ZpDNCHhGsiLm5xpODk9wHGl9Q.jpg'),
(102527, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rmlMBDMnbgFz5AitvQqzaPQtXbV.jpg'),
(102528, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/54YlS6L0cUbrv5ckh7Uhr6JZEXO.jpg'),
(102529, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b9aCJ0iWLiqYYoZWlUah1pID9MA.jpg'),
(102530, 7312, 'DuckTales: Os Caçadores de Aventuras S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/212055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vc8SaKDSPMNgwpkJswEZwzoSbPl.jpg'),
(102531, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4sIkAljiRCA6xCHr7NQZAvbGq8m.jpg'),
(102532, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wg9drOPjcG6Xg5kpLlKvdgKVhD1.jpg'),
(102533, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x47dHYTTM59dGESPsEq8qP5Ienk.jpg'),
(102534, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wz4bdQiL04WtXN8YznghCuxNmH5.jpg'),
(102535, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t05j3bybQkicwRaxJwlawe0bD51.jpg'),
(102536, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s6syELVxzDAmI96UuThEtWNyGG0.jpg'),
(102537, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h5cWK4B8DrEWFrLL0IEcgVEdHBw.jpg'),
(102538, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uzfB6ArhC6Ave5IjPJc3eTJBA1E.jpg'),
(102539, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/33IQlyHnhu6IW3i4Almki2sljJt.jpg'),
(102540, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g5JEd1y5hGm5QmclRiq8JCzGefc.jpg'),
(102541, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSBhTEaoGjORHjbaOV72UlM1p7K.jpg'),
(102542, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJSC6AIbDuWXTVbXxtorLa9EOO.jpg'),
(102543, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/51lvTxyTz1WeMcF10V8wsm5nnWy.jpg'),
(102544, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A4bmf0oiV0pkzB977BfELruoDJ.jpg'),
(102545, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sEg3g0X4KkBcSljiKF9SkkCt7Qo.jpg'),
(102546, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/txVxo1HkQq8cXL3dPBgGEjozog1.jpg'),
(102547, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x9jVfHIlBi09Ez3fZo816lX9JJG.jpg'),
(102548, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gEqJmAIRtvLJjzQ484QKHvpUzZO.jpg'),
(102549, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rKNbMRmURqxtaEQFLsyrYH1F9V2.jpg'),
(102550, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uRzX6aLPjCfdzYdK6zSy3XQs0UV.jpg'),
(102551, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWPQHBKvIsx5nzB0pLylu1jJESB.jpg'),
(102552, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yUWLs7xoa7TvsCylf3R5SmaO1mn.jpg'),
(102553, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/212078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sMDyrXcG5lRbzV3nkbrJGtGFELb.jpg'),
(102554, 7313, 'DuckTales: Os Caçadores de Aventuras S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/212079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6crGSew36jQs15LoC3HukZbhlCV.jpg'),
(102555, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y681AKmsR3GS8n9ZHviwCgPand2.jpg'),
(102556, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yCCYfONvfJVfvTA7V6Yciey1nZJ.jpg'),
(102557, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCU4EI6iX9YNJjdjbn7AOwFRqaT.jpg'),
(102558, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zDqP7GvaGmcKY0fT8ooI7bkCsXU.jpg'),
(102559, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iTPW0Dgq448M0FETIIez0ZQNQSa.jpg'),
(102560, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rBh3Mnc5jezC1Ub8mexK1HB1dt5.jpg'),
(102561, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7rhNCwDQ6hfYtqLAM6GPeLA0AP.jpg'),
(102562, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xXzYnEHXLliy3qMnG6fvtvRydlT.jpg'),
(102563, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iA8IXLpd2ee8S5j8qvigH28WeKZ.jpg'),
(102564, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/php0THKRV1tnuns2JqzQ4Jedf01.jpg'),
(102565, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tAsFTIgfh9mq6zCdZhbF8QDOPbj.jpg'),
(102566, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/phwqXJ5DJEXzhaVfDot3QuK6Z4h.jpg'),
(102567, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eSUp2jdznsRDS0k3dpZp6YDOBji.jpg'),
(102568, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Ze05K9OfsKAvkvPFIQnD1Sa0jx.jpg'),
(102569, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/212094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7sn9W07ZUCPw1rtTcR6nPbYxYb4.jpg'),
(102570, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/212095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9eMaE9K95u2OkwlGsWRHqtfotB8.jpg'),
(102571, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/212096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oP5MAV8CAWg8isIRAFGy4Y5YFJW.jpg'),
(102572, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/212097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1q8CjcPrQY4iFJPnhufu6QKM8L2.jpg'),
(102573, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/212098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svU7hKcAjZYEE98vMBLggy8svq5.jpg'),
(102574, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/212099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zNkhk7u8jZNMa8ZoUBKojR9A4zA.jpg'),
(102575, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/212100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/71EcmcRZRYEGc2Ik1uML927Huxj.jpg'),
(102576, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/212101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AkR8nsWlINGbKIPDZP9YRj58Yma.jpg'),
(102577, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/212102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ndrqGODrt53F0kkb5GXVCdDYjjD.jpg'),
(102578, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/212103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ndrqGODrt53F0kkb5GXVCdDYjjD.jpg'),
(102579, 7314, 'DuckTales: Os Caçadores de Aventuras S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/212104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ndrqGODrt53F0kkb5GXVCdDYjjD.jpg'),
(102580, 7315, 'Homem-Aranha: A Série Animada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mOY1nG6cS5Rwdx8Xno2UeRJnU6D.jpg'),
(102581, 7315, 'Homem-Aranha: A Série Animada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDZJLv1UIvGwMMKjdxh1FKmPrvH.jpg'),
(102582, 7315, 'Homem-Aranha: A Série Animada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r0kKvkQQ6CDf9w0XnHrZpDvYAWo.jpg'),
(102583, 7315, 'Homem-Aranha: A Série Animada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Vx9nS46ErsGF9rltMQ8RwzRRz0.jpg'),
(102584, 7315, 'Homem-Aranha: A Série Animada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lZ3Aslrrhu0v2O0vLPWMr9SSILB.jpg'),
(102585, 7315, 'Homem-Aranha: A Série Animada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4W7moiol1kGSJ6mqRQrqurby9nz.jpg'),
(102586, 7315, 'Homem-Aranha: A Série Animada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFEH3Upc2PwArX7v4a47OzQUfSe.jpg'),
(102587, 7315, 'Homem-Aranha: A Série Animada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/FFMPeCdoubP0GWcRkra2qfsPo4.jpg'),
(102588, 7315, 'Homem-Aranha: A Série Animada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/23llvdQDOncGG73y1gHOsBgOeGV.jpg'),
(102589, 7315, 'Homem-Aranha: A Série Animada S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/apwB4RBmGMUNtkOfXYeC25zYh94.jpg'),
(102590, 7315, 'Homem-Aranha: A Série Animada S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fljbHaKfBKg0cckJRp58ZT6vmit.jpg'),
(102591, 7315, 'Homem-Aranha: A Série Animada S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6l9T64z40TeWyi84yE4rfulcDNi.jpg'),
(102592, 7315, 'Homem-Aranha: A Série Animada S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ZvFB5FnOB4YRdz9ZpxUb53FMHc.jpg'),
(102593, 7316, 'Homem-Aranha: A Série Animada S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kjZlrS6gjpenZawmOEvTvsVK4Bv.jpg'),
(102594, 7316, 'Homem-Aranha: A Série Animada S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mIjMIRQaE77TVUo6mWiNCvw9c6N.jpg'),
(102595, 7316, 'Homem-Aranha: A Série Animada S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xGs6kHIs1fm7Wk0kOiRDkcXgnB.jpg'),
(102596, 7316, 'Homem-Aranha: A Série Animada S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQMbrjrP3rT7Hxa4Yp0PmiK2zEw.jpg'),
(102597, 7316, 'Homem-Aranha: A Série Animada S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uv0t7vw4aGqBS0eiy5hTGPxqYbw.jpg'),
(102598, 7316, 'Homem-Aranha: A Série Animada S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xAb9a1024cSPJS0qfjUAhPV4vRe.jpg'),
(102599, 7316, 'Homem-Aranha: A Série Animada S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1jEcUChQ7nSIDGKaTv1GgblC5HE.jpg'),
(102600, 7316, 'Homem-Aranha: A Série Animada S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bPdhEhhRDZT5hrn6JC3h9GrELSj.jpg'),
(102601, 7316, 'Homem-Aranha: A Série Animada S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybwsVFY1R5kaTE7kpdRG7pS9yWV.jpg'),
(102602, 7316, 'Homem-Aranha: A Série Animada S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4qntzQCdZKPsRlsXiMgxmcNS6v9.jpg'),
(102603, 7316, 'Homem-Aranha: A Série Animada S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qAI2j0DsrTQY4LMS1uMbzKUw48W.jpg'),
(102604, 7316, 'Homem-Aranha: A Série Animada S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfywEa4kOgFR8UGsx1u3u22bwIY.jpg'),
(102605, 7316, 'Homem-Aranha: A Série Animada S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tRqdFadfT7d37UoQ7NhGqbp0Zef.jpg'),
(102606, 7316, 'Homem-Aranha: A Série Animada S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/211994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/43PtPnoGyYm2YV5GYFcCboi84So.jpg'),
(102607, 7317, 'Homem-Aranha: A Série Animada S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/55infSpS5iH2WG3o4lmkpluYpqy.jpg'),
(102608, 7317, 'Homem-Aranha: A Série Animada S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5VXxXvku3bmLuMVUCbeSpZejo0k.jpg'),
(102609, 7317, 'Homem-Aranha: A Série Animada S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3m7GBi82vj2HnhuYCNIDefgJSdE.jpg'),
(102610, 7317, 'Homem-Aranha: A Série Animada S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qWczXa0o8a7fgrA1QG3SgK4wvRH.jpg'),
(102611, 7317, 'Homem-Aranha: A Série Animada S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qrBAahcKgczXA0JrivuZ9pz8hwZ.jpg'),
(102612, 7317, 'Homem-Aranha: A Série Animada S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yYhmIfk5Ak7M7HXFmrt0tJPbXhQ.jpg'),
(102613, 7317, 'Homem-Aranha: A Série Animada S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5pFVavZyGZ9X2um3ddkJ6fI2150.jpg'),
(102614, 7317, 'Homem-Aranha: A Série Animada S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bdtJkySm2h88945ptD9iQcQiRY2.jpg'),
(102615, 7317, 'Homem-Aranha: A Série Animada S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lqXC5z4GCE9ooOXwmdknn9XZx4j.jpg'),
(102616, 7317, 'Homem-Aranha: A Série Animada S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1qWPi5vIxUyq366LOPnr9fKg0rc.jpg'),
(102617, 7317, 'Homem-Aranha: A Série Animada S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pQAUqMxdzoSUIEoDb8jpzFmLPxr.jpg'),
(102618, 7317, 'Homem-Aranha: A Série Animada S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pOFVsTmwVEITYguwqHIwVAoYxoQ.jpg'),
(102619, 7317, 'Homem-Aranha: A Série Animada S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Bg1MfU2VP8Oi0gQbPeR2jszDlB.jpg'),
(102620, 7317, 'Homem-Aranha: A Série Animada S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/212008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lRY6WrnqTmYCR0HgCfiyGwUg4Ht.jpg'),
(102621, 7318, 'Homem-Aranha: A Série Animada S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fWSwSU5X2kzbtIipp3d7Gujwwlq.jpg'),
(102622, 7318, 'Homem-Aranha: A Série Animada S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9m0YvXF0VeAKwCdwl6KG0s9n4LD.jpg'),
(102623, 7318, 'Homem-Aranha: A Série Animada S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/32yC3OPazZcdh0xOT93pjG2Iphd.jpg'),
(102624, 7318, 'Homem-Aranha: A Série Animada S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zibIjZn3WtGd1vH8cEOYbWqQGlA.jpg'),
(102625, 7318, 'Homem-Aranha: A Série Animada S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jvE7Lu64c9RSNfJfUguv3GGEvM2.jpg'),
(102626, 7318, 'Homem-Aranha: A Série Animada S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zfK10SkebIwa032WCeDeEzThy8E.jpg'),
(102627, 7318, 'Homem-Aranha: A Série Animada S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lvWuMPkxs0cmL9vKj9Enlg8fMGl.jpg'),
(102628, 7318, 'Homem-Aranha: A Série Animada S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fclqUiaBImWjHeahlK0KydnjSSv.jpg'),
(102629, 7318, 'Homem-Aranha: A Série Animada S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x0FRHOMV461frkxvT3tHTHzXGJu.jpg'),
(102630, 7318, 'Homem-Aranha: A Série Animada S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4pNZppcrsWOsI3zVbAmdkE1nDwc.jpg'),
(102631, 7318, 'Homem-Aranha: A Série Animada S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xRYZw7DKFV5cQS4jc32YHVPdJv7.jpg'),
(102632, 7319, 'Homem-Aranha: A Série Animada S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/212020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hOp5YwFa1CL1KdRuim9ginV05Qo.jpg'),
(102633, 7319, 'Homem-Aranha: A Série Animada S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/212021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ZxY6jza0CYlVWUTZlVlxpI38ut.jpg'),
(102634, 7319, 'Homem-Aranha: A Série Animada S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/212022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/plTpEFcJzXdG0nJcxhTwqQEGaS9.jpg'),
(102635, 7319, 'Homem-Aranha: A Série Animada S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/212023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpa5mJLv4cQRXDQPGGmUj0Ly3le.jpg'),
(102636, 7319, 'Homem-Aranha: A Série Animada S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/212024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2yXdAdfL21Q1qFeFZM4B9QJOMoe.jpg'),
(102637, 7319, 'Homem-Aranha: A Série Animada S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/212025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A6iBUIx4krRRdRvWsBV4mHojKyQ.jpg'),
(102638, 7319, 'Homem-Aranha: A Série Animada S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/212026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/miknPHS6waBJXndFcj80RqAlcty.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(102639, 7319, 'Homem-Aranha: A Série Animada S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/212027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A5qj8MMq5nuhMbAQ31V1mXbiPuS.jpg'),
(102640, 7319, 'Homem-Aranha: A Série Animada S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/212028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7IDNa7XnzDIlgBqsXdeCkLTjrX6.jpg'),
(102641, 7319, 'Homem-Aranha: A Série Animada S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/212029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/llam7oprtd83aLjafeYiopy8IGu.jpg'),
(102642, 7319, 'Homem-Aranha: A Série Animada S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/212030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b2j8WdLJ0wDSBHIYPzZIXwglFYn.jpg'),
(102643, 7319, 'Homem-Aranha: A Série Animada S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/212031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y8aIG4jzmuZEODOzIJicU5lW0LG.jpg'),
(102644, 7319, 'Homem-Aranha: A Série Animada S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/212032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mSvy3PBKsjxYvik41UI1m6DtKXT.jpg'),
(102645, 7320, 'Mob Psycho 100 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zIejXZ330rYyC9NkigmrhM0gA2k.jpg'),
(102646, 7320, 'Mob Psycho 100 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2IRcb7QNpL1gnV4UkOfXLbtc0sm.jpg'),
(102647, 7320, 'Mob Psycho 100 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fbr4w6McLDh5Wx7fxWwLGtBa3Hs.jpg'),
(102648, 7320, 'Mob Psycho 100 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tgEW5zsvlmglOS5EEk6UmH48kNm.jpg'),
(102649, 7320, 'Mob Psycho 100 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h7ts0QOUbragMxy6CacCnGVFETV.jpg'),
(102650, 7320, 'Mob Psycho 100 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y6cLitqeuAh5R6yQRAlQhlHBHtl.jpg'),
(102651, 7320, 'Mob Psycho 100 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/deNkKthjJd0M6ybS5Tj1EtwXoPk.jpg'),
(102652, 7320, 'Mob Psycho 100 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l4uYdqcP4uorUUNUGYvCraQzAZL.jpg'),
(102653, 7320, 'Mob Psycho 100 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e7PzPH9webwk0km48CruE5BJaQf.jpg'),
(102654, 7320, 'Mob Psycho 100 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lRbnpyYSqUHt9fFP501gHXbQWRc.jpg'),
(102655, 7320, 'Mob Psycho 100 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ggSfFxpN2KTUy2iAERpMuA2nSpA.jpg'),
(102656, 7320, 'Mob Psycho 100 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g8JDTJ18lDQvGVyHXs3Yb3l6wwM.jpg'),
(102657, 7321, 'Mob Psycho 100 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8avaqhS8U5QDfqBprR6DUPf84xA.jpg'),
(102658, 7321, 'Mob Psycho 100 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhdahzuD9L1wsqrAF8rZiLNNX7D.jpg'),
(102659, 7321, 'Mob Psycho 100 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c0WoVoQgZ2LUEcF4LWPfSvhJVu8.jpg'),
(102660, 7321, 'Mob Psycho 100 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MWaUPTeVDD5uWQtr5bxtt6vZIU.jpg'),
(102661, 7321, 'Mob Psycho 100 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8a92F1fd76UNdNzQeizvPvUWKDf.jpg'),
(102662, 7321, 'Mob Psycho 100 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/afmIffJ0yN3LT2XQyS4bQ59oUcD.jpg'),
(102663, 7321, 'Mob Psycho 100 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oDybpLwNqwoYEl1IuA59gV93VsI.jpg'),
(102664, 7321, 'Mob Psycho 100 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mNgqdPRvyDAxwfaDmKdHVjh2a0g.jpg'),
(102665, 7321, 'Mob Psycho 100 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Q1r7Ii1VbTBV0cG6StzG94jbQ2.jpg'),
(102666, 7321, 'Mob Psycho 100 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lg2cGwfeeVfrhz0koWoBWwV53Q2.jpg'),
(102667, 7321, 'Mob Psycho 100 S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sYyxnqWgwaM6xgFDxcGY9Dkvmqo.jpg'),
(102668, 7321, 'Mob Psycho 100 S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mWy9ZkNPO5yfoYQ3X2gzvXDAc91.jpg'),
(102669, 7321, 'Mob Psycho 100 S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/211945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bVvWPZNtFpvnJKB5lC7jv6dhFGJ.jpg'),
(102670, 7322, 'Mob Psycho 100 S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2fuXXVuNEubip0qSdDxMgDyzo3Z.jpg'),
(102671, 7322, 'Mob Psycho 100 S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wHDXIU19U7CavBjkNZEHTIVtoIg.jpg'),
(102672, 7322, 'Mob Psycho 100 S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2zpObzsKGsN7nWqAcBNF3GWhKSX.jpg'),
(102673, 7322, 'Mob Psycho 100 S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6RAa5ddwcvhVd8Px77flJkMnr3v.jpg'),
(102674, 7322, 'Mob Psycho 100 S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTXMYrvKXVkW7d3LsXQ5Ym7NzAS.jpg'),
(102675, 7322, 'Mob Psycho 100 S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AkgxyfSgesTqjLOGd5exagW7T7Z.jpg'),
(102676, 7322, 'Mob Psycho 100 S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2A0FI7RhbBr4znsTGJuALHjWGab.jpg'),
(102677, 7322, 'Mob Psycho 100 S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hRDnMLOlATDfXM7T0Yp3niyIsoW.jpg'),
(102678, 7322, 'Mob Psycho 100 S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/211954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybsteucEyKvvxqEZJjvgru0UpI8.jpg'),
(102679, 7322, 'Mob Psycho 100 S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/211955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/27T90sxHL8hvOaYNKlFxj4OXULt.jpg'),
(102680, 7322, 'Mob Psycho 100 S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/211956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fG3EHYfATHH5zbdTdoQAaEkwL11.jpg'),
(102681, 7322, 'Mob Psycho 100 S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/211957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/17lwErm3WHM0mZU2OKXTd7Ne0ZK.jpg'),
(102682, 7323, 'A Diplomata S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5CdBj4c7co4ZAAWBbGA336jIgku.jpg'),
(102683, 7323, 'A Diplomata S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A4a9gcahgiXRtiQrXkWGwtaVeHz.jpg'),
(102684, 7323, 'A Diplomata S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/26IgdDkp0YSkFVXNgQ9h9nWJMNa.jpg'),
(102685, 7323, 'A Diplomata S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mUAIyDyGggdgJ0T1RYoayB5torN.jpg'),
(102686, 7323, 'A Diplomata S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c2PwuUdhovZDUL4bFeoNwUARmz2.jpg'),
(102687, 7323, 'A Diplomata S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f1T5pTKaoWADN5tbU4q4LdBlHzN.jpg'),
(102688, 7323, 'A Diplomata S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dBZhN7cvrmb52IwCw8llxf3q1OK.jpg'),
(102689, 7323, 'A Diplomata S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i9i8ZFEQgWfuPBxm32h1BFj0Tmu.jpg'),
(102690, 7324, 'A Diplomata S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/493228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DoshncExMCGK9skDMA7iddHalJ.jpg'),
(102691, 7324, 'A Diplomata S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/493229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DoshncExMCGK9skDMA7iddHalJ.jpg'),
(102692, 7324, 'A Diplomata S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/493230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DoshncExMCGK9skDMA7iddHalJ.jpg'),
(102693, 7324, 'A Diplomata S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/493231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DoshncExMCGK9skDMA7iddHalJ.jpg'),
(102694, 7324, 'A Diplomata S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/493232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DoshncExMCGK9skDMA7iddHalJ.jpg'),
(102695, 7324, 'A Diplomata S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/493233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DoshncExMCGK9skDMA7iddHalJ.jpg'),
(102696, 7325, 'A Diplomata S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/889115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DoshncExMCGK9skDMA7iddHalJ.jpg'),
(102697, 7325, 'A Diplomata S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/889116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DoshncExMCGK9skDMA7iddHalJ.jpg'),
(102698, 7325, 'A Diplomata S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/889117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DoshncExMCGK9skDMA7iddHalJ.jpg'),
(102699, 7325, 'A Diplomata S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/889118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DoshncExMCGK9skDMA7iddHalJ.jpg'),
(102700, 7325, 'A Diplomata S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/889119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DoshncExMCGK9skDMA7iddHalJ.jpg'),
(102701, 7325, 'A Diplomata S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/889120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DoshncExMCGK9skDMA7iddHalJ.jpg'),
(102702, 7325, 'A Diplomata S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/889121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DoshncExMCGK9skDMA7iddHalJ.jpg'),
(102703, 7325, 'A Diplomata S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/889122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DoshncExMCGK9skDMA7iddHalJ.jpg'),
(102704, 7326, 'A Verdade da Mentira: Uma Nova Missão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xnmTRXqPVm742eme6gi99m123D0.jpg'),
(102705, 7326, 'A Verdade da Mentira: Uma Nova Missão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zQRNBzQXhpja1cgMyQdRJigbwlY.jpg'),
(102706, 7326, 'A Verdade da Mentira: Uma Nova Missão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9nVYtamGNWtoCWCKxUT180JElI8.jpg'),
(102707, 7326, 'A Verdade da Mentira: Uma Nova Missão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213947.mp4', 'http://image.tmdb.org/t/p/w1280/mWHdHr9FFuF2Bg2VZujjpexCTQF.jpg'),
(102708, 7326, 'A Verdade da Mentira: Uma Nova Missão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213948.mp4', 'http://image.tmdb.org/t/p/w1280/9d09cWVakBWlXfIgeuA8pVJgsBY.jpg'),
(102709, 7326, 'A Verdade da Mentira: Uma Nova Missão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213949.mp4', 'http://image.tmdb.org/t/p/w1280/s3ITNEywESS9n2UdAEP9gswsTL.jpg'),
(102710, 7326, 'A Verdade da Mentira: Uma Nova Missão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213950.mp4', 'http://image.tmdb.org/t/p/w1280/cEB10QGtV6noeVsN7OsuDu3YQt1.jpg'),
(102711, 7326, 'A Verdade da Mentira: Uma Nova Missão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213951.mp4', 'http://image.tmdb.org/t/p/w1280/sd9v9PGhpZRaLTxsPA43AAbHB0Q.jpg'),
(102712, 7326, 'A Verdade da Mentira: Uma Nova Missão S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213952.mp4', 'http://image.tmdb.org/t/p/w1280/qJHgIHujqbQzowy0KGLA5w3ByrK.jpg'),
(102713, 7326, 'A Verdade da Mentira: Uma Nova Missão S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213953.mp4', 'http://image.tmdb.org/t/p/w1280/lHvi04zxfKuXouVlS9te3l47xDo.jpg'),
(102714, 7326, 'A Verdade da Mentira: Uma Nova Missão S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/213954.mp4', 'http://image.tmdb.org/t/p/w1280/mImBgvFA8MC5yKYYfbJBC6UEP7O.jpg'),
(102715, 7326, 'A Verdade da Mentira: Uma Nova Missão S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/213955.mp4', 'http://image.tmdb.org/t/p/w1280/9vXkbTzNvsoBCMoggm31IxHjysI.jpg'),
(102716, 7326, 'A Verdade da Mentira: Uma Nova Missão S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/213956.mp4', 'http://image.tmdb.org/t/p/w1280/skMYjydC5Tpj663Ns996jJybwn5.jpg'),
(102717, 7327, 'As Piores Prisoes do Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102718, 7327, 'As Piores Prisoes do Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102719, 7327, 'As Piores Prisoes do Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102720, 7327, 'As Piores Prisoes do Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102721, 7327, 'As Piores Prisoes do Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102722, 7327, 'As Piores Prisoes do Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102723, 7328, 'As Piores Prisoes do Mundo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102724, 7328, 'As Piores Prisoes do Mundo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102725, 7328, 'As Piores Prisoes do Mundo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102726, 7328, 'As Piores Prisoes do Mundo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102727, 7328, 'As Piores Prisoes do Mundo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102728, 7328, 'As Piores Prisoes do Mundo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102729, 7328, 'As Piores Prisoes do Mundo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102730, 7329, 'As Piores Prisoes do Mundo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102731, 7329, 'As Piores Prisoes do Mundo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102732, 7329, 'As Piores Prisoes do Mundo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102733, 7329, 'As Piores Prisoes do Mundo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102734, 7329, 'As Piores Prisoes do Mundo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102735, 7329, 'As Piores Prisoes do Mundo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102736, 7330, 'As Piores Prisoes do Mundo S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/385137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102737, 7330, 'As Piores Prisoes do Mundo S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/398080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102738, 7330, 'As Piores Prisoes do Mundo S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/401278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102739, 7330, 'As Piores Prisoes do Mundo S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/409694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102740, 7330, 'As Piores Prisoes do Mundo S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/413025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102741, 7330, 'As Piores Prisoes do Mundo S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/415072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qWx9r7MRvXxfP4X7z4ZhoT8t5Pk.jpg'),
(102742, 7331, 'Bring Back Alice S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kWDqSfIq5jPvTW3QlCKUkg0OsFV.jpg'),
(102743, 7331, 'Bring Back Alice S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nmp4oKwgqOmqaH8qnrEwcN3tvLt.jpg'),
(102744, 7331, 'Bring Back Alice S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tcHQAz1cfGhpxkICSzOvzbojKl0.jpg'),
(102745, 7331, 'Bring Back Alice S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213849.mp4', 'http://image.tmdb.org/t/p/w1280/5TaODfjmKCANW0nSm4xED0exz1w.jpg'),
(102746, 7331, 'Bring Back Alice S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6IXJDBhsLnatm5gRRdJXr85LR.jpg'),
(102747, 7331, 'Bring Back Alice S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nu6IXJDBhsLnatm5gRRdJXr85LR.jpg'),
(102748, 7332, 'Chefs de Alto Nível com Gordon Ramsay S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yhfcyKYrru4hn1R7g5fNfO1v2OE.jpg'),
(102749, 7332, 'Chefs de Alto Nível com Gordon Ramsay S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rDZWuhxW7tEAkpw7phabIAtnQFD.jpg'),
(102750, 7332, 'Chefs de Alto Nível com Gordon Ramsay S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2poUfoZj45WGo9qdPl57taTdhaO.jpg'),
(102751, 7332, 'Chefs de Alto Nível com Gordon Ramsay S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTk5UTSAdJeUSnCD4JAMHpY5WxO.jpg'),
(102752, 7332, 'Chefs de Alto Nível com Gordon Ramsay S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x03VZ4ZjfYHyn4hyY0NKqgMYwze.jpg'),
(102753, 7332, 'Chefs de Alto Nível com Gordon Ramsay S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yE3yMi6Q0lJnQ8Zq7S1MuqrCdRb.jpg'),
(102754, 7332, 'Chefs de Alto Nível com Gordon Ramsay S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A4aEAzyFGYDmNZcyHLJ1SfCjNLk.jpg'),
(102755, 7332, 'Chefs de Alto Nível com Gordon Ramsay S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pSJDcpb3ymalEsAlyivbOybbtx4.jpg'),
(102756, 7332, 'Chefs de Alto Nível com Gordon Ramsay S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3hpsnWJKrx4YGfxA6kM5PfpbqKe.jpg'),
(102757, 7332, 'Chefs de Alto Nível com Gordon Ramsay S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3sjZxz1eHmAhONk2nYRe6Naqizl.jpg'),
(102758, 7332, 'Chefs de Alto Nível com Gordon Ramsay S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ntsk7lydrc90jgN8hl6HTYFL45E.jpg'),
(102759, 7333, 'Chefs de Alto Nível com Gordon Ramsay S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ue6uJ2ApSgt6zWxXqXMR7qB1JsT.jpg'),
(102760, 7333, 'Chefs de Alto Nível com Gordon Ramsay S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rzkeABoevzt9weGoIUbyLISTTbR.jpg'),
(102761, 7333, 'Chefs de Alto Nível com Gordon Ramsay S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mBoTKMDfzbJno4ICaYiXEozUJgI.jpg'),
(102762, 7333, 'Chefs de Alto Nível com Gordon Ramsay S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/75Iuk0wcfXShck7sLyygxfxhwCI.jpg'),
(102763, 7333, 'Chefs de Alto Nível com Gordon Ramsay S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sqEhD5VuW4QI2vJ5F2UPe9XwGPT.jpg'),
(102764, 7333, 'Chefs de Alto Nível com Gordon Ramsay S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232971.mp4', 'http://image.tmdb.org/t/p/w1280/rsiggQm5tOTuC5L9XLAE61MuQew.jpg'),
(102765, 7333, 'Chefs de Alto Nível com Gordon Ramsay S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232972.mp4', 'http://image.tmdb.org/t/p/w1280/6byKXyuDSuCc7e3GF6rRaGId2uP.jpg'),
(102766, 7333, 'Chefs de Alto Nível com Gordon Ramsay S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232973.mp4', 'http://image.tmdb.org/t/p/w1280/v9YWiMcqbPDwAiRxRkrDCbhrZVD.jpg'),
(102767, 7333, 'Chefs de Alto Nível com Gordon Ramsay S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102768, 7333, 'Chefs de Alto Nível com Gordon Ramsay S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102769, 7333, 'Chefs de Alto Nível com Gordon Ramsay S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102770, 7333, 'Chefs de Alto Nível com Gordon Ramsay S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102771, 7333, 'Chefs de Alto Nível com Gordon Ramsay S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/232978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102772, 7333, 'Chefs de Alto Nível com Gordon Ramsay S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/232979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102773, 7333, 'Chefs de Alto Nível com Gordon Ramsay S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/232980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102774, 7334, 'Chefs de Alto Nível com Gordon Ramsay S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/323395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102775, 7334, 'Chefs de Alto Nível com Gordon Ramsay S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/323396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102776, 7334, 'Chefs de Alto Nível com Gordon Ramsay S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/323397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102777, 7334, 'Chefs de Alto Nível com Gordon Ramsay S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/461653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102778, 7334, 'Chefs de Alto Nível com Gordon Ramsay S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/461654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102779, 7334, 'Chefs de Alto Nível com Gordon Ramsay S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/461655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102780, 7334, 'Chefs de Alto Nível com Gordon Ramsay S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/461656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102781, 7334, 'Chefs de Alto Nível com Gordon Ramsay S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/461657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102782, 7334, 'Chefs de Alto Nível com Gordon Ramsay S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/467825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102783, 7334, 'Chefs de Alto Nível com Gordon Ramsay S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/467826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102784, 7334, 'Chefs de Alto Nível com Gordon Ramsay S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/467827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102785, 7334, 'Chefs de Alto Nível com Gordon Ramsay S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/467828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102786, 7334, 'Chefs de Alto Nível com Gordon Ramsay S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/467829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102787, 7334, 'Chefs de Alto Nível com Gordon Ramsay S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/467830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102788, 7334, 'Chefs de Alto Nível com Gordon Ramsay S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/467831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102789, 7334, 'Chefs de Alto Nível com Gordon Ramsay S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/467832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102790, 7335, 'Chefs de Alto Nível com Gordon Ramsay S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/806485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102791, 7335, 'Chefs de Alto Nível com Gordon Ramsay S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/806486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102792, 7335, 'Chefs de Alto Nível com Gordon Ramsay S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/810301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102793, 7335, 'Chefs de Alto Nível com Gordon Ramsay S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/810302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102794, 7335, 'Chefs de Alto Nível com Gordon Ramsay S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/839099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102795, 7335, 'Chefs de Alto Nível com Gordon Ramsay S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/839100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102796, 7335, 'Chefs de Alto Nível com Gordon Ramsay S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/839101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102797, 7335, 'Chefs de Alto Nível com Gordon Ramsay S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/874711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102798, 7335, 'Chefs de Alto Nível com Gordon Ramsay S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/874712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102799, 7335, 'Chefs de Alto Nível com Gordon Ramsay S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/874713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102800, 7335, 'Chefs de Alto Nível com Gordon Ramsay S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/874714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102801, 7335, 'Chefs de Alto Nível com Gordon Ramsay S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/874715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102802, 7335, 'Chefs de Alto Nível com Gordon Ramsay S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/878893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102803, 7335, 'Chefs de Alto Nível com Gordon Ramsay S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/879430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/di3eWx1NfkTGSiTCzBgn51Wpzvi.jpg'),
(102804, 7336, 'Como Ficar Rico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/evEFBHrxELCTsKPY5ScATN2rQZz.jpg'),
(102805, 7336, 'Como Ficar Rico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yqNN2Picmwv4CRcV1j8TF60U1AJ.jpg'),
(102806, 7336, 'Como Ficar Rico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgtfyd05b1mLalLpg6A7z0frbJR.jpg'),
(102807, 7336, 'Como Ficar Rico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vpiUmy9AFPMHMp5lrtvBHVnoGCE.jpg'),
(102808, 7336, 'Como Ficar Rico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5haq8yWQdDGrKXyOUKHSWGzaGGm.jpg'),
(102809, 7336, 'Como Ficar Rico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dsYnzYzu0EGs30Z1GsZekP8TXgL.jpg'),
(102810, 7336, 'Como Ficar Rico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2mWcGrWGtTVcAn0WdDpnHxUe7qz.jpg'),
(102811, 7336, 'Como Ficar Rico S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l1oIGMYk0lOJxvu4kLzGJXiU3dr.jpg'),
(102812, 7337, 'Diamantes Brutos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iFF1YkxN8Ime7xObsyTPnuy0Hn9.jpg'),
(102813, 7337, 'Diamantes Brutos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/45KpNbDFxMnnxTzA9KBTnyDANKC.jpg'),
(102814, 7337, 'Diamantes Brutos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o3UWNQz1nnI1NycZq85K2PwCzY5.jpg'),
(102815, 7337, 'Diamantes Brutos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/usKjf2hQ2CKQeiQkVcnbus4tIFr.jpg'),
(102816, 7337, 'Diamantes Brutos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4NMpKfeItgvzuNgR8T7kGPyLcoG.jpg'),
(102817, 7337, 'Diamantes Brutos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dgahZbqBnscoMumD9FqDgkEsPaK.jpg'),
(102818, 7337, 'Diamantes Brutos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Xi1j006LApEiwj6yKmGFy7WjZb.jpg'),
(102819, 7337, 'Diamantes Brutos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i1bZfS7oiek8nOCpoSN57V6lR1v.jpg'),
(102820, 7338, 'Gêmeas: Mórbida Semelhança S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iYXC8uPa53cRswen2RoeUSCoWW4.jpg'),
(102821, 7338, 'Gêmeas: Mórbida Semelhança S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kUeGWynOLMYwYyEM00IfdjUqmHt.jpg'),
(102822, 7338, 'Gêmeas: Mórbida Semelhança S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r8gYZpJoySeOi1duEqShE4jr2PJ.jpg'),
(102823, 7338, 'Gêmeas: Mórbida Semelhança S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/daDZSifZrlYdSxt1vK8ozh7Palh.jpg'),
(102824, 7338, 'Gêmeas: Mórbida Semelhança S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8xfFl1lVu65OExrSsOe6JXGyTaq.jpg'),
(102825, 7338, 'Gêmeas: Mórbida Semelhança S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/be3TacDCAzwAWFvaSxAFJ4nuBxc.jpg'),
(102826, 7339, 'Gotas Divinas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l5hm31u0JDu3dQudhxSafbkLRzS.jpg'),
(102827, 7339, 'Gotas Divinas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ag05bpR06k6RGQHhnRYMVdb3e0n.jpg'),
(102828, 7339, 'Gotas Divinas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216965.mp4', 'http://image.tmdb.org/t/p/w1280/zLaNrpkf6ZYgpJlaAv4uJio60Mi.jpg'),
(102829, 7339, 'Gotas Divinas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216966.mp4', 'http://image.tmdb.org/t/p/w1280/2lbSaUCpvIdDfJknaodAtE8RMa7.jpg'),
(102830, 7339, 'Gotas Divinas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216967.mp4', 'http://image.tmdb.org/t/p/w1280/zciGjtwuMFDhRNA5P9qXw7RLD18.jpg'),
(102831, 7339, 'Gotas Divinas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216968.mp4', 'http://image.tmdb.org/t/p/w1280/Au5hNyOHiCQm8f3ZxDNK0OTaJpn.jpg'),
(102832, 7339, 'Gotas Divinas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216969.mp4', 'http://image.tmdb.org/t/p/w1280/h11A1FDGMNfLHmqTAzN9Nu1ziiV.jpg'),
(102833, 7339, 'Gotas Divinas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216970.mp4', 'http://image.tmdb.org/t/p/w1280/8UESQPKBu91ut4QEiniUaXlhjb5.jpg'),
(102834, 7340, 'Grandes Animais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mmkQ41n4WFHZZhK2TElWoJFB2xZ.jpg'),
(102835, 7340, 'Grandes Animais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Lr2IUiLlxoO8IlpQFGb3hZ8GZd.jpg'),
(102836, 7340, 'Grandes Animais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g18CwvAeLdUYYEUfIbFWZ21oNu.jpg'),
(102837, 7340, 'Grandes Animais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ZXWpOysuS9zAsIdwKjw287FN03.jpg'),
(102838, 7340, 'Grandes Animais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nVUA9nLyPo8BDEya3cT4YP2fsic.jpg'),
(102839, 7340, 'Grandes Animais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/daj56X9lr4u5ftfy0aMSS3s2WPc.jpg'),
(102840, 7340, 'Grandes Animais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8XxWKbbYsk0bxW7uCp5X1GTv1aY.jpg'),
(102841, 7340, 'Grandes Animais S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rXfqlkswixP07QExAaigPNb27l1.jpg'),
(102842, 7340, 'Grandes Animais S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zGfnLo3FV1GcKwpHki45cJ4slzD.jpg'),
(102843, 7152, 'Histórias de Terror S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/50CKQvJWbf5YFaVSfrq5imwZs1q.jpg'),
(102844, 7152, 'Histórias de Terror S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LEAI056kA38MvY4qzCWvvIATrt.jpg'),
(102845, 7152, 'Histórias de Terror S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1DtLWohynR3RNgfRUQczt9uATY.jpg'),
(102846, 7152, 'Histórias de Terror S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cgxnLU4BKSRnZLKj7BhRbWzuxQp.jpg'),
(102847, 7152, 'Histórias de Terror S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bAwugUknyAE3EnCYRfscg7aHo5v.jpg'),
(102848, 7152, 'Histórias de Terror S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jqUQ8JbzfaMJnbnHbqA84D8V6Sd.jpg'),
(102849, 7152, 'Histórias de Terror S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qgzbR35agVG1pB4VSDBdk3ZBf6.jpg'),
(102850, 7152, 'Histórias de Terror S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4QyRI3nUKB5hWuC81bEvqEbxiNx.jpg'),
(102851, 7341, 'Ilhas Selvagens S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kwtjKCqoAsul13DEct2zRMlnpqo.jpg'),
(102852, 7341, 'Ilhas Selvagens S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j27WktY34YP9KRVPNNt8kmBMLKc.jpg'),
(102853, 7341, 'Ilhas Selvagens S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v7dpAgrR8NrZzjIWH78BlIcq5bK.jpg'),
(102854, 7341, 'Ilhas Selvagens S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/prVasyTNRleafyj67soS0qYtUEf.jpg'),
(102855, 7341, 'Ilhas Selvagens S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sQSDWhNVLUDEOzilXQoKAnQxdkv.jpg'),
(102856, 7342, 'Motel Valkirias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eZWZ8zSsdbzI3aCAYvB12kepsXH.jpg'),
(102857, 7342, 'Motel Valkirias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hs1TKX5bE7IIKsL2QkaDRMci0u4.jpg'),
(102858, 7342, 'Motel Valkirias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8cx3v7awtk3ffQVVFZKsyICl6NO.jpg'),
(102859, 7342, 'Motel Valkirias S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7eKvWwm2AzMzSpOxWh95Nd05pqK.jpg'),
(102860, 7342, 'Motel Valkirias S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/211355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fhF9TAmyhUSnA3kC29EEau7depP.jpg'),
(102861, 7342, 'Motel Valkirias S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/211356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sILDChm72mEOSwUVJTzB5J4yoWA.jpg'),
(102862, 7342, 'Motel Valkirias S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/211357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s4HWlm2tbOw8C5UbaOlXjooxhmB.jpg'),
(102863, 7342, 'Motel Valkirias S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/211358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3BkLnOdTm7gdX4rxAKm2B83CJOw.jpg'),
(102864, 7343, 'O Império dos Chimpanzés S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/211347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mXPzJwhmVIYrU2WfBusktXlsVfS.jpg'),
(102865, 7343, 'O Império dos Chimpanzés S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/211348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cq1o7DZS4e40McXUwxeDvHo83At.jpg'),
(102866, 7343, 'O Império dos Chimpanzés S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/211349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/taYj8QFsSFiUBDURZZgDxBUTHUW.jpg'),
(102867, 7343, 'O Império dos Chimpanzés S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/211350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4qKnHeHXP239uHN39VvjdJB3zMX.jpg'),
(102868, 7344, 'Looney Tunes Cartoons S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xtRvOAWnggiInULhyBF1ZmGzpX5.jpg'),
(102869, 7344, 'Looney Tunes Cartoons S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/96m6gsROP56NnUiQw2UWo9BLjXM.jpg'),
(102870, 7344, 'Looney Tunes Cartoons S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpFdN614LduqfMipQumYyGCFYyQ.jpg'),
(102871, 7344, 'Looney Tunes Cartoons S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5buFFgyAnqiVy50JfN7K2JzYtg.jpg'),
(102872, 7344, 'Looney Tunes Cartoons S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Y6celxLIJUGJEB4xodQdzMXd1x.jpg'),
(102873, 7344, 'Looney Tunes Cartoons S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ll38DR2DQktBKYn470JxQ3RSdFL.jpg'),
(102874, 7344, 'Looney Tunes Cartoons S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j5V1Lgxo9h4wtKADjgQWfJUVc1D.jpg'),
(102875, 7344, 'Looney Tunes Cartoons S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzWAIHzotA1QgAYYqWLGPc9Q7Oc.jpg'),
(102876, 7344, 'Looney Tunes Cartoons S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kTY0dPTZBxGnHL95YNXYwaa8Gt0.jpg'),
(102877, 7344, 'Looney Tunes Cartoons S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5uiXeyzMjr7qL0s3TFPYlsH9YLO.jpg'),
(102878, 7344, 'Looney Tunes Cartoons S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102879, 7344, 'Looney Tunes Cartoons S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102880, 7344, 'Looney Tunes Cartoons S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dDSs3twK5IqLHoKi9fbxno5qkAp.jpg'),
(102881, 7344, 'Looney Tunes Cartoons S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102882, 7344, 'Looney Tunes Cartoons S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ynwvyqyHdiI5E2nGSjZGy1S7hL4.jpg'),
(102883, 7344, 'Looney Tunes Cartoons S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/226733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102884, 7344, 'Looney Tunes Cartoons S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/226734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102885, 7344, 'Looney Tunes Cartoons S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/226735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/76BF369gZmJMdVlDfT67VSPInEC.jpg'),
(102886, 7344, 'Looney Tunes Cartoons S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/226736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102887, 7344, 'Looney Tunes Cartoons S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/226737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102888, 7344, 'Looney Tunes Cartoons S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/226738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102889, 7344, 'Looney Tunes Cartoons S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/226739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pCDIH9VfJoLWV8vIJ919qGs4FiL.jpg'),
(102890, 7344, 'Looney Tunes Cartoons S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/226740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102891, 7344, 'Looney Tunes Cartoons S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/226741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102892, 7344, 'Looney Tunes Cartoons S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/226742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9sZbPKFeudcJxUknPhKuhId6W3o.jpg'),
(102893, 7344, 'Looney Tunes Cartoons S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/226743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l18nuGMlwVmQ38fl1Sp1atPP32U.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(102894, 7344, 'Looney Tunes Cartoons S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/226744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dh3PqON8vZddBElszg33HsPfxZo.jpg'),
(102895, 7344, 'Looney Tunes Cartoons S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/226745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102896, 7344, 'Looney Tunes Cartoons S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/226746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102897, 7344, 'Looney Tunes Cartoons S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/226747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102898, 7344, 'Looney Tunes Cartoons S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/226748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102899, 7345, 'Looney Tunes Cartoons S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yw8QY8Yl8S3czvEkumDqtpSOe0X.jpg'),
(102900, 7345, 'Looney Tunes Cartoons S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h9koGQPWn2mtNLHJg5YdNiK0W6T.jpg'),
(102901, 7345, 'Looney Tunes Cartoons S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9MOIEguxInyj1c6DXT7V8vp9Nk3.jpg'),
(102902, 7345, 'Looney Tunes Cartoons S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xm7U62BSkQPcU9YJxvmIXctrHVK.jpg'),
(102903, 7345, 'Looney Tunes Cartoons S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ixBgrdFJAdWRehRIyhdXhsaxfO7.jpg'),
(102904, 7345, 'Looney Tunes Cartoons S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/psnJytiIhmOdXlDZ2GFiGv43O8O.jpg'),
(102905, 7345, 'Looney Tunes Cartoons S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/46nKqy84XRwKprAlYH7jn57aYii.jpg'),
(102906, 7345, 'Looney Tunes Cartoons S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zsNpPbYwbQUZC93h2VPrBJyhAxX.jpg'),
(102907, 7345, 'Looney Tunes Cartoons S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jXH1cXSrt5rv3a4WEC6rNY0hCpr.jpg'),
(102908, 7345, 'Looney Tunes Cartoons S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/15TUSsIMwhQIyfPxwsj3yWl0k68.jpg'),
(102909, 7346, 'Looney Tunes Cartoons S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zkNE8cNbe8PcrlXha35it7B4pN.jpg'),
(102910, 7346, 'Looney Tunes Cartoons S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hf7oJYh26PdSmSbw9nCwMXLRLWo.jpg'),
(102911, 7346, 'Looney Tunes Cartoons S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qOtqy08lSDcgCewfnhTcxeTw92V.jpg'),
(102912, 7346, 'Looney Tunes Cartoons S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1dyx0qb3f6SgwzFGUg4PVPGQhrQ.jpg'),
(102913, 7346, 'Looney Tunes Cartoons S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pGqCujMl2scXPLGG1bIYTZXIATI.jpg'),
(102914, 7346, 'Looney Tunes Cartoons S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rcTg49ghLgPqgcVPivBm8N82iVj.jpg'),
(102915, 7346, 'Looney Tunes Cartoons S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fXZjHrjo49KVJQs6Y60Bz9yI7PS.jpg'),
(102916, 7346, 'Looney Tunes Cartoons S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102917, 7346, 'Looney Tunes Cartoons S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102918, 7347, 'Looney Tunes Cartoons S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ttQuaKaVgBPgsCyaMk2l7taJEoq.jpg'),
(102919, 7347, 'Looney Tunes Cartoons S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102920, 7347, 'Looney Tunes Cartoons S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102921, 7347, 'Looney Tunes Cartoons S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102922, 7347, 'Looney Tunes Cartoons S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9xoQufhlj8R3X21vmgGeVEthr7O.jpg'),
(102923, 7347, 'Looney Tunes Cartoons S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102924, 7347, 'Looney Tunes Cartoons S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102925, 7347, 'Looney Tunes Cartoons S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/srZCJq7V5dLXomAqUBtziFWDCMI.jpg'),
(102926, 7347, 'Looney Tunes Cartoons S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102927, 7347, 'Looney Tunes Cartoons S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102928, 7348, 'Looney Tunes Cartoons S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102929, 7348, 'Looney Tunes Cartoons S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102930, 7348, 'Looney Tunes Cartoons S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102931, 7348, 'Looney Tunes Cartoons S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102932, 7348, 'Looney Tunes Cartoons S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102933, 7348, 'Looney Tunes Cartoons S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102934, 7348, 'Looney Tunes Cartoons S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102935, 7348, 'Looney Tunes Cartoons S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102936, 7348, 'Looney Tunes Cartoons S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102937, 7348, 'Looney Tunes Cartoons S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102938, 7348, 'Looney Tunes Cartoons S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102939, 7349, 'Looney Tunes Cartoons S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102940, 7349, 'Looney Tunes Cartoons S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102941, 7349, 'Looney Tunes Cartoons S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102942, 7349, 'Looney Tunes Cartoons S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102943, 7349, 'Looney Tunes Cartoons S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102944, 7349, 'Looney Tunes Cartoons S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102945, 7349, 'Looney Tunes Cartoons S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102946, 7349, 'Looney Tunes Cartoons S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102947, 7349, 'Looney Tunes Cartoons S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102948, 7349, 'Looney Tunes Cartoons S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/442250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pDQfZMJq95hckoaez9ou93Hmqy.jpg'),
(102949, 7350, 'Amor e Morte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1zJTsCTmWndVmHtJbUX9OANXHLR.jpg'),
(102950, 7350, 'Amor e Morte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sJR9gbsi0mviV3niWyT05vyWM1v.jpg'),
(102951, 7350, 'Amor e Morte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aA8fYWuGUaaKnNf2rUnDIs1LrqU.jpg'),
(102952, 7350, 'Amor e Morte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217468.mp4', 'http://image.tmdb.org/t/p/w1280/nkMN9bmHx2PaYidbfIPM2LVvGd2.jpg'),
(102953, 7350, 'Amor e Morte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217469.mp4', 'http://image.tmdb.org/t/p/w1280/rH6s4KH9DG858efuuToiG0AMmD.jpg'),
(102954, 7350, 'Amor e Morte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217470.mp4', 'http://image.tmdb.org/t/p/w1280/vhiIO3v1rTcZQ55aIK00SQAdKgc.jpg'),
(102955, 7350, 'Amor e Morte S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217471.mp4', 'http://image.tmdb.org/t/p/w1280/h1nNyJ94EHxTCYYfz96yk2MdccG.jpg'),
(102956, 7351, 'Atração Fatal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jqRMKADg8LuHwPsKdeHa22CmClZ.jpg'),
(102957, 7351, 'Atração Fatal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A2TgtzjAsFTwasMEPcFRnJumhRt.jpg'),
(102958, 7351, 'Atração Fatal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zX2X8dsue1nDeQXUenTkBX0ndZu.jpg'),
(102959, 7351, 'Atração Fatal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217240.mp4', 'http://image.tmdb.org/t/p/w1280/6KhtUqk4seKimQL9ZPr86dsMPl5.jpg'),
(102960, 7351, 'Atração Fatal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217241.mp4', 'http://image.tmdb.org/t/p/w1280/pRo5BPZIBSHiRTnMskZFyjdDeOZ.jpg'),
(102961, 7351, 'Atração Fatal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217242.mp4', 'http://image.tmdb.org/t/p/w1280/bHWE3Rb7z92tlsM5TWwg8t8sbn0.jpg'),
(102962, 7351, 'Atração Fatal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217243.mp4', 'http://image.tmdb.org/t/p/w1280/fvRzLHi4kTUQNufDBULzs1q2pPL.jpg'),
(102963, 7351, 'Atração Fatal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217244.mp4', 'http://image.tmdb.org/t/p/w1280/g6S4wXz9rUNlANKFRdUeXv0rxh7.jpg'),
(102964, 7352, 'Bungo Stray Dogs S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eCpIa4RJErtQ5xFtFXo9OwpA6ww.jpg'),
(102965, 7352, 'Bungo Stray Dogs S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6MQLk38FtAkqqJYG4U1QzWFLFK9.jpg'),
(102966, 7352, 'Bungo Stray Dogs S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q6OswAXgWvnKULmtYowtYPyzNsr.jpg'),
(102967, 7352, 'Bungo Stray Dogs S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fh2tXncKcwTn9Ea94GXV8Jh3klI.jpg'),
(102968, 7352, 'Bungo Stray Dogs S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3aasmHqxNJaMWeLhzjMmuyNn0hj.jpg'),
(102969, 7352, 'Bungo Stray Dogs S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oiYxxYegy6txf8sSvZlgSNWFYHe.jpg'),
(102970, 7352, 'Bungo Stray Dogs S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uytVblGUp9ZDX7HkGW1tYioUjlt.jpg'),
(102971, 7352, 'Bungo Stray Dogs S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2zfHBtuh00oi1eAqFWb3PbS6Zpy.jpg'),
(102972, 7352, 'Bungo Stray Dogs S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rxpHpcBCOlleVkPjn4Aw6jYBX1Z.jpg'),
(102973, 7352, 'Bungo Stray Dogs S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5crR2D0zxuvzTRMfx6PoMrQO6E.jpg'),
(102974, 7352, 'Bungo Stray Dogs S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qxP1380qiPt1XSWBhXA7Bd7szfh.jpg'),
(102975, 7352, 'Bungo Stray Dogs S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8vB4Fm56j3UQqOqAo73JdRLiAS7.jpg'),
(102976, 7353, 'Bungo Stray Dogs S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102977, 7353, 'Bungo Stray Dogs S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102978, 7353, 'Bungo Stray Dogs S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102979, 7353, 'Bungo Stray Dogs S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102980, 7353, 'Bungo Stray Dogs S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102981, 7353, 'Bungo Stray Dogs S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102982, 7353, 'Bungo Stray Dogs S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102983, 7353, 'Bungo Stray Dogs S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102984, 7353, 'Bungo Stray Dogs S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102985, 7353, 'Bungo Stray Dogs S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102986, 7353, 'Bungo Stray Dogs S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102987, 7353, 'Bungo Stray Dogs S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102988, 7353, 'Bungo Stray Dogs S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102989, 7354, 'Bungo Stray Dogs S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102990, 7354, 'Bungo Stray Dogs S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102991, 7354, 'Bungo Stray Dogs S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102992, 7354, 'Bungo Stray Dogs S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102993, 7354, 'Bungo Stray Dogs S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102994, 7354, 'Bungo Stray Dogs S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102995, 7354, 'Bungo Stray Dogs S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102996, 7354, 'Bungo Stray Dogs S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102997, 7354, 'Bungo Stray Dogs S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102998, 7354, 'Bungo Stray Dogs S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(102999, 7354, 'Bungo Stray Dogs S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103000, 7354, 'Bungo Stray Dogs S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103001, 7355, 'Bungo Stray Dogs S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103002, 7355, 'Bungo Stray Dogs S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103003, 7355, 'Bungo Stray Dogs S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103004, 7355, 'Bungo Stray Dogs S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103005, 7355, 'Bungo Stray Dogs S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103006, 7355, 'Bungo Stray Dogs S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103007, 7355, 'Bungo Stray Dogs S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103008, 7355, 'Bungo Stray Dogs S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103009, 7355, 'Bungo Stray Dogs S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103010, 7355, 'Bungo Stray Dogs S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103011, 7355, 'Bungo Stray Dogs S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103012, 7355, 'Bungo Stray Dogs S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103013, 7355, 'Bungo Stray Dogs S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103014, 7356, 'Bungo Stray Dogs S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103015, 7356, 'Bungo Stray Dogs S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103016, 7356, 'Bungo Stray Dogs S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103017, 7356, 'Bungo Stray Dogs S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103018, 7356, 'Bungo Stray Dogs S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103019, 7356, 'Bungo Stray Dogs S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103020, 7356, 'Bungo Stray Dogs S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103021, 7356, 'Bungo Stray Dogs S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103022, 7356, 'Bungo Stray Dogs S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103023, 7356, 'Bungo Stray Dogs S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103024, 7356, 'Bungo Stray Dogs S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4WlY8Wflsa4ySLxwQzBSLORBQPy.jpg'),
(103025, 7357, 'Citadel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4iGL5Xeb4bS4B2QSQqeT7DvTSWA.jpg'),
(103026, 7357, 'Citadel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o4HkAGaIc14fKVKIkt36whIB6U4.jpg'),
(103027, 7357, 'Citadel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217461.mp4', 'http://image.tmdb.org/t/p/w1280/1qtdEBVBgPvIOtQ02zrpfrxKg73.jpg'),
(103028, 7357, 'Citadel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217462.mp4', 'http://image.tmdb.org/t/p/w1280/iEspKb8Cpezi77vByEARmSKKxbZ.jpg'),
(103029, 7357, 'Citadel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217463.mp4', 'http://image.tmdb.org/t/p/w1280/eYcgZl9mVKn5Aumf4wuuUOGq9iI.jpg'),
(103030, 7357, 'Citadel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217464.mp4', 'http://image.tmdb.org/t/p/w1280/dJCOYjNNYt4OaQ44mSpi5QuvCpS.jpg'),
(103031, 7358, 'Coliseu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3LKKAAIfMSyrIGkhAQkTgKV05ip.jpg'),
(103032, 7358, 'Coliseu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fZtc5BGx4kQoOhLfHVzbISO6cIF.jpg'),
(103033, 7358, 'Coliseu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHEODvHCsldKFT1a3toyJ1ScdYg.jpg'),
(103034, 7358, 'Coliseu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hA2poo2g3WEYVlGfdtLiKKWHnfy.jpg'),
(103035, 7358, 'Coliseu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z0d4gzXgaWKFMiFYL5FYcoWSZML.jpg'),
(103036, 7358, 'Coliseu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pQyEfKtPVKAM5VrpuwL65u4o8vP.jpg'),
(103037, 7358, 'Coliseu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uicWgF7dCNXFsTfdbme04A1CSWi.jpg'),
(103038, 7358, 'Coliseu S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lu2oNxtKXEkkOwkY8lRUVxuRX9I.jpg'),
(103039, 7359, 'Amar e Matar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wcJyEt6T6yfT9aN5VZkqQQnivWx.jpg'),
(103040, 7359, 'Amar e Matar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dx3yKtOgLQWExkNlcZggmNudJ8d.jpg'),
(103041, 7359, 'Amar e Matar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/48dGgi6k1jbvsroUVKD6JdClTNA.jpg'),
(103042, 7359, 'Amar e Matar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tNPdZVGkFuDlyOcajaL6mPNgmsw.jpg'),
(103043, 7359, 'Amar e Matar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AhmFOvCf2PTkVnGwgcJBB9t61GO.jpg'),
(103044, 7359, 'Amar e Matar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shNVK3OA0SaiUTFnK4AIjYjjmDK.jpg'),
(103045, 7359, 'Amar e Matar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5RaJx9qbYnXHjq8S0uh7rOmcL.jpg'),
(103046, 7359, 'Amar e Matar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1HEy873agWDSbMQmCq0Zvmqdpmq.jpg'),
(103047, 7359, 'Amar e Matar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/smhnO7DTA4L9S5bQGIPqHWy33cI.jpg'),
(103048, 7359, 'Amar e Matar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7N0GuOZ9KkUB2sQWbCeAvEyjbqU.jpg'),
(103049, 7359, 'Amar e Matar S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/210743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWc6purnHtQprcIih8ATjr12UD3.jpg'),
(103050, 7359, 'Amar e Matar S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/210744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qdP6CDndYq4fUI02bnXK67AHiAp.jpg'),
(103051, 7359, 'Amar e Matar S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/210745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2HdwFYkKw2QMyezBwevGSdfm4uj.jpg'),
(103052, 7359, 'Amar e Matar S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/210746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xXsXRUHDdEkQUP3VydLIrWuGMUa.jpg'),
(103053, 7359, 'Amar e Matar S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/210747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aATae4n2Ecc79nTvN9Yf4wnDwGH.jpg'),
(103054, 7359, 'Amar e Matar S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/210748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qcfQRlZZEIBXLb4QkPXyKgfzk1T.jpg'),
(103055, 7360, 'Digman! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zOXFZuSkG15bONP61Y51GRLVoZH.jpg'),
(103056, 7360, 'Digman! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220550.mp4', 'http://image.tmdb.org/t/p/w1280/yhD1E7vZDNYObG2smhfKtXxpb2j.jpg'),
(103057, 7360, 'Digman! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220551.mp4', 'http://image.tmdb.org/t/p/w1280/tLlmUW4JOMUdBmYSJFotftxaagU.jpg'),
(103058, 7360, 'Digman! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220552.mp4', 'http://image.tmdb.org/t/p/w1280/2bNKAp0hKFTjZI2dtQRTfj5WLAi.jpg'),
(103059, 7360, 'Digman! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220553.mp4', 'http://image.tmdb.org/t/p/w1280/18G6I1tHrihMxcdkG32ZZCgwiIR.jpg'),
(103060, 7360, 'Digman! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220554.mp4', 'http://image.tmdb.org/t/p/w1280/47lAROO4dJnuhtfVJqgb9cUGMad.jpg'),
(103061, 7360, 'Digman! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220555.mp4', 'http://image.tmdb.org/t/p/w1280/nY7ifi0lXPVUQlnbQJEXUXKTVXN.jpg'),
(103062, 7360, 'Digman! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yt6yvFBpeWVaqowRqmeXmvU3IsT.jpg'),
(103063, 7361, 'Enfermeira S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m1MxlyDi6fQ4aqWx6Xh6jN8buKB.jpg'),
(103064, 7361, 'Enfermeira S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ctDjm1Hi3c1XqYzXOgXdHkZwxyd.jpg'),
(103065, 7361, 'Enfermeira S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qOUPTZ7dvnGMRo2dNsA2DWtRH6e.jpg'),
(103066, 7361, 'Enfermeira S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m8S7Ugnv79bcpq3yC5ZqDZLo2WT.jpg'),
(103067, 7362, 'Ganhei um Poder Apelão em Outro Mundo e Agora Sou Imbatível no Mundo Real S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mgxZkxHsBvX0IVNT5BJpiSW5FRR.jpg'),
(103068, 7362, 'Ganhei um Poder Apelão em Outro Mundo e Agora Sou Imbatível no Mundo Real S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223163.mp4', 'http://image.tmdb.org/t/p/w1280/oI1HElsgnNhlP2a0GkY9zDI4Q9r.jpg'),
(103069, 7362, 'Ganhei um Poder Apelão em Outro Mundo e Agora Sou Imbatível no Mundo Real S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223164.mp4', 'http://image.tmdb.org/t/p/w1280/jYCJbAFuEY5i3pHlF0OYMxW4zKG.jpg'),
(103070, 7362, 'Ganhei um Poder Apelão em Outro Mundo e Agora Sou Imbatível no Mundo Real S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223165.mp4', 'http://image.tmdb.org/t/p/w1280/bkfQg5f1jJYVThUrHx36kB1c8Qj.jpg'),
(103071, 7362, 'Ganhei um Poder Apelão em Outro Mundo e Agora Sou Imbatível no Mundo Real S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223166.mp4', 'http://image.tmdb.org/t/p/w1280/xNvMPmgPWq6hWMkeWAzmLa7rrPH.jpg'),
(103072, 7362, 'Ganhei um Poder Apelão em Outro Mundo e Agora Sou Imbatível no Mundo Real S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223167.mp4', 'http://image.tmdb.org/t/p/w1280/7gKIeGrtg1TbMQuTnYgYFN5wkQQ.jpg'),
(103073, 7362, 'Ganhei um Poder Apelão em Outro Mundo e Agora Sou Imbatível no Mundo Real S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223168.mp4', 'http://image.tmdb.org/t/p/w1280/ar1QV1RrcWGtOSMHmIUDirHnpKq.jpg'),
(103074, 7362, 'Ganhei um Poder Apelão em Outro Mundo e Agora Sou Imbatível no Mundo Real S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/50OsbGp6AWw4za2aAM82vKburcg.jpg'),
(103075, 7362, 'Ganhei um Poder Apelão em Outro Mundo e Agora Sou Imbatível no Mundo Real S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223170.mp4', 'http://image.tmdb.org/t/p/w1280/oOIY8WTR6w1KhWH6IgyTFPchMnd.jpg'),
(103076, 7362, 'Ganhei um Poder Apelão em Outro Mundo e Agora Sou Imbatível no Mundo Real S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223171.mp4', 'http://image.tmdb.org/t/p/w1280/lU9wTAG0LfNeakyFUr9X1IJLU4l.jpg'),
(103077, 7362, 'Ganhei um Poder Apelão em Outro Mundo e Agora Sou Imbatível no Mundo Real S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223172.mp4', 'http://image.tmdb.org/t/p/w1280/mVhziawAJvFc0JZ81xoMA2JfaG9.jpg'),
(103078, 7362, 'Ganhei um Poder Apelão em Outro Mundo e Agora Sou Imbatível no Mundo Real S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223173.mp4', 'http://image.tmdb.org/t/p/w1280/1PuATT6WVnsB3QQb11GOPd4PN7G.jpg'),
(103079, 7362, 'Ganhei um Poder Apelão em Outro Mundo e Agora Sou Imbatível no Mundo Real S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/883096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sAlUqCilYg3hrfbohIKL6Amse3.jpg'),
(103080, 7363, 'Grandes Expectativas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yONIPsLzcEqfh8GzfjFhI7ZZzd4.jpg'),
(103081, 7363, 'Grandes Expectativas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ly6eGQlsLKNU1NlClBMg66Bvmt9.jpg'),
(103082, 7363, 'Grandes Expectativas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217455.mp4', 'http://image.tmdb.org/t/p/w1280/7eHbKK67SErRuV9OcY56M0oPUVi.jpg'),
(103083, 7363, 'Grandes Expectativas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217456.mp4', 'http://image.tmdb.org/t/p/w1280/Ama2F9med8OIXngDyB7KwhwuLpC.jpg'),
(103084, 7363, 'Grandes Expectativas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217457.mp4', 'http://image.tmdb.org/t/p/w1280/4Ro5z8LdehWNynCz18UUTHQiYaD.jpg'),
(103085, 7363, 'Grandes Expectativas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217458.mp4', 'http://image.tmdb.org/t/p/w1280/1q1bibi5TgSVPbIe2RJGW5MZ60z.jpg'),
(103086, 7364, 'Jigokuraku S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cBYGS8slT5GnBfJylLrimTKPRQG.jpg'),
(103087, 7364, 'Jigokuraku S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/huhB21i6IKWnGBQLd6JRRIHRSgL.jpg'),
(103088, 7364, 'Jigokuraku S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227662.mp4', 'http://image.tmdb.org/t/p/w1280/9yZfCDYjgUvqwJj4cR1vaxSq9dQ.jpg'),
(103089, 7364, 'Jigokuraku S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227663.mp4', 'http://image.tmdb.org/t/p/w1280/czrHtpVCRGSQSLeDH0pgnOkiB6y.jpg'),
(103090, 7364, 'Jigokuraku S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227664.mp4', 'http://image.tmdb.org/t/p/w1280/fA4rb9YFSgq1xzlZEDpBEiRARb6.jpg'),
(103091, 7364, 'Jigokuraku S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227665.mp4', 'http://image.tmdb.org/t/p/w1280/1Is8K5zejhwAkGovdmKeIM6TEME.jpg'),
(103092, 7364, 'Jigokuraku S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227666.mp4', 'http://image.tmdb.org/t/p/w1280/uO1jm9qnpZaQivdhIL1aqwRxjJD.jpg'),
(103093, 7364, 'Jigokuraku S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227667.mp4', 'http://image.tmdb.org/t/p/w1280/3CF2Q6AZM1tHSovv1AwlrRlozJ3.jpg'),
(103094, 7364, 'Jigokuraku S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227668.mp4', 'http://image.tmdb.org/t/p/w1280/jfPvi2HkRrJGaNXngejJ96hwEzz.jpg'),
(103095, 7364, 'Jigokuraku S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227669.mp4', 'http://image.tmdb.org/t/p/w1280/ApVsykHWYMpwJnx2Qrk9pfT8g7C.jpg'),
(103096, 7364, 'Jigokuraku S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227670.mp4', 'http://image.tmdb.org/t/p/w1280/3Uf9vLl7gjIMUe0xEuXKaJQaPWP.jpg'),
(103097, 7364, 'Jigokuraku S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/227671.mp4', 'http://image.tmdb.org/t/p/w1280/iZE9vDF33ZKhKllFAFEUEuDt5B7.jpg'),
(103098, 7364, 'Jigokuraku S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/227672.mp4', 'http://image.tmdb.org/t/p/w1280/tddzRELfd45ZWGEu6komcGBg1Zp.jpg'),
(103099, 7365, 'Konosuba Uma Explosao Neste Mundo Maravilhoso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tnFG9R7OpRBk4ZuAEVkbSGsPHcx.jpg'),
(103100, 7365, 'Konosuba Uma Explosao Neste Mundo Maravilhoso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223332.mp4', 'http://image.tmdb.org/t/p/w1280/J881TJ28j7iiZOLAqbvUf0Ln4b.jpg'),
(103101, 7365, 'Konosuba Uma Explosao Neste Mundo Maravilhoso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223333.mp4', 'http://image.tmdb.org/t/p/w1280/17iOiN6uYDRpvu2a0MtlOlnkAzV.jpg'),
(103102, 7365, 'Konosuba Uma Explosao Neste Mundo Maravilhoso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223334.mp4', 'http://image.tmdb.org/t/p/w1280/2dvGRrM93r85rXyCBkC6Hyt8bah.jpg'),
(103103, 7365, 'Konosuba Uma Explosao Neste Mundo Maravilhoso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223335.mp4', 'http://image.tmdb.org/t/p/w1280/7lyCUtH96vCUsz7LMfNgCsGOnLK.jpg'),
(103104, 7365, 'Konosuba Uma Explosao Neste Mundo Maravilhoso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223336.mp4', 'http://image.tmdb.org/t/p/w1280/cZb98JT9rncZCFhylNzOEjgBJ8M.jpg'),
(103105, 7365, 'Konosuba Uma Explosao Neste Mundo Maravilhoso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223337.mp4', 'http://image.tmdb.org/t/p/w1280/qiEdZbtqDYvySSMSBowDvkUcvnB.jpg'),
(103106, 7365, 'Konosuba Uma Explosao Neste Mundo Maravilhoso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xcPT8KuiYAKvhCRaYa9SOtiEWSO.jpg'),
(103107, 7365, 'Konosuba Uma Explosao Neste Mundo Maravilhoso S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223339.mp4', 'http://image.tmdb.org/t/p/w1280/u0AMAYkGoYvePFDo07m4KnthOzm.jpg'),
(103108, 7365, 'Konosuba Uma Explosao Neste Mundo Maravilhoso S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223340.mp4', 'http://image.tmdb.org/t/p/w1280/xfCZgEM3Ur6dgDY8l7kLK7gKFzO.jpg'),
(103109, 7365, 'Konosuba Uma Explosao Neste Mundo Maravilhoso S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223341.mp4', 'http://image.tmdb.org/t/p/w1280/7iN2ojeYa2nOXp4eZjCBruD5WzR.jpg'),
(103110, 7365, 'Konosuba Uma Explosao Neste Mundo Maravilhoso S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223342.mp4', 'http://image.tmdb.org/t/p/w1280/5WynK3VbklZKeQhMyMbzYxFnxnC.jpg'),
(103111, 7366, 'Mansão das MILFs S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rZcn4NCEZqkZo2QHOoAg7nauqhn.jpg'),
(103112, 7366, 'Mansão das MILFs S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rZcn4NCEZqkZo2QHOoAg7nauqhn.jpg'),
(103113, 7366, 'Mansão das MILFs S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rZcn4NCEZqkZo2QHOoAg7nauqhn.jpg'),
(103114, 7366, 'Mansão das MILFs S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rZcn4NCEZqkZo2QHOoAg7nauqhn.jpg'),
(103115, 7366, 'Mansão das MILFs S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rZcn4NCEZqkZo2QHOoAg7nauqhn.jpg'),
(103116, 7366, 'Mansão das MILFs S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rZcn4NCEZqkZo2QHOoAg7nauqhn.jpg'),
(103117, 7366, 'Mansão das MILFs S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rZcn4NCEZqkZo2QHOoAg7nauqhn.jpg'),
(103118, 7366, 'Mansão das MILFs S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rZcn4NCEZqkZo2QHOoAg7nauqhn.jpg'),
(103119, 7366, 'Mansão das MILFs S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rZcn4NCEZqkZo2QHOoAg7nauqhn.jpg'),
(103120, 7367, 'Mansão das MILFs S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/432810.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4NXBl5BCJ2XzyVV2tmeb5yHwjDM.jpg'),
(103121, 7367, 'Mansão das MILFs S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/432811.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y9Tms0U2Sqi01BGF9fXq3g0jEmH.jpg'),
(103122, 7367, 'Mansão das MILFs S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/424685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rZcn4NCEZqkZo2QHOoAg7nauqhn.jpg'),
(103123, 7367, 'Mansão das MILFs S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/427408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rZcn4NCEZqkZo2QHOoAg7nauqhn.jpg'),
(103124, 7367, 'Mansão das MILFs S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/436346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rZcn4NCEZqkZo2QHOoAg7nauqhn.jpg'),
(103125, 7367, 'Mansão das MILFs S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/436347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rZcn4NCEZqkZo2QHOoAg7nauqhn.jpg'),
(103126, 7367, 'Mansão das MILFs S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/442169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rZcn4NCEZqkZo2QHOoAg7nauqhn.jpg'),
(103127, 7367, 'Mansão das MILFs S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/447617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rZcn4NCEZqkZo2QHOoAg7nauqhn.jpg'),
(103128, 7367, 'Mansão das MILFs S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/456084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rZcn4NCEZqkZo2QHOoAg7nauqhn.jpg'),
(103129, 7367, 'Mansão das MILFs S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/460847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rZcn4NCEZqkZo2QHOoAg7nauqhn.jpg'),
(103130, 7367, 'Mansão das MILFs S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/467302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rZcn4NCEZqkZo2QHOoAg7nauqhn.jpg'),
(103131, 7367, 'Mansão das MILFs S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/506891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rZcn4NCEZqkZo2QHOoAg7nauqhn.jpg'),
(103132, 7368, 'Mashle: Magia e Músculos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sNuDaeRpJeAN68nkicHXhUspgyn.jpg'),
(103133, 7368, 'Mashle: Magia e Músculos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222279.mp4', 'http://image.tmdb.org/t/p/w1280/wRhVcJOzPORex4f5MleMiBE0a8N.jpg'),
(103134, 7368, 'Mashle: Magia e Músculos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222280.mp4', 'http://image.tmdb.org/t/p/w1280/nUWfraG7hbtVIZ2VaZv2QNqMgsZ.jpg'),
(103135, 7368, 'Mashle: Magia e Músculos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222281.mp4', 'http://image.tmdb.org/t/p/w1280/yCkSMesQxSlUSl0bAwEA2QbShpk.jpg'),
(103136, 7368, 'Mashle: Magia e Músculos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222282.mp4', 'http://image.tmdb.org/t/p/w1280/kGWzULYc0GgdQaKFIMFNmM7COFq.jpg'),
(103137, 7368, 'Mashle: Magia e Músculos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222283.mp4', 'http://image.tmdb.org/t/p/w1280/AiSJOokpu1cBDUlMtth7SLj10iu.jpg'),
(103138, 7368, 'Mashle: Magia e Músculos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rpMnOXe42hkvMN1Dj5Dzsu6NZz.jpg'),
(103139, 7368, 'Mashle: Magia e Músculos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222285.mp4', 'http://image.tmdb.org/t/p/w1280/94Jx029j907EIqxZXbslIDcW07X.jpg'),
(103140, 7368, 'Mashle: Magia e Músculos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222286.mp4', 'http://image.tmdb.org/t/p/w1280/cWu9sSqfrd3YoSOzOHuk6F5qYbl.jpg'),
(103141, 7368, 'Mashle: Magia e Músculos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222287.mp4', 'http://image.tmdb.org/t/p/w1280/8kxD7JcC2Re1u4TNQ67s9IjGHLg.jpg'),
(103142, 7368, 'Mashle: Magia e Músculos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222288.mp4', 'http://image.tmdb.org/t/p/w1280/6bL1AUjhnUJjLhAoWkJ4SksPW3L.jpg'),
(103143, 7368, 'Mashle: Magia e Músculos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222289.mp4', 'http://image.tmdb.org/t/p/w1280/71iETgbXw6FragBF5GoNyRqQWkN.jpg'),
(103144, 7369, 'Mashle: Magia e Músculos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/270615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rpMnOXe42hkvMN1Dj5Dzsu6NZz.jpg'),
(103145, 7369, 'Mashle: Magia e Músculos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/270616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rpMnOXe42hkvMN1Dj5Dzsu6NZz.jpg'),
(103146, 7369, 'Mashle: Magia e Músculos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/271065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rpMnOXe42hkvMN1Dj5Dzsu6NZz.jpg'),
(103147, 7369, 'Mashle: Magia e Músculos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/276405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rpMnOXe42hkvMN1Dj5Dzsu6NZz.jpg'),
(103148, 7369, 'Mashle: Magia e Músculos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rpMnOXe42hkvMN1Dj5Dzsu6NZz.jpg'),
(103149, 7369, 'Mashle: Magia e Músculos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/297523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rpMnOXe42hkvMN1Dj5Dzsu6NZz.jpg'),
(103150, 7369, 'Mashle: Magia e Músculos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/302550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rpMnOXe42hkvMN1Dj5Dzsu6NZz.jpg'),
(103151, 7369, 'Mashle: Magia e Músculos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/308581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rpMnOXe42hkvMN1Dj5Dzsu6NZz.jpg'),
(103152, 7369, 'Mashle: Magia e Músculos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/315621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rpMnOXe42hkvMN1Dj5Dzsu6NZz.jpg'),
(103153, 7369, 'Mashle: Magia e Músculos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/322521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rpMnOXe42hkvMN1Dj5Dzsu6NZz.jpg'),
(103154, 7369, 'Mashle: Magia e Músculos S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/325577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rpMnOXe42hkvMN1Dj5Dzsu6NZz.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(103155, 7369, 'Mashle: Magia e Músculos S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/330569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rpMnOXe42hkvMN1Dj5Dzsu6NZz.jpg'),
(103156, 7370, 'Minha Mana Apelona S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zA4PF6ea2Ptyw3K3XF2RH5LWdxH.jpg'),
(103157, 7370, 'Minha Mana Apelona S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223265.mp4', 'http://image.tmdb.org/t/p/w1280/o8DAs99IvWwRfrdvcJNpKI9LXlH.jpg'),
(103158, 7370, 'Minha Mana Apelona S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223266.mp4', 'http://image.tmdb.org/t/p/w1280/ma092x6YVxiXiVoXdr2o5G1aylm.jpg'),
(103159, 7370, 'Minha Mana Apelona S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223267.mp4', 'http://image.tmdb.org/t/p/w1280/pdL0b9W8rrAquCXh3NyTf5l05Ic.jpg'),
(103160, 7370, 'Minha Mana Apelona S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223268.mp4', 'http://image.tmdb.org/t/p/w1280/dID8kA8NMP0QkyJZyldS4qHFFYc.jpg'),
(103161, 7370, 'Minha Mana Apelona S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223269.mp4', 'http://image.tmdb.org/t/p/w1280/gRqNcIQtsF8iEOD7YhwZOk0sBIO.jpg'),
(103162, 7370, 'Minha Mana Apelona S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223270.mp4', 'http://image.tmdb.org/t/p/w1280/fRwwlL2drevo2askFj5DqSFxPY6.jpg'),
(103163, 7370, 'Minha Mana Apelona S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sysz1yNPpgwA7weihJ7lIgHnt1O.jpg'),
(103164, 7370, 'Minha Mana Apelona S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223272.mp4', 'http://image.tmdb.org/t/p/w1280/edWgspRjt7Ck7OWrOzZGwnomBm7.jpg'),
(103165, 7370, 'Minha Mana Apelona S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223273.mp4', 'http://image.tmdb.org/t/p/w1280/6tCca2Lws4ZzjikCkwPTkWw4GTb.jpg'),
(103166, 7370, 'Minha Mana Apelona S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223274.mp4', 'http://image.tmdb.org/t/p/w1280/oonadxEPsK9p1H25WjkbOcPMbUp.jpg'),
(103167, 7370, 'Minha Mana Apelona S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223275.mp4', 'http://image.tmdb.org/t/p/w1280/floK8wgPIeovXplvaPVlTppSdPv.jpg'),
(103168, 7371, 'Os Pacientes do Dr. García S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mabnTMb29jiFIbOyxuIHkmvqkLe.jpg'),
(103169, 7371, 'Os Pacientes do Dr. García S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l0KFhV4dNclCC6ePw4zTufpAkpH.jpg'),
(103170, 7371, 'Os Pacientes do Dr. García S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4kmYdcS7RggAzBE48ZMTEzAMcxi.jpg'),
(103171, 7371, 'Os Pacientes do Dr. García S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i8mTsGiwmRAhrjjix7R1VdDBnWP.jpg'),
(103172, 7371, 'Os Pacientes do Dr. García S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wJrBtQUmElBmIePWBzUb1b0kHAt.jpg'),
(103173, 7371, 'Os Pacientes do Dr. García S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97RNZiTUEPgjv9JRc3DH9FUMdNr.jpg'),
(103174, 7371, 'Os Pacientes do Dr. García S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iLH8jfxZKz3OGmtpKQe5QyvDeRt.jpg'),
(103175, 7371, 'Os Pacientes do Dr. García S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xG58khbiG5gC42IbLshvhF0LXa1.jpg'),
(103176, 7371, 'Os Pacientes do Dr. García S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQYEuFdpPH0ZnMGH3zkEDoECg1V.jpg'),
(103177, 7371, 'Os Pacientes do Dr. García S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/UwGjjTZev46VKsqxUlyX5LEoij.jpg'),
(103178, 7372, 'Os Reis do Esgoto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r5oB9rPxhmyj6vqbRGiEwhNQbWB.jpg'),
(103179, 7372, 'Os Reis do Esgoto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216943.mp4', 'http://image.tmdb.org/t/p/w1280/hZYAaVNGS5XajaEqPDGW8oYoMOI.jpg'),
(103180, 7372, 'Os Reis do Esgoto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216944.mp4', 'http://image.tmdb.org/t/p/w1280/9hrquHfpn9TDHd61XZVdZ1iGPtr.jpg'),
(103181, 7372, 'Os Reis do Esgoto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216945.mp4', 'http://image.tmdb.org/t/p/w1280/hWDYEmHRhSJ1CRffvVoFu7N4atS.jpg'),
(103182, 7372, 'Os Reis do Esgoto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1jB4tpR6COZ0VAsfR2Hv4gf9nsb.jpg'),
(103183, 7372, 'Os Reis do Esgoto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1jB4tpR6COZ0VAsfR2Hv4gf9nsb.jpg'),
(103184, 7373, 'Rã e Sapo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2BI5BVHcKV960bM6xQjZ2enGUma.jpg'),
(103185, 7373, 'Rã e Sapo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDbeNBBKRBJM9WMfr1aysUqza5H.jpg'),
(103186, 7373, 'Rã e Sapo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s1AuAU7nsuKrawNAXiLOLO5MnEE.jpg'),
(103187, 7373, 'Rã e Sapo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/agruCmUA6GNI2a1syjDyoYZ34Lj.jpg'),
(103188, 7373, 'Rã e Sapo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ynfukHQIHc9EGzfln3Ugj0Sx4Fa.jpg'),
(103189, 7373, 'Rã e Sapo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hyq9nirvhbKvHCZ3e6JEX3m9cQ1.jpg'),
(103190, 7373, 'Rã e Sapo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/agruCmUA6GNI2a1syjDyoYZ34Lj.jpg'),
(103191, 7373, 'Rã e Sapo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5xVLalRNhGFsc3P6IJzq3dwdyAW.jpg'),
(103192, 7374, 'Saint X S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cX3OIYhhaosKzAXygmhMpCRS5oj.jpg'),
(103193, 7374, 'Saint X S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/O1N4PfIBpI5zaJSkDltUvnCABX.jpg'),
(103194, 7374, 'Saint X S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cXpMvq9R2OaVkaU42b4TIXgD9tt.jpg'),
(103195, 7374, 'Saint X S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216937.mp4', 'http://image.tmdb.org/t/p/w1280/v3BrlXtwcNmwgiFoa1OP3Xhpk63.jpg'),
(103196, 7374, 'Saint X S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216938.mp4', 'http://image.tmdb.org/t/p/w1280/rn34pT7uOSHTHYbTbskiHGvQlPT.jpg'),
(103197, 7374, 'Saint X S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wViKoQ7njLujruFWBMY5NUzj7EV.jpg'),
(103198, 7374, 'Saint X S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216940.mp4', 'http://image.tmdb.org/t/p/w1280/g0tYNyqYY8qWMVbsRmW3I9ET3PC.jpg'),
(103199, 7374, 'Saint X S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216941.mp4', 'http://image.tmdb.org/t/p/w1280/q2krEbgQajxFpK7ZS92c7DDc2tf.jpg'),
(103200, 7375, 'Saturdays: Pista de Patinação S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gS0dWf5w9VO8mwWUxA5dJIEPP0A.jpg'),
(103201, 7375, 'Saturdays: Pista de Patinação S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dR1HcnGbUjz0ILqT3D47Way0sgR.jpg'),
(103202, 7375, 'Saturdays: Pista de Patinação S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v7mvtJBvUPwHy65cF0JnFRy9bq0.jpg'),
(103203, 7375, 'Saturdays: Pista de Patinação S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fWfNKxDspXJp9uFnL41OHS7rt3.jpg'),
(103204, 7375, 'Saturdays: Pista de Patinação S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5OeqMc8ugL64A1mj0I7ixaEjYNg.jpg'),
(103205, 7375, 'Saturdays: Pista de Patinação S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/V4qIXHWA8sKbgBqI1LvxVex7zk.jpg'),
(103206, 7375, 'Saturdays: Pista de Patinação S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5faqwnwdhvliZL8oEy0iFqoPYFE.jpg'),
(103207, 7375, 'Saturdays: Pista de Patinação S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ri8f96CK9qN31JOIKerskDS4WTD.jpg'),
(103208, 7375, 'Saturdays: Pista de Patinação S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5aVIVI1EwXkeQKmXpYNJ9iakdO6.jpg'),
(103209, 7375, 'Saturdays: Pista de Patinação S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/566529.mp4', 'http://image.tmdb.org//t/p/w1280/iD1pyqucoOf9NjnTkKDCuqcHIhX.jpg'),
(103210, 7375, 'Saturdays: Pista de Patinação S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5faqwnwdhvliZL8oEy0iFqoPYFE.jpg'),
(103211, 7375, 'Saturdays: Pista de Patinação S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5faqwnwdhvliZL8oEy0iFqoPYFE.jpg'),
(103212, 7375, 'Saturdays: Pista de Patinação S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h7D6s00BAIu7jjOfZuvdzTSb9w3.jpg'),
(103213, 7375, 'Saturdays: Pista de Patinação S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5faqwnwdhvliZL8oEy0iFqoPYFE.jpg'),
(103214, 7376, 'Senhora Secretária S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8k8YOD0mXWrQB4un0HCoE8XHiq4.jpg'),
(103215, 7376, 'Senhora Secretária S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oghvfH0SsQGZmfcZtRVCy9JXv2V.jpg'),
(103216, 7376, 'Senhora Secretária S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lWsBQCqIYdLXxLORGPmM2gcqoZs.jpg'),
(103217, 7376, 'Senhora Secretária S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eIABPjjnsf94Bi2KUrqGEEFlgu4.jpg'),
(103218, 7376, 'Senhora Secretária S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/53H84CtrrMORyyCrZ4p0cAJ4qAl.jpg'),
(103219, 7376, 'Senhora Secretária S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3KhQlTd66e6m07guQvJfZzvO8Yu.jpg'),
(103220, 7376, 'Senhora Secretária S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/73LWgucFT230HcJMhs34R06UN8y.jpg'),
(103221, 7376, 'Senhora Secretária S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/P9k0QsXkESXn3ie65Y9Bld27UD.jpg'),
(103222, 7376, 'Senhora Secretária S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rhr5WTH2fWn0tqfk74tx8viCKJW.jpg'),
(103223, 7376, 'Senhora Secretária S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8JA4VkG5jSUQrhnuuuQhhJNCRA4.jpg'),
(103224, 7376, 'Senhora Secretária S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/210585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cI1JujvZbzGUkBhALjurBD6Y2Cm.jpg'),
(103225, 7376, 'Senhora Secretária S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/210586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oJQ9k8RkLAPSBe7kpdlVLhNSZyJ.jpg'),
(103226, 7376, 'Senhora Secretária S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/210587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgr1ZQh8mSnts7unVFgVl065wb6.jpg'),
(103227, 7376, 'Senhora Secretária S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/210588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yS1PwxLyiCr9Oi46FLHLwJhAzFX.jpg'),
(103228, 7376, 'Senhora Secretária S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/210589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6nkO0QKwHoFGL73ClOf7u8ysPFm.jpg'),
(103229, 7376, 'Senhora Secretária S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/210590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iX0qAr7n2lefCm6DzTkYAYatfv0.jpg'),
(103230, 7376, 'Senhora Secretária S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/210591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sbAL0yKAKc6XDyq6B932pbF6XlC.jpg'),
(103231, 7376, 'Senhora Secretária S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/210592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rHNPesrkVsq8Re9hoyhpzx7mCDQ.jpg'),
(103232, 7376, 'Senhora Secretária S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/210593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dICMXPpGc3dZGUpvbprPJYuYFNQ.jpg'),
(103233, 7376, 'Senhora Secretária S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/210594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t8YPLyX6V34yu86O0H4cwA8nbCa.jpg'),
(103234, 7376, 'Senhora Secretária S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/210595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5088I5ZVVFMPGyonoq8da8eSedM.jpg'),
(103235, 7376, 'Senhora Secretária S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/210596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xawDRYyHVhv92OGazltyk4oqthz.jpg'),
(103236, 7377, 'Senhora Secretária S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p5suEyhwNZkyMwgOzdUc3GySKt1.jpg'),
(103237, 7377, 'Senhora Secretária S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7qVrgC5WgQnGEMlXH7RYC7jvbCp.jpg'),
(103238, 7377, 'Senhora Secretária S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lmSLYBIeqLxqrlkaEYZ7JbaHo7.jpg'),
(103239, 7377, 'Senhora Secretária S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x77EZ1gpy5OktSpArd5cWGQrLRI.jpg'),
(103240, 7377, 'Senhora Secretária S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vs2OX1vBs0TfkkPKv6K3s3VE4jC.jpg'),
(103241, 7377, 'Senhora Secretária S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bPRhUnMOHUUDoq8BmfjS7ELtXEO.jpg'),
(103242, 7377, 'Senhora Secretária S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jfig5d1lWLMUZKIePf43GFv75zf.jpg'),
(103243, 7377, 'Senhora Secretária S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1M4yPnenKCdHICejBav4vMUx8AA.jpg'),
(103244, 7377, 'Senhora Secretária S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jDNAgri80fLzzdsxQPadxc3qrKq.jpg'),
(103245, 7377, 'Senhora Secretária S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cvshRGDJapSdjMU6XbEEBEJ0kwy.jpg'),
(103246, 7377, 'Senhora Secretária S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/210607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zkoOvhif4JzoTw1KNMbg0VbQYa8.jpg'),
(103247, 7377, 'Senhora Secretária S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/210608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4juaqJ48rYuKGEHFdc4cZpFHgf0.jpg'),
(103248, 7377, 'Senhora Secretária S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/210609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1PsLbRzHbJrfuqVIeDHO0aEF3lU.jpg'),
(103249, 7377, 'Senhora Secretária S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/210610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5oXqWDuDJD9BwkcmBYT2ZrPC1LF.jpg'),
(103250, 7377, 'Senhora Secretária S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/210611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ebrqNjv6T2VE3ePLDtGkvCp91i.jpg'),
(103251, 7377, 'Senhora Secretária S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/210612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nm9GadvVT4GvDdvziYGNl4UsgFS.jpg'),
(103252, 7377, 'Senhora Secretária S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/210613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hKeqb7YiRCGVGnBTS8fTbn4iSNJ.jpg'),
(103253, 7377, 'Senhora Secretária S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/210614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aVnAygzbOdZk94OJdwd2mSEaFLy.jpg'),
(103254, 7377, 'Senhora Secretária S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/210615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zkoOvhif4JzoTw1KNMbg0VbQYa8.jpg'),
(103255, 7377, 'Senhora Secretária S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/210616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCO0Is5jfLnV7BEOzUDqaSdijJU.jpg'),
(103256, 7377, 'Senhora Secretária S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/210617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pllIJkZSrsTyIQvnPNQcvQO2kuC.jpg'),
(103257, 7377, 'Senhora Secretária S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/210618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7hwAt2M3c6trJ8lKjgDgUIg77So.jpg'),
(103258, 7377, 'Senhora Secretária S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/210619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2uHtVsw0B01Fq3mPIziBtZlVcqX.jpg'),
(103259, 7378, 'Senhora Secretária S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/213xxaCqjt481pMGYvo3DoJuC3Z.jpg'),
(103260, 7378, 'Senhora Secretária S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7WqJSCYT3DYd1SLdcH8M6F5loDJ.jpg'),
(103261, 7378, 'Senhora Secretária S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUt2EhOD1L97RvdoFRe2WmdzLVc.jpg'),
(103262, 7378, 'Senhora Secretária S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fpYJQOhr0fHJVoIUWUhzzAgoWpB.jpg'),
(103263, 7378, 'Senhora Secretária S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zbOaBegGsrbS3CqgKFBPMkd10O7.jpg'),
(103264, 7378, 'Senhora Secretária S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zc7Oa8urElb3GIar2EhSujdH8CR.jpg'),
(103265, 7378, 'Senhora Secretária S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ozlywPSBbaooV6teUzpQzrp3GGA.jpg'),
(103266, 7378, 'Senhora Secretária S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ffoPfL0zqVzOiidjQupLeBUFPSU.jpg'),
(103267, 7378, 'Senhora Secretária S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/icscCiOZynIC3c4CIWBqNrkYY5i.jpg'),
(103268, 7378, 'Senhora Secretária S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Ba7UCUoYwuhergu1HF0FoRpvxW.jpg'),
(103269, 7378, 'Senhora Secretária S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/210630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cliqQiwXlZ63sTnczCnUMBouzSL.jpg'),
(103270, 7378, 'Senhora Secretária S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/210631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nrQQk11pjNupDHiCa0Q8tq63Y5H.jpg'),
(103271, 7378, 'Senhora Secretária S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/210632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e4CpGhOMRG1f9BazVM3GP399Cmv.jpg'),
(103272, 7378, 'Senhora Secretária S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/210633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zGV4EUGAsdfmG0FL60sXsYExoLu.jpg'),
(103273, 7378, 'Senhora Secretária S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/210634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9BSnHohvRkN1NBSL5QqI390bUAC.jpg'),
(103274, 7378, 'Senhora Secretária S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/210635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4gwxigdgqLnPT4aahhQN9RVAdhb.jpg'),
(103275, 7378, 'Senhora Secretária S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/210636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZyfwUA8Obgee9Akxk8vn5ItWTB.jpg'),
(103276, 7378, 'Senhora Secretária S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/210637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lcxyz5Y2Z8PPxbvUpt8wfKuODf1.jpg'),
(103277, 7378, 'Senhora Secretária S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/210638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mysxCq9DSYTTKJyA6VlPO1ne9iE.jpg'),
(103278, 7378, 'Senhora Secretária S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/210639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6182Kl2F1cTIAPppIQAGOKVb8Ze.jpg'),
(103279, 7378, 'Senhora Secretária S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/210640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7nQt20vP02KCcmUpFpnPMlMwSoK.jpg'),
(103280, 7378, 'Senhora Secretária S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/210641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/98yLXZVFOl4yVOaIOfdZYRVWB6e.jpg'),
(103281, 7378, 'Senhora Secretária S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/210642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rNxVxdL0XRQFMIeq9RiyK52yC1z.jpg'),
(103282, 7379, 'Senhora Secretária S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/txXJ4FBea2JUCkbJqkvvOaDGZyb.jpg'),
(103283, 7379, 'Senhora Secretária S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7r0Yv8m1QEaH2MceRaXGU0VA50q.jpg'),
(103284, 7379, 'Senhora Secretária S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kw389xhiJnYkZj4apnbVmtmcClQ.jpg'),
(103285, 7379, 'Senhora Secretária S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bfsV1EHqV9a8DsEer04BWdiBvea.jpg'),
(103286, 7379, 'Senhora Secretária S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/98yLXZVFOl4yVOaIOfdZYRVWB6e.jpg'),
(103287, 7379, 'Senhora Secretária S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6yF1hkOyN3SnVtYXZoIbDNdbSWc.jpg'),
(103288, 7379, 'Senhora Secretária S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jiXYVH7DgYiTG2bufbZHTuUCLC0.jpg'),
(103289, 7379, 'Senhora Secretária S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l1wJ199V7dYTg5BOHYEMgIijDqR.jpg'),
(103290, 7379, 'Senhora Secretária S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b3vRRKxoK5ZLseKjrJQxXAZvr8g.jpg'),
(103291, 7379, 'Senhora Secretária S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yoc4nhZ6rpdFTC79aXLdub3eQdS.jpg'),
(103292, 7379, 'Senhora Secretária S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/210653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8TEXyRKEVq9VJ4wZGDBctAkVNEu.jpg'),
(103293, 7379, 'Senhora Secretária S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/210654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/miGofefAZryS51nByREnz2vnWL5.jpg'),
(103294, 7379, 'Senhora Secretária S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/210655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zEi39Brr6CcoSMKEDsYZeGe2l2l.jpg'),
(103295, 7379, 'Senhora Secretária S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/210656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7L8dDLxu9uAvQqyK4ywkI0UWbd9.jpg'),
(103296, 7379, 'Senhora Secretária S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/210657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yXUCAmuIGPXrHHn5VSxZXH9DNnu.jpg'),
(103297, 7379, 'Senhora Secretária S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/210658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gPRHPn7teTwv7HGOJgJAYfFCY8v.jpg'),
(103298, 7379, 'Senhora Secretária S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/210659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6yvgqGfvhOT2UsoyZRwQGJ54ubF.jpg'),
(103299, 7379, 'Senhora Secretária S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/210660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybwpLPF1eTLELpwVThvzmbGs6PP.jpg'),
(103300, 7379, 'Senhora Secretária S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/210661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/khEJAxHieJXGuabomtY9k7q7WxG.jpg'),
(103301, 7379, 'Senhora Secretária S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/210662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kE7i6A88JcwUKRsHdihn9LMdx5.jpg'),
(103302, 7379, 'Senhora Secretária S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/210663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5RLgNErDesvxKBRlx6Mrg8f8Zg.jpg'),
(103303, 7379, 'Senhora Secretária S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/210664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8sxYMVmEwsvPxRaOkmMquh3G7Qi.jpg'),
(103304, 7380, 'Senhora Secretária S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qDyPeWpP3HUWmHVEJ994Opc6tsk.jpg'),
(103305, 7380, 'Senhora Secretária S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yzkSUZCm6p2vZPdVATmiZWJr8Nc.jpg'),
(103306, 7380, 'Senhora Secretária S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5tjFZn2f2CCbUzjg8HnVyaziaen.jpg'),
(103307, 7380, 'Senhora Secretária S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cQauoVpqQ1T0E9v2bJEj7nVnp90.jpg'),
(103308, 7380, 'Senhora Secretária S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rsvpRNDBG5QgP7njTaQgTPhgSXj.jpg'),
(103309, 7380, 'Senhora Secretária S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/434uOVu95sjYOaUmR9Rcr96YYot.jpg'),
(103310, 7380, 'Senhora Secretária S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vSkeRkIttfYviNS5rMRRViCJrNz.jpg'),
(103311, 7380, 'Senhora Secretária S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s4vKIUGLWcQwaBY4rglzJKrdDrd.jpg'),
(103312, 7380, 'Senhora Secretária S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8brT7flJSE5eJ63Bj7WdYAtVJVk.jpg'),
(103313, 7380, 'Senhora Secretária S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/58GbYJaXVvZUflDzVHq8HIlvlS6.jpg'),
(103314, 7380, 'Senhora Secretária S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/210675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/771OD5v2itNd77cBOJ9yjZFeYnK.jpg'),
(103315, 7380, 'Senhora Secretária S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/210676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qAJ9ZgC9oTv6nTjeEqKeFmTIcHa.jpg'),
(103316, 7380, 'Senhora Secretária S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/210677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sg8C2A9UBoV3WU5dR3Yo7VVqb4X.jpg'),
(103317, 7380, 'Senhora Secretária S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/210678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rMqSgnh5bLO1BdFzblvK6CKxZ1c.jpg'),
(103318, 7380, 'Senhora Secretária S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/210679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Nl1ablo4DNTLb4ZH7Mycz81AEt.jpg'),
(103319, 7380, 'Senhora Secretária S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/210680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Nl1ablo4DNTLb4ZH7Mycz81AEt.jpg'),
(103320, 7380, 'Senhora Secretária S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/210681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Nl1ablo4DNTLb4ZH7Mycz81AEt.jpg'),
(103321, 7380, 'Senhora Secretária S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/210682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Nl1ablo4DNTLb4ZH7Mycz81AEt.jpg'),
(103322, 7380, 'Senhora Secretária S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/210683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Nl1ablo4DNTLb4ZH7Mycz81AEt.jpg'),
(103323, 7380, 'Senhora Secretária S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/210684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lV6dk7lW8NcnCBTjOmihY7MHTPv.jpg'),
(103324, 7381, 'Senhora Secretária S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p143oqYNLrraG5CbybEJzSgBOu9.jpg'),
(103325, 7381, 'Senhora Secretária S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8erIEzDRFKE27HzJIlP0smc6Lgo.jpg'),
(103326, 7381, 'Senhora Secretária S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sySdB5X0USyGRzzj2qqUawIBpuH.jpg'),
(103327, 7381, 'Senhora Secretária S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oLWHGMioOvwjXuwKGeDkBD5tauF.jpg'),
(103328, 7381, 'Senhora Secretária S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m6CbFWmUZbmMFafJ5DBB4pecBUr.jpg'),
(103329, 7381, 'Senhora Secretária S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7QtapOf4RyiK7GBaBJEMCle1LMR.jpg'),
(103330, 7381, 'Senhora Secretária S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wswvj2dK7114UXGjNh8IycyrskE.jpg'),
(103331, 7381, 'Senhora Secretária S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tSzOYJpw4oW5aA5y1ev1cCZRjmn.jpg'),
(103332, 7381, 'Senhora Secretária S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ApEWXxWqpS47JotO0mVjWRnD23V.jpg'),
(103333, 7381, 'Senhora Secretária S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uEu7ov7xCaTnW9TQNAQQftByIIw.jpg'),
(103334, 7382, 'o Carneiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m7KY4Ku9e6qlYBmkQvxjr4cYiaF.jpg'),
(103335, 7382, 'o Carneiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cTqS4wBBhHSnJ8uUvrwc5VXYHCj.jpg'),
(103336, 7382, 'o Carneiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3LmpY2SaeSh2Rhs745L9PdZXMlt.jpg'),
(103337, 7382, 'o Carneiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ucdAkaYYbyypGVG8xWxGT0XgmP.jpg'),
(103338, 7382, 'o Carneiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qaEjuKu5gXaCgaKV6mF8QMl1TWl.jpg'),
(103339, 7382, 'o Carneiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sorEnRYTLQ19DMumDUPKJfZduJu.jpg'),
(103340, 7382, 'o Carneiro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oUozpbel62pB3SOx4N1ONLwKE1s.jpg'),
(103341, 7382, 'o Carneiro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xp91UPwOqYbrZqRel9f8nnLLyR8.jpg'),
(103342, 7382, 'o Carneiro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iZaJY7Sg0gJM2gJspSlbhTvLMvO.jpg'),
(103343, 7382, 'o Carneiro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/978Ywo7NjNL8pCHOIUGgNNnGxHm.jpg'),
(103344, 7382, 'o Carneiro S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/210447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2htsQuYesFWARz9UiTzzzaus1Ko.jpg'),
(103345, 7382, 'o Carneiro S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/210448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2nXfSF3Id0B8mwH6y7vwuWauHgN.jpg'),
(103346, 7382, 'o Carneiro S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/210449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6orV4ybREREJgekLiSSc1pPQqEK.jpg'),
(103347, 7382, 'o Carneiro S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/210450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hIiVBDkxncBdG1etIeMGgfQRUBw.jpg'),
(103348, 7382, 'o Carneiro S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/210451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wje6xnxojILU6ehmoATzjemCaxe.jpg'),
(103349, 7382, 'o Carneiro S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/210452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gzMUCqLILyxNug52dLhlba1Dj8o.jpg'),
(103350, 7382, 'o Carneiro S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/210453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jsrOnluCvjw5FTNYVZeTdQirVZb.jpg'),
(103351, 7382, 'o Carneiro S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/210454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ySB60VHsVoyoA7iw9avDUTIpLmD.jpg'),
(103352, 7382, 'o Carneiro S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/210455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1kQUgncp2zdtK92wDkD38RKyec.jpg'),
(103353, 7382, 'o Carneiro S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/210456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qdM4BH5S2zP2l0h67C897drwqvS.jpg'),
(103354, 7382, 'o Carneiro S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/210457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/88nV3eNCXRy8dbGxNnYenY3MONm.jpg'),
(103355, 7382, 'o Carneiro S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/210458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6XGYXwAjhs3E2Mrvm0bYRenpggR.jpg'),
(103356, 7382, 'o Carneiro S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/210459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nycp3c730k7gmaTZ7NnBKkuy0i.jpg'),
(103357, 7382, 'o Carneiro S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/210460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mpmIjBb9I316i1YMN4hAIYIeo6W.jpg'),
(103358, 7382, 'o Carneiro S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/210461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c10iN3M2JwfADshwcafdkSok9Wx.jpg'),
(103359, 7382, 'o Carneiro S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/210462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCJSDE01wpgU3C0PlBEWkAAQBo1.jpg'),
(103360, 7382, 'o Carneiro S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/210463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzUknn1O7w8hb5U3wiavtptan3H.jpg'),
(103361, 7382, 'o Carneiro S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/210464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AkoH9zOAKMLo5ChSMUMxBxLq2BT.jpg'),
(103362, 7382, 'o Carneiro S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/210465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s2j9iVQc6zjvgDc4RRy4wP4vJ8y.jpg'),
(103363, 7382, 'o Carneiro S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/210466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kGrPlpFsgpmn5j3NgjM1OZMK3jD.jpg'),
(103364, 7382, 'o Carneiro S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/210467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aXI2nRylR2mXYOxiOZs2blR44nA.jpg'),
(103365, 7382, 'o Carneiro S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/210468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xsPRUWfPFtnujLmEcVO7YHXmmFS.jpg'),
(103366, 7382, 'o Carneiro S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/210469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ozseDDQgRZJA0aG7SIGNBCFdv7h.jpg'),
(103367, 7382, 'o Carneiro S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/210470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjznHr90s2Kh2IP4z6aov24t0rB.jpg'),
(103368, 7382, 'o Carneiro S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/210471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gEfb8UNuboCZh8IK5q0KNgSPWvD.jpg'),
(103369, 7382, 'o Carneiro S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/210472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4JUKkOTA2EOLgUS7l85vDeP7weM.jpg'),
(103370, 7382, 'o Carneiro S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/210473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/upc2nHc2iSd8oSWxpOWXUnmJf9X.jpg'),
(103371, 7382, 'o Carneiro S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/210474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8zDoNR4vhArW4H9OFWp11hvHWJx.jpg'),
(103372, 7382, 'o Carneiro S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/210475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5TBgpVdbDkCKyMfUvD7r4AnXJfX.jpg'),
(103373, 7382, 'o Carneiro S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/210476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgnM6kSJ3VW0PAqOA9zApZNs5eB.jpg'),
(103374, 7383, 'o Carneiro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fptr5foTrKy14wp7L0JHiymlOWK.jpg'),
(103375, 7383, 'o Carneiro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lpFpz1yuOrSPGKEuszjWLBDbapW.jpg'),
(103376, 7383, 'o Carneiro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dqm4pMXdfvrTZorWEEXonKxjhFY.jpg'),
(103377, 7383, 'o Carneiro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/csFo2aA8220U5MqrNHSrGar6uYk.jpg'),
(103378, 7383, 'o Carneiro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rUKNdGUaJGNczRCBJtYasPQix06.jpg'),
(103379, 7383, 'o Carneiro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s4ZhBzvrbOnsywtcoEvaUCsiWUT.jpg'),
(103380, 7383, 'o Carneiro S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mRhpBrLzf4n8C0siVLKIet6APdm.jpg'),
(103381, 7383, 'o Carneiro S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oCRvWyQZbcA4CkshtbnSvpFOweo.jpg'),
(103382, 7383, 'o Carneiro S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6GX69mGSHkQfwthjPwAaBC4DIVA.jpg'),
(103383, 7383, 'o Carneiro S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hE47F0oWziGL8US8dSe1cw7VPiR.jpg'),
(103384, 7383, 'o Carneiro S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/210487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vaEcLlOtL3G8EN8QB1fawjtwP5q.jpg'),
(103385, 7383, 'o Carneiro S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/210488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9HpZdl0r0a2pUglF7bMXUYnCfgo.jpg'),
(103386, 7383, 'o Carneiro S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/210489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pTRT7XCrw9mXbR1bgGyNJV5YEZv.jpg'),
(103387, 7383, 'o Carneiro S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/210490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9RIhwqqXLFgZgz3qDJGYfELqFuN.jpg'),
(103388, 7383, 'o Carneiro S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/210491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j0yrZktoCYXv4qv5jIvjRMdSP4S.jpg'),
(103389, 7383, 'o Carneiro S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/210492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tu94Up52tzFwm0radaLcCEBTE15.jpg'),
(103390, 7383, 'o Carneiro S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/210493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kx6T5Rp51fTjan1GaHB031MTx4C.jpg'),
(103391, 7383, 'o Carneiro S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/210494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEduLnKFnd0FFEN9Iv8UCdgKMdL.jpg'),
(103392, 7383, 'o Carneiro S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/210495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f1RGBst6pfMOOW3SXLKa1FwkNAv.jpg'),
(103393, 7383, 'o Carneiro S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/210496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/biDUhicT3s7rDSz1cAEdvkMX9pW.jpg'),
(103394, 7383, 'o Carneiro S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/210497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dSBHwVsRNdiNPPUxRFAG2khui6S.jpg'),
(103395, 7383, 'o Carneiro S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/210498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/50UG9VIyptbyPA0YeDkkBioX9vG.jpg'),
(103396, 7383, 'o Carneiro S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/210499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rW6eyNTlC2gjxr3misGihM4NkX.jpg'),
(103397, 7383, 'o Carneiro S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/210500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6mIRZpFmlbTdGGWPhniYnfGd3zC.jpg'),
(103398, 7383, 'o Carneiro S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/210501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yelofRcpp6lLxswPhGMXtNFC0My.jpg'),
(103399, 7383, 'o Carneiro S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/210502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1RDAxUsoiLTdXOR9eUGp4bjcxjJ.jpg'),
(103400, 7383, 'o Carneiro S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/210503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qQ83Ry0SV0ynFYIylvfoVPkkeZi.jpg'),
(103401, 7383, 'o Carneiro S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/210504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aaBJ4JDzdjfWZBtQPzB4NXSh3Va.jpg'),
(103402, 7383, 'o Carneiro S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/210505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xuvXymVTG2lhOWMd8dA2E4NsBE3.jpg'),
(103403, 7383, 'o Carneiro S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/210506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pAnd7EIrFNFhApvkQeONuMf8alD.jpg'),
(103404, 7383, 'o Carneiro S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/210507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gB2zTHHAjvxqc9mfFgV6qCu6ji.jpg'),
(103405, 7383, 'o Carneiro S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/210508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5lJbpf0SnC0GmtDTmcnNUbT7ABv.jpg'),
(103406, 7383, 'o Carneiro S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/210509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9I1CRwP2q97ZVHVAczxMsCL5UB1.jpg'),
(103407, 7383, 'o Carneiro S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/210510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qjMwOcuQTs47SWCL1Z5sYzVIsaU.jpg'),
(103408, 7383, 'o Carneiro S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/210511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gzjtIervzWL6k8IZ4vU5uAFg12n.jpg'),
(103409, 7383, 'o Carneiro S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/210512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a4wz4Jj2AnHRfoa8gdUclpgncNO.jpg'),
(103410, 7383, 'o Carneiro S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/210513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cbiJynnZT0r4RBxP2xzwwBYR54G.jpg'),
(103411, 7383, 'o Carneiro S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/210514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qqFHrRZVicSFN3V79KzkqUXmgNm.jpg'),
(103412, 7383, 'o Carneiro S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/210515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kmok6I5VQdkrbAHL3t9eOQHDLv8.jpg'),
(103413, 7383, 'o Carneiro S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/210516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5UR9q5gJjzSdftgJrfk1snXokG0.jpg'),
(103414, 7384, 'o Carneiro S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o5XDyuRSjG1E53waWbZsUUvPH47.jpg'),
(103415, 7384, 'o Carneiro S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ywlJioIZYpuD5qDHrTOXoMKJgS2.jpg'),
(103416, 7384, 'o Carneiro S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PjOvUNOyxIcc30pSfIPpuXQFWv.jpg'),
(103417, 7384, 'o Carneiro S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJWg05LmNt07RbM8x7FooNsxk9p.jpg'),
(103418, 7384, 'o Carneiro S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qYN3ipxo9Ucv5yiRyvK375S9Fjk.jpg'),
(103419, 7384, 'o Carneiro S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ynUJLipbZPschiNR87SOc4unHYS.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(103420, 7384, 'o Carneiro S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/46GgcHoEDLMCQdpT9bWiR8Zf5g1.jpg'),
(103421, 7384, 'o Carneiro S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sd25SQQJaESTX5gcOQf3gTZWtmC.jpg'),
(103422, 7384, 'o Carneiro S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gqkcsEW8ttW7nS216Gtwnpn1rV4.jpg'),
(103423, 7384, 'o Carneiro S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hW2YDtCipbULVW3T4h7F31qTx44.jpg'),
(103424, 7384, 'o Carneiro S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/210527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r50LETgpqU2F5oqIKj8eku5iVKe.jpg'),
(103425, 7384, 'o Carneiro S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/210528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xHLwBSkveo7hs9CvCZ1pHTdUlF.jpg'),
(103426, 7384, 'o Carneiro S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/210529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1JsfDgivAMwS7LlqwVcOUIFDu1i.jpg'),
(103427, 7384, 'o Carneiro S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/210530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A1QVd4XdollqJBpPwszP1d1DEYy.jpg'),
(103428, 7384, 'o Carneiro S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/210531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1MsopwfzPc85ZEHamVjNb7sAKYI.jpg'),
(103429, 7384, 'o Carneiro S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/210532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yCtdqCdjtjw9C0BVLDhis5M62hn.jpg'),
(103430, 7384, 'o Carneiro S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/210533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/34hvDzRMgUSpA0HMVG11ueUW9Up.jpg'),
(103431, 7384, 'o Carneiro S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/210534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e7YGLGRnInhniksKCXMnV4SnbtS.jpg'),
(103432, 7384, 'o Carneiro S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/210535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gMOWgif6QeMt3KpJSc3c3T45zvw.jpg'),
(103433, 7384, 'o Carneiro S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/210536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y6c2mU5TSDCyh4WllDNtg3ZyjxA.jpg'),
(103434, 7385, 'o Carneiro S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4TPMzJ2cajSNWejcHdxaSl5pf7Z.jpg'),
(103435, 7385, 'o Carneiro S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ydhWH2g5ja1rRt6XNnAfrrWgRq4.jpg'),
(103436, 7385, 'o Carneiro S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iYs0mO4YrDUrG9t8GKvB1BkzYdU.jpg'),
(103437, 7385, 'o Carneiro S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oDE9w4zQGz9wURW9Iw9icES3hfe.jpg'),
(103438, 7385, 'o Carneiro S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aDgybKGUEL1BzzibG6bthOrkCFN.jpg'),
(103439, 7385, 'o Carneiro S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mNLh6hvSYTZzB1BOmy0ren35PdH.jpg'),
(103440, 7385, 'o Carneiro S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vp5lKOSEdffUqIKWMwQLVS9xrE4.jpg'),
(103441, 7385, 'o Carneiro S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wHDtDxpIB1y9QhWd4yOlo2nDCYU.jpg'),
(103442, 7385, 'o Carneiro S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lY6UpMzuu5ATS5jRm3CHC3uSxBb.jpg'),
(103443, 7385, 'o Carneiro S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zp9LTi35z2rTCDVafghWduET1tB.jpg'),
(103444, 7385, 'o Carneiro S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/210547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dXxpw4E8oeUPfsowjL8gGrC4y1h.jpg'),
(103445, 7385, 'o Carneiro S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/210548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wh1zoOls4qtlVmlLWXzPSv7wjES.jpg'),
(103446, 7385, 'o Carneiro S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/210549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQWmxi9fcOllYpSsOY6CeNyETUM.jpg'),
(103447, 7385, 'o Carneiro S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/210550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c7VZkQggiUE4C3wNnIiEbeG6OpR.jpg'),
(103448, 7385, 'o Carneiro S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/210551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r0XWuaz6stYoqd5Ija90X5MXJzu.jpg'),
(103449, 7385, 'o Carneiro S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/210552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/coJh1LPeUFh8pFd1KxwQrDf426t.jpg'),
(103450, 7385, 'o Carneiro S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/210553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sbPlBcAKuyYcv3sGr3HHStbWTkX.jpg'),
(103451, 7385, 'o Carneiro S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/210554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a9mqmuCDddO1Wn3SquGFSPfCAXc.jpg'),
(103452, 7386, 'o Carneiro S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wKKIPwdUV90abhf1nxXFNXAoDns.jpg'),
(103453, 7386, 'o Carneiro S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEgIiTaxn87HH6DedyDENbYebZW.jpg'),
(103454, 7386, 'o Carneiro S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xtjF1eumcIzdQUanz3wteDW1kvG.jpg'),
(103455, 7386, 'o Carneiro S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/R1A91YpIDYX7RIrujYZYxSYAlG.jpg'),
(103456, 7386, 'o Carneiro S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b159HD8mUIxOryoeHBCKTVFCujm.jpg'),
(103457, 7386, 'o Carneiro S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hODOkS0ZggnKaPQ86NAlZJEhPKM.jpg'),
(103458, 7386, 'o Carneiro S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyIGlkLgxqssbffMhJsBLju89Bz.jpg'),
(103459, 7386, 'o Carneiro S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xbkMIlHFDj17lUO3Nhigl9pWYDs.jpg'),
(103460, 7386, 'o Carneiro S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xcZzR3NsyPPF0SPXS2msaH10Zks.jpg'),
(103461, 7386, 'o Carneiro S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWasCjtAeAk8iA2rXtQg4iEP9JW.jpg'),
(103462, 7386, 'o Carneiro S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/210565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sLqkoqYNNgPwEzJII86ahJfGv1x.jpg'),
(103463, 7386, 'o Carneiro S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/210566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xFjjsWlmHDX4VqLTN7Qh7XyPyFH.jpg'),
(103464, 7386, 'o Carneiro S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/210567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hjZ9je4LlQBGe3oBnEZIKzx6lMp.jpg'),
(103465, 7386, 'o Carneiro S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/210568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ew3hUUgd45RnS8dRV8APoxyp2Tk.jpg'),
(103466, 7386, 'o Carneiro S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/210569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k6UwfYl7tm9I8mSwYChs4Wkexih.jpg'),
(103467, 7386, 'o Carneiro S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/210570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dM8TlQjGZEZ671LZETERjiAUU3W.jpg'),
(103468, 7386, 'o Carneiro S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/210571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zJ5VPCRpdYQpvUJbqKKBFTz8peq.jpg'),
(103469, 7386, 'o Carneiro S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/210572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l4H8fZ0WSQvE6FDMjJKWfGYczJx.jpg'),
(103470, 7386, 'o Carneiro S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/210573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xb4af7CpWqjnqRB7JQcMF2mjjxP.jpg'),
(103471, 7386, 'o Carneiro S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/210574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/smfYKWgxt64DVwVU8SBhEplBk7B.jpg'),
(103472, 7387, 'Star Wars: Aventuras dos Jovens Jedi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103473, 7387, 'Star Wars: Aventuras dos Jovens Jedi S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103474, 7387, 'Star Wars: Aventuras dos Jovens Jedi S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103475, 7387, 'Star Wars: Aventuras dos Jovens Jedi S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103476, 7387, 'Star Wars: Aventuras dos Jovens Jedi S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103477, 7387, 'Star Wars: Aventuras dos Jovens Jedi S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103478, 7387, 'Star Wars: Aventuras dos Jovens Jedi S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vt4lvVmm1BVObE3Wcm8JGrhhNPx.jpg'),
(103479, 7387, 'Star Wars: Aventuras dos Jovens Jedi S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/whujl6unVeAS8vwasm63NPSkMD4.jpg'),
(103480, 7387, 'Star Wars: Aventuras dos Jovens Jedi S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wLJwMdLIPrkzR8UflPnFGlgwVGy.jpg'),
(103481, 7387, 'Star Wars: Aventuras dos Jovens Jedi S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a2mg4Q3YXbBmTmvc8UGwmrGm22W.jpg'),
(103482, 7387, 'Star Wars: Aventuras dos Jovens Jedi S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rmMXrX37UotmB3ybkRxKmxEwkj9.jpg'),
(103483, 7387, 'Star Wars: Aventuras dos Jovens Jedi S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iHAnPgjVepMcMvGXs8l8ojeToNL.jpg'),
(103484, 7387, 'Star Wars: Aventuras dos Jovens Jedi S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uSToZySyByD6hK9gYpKT50sjzvW.jpg'),
(103485, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/432954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103486, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/432955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103487, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/432956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103488, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/432957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103489, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/432958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103490, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/432959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103491, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/432960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103492, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/432961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103493, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/432962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103494, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/432963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103495, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/432964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103496, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/737178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103497, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/737179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103498, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/737180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103499, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/737181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103500, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/737182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103501, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/737183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103502, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/737184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103503, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/737185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103504, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/737186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103505, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/737187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103506, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/737188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103507, 7388, 'Star Wars: Aventuras dos Jovens Jedi S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/737189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103508, 7389, 'Star Wars: Aventuras dos Jovens Jedi S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/895851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103509, 7389, 'Star Wars: Aventuras dos Jovens Jedi S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/895852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103510, 7389, 'Star Wars: Aventuras dos Jovens Jedi S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/895853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103511, 7389, 'Star Wars: Aventuras dos Jovens Jedi S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/895854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103512, 7389, 'Star Wars: Aventuras dos Jovens Jedi S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/895855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103513, 7389, 'Star Wars: Aventuras dos Jovens Jedi S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/895856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103514, 7389, 'Star Wars: Aventuras dos Jovens Jedi S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/895857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNTvClgnd3FfQ45IVQkk4HLHuBN.jpg'),
(103515, 7390, 'Tengoku-Daimakyo: Ilusão Celestial S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hjuA5thPA0vBIATH2WK05StjrTe.jpg'),
(103516, 7390, 'Tengoku-Daimakyo: Ilusão Celestial S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rn1dp9R7iEo5Rif6Opa8gKEtdad.jpg'),
(103517, 7390, 'Tengoku-Daimakyo: Ilusão Celestial S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oL61TjVPu5qe51roQFu76PmgGfP.jpg'),
(103518, 7390, 'Tengoku-Daimakyo: Ilusão Celestial S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ojsXaRIYuoVEhhWJqSf5g1mrCG.jpg'),
(103519, 7390, 'Tengoku-Daimakyo: Ilusão Celestial S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2hhmjQoMLsa3IjOm6J5dEdgNNUd.jpg'),
(103520, 7390, 'Tengoku-Daimakyo: Ilusão Celestial S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220037.mp4', 'http://image.tmdb.org/t/p/w1280/cYisyMBs1nzMfkodISbN0JyFjso.jpg'),
(103521, 7390, 'Tengoku-Daimakyo: Ilusão Celestial S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220038.mp4', 'http://image.tmdb.org/t/p/w1280/xWZQeuzl19Uz5KkQckDuv7va6GY.jpg'),
(103522, 7390, 'Tengoku-Daimakyo: Ilusão Celestial S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220039.mp4', 'http://image.tmdb.org/t/p/w1280/yGDUAKdwhUnIdsC51xdMf2awPt.jpg'),
(103523, 7390, 'Tengoku-Daimakyo: Ilusão Celestial S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220040.mp4', 'http://image.tmdb.org/t/p/w1280/5THJLi3mGeUsxlvGB2vsAPvbtLz.jpg'),
(103524, 7390, 'Tengoku-Daimakyo: Ilusão Celestial S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220041.mp4', 'http://image.tmdb.org/t/p/w1280/dmNnuDGKWLiS25ZF4GBLkNIdbvI.jpg'),
(103525, 7390, 'Tengoku-Daimakyo: Ilusão Celestial S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220042.mp4', 'http://image.tmdb.org/t/p/w1280/daueB9Wwh7B8QKPYUE3ayzsgDQd.jpg'),
(103526, 7390, 'Tengoku-Daimakyo: Ilusão Celestial S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jygWkvETR9TXtQsp26Hr14EzFiD.jpg'),
(103527, 7390, 'Tengoku-Daimakyo: Ilusão Celestial S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220044.mp4', 'http://image.tmdb.org/t/p/w1280/lpk0S5Q3tbsuRV1Otvz64bLB7e2.jpg'),
(103528, 7310, 'Trigun Stampede S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aN5hAxpjwSXczzHjaueONn8eS7G.jpg'),
(103529, 7310, 'Trigun Stampede S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q2T2pdmYtfhdkZFvLkq1nZHeQtv.jpg'),
(103530, 7310, 'Trigun Stampede S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tLw38Xk9YZBEAYJQXAq1aca4vwP.jpg'),
(103531, 7310, 'Trigun Stampede S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8UI6gDi6QDzwXtQNzwUdg9TfAyw.jpg'),
(103532, 7310, 'Trigun Stampede S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gn2x4ozxa5sZRVigKGq2s1VH9Rb.jpg'),
(103533, 7310, 'Trigun Stampede S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JRdLSjcGrC0hl33lxRNpcSjbxN.jpg'),
(103534, 7310, 'Trigun Stampede S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i7VRMw4i0zI1kVPhgcvCBxPxLnd.jpg'),
(103535, 7310, 'Trigun Stampede S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dPTMT3RuQqx8G8G80JeqRbBwdrW.jpg'),
(103536, 7310, 'Trigun Stampede S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ajNQHBkBWzSJtvPp5U0U37NXjzF.jpg'),
(103537, 7310, 'Trigun Stampede S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ddO1NYKO6GkdG9SAov3E3JDoLXj.jpg'),
(103538, 7310, 'Trigun Stampede S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/210435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kZ22uJgKh5hiWaY78j08m6iJUQJ.jpg'),
(103539, 7310, 'Trigun Stampede S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/210436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mqvaj0a74JZkvCc4w1J2ePchl.jpg'),
(103540, 7391, 'Meu Trabalho no Café Yuri S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Y9B80Tk2SvKV0oW6fwrL4j2OEo.jpg'),
(103541, 7392, 'Desafio Sob Fogo: America Latina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7xtTnDNp9yeSuI2Rmn7dW2ETe7.jpg'),
(103542, 7392, 'Desafio Sob Fogo: America Latina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7xtTnDNp9yeSuI2Rmn7dW2ETe7.jpg'),
(103543, 7392, 'Desafio Sob Fogo: America Latina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7xtTnDNp9yeSuI2Rmn7dW2ETe7.jpg'),
(103544, 7392, 'Desafio Sob Fogo: America Latina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7xtTnDNp9yeSuI2Rmn7dW2ETe7.jpg'),
(103545, 7392, 'Desafio Sob Fogo: America Latina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7xtTnDNp9yeSuI2Rmn7dW2ETe7.jpg'),
(103546, 7392, 'Desafio Sob Fogo: America Latina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7xtTnDNp9yeSuI2Rmn7dW2ETe7.jpg'),
(103547, 7392, 'Desafio Sob Fogo: America Latina S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7xtTnDNp9yeSuI2Rmn7dW2ETe7.jpg'),
(103548, 7392, 'Desafio Sob Fogo: America Latina S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7xtTnDNp9yeSuI2Rmn7dW2ETe7.jpg'),
(103549, 7393, 'Desafio Sob Fogo: America Latina S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7xtTnDNp9yeSuI2Rmn7dW2ETe7.jpg'),
(103550, 7393, 'Desafio Sob Fogo: America Latina S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7xtTnDNp9yeSuI2Rmn7dW2ETe7.jpg'),
(103551, 7393, 'Desafio Sob Fogo: America Latina S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7xtTnDNp9yeSuI2Rmn7dW2ETe7.jpg'),
(103552, 7393, 'Desafio Sob Fogo: America Latina S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7xtTnDNp9yeSuI2Rmn7dW2ETe7.jpg'),
(103553, 7393, 'Desafio Sob Fogo: America Latina S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7xtTnDNp9yeSuI2Rmn7dW2ETe7.jpg'),
(103554, 7393, 'Desafio Sob Fogo: America Latina S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7xtTnDNp9yeSuI2Rmn7dW2ETe7.jpg'),
(103555, 7393, 'Desafio Sob Fogo: America Latina S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7xtTnDNp9yeSuI2Rmn7dW2ETe7.jpg'),
(103556, 7393, 'Desafio Sob Fogo: America Latina S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7xtTnDNp9yeSuI2Rmn7dW2ETe7.jpg'),
(103557, 7394, 'MasterChef: Profissionais S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103558, 7394, 'MasterChef: Profissionais S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103559, 7394, 'MasterChef: Profissionais S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103560, 7394, 'MasterChef: Profissionais S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103561, 7394, 'MasterChef: Profissionais S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103562, 7394, 'MasterChef: Profissionais S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103563, 7394, 'MasterChef: Profissionais S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103564, 7394, 'MasterChef: Profissionais S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103565, 7394, 'MasterChef: Profissionais S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103566, 7394, 'MasterChef: Profissionais S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/245563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103567, 7394, 'MasterChef: Profissionais S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/245564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103568, 7394, 'MasterChef: Profissionais S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/245565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103569, 7394, 'MasterChef: Profissionais S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/245566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103570, 7394, 'MasterChef: Profissionais S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/245567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103571, 7395, 'MasterChef: Profissionais S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103572, 7395, 'MasterChef: Profissionais S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103573, 7395, 'MasterChef: Profissionais S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103574, 7395, 'MasterChef: Profissionais S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103575, 7395, 'MasterChef: Profissionais S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103576, 7395, 'MasterChef: Profissionais S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103577, 7395, 'MasterChef: Profissionais S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103578, 7395, 'MasterChef: Profissionais S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103579, 7395, 'MasterChef: Profissionais S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103580, 7395, 'MasterChef: Profissionais S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/245577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103581, 7395, 'MasterChef: Profissionais S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/245578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103582, 7395, 'MasterChef: Profissionais S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/245579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103583, 7395, 'MasterChef: Profissionais S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/245580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103584, 7395, 'MasterChef: Profissionais S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/245581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103585, 7395, 'MasterChef: Profissionais S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/245582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103586, 7395, 'MasterChef: Profissionais S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/245583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103587, 7395, 'MasterChef: Profissionais S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/245584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103588, 7396, 'MasterChef: Profissionais S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103589, 7396, 'MasterChef: Profissionais S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103590, 7396, 'MasterChef: Profissionais S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103591, 7396, 'MasterChef: Profissionais S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103592, 7396, 'MasterChef: Profissionais S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103593, 7396, 'MasterChef: Profissionais S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103594, 7396, 'MasterChef: Profissionais S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103595, 7396, 'MasterChef: Profissionais S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103596, 7396, 'MasterChef: Profissionais S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103597, 7397, 'MasterChef: Profissionais S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103598, 7397, 'MasterChef: Profissionais S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103599, 7397, 'MasterChef: Profissionais S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103600, 7397, 'MasterChef: Profissionais S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103601, 7397, 'MasterChef: Profissionais S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103602, 7397, 'MasterChef: Profissionais S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103603, 7397, 'MasterChef: Profissionais S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103604, 7397, 'MasterChef: Profissionais S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103605, 7397, 'MasterChef: Profissionais S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/583405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQJzipqT6OMesRgdIZNDM3ekuP2.jpg'),
(103606, 7398, 'A Small Light S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w25VQAY63VrFe4FO8VRX3xOhdKo.jpg'),
(103607, 7398, 'A Small Light S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/46UmLQbD90wkryFjMjoFRP0DA5x.jpg'),
(103608, 7398, 'A Small Light S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217474.mp4', 'http://image.tmdb.org/t/p/w1280/yIMmOuJEx4mHO4mZaRYwM1zReZ0.jpg'),
(103609, 7398, 'A Small Light S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217475.mp4', 'http://image.tmdb.org/t/p/w1280/bpN6nUGgWGLWSXwrlom5hYV8uuU.jpg'),
(103610, 7398, 'A Small Light S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217476.mp4', 'http://image.tmdb.org/t/p/w1280/2YgjAjebHqtv4TceZEeb1qSke5U.jpg'),
(103611, 7398, 'A Small Light S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217477.mp4', 'http://image.tmdb.org/t/p/w1280/nAVG7jiaTVa5MeVW1VPSniI2Gx6.jpg'),
(103612, 7398, 'A Small Light S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217478.mp4', 'http://image.tmdb.org/t/p/w1280/2xSTSEwQ0yZGljUIMgoiI3dvOjt.jpg'),
(103613, 7398, 'A Small Light S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217479.mp4', 'http://image.tmdb.org/t/p/w1280/ueucX1jeAAxaYaWD5aW1roMmduM.jpg'),
(103614, 7399, 'Alma de Cozinheira S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103615, 7399, 'Alma de Cozinheira S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103616, 7399, 'Alma de Cozinheira S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103617, 7399, 'Alma de Cozinheira S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103618, 7399, 'Alma de Cozinheira S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103619, 7399, 'Alma de Cozinheira S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103620, 7399, 'Alma de Cozinheira S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103621, 7399, 'Alma de Cozinheira S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103622, 7399, 'Alma de Cozinheira S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103623, 7399, 'Alma de Cozinheira S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103624, 7399, 'Alma de Cozinheira S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/333978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103625, 7399, 'Alma de Cozinheira S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/333979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103626, 7399, 'Alma de Cozinheira S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/333980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103627, 7399, 'Alma de Cozinheira S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/333981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103628, 7399, 'Alma de Cozinheira S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/333982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103629, 7399, 'Alma de Cozinheira S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/333983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103630, 7399, 'Alma de Cozinheira S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/333984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103631, 7399, 'Alma de Cozinheira S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/333985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103632, 7399, 'Alma de Cozinheira S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/333986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103633, 7399, 'Alma de Cozinheira S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/333987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103634, 7400, 'Alma de Cozinheira S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/448833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103635, 7400, 'Alma de Cozinheira S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/452944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103636, 7400, 'Alma de Cozinheira S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103637, 7400, 'Alma de Cozinheira S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/464824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103638, 7400, 'Alma de Cozinheira S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/470919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103639, 7400, 'Alma de Cozinheira S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103640, 7400, 'Alma de Cozinheira S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/483489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103641, 7400, 'Alma de Cozinheira S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/491729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103642, 7400, 'Alma de Cozinheira S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/493127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103643, 7400, 'Alma de Cozinheira S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/499603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9iFfe5McPOYKYM5lwU0JyLum5z.jpg'),
(103644, 7401, 'Bem-vindo à Família Plath S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tVMG619aX1ZNokoGfgq1BYoz5gn.jpg'),
(103645, 7401, 'Bem-vindo à Família Plath S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nNki2kQcrWxdBOCko73B1IbcS9E.jpg'),
(103646, 7401, 'Bem-vindo à Família Plath S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nZkDTinUEHYyR4C7nz8qRbW60Ne.jpg'),
(103647, 7401, 'Bem-vindo à Família Plath S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8s6B0YvfwAZrxudqy5InRNqHcZz.jpg'),
(103648, 7401, 'Bem-vindo à Família Plath S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4NpJXtLrhvoQIfHE5aBksxAjJQE.jpg'),
(103649, 7401, 'Bem-vindo à Família Plath S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pzvKGMbVgL1Xie4FmaI9tGBthwM.jpg'),
(103650, 7402, 'Bem-vindo à Família Plath S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b3sfa9AAyGMSMgaqoxhF5xk5Co9.jpg'),
(103651, 7402, 'Bem-vindo à Família Plath S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iTSXSHXsETLBwxUpGfUIIIsvC4i.jpg'),
(103652, 7402, 'Bem-vindo à Família Plath S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cUDpA0tYqBwNpGwrUSguIHMwCOZ.jpg'),
(103653, 7402, 'Bem-vindo à Família Plath S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mRjdtGsZ9rXihRyYWp0uQioCrlL.jpg'),
(103654, 7402, 'Bem-vindo à Família Plath S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Taa1yybhoYNHEdrY5DzwT7Cs2U.jpg'),
(103655, 7402, 'Bem-vindo à Família Plath S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1xwfcbQUG7Nh6TQY2QujNdHLPaj.jpg'),
(103656, 7402, 'Bem-vindo à Família Plath S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aKN9Thwy2OTBmapLjT1TubJykcY.jpg'),
(103657, 7402, 'Bem-vindo à Família Plath S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zgH5K3ke24NlT1ZHjoICcaG47dJ.jpg'),
(103658, 7402, 'Bem-vindo à Família Plath S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rYqsjSJbWL3L2DYnVa4lKY81JVb.jpg'),
(103659, 7403, 'Bem-vindo à Família Plath S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ukttAhUoIH0Js2FT0qjzehevbaz.jpg'),
(103660, 7403, 'Bem-vindo à Família Plath S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103661, 7403, 'Bem-vindo à Família Plath S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8bA0bF7wz1NBdmjhLWv3wIQSA0T.jpg'),
(103662, 7403, 'Bem-vindo à Família Plath S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wV2T9bRxpMaouNAZoGn3jD0mSDf.jpg'),
(103663, 7403, 'Bem-vindo à Família Plath S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xOc6nnJHdc5soTFsRewANyR3faK.jpg'),
(103664, 7403, 'Bem-vindo à Família Plath S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bKELsDUnmiAktz5aA1hKLrpofaB.jpg'),
(103665, 7403, 'Bem-vindo à Família Plath S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ihEnyRpnV26Moq4Ej8bGZFwpYP.jpg'),
(103666, 7403, 'Bem-vindo à Família Plath S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uIIfKXbekdHDOU2KoOtxw4fhaKi.jpg'),
(103667, 7403, 'Bem-vindo à Família Plath S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u5mo5YN4S0b1uG3wN4HhGqCRUnL.jpg'),
(103668, 7403, 'Bem-vindo à Família Plath S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hl5a3u4E2xyLyAwUee6EeUnko8L.jpg'),
(103669, 7403, 'Bem-vindo à Família Plath S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5LLUOhExyV2AB5Z8TmziskaeaBD.jpg'),
(103670, 7403, 'Bem-vindo à Família Plath S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOuOP4lrHiUXMepsVR0qPj23cQ3.jpg'),
(103671, 7403, 'Bem-vindo à Família Plath S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103672, 7404, 'Bem-vindo à Família Plath S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3jwZWQGtuO1vtObVBafxPFxdH8T.jpg'),
(103673, 7404, 'Bem-vindo à Família Plath S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d2J4LHAq6S6nHkUZzCZiP1VfIFd.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(103674, 7404, 'Bem-vindo à Família Plath S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkUJ0hbSsVvZjvAM48Ng6ImuDgF.jpg'),
(103675, 7404, 'Bem-vindo à Família Plath S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6nMGAMB4XxedsKeWrgS1fuzFsio.jpg'),
(103676, 7404, 'Bem-vindo à Família Plath S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nNHoEpYHBlFC6t0ijvwkV5D5PF0.jpg'),
(103677, 7404, 'Bem-vindo à Família Plath S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4YwRigqX2wcFva5a6pugFmj3V7t.jpg'),
(103678, 7404, 'Bem-vindo à Família Plath S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qkrSV59FaJbLdJObFKiuuRYN1gp.jpg'),
(103679, 7404, 'Bem-vindo à Família Plath S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221261.mp4', 'http://image.tmdb.org/t/p/w1280/cEpbcr6287ZNwQ6u5IxEqRYxnMA.jpg'),
(103680, 7404, 'Bem-vindo à Família Plath S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221262.mp4', 'http://image.tmdb.org/t/p/w1280/8BgZlbulxzVGttFuYhA03YwMm4S.jpg'),
(103681, 7404, 'Bem-vindo à Família Plath S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221263.mp4', 'http://image.tmdb.org/t/p/w1280/m6FOH6OZOxjCorYkLazL2A2zrJ8.jpg'),
(103682, 7404, 'Bem-vindo à Família Plath S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103683, 7404, 'Bem-vindo à Família Plath S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103684, 7404, 'Bem-vindo à Família Plath S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103685, 7405, 'Bem-vindo à Família Plath S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/272420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103686, 7405, 'Bem-vindo à Família Plath S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/272421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103687, 7405, 'Bem-vindo à Família Plath S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103688, 7405, 'Bem-vindo à Família Plath S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/288788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103689, 7405, 'Bem-vindo à Família Plath S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103690, 7405, 'Bem-vindo à Família Plath S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/300430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103691, 7405, 'Bem-vindo à Família Plath S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/305576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103692, 7405, 'Bem-vindo à Família Plath S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/310770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103693, 7405, 'Bem-vindo à Família Plath S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/319027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103694, 7405, 'Bem-vindo à Família Plath S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/325196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103695, 7405, 'Bem-vindo à Família Plath S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/329052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103696, 7405, 'Bem-vindo à Família Plath S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/333939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103697, 7405, 'Bem-vindo à Família Plath S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/341881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103698, 7405, 'Bem-vindo à Família Plath S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/349586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103699, 7406, 'Bem-vindo à Família Plath S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/491527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103700, 7406, 'Bem-vindo à Família Plath S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/698862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103701, 7406, 'Bem-vindo à Família Plath S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/698863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103702, 7406, 'Bem-vindo à Família Plath S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/698864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103703, 7406, 'Bem-vindo à Família Plath S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/698865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103704, 7406, 'Bem-vindo à Família Plath S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/698866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103705, 7406, 'Bem-vindo à Família Plath S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/698867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103706, 7406, 'Bem-vindo à Família Plath S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/698868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103707, 7406, 'Bem-vindo à Família Plath S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/698869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103708, 7406, 'Bem-vindo à Família Plath S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/698870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103709, 7406, 'Bem-vindo à Família Plath S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/698871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103710, 7406, 'Bem-vindo à Família Plath S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/698872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFsKthnAKUPLo7J0jhvJVjhPymU.jpg'),
(103711, 7407, 'Casa Feia Nunca Mais! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FjZSe7FDo8T4bgW0hgwkIF47RK.jpg'),
(103712, 7407, 'Casa Feia Nunca Mais! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l2QOFCN8dOw0NmYreUoK5rABsSi.jpg'),
(103713, 7407, 'Casa Feia Nunca Mais! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hU6nZcA0ZhDmHsPTtaacXIXhnOb.jpg'),
(103714, 7407, 'Casa Feia Nunca Mais! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dLrXP3xGvuS3Dngza12kzYclLFk.jpg'),
(103715, 7407, 'Casa Feia Nunca Mais! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uMAQw3ztuqZNvaMSLz9ZWCobrQi.jpg'),
(103716, 7408, 'Casa Feia Nunca Mais! S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3n3pxLlLo7QvccJ5zLbqjA8EDC7.jpg'),
(103717, 7408, 'Casa Feia Nunca Mais! S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/etZ76GyMlbHlIKkzPNm0gUi9SQo.jpg'),
(103718, 7408, 'Casa Feia Nunca Mais! S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6uhhzNPNYQnrnO7kUenJB8EF0kM.jpg'),
(103719, 7408, 'Casa Feia Nunca Mais! S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6uhhzNPNYQnrnO7kUenJB8EF0kM.jpg'),
(103720, 7408, 'Casa Feia Nunca Mais! S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6uhhzNPNYQnrnO7kUenJB8EF0kM.jpg'),
(103721, 7408, 'Casa Feia Nunca Mais! S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6uhhzNPNYQnrnO7kUenJB8EF0kM.jpg'),
(103722, 7409, 'Casamento à Moda Judaica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udVL2UH8z5oc097C8ErKyW6Rf1d.jpg'),
(103723, 7409, 'Casamento à Moda Judaica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3P4ojuSRxquVAMftxnFxVTfHb4C.jpg'),
(103724, 7409, 'Casamento à Moda Judaica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97D3iGrX8WGfiJtlMuOLERRFel0.jpg'),
(103725, 7409, 'Casamento à Moda Judaica S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2tWA0BSR4aCWDjSPLM1Keiht90O.jpg'),
(103726, 7409, 'Casamento à Moda Judaica S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qOv8NZHU39eoYxKHPeyCujdb1ru.jpg'),
(103727, 7409, 'Casamento à Moda Judaica S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nWscAWKRxVyTJcWCE2imp9RO1j6.jpg'),
(103728, 7409, 'Casamento à Moda Judaica S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSxeY42Xzn5s8795scucbXnKmL3.jpg'),
(103729, 7409, 'Casamento à Moda Judaica S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pXNSpiqusZL3FyPF03hq0y27leC.jpg'),
(103730, 7410, 'O Famoso Alfaiate S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xIvaP9ywc9g48763I16D0asVL57.jpg'),
(103731, 7410, 'O Famoso Alfaiate S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wXNH9LeskKQsmmF2E1UTzTmSFEg.jpg'),
(103732, 7410, 'O Famoso Alfaiate S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8kH7VQsr0qaE9akZEmmPvrzldOC.jpg'),
(103733, 7410, 'O Famoso Alfaiate S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hLPtQ3xVIHN2wG4iPmvQHkOg3T1.jpg'),
(103734, 7410, 'O Famoso Alfaiate S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wqDNGY7fOxIt9JiCqMplmTANrVI.jpg'),
(103735, 7410, 'O Famoso Alfaiate S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kKxsZAxbEjR3hwKP2Hp7Xlu1ci2.jpg'),
(103736, 7410, 'O Famoso Alfaiate S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nAM3yuji1SRqu1kF35Fw7kFXbuu.jpg'),
(103737, 7411, 'O Famoso Alfaiate S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y0zE96DmevPY7pN2H3tleUMSCzQ.jpg'),
(103738, 7411, 'O Famoso Alfaiate S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZS0hJTjqa9RbcLQtUf8a7zuEjH.jpg'),
(103739, 7411, 'O Famoso Alfaiate S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/95iyCvGX7Ti0HhN6hP0PjgHAOAK.jpg'),
(103740, 7411, 'O Famoso Alfaiate S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5d9hcuVIGkMbvZQJXMtGDZY2609.jpg'),
(103741, 7411, 'O Famoso Alfaiate S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/seMvHMEClTJVAoQ0sFVCuH82Xdi.jpg'),
(103742, 7411, 'O Famoso Alfaiate S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lVKlrEIYYBFChvkTYBM5KHK6zsX.jpg'),
(103743, 7411, 'O Famoso Alfaiate S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/auXSbXpxuPXBjezLtJfwz1dCe1a.jpg'),
(103744, 7411, 'O Famoso Alfaiate S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mKMyuNda3iKkyPEU4Oz23ElTKhH.jpg'),
(103745, 7412, 'O Famoso Alfaiate S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zA0BcBL0ufTetuB0UDnfbFiXA6w.jpg'),
(103746, 7412, 'O Famoso Alfaiate S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zA0BcBL0ufTetuB0UDnfbFiXA6w.jpg'),
(103747, 7412, 'O Famoso Alfaiate S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zA0BcBL0ufTetuB0UDnfbFiXA6w.jpg'),
(103748, 7412, 'O Famoso Alfaiate S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zA0BcBL0ufTetuB0UDnfbFiXA6w.jpg'),
(103749, 7412, 'O Famoso Alfaiate S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zA0BcBL0ufTetuB0UDnfbFiXA6w.jpg'),
(103750, 7412, 'O Famoso Alfaiate S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zA0BcBL0ufTetuB0UDnfbFiXA6w.jpg'),
(103751, 7412, 'O Famoso Alfaiate S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zA0BcBL0ufTetuB0UDnfbFiXA6w.jpg'),
(103752, 7412, 'O Famoso Alfaiate S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zA0BcBL0ufTetuB0UDnfbFiXA6w.jpg'),
(103753, 7413, 'Os Encanadores da Casa Branca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7QL4Ep8EN0CKIPLx83knLtpDqu.jpg'),
(103754, 7413, 'Os Encanadores da Casa Branca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216949.mp4', 'http://image.tmdb.org/t/p/w1280/w0bBVJI3MQgmM6DFs3RdITznkCK.jpg'),
(103755, 7413, 'Os Encanadores da Casa Branca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216950.mp4', 'http://image.tmdb.org/t/p/w1280/czCwQ37GbSi8olUZ9mh5ncOzwOx.jpg'),
(103756, 7413, 'Os Encanadores da Casa Branca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216951.mp4', 'http://image.tmdb.org/t/p/w1280/dInvhDjveLi5Xxm4J7aIKDcilZy.jpg'),
(103757, 7413, 'Os Encanadores da Casa Branca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216952.mp4', 'http://image.tmdb.org/t/p/w1280/wIfsZ48Loq5EitLq4J1NLoTpSLJ.jpg'),
(103758, 7414, 'Rainha Charlotte: Uma História Bridgerton S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cSZ4oxwL3Yk31LbAnork91bwDGp.jpg'),
(103759, 7414, 'Rainha Charlotte: Uma História Bridgerton S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7LkeMBNrHHKAR77UYrEALKbLayG.jpg'),
(103760, 7414, 'Rainha Charlotte: Uma História Bridgerton S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l3NKs2VUxybQl2CoRQmlDMj5UMs.jpg'),
(103761, 7414, 'Rainha Charlotte: Uma História Bridgerton S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2kYSb6TFaO3nP0NuMDZ0q3TYL0T.jpg'),
(103762, 7414, 'Rainha Charlotte: Uma História Bridgerton S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a8rhfd2YI7mkF0kbBhbio8MCDD5.jpg'),
(103763, 7414, 'Rainha Charlotte: Uma História Bridgerton S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/476GLqDFBBbIrnZcBTN04nthcxb.jpg'),
(103764, 7415, 'Tensei Kizoku no Isekai Boukenroku: Jichou wo Shiranai Kamigami no Shito S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pzY1GtvMx7Gax8LG37GM6FnKKn5.jpg'),
(103765, 7415, 'Tensei Kizoku no Isekai Boukenroku: Jichou wo Shiranai Kamigami no Shito S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkENKN9yVtYYU5tpIURrJiJ4JrN.jpg'),
(103766, 7415, 'Tensei Kizoku no Isekai Boukenroku: Jichou wo Shiranai Kamigami no Shito S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241774.mp4', 'http://image.tmdb.org/t/p/w1280/w3PfbAScRckdUmCBRGJArxrxwKf.jpg'),
(103767, 7415, 'Tensei Kizoku no Isekai Boukenroku: Jichou wo Shiranai Kamigami no Shito S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241775.mp4', 'http://image.tmdb.org/t/p/w1280/5PtRxKcnULTO10sOA0udVBDejVc.jpg'),
(103768, 7415, 'Tensei Kizoku no Isekai Boukenroku: Jichou wo Shiranai Kamigami no Shito S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241776.mp4', 'http://image.tmdb.org/t/p/w1280/ve4oPMoFOkZcp2AWEPv4yyDdPXI.jpg'),
(103769, 7415, 'Tensei Kizoku no Isekai Boukenroku: Jichou wo Shiranai Kamigami no Shito S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241777.mp4', 'http://image.tmdb.org/t/p/w1280/nKd70LVlp6fBRqcBHTw6DMblqGk.jpg'),
(103770, 7415, 'Tensei Kizoku no Isekai Boukenroku: Jichou wo Shiranai Kamigami no Shito S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zPuT9PlTQ8gympp72OzjBM80pgp.jpg'),
(103771, 7415, 'Tensei Kizoku no Isekai Boukenroku: Jichou wo Shiranai Kamigami no Shito S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zPuT9PlTQ8gympp72OzjBM80pgp.jpg'),
(103772, 7415, 'Tensei Kizoku no Isekai Boukenroku: Jichou wo Shiranai Kamigami no Shito S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zPuT9PlTQ8gympp72OzjBM80pgp.jpg'),
(103773, 7415, 'Tensei Kizoku no Isekai Boukenroku: Jichou wo Shiranai Kamigami no Shito S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zPuT9PlTQ8gympp72OzjBM80pgp.jpg'),
(103774, 7415, 'Tensei Kizoku no Isekai Boukenroku: Jichou wo Shiranai Kamigami no Shito S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zPuT9PlTQ8gympp72OzjBM80pgp.jpg'),
(103775, 7415, 'Tensei Kizoku no Isekai Boukenroku: Jichou wo Shiranai Kamigami no Shito S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zPuT9PlTQ8gympp72OzjBM80pgp.jpg'),
(103776, 7416, 'Without Sin: Sem Pecado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eYtpLcUVF49Gaq9zY2wnjrHOpmb.jpg'),
(103777, 7416, 'Without Sin: Sem Pecado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ezt0GDhRABf0QAGo8dR517iVLtI.jpg'),
(103778, 7416, 'Without Sin: Sem Pecado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7rMfNINjoyieieu3uQV6TxkhkUG.jpg'),
(103779, 7416, 'Without Sin: Sem Pecado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/67KahUB5jsbLHfDV35ncn1kJQfz.jpg'),
(103780, 7417, 'Linha Direta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7FcRnh2wVrFdRoWFDf2P64UgfbR.jpg'),
(103781, 7417, 'Linha Direta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7FcRnh2wVrFdRoWFDf2P64UgfbR.jpg'),
(103782, 7417, 'Linha Direta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7FcRnh2wVrFdRoWFDf2P64UgfbR.jpg'),
(103783, 7417, 'Linha Direta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7FcRnh2wVrFdRoWFDf2P64UgfbR.jpg'),
(103784, 7417, 'Linha Direta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7FcRnh2wVrFdRoWFDf2P64UgfbR.jpg'),
(103785, 7417, 'Linha Direta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7FcRnh2wVrFdRoWFDf2P64UgfbR.jpg'),
(103786, 7417, 'Linha Direta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7FcRnh2wVrFdRoWFDf2P64UgfbR.jpg'),
(103787, 7417, 'Linha Direta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7FcRnh2wVrFdRoWFDf2P64UgfbR.jpg'),
(103788, 7417, 'Linha Direta S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7FcRnh2wVrFdRoWFDf2P64UgfbR.jpg'),
(103789, 7417, 'Linha Direta S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7FcRnh2wVrFdRoWFDf2P64UgfbR.jpg'),
(103790, 7418, 'Linha Direta S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7FcRnh2wVrFdRoWFDf2P64UgfbR.jpg'),
(103791, 7418, 'Linha Direta S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/336317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7FcRnh2wVrFdRoWFDf2P64UgfbR.jpg'),
(103792, 7418, 'Linha Direta S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/345248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7FcRnh2wVrFdRoWFDf2P64UgfbR.jpg'),
(103793, 7418, 'Linha Direta S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/352089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7FcRnh2wVrFdRoWFDf2P64UgfbR.jpg'),
(103794, 7418, 'Linha Direta S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/352090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7FcRnh2wVrFdRoWFDf2P64UgfbR.jpg'),
(103795, 7418, 'Linha Direta S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/359503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7FcRnh2wVrFdRoWFDf2P64UgfbR.jpg'),
(103796, 7418, 'Linha Direta S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/368164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7FcRnh2wVrFdRoWFDf2P64UgfbR.jpg'),
(103797, 7418, 'Linha Direta S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/377825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7FcRnh2wVrFdRoWFDf2P64UgfbR.jpg'),
(103798, 7418, 'Linha Direta S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/396677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7FcRnh2wVrFdRoWFDf2P64UgfbR.jpg'),
(103799, 7418, 'Linha Direta S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/396678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7FcRnh2wVrFdRoWFDf2P64UgfbR.jpg'),
(103800, 7419, 'Noiva por Vingança S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iMV3tMnKWZVbWjk29QvDLsk0zQ9.jpg'),
(103801, 7419, 'Noiva por Vingança S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nf5Rs79CwDr4AcZvw9TjATWwLHi.jpg'),
(103802, 7419, 'Noiva por Vingança S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQzpESxXkPky0OoArd8Y6FtNIOn.jpg'),
(103803, 7419, 'Noiva por Vingança S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sz7oaeZyjv56X9DxgKYPUyMxoGX.jpg'),
(103804, 7419, 'Noiva por Vingança S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/seoWpndwtummpRu87uFyGRzLyMg.jpg'),
(103805, 7419, 'Noiva por Vingança S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bVyDJCSFY4zANsBnNWC6rTc0XDx.jpg'),
(103806, 7419, 'Noiva por Vingança S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/89ex7yBDiEg9NkotQ1mgbLd8I1Q.jpg'),
(103807, 7419, 'Noiva por Vingança S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r6OnEz1xnR6EByrrpreUSh9C7Qt.jpg'),
(103808, 7419, 'Noiva por Vingança S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ls0MtTxs001d3hmIf7RsvBPzK7x.jpg'),
(103809, 7419, 'Noiva por Vingança S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ccRdyYfSqejrDchtSdlTYt4y2RX.jpg'),
(103810, 7419, 'Noiva por Vingança S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/210377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6j3t9sV0RvJLuvg7wwqkutL3ZU6.jpg'),
(103811, 7419, 'Noiva por Vingança S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/210378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sizeVmYXIpfBioErUXA6zYYwjRW.jpg'),
(103812, 7419, 'Noiva por Vingança S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/210379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bFfWkLKHLJljfqd57yuFR0aiO53.jpg'),
(103813, 7419, 'Noiva por Vingança S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/210380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7APcLBCK060ZJ6dhvHLiCWkEVLX.jpg'),
(103814, 7419, 'Noiva por Vingança S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/210381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8RQi4NlVM9aN54NjEuPX7XH2uOV.jpg'),
(103815, 7419, 'Noiva por Vingança S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/210382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yU7w0Q5tpl56PKtjHJO8xeCOMcT.jpg'),
(103816, 7420, 'Santuário do Sumô S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQpPisIfgPivsCg1f04oVqoddep.jpg'),
(103817, 7420, 'Santuário do Sumô S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mctKFtIsVSFyrjtx90DyAJag5r0.jpg'),
(103818, 7420, 'Santuário do Sumô S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zInLx0vLMAqCIlu2uQDcsFqf13X.jpg'),
(103819, 7420, 'Santuário do Sumô S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zcSAbkiqHN5JXgcauUSy5emRf7U.jpg'),
(103820, 7420, 'Santuário do Sumô S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d03Vcd88HxuftnfTojgYjCb2mSv.jpg'),
(103821, 7420, 'Santuário do Sumô S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cnUxdxp6dQ1ocbWDsVpn9pOkWwL.jpg'),
(103822, 7420, 'Santuário do Sumô S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oxaGQLGSHMmf6Xun5oK2OiRRGcn.jpg'),
(103823, 7420, 'Santuário do Sumô S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sRbuBUkXBzrXYZuDExnWZuV3FnK.jpg'),
(103824, 7421, 'Silo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpZhJcWPpyLvPC5Vid61GD6JHVu.jpg'),
(103825, 7421, 'Silo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bRYHFClG8YkTJTy8fx73hgCd8Ac.jpg'),
(103826, 7421, 'Silo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219411.mp4', 'http://image.tmdb.org/t/p/w1280/8hQB4jxk9ydj55Mrl9sY95smV7.jpg'),
(103827, 7421, 'Silo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219412.mp4', 'http://image.tmdb.org/t/p/w1280/x3fMuXhTx5f91tQgjXNzopo5B5g.jpg'),
(103828, 7421, 'Silo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219413.mp4', 'http://image.tmdb.org/t/p/w1280/yzLUNo2jU82N5rdRG0xZ2A2ed79.jpg'),
(103829, 7421, 'Silo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219414.mp4', 'http://image.tmdb.org/t/p/w1280/k5UxYAS4Xmcsn3GZdCklXGMIBMd.jpg'),
(103830, 7421, 'Silo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219415.mp4', 'http://image.tmdb.org/t/p/w1280/ukzV8BZbjlIU6WOKdoZqhHMg2yi.jpg'),
(103831, 7421, 'Silo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j9wyX1KxM9GDH3BRTaAe9MGTldj.jpg'),
(103832, 7421, 'Silo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219417.mp4', 'http://image.tmdb.org/t/p/w1280/mogTf95jiLdvSXwnjpQcIs6Wxh2.jpg'),
(103833, 7421, 'Silo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219418.mp4', 'http://image.tmdb.org/t/p/w1280/qcqkEv0S8Re5V2UV9LFUWzHYyq3.jpg'),
(103834, 7422, 'Silo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/504747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j9wyX1KxM9GDH3BRTaAe9MGTldj.jpg'),
(103835, 7422, 'Silo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/512754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j9wyX1KxM9GDH3BRTaAe9MGTldj.jpg'),
(103836, 7422, 'Silo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/514948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j9wyX1KxM9GDH3BRTaAe9MGTldj.jpg'),
(103837, 7422, 'Silo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/517004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j9wyX1KxM9GDH3BRTaAe9MGTldj.jpg'),
(103838, 7422, 'Silo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/521890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j9wyX1KxM9GDH3BRTaAe9MGTldj.jpg'),
(103839, 7422, 'Silo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/638951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j9wyX1KxM9GDH3BRTaAe9MGTldj.jpg'),
(103840, 7422, 'Silo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/643623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j9wyX1KxM9GDH3BRTaAe9MGTldj.jpg'),
(103841, 7422, 'Silo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/657434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j9wyX1KxM9GDH3BRTaAe9MGTldj.jpg'),
(103842, 7422, 'Silo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/661317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j9wyX1KxM9GDH3BRTaAe9MGTldj.jpg'),
(103843, 7422, 'Silo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/667391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j9wyX1KxM9GDH3BRTaAe9MGTldj.jpg'),
(103844, 7423, 'Família Larva S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5WYKClgu17xq0IcHkvYYfa25TTW.jpg'),
(103845, 7423, 'Família Larva S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5WYKClgu17xq0IcHkvYYfa25TTW.jpg'),
(103846, 7423, 'Família Larva S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5WYKClgu17xq0IcHkvYYfa25TTW.jpg'),
(103847, 7423, 'Família Larva S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5WYKClgu17xq0IcHkvYYfa25TTW.jpg'),
(103848, 7423, 'Família Larva S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5WYKClgu17xq0IcHkvYYfa25TTW.jpg'),
(103849, 7423, 'Família Larva S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5WYKClgu17xq0IcHkvYYfa25TTW.jpg'),
(103850, 7423, 'Família Larva S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5WYKClgu17xq0IcHkvYYfa25TTW.jpg'),
(103851, 7423, 'Família Larva S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5WYKClgu17xq0IcHkvYYfa25TTW.jpg'),
(103852, 7423, 'Família Larva S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5WYKClgu17xq0IcHkvYYfa25TTW.jpg'),
(103853, 7424, 'Unicorn: Warriors Eternal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2WhgjYh6oLGvrTYaJ1ZYeLOhJuR.jpg'),
(103854, 7424, 'Unicorn: Warriors Eternal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4YQPKmzUzbPLJm2WE6xP96ZgTYx.jpg'),
(103855, 7424, 'Unicorn: Warriors Eternal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219189.mp4', 'http://image.tmdb.org/t/p/w1280/iGeafrFSNzMJ6TqUjX2SlrlW5Gx.jpg'),
(103856, 7424, 'Unicorn: Warriors Eternal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219190.mp4', 'http://image.tmdb.org/t/p/w1280/iz5hqjhOZLFBVJ7EfUWQjNx68oi.jpg'),
(103857, 7424, 'Unicorn: Warriors Eternal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219191.mp4', 'http://image.tmdb.org/t/p/w1280/rxtwIQt86NwIa85RK46EPZNAhrj.jpg'),
(103858, 7424, 'Unicorn: Warriors Eternal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219192.mp4', 'http://image.tmdb.org/t/p/w1280/yjXMjapSKgalslF4DImzAlUy2vX.jpg'),
(103859, 7424, 'Unicorn: Warriors Eternal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219193.mp4', 'http://image.tmdb.org/t/p/w1280/2tVYD6BPqDVIujJNoHJFfkDj6go.jpg'),
(103860, 7424, 'Unicorn: Warriors Eternal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219194.mp4', 'http://image.tmdb.org/t/p/w1280/fRH3OOn7EUVEoDoMk0mpwGsyPTt.jpg'),
(103861, 7424, 'Unicorn: Warriors Eternal S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219195.mp4', 'http://image.tmdb.org/t/p/w1280/p2jsGOUrpA4dWW2zDya1bmPTzWa.jpg'),
(103862, 7424, 'Unicorn: Warriors Eternal S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219196.mp4', 'http://image.tmdb.org/t/p/w1280/t4l3vBmbrnTuYh53AjrL9B1hGrI.jpg'),
(103863, 7425, 'Watashi no Yuri wa Oshigoto desu! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Y9B80Tk2SvKV0oW6fwrL4j2OEo.jpg'),
(103864, 7425, 'Watashi no Yuri wa Oshigoto desu! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tIXqtp9046nUcmPPBXlNG0TuHEl.jpg'),
(103865, 7425, 'Watashi no Yuri wa Oshigoto desu! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223242.mp4', 'http://image.tmdb.org/t/p/w1280/bRe8zPGDVoAFffYAKYSPSxJQnAb.jpg'),
(103866, 7425, 'Watashi no Yuri wa Oshigoto desu! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223243.mp4', 'http://image.tmdb.org/t/p/w1280/2Al8x7DY98jLSPJKIqbLuvvLArN.jpg'),
(103867, 7425, 'Watashi no Yuri wa Oshigoto desu! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223244.mp4', 'http://image.tmdb.org/t/p/w1280/chFgUSwt346X7l6tXZrAFoEdrJU.jpg'),
(103868, 7425, 'Watashi no Yuri wa Oshigoto desu! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223245.mp4', 'http://image.tmdb.org/t/p/w1280/52xyR7pL3torYmzp3IFSgnvYCrb.jpg'),
(103869, 7425, 'Watashi no Yuri wa Oshigoto desu! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4sAEhGkhOynh1PQwfCKAcCTaxqw.jpg'),
(103870, 7425, 'Watashi no Yuri wa Oshigoto desu! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4sAEhGkhOynh1PQwfCKAcCTaxqw.jpg'),
(103871, 7425, 'Watashi no Yuri wa Oshigoto desu! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223248.mp4', 'http://image.tmdb.org/t/p/w1280/cc7S6a41Lgm9F5JYO8NWnONSyU9.jpg'),
(103872, 7425, 'Watashi no Yuri wa Oshigoto desu! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223249.mp4', 'http://image.tmdb.org/t/p/w1280/aKQjNwIwcRJPvtpDWuPgyXLxvRh.jpg'),
(103873, 7425, 'Watashi no Yuri wa Oshigoto desu! S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223250.mp4', 'http://image.tmdb.org/t/p/w1280/fnLP8wDj49jG9prWsr8rwxGlNnS.jpg'),
(103874, 7425, 'Watashi no Yuri wa Oshigoto desu! S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223251.mp4', 'http://image.tmdb.org/t/p/w1280/xssCTx7xJbQy7CSCHC6dO9hvp5l.jpg'),
(103875, 7426, 'A Infância de Romeu e Julieta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w5Uw1QkOD9nWntK8wX3O0v2u4JM.jpg'),
(103876, 7426, 'A Infância de Romeu e Julieta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ScSJUvugoH9341g22kAwTN8ZhF.jpg'),
(103877, 7426, 'A Infância de Romeu e Julieta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVAqCoHYSIOrZPgNctDAMVD1Ue8.jpg'),
(103878, 7426, 'A Infância de Romeu e Julieta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wV0jCx9k8X8lDvEy1XR1FXgt9r1.jpg'),
(103879, 7426, 'A Infância de Romeu e Julieta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tOCHe6ZeUgyF6GAEEuPX6UdeiqK.jpg'),
(103880, 7426, 'A Infância de Romeu e Julieta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103881, 7426, 'A Infância de Romeu e Julieta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103882, 7426, 'A Infância de Romeu e Julieta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103883, 7426, 'A Infância de Romeu e Julieta S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103884, 7426, 'A Infância de Romeu e Julieta S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103885, 7426, 'A Infância de Romeu e Julieta S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103886, 7426, 'A Infância de Romeu e Julieta S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103887, 7426, 'A Infância de Romeu e Julieta S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103888, 7426, 'A Infância de Romeu e Julieta S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103889, 7426, 'A Infância de Romeu e Julieta S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103890, 7426, 'A Infância de Romeu e Julieta S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103891, 7426, 'A Infância de Romeu e Julieta S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/263590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103892, 7426, 'A Infância de Romeu e Julieta S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/263591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103893, 7426, 'A Infância de Romeu e Julieta S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/263592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103894, 7426, 'A Infância de Romeu e Julieta S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/263593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103895, 7426, 'A Infância de Romeu e Julieta S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/263594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103896, 7426, 'A Infância de Romeu e Julieta S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/263595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103897, 7426, 'A Infância de Romeu e Julieta S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/263596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103898, 7426, 'A Infância de Romeu e Julieta S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/263597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103899, 7426, 'A Infância de Romeu e Julieta S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/263598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103900, 7426, 'A Infância de Romeu e Julieta S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/263599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103901, 7426, 'A Infância de Romeu e Julieta S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/263600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103902, 7426, 'A Infância de Romeu e Julieta S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/263601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103903, 7426, 'A Infância de Romeu e Julieta S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/263602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103904, 7426, 'A Infância de Romeu e Julieta S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/263603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103905, 7426, 'A Infância de Romeu e Julieta S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/263604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103906, 7426, 'A Infância de Romeu e Julieta S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/263605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103907, 7426, 'A Infância de Romeu e Julieta S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/263606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103908, 7426, 'A Infância de Romeu e Julieta S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/263607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103909, 7426, 'A Infância de Romeu e Julieta S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/263608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103910, 7426, 'A Infância de Romeu e Julieta S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/263609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103911, 7426, 'A Infância de Romeu e Julieta S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/263610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103912, 7426, 'A Infância de Romeu e Julieta S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/263611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103913, 7426, 'A Infância de Romeu e Julieta S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/263612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103914, 7426, 'A Infância de Romeu e Julieta S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/263613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103915, 7426, 'A Infância de Romeu e Julieta S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/263614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103916, 7426, 'A Infância de Romeu e Julieta S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/263615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103917, 7426, 'A Infância de Romeu e Julieta S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/263616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103918, 7426, 'A Infância de Romeu e Julieta S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/263617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103919, 7426, 'A Infância de Romeu e Julieta S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/263618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103920, 7426, 'A Infância de Romeu e Julieta S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/263619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103921, 7426, 'A Infância de Romeu e Julieta S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/263620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103922, 7426, 'A Infância de Romeu e Julieta S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/263621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103923, 7426, 'A Infância de Romeu e Julieta S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/263622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103924, 7426, 'A Infância de Romeu e Julieta S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/263623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103925, 7426, 'A Infância de Romeu e Julieta S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/263624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103926, 7426, 'A Infância de Romeu e Julieta S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/263625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103927, 7426, 'A Infância de Romeu e Julieta S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/263626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(103928, 7426, 'A Infância de Romeu e Julieta S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/263627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103929, 7426, 'A Infância de Romeu e Julieta S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/263628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103930, 7426, 'A Infância de Romeu e Julieta S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/263629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103931, 7426, 'A Infância de Romeu e Julieta S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/263630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103932, 7426, 'A Infância de Romeu e Julieta S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/263631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103933, 7426, 'A Infância de Romeu e Julieta S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/263632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103934, 7426, 'A Infância de Romeu e Julieta S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/263633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103935, 7426, 'A Infância de Romeu e Julieta S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/263634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103936, 7426, 'A Infância de Romeu e Julieta S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/263635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103937, 7426, 'A Infância de Romeu e Julieta S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/263636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103938, 7426, 'A Infância de Romeu e Julieta S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/263637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103939, 7426, 'A Infância de Romeu e Julieta S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/263638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103940, 7426, 'A Infância de Romeu e Julieta S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/263639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103941, 7426, 'A Infância de Romeu e Julieta S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/263640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103942, 7426, 'A Infância de Romeu e Julieta S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/263641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103943, 7426, 'A Infância de Romeu e Julieta S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/263642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103944, 7426, 'A Infância de Romeu e Julieta S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/263643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103945, 7426, 'A Infância de Romeu e Julieta S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/263644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103946, 7426, 'A Infância de Romeu e Julieta S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/263645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103947, 7426, 'A Infância de Romeu e Julieta S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/263646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103948, 7426, 'A Infância de Romeu e Julieta S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/263647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103949, 7426, 'A Infância de Romeu e Julieta S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/263648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103950, 7426, 'A Infância de Romeu e Julieta S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/263649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103951, 7426, 'A Infância de Romeu e Julieta S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/263650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103952, 7426, 'A Infância de Romeu e Julieta S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/263651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103953, 7426, 'A Infância de Romeu e Julieta S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/263652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103954, 7426, 'A Infância de Romeu e Julieta S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/263653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103955, 7426, 'A Infância de Romeu e Julieta S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/263654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103956, 7426, 'A Infância de Romeu e Julieta S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/263655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103957, 7426, 'A Infância de Romeu e Julieta S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/263656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103958, 7426, 'A Infância de Romeu e Julieta S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/263657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103959, 7426, 'A Infância de Romeu e Julieta S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/263658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103960, 7426, 'A Infância de Romeu e Julieta S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/263659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103961, 7426, 'A Infância de Romeu e Julieta S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/263660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103962, 7426, 'A Infância de Romeu e Julieta S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/263661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103963, 7426, 'A Infância de Romeu e Julieta S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/263662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103964, 7426, 'A Infância de Romeu e Julieta S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/263663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103965, 7426, 'A Infância de Romeu e Julieta S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/263664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103966, 7426, 'A Infância de Romeu e Julieta S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/263665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103967, 7426, 'A Infância de Romeu e Julieta S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/263666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103968, 7426, 'A Infância de Romeu e Julieta S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/263667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103969, 7426, 'A Infância de Romeu e Julieta S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/263668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103970, 7426, 'A Infância de Romeu e Julieta S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/263669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103971, 7426, 'A Infância de Romeu e Julieta S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/263670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103972, 7426, 'A Infância de Romeu e Julieta S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/263671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103973, 7426, 'A Infância de Romeu e Julieta S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/263672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103974, 7426, 'A Infância de Romeu e Julieta S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/263673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103975, 7426, 'A Infância de Romeu e Julieta S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/263674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103976, 7426, 'A Infância de Romeu e Julieta S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/263675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103977, 7426, 'A Infância de Romeu e Julieta S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/263676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103978, 7426, 'A Infância de Romeu e Julieta S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/263677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103979, 7426, 'A Infância de Romeu e Julieta S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/263678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103980, 7426, 'A Infância de Romeu e Julieta S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/263679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103981, 7426, 'A Infância de Romeu e Julieta S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/263680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103982, 7426, 'A Infância de Romeu e Julieta S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/263681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103983, 7426, 'A Infância de Romeu e Julieta S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/263682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103984, 7426, 'A Infância de Romeu e Julieta S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/263683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103985, 7426, 'A Infância de Romeu e Julieta S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/263684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103986, 7426, 'A Infância de Romeu e Julieta S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/263685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103987, 7426, 'A Infância de Romeu e Julieta S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/263686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103988, 7426, 'A Infância de Romeu e Julieta S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/263687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103989, 7426, 'A Infância de Romeu e Julieta S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/263688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103990, 7426, 'A Infância de Romeu e Julieta S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/263689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103991, 7426, 'A Infância de Romeu e Julieta S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/263690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103992, 7426, 'A Infância de Romeu e Julieta S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/263691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103993, 7426, 'A Infância de Romeu e Julieta S01 E119', 'http://sinalprivado.info:80/series/1533784/1533784/263692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103994, 7426, 'A Infância de Romeu e Julieta S01 E120', 'http://sinalprivado.info:80/series/1533784/1533784/263693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103995, 7426, 'A Infância de Romeu e Julieta S01 E121', 'http://sinalprivado.info:80/series/1533784/1533784/263694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103996, 7426, 'A Infância de Romeu e Julieta S01 E122', 'http://sinalprivado.info:80/series/1533784/1533784/263695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103997, 7426, 'A Infância de Romeu e Julieta S01 E123', 'http://sinalprivado.info:80/series/1533784/1533784/263696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103998, 7426, 'A Infância de Romeu e Julieta S01 E124', 'http://sinalprivado.info:80/series/1533784/1533784/263697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(103999, 7426, 'A Infância de Romeu e Julieta S01 E125', 'http://sinalprivado.info:80/series/1533784/1533784/263698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104000, 7426, 'A Infância de Romeu e Julieta S01 E126', 'http://sinalprivado.info:80/series/1533784/1533784/263699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104001, 7426, 'A Infância de Romeu e Julieta S01 E127', 'http://sinalprivado.info:80/series/1533784/1533784/263700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104002, 7426, 'A Infância de Romeu e Julieta S01 E128', 'http://sinalprivado.info:80/series/1533784/1533784/263701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104003, 7426, 'A Infância de Romeu e Julieta S01 E129', 'http://sinalprivado.info:80/series/1533784/1533784/263702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104004, 7426, 'A Infância de Romeu e Julieta S01 E130', 'http://sinalprivado.info:80/series/1533784/1533784/263703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104005, 7426, 'A Infância de Romeu e Julieta S01 E131', 'http://sinalprivado.info:80/series/1533784/1533784/263704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104006, 7426, 'A Infância de Romeu e Julieta S01 E132', 'http://sinalprivado.info:80/series/1533784/1533784/263705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104007, 7426, 'A Infância de Romeu e Julieta S01 E133', 'http://sinalprivado.info:80/series/1533784/1533784/263706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104008, 7426, 'A Infância de Romeu e Julieta S01 E134', 'http://sinalprivado.info:80/series/1533784/1533784/263707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104009, 7426, 'A Infância de Romeu e Julieta S01 E135', 'http://sinalprivado.info:80/series/1533784/1533784/263708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104010, 7426, 'A Infância de Romeu e Julieta S01 E136', 'http://sinalprivado.info:80/series/1533784/1533784/263709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104011, 7426, 'A Infância de Romeu e Julieta S01 E137', 'http://sinalprivado.info:80/series/1533784/1533784/263710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104012, 7426, 'A Infância de Romeu e Julieta S01 E138', 'http://sinalprivado.info:80/series/1533784/1533784/263711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104013, 7426, 'A Infância de Romeu e Julieta S01 E139', 'http://sinalprivado.info:80/series/1533784/1533784/263712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104014, 7426, 'A Infância de Romeu e Julieta S01 E140', 'http://sinalprivado.info:80/series/1533784/1533784/263713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104015, 7426, 'A Infância de Romeu e Julieta S01 E141', 'http://sinalprivado.info:80/series/1533784/1533784/263714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104016, 7426, 'A Infância de Romeu e Julieta S01 E142', 'http://sinalprivado.info:80/series/1533784/1533784/263715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104017, 7426, 'A Infância de Romeu e Julieta S01 E143', 'http://sinalprivado.info:80/series/1533784/1533784/263716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104018, 7426, 'A Infância de Romeu e Julieta S01 E144', 'http://sinalprivado.info:80/series/1533784/1533784/263717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104019, 7426, 'A Infância de Romeu e Julieta S01 E145', 'http://sinalprivado.info:80/series/1533784/1533784/263718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104020, 7426, 'A Infância de Romeu e Julieta S01 E146', 'http://sinalprivado.info:80/series/1533784/1533784/263719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104021, 7426, 'A Infância de Romeu e Julieta S01 E147', 'http://sinalprivado.info:80/series/1533784/1533784/263720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104022, 7426, 'A Infância de Romeu e Julieta S01 E148', 'http://sinalprivado.info:80/series/1533784/1533784/263721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104023, 7426, 'A Infância de Romeu e Julieta S01 E149', 'http://sinalprivado.info:80/series/1533784/1533784/263722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104024, 7426, 'A Infância de Romeu e Julieta S01 E150', 'http://sinalprivado.info:80/series/1533784/1533784/263723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104025, 7426, 'A Infância de Romeu e Julieta S01 E151', 'http://sinalprivado.info:80/series/1533784/1533784/263724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104026, 7426, 'A Infância de Romeu e Julieta S01 E152', 'http://sinalprivado.info:80/series/1533784/1533784/263725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104027, 7426, 'A Infância de Romeu e Julieta S01 E153', 'http://sinalprivado.info:80/series/1533784/1533784/263726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104028, 7426, 'A Infância de Romeu e Julieta S01 E154', 'http://sinalprivado.info:80/series/1533784/1533784/263727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104029, 7426, 'A Infância de Romeu e Julieta S01 E155', 'http://sinalprivado.info:80/series/1533784/1533784/263728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104030, 7426, 'A Infância de Romeu e Julieta S01 E156', 'http://sinalprivado.info:80/series/1533784/1533784/263729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104031, 7426, 'A Infância de Romeu e Julieta S01 E157', 'http://sinalprivado.info:80/series/1533784/1533784/263730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104032, 7426, 'A Infância de Romeu e Julieta S01 E158', 'http://sinalprivado.info:80/series/1533784/1533784/263731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104033, 7426, 'A Infância de Romeu e Julieta S01 E159', 'http://sinalprivado.info:80/series/1533784/1533784/263732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104034, 7426, 'A Infância de Romeu e Julieta S01 E160', 'http://sinalprivado.info:80/series/1533784/1533784/263733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104035, 7426, 'A Infância de Romeu e Julieta S01 E161', 'http://sinalprivado.info:80/series/1533784/1533784/263734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104036, 7426, 'A Infância de Romeu e Julieta S01 E162', 'http://sinalprivado.info:80/series/1533784/1533784/263735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104037, 7426, 'A Infância de Romeu e Julieta S01 E163', 'http://sinalprivado.info:80/series/1533784/1533784/263736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104038, 7426, 'A Infância de Romeu e Julieta S01 E164', 'http://sinalprivado.info:80/series/1533784/1533784/263737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104039, 7426, 'A Infância de Romeu e Julieta S01 E165', 'http://sinalprivado.info:80/series/1533784/1533784/263738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104040, 7426, 'A Infância de Romeu e Julieta S01 E166', 'http://sinalprivado.info:80/series/1533784/1533784/263739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104041, 7426, 'A Infância de Romeu e Julieta S01 E167', 'http://sinalprivado.info:80/series/1533784/1533784/263740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104042, 7426, 'A Infância de Romeu e Julieta S01 E168', 'http://sinalprivado.info:80/series/1533784/1533784/263741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104043, 7426, 'A Infância de Romeu e Julieta S01 E169', 'http://sinalprivado.info:80/series/1533784/1533784/620839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104044, 7426, 'A Infância de Romeu e Julieta S01 E170', 'http://sinalprivado.info:80/series/1533784/1533784/263744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104045, 7426, 'A Infância de Romeu e Julieta S01 E171', 'http://sinalprivado.info:80/series/1533784/1533784/263745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104046, 7426, 'A Infância de Romeu e Julieta S01 E172', 'http://sinalprivado.info:80/series/1533784/1533784/263746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104047, 7426, 'A Infância de Romeu e Julieta S01 E173', 'http://sinalprivado.info:80/series/1533784/1533784/263747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104048, 7426, 'A Infância de Romeu e Julieta S01 E174', 'http://sinalprivado.info:80/series/1533784/1533784/263748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104049, 7426, 'A Infância de Romeu e Julieta S01 E175', 'http://sinalprivado.info:80/series/1533784/1533784/263749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104050, 7426, 'A Infância de Romeu e Julieta S01 E176', 'http://sinalprivado.info:80/series/1533784/1533784/263750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104051, 7426, 'A Infância de Romeu e Julieta S01 E177', 'http://sinalprivado.info:80/series/1533784/1533784/263751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104052, 7426, 'A Infância de Romeu e Julieta S01 E178', 'http://sinalprivado.info:80/series/1533784/1533784/263752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104053, 7426, 'A Infância de Romeu e Julieta S01 E179', 'http://sinalprivado.info:80/series/1533784/1533784/263753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104054, 7426, 'A Infância de Romeu e Julieta S01 E180', 'http://sinalprivado.info:80/series/1533784/1533784/263754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104055, 7426, 'A Infância de Romeu e Julieta S01 E181', 'http://sinalprivado.info:80/series/1533784/1533784/263755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104056, 7426, 'A Infância de Romeu e Julieta S01 E182', 'http://sinalprivado.info:80/series/1533784/1533784/263756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104057, 7426, 'A Infância de Romeu e Julieta S01 E183', 'http://sinalprivado.info:80/series/1533784/1533784/263757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104058, 7426, 'A Infância de Romeu e Julieta S01 E184', 'http://sinalprivado.info:80/series/1533784/1533784/263758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104059, 7426, 'A Infância de Romeu e Julieta S01 E185', 'http://sinalprivado.info:80/series/1533784/1533784/263759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104060, 7426, 'A Infância de Romeu e Julieta S01 E186', 'http://sinalprivado.info:80/series/1533784/1533784/263760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104061, 7426, 'A Infância de Romeu e Julieta S01 E187', 'http://sinalprivado.info:80/series/1533784/1533784/263761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104062, 7426, 'A Infância de Romeu e Julieta S01 E188', 'http://sinalprivado.info:80/series/1533784/1533784/263762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104063, 7426, 'A Infância de Romeu e Julieta S01 E189', 'http://sinalprivado.info:80/series/1533784/1533784/263763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104064, 7426, 'A Infância de Romeu e Julieta S01 E190', 'http://sinalprivado.info:80/series/1533784/1533784/263764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104065, 7426, 'A Infância de Romeu e Julieta S01 E191', 'http://sinalprivado.info:80/series/1533784/1533784/287997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104066, 7426, 'A Infância de Romeu e Julieta S01 E192', 'http://sinalprivado.info:80/series/1533784/1533784/277161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104067, 7426, 'A Infância de Romeu e Julieta S01 E193', 'http://sinalprivado.info:80/series/1533784/1533784/277162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104068, 7426, 'A Infância de Romeu e Julieta S01 E194', 'http://sinalprivado.info:80/series/1533784/1533784/277163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104069, 7426, 'A Infância de Romeu e Julieta S01 E195', 'http://sinalprivado.info:80/series/1533784/1533784/277164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104070, 7426, 'A Infância de Romeu e Julieta S01 E196', 'http://sinalprivado.info:80/series/1533784/1533784/277165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104071, 7426, 'A Infância de Romeu e Julieta S01 E197', 'http://sinalprivado.info:80/series/1533784/1533784/277166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104072, 7426, 'A Infância de Romeu e Julieta S01 E198', 'http://sinalprivado.info:80/series/1533784/1533784/277167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104073, 7426, 'A Infância de Romeu e Julieta S01 E199', 'http://sinalprivado.info:80/series/1533784/1533784/277168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104074, 7426, 'A Infância de Romeu e Julieta S01 E200', 'http://sinalprivado.info:80/series/1533784/1533784/277169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104075, 7426, 'A Infância de Romeu e Julieta S01 E201', 'http://sinalprivado.info:80/series/1533784/1533784/277170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104076, 7426, 'A Infância de Romeu e Julieta S01 E202', 'http://sinalprivado.info:80/series/1533784/1533784/277171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104077, 7426, 'A Infância de Romeu e Julieta S01 E203', 'http://sinalprivado.info:80/series/1533784/1533784/277172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104078, 7426, 'A Infância de Romeu e Julieta S01 E204', 'http://sinalprivado.info:80/series/1533784/1533784/277173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104079, 7426, 'A Infância de Romeu e Julieta S01 E205', 'http://sinalprivado.info:80/series/1533784/1533784/277174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104080, 7426, 'A Infância de Romeu e Julieta S01 E206', 'http://sinalprivado.info:80/series/1533784/1533784/277175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104081, 7426, 'A Infância de Romeu e Julieta S01 E207', 'http://sinalprivado.info:80/series/1533784/1533784/277176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104082, 7426, 'A Infância de Romeu e Julieta S01 E208', 'http://sinalprivado.info:80/series/1533784/1533784/277177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104083, 7426, 'A Infância de Romeu e Julieta S01 E209', 'http://sinalprivado.info:80/series/1533784/1533784/277178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104084, 7426, 'A Infância de Romeu e Julieta S01 E210', 'http://sinalprivado.info:80/series/1533784/1533784/277179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104085, 7426, 'A Infância de Romeu e Julieta S01 E211', 'http://sinalprivado.info:80/series/1533784/1533784/277180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104086, 7426, 'A Infância de Romeu e Julieta S01 E212', 'http://sinalprivado.info:80/series/1533784/1533784/277181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104087, 7426, 'A Infância de Romeu e Julieta S01 E213', 'http://sinalprivado.info:80/series/1533784/1533784/277182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104088, 7426, 'A Infância de Romeu e Julieta S01 E214', 'http://sinalprivado.info:80/series/1533784/1533784/277183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104089, 7426, 'A Infância de Romeu e Julieta S01 E215', 'http://sinalprivado.info:80/series/1533784/1533784/277184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104090, 7426, 'A Infância de Romeu e Julieta S01 E216', 'http://sinalprivado.info:80/series/1533784/1533784/281790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104091, 7426, 'A Infância de Romeu e Julieta S01 E217', 'http://sinalprivado.info:80/series/1533784/1533784/281791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104092, 7426, 'A Infância de Romeu e Julieta S01 E218', 'http://sinalprivado.info:80/series/1533784/1533784/281792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104093, 7426, 'A Infância de Romeu e Julieta S01 E219', 'http://sinalprivado.info:80/series/1533784/1533784/281793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104094, 7426, 'A Infância de Romeu e Julieta S01 E220', 'http://sinalprivado.info:80/series/1533784/1533784/281794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104095, 7426, 'A Infância de Romeu e Julieta S01 E221', 'http://sinalprivado.info:80/series/1533784/1533784/296112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104096, 7426, 'A Infância de Romeu e Julieta S01 E222', 'http://sinalprivado.info:80/series/1533784/1533784/296113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104097, 7426, 'A Infância de Romeu e Julieta S01 E223', 'http://sinalprivado.info:80/series/1533784/1533784/298768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104098, 7426, 'A Infância de Romeu e Julieta S01 E224', 'http://sinalprivado.info:80/series/1533784/1533784/296114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104099, 7426, 'A Infância de Romeu e Julieta S01 E225', 'http://sinalprivado.info:80/series/1533784/1533784/298770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104100, 7426, 'A Infância de Romeu e Julieta S01 E226', 'http://sinalprivado.info:80/series/1533784/1533784/298771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104101, 7426, 'A Infância de Romeu e Julieta S01 E227', 'http://sinalprivado.info:80/series/1533784/1533784/296115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104102, 7426, 'A Infância de Romeu e Julieta S01 E228', 'http://sinalprivado.info:80/series/1533784/1533784/298773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104103, 7426, 'A Infância de Romeu e Julieta S01 E229', 'http://sinalprivado.info:80/series/1533784/1533784/298774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104104, 7426, 'A Infância de Romeu e Julieta S01 E230', 'http://sinalprivado.info:80/series/1533784/1533784/296116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104105, 7426, 'A Infância de Romeu e Julieta S01 E231', 'http://sinalprivado.info:80/series/1533784/1533784/311027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104106, 7426, 'A Infância de Romeu e Julieta S01 E232', 'http://sinalprivado.info:80/series/1533784/1533784/311028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104107, 7426, 'A Infância de Romeu e Julieta S01 E233', 'http://sinalprivado.info:80/series/1533784/1533784/311029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104108, 7426, 'A Infância de Romeu e Julieta S01 E234', 'http://sinalprivado.info:80/series/1533784/1533784/311030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104109, 7426, 'A Infância de Romeu e Julieta S01 E235', 'http://sinalprivado.info:80/series/1533784/1533784/311031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104110, 7426, 'A Infância de Romeu e Julieta S01 E236', 'http://sinalprivado.info:80/series/1533784/1533784/311032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104111, 7426, 'A Infância de Romeu e Julieta S01 E237', 'http://sinalprivado.info:80/series/1533784/1533784/311033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104112, 7426, 'A Infância de Romeu e Julieta S01 E238', 'http://sinalprivado.info:80/series/1533784/1533784/311034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104113, 7426, 'A Infância de Romeu e Julieta S01 E239', 'http://sinalprivado.info:80/series/1533784/1533784/311035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104114, 7426, 'A Infância de Romeu e Julieta S01 E240', 'http://sinalprivado.info:80/series/1533784/1533784/311036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104115, 7426, 'A Infância de Romeu e Julieta S01 E241', 'http://sinalprivado.info:80/series/1533784/1533784/312887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104116, 7426, 'A Infância de Romeu e Julieta S01 E242', 'http://sinalprivado.info:80/series/1533784/1533784/312888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104117, 7426, 'A Infância de Romeu e Julieta S01 E243', 'http://sinalprivado.info:80/series/1533784/1533784/312889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104118, 7426, 'A Infância de Romeu e Julieta S01 E244', 'http://sinalprivado.info:80/series/1533784/1533784/312890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104119, 7426, 'A Infância de Romeu e Julieta S01 E245', 'http://sinalprivado.info:80/series/1533784/1533784/312891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104120, 7426, 'A Infância de Romeu e Julieta S01 E246', 'http://sinalprivado.info:80/series/1533784/1533784/323342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104121, 7426, 'A Infância de Romeu e Julieta S01 E247', 'http://sinalprivado.info:80/series/1533784/1533784/323343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104122, 7426, 'A Infância de Romeu e Julieta S01 E248', 'http://sinalprivado.info:80/series/1533784/1533784/323344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104123, 7426, 'A Infância de Romeu e Julieta S01 E249', 'http://sinalprivado.info:80/series/1533784/1533784/323345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104124, 7426, 'A Infância de Romeu e Julieta S01 E250', 'http://sinalprivado.info:80/series/1533784/1533784/323346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104125, 7426, 'A Infância de Romeu e Julieta S01 E251', 'http://sinalprivado.info:80/series/1533784/1533784/334288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104126, 7426, 'A Infância de Romeu e Julieta S01 E252', 'http://sinalprivado.info:80/series/1533784/1533784/334289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104127, 7426, 'A Infância de Romeu e Julieta S01 E253', 'http://sinalprivado.info:80/series/1533784/1533784/334290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104128, 7426, 'A Infância de Romeu e Julieta S01 E254', 'http://sinalprivado.info:80/series/1533784/1533784/334291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104129, 7426, 'A Infância de Romeu e Julieta S01 E255', 'http://sinalprivado.info:80/series/1533784/1533784/334292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104130, 7426, 'A Infância de Romeu e Julieta S01 E256', 'http://sinalprivado.info:80/series/1533784/1533784/334293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104131, 7426, 'A Infância de Romeu e Julieta S01 E257', 'http://sinalprivado.info:80/series/1533784/1533784/334294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104132, 7426, 'A Infância de Romeu e Julieta S01 E258', 'http://sinalprivado.info:80/series/1533784/1533784/334295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104133, 7426, 'A Infância de Romeu e Julieta S01 E259', 'http://sinalprivado.info:80/series/1533784/1533784/334296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104134, 7426, 'A Infância de Romeu e Julieta S01 E260', 'http://sinalprivado.info:80/series/1533784/1533784/334297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104135, 7426, 'A Infância de Romeu e Julieta S01 E261', 'http://sinalprivado.info:80/series/1533784/1533784/346143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104136, 7426, 'A Infância de Romeu e Julieta S01 E262', 'http://sinalprivado.info:80/series/1533784/1533784/346144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104137, 7426, 'A Infância de Romeu e Julieta S01 E263', 'http://sinalprivado.info:80/series/1533784/1533784/346145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104138, 7426, 'A Infância de Romeu e Julieta S01 E264', 'http://sinalprivado.info:80/series/1533784/1533784/346146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104139, 7426, 'A Infância de Romeu e Julieta S01 E265', 'http://sinalprivado.info:80/series/1533784/1533784/346147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104140, 7426, 'A Infância de Romeu e Julieta S01 E266', 'http://sinalprivado.info:80/series/1533784/1533784/346148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104141, 7426, 'A Infância de Romeu e Julieta S01 E267', 'http://sinalprivado.info:80/series/1533784/1533784/346149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104142, 7426, 'A Infância de Romeu e Julieta S01 E268', 'http://sinalprivado.info:80/series/1533784/1533784/346150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104143, 7426, 'A Infância de Romeu e Julieta S01 E269', 'http://sinalprivado.info:80/series/1533784/1533784/346151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104144, 7426, 'A Infância de Romeu e Julieta S01 E270', 'http://sinalprivado.info:80/series/1533784/1533784/346152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104145, 7426, 'A Infância de Romeu e Julieta S01 E271', 'http://sinalprivado.info:80/series/1533784/1533784/350698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104146, 7426, 'A Infância de Romeu e Julieta S01 E272', 'http://sinalprivado.info:80/series/1533784/1533784/350699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104147, 7426, 'A Infância de Romeu e Julieta S01 E273', 'http://sinalprivado.info:80/series/1533784/1533784/350700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104148, 7426, 'A Infância de Romeu e Julieta S01 E274', 'http://sinalprivado.info:80/series/1533784/1533784/350701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104149, 7426, 'A Infância de Romeu e Julieta S01 E275', 'http://sinalprivado.info:80/series/1533784/1533784/350702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104150, 7426, 'A Infância de Romeu e Julieta S01 E276', 'http://sinalprivado.info:80/series/1533784/1533784/350703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104151, 7426, 'A Infância de Romeu e Julieta S01 E277', 'http://sinalprivado.info:80/series/1533784/1533784/350704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104152, 7426, 'A Infância de Romeu e Julieta S01 E278', 'http://sinalprivado.info:80/series/1533784/1533784/350705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104153, 7426, 'A Infância de Romeu e Julieta S01 E279', 'http://sinalprivado.info:80/series/1533784/1533784/350706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104154, 7426, 'A Infância de Romeu e Julieta S01 E280', 'http://sinalprivado.info:80/series/1533784/1533784/350707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104155, 7426, 'A Infância de Romeu e Julieta S01 E281', 'http://sinalprivado.info:80/series/1533784/1533784/364040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104156, 7426, 'A Infância de Romeu e Julieta S01 E282', 'http://sinalprivado.info:80/series/1533784/1533784/364041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104157, 7426, 'A Infância de Romeu e Julieta S01 E283', 'http://sinalprivado.info:80/series/1533784/1533784/364042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104158, 7426, 'A Infância de Romeu e Julieta S01 E284', 'http://sinalprivado.info:80/series/1533784/1533784/364043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104159, 7426, 'A Infância de Romeu e Julieta S01 E285', 'http://sinalprivado.info:80/series/1533784/1533784/364044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104160, 7426, 'A Infância de Romeu e Julieta S01 E286', 'http://sinalprivado.info:80/series/1533784/1533784/375790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104161, 7426, 'A Infância de Romeu e Julieta S01 E287', 'http://sinalprivado.info:80/series/1533784/1533784/375791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104162, 7426, 'A Infância de Romeu e Julieta S01 E288', 'http://sinalprivado.info:80/series/1533784/1533784/375792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104163, 7426, 'A Infância de Romeu e Julieta S01 E289', 'http://sinalprivado.info:80/series/1533784/1533784/375793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104164, 7426, 'A Infância de Romeu e Julieta S01 E290', 'http://sinalprivado.info:80/series/1533784/1533784/375794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104165, 7426, 'A Infância de Romeu e Julieta S01 E291', 'http://sinalprivado.info:80/series/1533784/1533784/378706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104166, 7426, 'A Infância de Romeu e Julieta S01 E292', 'http://sinalprivado.info:80/series/1533784/1533784/378707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104167, 7426, 'A Infância de Romeu e Julieta S01 E293', 'http://sinalprivado.info:80/series/1533784/1533784/378708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104168, 7426, 'A Infância de Romeu e Julieta S01 E294', 'http://sinalprivado.info:80/series/1533784/1533784/378709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104169, 7426, 'A Infância de Romeu e Julieta S01 E295', 'http://sinalprivado.info:80/series/1533784/1533784/378710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104170, 7426, 'A Infância de Romeu e Julieta S01 E296', 'http://sinalprivado.info:80/series/1533784/1533784/388167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(104171, 7426, 'A Infância de Romeu e Julieta S01 E297', 'http://sinalprivado.info:80/series/1533784/1533784/388168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104172, 7426, 'A Infância de Romeu e Julieta S01 E298', 'http://sinalprivado.info:80/series/1533784/1533784/388169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104173, 7426, 'A Infância de Romeu e Julieta S01 E299', 'http://sinalprivado.info:80/series/1533784/1533784/388170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104174, 7426, 'A Infância de Romeu e Julieta S01 E300', 'http://sinalprivado.info:80/series/1533784/1533784/388171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104175, 7426, 'A Infância de Romeu e Julieta S01 E301', 'http://sinalprivado.info:80/series/1533784/1533784/399126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104176, 7426, 'A Infância de Romeu e Julieta S01 E302', 'http://sinalprivado.info:80/series/1533784/1533784/399127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104177, 7426, 'A Infância de Romeu e Julieta S01 E303', 'http://sinalprivado.info:80/series/1533784/1533784/399128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104178, 7426, 'A Infância de Romeu e Julieta S01 E304', 'http://sinalprivado.info:80/series/1533784/1533784/399129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104179, 7426, 'A Infância de Romeu e Julieta S01 E305', 'http://sinalprivado.info:80/series/1533784/1533784/399130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104180, 7426, 'A Infância de Romeu e Julieta S01 E306', 'http://sinalprivado.info:80/series/1533784/1533784/399131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104181, 7426, 'A Infância de Romeu e Julieta S01 E307', 'http://sinalprivado.info:80/series/1533784/1533784/399132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104182, 7426, 'A Infância de Romeu e Julieta S01 E308', 'http://sinalprivado.info:80/series/1533784/1533784/399133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104183, 7426, 'A Infância de Romeu e Julieta S01 E309', 'http://sinalprivado.info:80/series/1533784/1533784/399134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104184, 7426, 'A Infância de Romeu e Julieta S01 E310', 'http://sinalprivado.info:80/series/1533784/1533784/399135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104185, 7426, 'A Infância de Romeu e Julieta S01 E311', 'http://sinalprivado.info:80/series/1533784/1533784/413379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104186, 7426, 'A Infância de Romeu e Julieta S01 E312', 'http://sinalprivado.info:80/series/1533784/1533784/413380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104187, 7426, 'A Infância de Romeu e Julieta S01 E313', 'http://sinalprivado.info:80/series/1533784/1533784/413381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104188, 7426, 'A Infância de Romeu e Julieta S01 E314', 'http://sinalprivado.info:80/series/1533784/1533784/413382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104189, 7426, 'A Infância de Romeu e Julieta S01 E315', 'http://sinalprivado.info:80/series/1533784/1533784/413383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104190, 7426, 'A Infância de Romeu e Julieta S01 E316', 'http://sinalprivado.info:80/series/1533784/1533784/413384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104191, 7426, 'A Infância de Romeu e Julieta S01 E317', 'http://sinalprivado.info:80/series/1533784/1533784/413385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104192, 7426, 'A Infância de Romeu e Julieta S01 E318', 'http://sinalprivado.info:80/series/1533784/1533784/413386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104193, 7426, 'A Infância de Romeu e Julieta S01 E319', 'http://sinalprivado.info:80/series/1533784/1533784/413387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104194, 7426, 'A Infância de Romeu e Julieta S01 E320', 'http://sinalprivado.info:80/series/1533784/1533784/413388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104195, 7426, 'A Infância de Romeu e Julieta S01 E321', 'http://sinalprivado.info:80/series/1533784/1533784/428321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104196, 7426, 'A Infância de Romeu e Julieta S01 E322', 'http://sinalprivado.info:80/series/1533784/1533784/428322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104197, 7426, 'A Infância de Romeu e Julieta S01 E323', 'http://sinalprivado.info:80/series/1533784/1533784/428323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104198, 7426, 'A Infância de Romeu e Julieta S01 E324', 'http://sinalprivado.info:80/series/1533784/1533784/428324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104199, 7426, 'A Infância de Romeu e Julieta S01 E325', 'http://sinalprivado.info:80/series/1533784/1533784/428325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104200, 7426, 'A Infância de Romeu e Julieta S01 E326', 'http://sinalprivado.info:80/series/1533784/1533784/428326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104201, 7426, 'A Infância de Romeu e Julieta S01 E327', 'http://sinalprivado.info:80/series/1533784/1533784/428327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104202, 7426, 'A Infância de Romeu e Julieta S01 E328', 'http://sinalprivado.info:80/series/1533784/1533784/428328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104203, 7426, 'A Infância de Romeu e Julieta S01 E329', 'http://sinalprivado.info:80/series/1533784/1533784/428329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104204, 7426, 'A Infância de Romeu e Julieta S01 E330', 'http://sinalprivado.info:80/series/1533784/1533784/428330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104205, 7426, 'A Infância de Romeu e Julieta S01 E331', 'http://sinalprivado.info:80/series/1533784/1533784/428331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104206, 7426, 'A Infância de Romeu e Julieta S01 E332', 'http://sinalprivado.info:80/series/1533784/1533784/458588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104207, 7426, 'A Infância de Romeu e Julieta S01 E333', 'http://sinalprivado.info:80/series/1533784/1533784/458589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kW7gbPpzJnhxKJWeYAENnwTdOaU.jpg'),
(104208, 7427, 'Agentes do FBI S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eQgLPpp8UGNTPLxeLZic5TBBXrf.jpg'),
(104209, 7427, 'Agentes do FBI S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A1Cf1rW3wjP3QmvX5yLmkCNMDGG.jpg'),
(104210, 7427, 'Agentes do FBI S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220163.mp4', 'http://image.tmdb.org/t/p/w1280/psMGHkzoLztt8COoYKAi3kZ0qgm.jpg'),
(104211, 7427, 'Agentes do FBI S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220164.mp4', 'http://image.tmdb.org/t/p/w1280/qQw1zJW3bUlPSc3SfJGEHaqsaYX.jpg'),
(104212, 7427, 'Agentes do FBI S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220165.mp4', 'http://image.tmdb.org/t/p/w1280/cmi3qeM9NzkUXEP2LCjUEDMwBJU.jpg'),
(104213, 7427, 'Agentes do FBI S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220166.mp4', 'http://image.tmdb.org/t/p/w1280/dc5KuwLnTF7IqVVCbEAK0Kp47LI.jpg'),
(104214, 7427, 'Agentes do FBI S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220167.mp4', 'http://image.tmdb.org/t/p/w1280/c0x23IggvhFm24oOnKTSaozvb2g.jpg'),
(104215, 7427, 'Agentes do FBI S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220168.mp4', 'http://image.tmdb.org/t/p/w1280/j99i1qGvaD8NJUyWiMWatceL0bT.jpg'),
(104216, 7428, 'As Irmãs Culpo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iLxNLSoaAhnDHFUeOyXJQaQUnXp.jpg'),
(104217, 7428, 'As Irmãs Culpo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iLxNLSoaAhnDHFUeOyXJQaQUnXp.jpg'),
(104218, 7428, 'As Irmãs Culpo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iLxNLSoaAhnDHFUeOyXJQaQUnXp.jpg'),
(104219, 7428, 'As Irmãs Culpo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iLxNLSoaAhnDHFUeOyXJQaQUnXp.jpg'),
(104220, 7428, 'As Irmãs Culpo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iLxNLSoaAhnDHFUeOyXJQaQUnXp.jpg'),
(104221, 7428, 'As Irmãs Culpo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iLxNLSoaAhnDHFUeOyXJQaQUnXp.jpg'),
(104222, 7429, 'Black Knight S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qFHWQ2KqF4LEgChX0i2DE2ZlINM.jpg'),
(104223, 7429, 'Black Knight S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d8jXZyuAzEL5ND2fGIFFZAREMiF.jpg'),
(104224, 7429, 'Black Knight S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qtI9Yx0NIPzZMq63TC4bto32Mjt.jpg'),
(104225, 7429, 'Black Knight S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t663CRRsW4qOSpUeRV0CgDvYLu3.jpg'),
(104226, 7429, 'Black Knight S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gRd8l57De30C9QV4lV2gIo8fAYV.jpg'),
(104227, 7429, 'Black Knight S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/npYn0sTj0KAzBv4U9UmIAL9KSW9.jpg'),
(104228, 7430, 'Dance Brothers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c5eJeXfhjKSWhsAXt2EhC7TGmhY.jpg'),
(104229, 7430, 'Dance Brothers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rNhQe6XFHosASjVk2Pis2IAELHS.jpg'),
(104230, 7430, 'Dance Brothers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6k3Rx2oDjrQHxbTSCuq4p2Ik5lY.jpg'),
(104231, 7430, 'Dance Brothers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7kZWm9mdz0dC3sAEQSJ5551PdtJ.jpg'),
(104232, 7430, 'Dance Brothers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/arPQolMZJqhwSQtwbqN6orKVn74.jpg'),
(104233, 7430, 'Dance Brothers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gdsj01EQjFm2HMWYGAafaxDHp4z.jpg'),
(104234, 7430, 'Dance Brothers S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/M6IcNCW3WOB3AeQvFPyvl2r412.jpg'),
(104235, 7430, 'Dance Brothers S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6rJYE05C1L6ZTPO9YllqdOMwEST.jpg'),
(104236, 7430, 'Dance Brothers S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/210125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lxZX0h6aV9kEWGt1cYX0jwtyxnv.jpg'),
(104237, 7430, 'Dance Brothers S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/210126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oIhRoaUQbxt3DqzGDERNs1f5n2s.jpg'),
(104238, 7431, 'Dois Tempos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2GFTkeiFgE3gBx8zV6VaseyeB93.jpg'),
(104239, 7431, 'Dois Tempos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8tmXjVkqcZiAkS9U0Dooqsn1VPF.jpg'),
(104240, 7431, 'Dois Tempos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5m4WuxFzZK1CTFDDEHphzwIPG7b.jpg'),
(104241, 7431, 'Dois Tempos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7pCrKOPcnwmOWnAnfZCuAJcud78.jpg'),
(104242, 7431, 'Dois Tempos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/210113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wVSHdRmPSMJ7IGvhlSl487qDmpF.jpg'),
(104243, 7431, 'Dois Tempos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/210114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1v49qpNmxBWqXB9Hae0mRvJDlYU.jpg'),
(104244, 7431, 'Dois Tempos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/210115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJTV7v8bUneAwCMrQ0HgzLEk4ol.jpg'),
(104245, 7431, 'Dois Tempos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/210116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ziarCiLW0fhJKM85YMq2AnxqiBm.jpg'),
(104246, 7432, 'Lambert vs. Lambert: Só por Cima de seu Cadáver S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/210105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iYwRpg9uOAilzqtfYQ4wzfqwB4r.jpg'),
(104247, 7432, 'Lambert vs. Lambert: Só por Cima de seu Cadáver S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/210106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Z9FHQgr7nN3HasF9kt1E4LFfMP.jpg'),
(104248, 7432, 'Lambert vs. Lambert: Só por Cima de seu Cadáver S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/210107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rjwYzSLnIgiP5HwfcoGQI7AGcpo.jpg'),
(104249, 7432, 'Lambert vs. Lambert: Só por Cima de seu Cadáver S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/210108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3XRpZFo57mfZ8NKMqJNIF0lbO8.jpg'),
(104250, 7433, 'Busca Imediata: Pessoas Desaparecidas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sc9oCRqpO2vCVSIyomz3S9WogXG.jpg'),
(104251, 7433, 'Busca Imediata: Pessoas Desaparecidas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sNH2CbWXr3OQuu3gWxbNQHm2UyF.jpg'),
(104252, 7433, 'Busca Imediata: Pessoas Desaparecidas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6peILB5EfWo2mADKZS06rmernmW.jpg'),
(104253, 7433, 'Busca Imediata: Pessoas Desaparecidas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zFHvkPpvP5TzBYdYJ9gK6kDDGpQ.jpg'),
(104254, 7434, 'Mulligan S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x00Ta90IhrMRRnkkQ93fss70OH9.jpg'),
(104255, 7434, 'Mulligan S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7uge0wIPyvdomY76M9bDFKc37do.jpg'),
(104256, 7434, 'Mulligan S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xvMN2SbeSc02lW9ePMWj1JIgAeW.jpg'),
(104257, 7434, 'Mulligan S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v4yvxQnxWsFAgVsxVDYT44k8vrf.jpg'),
(104258, 7434, 'Mulligan S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/azLpTSY7eLRsrYCpjrbZnjOJpym.jpg'),
(104259, 7434, 'Mulligan S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBGAsDI3uUQhOJ3zm9mnPFwrBpJ.jpg'),
(104260, 7434, 'Mulligan S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yGA4GImbnNkRpaCKGqJ3yq3VBwT.jpg'),
(104261, 7434, 'Mulligan S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pxcZyLXeTX7h9OaCaagJMUXZjjM.jpg'),
(104262, 7434, 'Mulligan S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24WioJmOZFb2Ln9WNWu9gkEXGiG.jpg'),
(104263, 7434, 'Mulligan S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/99N4TbZXx85PYeilj7oVa4CZNMn.jpg'),
(104264, 7435, 'Mulligan S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/360594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t4jMaK7u5S4p5sEW76GmBNQfE90.jpg'),
(104265, 7435, 'Mulligan S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/360595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t4jMaK7u5S4p5sEW76GmBNQfE90.jpg'),
(104266, 7435, 'Mulligan S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/360596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t4jMaK7u5S4p5sEW76GmBNQfE90.jpg'),
(104267, 7435, 'Mulligan S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/360597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t4jMaK7u5S4p5sEW76GmBNQfE90.jpg'),
(104268, 7435, 'Mulligan S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/360598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t4jMaK7u5S4p5sEW76GmBNQfE90.jpg'),
(104269, 7435, 'Mulligan S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/360599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t4jMaK7u5S4p5sEW76GmBNQfE90.jpg'),
(104270, 7435, 'Mulligan S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/360600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t4jMaK7u5S4p5sEW76GmBNQfE90.jpg'),
(104271, 7435, 'Mulligan S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/360601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t4jMaK7u5S4p5sEW76GmBNQfE90.jpg'),
(104272, 7435, 'Mulligan S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/360602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t4jMaK7u5S4p5sEW76GmBNQfE90.jpg'),
(104273, 7435, 'Mulligan S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/360603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t4jMaK7u5S4p5sEW76GmBNQfE90.jpg'),
(104274, 7436, 'Muppets e o Caos Elétrico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AcL6hMinLZpIG59kWjlWZSA3Dtf.jpg'),
(104275, 7436, 'Muppets e o Caos Elétrico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v2Mz889HY2uRRWcFFjsEvqG6LTQ.jpg'),
(104276, 7436, 'Muppets e o Caos Elétrico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aVeFuq8qsnoQSbad5Noe9Zua6gr.jpg'),
(104277, 7436, 'Muppets e o Caos Elétrico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzRWLL6UPSdBEesGN3FG5lIOxCQ.jpg'),
(104278, 7436, 'Muppets e o Caos Elétrico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xHkIeWoe8RNUljRH0JCJLKvdF4U.jpg'),
(104279, 7436, 'Muppets e o Caos Elétrico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wdqPu24tFdgyy4OVo9UYfuXnHsf.jpg'),
(104280, 7436, 'Muppets e o Caos Elétrico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g6j1hh61HCg74YvpTkZzot41Ee6.jpg'),
(104281, 7436, 'Muppets e o Caos Elétrico S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/61JsSRjG0z2Xzef1Qt8FwAPSDBY.jpg'),
(104282, 7436, 'Muppets e o Caos Elétrico S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5h5DhirnQnAOGCnmVoSxLKMpPND.jpg'),
(104283, 7436, 'Muppets e o Caos Elétrico S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vONOzslF8BkZZfMGovGbHxNycoz.jpg'),
(104284, 7437, 'QUINTUPLICOU S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7osEkb7nIMpELoLotQl5qYWfnsa.jpg'),
(104285, 7437, 'QUINTUPLICOU S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tbhNSLXOr0ShO8o78wy0mV6n8XM.jpg'),
(104286, 7437, 'QUINTUPLICOU S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dfgtYXkGaHIDfAziYojPlwpK0Vt.jpg'),
(104287, 7437, 'QUINTUPLICOU S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9BaSBpE0unyTLGvWWkIJaMPfAM.jpg'),
(104288, 7437, 'QUINTUPLICOU S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nnctPGmBUbx3iscrTyreFP8h8Hf.jpg'),
(104289, 7437, 'QUINTUPLICOU S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mxz0W3C5FA1FgFmzpIg8wpD9iZi.jpg'),
(104290, 7438, 'Rainha Cleópatra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3S0iMO6HHjwUbenhs3MN6RG8EKL.jpg'),
(104291, 7438, 'Rainha Cleópatra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLpVBhkqyRqcFV39J3CUa3fOS1B.jpg'),
(104292, 7438, 'Rainha Cleópatra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m6R446AfZUF4aup1keO7qeN8ZxK.jpg'),
(104293, 7438, 'Rainha Cleópatra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/33oRbzzWd874DcqMFIARIPanqmU.jpg'),
(104294, 7439, 'Salvando Reformas com Jasmine Roth S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104295, 7439, 'Salvando Reformas com Jasmine Roth S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104296, 7439, 'Salvando Reformas com Jasmine Roth S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104297, 7439, 'Salvando Reformas com Jasmine Roth S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104298, 7439, 'Salvando Reformas com Jasmine Roth S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104299, 7439, 'Salvando Reformas com Jasmine Roth S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104300, 7440, 'Salvando Reformas com Jasmine Roth S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104301, 7440, 'Salvando Reformas com Jasmine Roth S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104302, 7440, 'Salvando Reformas com Jasmine Roth S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104303, 7440, 'Salvando Reformas com Jasmine Roth S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104304, 7440, 'Salvando Reformas com Jasmine Roth S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104305, 7440, 'Salvando Reformas com Jasmine Roth S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104306, 7440, 'Salvando Reformas com Jasmine Roth S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104307, 7440, 'Salvando Reformas com Jasmine Roth S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104308, 7441, 'Salvando Reformas com Jasmine Roth S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104309, 7441, 'Salvando Reformas com Jasmine Roth S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104310, 7441, 'Salvando Reformas com Jasmine Roth S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104311, 7441, 'Salvando Reformas com Jasmine Roth S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104312, 7441, 'Salvando Reformas com Jasmine Roth S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104313, 7441, 'Salvando Reformas com Jasmine Roth S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5qM09qWH8tV9pQ9hMb5cJTsdqH0.jpg'),
(104314, 7441, 'Salvando Reformas com Jasmine Roth S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104315, 7441, 'Salvando Reformas com Jasmine Roth S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104316, 7441, 'Salvando Reformas com Jasmine Roth S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104317, 7441, 'Salvando Reformas com Jasmine Roth S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwOAHPu22rmnID9b7z2TcqjTxYJ.jpg'),
(104318, 7442, 'Vanda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c1JByGHJQQ1gT10TgtuGbTeMIbP.jpg'),
(104319, 7442, 'Vanda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219382.mp4', 'http://image.tmdb.org/t/p/w1280/8w3WpjY8Wz288mqry0JKsPW09u9.jpg'),
(104320, 7442, 'Vanda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219383.mp4', 'http://image.tmdb.org/t/p/w1280/fgHse8btjFn8jKaK8gBcvfWSy5Z.jpg'),
(104321, 7442, 'Vanda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219384.mp4', 'http://image.tmdb.org/t/p/w1280/wPpeCrZeTdqushVUbHgAcNprG1Y.jpg'),
(104322, 7442, 'Vanda S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219385.mp4', 'http://image.tmdb.org/t/p/w1280/1tImfsoPnbjjHFraQP5TNsQId9T.jpg'),
(104323, 7442, 'Vanda S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aNsPraDR9Yq7xeK5K4jkPc6gnis.jpg'),
(104324, 7442, 'Vanda S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219387.mp4', 'http://image.tmdb.org/t/p/w1280/6QSiyX7JJukCVfRk5cXehNJiZPc.jpg'),
(104325, 7442, 'Vanda S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219388.mp4', 'http://image.tmdb.org/t/p/w1280/mVuwhHLSmc07Z2SW2ZmgMLeVv3A.jpg'),
(104326, 7443, 'Vencer na Vida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g8tmXDltgyTmEDmarEv79xYZESz.jpg'),
(104327, 7443, 'Vencer na Vida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/raXPt9FPtebLJr2qM2bao3FIVnh.jpg'),
(104328, 7443, 'Vencer na Vida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6GGEXW8vzycCwRYFsKyGvTaKcOC.jpg'),
(104329, 7443, 'Vencer na Vida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6GGEXW8vzycCwRYFsKyGvTaKcOC.jpg'),
(104330, 7444, 'Vencer na Vida S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/379199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6GGEXW8vzycCwRYFsKyGvTaKcOC.jpg'),
(104331, 7444, 'Vencer na Vida S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/379200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6GGEXW8vzycCwRYFsKyGvTaKcOC.jpg'),
(104332, 7444, 'Vencer na Vida S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/379201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6GGEXW8vzycCwRYFsKyGvTaKcOC.jpg'),
(104333, 7444, 'Vencer na Vida S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/379202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6GGEXW8vzycCwRYFsKyGvTaKcOC.jpg'),
(104334, 7444, 'Vencer na Vida S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/379203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6GGEXW8vzycCwRYFsKyGvTaKcOC.jpg'),
(104335, 7444, 'Vencer na Vida S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/379204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6GGEXW8vzycCwRYFsKyGvTaKcOC.jpg'),
(104336, 7445, 'Vencer na Vida S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/708252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6GGEXW8vzycCwRYFsKyGvTaKcOC.jpg'),
(104337, 7445, 'Vencer na Vida S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/708253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6GGEXW8vzycCwRYFsKyGvTaKcOC.jpg'),
(104338, 7445, 'Vencer na Vida S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/708254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6GGEXW8vzycCwRYFsKyGvTaKcOC.jpg'),
(104339, 7445, 'Vencer na Vida S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/708255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6GGEXW8vzycCwRYFsKyGvTaKcOC.jpg'),
(104340, 7446, 'Vestidas de Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i5VO57PgCa2Bh3NRGhqUrz4xRiS.jpg'),
(104341, 7446, 'Vestidas de Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i5VO57PgCa2Bh3NRGhqUrz4xRiS.jpg'),
(104342, 7446, 'Vestidas de Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i5VO57PgCa2Bh3NRGhqUrz4xRiS.jpg'),
(104343, 7446, 'Vestidas de Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i5VO57PgCa2Bh3NRGhqUrz4xRiS.jpg'),
(104344, 7446, 'Vestidas de Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i5VO57PgCa2Bh3NRGhqUrz4xRiS.jpg'),
(104345, 7446, 'Vestidas de Amor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i5VO57PgCa2Bh3NRGhqUrz4xRiS.jpg'),
(104346, 7447, 'A Internet do Mal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t09cSh7u9eIyCwuE3vTdsDbFuW.jpg'),
(104347, 7447, 'A Internet do Mal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aq3oLGa2MprkyxhriKDg3ig5s52.jpg'),
(104348, 7447, 'A Internet do Mal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5KG2WZ4HOhMwjBvwFT7SyYnrBEe.jpg'),
(104349, 7447, 'A Internet do Mal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rZNRcc58maHTASJffyNVWGh6Vp.jpg'),
(104350, 7447, 'A Internet do Mal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z7nmo8PS1uhebyUmTI7OSTb8A3b.jpg'),
(104351, 7448, 'Cena do Crime: Arquivos Confidenciais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tecIdiyex66qjbtWTlOnmiYJQL.jpg'),
(104352, 7448, 'Cena do Crime: Arquivos Confidenciais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLyylmpAuPvsbCaSI0btKV1MrFD.jpg'),
(104353, 7448, 'Cena do Crime: Arquivos Confidenciais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8laHs86uABdn3ipj2Bkm2rqvt8Y.jpg'),
(104354, 7448, 'Cena do Crime: Arquivos Confidenciais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aLUniS1HvXFAVxSqxm1F3VUW3g8.jpg'),
(104355, 7448, 'Cena do Crime: Arquivos Confidenciais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v0thRmm2VyRpaqWgbQoBrDyVUQ.jpg'),
(104356, 7448, 'Cena do Crime: Arquivos Confidenciais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9j7meHoUFWqd4LNrK1Eyh9PjwJ0.jpg'),
(104357, 7449, 'Cena do Crime: Arquivos Confidenciais S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/310629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jpm7z79oZcWlHY5B2fk3oFdzrG.jpg'),
(104358, 7449, 'Cena do Crime: Arquivos Confidenciais S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/310630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jpm7z79oZcWlHY5B2fk3oFdzrG.jpg'),
(104359, 7449, 'Cena do Crime: Arquivos Confidenciais S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/310631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jpm7z79oZcWlHY5B2fk3oFdzrG.jpg'),
(104360, 7449, 'Cena do Crime: Arquivos Confidenciais S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/310632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jpm7z79oZcWlHY5B2fk3oFdzrG.jpg'),
(104361, 7449, 'Cena do Crime: Arquivos Confidenciais S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/319898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jpm7z79oZcWlHY5B2fk3oFdzrG.jpg'),
(104362, 7449, 'Cena do Crime: Arquivos Confidenciais S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/326230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jpm7z79oZcWlHY5B2fk3oFdzrG.jpg'),
(104363, 7449, 'Cena do Crime: Arquivos Confidenciais S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/360929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jpm7z79oZcWlHY5B2fk3oFdzrG.jpg'),
(104364, 7449, 'Cena do Crime: Arquivos Confidenciais S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/360930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jpm7z79oZcWlHY5B2fk3oFdzrG.jpg'),
(104365, 7450, 'Cidade em Chamas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A9G0cI4E2YqqGf5qcYzTlZpoCvo.jpg'),
(104366, 7450, 'Cidade em Chamas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jfB3cYt1HqIlc97oAFaPDkzZo8B.jpg'),
(104367, 7450, 'Cidade em Chamas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sh9jzvAcuRtBugMoWVNHfsX6a4m.jpg'),
(104368, 7450, 'Cidade em Chamas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220585.mp4', 'http://image.tmdb.org/t/p/w1280/5GOBh451KxzcNauEGwy56E97HjP.jpg'),
(104369, 7450, 'Cidade em Chamas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220586.mp4', 'http://image.tmdb.org/t/p/w1280/psZiPb61b06JMc5fronOkvO4MbE.jpg'),
(104370, 7450, 'Cidade em Chamas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220587.mp4', 'http://image.tmdb.org/t/p/w1280/uM8x9zyBFsLdbplP4ChEyV0LzVh.jpg'),
(104371, 7450, 'Cidade em Chamas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220588.mp4', 'http://image.tmdb.org/t/p/w1280/9wIFKeqq9MGK8YuqZZYePrwSAZE.jpg'),
(104372, 7450, 'Cidade em Chamas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2FAdkFiA9IxsGQevgLnxmECrmO2.jpg'),
(104373, 7451, 'Espíritos na Escola S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mWrcvysgwLKzF1B53AZcoErlx9k.jpg'),
(104374, 7451, 'Espíritos na Escola S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nw2Vr7peqdkYCsRYotunZtnLfbg.jpg'),
(104375, 7451, 'Espíritos na Escola S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pMfry31QeZpQmkGlst2v3oDxO9r.jpg'),
(104376, 7451, 'Espíritos na Escola S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220544.mp4', 'http://image.tmdb.org/t/p/w1280/fOaQ0kWG2Oi0jCOJ2pEsZEr26T6.jpg'),
(104377, 7451, 'Espíritos na Escola S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220545.mp4', 'http://image.tmdb.org/t/p/w1280/b6QjIHr7hrPFeAGXWSGQSS61Xno.jpg'),
(104378, 7451, 'Espíritos na Escola S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220546.mp4', 'http://image.tmdb.org/t/p/w1280/lMNVaqchqyA6Us4P9uxVOXyysyD.jpg'),
(104379, 7451, 'Espíritos na Escola S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220547.mp4', 'http://image.tmdb.org/t/p/w1280/pvXOJU3JSR5rUt6dqhChwFrDyPY.jpg'),
(104380, 7451, 'Espíritos na Escola S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eb7ZJYZjed1bBQ8a4aMDwp5nvjF.jpg'),
(104381, 7452, 'Espíritos na Escola S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/679813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eb7ZJYZjed1bBQ8a4aMDwp5nvjF.jpg'),
(104382, 7452, 'Espíritos na Escola S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/679814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eb7ZJYZjed1bBQ8a4aMDwp5nvjF.jpg'),
(104383, 7452, 'Espíritos na Escola S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/679815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eb7ZJYZjed1bBQ8a4aMDwp5nvjF.jpg'),
(104384, 7452, 'Espíritos na Escola S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/687677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eb7ZJYZjed1bBQ8a4aMDwp5nvjF.jpg'),
(104385, 7452, 'Espíritos na Escola S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/696201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eb7ZJYZjed1bBQ8a4aMDwp5nvjF.jpg'),
(104386, 7452, 'Espíritos na Escola S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/702011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eb7ZJYZjed1bBQ8a4aMDwp5nvjF.jpg'),
(104387, 7452, 'Espíritos na Escola S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/707876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eb7ZJYZjed1bBQ8a4aMDwp5nvjF.jpg'),
(104388, 7452, 'Espíritos na Escola S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/718572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eb7ZJYZjed1bBQ8a4aMDwp5nvjF.jpg'),
(104389, 7453, 'Fired on Mars S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZApkATILqYuQjiPeWsH1DIVlnC.jpg'),
(104390, 7453, 'Fired on Mars S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t5RjsTxPjpZfN2OpuAyrvNFv1AT.jpg'),
(104391, 7453, 'Fired on Mars S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rHhjPqhWdB9DBlbXON8YbOuURXu.jpg'),
(104392, 7453, 'Fired on Mars S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tLp3BMCTl0k1nj6LIKzuWFIli8H.jpg'),
(104393, 7453, 'Fired on Mars S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n05InyMqWGxqbBdXJhpPRCkB5q6.jpg'),
(104394, 7453, 'Fired on Mars S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tFtXAiK8Jm8smoz3yt9ZlHyUoUy.jpg'),
(104395, 7453, 'Fired on Mars S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mNCICcxo8Gbs4V6E6dlDAHrsDbL.jpg'),
(104396, 7453, 'Fired on Mars S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iqfny9xhO0KnrrHUffvOPcdT2lF.jpg'),
(104397, 7454, 'HIV 40 anos AIDS e Suas Historias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213852.mp4', 'https://i.bj-share.info/18196adb0fd88fc1ecf0cd274f786ec9.jpg'),
(104398, 7454, 'HIV 40 anos AIDS e Suas Historias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213853.mp4', 'https://i.bj-share.info/18196adb0fd88fc1ecf0cd274f786ec9.jpg'),
(104399, 7454, 'HIV 40 anos AIDS e Suas Historias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213854.mp4', 'https://i.bj-share.info/18196adb0fd88fc1ecf0cd274f786ec9.jpg'),
(104400, 7454, 'HIV 40 anos AIDS e Suas Historias S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213855.mp4', 'https://i.bj-share.info/18196adb0fd88fc1ecf0cd274f786ec9.jpg'),
(104401, 7454, 'HIV 40 anos AIDS e Suas Historias S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213856.mp4', 'https://i.bj-share.info/18196adb0fd88fc1ecf0cd274f786ec9.jpg'),
(104402, 7454, 'HIV 40 anos AIDS e Suas Historias S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213857.mp4', 'https://i.bj-share.info/18196adb0fd88fc1ecf0cd274f786ec9.jpg'),
(104403, 7455, 'My Home Hero S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0eeYsM8SXBEPZQibL3uBdDrYta.jpg'),
(104404, 7455, 'My Home Hero S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a4CU0lpWITbdTGEyaJr6zwK0PE7.jpg'),
(104405, 7455, 'My Home Hero S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tw0Bp65ZM2XAcctCjSUkkOMReO0.jpg'),
(104406, 7455, 'My Home Hero S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/PTmDBbTNOqHGAn0pqdSj1ldOZG.jpg'),
(104407, 7455, 'My Home Hero S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223865.mp4', 'http://image.tmdb.org/t/p/w1280/3qEVNqpbZwLf3lKJbkMVXduhFTn.jpg'),
(104408, 7455, 'My Home Hero S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223866.mp4', 'http://image.tmdb.org/t/p/w1280/8YBw1eH9zEOjY8AI63vIhHjYDZr.jpg'),
(104409, 7455, 'My Home Hero S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223867.mp4', 'http://image.tmdb.org/t/p/w1280/ql8MfFujMbtUcvNMlJAvjkqGVVw.jpg'),
(104410, 7455, 'My Home Hero S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223868.mp4', 'http://image.tmdb.org/t/p/w1280/p7carTXZDxh4VBy7rL3FC5bltGl.jpg'),
(104411, 7455, 'My Home Hero S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x6YEVah5vR5mvbkkZAbesPw6bYv.jpg'),
(104412, 7455, 'My Home Hero S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223870.mp4', 'http://image.tmdb.org/t/p/w1280/vqv8rmZLDjWjtuLW6pzLnalGrBK.jpg'),
(104413, 7455, 'My Home Hero S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223871.mp4', 'http://image.tmdb.org/t/p/w1280/enlxp5rI12haje9yw24qsqtoe1m.jpg'),
(104414, 7455, 'My Home Hero S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223872.mp4', 'http://image.tmdb.org/t/p/w1280/6r59JfNCwJeir7o2HhWIgL4OKY0.jpg'),
(104415, 7456, 'O Lado Obscuro da Fama S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hFzG8I5RX1uxmldbZK2Wdzw2GO9.jpg'),
(104416, 7456, 'O Lado Obscuro da Fama S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kUmutS9XEJpggfOtx4YjefWXnWy.jpg'),
(104417, 7456, 'O Lado Obscuro da Fama S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220481.mp4', 'http://image.tmdb.org/t/p/w1280/10gDN5kk3ciYvAfKM8rTqKyJS39.jpg'),
(104418, 7456, 'O Lado Obscuro da Fama S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220482.mp4', 'http://image.tmdb.org/t/p/w1280/2qQRm33LPXAieIdULraiRTT85KV.jpg'),
(104419, 7456, 'O Lado Obscuro da Fama S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220483.mp4', 'http://image.tmdb.org/t/p/w1280/rsbkyBNauPNZHB3M0lNZI8WVGVe.jpg'),
(104420, 7456, 'O Lado Obscuro da Fama S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5IwQNFHgiCVri0BnX5Gplb8BdI.jpg'),
(104421, 7457, 'O Lado Obscuro da Fama S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/460639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5IwQNFHgiCVri0BnX5Gplb8BdI.jpg'),
(104422, 7457, 'O Lado Obscuro da Fama S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/460640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5IwQNFHgiCVri0BnX5Gplb8BdI.jpg'),
(104423, 7457, 'O Lado Obscuro da Fama S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/460641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5IwQNFHgiCVri0BnX5Gplb8BdI.jpg'),
(104424, 7457, 'O Lado Obscuro da Fama S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/460642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5IwQNFHgiCVri0BnX5Gplb8BdI.jpg'),
(104425, 7457, 'O Lado Obscuro da Fama S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/467094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5IwQNFHgiCVri0BnX5Gplb8BdI.jpg'),
(104426, 7457, 'O Lado Obscuro da Fama S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/473900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5IwQNFHgiCVri0BnX5Gplb8BdI.jpg'),
(104427, 7457, 'O Lado Obscuro da Fama S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/477312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5IwQNFHgiCVri0BnX5Gplb8BdI.jpg'),
(104428, 7457, 'O Lado Obscuro da Fama S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/488510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5IwQNFHgiCVri0BnX5Gplb8BdI.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(104429, 7458, 'O Lado Obscuro da Fama S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/765561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5IwQNFHgiCVri0BnX5Gplb8BdI.jpg'),
(104430, 7458, 'O Lado Obscuro da Fama S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/765562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5IwQNFHgiCVri0BnX5Gplb8BdI.jpg'),
(104431, 7458, 'O Lado Obscuro da Fama S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/765563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5IwQNFHgiCVri0BnX5Gplb8BdI.jpg'),
(104432, 7458, 'O Lado Obscuro da Fama S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/765564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5IwQNFHgiCVri0BnX5Gplb8BdI.jpg'),
(104433, 7458, 'O Lado Obscuro da Fama S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/765565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5IwQNFHgiCVri0BnX5Gplb8BdI.jpg'),
(104434, 7458, 'O Lado Obscuro da Fama S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/765566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5IwQNFHgiCVri0BnX5Gplb8BdI.jpg'),
(104435, 7458, 'O Lado Obscuro da Fama S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/765567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5IwQNFHgiCVri0BnX5Gplb8BdI.jpg'),
(104436, 7458, 'O Lado Obscuro da Fama S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/765568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5IwQNFHgiCVri0BnX5Gplb8BdI.jpg'),
(104437, 7459, 'The Good Bad Mother S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pQCoSxeFSfmOgfOskQ8YREPfE4c.jpg'),
(104438, 7459, 'The Good Bad Mother S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7s2zr1RbaqD1cBtXjGvNmiDvrhA.jpg'),
(104439, 7459, 'The Good Bad Mother S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219907.mp4', 'http://image.tmdb.org/t/p/w1280/1Lr8VIXxRlFpRoHn2wJdhO6DlsE.jpg'),
(104440, 7459, 'The Good Bad Mother S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219908.mp4', 'http://image.tmdb.org/t/p/w1280/gUX5MfAE8juks7Sl76PyIfLotxW.jpg'),
(104441, 7459, 'The Good Bad Mother S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219909.mp4', 'http://image.tmdb.org/t/p/w1280/eOL6Ejv14hvQO4mBmLJp8FiJquy.jpg'),
(104442, 7459, 'The Good Bad Mother S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219910.mp4', 'http://image.tmdb.org/t/p/w1280/6mTPgTnWYVr70QSBP8CtPj9AAi8.jpg'),
(104443, 7459, 'The Good Bad Mother S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219911.mp4', 'http://image.tmdb.org/t/p/w1280/n1ueQ1u3r32OUET14qi0MisOhLN.jpg'),
(104444, 7459, 'The Good Bad Mother S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219912.mp4', 'http://image.tmdb.org/t/p/w1280/9XtAbdqg0cV9dVWrT7kndI6AqIW.jpg'),
(104445, 7459, 'The Good Bad Mother S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o8h8BJz85BNI6g6ty47jbpEDAiK.jpg'),
(104446, 7459, 'The Good Bad Mother S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o8h8BJz85BNI6g6ty47jbpEDAiK.jpg'),
(104447, 7459, 'The Good Bad Mother S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219915.mp4', 'http://image.tmdb.org/t/p/w1280/vdSfVjcJxe0ApTvNwqOMHXHiqGd.jpg'),
(104448, 7459, 'The Good Bad Mother S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219916.mp4', 'http://image.tmdb.org/t/p/w1280/cfltluE9akREKmi2lwR1CrZxyEU.jpg'),
(104449, 7459, 'The Good Bad Mother S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219917.mp4', 'http://image.tmdb.org/t/p/w1280/dDOzQa4wxxkCfGtJlcGe7kBd0hY.jpg'),
(104450, 7459, 'The Good Bad Mother S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/219918.mp4', 'http://image.tmdb.org/t/p/w1280/vMZXZr1Nzqd2xvV47wig48M6M2q.jpg'),
(104451, 7460, 'Uma Vizinha de Outro Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSEtViXIaFbbwpJjXx9aTxlcJrM.jpg'),
(104452, 7460, 'Uma Vizinha de Outro Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJr0vytrlBcgdrIU3jl5VYa6eQr.jpg'),
(104453, 7460, 'Uma Vizinha de Outro Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x4I5Ss7g7wEIi3lVUTAoDdoGnhG.jpg'),
(104454, 7460, 'Uma Vizinha de Outro Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223255.mp4', 'http://image.tmdb.org/t/p/w1280/aZhECnrmI5i4gWTEFdogKPKDxfD.jpg'),
(104455, 7460, 'Uma Vizinha de Outro Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223256.mp4', 'http://image.tmdb.org/t/p/w1280/fCmJArpyNvj4OmWG5F4kpBCDw6q.jpg'),
(104456, 7460, 'Uma Vizinha de Outro Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/95SpmT6Ti3wVtIyKELKfHDkmA64.jpg'),
(104457, 7460, 'Uma Vizinha de Outro Mundo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bhcWtUq3SuQ8jbOfvYsO3iKX5H1.jpg'),
(104458, 7460, 'Uma Vizinha de Outro Mundo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/55X00rRZuU8X2mxwXsNtqqGXjyS.jpg'),
(104459, 7460, 'Uma Vizinha de Outro Mundo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1yeeWJACQ96vDFRgN7L8vv6sUcz.jpg'),
(104460, 7460, 'Uma Vizinha de Outro Mundo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ua6ICaL3g3KklcctBX1ghEpNmc.jpg'),
(104461, 7460, 'Uma Vizinha de Outro Mundo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y7nMHYbbpTXVHWEWGoxq6Sk1R4q.jpg'),
(104462, 7460, 'Uma Vizinha de Outro Mundo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kgZWxqRj7euxnNE3QEF15K3sh45.jpg'),
(104463, 7461, 'Mr Inbetween S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xd4e8gBXmggPueBw0nyU2WIB8Wl.jpg'),
(104464, 7461, 'Mr Inbetween S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dcNIqvdqkNKLrlLyJt4AbaPKblY.jpg'),
(104465, 7461, 'Mr Inbetween S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nIwasUmnHpdd96V9qu2wGfAO7P2.jpg'),
(104466, 7461, 'Mr Inbetween S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dD9IsXPxM54GbBG5YGXS73g6G8v.jpg'),
(104467, 7461, 'Mr Inbetween S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fcoVlsHV2DHNKtUcp3itiVQ0N0X.jpg'),
(104468, 7461, 'Mr Inbetween S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fLmVZrjme7ggBnNpJeEHGRHmKJH.jpg'),
(104469, 7462, 'Mr Inbetween S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zAkJQZpnQM6J2LawB2aURQSYkrT.jpg'),
(104470, 7462, 'Mr Inbetween S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lbsiYVzJYmUCjb6P1kfyHNWM8vZ.jpg'),
(104471, 7462, 'Mr Inbetween S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJl32rnv8rJNDBCCezpvc2nFF4K.jpg'),
(104472, 7462, 'Mr Inbetween S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qOlr7FXvi315lGtnJjOboWCUtL3.jpg'),
(104473, 7462, 'Mr Inbetween S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pzLxj8WXTFVblJQ05LhEsHoy05f.jpg'),
(104474, 7462, 'Mr Inbetween S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9VYTBSW4qhUWNIb1OkXC7AoOiMa.jpg'),
(104475, 7462, 'Mr Inbetween S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wvjN4D9wBXgjDCSYYJt5Vy1WaB6.jpg'),
(104476, 7462, 'Mr Inbetween S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dT4JGQg7IP55zW3sxrJd0HzymjJ.jpg'),
(104477, 7462, 'Mr Inbetween S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qHnk9tAswsgzSdxz5aEpHhQ7yUf.jpg'),
(104478, 7462, 'Mr Inbetween S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5bMMaFWMoqNfKR6TIFCk5h9RxZX.jpg'),
(104479, 7462, 'Mr Inbetween S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/213693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/au6orQQehIYWGzzcsoihZfR7JkS.jpg'),
(104480, 7463, 'Mr Inbetween S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9sUPcf6gEzKv4SaxZcSMzYnexYA.jpg'),
(104481, 7463, 'Mr Inbetween S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rKtDT4fdapfbGoFVIAQUKT0rDSE.jpg'),
(104482, 7463, 'Mr Inbetween S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jSbFeO9fY1AfC2SHc3W0YYCQfhy.jpg'),
(104483, 7463, 'Mr Inbetween S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9YJkDj1Tqv0YBR1tFrDY0x7b24x.jpg'),
(104484, 7463, 'Mr Inbetween S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nC42wMSdk3961MlTKuZE3ugfZpz.jpg'),
(104485, 7463, 'Mr Inbetween S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tGLCya3M2TzfwgoI1ph630ju7ih.jpg'),
(104486, 7463, 'Mr Inbetween S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xoYbrg9qx4eggK7OiBFWBJYbQLX.jpg'),
(104487, 7463, 'Mr Inbetween S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/SbYkdu8w7FEKx88Y2P5tIR8RwW.jpg'),
(104488, 7463, 'Mr Inbetween S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dHa9FM6BPnOdbIIqVMAzR2IhOe4.jpg'),
(104489, 7464, 'Fullmetal Alchemist: Brotherhood S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9OQdBV5ca27OhfoCWKjJT4Pq0AB.jpg'),
(104490, 7464, 'Fullmetal Alchemist: Brotherhood S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7nj2xLJvjNecLnftoCSmC8QTk6t.jpg'),
(104491, 7464, 'Fullmetal Alchemist: Brotherhood S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4V97HpXyziLoT5v8ByaT1AXo5vc.jpg'),
(104492, 7464, 'Fullmetal Alchemist: Brotherhood S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gK9PNwrvLBcVMO7OIaW5nTXRgZS.jpg'),
(104493, 7464, 'Fullmetal Alchemist: Brotherhood S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/feiw4Fe4sVQU7yUXqLEem7qK1rR.jpg'),
(104494, 7464, 'Fullmetal Alchemist: Brotherhood S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pjgpBrj4dJTAKobjgjjpfqRTU6J.jpg'),
(104495, 7464, 'Fullmetal Alchemist: Brotherhood S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vS7vHBoDDP5ldnggatjHyK4DbPb.jpg'),
(104496, 7464, 'Fullmetal Alchemist: Brotherhood S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pg7V7aRpvv1z9H63OrMBn0po6zL.jpg'),
(104497, 7464, 'Fullmetal Alchemist: Brotherhood S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zW9qMXytsyDUZlcoVNh5RAYINTZ.jpg'),
(104498, 7464, 'Fullmetal Alchemist: Brotherhood S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gDA5XcbEVBTIGSEfArGa2mCz2Kz.jpg'),
(104499, 7464, 'Fullmetal Alchemist: Brotherhood S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/213623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kDxLtWN9ONnVbC2FlzjrZ0XL0mg.jpg'),
(104500, 7464, 'Fullmetal Alchemist: Brotherhood S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/213624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/brYaKIpdCct90vtjilXB9mbn06X.jpg'),
(104501, 7464, 'Fullmetal Alchemist: Brotherhood S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/213625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/utROdhaxJfQPWjMyWiL7O6QdJpi.jpg'),
(104502, 7464, 'Fullmetal Alchemist: Brotherhood S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/213626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZ8xGe6tPufUwpz7zuOMg0fojyC.jpg'),
(104503, 7464, 'Fullmetal Alchemist: Brotherhood S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/213627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mFPJEHgztVMT8ywiDFBetIPPdzf.jpg'),
(104504, 7464, 'Fullmetal Alchemist: Brotherhood S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/213628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hWNUpZRw3WRXaQLKde8EBYDs0ui.jpg'),
(104505, 7464, 'Fullmetal Alchemist: Brotherhood S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/213629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g4gpLYNYgPMSailz3pZ3IsBohBj.jpg'),
(104506, 7464, 'Fullmetal Alchemist: Brotherhood S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/213630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kU4ivjQSJfchbRYY7fjAa4q2aO9.jpg'),
(104507, 7464, 'Fullmetal Alchemist: Brotherhood S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/213631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g9mtvFD7h85USSVs4Ny6TtZL6xy.jpg'),
(104508, 7464, 'Fullmetal Alchemist: Brotherhood S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/213632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqDV7zTLeQpI9yeDqf05dGzoXc0.jpg'),
(104509, 7464, 'Fullmetal Alchemist: Brotherhood S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/213633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fgNidBjqsAc9G0j43IEQefcikbT.jpg'),
(104510, 7464, 'Fullmetal Alchemist: Brotherhood S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/213634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aTvRDaxSWvM5KKxdRdCMJPNdikT.jpg'),
(104511, 7464, 'Fullmetal Alchemist: Brotherhood S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/213635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rDFDNcUNmYIpcHuadoXO05apwos.jpg'),
(104512, 7464, 'Fullmetal Alchemist: Brotherhood S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/213636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uOuxOrhlTWGtpyJRs9J6piWoULV.jpg'),
(104513, 7464, 'Fullmetal Alchemist: Brotherhood S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/213637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sJO5IGaVKYCNZTJPELH9O5IxGjR.jpg'),
(104514, 7464, 'Fullmetal Alchemist: Brotherhood S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/213638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cEWatlR8yxZTGeAV4e9Id2CorYQ.jpg'),
(104515, 7464, 'Fullmetal Alchemist: Brotherhood S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/213639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bfZrYNbKD6WTYOb96WYYrEuNb6z.jpg'),
(104516, 7464, 'Fullmetal Alchemist: Brotherhood S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/213640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2D0O1rXQeKGjY7wB7MUKP1REy1.jpg'),
(104517, 7464, 'Fullmetal Alchemist: Brotherhood S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/213641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFc4zxin9mGkNMTQfukyi4JLeEZ.jpg'),
(104518, 7464, 'Fullmetal Alchemist: Brotherhood S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/213642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1s33QZOZMIp7UkqHKXuC515DazL.jpg'),
(104519, 7464, 'Fullmetal Alchemist: Brotherhood S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/213643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/btRFHxpvplUcqpdo976Mwhzgo9I.jpg'),
(104520, 7464, 'Fullmetal Alchemist: Brotherhood S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/213644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y1N1Qer0nQAHTcKI1P7p7jTyyVf.jpg'),
(104521, 7464, 'Fullmetal Alchemist: Brotherhood S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/213645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7bc4bYOrcSUbqyGHwv6QYnv97Ci.jpg'),
(104522, 7464, 'Fullmetal Alchemist: Brotherhood S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/213646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hzbzNKKnRyEIShfgGi1i7K8wB9u.jpg'),
(104523, 7464, 'Fullmetal Alchemist: Brotherhood S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/213647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y1eoPLHirQ5SHipk5TZi3pRnsG.jpg'),
(104524, 7464, 'Fullmetal Alchemist: Brotherhood S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/213648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lP717MoBOQAkDzQBnLQuEdSSGpA.jpg'),
(104525, 7464, 'Fullmetal Alchemist: Brotherhood S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/213649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gAR9g52DCrJTpw3Y3QqQyAraiFw.jpg'),
(104526, 7464, 'Fullmetal Alchemist: Brotherhood S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/213650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v8IyctZOE8SU0lnL4TFMzuV0c9A.jpg'),
(104527, 7464, 'Fullmetal Alchemist: Brotherhood S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/213651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iRwIv95qGLQSp8c0xJha2Ii2Zxk.jpg'),
(104528, 7464, 'Fullmetal Alchemist: Brotherhood S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/213652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c90IsrYr4xhUc0Pby5tdrfPcEQD.jpg'),
(104529, 7464, 'Fullmetal Alchemist: Brotherhood S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/213653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1p1SVIudH5qtXr3j40u7dMQrRJc.jpg'),
(104530, 7464, 'Fullmetal Alchemist: Brotherhood S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/213654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vgwWHsn1fW6na40tEpV2lmXDzDF.jpg'),
(104531, 7464, 'Fullmetal Alchemist: Brotherhood S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/213655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mwu2cX5NciDSMdaCOWt9XWZpZr1.jpg'),
(104532, 7464, 'Fullmetal Alchemist: Brotherhood S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/213656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qF3NxbO4asKO5AGA93IDrKhE8Qu.jpg'),
(104533, 7464, 'Fullmetal Alchemist: Brotherhood S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/213657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z2t7bL9gghOjYVLc9Xj9Lqm1kpo.jpg'),
(104534, 7464, 'Fullmetal Alchemist: Brotherhood S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/213658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/goPpy0AeJJZLorKnjjY7aiUVaom.jpg'),
(104535, 7464, 'Fullmetal Alchemist: Brotherhood S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/213659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oZHvdz3Kv6BUOEKJFgmvy90ZEre.jpg'),
(104536, 7464, 'Fullmetal Alchemist: Brotherhood S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/213660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kbTFxfb2LgjBuOWhGRmU9bN0ZkK.jpg'),
(104537, 7464, 'Fullmetal Alchemist: Brotherhood S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/213661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zQ3DpbTM1w2fdxI6Xlnz65agfYo.jpg'),
(104538, 7464, 'Fullmetal Alchemist: Brotherhood S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/213662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jguhoZ3DtlJAjofMOYMYJX9MWGn.jpg'),
(104539, 7464, 'Fullmetal Alchemist: Brotherhood S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/213663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kh8s94fVQlbShEtSuzSv2EWLhjO.jpg'),
(104540, 7464, 'Fullmetal Alchemist: Brotherhood S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/213664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b7cnmFtfKizZ4aExa8XY8LrVStb.jpg'),
(104541, 7464, 'Fullmetal Alchemist: Brotherhood S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/213665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4xr4Jsgcy11JDlvYbBHXUCBq1L8.jpg'),
(104542, 7464, 'Fullmetal Alchemist: Brotherhood S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/213666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fKoyHq0phWuvABaYLng5Ndl5xxL.jpg'),
(104543, 7464, 'Fullmetal Alchemist: Brotherhood S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/213667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ixaLOBTwJB8SuGcHm2fystMB0T4.jpg'),
(104544, 7464, 'Fullmetal Alchemist: Brotherhood S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/213668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rvUeL9WjHIUOrZJtcT4rVyDUv7g.jpg'),
(104545, 7464, 'Fullmetal Alchemist: Brotherhood S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/213669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cMPdshphOfsx47U4tr30turNma6.jpg'),
(104546, 7464, 'Fullmetal Alchemist: Brotherhood S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/213670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pq6SU0cTfineB72AChv8lpPnZcO.jpg'),
(104547, 7464, 'Fullmetal Alchemist: Brotherhood S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/213671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfyW3xD7i1wxXFv3QM7DJklCgHO.jpg'),
(104548, 7464, 'Fullmetal Alchemist: Brotherhood S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/213672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e8UgXVpJruEnNieufJRaTnDx6OF.jpg'),
(104549, 7464, 'Fullmetal Alchemist: Brotherhood S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/213673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2sZlh2BYgdq7JxBfKrOmBtupwzN.jpg'),
(104550, 7464, 'Fullmetal Alchemist: Brotherhood S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/213674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kKi0XWJYQOxMD2j5ajcV1biX7km.jpg'),
(104551, 7464, 'Fullmetal Alchemist: Brotherhood S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/213675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uinXpRszb1EHz3tSi4pHSzYS86.jpg'),
(104552, 7464, 'Fullmetal Alchemist: Brotherhood S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/213676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzCIX2bXrwTKfWApaJeTDWIASjj.jpg'),
(104553, 7465, 'Rosewood S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mrRvJ3dn2JlLme8tpYP9QTqWAz6.jpg'),
(104554, 7465, 'Rosewood S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/WIksoOmnu9DD111Z96a4Tp9mn7.jpg'),
(104555, 7465, 'Rosewood S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8YoTbrGmIGHFYJfJLdM0shXjHuu.jpg'),
(104556, 7465, 'Rosewood S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/og48abMm5zWdQGjBbrAfBJs48DB.jpg'),
(104557, 7465, 'Rosewood S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ih2JM869jeOxdrBDDnOMqIcNIi1.jpg'),
(104558, 7465, 'Rosewood S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g4BPKeEId62fpPLWUrmqcpGOmWW.jpg'),
(104559, 7465, 'Rosewood S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y8mHta7wzUYYS1DCYBl8wM0RHD1.jpg'),
(104560, 7465, 'Rosewood S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o50AadMLBqUvQK9iEcKfa8p17kW.jpg'),
(104561, 7465, 'Rosewood S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4xFjDVBK6q35p3XO5tRDFqWlkmy.jpg'),
(104562, 7465, 'Rosewood S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/30Df88jFVzOkTyharOxp2v0nQmK.jpg'),
(104563, 7465, 'Rosewood S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/213467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOAmyZ0RbCIaCf3PRU2GrbaZcrV.jpg'),
(104564, 7465, 'Rosewood S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/213468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5SasyCsz6qeYipVZbvNsBn50BHN.jpg'),
(104565, 7465, 'Rosewood S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/213469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h28w3IsXfNmmeWhZKVudMI3mV7.jpg'),
(104566, 7465, 'Rosewood S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/213470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svrCKzx15leeJMm7drvnSTp07GQ.jpg'),
(104567, 7465, 'Rosewood S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/213471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4271Wc7jvOTPDLNGF886tn1A09X.jpg'),
(104568, 7465, 'Rosewood S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/213472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eOC3oIIM1DqG2tsJHNDFtjnjxoS.jpg'),
(104569, 7465, 'Rosewood S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/213473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eGW8TDigCtXonXzLtL1gIjMgYLw.jpg'),
(104570, 7465, 'Rosewood S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/213474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k7Jq6cGz5XM9HRhtlSCoDUuOYOW.jpg'),
(104571, 7465, 'Rosewood S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/213475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1s3BXjd2J4vjt0ZgfqnUVLOxupj.jpg'),
(104572, 7465, 'Rosewood S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/213476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kiehnSzJloQrQiNVdeVOD5ZHWyH.jpg'),
(104573, 7465, 'Rosewood S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/213477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGAhnd8S3BD5js0mhfC1VBsG9eX.jpg'),
(104574, 7465, 'Rosewood S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/213478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4b1kypZUO7HR2egFMCtqOxHW9PT.jpg'),
(104575, 7466, 'Rosewood S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJTmhs3A4mpbohbuSBjI2K1wzrM.jpg'),
(104576, 7466, 'Rosewood S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Wy5pTFHafaOE1Ol8pOowZH60Tb.jpg'),
(104577, 7466, 'Rosewood S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/95rRMVMAm2KpaBwUEZPJuXEHHXD.jpg'),
(104578, 7466, 'Rosewood S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6vUVULB1i8fhDHDMjzkpCB2KSc6.jpg'),
(104579, 7466, 'Rosewood S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2NgLLW6wAfvhmHFyYFojpJOaurG.jpg'),
(104580, 7466, 'Rosewood S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dbE075QszHaa5wGRQrVuFpF8kml.jpg'),
(104581, 7466, 'Rosewood S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zwqm6clRRY9MAzjBosSzlV97xAz.jpg'),
(104582, 7466, 'Rosewood S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Yzelt8B4wBUAsaMuN8EgoI3jqy.jpg'),
(104583, 7466, 'Rosewood S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AqfcGXQSya9M0DEXMM84VLIqP98.jpg'),
(104584, 7466, 'Rosewood S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fXfgZzfjZ0rgDe2HFJHraiNU0S8.jpg'),
(104585, 7466, 'Rosewood S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/213489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jClBxPn366PsxAzlg4XaGK4NyLb.jpg'),
(104586, 7466, 'Rosewood S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/213490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4CnIbRyOihgjC3Fe8FradTMWMxT.jpg'),
(104587, 7466, 'Rosewood S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/213491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtIuOADcfyjykW4sw8tpdrjvv2e.jpg'),
(104588, 7466, 'Rosewood S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/213492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yixP8f5EHlQpORPxxWNCFlcFEf5.jpg'),
(104589, 7466, 'Rosewood S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/213493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvYEdfawkjGCzBx9zYBiT9Sx8nc.jpg'),
(104590, 7466, 'Rosewood S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/213494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ThOGKsX8sl4kowPQgau2RdnxW.jpg'),
(104591, 7466, 'Rosewood S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/213495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q6vjjeKPd8tFTxrJw7WIrWsocZD.jpg'),
(104592, 7466, 'Rosewood S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/213496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hqRNLDb3WFampfsAgoTQoTmC9Ft.jpg'),
(104593, 7466, 'Rosewood S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/213497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o84R6oOFOvEzjsbRRx55C7V3KhL.jpg'),
(104594, 7466, 'Rosewood S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/213498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnYh0b6BbYNAKcomSc8My1KAKNu.jpg'),
(104595, 7466, 'Rosewood S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/213499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c1FGcWMT3gKsC5LhN4bLslk9Ctr.jpg'),
(104596, 7466, 'Rosewood S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/213500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1USALAZS045WsEp8ED6dL98ZEKn.jpg'),
(104597, 7467, 'Ousama Ranking: Yuuki no Takarabako S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223851.mp4', 'http://image.tmdb.org/t/p/w1280/9VU6ABBy7jVkymQk8NEppC9DyKI.jpg'),
(104598, 7467, 'Ousama Ranking: Yuuki no Takarabako S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223852.mp4', 'http://image.tmdb.org/t/p/w1280/wenwzlb54GEGacY7oVlq4YV4yek.jpg'),
(104599, 7467, 'Ousama Ranking: Yuuki no Takarabako S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223853.mp4', 'http://image.tmdb.org/t/p/w1280/gQ9R0IhmgIU7gBlFrjReRxqVnKl.jpg'),
(104600, 7467, 'Ousama Ranking: Yuuki no Takarabako S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nIDLacmyToFgkzdnOClb4dug7Kr.jpg'),
(104601, 7467, 'Ousama Ranking: Yuuki no Takarabako S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/48hDKsmwTJ474jpEaX0SKj8hz1g.jpg'),
(104602, 7467, 'Ousama Ranking: Yuuki no Takarabako S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fktOM41hQ7Ha7ZGPtPeM2kuOg4T.jpg'),
(104603, 7467, 'Ousama Ranking: Yuuki no Takarabako S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hfZH1DAPluiYvxAWlIk838vgnev.jpg'),
(104604, 7467, 'Ousama Ranking: Yuuki no Takarabako S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3bTxKDbw0NSH8AmlxgxbiAJJBgA.jpg'),
(104605, 7467, 'Ousama Ranking: Yuuki no Takarabako S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9fPZz7X66aftdOXHPT7GEb6KZjd.jpg'),
(104606, 7467, 'Ousama Ranking: Yuuki no Takarabako S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7LXvjuqx60N1VzrfwfFEemfc1kw.jpg'),
(104607, 7468, 'A Família Stallone S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wCCmpCm52wmM8nI4Res7iFvpbdD.jpg'),
(104608, 7468, 'A Família Stallone S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219074.mp4', 'http://image.tmdb.org/t/p/w1280/9PudiAUz20umOA6M5iu1YnltucJ.jpg'),
(104609, 7468, 'A Família Stallone S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219075.mp4', 'http://image.tmdb.org/t/p/w1280/9tUxQZNDKCvV60BwBCrbGsCTJVj.jpg'),
(104610, 7468, 'A Família Stallone S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219076.mp4', 'http://image.tmdb.org/t/p/w1280/llYCesRIRWsiDp1kcsRH2MzQ6L8.jpg'),
(104611, 7468, 'A Família Stallone S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219077.mp4', 'http://image.tmdb.org/t/p/w1280/8mkJcb5W0P1ZZCxhJdQarHTFfUJ.jpg'),
(104612, 7468, 'A Família Stallone S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219078.mp4', 'http://image.tmdb.org/t/p/w1280/cI44PU7y8M97H2FExMnTrIdcM4j.jpg'),
(104613, 7468, 'A Família Stallone S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219079.mp4', 'http://image.tmdb.org/t/p/w1280/3VprPfhvEh1eA9Mgjr6yiEZbFT.jpg'),
(104614, 7468, 'A Família Stallone S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219080.mp4', 'http://image.tmdb.org/t/p/w1280/bYsIgnnEZIhjYblyZS8T1uOsSdo.jpg'),
(104615, 7469, 'A Família Stallone S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/277397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hwdgvw8H459HVxE6htcrEUTQzlS.jpg'),
(104616, 7469, 'A Família Stallone S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/277398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hwdgvw8H459HVxE6htcrEUTQzlS.jpg'),
(104617, 7469, 'A Família Stallone S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/288357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hwdgvw8H459HVxE6htcrEUTQzlS.jpg'),
(104618, 7469, 'A Família Stallone S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hwdgvw8H459HVxE6htcrEUTQzlS.jpg'),
(104619, 7469, 'A Família Stallone S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/300443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hwdgvw8H459HVxE6htcrEUTQzlS.jpg'),
(104620, 7469, 'A Família Stallone S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/305624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hwdgvw8H459HVxE6htcrEUTQzlS.jpg'),
(104621, 7469, 'A Família Stallone S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/311051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hwdgvw8H459HVxE6htcrEUTQzlS.jpg'),
(104622, 7469, 'A Família Stallone S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/319073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hwdgvw8H459HVxE6htcrEUTQzlS.jpg'),
(104623, 7469, 'A Família Stallone S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/325239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hwdgvw8H459HVxE6htcrEUTQzlS.jpg'),
(104624, 7469, 'A Família Stallone S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/329118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hwdgvw8H459HVxE6htcrEUTQzlS.jpg'),
(104625, 7470, 'A Virada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/roqr5RyMY1tv9XZX0cAYEvvDDyc.jpg'),
(104626, 7470, 'A Virada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/roqr5RyMY1tv9XZX0cAYEvvDDyc.jpg'),
(104627, 7470, 'A Virada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/roqr5RyMY1tv9XZX0cAYEvvDDyc.jpg'),
(104628, 7470, 'A Virada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/roqr5RyMY1tv9XZX0cAYEvvDDyc.jpg'),
(104629, 7471, 'Com Carinho Kitty S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3jWKZBV0W0DWWQd7IRXkKzRAvFf.jpg'),
(104630, 7471, 'Com Carinho Kitty S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbM0zNhmgQJgWzfK0SEHCuQqYbG.jpg'),
(104631, 7471, 'Com Carinho Kitty S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZlfchfhtjVyxNtbru7LVu7mmmL.jpg'),
(104632, 7471, 'Com Carinho Kitty S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kifaBVSD4ZUCepHqhxTRNZ3t8kw.jpg'),
(104633, 7471, 'Com Carinho Kitty S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pE4tzxTlRSfEGSj6UjdKqZYq46N.jpg'),
(104634, 7471, 'Com Carinho Kitty S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2gq84XQFcxD4ozhEhvWYg8cokIL.jpg'),
(104635, 7471, 'Com Carinho Kitty S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n5myY4XFwhUSClBNWZkU50JUHTS.jpg'),
(104636, 7471, 'Com Carinho Kitty S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/27vJgkQmN6lUzhxeaQjABuNu8dT.jpg'),
(104637, 7471, 'Com Carinho Kitty S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qDZl06FrlbVlt6tM1iFT07xGjq4.jpg'),
(104638, 7471, 'Com Carinho Kitty S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sPDIbi1YKhjTFIwlSTFwt3SY7Ig.jpg'),
(104639, 7472, 'Com Carinho Kitty S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/665383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ed1c8LZns4lFUZNS72OhmqXmYHE.jpg'),
(104640, 7472, 'Com Carinho Kitty S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/665384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ed1c8LZns4lFUZNS72OhmqXmYHE.jpg'),
(104641, 7472, 'Com Carinho Kitty S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/665385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ed1c8LZns4lFUZNS72OhmqXmYHE.jpg'),
(104642, 7472, 'Com Carinho Kitty S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/665386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ed1c8LZns4lFUZNS72OhmqXmYHE.jpg'),
(104643, 7472, 'Com Carinho Kitty S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/665387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ed1c8LZns4lFUZNS72OhmqXmYHE.jpg'),
(104644, 7472, 'Com Carinho Kitty S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/665388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ed1c8LZns4lFUZNS72OhmqXmYHE.jpg'),
(104645, 7472, 'Com Carinho Kitty S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/665389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ed1c8LZns4lFUZNS72OhmqXmYHE.jpg'),
(104646, 7472, 'Com Carinho Kitty S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/665390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ed1c8LZns4lFUZNS72OhmqXmYHE.jpg'),
(104647, 7473, 'Conor McGregor: Além do Octógono S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wazIL6jO8WizaiYNQ4DUOgajxuM.jpg'),
(104648, 7473, 'Conor McGregor: Além do Octógono S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUV5aSExVBWAM0LgxzMv8Bfb3D0.jpg'),
(104649, 7473, 'Conor McGregor: Além do Octógono S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ukKUDuaBTICDroWlFU8y9tNN3DM.jpg'),
(104650, 7473, 'Conor McGregor: Além do Octógono S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jUWRwAjF0N2E4CfVLVHBQjyMRSf.jpg'),
(104651, 7474, 'De Férias com o Ex: A Ressaca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4f2SQoRwf98cSD4KIaLg597F52e.jpg'),
(104652, 7474, 'De Férias com o Ex: A Ressaca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220564.mp4', 'http://image.tmdb.org/t/p/w1280/quuCJkA12rsVXbWXrz4GuWXAdgV.jpg'),
(104653, 7474, 'De Férias com o Ex: A Ressaca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220565.mp4', 'http://image.tmdb.org/t/p/w1280/fqAxnVzwSH1z8tPXPmWb4rfvXXt.jpg'),
(104654, 7474, 'De Férias com o Ex: A Ressaca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220566.mp4', 'http://image.tmdb.org/t/p/w1280/voGU39R1hc19fO2GwSZf6G63zZ8.jpg'),
(104655, 7474, 'De Férias com o Ex: A Ressaca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5B9OFCDJnEzzMTQblZ3bdsqZQ3c.jpg'),
(104656, 7475, 'Deserto Selvagem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lJWi5rqzKcUh4zpXU6Xkg0I5hQ6.jpg'),
(104657, 7475, 'Deserto Selvagem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d1EdiHUvuzrMDvEA7PK0uCO2ghj.jpg'),
(104658, 7475, 'Deserto Selvagem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/reKeKuzx99457CRwSmbSXf4yFQJ.jpg'),
(104659, 7475, 'Deserto Selvagem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220156.mp4', 'http://image.tmdb.org/t/p/w1280/dcOgcsjA0QTAzadCBhtq9NWJGZp.jpg'),
(104660, 7475, 'Deserto Selvagem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220157.mp4', 'http://image.tmdb.org/t/p/w1280/41dEx7z5zezkikbPZiVW6OYJ9K3.jpg'),
(104661, 7475, 'Deserto Selvagem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220158.mp4', 'http://image.tmdb.org/t/p/w1280/nSpbu3eydTb6wUGBQw8cMzKBaxy.jpg'),
(104662, 7475, 'Deserto Selvagem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4HDYIDFKmAiwcphR3mzFGUqmQc.jpg'),
(104663, 7475, 'Deserto Selvagem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220160.mp4', 'http://image.tmdb.org/t/p/w1280/xSGvD62JGMnTmNqEcBINq3SRykW.jpg'),
(104664, 7476, 'Dra. Cha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ctEWnAG5kVkPpTLu56Wy6gheUyT.jpg'),
(104665, 7476, 'Dra. Cha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tvp8HoXds51u6uUWZXO9vSqNn14.jpg'),
(104666, 7476, 'Dra. Cha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219027.mp4', 'http://image.tmdb.org/t/p/w1280/2vdzXySI4FrurMGiWjsnUQvVF5d.jpg'),
(104667, 7476, 'Dra. Cha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219028.mp4', 'http://image.tmdb.org/t/p/w1280/es5h1FeE1xAwyT4tswVteh9uDH3.jpg'),
(104668, 7476, 'Dra. Cha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219029.mp4', 'http://image.tmdb.org/t/p/w1280/dHrcP8XRGCfXcHIHwX5GUzUQoCR.jpg'),
(104669, 7476, 'Dra. Cha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219030.mp4', 'http://image.tmdb.org/t/p/w1280/4k6fOZNWDMYDMXph1eD4KYoX9fQ.jpg'),
(104670, 7476, 'Dra. Cha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219031.mp4', 'http://image.tmdb.org/t/p/w1280/d1PKvtkn53encaioostF9p5LtJW.jpg'),
(104671, 7476, 'Dra. Cha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219032.mp4', 'http://image.tmdb.org/t/p/w1280/c63yrpILk5XaPYcEymVGRiQoz07.jpg'),
(104672, 7476, 'Dra. Cha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/83x0TPz8huGChaA8rjmiu89qysv.jpg'),
(104673, 7476, 'Dra. Cha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/83x0TPz8huGChaA8rjmiu89qysv.jpg'),
(104674, 7476, 'Dra. Cha S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219035.mp4', 'http://image.tmdb.org/t/p/w1280/8r4oIAx1N4kopwN3eI4rIgfbgXY.jpg'),
(104675, 7476, 'Dra. Cha S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219036.mp4', 'http://image.tmdb.org/t/p/w1280/5LmxjwBY9E3q1pS81lMw6EuQDbs.jpg'),
(104676, 7476, 'Dra. Cha S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219037.mp4', 'http://image.tmdb.org/t/p/w1280/3UHiNJafi8KeOmJ6Shu4gW8KVKi.jpg'),
(104677, 7476, 'Dra. Cha S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/219038.mp4', 'http://image.tmdb.org/t/p/w1280/nAU6d1bbmjedQim925T30sbe8gL.jpg'),
(104678, 7476, 'Dra. Cha S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/219039.mp4', 'http://image.tmdb.org/t/p/w1280/4lnTazrdQr81Lp2Du8oTXTCNf3f.jpg'),
(104679, 7476, 'Dra. Cha S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/219040.mp4', 'http://image.tmdb.org/t/p/w1280/uhHcZEMSH0Tw46S6FM6KqsX21ZN.jpg'),
(104680, 7477, 'Kitti Katz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pIhZa8pyPIUKchLGorMEd27BP8h.jpg'),
(104681, 7477, 'Kitti Katz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7taGYOxdsv7lWnLlHmpxfdYfuiJ.jpg'),
(104682, 7477, 'Kitti Katz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfSLU7EZqJz47HkuTiLz0LFSVLw.jpg'),
(104683, 7477, 'Kitti Katz S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xGof7QQ4P4P1QNcOagN3Gtm4vGz.jpg'),
(104684, 7477, 'Kitti Katz S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6LUYC9iFrAyTYGdDa05hXwmlGsk.jpg'),
(104685, 7477, 'Kitti Katz S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wVqwxVFh4v4UUrtkm9hmpkyfDDw.jpg'),
(104686, 7477, 'Kitti Katz S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gBKmHagNOFc2J42kuWs2P4PnBXf.jpg'),
(104687, 7477, 'Kitti Katz S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oOFDyxzigO0aBLbcYKhjLllARhg.jpg'),
(104688, 7477, 'Kitti Katz S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sD6mtpWaBdG09RGhGVrdYTcatE9.jpg'),
(104689, 7477, 'Kitti Katz S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wh4XGAbdGtGJNLOJNVaaUNkfxJo.jpg'),
(104690, 7478, 'Os 20 dias de Lazaro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213186.mp4', 'https://i.bj-share.info/7b7f02040b5bd4c5095d5895286a2b98.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(104691, 7478, 'Os 20 dias de Lazaro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213187.mp4', 'https://i.bj-share.info/7b7f02040b5bd4c5095d5895286a2b98.jpg'),
(104692, 7478, 'Os 20 dias de Lazaro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213188.mp4', 'https://i.bj-share.info/7b7f02040b5bd4c5095d5895286a2b98.jpg'),
(104693, 7478, 'Os 20 dias de Lazaro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213189.mp4', 'https://i.bj-share.info/7b7f02040b5bd4c5095d5895286a2b98.jpg'),
(104694, 7478, 'Os 20 dias de Lazaro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213190.mp4', 'https://i.bj-share.info/7b7f02040b5bd4c5095d5895286a2b98.jpg'),
(104695, 7478, 'Os 20 dias de Lazaro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213191.mp4', 'https://i.bj-share.info/7b7f02040b5bd4c5095d5895286a2b98.jpg'),
(104696, 7479, 'Silêncio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a64Hewfz1zZGtmSwoVBm06zvf3z.jpg'),
(104697, 7479, 'Silêncio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ERPvYDfaFJy6KOmG29VqgGU9D0.jpg'),
(104698, 7479, 'Silêncio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nh8HLYhdZwfrmF2w6DM2rolhG25.jpg'),
(104699, 7479, 'Silêncio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tZJia3Jk3bUUbR56f7GYThwxpFO.jpg'),
(104700, 7479, 'Silêncio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ysJK6Omnv5rG3lNHXfLopcxcZm1.jpg'),
(104701, 7479, 'Silêncio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/33otqFOk0sbrFdwXn9OmexBNKjQ.jpg'),
(104702, 7480, 'Skip and Loafer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lf6JdQm0XtJTxEE49tioDx0OfqE.jpg'),
(104703, 7480, 'Skip and Loafer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pRtxYDNJf4mb6uwW5fXSTEdpdAt.jpg'),
(104704, 7480, 'Skip and Loafer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i7baAIUQnKogfp2bcC7puepvzBz.jpg'),
(104705, 7480, 'Skip and Loafer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zaoTMX45gAa0pGR03GTVeD49ac4.jpg'),
(104706, 7480, 'Skip and Loafer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o7IBOYPzHCtwRAHaFBTG8I9Sill.jpg'),
(104707, 7480, 'Skip and Loafer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8YWgn0qA53Z3VKdy2x1V8oxqn0Z.jpg'),
(104708, 7480, 'Skip and Loafer S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mxu76LHd9GbTq4wjKSHz8I0HoH0.jpg'),
(104709, 7480, 'Skip and Loafer S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y6kWh2LRMfjq4LOBfsl6jTzwbWO.jpg'),
(104710, 7480, 'Skip and Loafer S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oT2twMT4WJjINBCZDRn3gQaKdX4.jpg'),
(104711, 7480, 'Skip and Loafer S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rr9bQ2Dtg7JpEoYW79Y4jNhXtO2.jpg'),
(104712, 7480, 'Skip and Loafer S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yL5WlOArVsfMXBWxvNSbwV3VXHV.jpg'),
(104713, 7480, 'Skip and Loafer S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223185.mp4', 'http://image.tmdb.org/t/p/w1280/eCDlXZr91NQkNBNJIblwbSlLLUm.jpg'),
(104714, 7481, 'TRABALHO S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cVHKKnZSBeOpK2IEZkEKz9U42Hh.jpg'),
(104715, 7481, 'TRABALHO S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9eIvuA9SmmjGQ43vZ0e8yW9wngd.jpg'),
(104716, 7481, 'TRABALHO S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4A1sPCwPZy9yW3V8xc6izUtwZFt.jpg'),
(104717, 7481, 'TRABALHO S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AuYbhFBSqrWdQSCdsTEQvrEh5wd.jpg'),
(104718, 7482, 'Vinland Saga S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/20sCGFmd3Tsn6NWJAG56c000hSZ.jpg'),
(104719, 7482, 'Vinland Saga S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uOHYGhjbnj172E3TOLXDhx4FHbn.jpg'),
(104720, 7482, 'Vinland Saga S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iMl5CIdLGYJSw9H8ZKt1bnwJgUX.jpg'),
(104721, 7482, 'Vinland Saga S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rk8O2qX6Vlr3vayXeHveE46syDF.jpg'),
(104722, 7482, 'Vinland Saga S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xl2eHxtN8Z7K2y008VKQv5kXFJB.jpg'),
(104723, 7482, 'Vinland Saga S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQBhFPORk2qiHd6lrAhO7LmsXt7.jpg'),
(104724, 7482, 'Vinland Saga S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/TEscn9jYP0fO4BvJwWj2dISivD.jpg'),
(104725, 7482, 'Vinland Saga S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kXqzBmmofkcldGwE8J3nwshPfdL.jpg'),
(104726, 7482, 'Vinland Saga S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kRpuMZ51xi6nNrrCxQB0ofIgOc6.jpg'),
(104727, 7482, 'Vinland Saga S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ifYEkh4l8S3nr60pR2vqn0ulAnV.jpg'),
(104728, 7482, 'Vinland Saga S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lVBvExqW88xlBhKAUdvlMlF0Snm.jpg'),
(104729, 7482, 'Vinland Saga S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gv6oEX3yk14ULRzpzwb2SeXhpjo.jpg'),
(104730, 7482, 'Vinland Saga S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/223533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pYW3pmIQRiF2n96d71zkFlH5vaY.jpg'),
(104731, 7482, 'Vinland Saga S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/223534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AjgMB92oc3psHCvG7IN25vqav5n.jpg'),
(104732, 7482, 'Vinland Saga S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/223535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uyg8j4ILWnHDGiAwjceb2QSgK1V.jpg'),
(104733, 7482, 'Vinland Saga S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/223536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dGSSIz36eRvXHjpr4XUPWgv1wE5.jpg'),
(104734, 7482, 'Vinland Saga S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/223537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/giCXN698HTHwZPDGYfXB636Dmvx.jpg'),
(104735, 7482, 'Vinland Saga S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/223538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zKYuwDsFkTd7gR27eouZ6PwVeHk.jpg'),
(104736, 7482, 'Vinland Saga S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/223539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0oU85bZ924v6A0ah9nnJESwzLl.jpg'),
(104737, 7482, 'Vinland Saga S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/223540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3sWjsqhb29BDee7g1MH6Enudyca.jpg'),
(104738, 7482, 'Vinland Saga S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/223541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2pDnNNSyZgC2OGanRsohCPWHCb.jpg'),
(104739, 7482, 'Vinland Saga S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/223542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oNFBQHPnpBOp2imod7HxFvrokyy.jpg'),
(104740, 7482, 'Vinland Saga S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/223543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aE48nt9kL8J1VWA2je6JrOVuZx3.jpg'),
(104741, 7482, 'Vinland Saga S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/223544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/32cLSDA0Zbvv2qA11wUeC2NSB99.jpg'),
(104742, 7483, 'Vinland Saga S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/39Egg6NtF0yWU9YxLMH35jPceJr.jpg'),
(104743, 7483, 'Vinland Saga S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kARuAybuBELgFlFeADMDuGNNFbg.jpg'),
(104744, 7483, 'Vinland Saga S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyUgkAmFx5YBhex0yEaDw6Hz3YE.jpg'),
(104745, 7483, 'Vinland Saga S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rQIAdFTAO7zNjSq5s1GXroIRFby.jpg'),
(104746, 7483, 'Vinland Saga S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bsl84lrge48qEIMA8TTLTLoDxYX.jpg'),
(104747, 7483, 'Vinland Saga S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ooEahQG2QxwT2RR5t2s64HGlFg7.jpg'),
(104748, 7483, 'Vinland Saga S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aPwKhTUAjAEr5BIsIUlgUZLG9RV.jpg'),
(104749, 7483, 'Vinland Saga S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5SHrVV8uDvxB6ZgYcoDDEecRTS0.jpg'),
(104750, 7483, 'Vinland Saga S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1jxQe0I4nbCaW5DoyAaLcrfswV.jpg'),
(104751, 7483, 'Vinland Saga S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zXoLhLbMAMgJqKsk5HytCEHTSwt.jpg'),
(104752, 7483, 'Vinland Saga S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5lpzPKNaW1qFUugkXeALjFW66Bp.jpg'),
(104753, 7483, 'Vinland Saga S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yOmg9WVeLT7b8vLiofGBiqsKWKW.jpg'),
(104754, 7483, 'Vinland Saga S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/223557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l4l49Q6L0NMFfpPUvKTH1K4MlKf.jpg'),
(104755, 7483, 'Vinland Saga S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/223558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iyq3mKEyeIEie30eCydNxfs6WfG.jpg'),
(104756, 7483, 'Vinland Saga S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/223559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/burs3cqa5cCVbYGV7znayAi7DQt.jpg'),
(104757, 7483, 'Vinland Saga S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/223560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3u7dbjGNpAoLiMhyXbWWe9F8cu.jpg'),
(104758, 7483, 'Vinland Saga S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/223561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hrbjEw5HzneU2QNBeS7QgncwGyf.jpg'),
(104759, 7483, 'Vinland Saga S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/223562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pBBvPM0SxzonWR19WtizP05oaL0.jpg'),
(104760, 7483, 'Vinland Saga S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/223563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1W7U1TVRM0hJA76R6pxkDOs67R.jpg'),
(104761, 7483, 'Vinland Saga S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/223564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9KtEVVJ3O4OZHcSWk5d4uuLEVL2.jpg'),
(104762, 7483, 'Vinland Saga S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/223565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uYSWeoZsDmTMTSQSZbH78scPKfl.jpg'),
(104763, 7483, 'Vinland Saga S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/223566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xROo4ESn6Tmk9NAD8zlhFLu1n2M.jpg'),
(104764, 7483, 'Vinland Saga S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/223567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mrF7kEJHtH6r4Cz1OaAZ7sIdLU8.jpg'),
(104765, 7483, 'Vinland Saga S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/223568.mp4', 'http://image.tmdb.org/t/p/w1280/aorS01rq0HnmbCseTe6K66z8t7z.jpg'),
(104766, 7484, 'Yakitori: Soldados do Desastre S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m1zhce6f92l05nWl0EjksaqDGXI.jpg'),
(104767, 7484, 'Yakitori: Soldados do Desastre S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6US94NSRUUawa44EiYi61oIF8Jk.jpg'),
(104768, 7484, 'Yakitori: Soldados do Desastre S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2f3PG6tjwcwCleKrhrnhzA1KPHa.jpg'),
(104769, 7484, 'Yakitori: Soldados do Desastre S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8MLbhyEvNtFhYkpSmC9yKx1AQBM.jpg'),
(104770, 7484, 'Yakitori: Soldados do Desastre S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p5JEfNP9JBOqtXRyVKPfkDTzn2o.jpg'),
(104771, 7484, 'Yakitori: Soldados do Desastre S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zmBzICMEyeSU0Oy3TxLnRI5nilF.jpg'),
(104772, 7485, 'A Louva-a-deus S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oPydwVhEhBBgTnBVRJdRNdsWrE5.jpg'),
(104773, 7485, 'A Louva-a-deus S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bskTeZBSn0C8qKmpuYeUgUMECUw.jpg'),
(104774, 7485, 'A Louva-a-deus S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oTPNbcsQVfrGJDCwz4eWzUZY2Hs.jpg'),
(104775, 7485, 'A Louva-a-deus S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zRGk8TRswQqGmc5XgmAfitdHNzA.jpg'),
(104776, 7485, 'A Louva-a-deus S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sRZgHpjLuiQPN9SBXfesm7kviIU.jpg'),
(104777, 7485, 'A Louva-a-deus S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qcR1otllRXYw0ddjgWoCuRuvhQi.jpg'),
(104778, 7486, 'Poldark: Herói de Guerra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJnfSevbSU5zQ8t1ztix06dX8Si.jpg'),
(104779, 7486, 'Poldark: Herói de Guerra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aHaCCVYhC2aGjDrc4UcuUkHXSnf.jpg'),
(104780, 7486, 'Poldark: Herói de Guerra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dtaapfCOfnhIHgn2rpfhziLZ6p3.jpg'),
(104781, 7486, 'Poldark: Herói de Guerra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vc0IzUPlVSu5yU4P1rn9zgv6J6.jpg'),
(104782, 7486, 'Poldark: Herói de Guerra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cQS5xHvY64wMAaT33UunQSJMPtM.jpg'),
(104783, 7486, 'Poldark: Herói de Guerra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zAbazXDEiuABIQZS5ymCKfP1oXj.jpg'),
(104784, 7486, 'Poldark: Herói de Guerra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9xUcx2FVog2PMLeJlYPgSy6H6lm.jpg'),
(104785, 7486, 'Poldark: Herói de Guerra S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/phqk3CD5n4VNlnFVR2uYQzv7csb.jpg'),
(104786, 7487, 'Poldark: Herói de Guerra S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eZqtyoOP9AKBmx5ggv9bd86V1Rr.jpg'),
(104787, 7487, 'Poldark: Herói de Guerra S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cI4KlHkTpmsUqXTNVYK5wWBswqa.jpg'),
(104788, 7487, 'Poldark: Herói de Guerra S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ur5xN5Zu8ijn77PLgPdAMmXcecy.jpg'),
(104789, 7487, 'Poldark: Herói de Guerra S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8612b3T9x9Y1cR29RJpBH7oaiEw.jpg'),
(104790, 7487, 'Poldark: Herói de Guerra S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mTyH3acm9CjgU1WEdlkUcxnkj6.jpg'),
(104791, 7487, 'Poldark: Herói de Guerra S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/22b3fnGOYY0rZkJ3pt9N84HqtRV.jpg'),
(104792, 7487, 'Poldark: Herói de Guerra S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gYiM4d1vE3L7Teo4e1dLeLbfAiT.jpg'),
(104793, 7487, 'Poldark: Herói de Guerra S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kC3K2AnUUjaQsMKXLFr1Sb9b6H1.jpg'),
(104794, 7487, 'Poldark: Herói de Guerra S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/GPTRt27IqWTAgOaFCwNwPHHOHV.jpg'),
(104795, 7487, 'Poldark: Herói de Guerra S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xlglGLMUnhEKDndFyPYpxUFbGOo.jpg'),
(104796, 7488, 'Poldark: Herói de Guerra S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xD1Uj6SgIdA4wRgPx7YOF6cX8kK.jpg'),
(104797, 7488, 'Poldark: Herói de Guerra S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2jWDBP6puF4NNKY6mW6MDMhh5k0.jpg'),
(104798, 7488, 'Poldark: Herói de Guerra S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eHSQZlbpmIR3DthnCwUNCnKwfgg.jpg'),
(104799, 7488, 'Poldark: Herói de Guerra S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h6S04Sw425hNKZ4VzVr1WnXu386.jpg'),
(104800, 7488, 'Poldark: Herói de Guerra S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVQr2q3gYG5O8YiO3SjvFm9rvFY.jpg'),
(104801, 7488, 'Poldark: Herói de Guerra S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h2B87CmC12NX9kzNGnVupIp5Pda.jpg'),
(104802, 7488, 'Poldark: Herói de Guerra S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wb5Ycpr1pgRWJ2TRlw5ks1Srq7S.jpg'),
(104803, 7488, 'Poldark: Herói de Guerra S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A1Axz9u8nYbUbpVIScn24rOIJQu.jpg'),
(104804, 7488, 'Poldark: Herói de Guerra S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2TUcNLpyPtsgt07NwsGNTwpLKvp.jpg'),
(104805, 7489, 'Poldark: Herói de Guerra S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7O4eHkLFrmEf7Ww3xpHR97tKLWk.jpg'),
(104806, 7489, 'Poldark: Herói de Guerra S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3gJTpj5gUU9ez1XrVKAUlpPzeyB.jpg'),
(104807, 7489, 'Poldark: Herói de Guerra S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aCIhWrWIwZCImIOPZiSgrFYK1Ot.jpg'),
(104808, 7489, 'Poldark: Herói de Guerra S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yA7X62mespAgc8SkMboyZp5cO9f.jpg'),
(104809, 7489, 'Poldark: Herói de Guerra S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tIePivXZ6uN0ok9bSUVE6Xx7P7f.jpg'),
(104810, 7489, 'Poldark: Herói de Guerra S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zK5emVhZLtw1YMgKdrKAiuZlyo3.jpg'),
(104811, 7489, 'Poldark: Herói de Guerra S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jGEylXlObeLVNQNOjAczS1UKjfp.jpg'),
(104812, 7489, 'Poldark: Herói de Guerra S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCXqkQEzxO15zYSBI5eDXWhjYx.jpg'),
(104813, 7490, 'Poldark: Herói de Guerra S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4MjcAEWVV77CIJ540Mskzi5bzc5.jpg'),
(104814, 7490, 'Poldark: Herói de Guerra S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pZJsJgPbvbOmnlHQCpQfTmUeDbM.jpg'),
(104815, 7490, 'Poldark: Herói de Guerra S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/joaSzcTDb8KIO7DHWcxx7KEypuR.jpg'),
(104816, 7490, 'Poldark: Herói de Guerra S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/77GNkZZHtgaAOIRnXz7QUC1OU6.jpg'),
(104817, 7490, 'Poldark: Herói de Guerra S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3AQB3UMxLMn7vdi1sIopU3Korhs.jpg'),
(104818, 7490, 'Poldark: Herói de Guerra S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7O0jWsLlexJtxvTMkXSLvgNYGqR.jpg'),
(104819, 7490, 'Poldark: Herói de Guerra S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkJ7i3ul38xdLmcLNEx5Ix5UTqI.jpg'),
(104820, 7490, 'Poldark: Herói de Guerra S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gTnTSPy9V1Tw7xJTAGWW6iP6lOR.jpg'),
(104821, 7491, 'Nurse Jackie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zCdS21S26owW1sA55iXK7VCEkPt.jpg'),
(104822, 7491, 'Nurse Jackie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bRuAxKOK6yLlmXGqMHT0tfr1NcQ.jpg'),
(104823, 7491, 'Nurse Jackie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cu2vW946cOenOmjFTH3z67670kS.jpg'),
(104824, 7491, 'Nurse Jackie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d71wvaxGck5nWvynzmPPO6RnhwJ.jpg'),
(104825, 7491, 'Nurse Jackie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bcRZTT7wdMMTnqYCYHf6KDR1L53.jpg'),
(104826, 7491, 'Nurse Jackie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sn5Iai8lSioTQ6N6O9quX07xX7m.jpg'),
(104827, 7491, 'Nurse Jackie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zCckqzOgHWalo9S62bHUqxSxXZM.jpg'),
(104828, 7491, 'Nurse Jackie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6qEUaxEhVRCv21R1fRIhUhI4MXP.jpg'),
(104829, 7491, 'Nurse Jackie S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xxe9Tz50U0WSAwuhLruhwaDLCRP.jpg'),
(104830, 7491, 'Nurse Jackie S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pt7KkDyZDI3j9CRNvtNQ6Dr8q1M.jpg'),
(104831, 7491, 'Nurse Jackie S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCv84HsqpJlZIXhFs0Bbub117hw.jpg'),
(104832, 7491, 'Nurse Jackie S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/piqkkhBBahATBZGJcLxHTnSt3kY.jpg'),
(104833, 7492, 'Nurse Jackie S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e3MH8UDVHx82ne0AblG11VriZ0Z.jpg'),
(104834, 7492, 'Nurse Jackie S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1JyCzFnFzEMz9xL2BMwNmV2Vybr.jpg'),
(104835, 7492, 'Nurse Jackie S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ll6UpA02etSRRb1k2Yj039NEWgS.jpg'),
(104836, 7492, 'Nurse Jackie S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xRE6UMKXSeT83IpVgka4qSwaBvy.jpg'),
(104837, 7492, 'Nurse Jackie S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9E8eXU9WlHfzVNParb5D9XX6DJj.jpg'),
(104838, 7492, 'Nurse Jackie S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rAM951ci2zW5I63Wkk05n87dEh1.jpg'),
(104839, 7492, 'Nurse Jackie S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2pjy40heq4L5PBlgxMHZK2VMSi.jpg'),
(104840, 7492, 'Nurse Jackie S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qeJFNvGB5DTzzl4Yb5sHPYMkqhR.jpg'),
(104841, 7492, 'Nurse Jackie S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uPLCMxrkCJm0UjWsQCjKEeppScb.jpg'),
(104842, 7492, 'Nurse Jackie S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4HE7GjYYYAyUhGIN9qpwaR6EPc.jpg'),
(104843, 7492, 'Nurse Jackie S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rEGwsNsd9N5U9RcOTkLuPBa7rfh.jpg'),
(104844, 7492, 'Nurse Jackie S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nTuCbxADeuzE866N22kGP1FRWJy.jpg'),
(104845, 7493, 'Nurse Jackie S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgHAUpPSV8bt3Ie7CnGGIUTRUsV.jpg'),
(104846, 7493, 'Nurse Jackie S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/coCy8utSvqSvdrdhfojQGIuObLb.jpg'),
(104847, 7493, 'Nurse Jackie S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ilmn6z2OBCj8WfNHrnrxxJFF8EI.jpg'),
(104848, 7493, 'Nurse Jackie S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5rWAMOgqcv62a7psOlBc58gaH7a.jpg'),
(104849, 7493, 'Nurse Jackie S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ZPVQ2BGZ1CHj1D9VmXXMegQq86.jpg'),
(104850, 7493, 'Nurse Jackie S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9cHhvRMOrEqOzab2634OYBE5R8p.jpg'),
(104851, 7493, 'Nurse Jackie S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ezNfnEMDcwXe0BuVOTzVuavI55f.jpg'),
(104852, 7493, 'Nurse Jackie S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gTKuj0QoUqZayoH1taVz0D7kSWb.jpg'),
(104853, 7493, 'Nurse Jackie S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8zp75KwGFJdMOqjeaZmE5eXmPfO.jpg'),
(104854, 7493, 'Nurse Jackie S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/38HNOngqTMBqvEewwEfCJueqZDv.jpg'),
(104855, 7493, 'Nurse Jackie S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6RR5UFPgMrGm5KETIuFcyU83vue.jpg'),
(104856, 7493, 'Nurse Jackie S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3A2cd7rvprJSy7rFEL9zwCTC0MP.jpg'),
(104857, 7494, 'Nurse Jackie S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6uZ5rxeRmiaPJbSmngtxexU7zGb.jpg'),
(104858, 7494, 'Nurse Jackie S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eEelR3LRC0NoTx5nNwVt02lYQXB.jpg'),
(104859, 7494, 'Nurse Jackie S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qpEnk015h9mrLm00L1MP8e5NGNi.jpg'),
(104860, 7494, 'Nurse Jackie S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e0HQDomO2W7XiuIUqEU4RRSNTS9.jpg'),
(104861, 7494, 'Nurse Jackie S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/syiV4H0RWruylbrp309s2XMvXli.jpg'),
(104862, 7494, 'Nurse Jackie S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t9WvScKCdkZUC0Gv192wm9isiVC.jpg'),
(104863, 7494, 'Nurse Jackie S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yiSOiUVrOYKoGDNb0QVUfYYqPTJ.jpg'),
(104864, 7494, 'Nurse Jackie S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6pM4mhrdYfS2xo3Mf6BUqNDduVu.jpg'),
(104865, 7494, 'Nurse Jackie S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jumyvJZmJPNsT4W9seTs8wtbe6x.jpg'),
(104866, 7494, 'Nurse Jackie S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ztXl0m4QFuIT8SajWlnSxFNBX8.jpg'),
(104867, 7495, 'Nurse Jackie S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c35JJvLD46YJniFaw6iaf0soH1g.jpg'),
(104868, 7495, 'Nurse Jackie S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/roMtNjacQygPLi587SDbgOZg7jq.jpg'),
(104869, 7495, 'Nurse Jackie S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yPKW6sRmtgvtvLeIqdLFffJfcAU.jpg'),
(104870, 7495, 'Nurse Jackie S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/90968xSLqryXeyURkbsTeuSrXNP.jpg'),
(104871, 7495, 'Nurse Jackie S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ualWC8XNOdH962ovJUS2Xmixqi9.jpg'),
(104872, 7495, 'Nurse Jackie S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ccWaZ5IB7ZH8RkzGG65eY6qj9SQ.jpg'),
(104873, 7495, 'Nurse Jackie S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lmcTw1ptXox13D9ydQGT3ft387X.jpg'),
(104874, 7495, 'Nurse Jackie S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ly1PA3JQKJhApmiPgCRVv6SKOZI.jpg'),
(104875, 7495, 'Nurse Jackie S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kRMBLE70StwfncUp644stYChmr4.jpg'),
(104876, 7495, 'Nurse Jackie S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJ01HrSPXiY60IcNwjya7ybhKiz.jpg'),
(104877, 7496, 'Nurse Jackie S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/auehez7SEf28gr4vniyTZ373dDb.jpg'),
(104878, 7496, 'Nurse Jackie S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r4l0MUHgNGgebckvRlJNjeCU2ne.jpg'),
(104879, 7496, 'Nurse Jackie S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yM1pX1h8FjsBqAapLJx8Dz2q9x7.jpg'),
(104880, 7496, 'Nurse Jackie S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pirFVaNjvHxwXviZeZDJZrPAr4U.jpg'),
(104881, 7496, 'Nurse Jackie S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fM49NKpNmQ5YPmzOLf9pmQhCfg3.jpg'),
(104882, 7496, 'Nurse Jackie S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/BOxKVin0oytDMiWc4ZhFlXOFeT.jpg'),
(104883, 7496, 'Nurse Jackie S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oSRSRdgHWwYhYgQhHhEaRBUcnFI.jpg'),
(104884, 7496, 'Nurse Jackie S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oGT6NoE6ekmZKi3mdhsjByrRcDQ.jpg'),
(104885, 7496, 'Nurse Jackie S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qy7IVZv178ZY2miZE8Ba3jYofrm.jpg'),
(104886, 7496, 'Nurse Jackie S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8T1SEPVdUNpIkoYggSpeKNghwdT.jpg'),
(104887, 7496, 'Nurse Jackie S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ygwwzZ1Pksg5pNYbcDCRKMcciQ.jpg'),
(104888, 7496, 'Nurse Jackie S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wV9jScFZp7tLgtm3YnpCk88NOTV.jpg'),
(104889, 7497, 'Nurse Jackie S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f6HgWI3oqgCrfGhNUOutrGeES6c.jpg'),
(104890, 7497, 'Nurse Jackie S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xVQGmMA2wBUqicCFTXrFEBR6Wu9.jpg'),
(104891, 7497, 'Nurse Jackie S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/31Ak9k7503RC6rU7v2RbeJQ9x3D.jpg'),
(104892, 7497, 'Nurse Jackie S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/izSmxwo4Bfrh97E8Gbm3naZEhdK.jpg'),
(104893, 7497, 'Nurse Jackie S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bk1k4MaD6ZrLGlVGUa6eBmivS8B.jpg'),
(104894, 7497, 'Nurse Jackie S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ckCwXuda5NqtRO75S4SX0WVO58W.jpg'),
(104895, 7497, 'Nurse Jackie S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDnmQgJjVlYMfpHZcjvThZ1rgzf.jpg'),
(104896, 7497, 'Nurse Jackie S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r9ctCWit4RdsLK4uVMFSWCSsXC4.jpg'),
(104897, 7497, 'Nurse Jackie S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rl0xcjX9FbYgZXdp6sUfHPwKp5V.jpg'),
(104898, 7497, 'Nurse Jackie S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ra1BkufmAstkynlIKbtNE0b6ubh.jpg'),
(104899, 7497, 'Nurse Jackie S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vrTxCUWjHw5E6lvlxIoTLuLkCEl.jpg'),
(104900, 7497, 'Nurse Jackie S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yIeKdSZ0wDx61wcapJskJblD6xp.jpg'),
(104901, 7498, 'Clube da Aventura S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7A9YMQEmVrTGLsxWkt0uc0L1b.jpg'),
(104902, 7498, 'Clube da Aventura S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4iYbC42l7ZhevDWspPT08Sx9Y89.jpg'),
(104903, 7498, 'Clube da Aventura S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4iYbC42l7ZhevDWspPT08Sx9Y89.jpg'),
(104904, 7498, 'Clube da Aventura S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4iYbC42l7ZhevDWspPT08Sx9Y89.jpg'),
(104905, 7498, 'Clube da Aventura S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4iYbC42l7ZhevDWspPT08Sx9Y89.jpg'),
(104906, 7498, 'Clube da Aventura S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4iYbC42l7ZhevDWspPT08Sx9Y89.jpg'),
(104907, 7499, 'Diários de Quarto: Lentes Que Revelam S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6VVjQfpZmZFvXBNriGNZCoYi0Xs.jpg'),
(104908, 7499, 'Diários de Quarto: Lentes Que Revelam S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4jMp70cm6lEgHJlOl8BHOR25eDQ.jpg'),
(104909, 7499, 'Diários de Quarto: Lentes Que Revelam S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7mzTa4maAldGVVxLDFnOi2i5Ame.jpg'),
(104910, 7499, 'Diários de Quarto: Lentes Que Revelam S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220560.mp4', 'http://image.tmdb.org/t/p/w1280/74w6Rhxi9YOUCio1ddtsIRAyLnU.jpg'),
(104911, 7499, 'Diários de Quarto: Lentes Que Revelam S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220561.mp4', 'http://image.tmdb.org/t/p/w1280/mxq2ELDbWIt7wdl0Iv258VbumnX.jpg'),
(104912, 7499, 'Diários de Quarto: Lentes Que Revelam S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/744UHwd5Za0rVAZH1XAMwvWyE88.jpg'),
(104913, 7500, 'Glee: O Preço da Fama S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aath2QqhR1E9msbiOktIYS9NBeN.jpg'),
(104914, 7500, 'Glee: O Preço da Fama S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ig90X1VEoux7maDcCumeszDkfjV.jpg'),
(104915, 7500, 'Glee: O Preço da Fama S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oSiHXAQWbU1Y8DNbx0d97ZgVbHL.jpg'),
(104916, 7501, 'Reforma em Família com Karen e Mina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2MCBcB8laiCiWLawzTyfTe05qaM.jpg'),
(104917, 7501, 'Reforma em Família com Karen e Mina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104918, 7501, 'Reforma em Família com Karen e Mina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104919, 7501, 'Reforma em Família com Karen e Mina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104920, 7501, 'Reforma em Família com Karen e Mina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104921, 7501, 'Reforma em Família com Karen e Mina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104922, 7502, 'Reforma em Família com Karen e Mina S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104923, 7502, 'Reforma em Família com Karen e Mina S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104924, 7502, 'Reforma em Família com Karen e Mina S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104925, 7502, 'Reforma em Família com Karen e Mina S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104926, 7502, 'Reforma em Família com Karen e Mina S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104927, 7502, 'Reforma em Família com Karen e Mina S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104928, 7502, 'Reforma em Família com Karen e Mina S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104929, 7502, 'Reforma em Família com Karen e Mina S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104930, 7502, 'Reforma em Família com Karen e Mina S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104931, 7502, 'Reforma em Família com Karen e Mina S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104932, 7502, 'Reforma em Família com Karen e Mina S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104933, 7502, 'Reforma em Família com Karen e Mina S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104934, 7502, 'Reforma em Família com Karen e Mina S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104935, 7503, 'Reforma em Família com Karen e Mina S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104936, 7503, 'Reforma em Família com Karen e Mina S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104937, 7503, 'Reforma em Família com Karen e Mina S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104938, 7503, 'Reforma em Família com Karen e Mina S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104939, 7503, 'Reforma em Família com Karen e Mina S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104940, 7503, 'Reforma em Família com Karen e Mina S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104941, 7503, 'Reforma em Família com Karen e Mina S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104942, 7503, 'Reforma em Família com Karen e Mina S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104943, 7503, 'Reforma em Família com Karen e Mina S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104944, 7503, 'Reforma em Família com Karen e Mina S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104945, 7503, 'Reforma em Família com Karen e Mina S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104946, 7503, 'Reforma em Família com Karen e Mina S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104947, 7503, 'Reforma em Família com Karen e Mina S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104948, 7504, 'Reforma em Família com Karen e Mina S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104949, 7504, 'Reforma em Família com Karen e Mina S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uFtMpf1KhM7JnDtakHR4dsZP1l4.jpg'),
(104950, 7504, 'Reforma em Família com Karen e Mina S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104951, 7504, 'Reforma em Família com Karen e Mina S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(104952, 7504, 'Reforma em Família com Karen e Mina S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104953, 7504, 'Reforma em Família com Karen e Mina S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104954, 7504, 'Reforma em Família com Karen e Mina S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104955, 7504, 'Reforma em Família com Karen e Mina S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104956, 7504, 'Reforma em Família com Karen e Mina S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104957, 7504, 'Reforma em Família com Karen e Mina S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104958, 7504, 'Reforma em Família com Karen e Mina S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104959, 7504, 'Reforma em Família com Karen e Mina S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104960, 7504, 'Reforma em Família com Karen e Mina S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104961, 7504, 'Reforma em Família com Karen e Mina S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104962, 7504, 'Reforma em Família com Karen e Mina S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104963, 7505, 'Reforma em Família com Karen e Mina S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104964, 7505, 'Reforma em Família com Karen e Mina S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104965, 7505, 'Reforma em Família com Karen e Mina S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104966, 7505, 'Reforma em Família com Karen e Mina S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104967, 7505, 'Reforma em Família com Karen e Mina S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104968, 7505, 'Reforma em Família com Karen e Mina S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104969, 7505, 'Reforma em Família com Karen e Mina S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104970, 7505, 'Reforma em Família com Karen e Mina S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104971, 7505, 'Reforma em Família com Karen e Mina S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104972, 7505, 'Reforma em Família com Karen e Mina S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104973, 7505, 'Reforma em Família com Karen e Mina S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104974, 7505, 'Reforma em Família com Karen e Mina S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104975, 7505, 'Reforma em Família com Karen e Mina S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104976, 7505, 'Reforma em Família com Karen e Mina S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104977, 7506, 'Reforma em Família com Karen e Mina S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104978, 7506, 'Reforma em Família com Karen e Mina S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104979, 7506, 'Reforma em Família com Karen e Mina S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104980, 7506, 'Reforma em Família com Karen e Mina S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104981, 7506, 'Reforma em Família com Karen e Mina S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104982, 7506, 'Reforma em Família com Karen e Mina S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104983, 7506, 'Reforma em Família com Karen e Mina S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104984, 7506, 'Reforma em Família com Karen e Mina S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104985, 7506, 'Reforma em Família com Karen e Mina S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104986, 7506, 'Reforma em Família com Karen e Mina S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104987, 7506, 'Reforma em Família com Karen e Mina S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104988, 7506, 'Reforma em Família com Karen e Mina S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104989, 7506, 'Reforma em Família com Karen e Mina S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104990, 7506, 'Reforma em Família com Karen e Mina S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104991, 7507, 'Reforma em Família com Karen e Mina S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eog8jSBwFIJ2PU3mjMMcYdBMAE.jpg'),
(104992, 7507, 'Reforma em Família com Karen e Mina S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eog8jSBwFIJ2PU3mjMMcYdBMAE.jpg'),
(104993, 7507, 'Reforma em Família com Karen e Mina S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eog8jSBwFIJ2PU3mjMMcYdBMAE.jpg'),
(104994, 7507, 'Reforma em Família com Karen e Mina S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104995, 7507, 'Reforma em Família com Karen e Mina S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104996, 7507, 'Reforma em Família com Karen e Mina S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104997, 7507, 'Reforma em Família com Karen e Mina S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104998, 7507, 'Reforma em Família com Karen e Mina S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(104999, 7507, 'Reforma em Família com Karen e Mina S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(105000, 7507, 'Reforma em Família com Karen e Mina S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(105001, 7507, 'Reforma em Família com Karen e Mina S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(105002, 7507, 'Reforma em Família com Karen e Mina S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(105003, 7507, 'Reforma em Família com Karen e Mina S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(105004, 7508, 'Reforma em Família com Karen e Mina S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(105005, 7508, 'Reforma em Família com Karen e Mina S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pG4B9nBTtXGPuEL3V2hgjHWIJiG.jpg'),
(105006, 7509, 'Royal Crackers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uKZ3aw8QiunInTHtRgqYrijNekL.jpg'),
(105007, 7509, 'Royal Crackers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/orOTpGWrA0QhOo4doCq2dv7uPlh.jpg'),
(105008, 7509, 'Royal Crackers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qFf50ALEVC98JVSA349ccHuZ6Um.jpg'),
(105009, 7509, 'Royal Crackers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5WDPKmzEttXu7zat3N01NQApg0Y.jpg'),
(105010, 7509, 'Royal Crackers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bcHddPsXtevIZzFh8PLE6TuB63n.jpg'),
(105011, 7509, 'Royal Crackers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kUckhMwvjJyUTQ5pKoVA4e70Co8.jpg'),
(105012, 7509, 'Royal Crackers S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e0WZDfojNLFMKAFE6SyTkC22ZGs.jpg'),
(105013, 7509, 'Royal Crackers S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7elwvEh2SZ8b516eBmYCtc15c6o.jpg'),
(105014, 7509, 'Royal Crackers S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/op8DG8Hg1MW2IYuqvsB1k220XEJ.jpg'),
(105015, 7509, 'Royal Crackers S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dPrAhq4qhQ3mxlIn6kttYMWz29M.jpg'),
(105016, 7510, 'Royal Crackers S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yD38GFBAkJ0Bnt8lBoEJUKgtQHk.jpg'),
(105017, 7510, 'Royal Crackers S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/295246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yD38GFBAkJ0Bnt8lBoEJUKgtQHk.jpg'),
(105018, 7510, 'Royal Crackers S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/301092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yD38GFBAkJ0Bnt8lBoEJUKgtQHk.jpg'),
(105019, 7510, 'Royal Crackers S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/312256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yD38GFBAkJ0Bnt8lBoEJUKgtQHk.jpg'),
(105020, 7510, 'Royal Crackers S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/312257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yD38GFBAkJ0Bnt8lBoEJUKgtQHk.jpg'),
(105021, 7510, 'Royal Crackers S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/321213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yD38GFBAkJ0Bnt8lBoEJUKgtQHk.jpg'),
(105022, 7510, 'Royal Crackers S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/343336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yD38GFBAkJ0Bnt8lBoEJUKgtQHk.jpg'),
(105023, 7510, 'Royal Crackers S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/343337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yD38GFBAkJ0Bnt8lBoEJUKgtQHk.jpg'),
(105024, 7510, 'Royal Crackers S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/343338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yD38GFBAkJ0Bnt8lBoEJUKgtQHk.jpg'),
(105025, 7510, 'Royal Crackers S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/343339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yD38GFBAkJ0Bnt8lBoEJUKgtQHk.jpg'),
(105026, 7511, 'Segredos dos Elefantes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fl5dqWSBlZ9UmpLURK1dm6vdGQP.jpg'),
(105027, 7511, 'Segredos dos Elefantes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xj9boXZ4TARolh4C1AlZ73tsj3P.jpg'),
(105028, 7511, 'Segredos dos Elefantes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hhOYAjFwX11RetsaWGzRkxOR35V.jpg'),
(105029, 7511, 'Segredos dos Elefantes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t84MMrGIC2ZqzS43I4XsUWkuIAk.jpg'),
(105030, 7512, 'Ultraman S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AuI7rBQ3vb7S4sYanJgAR8wj5A6.jpg'),
(105031, 7512, 'Ultraman S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/agHnU7gzbVRWh8XnZ0Ll6EnR5me.jpg'),
(105032, 7512, 'Ultraman S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oczfTAV2EfgtMbqcS0OfG6hpkrX.jpg'),
(105033, 7512, 'Ultraman S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qQZ8vvLHENqe403FT7PPtTteW6x.jpg'),
(105034, 7512, 'Ultraman S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eWsmBtdZuCeZWYc1d9G9GAGZ0IY.jpg'),
(105035, 7512, 'Ultraman S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rd8GEX3eqbB6AZkSNWq3kVGASlU.jpg'),
(105036, 7512, 'Ultraman S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yYiTa2eQGuZ44mQYY9jAMK2zQR5.jpg'),
(105037, 7512, 'Ultraman S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aR9U2t7hHhnVE975MK8L3HqtP7c.jpg'),
(105038, 7512, 'Ultraman S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4GbG7yG7BGpVfnoA5SoSGncOIx.jpg'),
(105039, 7512, 'Ultraman S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xuBahTfxEr2tMMm6xHalkt60tuy.jpg'),
(105040, 7512, 'Ultraman S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dYHiRQZvExqL30nDcNLVn5zgFZn.jpg'),
(105041, 7512, 'Ultraman S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kTyZwZC249QdcQkr8im6GpcmYdS.jpg'),
(105042, 7512, 'Ultraman S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rt5U8mYRBs2zLgqPdJNJiSyrcn.jpg'),
(105043, 7513, 'Ultraman S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/upEVEHEzh3Z22SroMLXqgIMdSQr.jpg'),
(105044, 7513, 'Ultraman S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6bn5DNh8XUS3tc8SXl10rIALMrr.jpg'),
(105045, 7513, 'Ultraman S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5WeiQbg9We9pwnfjcqXIF8mtrl5.jpg'),
(105046, 7513, 'Ultraman S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wpo2I6CZ5fXISX90lEihev0uNWs.jpg'),
(105047, 7513, 'Ultraman S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzFkdNXSR8OTUcvYYE6pZjEY1Bb.jpg'),
(105048, 7513, 'Ultraman S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pp156jnSal527ZxiV4bvXVwAHB4.jpg'),
(105049, 7514, 'Ultraman S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3iKqHVNgCAUUUepjs17GT1rQn1O.jpg'),
(105050, 7514, 'Ultraman S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/25gwyHmzu1QVxJJ5MMbwYtHeNvX.jpg'),
(105051, 7514, 'Ultraman S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8XvMIlryzbtEbU38Jp41OXOp9pm.jpg'),
(105052, 7514, 'Ultraman S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9LMf4Mb41CJCqQxhuEBOcjKch8d.jpg'),
(105053, 7514, 'Ultraman S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/65rCrETM9bdjSs8lvN1Cj9D3Feo.jpg'),
(105054, 7514, 'Ultraman S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eN6UdMHHtMQXNjd8IIUpjgwEAIk.jpg'),
(105055, 7514, 'Ultraman S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mvOhbH0NXFSxVR3leAB71DfuO57.jpg'),
(105056, 7514, 'Ultraman S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7McdeCvGzWbi7nrygJJFXtAkATY.jpg'),
(105057, 7514, 'Ultraman S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sEeiFXELw98YhJBBlSnVTw2niFO.jpg'),
(105058, 7514, 'Ultraman S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wQDbq90vp2saVfkDxv2RQG15oL8.jpg'),
(105059, 7514, 'Ultraman S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tIPOZXLvaIZ9qXbYmW0TQH0KqTy.jpg'),
(105060, 7514, 'Ultraman S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z2gxK0cszVv5ry14Zv7jLDSHLW8.jpg'),
(105061, 7515, 'Terra Amarga S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p0WmZmOAHjSRk5MX4xZI6g6g8MV.jpg'),
(105062, 7515, 'Terra Amarga S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5AagLPaYu2cKHBQvtzk3vrEoQG1.jpg'),
(105063, 7515, 'Terra Amarga S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/abt2SSmqgE92er9nQoc4xdD58GE.jpg'),
(105064, 7515, 'Terra Amarga S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8RZwt1xKzfBB3QNiNsSHSLmA0DI.jpg'),
(105065, 7515, 'Terra Amarga S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pGlVpuVUKeWuyIlGVwbicollTY3.jpg'),
(105066, 7515, 'Terra Amarga S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a9zvbkafVgmXWtq28Y9vC2mwpcC.jpg'),
(105067, 7515, 'Terra Amarga S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ROkRnV08nrtwop9BW1Oh4SRYC0.jpg'),
(105068, 7515, 'Terra Amarga S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jV48I5sF2lleeM3P9yAEpCwHxvQ.jpg'),
(105069, 7515, 'Terra Amarga S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4hfPAOWhCfTQpAQVj2ZiuODB7V4.jpg'),
(105070, 7515, 'Terra Amarga S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a9zvbkafVgmXWtq28Y9vC2mwpcC.jpg'),
(105071, 7515, 'Terra Amarga S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wSI1pAYFxjHejZFyNX80Ojw9bT.jpg'),
(105072, 7515, 'Terra Amarga S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xHmIsQmQKeIc8WH9Tfu9z0bFR4u.jpg'),
(105073, 7515, 'Terra Amarga S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWlsL8helaT4OaiJXVDXLo0hJ8K.jpg'),
(105074, 7515, 'Terra Amarga S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQBVKMbX8VPtDuRDCD84fgbDk3L.jpg'),
(105075, 7515, 'Terra Amarga S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/73X6F8tkPkLv1ndnddTfmA60nLT.jpg'),
(105076, 7515, 'Terra Amarga S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hR7kLfUSsr9AbyWrr5pCaTMwqcb.jpg'),
(105077, 7515, 'Terra Amarga S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/215091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odGJwkU1rFFsPWMGJ7TlsdghN3m.jpg'),
(105078, 7515, 'Terra Amarga S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/215092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l8KRAOVJE1xsb2b3SMOPrFJXDCk.jpg'),
(105079, 7515, 'Terra Amarga S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/215093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Zp4gtxE4hzfrPB9HhleuuJ41un.jpg'),
(105080, 7515, 'Terra Amarga S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/215094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/czExMpTAd2oo8tZBHk796fFJVmR.jpg'),
(105081, 7515, 'Terra Amarga S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/215095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vSEmWc2VhZziD7L11plZfx6vLz5.jpg'),
(105082, 7515, 'Terra Amarga S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/215096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iB5x5PeCgAOIZKVBY45ECZBm5e0.jpg'),
(105083, 7515, 'Terra Amarga S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/215097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2W6qJvuT3dAPoaz0cAcbUZAw0aE.jpg'),
(105084, 7515, 'Terra Amarga S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/215098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rQT5eY19mUEic2GAPvU95PjSJAd.jpg'),
(105085, 7515, 'Terra Amarga S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/215099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odfNPb8OzOef3oHDvFTa08E11fR.jpg'),
(105086, 7515, 'Terra Amarga S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/215100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e9Sffw3w3H8aZNGVsnzt5RtkpWE.jpg'),
(105087, 7515, 'Terra Amarga S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/215101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ZWlUQyt7AHfx3UFK1r8y2z752F.jpg'),
(105088, 7515, 'Terra Amarga S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/215102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kEUSOttXCvBTVDtgUjGC68zUIrb.jpg'),
(105089, 7515, 'Terra Amarga S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/215103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eXYt9Y6QfzBYe30jtbxRro1juBx.jpg'),
(105090, 7515, 'Terra Amarga S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/215104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AtGKqnbTNVVFSSGP9z2ucTuSFSE.jpg'),
(105091, 7515, 'Terra Amarga S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/215105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105092, 7515, 'Terra Amarga S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/215106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qXVkeMTtFAe7HDYuH8zECecBK94.jpg'),
(105093, 7515, 'Terra Amarga S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/215107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1XROUMw5Xt7xyi9iMLuJmjVU0Sx.jpg'),
(105094, 7515, 'Terra Amarga S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/215108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fCn3hW0fyG4vbk7GfDX2rjJtaZ9.jpg'),
(105095, 7515, 'Terra Amarga S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/215109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rYUooUCYbOp9MiujuGGcg5Pkezx.jpg'),
(105096, 7515, 'Terra Amarga S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/215110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105097, 7515, 'Terra Amarga S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/215111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105098, 7515, 'Terra Amarga S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/215112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105099, 7515, 'Terra Amarga S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/215113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105100, 7515, 'Terra Amarga S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/215114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105101, 7515, 'Terra Amarga S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/215115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105102, 7515, 'Terra Amarga S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/215116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105103, 7515, 'Terra Amarga S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/215117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105104, 7515, 'Terra Amarga S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/215118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105105, 7515, 'Terra Amarga S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/215119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105106, 7515, 'Terra Amarga S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/215120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105107, 7515, 'Terra Amarga S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/215121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105108, 7515, 'Terra Amarga S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/215122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105109, 7515, 'Terra Amarga S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/215123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105110, 7515, 'Terra Amarga S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/215124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105111, 7515, 'Terra Amarga S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/215125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105112, 7515, 'Terra Amarga S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/215126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105113, 7515, 'Terra Amarga S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/215127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105114, 7515, 'Terra Amarga S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/215128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105115, 7515, 'Terra Amarga S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/215129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105116, 7515, 'Terra Amarga S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/215130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105117, 7515, 'Terra Amarga S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/215131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105118, 7515, 'Terra Amarga S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/215132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105119, 7515, 'Terra Amarga S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/215133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105120, 7515, 'Terra Amarga S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/215134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105121, 7515, 'Terra Amarga S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/215135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105122, 7515, 'Terra Amarga S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/215136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105123, 7515, 'Terra Amarga S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/215137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105124, 7515, 'Terra Amarga S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/215138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105125, 7515, 'Terra Amarga S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/215139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105126, 7515, 'Terra Amarga S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/215140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105127, 7515, 'Terra Amarga S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/215141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105128, 7515, 'Terra Amarga S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/215142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105129, 7515, 'Terra Amarga S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/215143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105130, 7515, 'Terra Amarga S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/215144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105131, 7515, 'Terra Amarga S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/215145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105132, 7515, 'Terra Amarga S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/215146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105133, 7515, 'Terra Amarga S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/215147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105134, 7515, 'Terra Amarga S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/215148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105135, 7515, 'Terra Amarga S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/215149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105136, 7515, 'Terra Amarga S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/215150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105137, 7515, 'Terra Amarga S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/215151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105138, 7515, 'Terra Amarga S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/215152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105139, 7515, 'Terra Amarga S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/215153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105140, 7515, 'Terra Amarga S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/215154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105141, 7515, 'Terra Amarga S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/215155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105142, 7515, 'Terra Amarga S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/215156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105143, 7515, 'Terra Amarga S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/215157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105144, 7515, 'Terra Amarga S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/215158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105145, 7515, 'Terra Amarga S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/215159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105146, 7515, 'Terra Amarga S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/215160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105147, 7515, 'Terra Amarga S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/215161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105148, 7515, 'Terra Amarga S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/215162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105149, 7515, 'Terra Amarga S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/215163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105150, 7515, 'Terra Amarga S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/215164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105151, 7515, 'Terra Amarga S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/215165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105152, 7515, 'Terra Amarga S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/215166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105153, 7515, 'Terra Amarga S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/215167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105154, 7515, 'Terra Amarga S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/215168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105155, 7515, 'Terra Amarga S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/215169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105156, 7515, 'Terra Amarga S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/215170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105157, 7515, 'Terra Amarga S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/215171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105158, 7515, 'Terra Amarga S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/215172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105159, 7515, 'Terra Amarga S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/215173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105160, 7515, 'Terra Amarga S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/215174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105161, 7515, 'Terra Amarga S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/215175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105162, 7515, 'Terra Amarga S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/215176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105163, 7515, 'Terra Amarga S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/215177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105164, 7515, 'Terra Amarga S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/215178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105165, 7515, 'Terra Amarga S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/215179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105166, 7515, 'Terra Amarga S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/215180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105167, 7515, 'Terra Amarga S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/215181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105168, 7515, 'Terra Amarga S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/215182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105169, 7515, 'Terra Amarga S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/215183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105170, 7515, 'Terra Amarga S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/215184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105171, 7515, 'Terra Amarga S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/215185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105172, 7515, 'Terra Amarga S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/215186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105173, 7515, 'Terra Amarga S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/215187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105174, 7515, 'Terra Amarga S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/830354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105175, 7515, 'Terra Amarga S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/830355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105176, 7515, 'Terra Amarga S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/830356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105177, 7515, 'Terra Amarga S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/830357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105178, 7516, 'Terra Amarga S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/830358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105179, 7516, 'Terra Amarga S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/830359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105180, 7516, 'Terra Amarga S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/830360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105181, 7516, 'Terra Amarga S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/830361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105182, 7516, 'Terra Amarga S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/830362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105183, 7516, 'Terra Amarga S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/830363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105184, 7516, 'Terra Amarga S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/830364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105185, 7516, 'Terra Amarga S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/830365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105186, 7516, 'Terra Amarga S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/830366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105187, 7516, 'Terra Amarga S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/830367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105188, 7516, 'Terra Amarga S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/830368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105189, 7516, 'Terra Amarga S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/830369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105190, 7516, 'Terra Amarga S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/830370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105191, 7516, 'Terra Amarga S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/830371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105192, 7516, 'Terra Amarga S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/830372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105193, 7516, 'Terra Amarga S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/830373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105194, 7516, 'Terra Amarga S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/830374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105195, 7516, 'Terra Amarga S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/830375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105196, 7516, 'Terra Amarga S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/830376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105197, 7516, 'Terra Amarga S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/830377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105198, 7516, 'Terra Amarga S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/830378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105199, 7516, 'Terra Amarga S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/830379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105200, 7516, 'Terra Amarga S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/830380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105201, 7516, 'Terra Amarga S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/830381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105202, 7516, 'Terra Amarga S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/830382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105203, 7516, 'Terra Amarga S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/830383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105204, 7516, 'Terra Amarga S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/830384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105205, 7516, 'Terra Amarga S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/830385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105206, 7516, 'Terra Amarga S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/830386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105207, 7516, 'Terra Amarga S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/830387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105208, 7516, 'Terra Amarga S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/830388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105209, 7516, 'Terra Amarga S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/830389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105210, 7516, 'Terra Amarga S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/830390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105211, 7516, 'Terra Amarga S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/830391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105212, 7516, 'Terra Amarga S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/830392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(105213, 7516, 'Terra Amarga S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/830393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105214, 7516, 'Terra Amarga S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/830394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105215, 7516, 'Terra Amarga S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/830395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105216, 7516, 'Terra Amarga S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/830396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105217, 7516, 'Terra Amarga S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/830397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105218, 7516, 'Terra Amarga S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/830398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105219, 7516, 'Terra Amarga S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/830399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105220, 7516, 'Terra Amarga S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/830400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105221, 7516, 'Terra Amarga S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/830401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105222, 7516, 'Terra Amarga S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/830402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105223, 7516, 'Terra Amarga S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/830403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105224, 7516, 'Terra Amarga S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/830404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105225, 7516, 'Terra Amarga S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/830405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105226, 7516, 'Terra Amarga S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/830406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105227, 7516, 'Terra Amarga S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/830407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105228, 7516, 'Terra Amarga S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/830408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105229, 7516, 'Terra Amarga S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/830409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105230, 7516, 'Terra Amarga S02 E53', 'http://sinalprivado.info:80/series/1533784/1533784/830410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105231, 7516, 'Terra Amarga S02 E54', 'http://sinalprivado.info:80/series/1533784/1533784/830411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105232, 7516, 'Terra Amarga S02 E55', 'http://sinalprivado.info:80/series/1533784/1533784/830412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105233, 7516, 'Terra Amarga S02 E56', 'http://sinalprivado.info:80/series/1533784/1533784/830413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105234, 7516, 'Terra Amarga S02 E57', 'http://sinalprivado.info:80/series/1533784/1533784/830414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105235, 7516, 'Terra Amarga S02 E58', 'http://sinalprivado.info:80/series/1533784/1533784/830415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105236, 7516, 'Terra Amarga S02 E59', 'http://sinalprivado.info:80/series/1533784/1533784/830416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105237, 7516, 'Terra Amarga S02 E60', 'http://sinalprivado.info:80/series/1533784/1533784/830417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105238, 7516, 'Terra Amarga S02 E61', 'http://sinalprivado.info:80/series/1533784/1533784/830418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105239, 7516, 'Terra Amarga S02 E62', 'http://sinalprivado.info:80/series/1533784/1533784/830419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105240, 7516, 'Terra Amarga S02 E63', 'http://sinalprivado.info:80/series/1533784/1533784/830420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105241, 7516, 'Terra Amarga S02 E64', 'http://sinalprivado.info:80/series/1533784/1533784/830421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105242, 7516, 'Terra Amarga S02 E65', 'http://sinalprivado.info:80/series/1533784/1533784/830422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105243, 7516, 'Terra Amarga S02 E66', 'http://sinalprivado.info:80/series/1533784/1533784/830423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105244, 7516, 'Terra Amarga S02 E67', 'http://sinalprivado.info:80/series/1533784/1533784/830424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105245, 7516, 'Terra Amarga S02 E68', 'http://sinalprivado.info:80/series/1533784/1533784/830425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105246, 7516, 'Terra Amarga S02 E69', 'http://sinalprivado.info:80/series/1533784/1533784/830426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105247, 7516, 'Terra Amarga S02 E70', 'http://sinalprivado.info:80/series/1533784/1533784/830427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105248, 7516, 'Terra Amarga S02 E71', 'http://sinalprivado.info:80/series/1533784/1533784/830428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105249, 7516, 'Terra Amarga S02 E72', 'http://sinalprivado.info:80/series/1533784/1533784/830429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105250, 7516, 'Terra Amarga S02 E73', 'http://sinalprivado.info:80/series/1533784/1533784/830430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105251, 7516, 'Terra Amarga S02 E74', 'http://sinalprivado.info:80/series/1533784/1533784/830431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105252, 7516, 'Terra Amarga S02 E75', 'http://sinalprivado.info:80/series/1533784/1533784/830432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105253, 7516, 'Terra Amarga S02 E76', 'http://sinalprivado.info:80/series/1533784/1533784/830433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105254, 7516, 'Terra Amarga S02 E77', 'http://sinalprivado.info:80/series/1533784/1533784/830434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105255, 7516, 'Terra Amarga S02 E78', 'http://sinalprivado.info:80/series/1533784/1533784/830435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105256, 7516, 'Terra Amarga S02 E79', 'http://sinalprivado.info:80/series/1533784/1533784/830436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105257, 7516, 'Terra Amarga S02 E80', 'http://sinalprivado.info:80/series/1533784/1533784/830437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105258, 7516, 'Terra Amarga S02 E81', 'http://sinalprivado.info:80/series/1533784/1533784/830438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105259, 7516, 'Terra Amarga S02 E82', 'http://sinalprivado.info:80/series/1533784/1533784/830439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105260, 7516, 'Terra Amarga S02 E83', 'http://sinalprivado.info:80/series/1533784/1533784/830440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105261, 7516, 'Terra Amarga S02 E84', 'http://sinalprivado.info:80/series/1533784/1533784/830441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105262, 7516, 'Terra Amarga S02 E85', 'http://sinalprivado.info:80/series/1533784/1533784/830442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105263, 7516, 'Terra Amarga S02 E86', 'http://sinalprivado.info:80/series/1533784/1533784/830443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105264, 7516, 'Terra Amarga S02 E87', 'http://sinalprivado.info:80/series/1533784/1533784/830444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105265, 7516, 'Terra Amarga S02 E88', 'http://sinalprivado.info:80/series/1533784/1533784/830445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105266, 7517, 'Terra Amarga S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/830446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105267, 7517, 'Terra Amarga S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/830447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105268, 7517, 'Terra Amarga S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/830448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105269, 7517, 'Terra Amarga S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/830449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105270, 7517, 'Terra Amarga S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/830450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105271, 7517, 'Terra Amarga S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/830451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105272, 7517, 'Terra Amarga S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/830452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105273, 7517, 'Terra Amarga S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/830453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105274, 7517, 'Terra Amarga S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/830454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105275, 7517, 'Terra Amarga S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/830455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105276, 7517, 'Terra Amarga S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/830456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105277, 7517, 'Terra Amarga S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/830457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105278, 7517, 'Terra Amarga S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/830458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105279, 7517, 'Terra Amarga S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/830459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105280, 7517, 'Terra Amarga S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/830460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105281, 7517, 'Terra Amarga S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/830461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105282, 7517, 'Terra Amarga S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/830462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105283, 7517, 'Terra Amarga S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/830463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105284, 7517, 'Terra Amarga S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/830464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105285, 7517, 'Terra Amarga S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/830465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105286, 7517, 'Terra Amarga S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/830466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105287, 7517, 'Terra Amarga S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/830467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105288, 7517, 'Terra Amarga S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/830468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105289, 7517, 'Terra Amarga S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/830469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105290, 7517, 'Terra Amarga S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/830470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105291, 7517, 'Terra Amarga S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/830471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105292, 7517, 'Terra Amarga S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/830472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105293, 7517, 'Terra Amarga S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/830473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105294, 7517, 'Terra Amarga S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/830474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105295, 7517, 'Terra Amarga S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/830475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105296, 7517, 'Terra Amarga S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/830476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105297, 7517, 'Terra Amarga S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/830477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105298, 7517, 'Terra Amarga S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/830478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105299, 7517, 'Terra Amarga S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/830479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105300, 7517, 'Terra Amarga S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/830480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105301, 7517, 'Terra Amarga S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/830481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105302, 7517, 'Terra Amarga S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/830482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105303, 7517, 'Terra Amarga S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/830483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105304, 7517, 'Terra Amarga S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/830484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105305, 7517, 'Terra Amarga S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/830485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105306, 7517, 'Terra Amarga S03 E41', 'http://sinalprivado.info:80/series/1533784/1533784/830486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105307, 7517, 'Terra Amarga S03 E42', 'http://sinalprivado.info:80/series/1533784/1533784/830487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105308, 7517, 'Terra Amarga S03 E43', 'http://sinalprivado.info:80/series/1533784/1533784/830488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105309, 7517, 'Terra Amarga S03 E44', 'http://sinalprivado.info:80/series/1533784/1533784/830489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105310, 7517, 'Terra Amarga S03 E45', 'http://sinalprivado.info:80/series/1533784/1533784/830490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105311, 7517, 'Terra Amarga S03 E46', 'http://sinalprivado.info:80/series/1533784/1533784/830491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105312, 7517, 'Terra Amarga S03 E47', 'http://sinalprivado.info:80/series/1533784/1533784/830492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105313, 7517, 'Terra Amarga S03 E48', 'http://sinalprivado.info:80/series/1533784/1533784/830493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105314, 7517, 'Terra Amarga S03 E49', 'http://sinalprivado.info:80/series/1533784/1533784/830494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105315, 7517, 'Terra Amarga S03 E50', 'http://sinalprivado.info:80/series/1533784/1533784/830495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105316, 7517, 'Terra Amarga S03 E51', 'http://sinalprivado.info:80/series/1533784/1533784/830496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105317, 7517, 'Terra Amarga S03 E52', 'http://sinalprivado.info:80/series/1533784/1533784/830497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105318, 7517, 'Terra Amarga S03 E53', 'http://sinalprivado.info:80/series/1533784/1533784/830498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105319, 7517, 'Terra Amarga S03 E54', 'http://sinalprivado.info:80/series/1533784/1533784/830499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105320, 7517, 'Terra Amarga S03 E55', 'http://sinalprivado.info:80/series/1533784/1533784/830500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105321, 7517, 'Terra Amarga S03 E56', 'http://sinalprivado.info:80/series/1533784/1533784/830501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105322, 7517, 'Terra Amarga S03 E57', 'http://sinalprivado.info:80/series/1533784/1533784/830502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105323, 7517, 'Terra Amarga S03 E58', 'http://sinalprivado.info:80/series/1533784/1533784/830503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105324, 7517, 'Terra Amarga S03 E59', 'http://sinalprivado.info:80/series/1533784/1533784/830504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105325, 7517, 'Terra Amarga S03 E60', 'http://sinalprivado.info:80/series/1533784/1533784/830505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105326, 7517, 'Terra Amarga S03 E61', 'http://sinalprivado.info:80/series/1533784/1533784/830506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105327, 7517, 'Terra Amarga S03 E62', 'http://sinalprivado.info:80/series/1533784/1533784/830507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105328, 7517, 'Terra Amarga S03 E63', 'http://sinalprivado.info:80/series/1533784/1533784/830508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105329, 7517, 'Terra Amarga S03 E64', 'http://sinalprivado.info:80/series/1533784/1533784/830509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105330, 7517, 'Terra Amarga S03 E65', 'http://sinalprivado.info:80/series/1533784/1533784/830510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105331, 7517, 'Terra Amarga S03 E66', 'http://sinalprivado.info:80/series/1533784/1533784/830511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105332, 7517, 'Terra Amarga S03 E67', 'http://sinalprivado.info:80/series/1533784/1533784/830512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105333, 7517, 'Terra Amarga S03 E68', 'http://sinalprivado.info:80/series/1533784/1533784/830513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105334, 7517, 'Terra Amarga S03 E69', 'http://sinalprivado.info:80/series/1533784/1533784/830514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105335, 7517, 'Terra Amarga S03 E70', 'http://sinalprivado.info:80/series/1533784/1533784/830515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105336, 7517, 'Terra Amarga S03 E71', 'http://sinalprivado.info:80/series/1533784/1533784/830516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105337, 7517, 'Terra Amarga S03 E72', 'http://sinalprivado.info:80/series/1533784/1533784/830517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105338, 7517, 'Terra Amarga S03 E73', 'http://sinalprivado.info:80/series/1533784/1533784/830518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105339, 7517, 'Terra Amarga S03 E74', 'http://sinalprivado.info:80/series/1533784/1533784/830519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105340, 7517, 'Terra Amarga S03 E75', 'http://sinalprivado.info:80/series/1533784/1533784/830520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105341, 7517, 'Terra Amarga S03 E76', 'http://sinalprivado.info:80/series/1533784/1533784/830521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105342, 7517, 'Terra Amarga S03 E77', 'http://sinalprivado.info:80/series/1533784/1533784/830522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105343, 7517, 'Terra Amarga S03 E78', 'http://sinalprivado.info:80/series/1533784/1533784/830523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105344, 7517, 'Terra Amarga S03 E79', 'http://sinalprivado.info:80/series/1533784/1533784/830524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105345, 7517, 'Terra Amarga S03 E80', 'http://sinalprivado.info:80/series/1533784/1533784/830525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105346, 7517, 'Terra Amarga S03 E81', 'http://sinalprivado.info:80/series/1533784/1533784/830526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105347, 7517, 'Terra Amarga S03 E82', 'http://sinalprivado.info:80/series/1533784/1533784/830527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105348, 7517, 'Terra Amarga S03 E83', 'http://sinalprivado.info:80/series/1533784/1533784/830528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105349, 7517, 'Terra Amarga S03 E84', 'http://sinalprivado.info:80/series/1533784/1533784/830529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105350, 7517, 'Terra Amarga S03 E85', 'http://sinalprivado.info:80/series/1533784/1533784/830530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105351, 7517, 'Terra Amarga S03 E86', 'http://sinalprivado.info:80/series/1533784/1533784/830531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105352, 7517, 'Terra Amarga S03 E87', 'http://sinalprivado.info:80/series/1533784/1533784/830532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105353, 7517, 'Terra Amarga S03 E88', 'http://sinalprivado.info:80/series/1533784/1533784/830533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105354, 7517, 'Terra Amarga S03 E89', 'http://sinalprivado.info:80/series/1533784/1533784/830534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105355, 7517, 'Terra Amarga S03 E90', 'http://sinalprivado.info:80/series/1533784/1533784/830535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105356, 7517, 'Terra Amarga S03 E91', 'http://sinalprivado.info:80/series/1533784/1533784/830536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105357, 7517, 'Terra Amarga S03 E92', 'http://sinalprivado.info:80/series/1533784/1533784/830537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105358, 7517, 'Terra Amarga S03 E93', 'http://sinalprivado.info:80/series/1533784/1533784/830538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105359, 7517, 'Terra Amarga S03 E94', 'http://sinalprivado.info:80/series/1533784/1533784/830539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105360, 7517, 'Terra Amarga S03 E95', 'http://sinalprivado.info:80/series/1533784/1533784/830540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105361, 7517, 'Terra Amarga S03 E96', 'http://sinalprivado.info:80/series/1533784/1533784/830541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105362, 7517, 'Terra Amarga S03 E97', 'http://sinalprivado.info:80/series/1533784/1533784/830542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105363, 7517, 'Terra Amarga S03 E98', 'http://sinalprivado.info:80/series/1533784/1533784/830543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105364, 7517, 'Terra Amarga S03 E99', 'http://sinalprivado.info:80/series/1533784/1533784/830544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105365, 7517, 'Terra Amarga S03 E100', 'http://sinalprivado.info:80/series/1533784/1533784/830545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105366, 7517, 'Terra Amarga S03 E101', 'http://sinalprivado.info:80/series/1533784/1533784/830546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105367, 7517, 'Terra Amarga S03 E102', 'http://sinalprivado.info:80/series/1533784/1533784/830547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105368, 7517, 'Terra Amarga S03 E103', 'http://sinalprivado.info:80/series/1533784/1533784/830548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105369, 7517, 'Terra Amarga S03 E104', 'http://sinalprivado.info:80/series/1533784/1533784/830549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105370, 7517, 'Terra Amarga S03 E105', 'http://sinalprivado.info:80/series/1533784/1533784/830550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105371, 7517, 'Terra Amarga S03 E106', 'http://sinalprivado.info:80/series/1533784/1533784/830551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105372, 7517, 'Terra Amarga S03 E107', 'http://sinalprivado.info:80/series/1533784/1533784/830552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105373, 7517, 'Terra Amarga S03 E108', 'http://sinalprivado.info:80/series/1533784/1533784/830553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105374, 7517, 'Terra Amarga S03 E109', 'http://sinalprivado.info:80/series/1533784/1533784/830554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105375, 7517, 'Terra Amarga S03 E110', 'http://sinalprivado.info:80/series/1533784/1533784/830555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105376, 7517, 'Terra Amarga S03 E111', 'http://sinalprivado.info:80/series/1533784/1533784/830556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105377, 7517, 'Terra Amarga S03 E112', 'http://sinalprivado.info:80/series/1533784/1533784/830557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105378, 7517, 'Terra Amarga S03 E113', 'http://sinalprivado.info:80/series/1533784/1533784/830558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105379, 7517, 'Terra Amarga S03 E114', 'http://sinalprivado.info:80/series/1533784/1533784/830559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105380, 7518, 'Terra Amarga S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/830560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105381, 7518, 'Terra Amarga S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/830561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105382, 7518, 'Terra Amarga S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/830562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105383, 7518, 'Terra Amarga S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/830563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105384, 7518, 'Terra Amarga S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/830564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105385, 7518, 'Terra Amarga S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/830565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105386, 7518, 'Terra Amarga S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/830566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105387, 7518, 'Terra Amarga S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/830567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105388, 7518, 'Terra Amarga S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/830568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105389, 7518, 'Terra Amarga S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/830569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105390, 7518, 'Terra Amarga S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/830570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105391, 7518, 'Terra Amarga S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/830571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105392, 7518, 'Terra Amarga S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/830572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105393, 7518, 'Terra Amarga S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/830573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105394, 7518, 'Terra Amarga S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/830574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105395, 7518, 'Terra Amarga S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/830575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105396, 7518, 'Terra Amarga S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/830576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105397, 7518, 'Terra Amarga S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/830577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105398, 7518, 'Terra Amarga S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/830578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105399, 7518, 'Terra Amarga S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/830579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105400, 7518, 'Terra Amarga S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/830580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105401, 7518, 'Terra Amarga S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/830581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105402, 7518, 'Terra Amarga S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/830582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105403, 7518, 'Terra Amarga S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/830583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105404, 7518, 'Terra Amarga S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/830584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105405, 7518, 'Terra Amarga S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/830585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105406, 7518, 'Terra Amarga S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/830586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105407, 7518, 'Terra Amarga S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/830587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105408, 7518, 'Terra Amarga S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/830588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105409, 7518, 'Terra Amarga S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/830589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105410, 7518, 'Terra Amarga S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/830590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105411, 7518, 'Terra Amarga S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/830591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105412, 7518, 'Terra Amarga S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/830592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105413, 7518, 'Terra Amarga S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/830593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105414, 7518, 'Terra Amarga S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/830594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105415, 7518, 'Terra Amarga S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/830595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105416, 7518, 'Terra Amarga S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/830596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105417, 7518, 'Terra Amarga S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/830597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105418, 7518, 'Terra Amarga S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/830598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105419, 7518, 'Terra Amarga S04 E40', 'http://sinalprivado.info:80/series/1533784/1533784/830599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105420, 7518, 'Terra Amarga S04 E41', 'http://sinalprivado.info:80/series/1533784/1533784/830600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105421, 7518, 'Terra Amarga S04 E42', 'http://sinalprivado.info:80/series/1533784/1533784/830601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105422, 7518, 'Terra Amarga S04 E43', 'http://sinalprivado.info:80/series/1533784/1533784/830602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105423, 7518, 'Terra Amarga S04 E44', 'http://sinalprivado.info:80/series/1533784/1533784/830603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105424, 7518, 'Terra Amarga S04 E45', 'http://sinalprivado.info:80/series/1533784/1533784/830604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105425, 7518, 'Terra Amarga S04 E46', 'http://sinalprivado.info:80/series/1533784/1533784/830605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105426, 7518, 'Terra Amarga S04 E47', 'http://sinalprivado.info:80/series/1533784/1533784/830606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105427, 7518, 'Terra Amarga S04 E48', 'http://sinalprivado.info:80/series/1533784/1533784/830607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105428, 7518, 'Terra Amarga S04 E49', 'http://sinalprivado.info:80/series/1533784/1533784/830608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105429, 7518, 'Terra Amarga S04 E50', 'http://sinalprivado.info:80/series/1533784/1533784/830609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105430, 7518, 'Terra Amarga S04 E51', 'http://sinalprivado.info:80/series/1533784/1533784/830610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105431, 7518, 'Terra Amarga S04 E52', 'http://sinalprivado.info:80/series/1533784/1533784/830611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105432, 7518, 'Terra Amarga S04 E53', 'http://sinalprivado.info:80/series/1533784/1533784/830612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105433, 7518, 'Terra Amarga S04 E54', 'http://sinalprivado.info:80/series/1533784/1533784/830613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105434, 7518, 'Terra Amarga S04 E55', 'http://sinalprivado.info:80/series/1533784/1533784/830614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105435, 7518, 'Terra Amarga S04 E56', 'http://sinalprivado.info:80/series/1533784/1533784/830615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105436, 7518, 'Terra Amarga S04 E57', 'http://sinalprivado.info:80/series/1533784/1533784/830616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105437, 7518, 'Terra Amarga S04 E58', 'http://sinalprivado.info:80/series/1533784/1533784/830617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105438, 7518, 'Terra Amarga S04 E59', 'http://sinalprivado.info:80/series/1533784/1533784/830618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6wp1xBZRJFXhJn3AFAm8E0yQK6E.jpg'),
(105439, 7519, 'The Tudors S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w4XSM4tn4DppQgE80jfmLojab5T.jpg'),
(105440, 7519, 'The Tudors S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a1PJKNPmT8VBTqV3N7EHolvI5GQ.jpg'),
(105441, 7519, 'The Tudors S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8VM4iAGCZvI9oZFDfOQqbuS2Up8.jpg'),
(105442, 7519, 'The Tudors S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AtKfYoMudXS99swKoGHSFPdHJoB.jpg'),
(105443, 7519, 'The Tudors S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qXvDya9x8eVB67i3ik41K76BRwU.jpg'),
(105444, 7519, 'The Tudors S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kwaoI3eBaWzA0ReutkZlt16KMTu.jpg'),
(105445, 7519, 'The Tudors S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ZZnRvtAMdT2kCIePyxCvWQmooo.jpg'),
(105446, 7519, 'The Tudors S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gek38UErjbfBJnwCfH1x22Vr6da.jpg'),
(105447, 7519, 'The Tudors S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/raUIyzFVZ18hZPcvSAHv47Iqc0g.jpg'),
(105448, 7519, 'The Tudors S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/axVc2NKOcYuXNVJfpMCxMEw5mfh.jpg'),
(105449, 7520, 'The Tudors S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pbXObQH3EhNPbDMCFGCQEC7xu8u.jpg'),
(105450, 7520, 'The Tudors S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eicQLciMpUjX4cI8NpNbsgmZ6Vd.jpg'),
(105451, 7520, 'The Tudors S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nTZ8DbJiq4CsauXgom9df5IdFRl.jpg'),
(105452, 7520, 'The Tudors S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xA3MlHs9i9knMs0egYJczn66HNx.jpg'),
(105453, 7520, 'The Tudors S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pCTzE8p7gk71bMh5XEtxMIK8JMf.jpg'),
(105454, 7520, 'The Tudors S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/98U9IxAfUX5yUkuBiOTT5kkqCxa.jpg'),
(105455, 7520, 'The Tudors S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cYYAmAjsRKZcwJ2ZCA24r1hCeyI.jpg'),
(105456, 7520, 'The Tudors S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wzSjIJchrP9lh5FJFCyP0sWT16g.jpg'),
(105457, 7520, 'The Tudors S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bXF8aS8jPKI3duyIQdDGHidS3YX.jpg'),
(105458, 7520, 'The Tudors S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u3As097GyAwrk7WopATgg1D7QBm.jpg'),
(105459, 7521, 'The Tudors S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nNwEDSmpBZBVtt3LV2qwM1UKf87.jpg'),
(105460, 7521, 'The Tudors S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qKOdKHaP7UvFI5fVJWgICqyD9t.jpg'),
(105461, 7521, 'The Tudors S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x84jBLWWlVyQm2SEorfG1uy4CZM.jpg'),
(105462, 7521, 'The Tudors S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dSb98JKvYjBGsLx00lHltmXROKl.jpg'),
(105463, 7521, 'The Tudors S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r6U4OiehYpbEacY92S20X7DJEB4.jpg'),
(105464, 7521, 'The Tudors S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1hTFLGATkE62kSbZW8F2LjsdF6w.jpg'),
(105465, 7521, 'The Tudors S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g6qrMqD156CbEPAxiQbXhL0XpD.jpg'),
(105466, 7521, 'The Tudors S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lu06FwcbfjBZ4ClukCpgznKkPZ.jpg'),
(105467, 7522, 'The Tudors S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aN0K95Y4hGG7kTSTYN5f4Y6d3cM.jpg'),
(105468, 7522, 'The Tudors S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9bjRX0vYdTj3ubEiZ9EUtUZOyME.jpg'),
(105469, 7522, 'The Tudors S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uUuqz7yF48kdjIqpbQuAnUzsv5.jpg'),
(105470, 7522, 'The Tudors S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iGCmxUAm3kJZfNgpMpSJ6PSQlrL.jpg'),
(105471, 7522, 'The Tudors S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j0LFcNyKjXoGA3eEAHNO0BQW1TT.jpg'),
(105472, 7522, 'The Tudors S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4yeBCkus2msip5RfxxiVh5ZBnrU.jpg'),
(105473, 7522, 'The Tudors S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hsgilgT7YpQ4TKHkQcLNUR47TFC.jpg'),
(105474, 7522, 'The Tudors S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Xqv5PZbmHnyOykxE09WQo5P5dY.jpg'),
(105475, 7522, 'The Tudors S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ntn2GkfDkseKdiCtId4j2jHVeq.jpg'),
(105476, 7522, 'The Tudors S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/DZzn8AOFu0qIwpHXkL5j1QNROs.jpg'),
(105477, 7523, 'A Mulher do Diabo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ejfzvZ6PXmMMGKN9F3LRpE11GR4.jpg'),
(105478, 7523, 'A Mulher do Diabo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dC2kobiRuWxzgNq2txrZdJ5g7VO.jpg'),
(105479, 7523, 'A Mulher do Diabo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/krJWvUHvrOE5ITlnZvmuzqE7SBW.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(105480, 7523, 'A Mulher do Diabo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aahe2W8bnpPV44W5fZnvNJh4FG0.jpg'),
(105481, 7523, 'A Mulher do Diabo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eaXYuyu44327adc37XP0RS1JJLM.jpg'),
(105482, 7523, 'A Mulher do Diabo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJWT339fjAfGC9FyOOfQHf2WB9t.jpg'),
(105483, 7523, 'A Mulher do Diabo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yOFw3WHQCy1GpVRnUWuZK2IIEdU.jpg'),
(105484, 7523, 'A Mulher do Diabo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ASmGKWQC6dhLQTfRIGwW0AZyTc.jpg'),
(105485, 7524, 'A Mulher do Diabo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2NQlxsd86RVYURjGMzR2oJZl0Wg.jpg'),
(105486, 7524, 'A Mulher do Diabo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2NQlxsd86RVYURjGMzR2oJZl0Wg.jpg'),
(105487, 7524, 'A Mulher do Diabo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2NQlxsd86RVYURjGMzR2oJZl0Wg.jpg'),
(105488, 7524, 'A Mulher do Diabo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2NQlxsd86RVYURjGMzR2oJZl0Wg.jpg'),
(105489, 7524, 'A Mulher do Diabo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2NQlxsd86RVYURjGMzR2oJZl0Wg.jpg'),
(105490, 7524, 'A Mulher do Diabo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2NQlxsd86RVYURjGMzR2oJZl0Wg.jpg'),
(105491, 7524, 'A Mulher do Diabo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2NQlxsd86RVYURjGMzR2oJZl0Wg.jpg'),
(105492, 7524, 'A Mulher do Diabo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2NQlxsd86RVYURjGMzR2oJZl0Wg.jpg'),
(105493, 7525, 'A Mulher do Diabo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/323086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2NQlxsd86RVYURjGMzR2oJZl0Wg.jpg'),
(105494, 7525, 'A Mulher do Diabo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/323087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2NQlxsd86RVYURjGMzR2oJZl0Wg.jpg'),
(105495, 7525, 'A Mulher do Diabo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/323088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2NQlxsd86RVYURjGMzR2oJZl0Wg.jpg'),
(105496, 7525, 'A Mulher do Diabo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/323089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2NQlxsd86RVYURjGMzR2oJZl0Wg.jpg'),
(105497, 7525, 'A Mulher do Diabo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/323090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2NQlxsd86RVYURjGMzR2oJZl0Wg.jpg'),
(105498, 7525, 'A Mulher do Diabo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/323091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2NQlxsd86RVYURjGMzR2oJZl0Wg.jpg'),
(105499, 7525, 'A Mulher do Diabo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/323092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2NQlxsd86RVYURjGMzR2oJZl0Wg.jpg'),
(105500, 7525, 'A Mulher do Diabo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/323093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2NQlxsd86RVYURjGMzR2oJZl0Wg.jpg'),
(105501, 7525, 'A Mulher do Diabo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/323094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2NQlxsd86RVYURjGMzR2oJZl0Wg.jpg'),
(105502, 7525, 'A Mulher do Diabo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/323095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2NQlxsd86RVYURjGMzR2oJZl0Wg.jpg'),
(105503, 5976, 'A Ponte: The Bridge Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217320.mp4', 'http://timg.bdta.pro/images/2e6d155c807079e211610eee9d5029df.jpg'),
(105504, 5976, 'A Ponte: The Bridge Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217321.mp4', 'http://timg.bdta.pro/images/0cd5ba35142521808c6151ddf0fe0e2f.jpg'),
(105505, 5976, 'A Ponte: The Bridge Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217322.mp4', 'http://timg.bdta.pro/images/29ab5b8a3b2e6527f2b9cf6a9ceaea45.jpg'),
(105506, 5976, 'A Ponte: The Bridge Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217323.mp4', 'http://timg.bdta.pro/images/e89196a9c4091c2b27dd3884d099f4b1.jpg'),
(105507, 5976, 'A Ponte: The Bridge Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217324.mp4', 'http://timg.bdta.pro/images/dd125fd5fd22ab3152f97ddd2f6be62f.jpg'),
(105508, 5976, 'A Ponte: The Bridge Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217325.mp4', 'http://timg.bdta.pro/images/4e0278acdeec4863f85bec7b24a2676c.jpg'),
(105509, 5976, 'A Ponte: The Bridge Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217326.mp4', 'http://timg.bdta.pro/images/38deabc078cb8ffba0666813546971a4.jpg'),
(105510, 5976, 'A Ponte: The Bridge Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217327.mp4', 'http://timg.bdta.pro/images/677a6759bb673834b9448008129b3dd8.jpg'),
(105511, 7526, 'Amor Platônico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1KYObNxzT45sUuGUWw5Em8DmCyy.jpg'),
(105512, 7526, 'Amor Platônico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xydh0dxpHJYEznXaAXXO6iu0lnC.jpg'),
(105513, 7526, 'Amor Platônico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4US9L1Fs7izSsnZI6hImOBRQPYA.jpg'),
(105514, 7526, 'Amor Platônico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223501.mp4', 'http://image.tmdb.org/t/p/w1280/68X2LD15cwIi8ohWHMhWSEujk7J.jpg'),
(105515, 7526, 'Amor Platônico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223502.mp4', 'http://image.tmdb.org/t/p/w1280/7SPcziyvMxUCnZLVJUC8SSKPhk.jpg'),
(105516, 7526, 'Amor Platônico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223503.mp4', 'http://image.tmdb.org/t/p/w1280/zREBlNPB056XsSQk7IPbAXJ2vfl.jpg'),
(105517, 7526, 'Amor Platônico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223504.mp4', 'http://image.tmdb.org/t/p/w1280/fcJBIWaW2Ld8zkoopu6ZMhbN1A2.jpg'),
(105518, 7526, 'Amor Platônico S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223505.mp4', 'http://image.tmdb.org/t/p/w1280/xzzLgC1ELYRZuBRVTc0Fm7yGg2o.jpg'),
(105519, 7526, 'Amor Platônico S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223506.mp4', 'http://image.tmdb.org/t/p/w1280/5s5TypxgHs87I9lc57EED9ApZjk.jpg'),
(105520, 7526, 'Amor Platônico S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223507.mp4', 'http://image.tmdb.org/t/p/w1280/yjrJwtoDvMo7obZpAZpBuPNZKG5.jpg'),
(105521, 7527, 'Amor Platônico S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/879998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69ZB5ZGxWJI7WpdlQKIVgonCFU1.jpg'),
(105522, 7527, 'Amor Platônico S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/879999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69ZB5ZGxWJI7WpdlQKIVgonCFU1.jpg'),
(105523, 7527, 'Amor Platônico S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/880416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69ZB5ZGxWJI7WpdlQKIVgonCFU1.jpg'),
(105524, 7527, 'Amor Platônico S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/881257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69ZB5ZGxWJI7WpdlQKIVgonCFU1.jpg'),
(105525, 7527, 'Amor Platônico S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/881360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69ZB5ZGxWJI7WpdlQKIVgonCFU1.jpg'),
(105526, 7527, 'Amor Platônico S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/882879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69ZB5ZGxWJI7WpdlQKIVgonCFU1.jpg'),
(105527, 7527, 'Amor Platônico S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/883838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69ZB5ZGxWJI7WpdlQKIVgonCFU1.jpg'),
(105528, 7527, 'Amor Platônico S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/885341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69ZB5ZGxWJI7WpdlQKIVgonCFU1.jpg'),
(105529, 7527, 'Amor Platônico S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/886107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69ZB5ZGxWJI7WpdlQKIVgonCFU1.jpg'),
(105530, 7527, 'Amor Platônico S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/887643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69ZB5ZGxWJI7WpdlQKIVgonCFU1.jpg'),
(105531, 7528, 'As Ginastas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cbZ3hBynkwonuEnv9iglmUVuksg.jpg'),
(105532, 7528, 'As Ginastas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cbZ3hBynkwonuEnv9iglmUVuksg.jpg'),
(105533, 7528, 'As Ginastas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cbZ3hBynkwonuEnv9iglmUVuksg.jpg'),
(105534, 7528, 'As Ginastas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cbZ3hBynkwonuEnv9iglmUVuksg.jpg'),
(105535, 7528, 'As Ginastas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cbZ3hBynkwonuEnv9iglmUVuksg.jpg'),
(105536, 7528, 'As Ginastas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cbZ3hBynkwonuEnv9iglmUVuksg.jpg'),
(105537, 7529, 'Feridas do Passado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6XoEUavtSIY7jcPMvUVNfdiFb7K.jpg'),
(105538, 7529, 'Feridas do Passado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ff24EcpFSwS682kIQafCwPWGPRE.jpg'),
(105539, 7529, 'Feridas do Passado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oYzO9SYsUAdQFlxbs5dfUhDmGag.jpg'),
(105540, 7529, 'Feridas do Passado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gx8YXMU0yZXf6ImzazbhS1tirxn.jpg'),
(105541, 7529, 'Feridas do Passado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kWIsSvQSVibKcGNFzxScClQWIsh.jpg'),
(105542, 7529, 'Feridas do Passado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4g8UWUvf3xEND9easuWSd3jxACP.jpg'),
(105543, 7529, 'Feridas do Passado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGBEeA0jMvNLq7mqKaazM6b6U2u.jpg'),
(105544, 7529, 'Feridas do Passado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kNHzqtICrTWo8BkYycrSC1ZAfl5.jpg'),
(105545, 7529, 'Feridas do Passado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2wmLRAJIDuIGSKyuUfxdWcVxxK7.jpg'),
(105546, 7529, 'Feridas do Passado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5myCXBywKFPJ8udPybx2y6fM14w.jpg'),
(105547, 7529, 'Feridas do Passado S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3S6EKIJwUaP5OOENEu7b0PE9YuK.jpg'),
(105548, 7529, 'Feridas do Passado S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/taWW77c7StoiupB8jBG14LiXFes.jpg'),
(105549, 7529, 'Feridas do Passado S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/23FFO15aXF27qoJ9Jek3t8KfHF2.jpg'),
(105550, 7530, 'Fubar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9siVkL01SX80Ynp3gXCQmbhm8RS.jpg'),
(105551, 7530, 'Fubar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1IAiiCDxTl0AuSCr1bhIzrhQsH8.jpg'),
(105552, 7530, 'Fubar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uFB0JisNqDHYteopbo8SNo44vmJ.jpg'),
(105553, 7530, 'Fubar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhQdRh9ZhbVIQ4O7hGvDm0JtD1U.jpg'),
(105554, 7530, 'Fubar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aPDMDbWlv0dn1DNiIjBGwPeg6O4.jpg'),
(105555, 7530, 'Fubar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/huV19z9ozKsmDqhznwrzCVhfwNH.jpg'),
(105556, 7530, 'Fubar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4posO0yEJuIF2D2jClRtTAmLCvK.jpg'),
(105557, 7530, 'Fubar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Iox7uqxMy4FS2GBZIj8ZyrYFhm.jpg'),
(105558, 7531, 'Fubar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/866003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lWbZzSzt5VCIJ8Z5zNkZ1dUWNax.jpg'),
(105559, 7531, 'Fubar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/866004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pKaK4qFbV6g4kSLOgSMTfYZVrfi.jpg'),
(105560, 7531, 'Fubar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/866005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nBNU6hXc2AY44KZgD82mtTBuPap.jpg'),
(105561, 7531, 'Fubar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/866006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g8tKR7w6M3Mdl4hHlGWbwlo0iUo.jpg'),
(105562, 7531, 'Fubar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/866007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jICQ62ncwWn0OPSxOqotuyWuy0e.jpg'),
(105563, 7531, 'Fubar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/866008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ge6LBsX5PvWCCvEYrGK3LVlTqWg.jpg'),
(105564, 7531, 'Fubar S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/866009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c88CI3qrxaux54BKyNYYEWcPKdX.jpg'),
(105565, 7531, 'Fubar S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/866010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv4jG703SJjO7z6GmlndpkV3wBQ.jpg'),
(105566, 7532, 'Gremlins: Segredos dos Mogwai S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qFh7vrtHL3xfpwUIJsi6du32MfU.jpg'),
(105567, 7532, 'Gremlins: Segredos dos Mogwai S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2aeXLjJVyu24SGVAamrp0TbQN9Q.jpg'),
(105568, 7532, 'Gremlins: Segredos dos Mogwai S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220145.mp4', 'http://image.tmdb.org/t/p/w1280/j5JM30um3oL0tlbfYPRDLOrRv9U.jpg'),
(105569, 7532, 'Gremlins: Segredos dos Mogwai S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220146.mp4', 'http://image.tmdb.org/t/p/w1280/veIPcVROXFFi6ZcZr4ORrO51uPp.jpg'),
(105570, 7532, 'Gremlins: Segredos dos Mogwai S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7dQISLQdRUCvA2AKwdNSTlUls8.jpg'),
(105571, 7532, 'Gremlins: Segredos dos Mogwai S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bmXuSsN78x6u5jP7fpmzDrOwfMw.jpg'),
(105572, 7532, 'Gremlins: Segredos dos Mogwai S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ujH1FGeSQnSzIdGfeETZxOinnph.jpg'),
(105573, 7532, 'Gremlins: Segredos dos Mogwai S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ujH1FGeSQnSzIdGfeETZxOinnph.jpg'),
(105574, 7532, 'Gremlins: Segredos dos Mogwai S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220151.mp4', 'http://image.tmdb.org/t/p/w1280/wnkf5unPHkx7ioyiP5RnufiQ1kC.jpg'),
(105575, 7532, 'Gremlins: Segredos dos Mogwai S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220152.mp4', 'http://image.tmdb.org/t/p/w1280/yZxPaL9SJfbIER0YNh9WABhoV79.jpg'),
(105576, 7533, 'Gremlins: Segredos dos Mogwai S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/492795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ujH1FGeSQnSzIdGfeETZxOinnph.jpg'),
(105577, 7533, 'Gremlins: Segredos dos Mogwai S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/492796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ujH1FGeSQnSzIdGfeETZxOinnph.jpg'),
(105578, 7533, 'Gremlins: Segredos dos Mogwai S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/492797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ujH1FGeSQnSzIdGfeETZxOinnph.jpg'),
(105579, 7533, 'Gremlins: Segredos dos Mogwai S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/492798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ujH1FGeSQnSzIdGfeETZxOinnph.jpg'),
(105580, 7533, 'Gremlins: Segredos dos Mogwai S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/492799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ujH1FGeSQnSzIdGfeETZxOinnph.jpg'),
(105581, 7533, 'Gremlins: Segredos dos Mogwai S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/766766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ujH1FGeSQnSzIdGfeETZxOinnph.jpg'),
(105582, 7533, 'Gremlins: Segredos dos Mogwai S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/766767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ujH1FGeSQnSzIdGfeETZxOinnph.jpg'),
(105583, 7533, 'Gremlins: Segredos dos Mogwai S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/766768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ujH1FGeSQnSzIdGfeETZxOinnph.jpg'),
(105584, 7533, 'Gremlins: Segredos dos Mogwai S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/766769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ujH1FGeSQnSzIdGfeETZxOinnph.jpg'),
(105585, 7533, 'Gremlins: Segredos dos Mogwai S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/766770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ujH1FGeSQnSzIdGfeETZxOinnph.jpg'),
(105586, 7534, 'Irmãos Construtores e a Fábrica de Sonhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(105587, 7534, 'Irmãos Construtores e a Fábrica de Sonhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(105588, 7534, 'Irmãos Construtores e a Fábrica de Sonhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(105589, 7534, 'Irmãos Construtores e a Fábrica de Sonhos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(105590, 7534, 'Irmãos Construtores e a Fábrica de Sonhos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(105591, 7534, 'Irmãos Construtores e a Fábrica de Sonhos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(105592, 7534, 'Irmãos Construtores e a Fábrica de Sonhos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(105593, 7534, 'Irmãos Construtores e a Fábrica de Sonhos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(105594, 7534, 'Irmãos Construtores e a Fábrica de Sonhos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(105595, 7535, 'Mar Branco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBj7XnuvQfaACI20YwSjW3K3wb0.jpg'),
(105596, 7535, 'Mar Branco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdSRSweoIpAqxp8u298c3q0Q2sS.jpg'),
(105597, 7535, 'Mar Branco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dpdmqpl0N4RlOuoxHWQ8rT0ZRi9.jpg'),
(105598, 7535, 'Mar Branco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cBI1Q2tSS9xqq3Jx4Pk0WP1af1W.jpg'),
(105599, 7535, 'Mar Branco S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfip3ZZ6stP2OAYEFTWVCBOaczm.jpg'),
(105600, 7535, 'Mar Branco S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xSwEUTuaLvv2fTbAd8H0cUfe54B.jpg'),
(105601, 7535, 'Mar Branco S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBksQP3PlxWZWYxWI7zDycnXod8.jpg'),
(105602, 7536, 'Mecânica em Família S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AreUldTLWKOcunX6Qy5wVpDFcNt.jpg'),
(105603, 7536, 'Mecânica em Família S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJBoULxulfa0EO9x2WMFlJpm0jr.jpg'),
(105604, 7536, 'Mecânica em Família S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kb0ESds5tkNV79OeHurjqlWPuYb.jpg'),
(105605, 7536, 'Mecânica em Família S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bz5PmsTfJh6JC3p3GQZKGENChDZ.jpg'),
(105606, 7536, 'Mecânica em Família S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a1Ud6VpSHY0cBh5cFKEF3cq4KVw.jpg'),
(105607, 7536, 'Mecânica em Família S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tPxEweeUrjGRkxq3BpF0H7wFGkV.jpg'),
(105608, 7536, 'Mecânica em Família S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzjP82PVIEXP3MEMXpsvujcDBL9.jpg'),
(105609, 7536, 'Mecânica em Família S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUWWtiuTe70woVVJbkAKHp5Y4Tc.jpg'),
(105610, 7537, 'O Grifo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hCuEAs68EuvItzDVFg2FM0q2NCQ.jpg'),
(105611, 7537, 'O Grifo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tQFVP5Erlr2HNwsu3Wt7SV7Y9Eq.jpg'),
(105612, 7537, 'O Grifo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jKhwDDKcyRC5vjxNfETlzrB2h8l.jpg'),
(105613, 7537, 'O Grifo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pZ9wSrULtmyQK2PqIHiCvxbKyHd.jpg'),
(105614, 7537, 'O Grifo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fQWbmvcLd2sh9z07umZNSUsWXAw.jpg'),
(105615, 7537, 'O Grifo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n6OyfKb8Er9rhgDPOiEuaxu3Y81.jpg'),
(105616, 7538, 'O Renovador S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZE1DIPHSD37GP1OZ8Zpi5hHBP.jpg'),
(105617, 7538, 'O Renovador S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4HHMfkxLadE3YCMYnAk5UQI3TUp.jpg'),
(105618, 7538, 'O Renovador S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ayWQifUPis6rj3ggRdR3Nsq8BYf.jpg'),
(105619, 7538, 'O Renovador S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rKT4Gp2MSirTCYaW0zPiCKD2kfx.jpg'),
(105620, 7538, 'O Renovador S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ajSt0Ta5GYwLy1svYD2qFTEF4QQ.jpg'),
(105621, 7538, 'O Renovador S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ajSt0Ta5GYwLy1svYD2qFTEF4QQ.jpg'),
(105622, 7538, 'O Renovador S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ajSt0Ta5GYwLy1svYD2qFTEF4QQ.jpg'),
(105623, 7538, 'O Renovador S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ajSt0Ta5GYwLy1svYD2qFTEF4QQ.jpg'),
(105624, 7539, 'O Ultimato: Queer Love S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4rKQpTZVUnceqzpIN5VGAltXHcv.jpg'),
(105625, 7539, 'O Ultimato: Queer Love S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzVrydvyYHmU9x9wNuBDn724BRJ.jpg'),
(105626, 7539, 'O Ultimato: Queer Love S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h10nF7rvH4HTIu3x8pG0yCkn0wX.jpg'),
(105627, 7539, 'O Ultimato: Queer Love S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pMd7eV9JB9CSa3h0etliOlxsSMC.jpg'),
(105628, 7539, 'O Ultimato: Queer Love S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7vPQQlkIq0Jk3nbeVF15zVSPNsX.jpg'),
(105629, 7539, 'O Ultimato: Queer Love S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZ62xzCh1IIgyHEkY7rHPUTZ02X.jpg'),
(105630, 7539, 'O Ultimato: Queer Love S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zyNbamGRvF0T5y8hU3LxAdZLdCu.jpg'),
(105631, 7539, 'O Ultimato: Queer Love S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ia0un5LBhpy6g73F7oARF1wPIFA.jpg'),
(105632, 7539, 'O Ultimato: Queer Love S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215400.mp4', 'http://image.tmdb.org/t/p/w1280/1hSw9aQmp9JGWdSpsHUXXO1tqdT.jpg'),
(105633, 7539, 'O Ultimato: Queer Love S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215401.mp4', 'http://image.tmdb.org/t/p/w1280/rbaE8fWWLcamTByA1Z6OTWSc8r9.jpg'),
(105634, 7540, 'O Ultimato: Queer Love S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/855816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5oRJHZ0xf4koXbNKONacJUw3Rdg.jpg'),
(105635, 7540, 'O Ultimato: Queer Love S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/855817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5oRJHZ0xf4koXbNKONacJUw3Rdg.jpg'),
(105636, 7540, 'O Ultimato: Queer Love S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/855818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5oRJHZ0xf4koXbNKONacJUw3Rdg.jpg'),
(105637, 7540, 'O Ultimato: Queer Love S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/855819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5oRJHZ0xf4koXbNKONacJUw3Rdg.jpg'),
(105638, 7540, 'O Ultimato: Queer Love S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/855820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5oRJHZ0xf4koXbNKONacJUw3Rdg.jpg'),
(105639, 7540, 'O Ultimato: Queer Love S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/855821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5oRJHZ0xf4koXbNKONacJUw3Rdg.jpg'),
(105640, 7540, 'O Ultimato: Queer Love S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/855822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5oRJHZ0xf4koXbNKONacJUw3Rdg.jpg'),
(105641, 7540, 'O Ultimato: Queer Love S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/855823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5oRJHZ0xf4koXbNKONacJUw3Rdg.jpg'),
(105642, 7540, 'O Ultimato: Queer Love S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/855824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5oRJHZ0xf4koXbNKONacJUw3Rdg.jpg'),
(105643, 7540, 'O Ultimato: Queer Love S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/880492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5oRJHZ0xf4koXbNKONacJUw3Rdg.jpg'),
(105644, 2857, 'Seduced: Inside the NXIVM Cult S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qhgf2jIcjYYy7UiZNvDjD2Ge7t5.jpg'),
(105645, 2857, 'Seduced: Inside the NXIVM Cult S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/27sixTmsBSxhorloJ8GAyXFfRzF.jpg'),
(105646, 2857, 'Seduced: Inside the NXIVM Cult S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Kxz6EbqHOJtmQMTZ2siLShW2y0.jpg'),
(105647, 2857, 'Seduced: Inside the NXIVM Cult S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYfoDG6h3F33TxVx8m8LTgAzaID.jpg'),
(105648, 7541, 'Smartless: Na Estrada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sKtCe3HNfua648e5gxtP2xP8VeZ.jpg'),
(105649, 7541, 'Smartless: Na Estrada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fzGmwHZdc5uShKHk2UED9AS3Yfn.jpg'),
(105650, 7541, 'Smartless: Na Estrada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FSuUslzGdKdy40SoQb0dVH6I7I.jpg'),
(105651, 7541, 'Smartless: Na Estrada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o7uv71PRbGBqxIuPP1y9e82kCXC.jpg'),
(105652, 7541, 'Smartless: Na Estrada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7AV8JfqDAueJY27Yvl80THHwtqc.jpg'),
(105653, 7541, 'Smartless: Na Estrada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d5CMeuMOB5aWHij56IoRafxp3vi.jpg'),
(105654, 7542, 'VGLY S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2AlnhDcWM37q0a3E9XdN0rGEPid.jpg'),
(105655, 7542, 'VGLY S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hoVhAk1onxQ8zXKpbXn9zqxuOwc.jpg'),
(105656, 7542, 'VGLY S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kPuoEhpiaUBl1bRFedEuElpl693.jpg'),
(105657, 7542, 'VGLY S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uUYxynziOs8gaYQDxO5WU8evtaX.jpg'),
(105658, 7542, 'VGLY S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p1ZzGE1sgRfEarCaDA9xvMKfYFd.jpg'),
(105659, 7542, 'VGLY S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/foPA32QUtPdU34h3xSihef1NB3j.jpg'),
(105660, 7542, 'VGLY S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8NgYhcygPlajzfxE8lTrr0Qc0lh.jpg'),
(105661, 7542, 'VGLY S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220418.mp4', 'http://image.tmdb.org/t/p/w1280/cbgfLJqiK3bcbqYrmsegS3XQi28.jpg'),
(105662, 7542, 'VGLY S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220419.mp4', 'http://image.tmdb.org/t/p/w1280/pGuhdMIa4HNf6pcsqxeU9liv5gU.jpg'),
(105663, 7542, 'VGLY S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/SYvwtsk4vWPAtB0wlgLlecWCFc.jpg'),
(105664, 7542, 'VGLY S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/SYvwtsk4vWPAtB0wlgLlecWCFc.jpg'),
(105665, 7542, 'VGLY S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220422.mp4', 'http://image.tmdb.org/t/p/w1280/s46R2QYyLwB0Zou5uENbfhkdvZ1.jpg'),
(105666, 7542, 'VGLY S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/220423.mp4', 'http://image.tmdb.org/t/p/w1280/qKq14TFQ6oHUb1FtHTe1gaKFTSa.jpg'),
(105667, 7543, 'VGLY S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/889594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/SYvwtsk4vWPAtB0wlgLlecWCFc.jpg'),
(105668, 7543, 'VGLY S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/889595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/SYvwtsk4vWPAtB0wlgLlecWCFc.jpg'),
(105669, 7543, 'VGLY S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/890632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/SYvwtsk4vWPAtB0wlgLlecWCFc.jpg'),
(105670, 7543, 'VGLY S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/890633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/SYvwtsk4vWPAtB0wlgLlecWCFc.jpg'),
(105671, 7543, 'VGLY S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/891811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/SYvwtsk4vWPAtB0wlgLlecWCFc.jpg'),
(105672, 7543, 'VGLY S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/892404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/SYvwtsk4vWPAtB0wlgLlecWCFc.jpg'),
(105673, 7543, 'VGLY S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/893549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/SYvwtsk4vWPAtB0wlgLlecWCFc.jpg'),
(105674, 7543, 'VGLY S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/893550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/SYvwtsk4vWPAtB0wlgLlecWCFc.jpg'),
(105675, 7543, 'VGLY S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/894183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/SYvwtsk4vWPAtB0wlgLlecWCFc.jpg'),
(105676, 7543, 'VGLY S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/895809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/SYvwtsk4vWPAtB0wlgLlecWCFc.jpg'),
(105677, 7544, '90 Dias Para Casar Seguindo Jorge e Anfisa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216478.mp4', 'https://i.bj-share.info/1a799589b6429071c35e7de7b4126f72.jpg'),
(105678, 7544, '90 Dias Para Casar Seguindo Jorge e Anfisa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216479.mp4', 'https://i.bj-share.info/1a799589b6429071c35e7de7b4126f72.jpg'),
(105679, 7544, '90 Dias Para Casar Seguindo Jorge e Anfisa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216480.mp4', 'https://i.bj-share.info/1a799589b6429071c35e7de7b4126f72.jpg'),
(105680, 7544, '90 Dias Para Casar Seguindo Jorge e Anfisa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216481.mp4', 'https://i.bj-share.info/1a799589b6429071c35e7de7b4126f72.jpg'),
(105681, 7544, '90 Dias Para Casar Seguindo Jorge e Anfisa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216482.mp4', 'https://i.bj-share.info/1a799589b6429071c35e7de7b4126f72.jpg'),
(105682, 7544, '90 Dias Para Casar Seguindo Jorge e Anfisa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216483.mp4', 'https://i.bj-share.info/1a799589b6429071c35e7de7b4126f72.jpg'),
(105683, 7544, '90 Dias Para Casar Seguindo Jorge e Anfisa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216484.mp4', 'https://i.bj-share.info/1a799589b6429071c35e7de7b4126f72.jpg'),
(105684, 7544, '90 Dias Para Casar Seguindo Jorge e Anfisa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216485.mp4', 'https://i.bj-share.info/1a799589b6429071c35e7de7b4126f72.jpg'),
(105685, 7544, '90 Dias Para Casar Seguindo Jorge e Anfisa S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216486.mp4', 'https://i.bj-share.info/1a799589b6429071c35e7de7b4126f72.jpg'),
(105686, 7544, '90 Dias Para Casar Seguindo Jorge e Anfisa S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216487.mp4', 'https://i.bj-share.info/1a799589b6429071c35e7de7b4126f72.jpg'),
(105687, 7545, 'A Atriz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d37zakaC8H8GDaNQxdw6HW8Keah.jpg'),
(105688, 7545, 'A Atriz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/avav3pA2EMGK8hdnbg2xjpTYznC.jpg'),
(105689, 7545, 'A Atriz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7dmjEK0TGT3SLn85LVOOiPjNS9L.jpg'),
(105690, 7545, 'A Atriz S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oCEC7vsr8uO6tV9c22Yb8twJc7F.jpg'),
(105691, 7545, 'A Atriz S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i9UvpyRTxyA9kzNnEk51yLEbZy8.jpg'),
(105692, 7545, 'A Atriz S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sDcz7kbJlxUaSLRgmOZYpC1R8ge.jpg'),
(105693, 7545, 'A Atriz S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wPLVdYfuhHutQ1AZvoyfTKuhn8B.jpg'),
(105694, 7545, 'A Atriz S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/euuSNbdlYm15X8m0hunMsP192pk.jpg'),
(105695, 7546, 'A Vingança do Nerd S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5WXQ2u5QxRUSgWhS4ctTpNgNBMI.jpg'),
(105696, 7546, 'A Vingança do Nerd S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x23fMUKrkNHlHDhjeJAdizGQELx.jpg'),
(105697, 7546, 'A Vingança do Nerd S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229272.mp4', 'http://image.tmdb.org/t/p/w1280/ctR0790zebKNaSUaWDHdSsYLqT3.jpg'),
(105698, 7546, 'A Vingança do Nerd S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229273.mp4', 'http://image.tmdb.org/t/p/w1280/26fqxJ3mfAcMaW0Y7y7lEh7a6E8.jpg'),
(105699, 7546, 'A Vingança do Nerd S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8oHUbYocJysIHaFelRnJ8XjS7va.jpg'),
(105700, 7546, 'A Vingança do Nerd S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8oHUbYocJysIHaFelRnJ8XjS7va.jpg'),
(105701, 7546, 'A Vingança do Nerd S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8oHUbYocJysIHaFelRnJ8XjS7va.jpg'),
(105702, 7547, 'Agency S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tPvp0EAK1u9QXkCYa4nlbOJcgwg.jpg'),
(105703, 7547, 'Agency S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCVwnvk3JZBAMLBMIPAZxNtquwy.jpg'),
(105704, 7547, 'Agency S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mCFPkJbDdbBbpNbzBuNoqok13zi.jpg'),
(105705, 7547, 'Agency S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e7BdRe9ZaZbVkKWt7tzBQJ2myEw.jpg'),
(105706, 7547, 'Agency S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5NLy6MjiksyFZ5lXEAjp2muEGQh.jpg'),
(105707, 7547, 'Agency S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AmtAoXaSRW8qSZn3kd8STyYpLTE.jpg'),
(105708, 7547, 'Agency S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ed7uUlVxKn51NtBg1oBLLe4Uq9.jpg'),
(105709, 7547, 'Agency S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A7u4DopTghxDnM0WuS13VLAKR4Z.jpg'),
(105710, 7547, 'Agency S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k5NFkyYHpn89JDYbkQeovHyOAah.jpg'),
(105711, 7547, 'Agency S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/alvZPY5PhxNy4DkS80HHw6rNfge.jpg'),
(105712, 7547, 'Agency S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2SjRAPNklMqLHdTkq7IBbK7IgGs.jpg'),
(105713, 7547, 'Agency S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lSpD8t5HFUufl6JJ0K73ru8rvU8.jpg'),
(105714, 7547, 'Agency S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yeiOALXrBkBiDWGc5lMBykXUSn9.jpg'),
(105715, 7547, 'Agency S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/peLA0gLmDV7fDUe2QWzcsBiDW0G.jpg'),
(105716, 7547, 'Agency S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/216468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sBsEFcpe3SEUjNAAYKJoo0rzNQ.jpg'),
(105717, 7547, 'Agency S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/216469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iLW0GxYhTGy6CiUITGmmQXSrfgh.jpg'),
(105718, 7548, 'Barracuda Queens S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rHgPVIKHes6q5BHdbobecoyLvSE.jpg'),
(105719, 7548, 'Barracuda Queens S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9cOfpy0ZsHDXVVBykzEwShbVCQn.jpg'),
(105720, 7548, 'Barracuda Queens S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3NvOO5x4NxydfEkZn00R21RIL3n.jpg'),
(105721, 7548, 'Barracuda Queens S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rQIat5C8fL4KRYVx4LieEZSdQ8U.jpg'),
(105722, 7548, 'Barracuda Queens S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f1uP9RyGCdl9eXEyyMaDufAF5WA.jpg'),
(105723, 7548, 'Barracuda Queens S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e2dE62faR9ryjaKhWO2c9Oi5OSR.jpg'),
(105724, 7549, 'Chibiverso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lS1JPZse6gnWnl7isxSNxb55b7z.jpg'),
(105725, 7549, 'Chibiverso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7FCrVIv4mUZrpCiEh7Cuz7LpPst.jpg'),
(105726, 7549, 'Chibiverso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ptijynEa95rEhnR4Ru7tGDqFcbQ.jpg'),
(105727, 7549, 'Chibiverso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sfLdBGHL0qsIqP7IsuMxgTYA890.jpg'),
(105728, 7550, 'Coisa de Menino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5VVf6jtJL1N8Ipw56Drp3hrEHeD.jpg'),
(105729, 7550, 'Coisa de Menino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pTL9fwkGFEAMZyKbiOqLEIIxhS.jpg'),
(105730, 7550, 'Coisa de Menino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4ptHFa8avQujmUtO73vg2PnZU5.jpg'),
(105731, 7550, 'Coisa de Menino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rA2HmJGvXUFTTX3ETvM15Db0jyR.jpg'),
(105732, 7550, 'Coisa de Menino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFgaPchSd4i1mW7Upgq15Y8DxlA.jpg'),
(105733, 7551, 'Deadloch S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hcdiepBUX8ofrt9xhh29io6LsZn.jpg'),
(105734, 7551, 'Deadloch S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/BOqDHzh2SGHSKc46rK1laQxZl6.jpg'),
(105735, 7551, 'Deadloch S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6H422ecsTVm1CnupZ7UclzAKiXk.jpg'),
(105736, 7551, 'Deadloch S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217833.mp4', 'http://image.tmdb.org/t/p/w1280/1KDSnVZ56jV4FSrH4DQ7nYRlMKN.jpg'),
(105737, 7551, 'Deadloch S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fYNBOOgEnaPTwZQdpdVMUGJDcYT.jpg'),
(105738, 7551, 'Deadloch S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217835.mp4', 'http://image.tmdb.org/t/p/w1280/2qMQ5SW57FPwvITqBKxgM8LQO8W.jpg'),
(105739, 7551, 'Deadloch S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217836.mp4', 'http://image.tmdb.org/t/p/w1280/2I2k7PaMMRb8VVKIJd5wwzeiAyR.jpg'),
(105740, 7551, 'Deadloch S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217837.mp4', 'http://image.tmdb.org/t/p/w1280/nKhTe3QB7z2SNS9cS5SqKlNQ2IW.jpg'),
(105741, 7552, 'Expedicao Cicloturismo A Vida em Movimento S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216432.mp4', 'https://i.bj-share.info/49c8fc5656497b0cb29dcf21467d7f2a.jpg'),
(105742, 7552, 'Expedicao Cicloturismo A Vida em Movimento S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216433.mp4', 'https://i.bj-share.info/49c8fc5656497b0cb29dcf21467d7f2a.jpg'),
(105743, 7552, 'Expedicao Cicloturismo A Vida em Movimento S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216434.mp4', 'https://i.bj-share.info/49c8fc5656497b0cb29dcf21467d7f2a.jpg'),
(105744, 7552, 'Expedicao Cicloturismo A Vida em Movimento S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216435.mp4', 'https://i.bj-share.info/49c8fc5656497b0cb29dcf21467d7f2a.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(105745, 7552, 'Expedicao Cicloturismo A Vida em Movimento S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216436.mp4', 'https://i.bj-share.info/49c8fc5656497b0cb29dcf21467d7f2a.jpg'),
(105746, 7552, 'Expedicao Cicloturismo A Vida em Movimento S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216437.mp4', 'https://i.bj-share.info/49c8fc5656497b0cb29dcf21467d7f2a.jpg'),
(105747, 7552, 'Expedicao Cicloturismo A Vida em Movimento S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216438.mp4', 'https://i.bj-share.info/49c8fc5656497b0cb29dcf21467d7f2a.jpg'),
(105748, 7553, 'Gêmeas Trans: Uma Nova Vida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wqhkkrEKsHt9pJvOcHvaYBKYvbI.jpg'),
(105749, 7553, 'Gêmeas Trans: Uma Nova Vida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sIvjJCWfbKoNht8aFy3g9mOggVY.jpg'),
(105750, 7553, 'Gêmeas Trans: Uma Nova Vida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y9tziivDADw49VywPWhCOGafXS5.jpg'),
(105751, 7553, 'Gêmeas Trans: Uma Nova Vida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e7fy8dtswdVCXeWY1LiU58LEBcc.jpg'),
(105752, 7553, 'Gêmeas Trans: Uma Nova Vida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e7fy8dtswdVCXeWY1LiU58LEBcc.jpg'),
(105753, 7553, 'Gêmeas Trans: Uma Nova Vida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e7fy8dtswdVCXeWY1LiU58LEBcc.jpg'),
(105754, 7554, 'Ninjago Ascensão dos Dragões S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w4GNmmbgEfibpbSQmtf4ixWvgyR.jpg'),
(105755, 7554, 'Ninjago Ascensão dos Dragões S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rkPba7asJjE4kWdaqUiTG9I16NT.jpg'),
(105756, 7554, 'Ninjago Ascensão dos Dragões S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n422x7Cijk3XaVyfGGnR1sRjp6b.jpg'),
(105757, 7554, 'Ninjago Ascensão dos Dragões S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xMsHK94mJdquwwgN11FoKFvza1Q.jpg'),
(105758, 7554, 'Ninjago Ascensão dos Dragões S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3Od8SAaO2xNsZiN773c8QwfHIx.jpg'),
(105759, 7554, 'Ninjago Ascensão dos Dragões S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/veC4mgNq6CmCHM9FWnt97IBSTap.jpg'),
(105760, 7554, 'Ninjago Ascensão dos Dragões S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7WEoVKMo8sl9M4rJR4b2P5lR7Em.jpg'),
(105761, 7554, 'Ninjago Ascensão dos Dragões S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oJoRgQG84iJQJo5f5jQePoT5Pd7.jpg'),
(105762, 7554, 'Ninjago Ascensão dos Dragões S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2WIVVXRZneRHTCBOaAsmJ9i0DfT.jpg'),
(105763, 7554, 'Ninjago Ascensão dos Dragões S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vNFaVeFXrqrZJJhxe9t5XrGbFvv.jpg'),
(105764, 7555, 'O Caso Escola Base S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/33BcVBSaKZpCKHf5G0iFc7GU4Sp.jpg'),
(105765, 7555, 'O Caso Escola Base S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/33BcVBSaKZpCKHf5G0iFc7GU4Sp.jpg'),
(105766, 7555, 'O Caso Escola Base S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/33BcVBSaKZpCKHf5G0iFc7GU4Sp.jpg'),
(105767, 7555, 'O Caso Escola Base S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/33BcVBSaKZpCKHf5G0iFc7GU4Sp.jpg'),
(105768, 7556, 'Os Outros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h68dOo8QchQwmddYUzYooRnmlJB.jpg'),
(105769, 7556, 'Os Outros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGGKph3VuCY5fDSrlBEv4SXe3CT.jpg'),
(105770, 7556, 'Os Outros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224111.mp4', 'http://image.tmdb.org/t/p/w1280/rr79BD03lmEgN0FjxDa0Xbz4nCc.jpg'),
(105771, 7556, 'Os Outros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224112.mp4', 'http://image.tmdb.org/t/p/w1280/5mDxnPccXQ6c0fePJDgJu3nTgUg.jpg'),
(105772, 7556, 'Os Outros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGGKph3VuCY5fDSrlBEv4SXe3CT.jpg'),
(105773, 7556, 'Os Outros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGGKph3VuCY5fDSrlBEv4SXe3CT.jpg'),
(105774, 7556, 'Os Outros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGGKph3VuCY5fDSrlBEv4SXe3CT.jpg'),
(105775, 7556, 'Os Outros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224116.mp4', 'http://image.tmdb.org/t/p/w1280/ilZLvOwUTYUszC7NuHaLYL07ydC.jpg'),
(105776, 7556, 'Os Outros S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224117.mp4', 'http://image.tmdb.org/t/p/w1280/otKFhREX639uMW4TosSiwtqgNRn.jpg'),
(105777, 7556, 'Os Outros S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGGKph3VuCY5fDSrlBEv4SXe3CT.jpg'),
(105778, 7556, 'Os Outros S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224119.mp4', 'http://image.tmdb.org/t/p/w1280/qy2MdgcZCO26fiLvuiuYiJRrjpY.jpg'),
(105779, 7556, 'Os Outros S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGGKph3VuCY5fDSrlBEv4SXe3CT.jpg'),
(105780, 7557, 'Os Outros S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/429238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGGKph3VuCY5fDSrlBEv4SXe3CT.jpg'),
(105781, 7557, 'Os Outros S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/429239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGGKph3VuCY5fDSrlBEv4SXe3CT.jpg'),
(105782, 7557, 'Os Outros S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/429240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGGKph3VuCY5fDSrlBEv4SXe3CT.jpg'),
(105783, 7557, 'Os Outros S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGGKph3VuCY5fDSrlBEv4SXe3CT.jpg'),
(105784, 7557, 'Os Outros S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGGKph3VuCY5fDSrlBEv4SXe3CT.jpg'),
(105785, 7557, 'Os Outros S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGGKph3VuCY5fDSrlBEv4SXe3CT.jpg'),
(105786, 7557, 'Os Outros S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/441636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGGKph3VuCY5fDSrlBEv4SXe3CT.jpg'),
(105787, 7557, 'Os Outros S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/441637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGGKph3VuCY5fDSrlBEv4SXe3CT.jpg'),
(105788, 7557, 'Os Outros S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/445850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGGKph3VuCY5fDSrlBEv4SXe3CT.jpg'),
(105789, 7557, 'Os Outros S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/445851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGGKph3VuCY5fDSrlBEv4SXe3CT.jpg'),
(105790, 7557, 'Os Outros S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/452218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGGKph3VuCY5fDSrlBEv4SXe3CT.jpg'),
(105791, 7557, 'Os Outros S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/452219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGGKph3VuCY5fDSrlBEv4SXe3CT.jpg'),
(105792, 7558, 'Perfil Falso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vM4noAp4Jp2KUmdl8AFnGIbzQtF.jpg'),
(105793, 7558, 'Perfil Falso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c36ZuT8AqfJhld1Mjv7xy704uWu.jpg'),
(105794, 7558, 'Perfil Falso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/luF32PEmbBaLK86qtW2l9uQPvSd.jpg'),
(105795, 7558, 'Perfil Falso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zkbCzctXtPN8x4mrqtc8RsyNNnQ.jpg'),
(105796, 7558, 'Perfil Falso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/99TJeZRfpVIzVvdeTvtO3rqeIO4.jpg'),
(105797, 7558, 'Perfil Falso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lONsoE6XfUUPkN3A14gMqtKwuH1.jpg'),
(105798, 7558, 'Perfil Falso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nHNBoJ0yGeQwcbLYRA7UXebWGvR.jpg'),
(105799, 7558, 'Perfil Falso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ckcfCN7hxMO4zTVNlCZTxDxcwHR.jpg'),
(105800, 7558, 'Perfil Falso S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v3n3QkgfDDxr9XUC31U8SciSplx.jpg'),
(105801, 7558, 'Perfil Falso S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7lXXHDI8YbWCr3IiLRvoJLRdBA.jpg'),
(105802, 7559, 'Perfil Falso S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/661779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/luF32PEmbBaLK86qtW2l9uQPvSd.jpg'),
(105803, 7559, 'Perfil Falso S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/661780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/luF32PEmbBaLK86qtW2l9uQPvSd.jpg'),
(105804, 7559, 'Perfil Falso S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/661781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/luF32PEmbBaLK86qtW2l9uQPvSd.jpg'),
(105805, 7559, 'Perfil Falso S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/661782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/luF32PEmbBaLK86qtW2l9uQPvSd.jpg'),
(105806, 7559, 'Perfil Falso S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/661783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/luF32PEmbBaLK86qtW2l9uQPvSd.jpg'),
(105807, 7559, 'Perfil Falso S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/661784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/luF32PEmbBaLK86qtW2l9uQPvSd.jpg'),
(105808, 7559, 'Perfil Falso S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/661785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/luF32PEmbBaLK86qtW2l9uQPvSd.jpg'),
(105809, 7559, 'Perfil Falso S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/661786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/luF32PEmbBaLK86qtW2l9uQPvSd.jpg'),
(105810, 7559, 'Perfil Falso S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/661787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/luF32PEmbBaLK86qtW2l9uQPvSd.jpg'),
(105811, 7559, 'Perfil Falso S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/661788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/luF32PEmbBaLK86qtW2l9uQPvSd.jpg'),
(105812, 7560, 'Projeto Clonagem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6iE4WyCNMSeYAzByoRK3i9rXRTG.jpg'),
(105813, 7560, 'Projeto Clonagem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cRGfFmBpCeQB5N73KQFHl28WikR.jpg'),
(105814, 7560, 'Projeto Clonagem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOPvaA8xcFFW5694mzCPDDfpNfy.jpg'),
(105815, 7560, 'Projeto Clonagem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Jw4vRxy3pX7C1pNHScKeiMg7MM.jpg'),
(105816, 7560, 'Projeto Clonagem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220137.mp4', 'http://image.tmdb.org/t/p/w1280/bWJ0fa21LUPQU3duBX8IWjEncVJ.jpg'),
(105817, 7560, 'Projeto Clonagem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220138.mp4', 'http://image.tmdb.org/t/p/w1280/saKuV7DDWWR5NxhT9xA1Es5N0Qa.jpg'),
(105818, 7560, 'Projeto Clonagem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bA8R9O2wUgt9u0W5oIYZRTXu7mr.jpg'),
(105819, 7560, 'Projeto Clonagem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bA8R9O2wUgt9u0W5oIYZRTXu7mr.jpg'),
(105820, 7560, 'Projeto Clonagem S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bA8R9O2wUgt9u0W5oIYZRTXu7mr.jpg'),
(105821, 7560, 'Projeto Clonagem S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bA8R9O2wUgt9u0W5oIYZRTXu7mr.jpg'),
(105822, 7561, 'Projeto Clonagem S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/270683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bA8R9O2wUgt9u0W5oIYZRTXu7mr.jpg'),
(105823, 7561, 'Projeto Clonagem S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/270684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bA8R9O2wUgt9u0W5oIYZRTXu7mr.jpg'),
(105824, 7561, 'Projeto Clonagem S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/270685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bA8R9O2wUgt9u0W5oIYZRTXu7mr.jpg'),
(105825, 7561, 'Projeto Clonagem S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/270686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bA8R9O2wUgt9u0W5oIYZRTXu7mr.jpg'),
(105826, 7561, 'Projeto Clonagem S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/270687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bA8R9O2wUgt9u0W5oIYZRTXu7mr.jpg'),
(105827, 7561, 'Projeto Clonagem S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/270688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bA8R9O2wUgt9u0W5oIYZRTXu7mr.jpg'),
(105828, 7561, 'Projeto Clonagem S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/270689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bA8R9O2wUgt9u0W5oIYZRTXu7mr.jpg'),
(105829, 7561, 'Projeto Clonagem S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/270690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bA8R9O2wUgt9u0W5oIYZRTXu7mr.jpg'),
(105830, 7561, 'Projeto Clonagem S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/270691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bA8R9O2wUgt9u0W5oIYZRTXu7mr.jpg'),
(105831, 7561, 'Projeto Clonagem S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/270692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bA8R9O2wUgt9u0W5oIYZRTXu7mr.jpg'),
(105832, 7562, 'The Idol S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/syhCydMwvWlip2BsUF7AltIzGgC.jpg'),
(105833, 7562, 'The Idol S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219134.mp4', 'http://image.tmdb.org/t/p/w1280/trw3fGpKKuhjMItkIFFD3pgZSNk.jpg'),
(105834, 7562, 'The Idol S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219135.mp4', 'http://image.tmdb.org/t/p/w1280/meAHiirNo6ffOAtYyKldvs6zORP.jpg'),
(105835, 7562, 'The Idol S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219136.mp4', 'http://image.tmdb.org/t/p/w1280/hYqkfgO3nQGriW1LBTosVglj6wd.jpg'),
(105836, 7562, 'The Idol S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219137.mp4', 'http://image.tmdb.org/t/p/w1280/nsz5beHWn8rxkiWO0uWiQuirTxW.jpg'),
(105837, 7563, 'Tokyo Vice S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216400.mp4', 'http://timg.bdta.pro/images/92a202435fa8f2d84092532ffff761fb.jpg'),
(105838, 7563, 'Tokyo Vice S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216401.mp4', 'http://timg.bdta.pro/images/9324c8b0f78b16f182ac2df46500b1d6.jpg'),
(105839, 7563, 'Tokyo Vice S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216402.mp4', 'http://timg.bdta.pro/images/1a61b44e21d44cb0413d60de24ca86ec.jpg'),
(105840, 7563, 'Tokyo Vice S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216403.mp4', 'http://timg.bdta.pro/images/bd19128bbb5dd791f1999c975498678b.jpg'),
(105841, 7563, 'Tokyo Vice S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216404.mp4', 'http://timg.bdta.pro/images/d807bc7afd6bf14dc81243ffc86c49c3.jpg'),
(105842, 7563, 'Tokyo Vice S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216405.mp4', 'http://timg.bdta.pro/images/cb475730b949720a5da246fef1efe00e.jpg'),
(105843, 7563, 'Tokyo Vice S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216406.mp4', 'http://timg.bdta.pro/images/430118b5f8b847829dc18bacb8114d45.jpg'),
(105844, 7563, 'Tokyo Vice S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216407.mp4', 'http://timg.bdta.pro/images/d8e2cd92d13b6e0e7db08f41217c0b36.jpg'),
(105845, 7564, 'Tokyo Vice S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/270731.mp4', 'http://gstaticontent.com/images/b540f53fb5474302087bf4997dc3f9a8.jpg'),
(105846, 7564, 'Tokyo Vice S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/270732.mp4', 'http://gstaticontent.com/images/b540f53fb5474302087bf4997dc3f9a8.jpg'),
(105847, 7564, 'Tokyo Vice S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/272483.mp4', 'http://gstaticontent.com/images/b540f53fb5474302087bf4997dc3f9a8.jpg'),
(105848, 7564, 'Tokyo Vice S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278855.mp4', 'http://gstaticontent.com/images/b540f53fb5474302087bf4997dc3f9a8.jpg'),
(105849, 7564, 'Tokyo Vice S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/288147.mp4', 'http://gstaticontent.com/images/b540f53fb5474302087bf4997dc3f9a8.jpg'),
(105850, 7564, 'Tokyo Vice S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/296645.mp4', 'http://gstaticontent.com/images/b540f53fb5474302087bf4997dc3f9a8.jpg'),
(105851, 7564, 'Tokyo Vice S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/299725.mp4', 'http://gstaticontent.com/images/b540f53fb5474302087bf4997dc3f9a8.jpg'),
(105852, 7564, 'Tokyo Vice S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/303783.mp4', 'http://gstaticontent.com/images/b540f53fb5474302087bf4997dc3f9a8.jpg'),
(105853, 7564, 'Tokyo Vice S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/313085.mp4', 'http://gstaticontent.com/images/b540f53fb5474302087bf4997dc3f9a8.jpg'),
(105854, 7564, 'Tokyo Vice S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/319230.mp4', 'http://gstaticontent.com/images/b540f53fb5474302087bf4997dc3f9a8.jpg'),
(105855, 7565, 'Três Dias que Mudaram Tudo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nI2HsudabZhaGoRk33IcSsE0VIO.jpg'),
(105856, 7565, 'Três Dias que Mudaram Tudo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jSI8A0BRIl1KhJeBa8LfJuKKNsD.jpg'),
(105857, 7565, 'Três Dias que Mudaram Tudo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tgzPOyp9GJFxAKeHvwUzCQ2tE7G.jpg'),
(105858, 7565, 'Três Dias que Mudaram Tudo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jwXfUcj9o3EmCbiMLBBOKnytqGn.jpg'),
(105859, 7565, 'Três Dias que Mudaram Tudo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kTiaxYYZpdr3Xy4751dcwQqZzC8.jpg'),
(105860, 7565, 'Três Dias que Mudaram Tudo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6hqOBE667YzOaGCrFNYFzylYeHD.jpg'),
(105861, 7565, 'Três Dias que Mudaram Tudo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6NVsLK81eIYKJ85N3OY73ucyJ9p.jpg'),
(105862, 7565, 'Três Dias que Mudaram Tudo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g6ftG998CsbSld1QIUWFJ9h5EEu.jpg'),
(105863, 7566, 'Brasil Visto de Cima S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105864, 7566, 'Brasil Visto de Cima S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105865, 7566, 'Brasil Visto de Cima S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105866, 7566, 'Brasil Visto de Cima S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105867, 7566, 'Brasil Visto de Cima S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105868, 7566, 'Brasil Visto de Cima S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105869, 7566, 'Brasil Visto de Cima S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105870, 7566, 'Brasil Visto de Cima S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105871, 7566, 'Brasil Visto de Cima S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105872, 7566, 'Brasil Visto de Cima S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105873, 7566, 'Brasil Visto de Cima S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105874, 7566, 'Brasil Visto de Cima S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105875, 7566, 'Brasil Visto de Cima S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105876, 7567, 'Brasil Visto de Cima S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105877, 7567, 'Brasil Visto de Cima S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105878, 7567, 'Brasil Visto de Cima S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105879, 7567, 'Brasil Visto de Cima S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105880, 7567, 'Brasil Visto de Cima S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105881, 7567, 'Brasil Visto de Cima S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105882, 7567, 'Brasil Visto de Cima S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105883, 7567, 'Brasil Visto de Cima S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105884, 7567, 'Brasil Visto de Cima S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105885, 7567, 'Brasil Visto de Cima S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105886, 7567, 'Brasil Visto de Cima S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105887, 7567, 'Brasil Visto de Cima S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105888, 7567, 'Brasil Visto de Cima S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105889, 7568, 'Brasil Visto de Cima S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105890, 7568, 'Brasil Visto de Cima S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105891, 7568, 'Brasil Visto de Cima S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105892, 7568, 'Brasil Visto de Cima S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105893, 7568, 'Brasil Visto de Cima S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105894, 7568, 'Brasil Visto de Cima S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105895, 7568, 'Brasil Visto de Cima S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105896, 7568, 'Brasil Visto de Cima S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105897, 7568, 'Brasil Visto de Cima S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105898, 7568, 'Brasil Visto de Cima S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105899, 7568, 'Brasil Visto de Cima S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105900, 7568, 'Brasil Visto de Cima S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105901, 7568, 'Brasil Visto de Cima S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105902, 7569, 'Brasil Visto de Cima S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105903, 7569, 'Brasil Visto de Cima S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105904, 7569, 'Brasil Visto de Cima S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105905, 7569, 'Brasil Visto de Cima S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105906, 7569, 'Brasil Visto de Cima S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105907, 7569, 'Brasil Visto de Cima S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105908, 7569, 'Brasil Visto de Cima S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105909, 7569, 'Brasil Visto de Cima S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105910, 7569, 'Brasil Visto de Cima S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105911, 7569, 'Brasil Visto de Cima S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105912, 7569, 'Brasil Visto de Cima S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105913, 7569, 'Brasil Visto de Cima S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105914, 7569, 'Brasil Visto de Cima S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105915, 7569, 'Brasil Visto de Cima S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/216354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105916, 7569, 'Brasil Visto de Cima S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/216355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105917, 7569, 'Brasil Visto de Cima S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/216356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105918, 7569, 'Brasil Visto de Cima S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/216357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105919, 7569, 'Brasil Visto de Cima S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/216358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105920, 7569, 'Brasil Visto de Cima S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/216359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105921, 7569, 'Brasil Visto de Cima S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/216360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105922, 7569, 'Brasil Visto de Cima S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/216361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105923, 7569, 'Brasil Visto de Cima S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/216362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105924, 7569, 'Brasil Visto de Cima S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/216363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105925, 7569, 'Brasil Visto de Cima S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/216364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105926, 7569, 'Brasil Visto de Cima S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/216365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105927, 7569, 'Brasil Visto de Cima S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/216366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105928, 7569, 'Brasil Visto de Cima S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/216367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105929, 7569, 'Brasil Visto de Cima S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/216368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105930, 7569, 'Brasil Visto de Cima S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/216369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105931, 7569, 'Brasil Visto de Cima S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/216370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105932, 7569, 'Brasil Visto de Cima S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/216371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105933, 7569, 'Brasil Visto de Cima S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/216372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105934, 7569, 'Brasil Visto de Cima S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/216373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105935, 7569, 'Brasil Visto de Cima S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/216374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105936, 7569, 'Brasil Visto de Cima S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/216375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105937, 7569, 'Brasil Visto de Cima S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/216376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105938, 7569, 'Brasil Visto de Cima S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/216377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105939, 7569, 'Brasil Visto de Cima S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/216378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105940, 7570, 'Brasil Visto de Cima S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105941, 7570, 'Brasil Visto de Cima S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105942, 7570, 'Brasil Visto de Cima S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105943, 7570, 'Brasil Visto de Cima S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105944, 7570, 'Brasil Visto de Cima S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105945, 7570, 'Brasil Visto de Cima S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105946, 7570, 'Brasil Visto de Cima S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105947, 7570, 'Brasil Visto de Cima S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105948, 7570, 'Brasil Visto de Cima S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105949, 7570, 'Brasil Visto de Cima S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105950, 7570, 'Brasil Visto de Cima S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/216389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105951, 7570, 'Brasil Visto de Cima S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/216390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105952, 7570, 'Brasil Visto de Cima S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/216391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1eCFwJDcyghwWTEdJLwojQUgoeS.jpg'),
(105953, 7571, 'Arnold S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/goXikY4FpdwYpG0o9PktWaZde27.jpg'),
(105954, 7571, 'Arnold S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e5a7OKMWyTlQs2SfLY8G0vDeMvv.jpg'),
(105955, 7571, 'Arnold S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lRstfefRZgTFvSXeg16xao38KK5.jpg'),
(105956, 7200, 'Chuva Negra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mNFZpuZIrQBUp5hTKKvXaJy9Fy.jpg'),
(105957, 7200, 'Chuva Negra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mNFZpuZIrQBUp5hTKKvXaJy9Fy.jpg'),
(105958, 7200, 'Chuva Negra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mNFZpuZIrQBUp5hTKKvXaJy9Fy.jpg'),
(105959, 7200, 'Chuva Negra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mNFZpuZIrQBUp5hTKKvXaJy9Fy.jpg'),
(105960, 7200, 'Chuva Negra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mNFZpuZIrQBUp5hTKKvXaJy9Fy.jpg'),
(105961, 7200, 'Chuva Negra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mNFZpuZIrQBUp5hTKKvXaJy9Fy.jpg'),
(105962, 7200, 'Chuva Negra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mNFZpuZIrQBUp5hTKKvXaJy9Fy.jpg'),
(105963, 7200, 'Chuva Negra S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/216111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mNFZpuZIrQBUp5hTKKvXaJy9Fy.jpg'),
(105964, 7200, 'Chuva Negra S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/216112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mNFZpuZIrQBUp5hTKKvXaJy9Fy.jpg'),
(105965, 7200, 'Chuva Negra S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/216113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mNFZpuZIrQBUp5hTKKvXaJy9Fy.jpg'),
(105966, 7572, 'Love Touch S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/216097.mp4', 'https://i.bj-share.info/54da5b6c25091a1c5b2ead704dc3ccbd.jpg'),
(105967, 7572, 'Love Touch S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/216098.mp4', 'https://i.bj-share.info/54da5b6c25091a1c5b2ead704dc3ccbd.jpg'),
(105968, 7572, 'Love Touch S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/216099.mp4', 'https://i.bj-share.info/54da5b6c25091a1c5b2ead704dc3ccbd.jpg'),
(105969, 7572, 'Love Touch S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/216100.mp4', 'https://i.bj-share.info/54da5b6c25091a1c5b2ead704dc3ccbd.jpg'),
(105970, 7572, 'Love Touch S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/216101.mp4', 'https://i.bj-share.info/54da5b6c25091a1c5b2ead704dc3ccbd.jpg'),
(105971, 7572, 'Love Touch S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/216102.mp4', 'https://i.bj-share.info/54da5b6c25091a1c5b2ead704dc3ccbd.jpg'),
(105972, 7572, 'Love Touch S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/216103.mp4', 'https://i.bj-share.info/54da5b6c25091a1c5b2ead704dc3ccbd.jpg'),
(105973, 7573, 'Stargate Universe [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/569303.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/npobKwfbMOEHyemIaStK83EDjYa.jpg'),
(105974, 7573, 'Stargate Universe [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yA3jY2wpGBQUYDW680l7JieoJ1t.jpg'),
(105975, 7573, 'Stargate Universe [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/569306.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6IQx2enx9z8qOwUFXfrq64kO7PB.jpg'),
(105976, 7573, 'Stargate Universe [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/569308.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hhzo9FS5zZVMTvRSzsEVfu10cZA.jpg'),
(105977, 7573, 'Stargate Universe [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/569310.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wx2pha6WetaHzuBmFTaS0wr7dGX.jpg'),
(105978, 7573, 'Stargate Universe [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/569312.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r2juwNGwcadbsi669rIKVEqFIn1.jpg'),
(105979, 7573, 'Stargate Universe [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/569314.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t7zlW0W2CsuiAH3VyKgJLZTHssP.jpg'),
(105980, 7573, 'Stargate Universe [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/569316.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wwwTNBnxPy6xq39N9HhWCNIjO5C.jpg'),
(105981, 7573, 'Stargate Universe [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/569318.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cMpIKDdvLJVmjw8Lj2NoKdrDdCC.jpg'),
(105982, 7573, 'Stargate Universe [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/569320.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jU9X4CsnQtq8YkctaUdhJ0CmiSk.jpg'),
(105983, 7573, 'Stargate Universe [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/569322.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2lzvsNVDBvtlrlctZV0VjDfFFUX.jpg'),
(105984, 7573, 'Stargate Universe [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/569324.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cM3XEMdzQIz3Uc4pIez71uFH3Y8.jpg'),
(105985, 7573, 'Stargate Universe [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/569326.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aCQdZwU3FBzk6PJG36l0c86ZRxd.jpg'),
(105986, 7573, 'Stargate Universe [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/569328.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kfFkNUsXBQ9wSOL5M9rhxd7xTpH.jpg'),
(105987, 7573, 'Stargate Universe [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/569330.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nta0N317t9P98VBcjl6UFZcd3fo.jpg'),
(105988, 7573, 'Stargate Universe [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/569332.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y67LB6lz4J9HRXJ2MiWoPD3q3pV.jpg'),
(105989, 7573, 'Stargate Universe [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/569334.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dCGli6d8NeWydJhMSZEVORYYLQR.jpg'),
(105990, 7573, 'Stargate Universe [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/569336.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fqmTtlnMaqW6rR74jp8RFt0wVuJ.jpg'),
(105991, 7573, 'Stargate Universe [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/569338.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ou49VVLVg3fnQXXZCLI2Fpz80Mw.jpg'),
(105992, 7573, 'Stargate Universe [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/569340.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j8RhBfK3v3EWO5iQbkaPCNnVMYt.jpg'),
(105993, 7574, 'Cães de Caça S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7pYgTblejrDMULmTK0Ie19T9p2.jpg'),
(105994, 7574, 'Cães de Caça S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Z7YtC2EHQmiPBGYyOJljDkitdi.jpg'),
(105995, 7574, 'Cães de Caça S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Ert2ew3YvqN5VdCauTj8cBpjjg.jpg'),
(105996, 7574, 'Cães de Caça S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2E9Ta5mQtRG2suqTaDX9nYo0NNX.jpg'),
(105997, 7574, 'Cães de Caça S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/onX21NbvjDq7LT5dtWboe7LbD8k.jpg'),
(105998, 7574, 'Cães de Caça S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vnPmrOW9TJnnOykoSfPPMCMyXpW.jpg'),
(105999, 7574, 'Cães de Caça S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pZab8rad54vhfHnxRQQtc9nX9Vh.jpg'),
(106000, 7574, 'Cães de Caça S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iNMEVcCht0zxJwzIw5qlH8iL8Gj.jpg'),
(106001, 7575, 'Entre Estranhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xrme1nEROSA61ZVUxWpxWYRZTsR.jpg'),
(106002, 7575, 'Entre Estranhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hKHVakg7oZpVeKIbGCd7RDEsvZc.jpg'),
(106003, 7575, 'Entre Estranhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sM5v44dkSPHmbnUNL1THcIsd6Ic.jpg'),
(106004, 7575, 'Entre Estranhos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kjgM6baJMb4889MxHLwFAePowcb.jpg'),
(106005, 7575, 'Entre Estranhos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227368.mp4', 'http://image.tmdb.org/t/p/w1280/bdpoCmbLSVRh3pG2FLxA1vHD1ZX.jpg'),
(106006, 7575, 'Entre Estranhos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227369.mp4', 'http://image.tmdb.org/t/p/w1280/dS2kXx5Ermn1G3m19tVcNgHWE0f.jpg'),
(106007, 7575, 'Entre Estranhos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227370.mp4', 'http://image.tmdb.org/t/p/w1280/sABonTcD16pzfWLE8FI9FZU3Z2z.jpg'),
(106008, 7575, 'Entre Estranhos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227371.mp4', 'http://image.tmdb.org/t/p/w1280/fytWaQhSJIoR4SSHBqC970GaFZY.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(106009, 7575, 'Entre Estranhos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227372.mp4', 'http://image.tmdb.org/t/p/w1280/bC9ldiwrpHSIh035fKYRczb3hlN.jpg'),
(106010, 7575, 'Entre Estranhos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227373.mp4', 'http://image.tmdb.org/t/p/w1280/uXeDoUaajZWzjS0uwOIZwLlWt5s.jpg'),
(106011, 7576, 'Este Mundo Não Vai me Derrubar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qXjlOuBICkTa9nQm83tW93esfP.jpg'),
(106012, 7576, 'Este Mundo Não Vai me Derrubar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rBd8DUbLZKvhEN7r3romEUUbsLX.jpg'),
(106013, 7576, 'Este Mundo Não Vai me Derrubar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ubvkEZD5cqHXuhA0ejbh3zXzb1.jpg'),
(106014, 7576, 'Este Mundo Não Vai me Derrubar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g3cwHhPHvJIWrb0Q4tuS5JIDEo0.jpg'),
(106015, 7576, 'Este Mundo Não Vai me Derrubar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/neaGPBG7rPnHWGkELFn3kfST2DC.jpg'),
(106016, 7576, 'Este Mundo Não Vai me Derrubar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/opRwEYnMCdrbWyzgOUf9DguQsoD.jpg'),
(106017, 7577, 'Joe Mazza: O Homem das Casas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4OCFoh1yC7Y08BG8pKFHVo0z76.jpg'),
(106018, 7577, 'Joe Mazza: O Homem das Casas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4OCFoh1yC7Y08BG8pKFHVo0z76.jpg'),
(106019, 7577, 'Joe Mazza: O Homem das Casas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4OCFoh1yC7Y08BG8pKFHVo0z76.jpg'),
(106020, 7577, 'Joe Mazza: O Homem das Casas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4OCFoh1yC7Y08BG8pKFHVo0z76.jpg'),
(106021, 7577, 'Joe Mazza: O Homem das Casas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4OCFoh1yC7Y08BG8pKFHVo0z76.jpg'),
(106022, 7577, 'Joe Mazza: O Homem das Casas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4OCFoh1yC7Y08BG8pKFHVo0z76.jpg'),
(106023, 7577, 'Joe Mazza: O Homem das Casas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4OCFoh1yC7Y08BG8pKFHVo0z76.jpg'),
(106024, 7577, 'Joe Mazza: O Homem das Casas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4OCFoh1yC7Y08BG8pKFHVo0z76.jpg'),
(106025, 7577, 'Joe Mazza: O Homem das Casas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4OCFoh1yC7Y08BG8pKFHVo0z76.jpg'),
(106026, 7577, 'Joe Mazza: O Homem das Casas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4OCFoh1yC7Y08BG8pKFHVo0z76.jpg'),
(106027, 7578, 'Kiff S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106028, 7578, 'Kiff S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106029, 7578, 'Kiff S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106030, 7578, 'Kiff S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106031, 7578, 'Kiff S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106032, 7578, 'Kiff S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106033, 7578, 'Kiff S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106034, 7578, 'Kiff S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106035, 7578, 'Kiff S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106036, 7578, 'Kiff S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106037, 7578, 'Kiff S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/261383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106038, 7578, 'Kiff S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/261384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106039, 7578, 'Kiff S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/261385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106040, 7578, 'Kiff S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/261386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106041, 7578, 'Kiff S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/261387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106042, 7578, 'Kiff S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/261388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106043, 7578, 'Kiff S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/261389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106044, 7578, 'Kiff S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/261390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106045, 7578, 'Kiff S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/261391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106046, 7578, 'Kiff S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/261392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106047, 7578, 'Kiff S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/261393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106048, 7578, 'Kiff S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/261394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106049, 7578, 'Kiff S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/261395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106050, 7578, 'Kiff S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/261396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106051, 7578, 'Kiff S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/261397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106052, 7578, 'Kiff S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/290029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106053, 7578, 'Kiff S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/290030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106054, 7578, 'Kiff S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/315819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106055, 7578, 'Kiff S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/315820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106056, 7578, 'Kiff S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/415756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106057, 7579, 'Kiff S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/887572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106058, 7579, 'Kiff S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/887573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106059, 7579, 'Kiff S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/887574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106060, 7579, 'Kiff S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/887575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106061, 7579, 'Kiff S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/887576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106062, 7579, 'Kiff S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/887577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106063, 7579, 'Kiff S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/887578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106064, 7579, 'Kiff S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/887579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106065, 7579, 'Kiff S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/887580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106066, 7579, 'Kiff S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/887581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106067, 7579, 'Kiff S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/887582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106068, 7579, 'Kiff S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/887583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106069, 7579, 'Kiff S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/887584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106070, 7579, 'Kiff S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/887585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106071, 7579, 'Kiff S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/887586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106072, 7579, 'Kiff S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/887587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106073, 7579, 'Kiff S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/887588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106074, 7579, 'Kiff S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/887589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106075, 7579, 'Kiff S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/890074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106076, 7579, 'Kiff S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/890075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106077, 7579, 'Kiff S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/891858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106078, 7579, 'Kiff S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/893118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106079, 7579, 'Kiff S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/893119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106080, 7579, 'Kiff S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/893465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106081, 7579, 'Kiff S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/893466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h7xhJ1uWu7FurJ3W5iKzrfiPF3K.jpg'),
(106082, 7580, 'Meka Builders S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDPYBJxJCLq0D6uwuLY9IquoRqP.jpg'),
(106083, 7580, 'Meka Builders S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDPYBJxJCLq0D6uwuLY9IquoRqP.jpg'),
(106084, 7580, 'Meka Builders S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDPYBJxJCLq0D6uwuLY9IquoRqP.jpg'),
(106085, 7580, 'Meka Builders S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDPYBJxJCLq0D6uwuLY9IquoRqP.jpg'),
(106086, 7580, 'Meka Builders S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDPYBJxJCLq0D6uwuLY9IquoRqP.jpg'),
(106087, 7580, 'Meka Builders S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDPYBJxJCLq0D6uwuLY9IquoRqP.jpg'),
(106088, 7580, 'Meka Builders S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDPYBJxJCLq0D6uwuLY9IquoRqP.jpg'),
(106089, 7580, 'Meka Builders S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDPYBJxJCLq0D6uwuLY9IquoRqP.jpg'),
(106090, 7580, 'Meka Builders S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDPYBJxJCLq0D6uwuLY9IquoRqP.jpg'),
(106091, 7580, 'Meka Builders S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDPYBJxJCLq0D6uwuLY9IquoRqP.jpg'),
(106092, 7580, 'Meka Builders S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDPYBJxJCLq0D6uwuLY9IquoRqP.jpg'),
(106093, 7580, 'Meka Builders S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDPYBJxJCLq0D6uwuLY9IquoRqP.jpg'),
(106094, 7580, 'Meka Builders S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDPYBJxJCLq0D6uwuLY9IquoRqP.jpg'),
(106095, 7580, 'Meka Builders S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDPYBJxJCLq0D6uwuLY9IquoRqP.jpg'),
(106096, 7580, 'Meka Builders S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDPYBJxJCLq0D6uwuLY9IquoRqP.jpg'),
(106097, 7580, 'Meka Builders S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDPYBJxJCLq0D6uwuLY9IquoRqP.jpg'),
(106098, 7580, 'Meka Builders S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/215769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDPYBJxJCLq0D6uwuLY9IquoRqP.jpg'),
(106099, 7580, 'Meka Builders S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/215770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDPYBJxJCLq0D6uwuLY9IquoRqP.jpg'),
(106100, 7580, 'Meka Builders S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/215771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDPYBJxJCLq0D6uwuLY9IquoRqP.jpg'),
(106101, 7580, 'Meka Builders S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/215772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDPYBJxJCLq0D6uwuLY9IquoRqP.jpg'),
(106102, 7580, 'Meka Builders S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/215773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDPYBJxJCLq0D6uwuLY9IquoRqP.jpg'),
(106103, 7581, 'Os Desafios de Hailey S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yuCsf7LqOFCitBrbgHCxHRB92KA.jpg'),
(106104, 7581, 'Os Desafios de Hailey S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2WVhevcAsDUffw4pxDY3KYVf4j.jpg'),
(106105, 7581, 'Os Desafios de Hailey S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/296718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2WVhevcAsDUffw4pxDY3KYVf4j.jpg'),
(106106, 7581, 'Os Desafios de Hailey S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vsihK2iPg2KPMSKTESdrpUDbT5O.jpg'),
(106107, 7581, 'Os Desafios de Hailey S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mU1LYxek0L04CIo6uVE3HFhYnLu.jpg'),
(106108, 7581, 'Os Desafios de Hailey S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/314474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2WVhevcAsDUffw4pxDY3KYVf4j.jpg'),
(106109, 7581, 'Os Desafios de Hailey S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9PrOQMeVCZ3goLtdXtpRzLkdqrQ.jpg'),
(106110, 7581, 'Os Desafios de Hailey S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5U3WdXuRUmu9me9LmYOTRgVIhqc.jpg'),
(106111, 7581, 'Os Desafios de Hailey S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/llL4xDqZ9ts1Py0TU7UrnPdWHKX.jpg'),
(106112, 7581, 'Os Desafios de Hailey S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xEGusEtDzIdncSQy1OjTvCKym00.jpg'),
(106113, 7581, 'Os Desafios de Hailey S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c5guPOaxLgSnCvJBRLS4YLE62E8.jpg'),
(106114, 7581, 'Os Desafios de Hailey S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sGWpNe9v7sgn7ceVCMGKEI3k5yo.jpg'),
(106115, 7581, 'Os Desafios de Hailey S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zNT2UTExwCbhwurBxYQjvgeDdJv.jpg'),
(106116, 7581, 'Os Desafios de Hailey S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/257449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2WVhevcAsDUffw4pxDY3KYVf4j.jpg'),
(106117, 7581, 'Os Desafios de Hailey S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/257450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2WVhevcAsDUffw4pxDY3KYVf4j.jpg'),
(106118, 7581, 'Os Desafios de Hailey S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/257451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2WVhevcAsDUffw4pxDY3KYVf4j.jpg'),
(106119, 7581, 'Os Desafios de Hailey S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/331313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2WVhevcAsDUffw4pxDY3KYVf4j.jpg'),
(106120, 7581, 'Os Desafios de Hailey S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/331314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2WVhevcAsDUffw4pxDY3KYVf4j.jpg'),
(106121, 7581, 'Os Desafios de Hailey S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/331315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2WVhevcAsDUffw4pxDY3KYVf4j.jpg'),
(106122, 7582, 'Tex Mex Motors S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oU33mgBUx0os3tLNc4RpEZa1hb2.jpg'),
(106123, 7582, 'Tex Mex Motors S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oU33mgBUx0os3tLNc4RpEZa1hb2.jpg'),
(106124, 7582, 'Tex Mex Motors S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oU33mgBUx0os3tLNc4RpEZa1hb2.jpg'),
(106125, 7582, 'Tex Mex Motors S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oU33mgBUx0os3tLNc4RpEZa1hb2.jpg'),
(106126, 7582, 'Tex Mex Motors S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oU33mgBUx0os3tLNc4RpEZa1hb2.jpg'),
(106127, 7582, 'Tex Mex Motors S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oU33mgBUx0os3tLNc4RpEZa1hb2.jpg'),
(106128, 7582, 'Tex Mex Motors S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oU33mgBUx0os3tLNc4RpEZa1hb2.jpg'),
(106129, 7582, 'Tex Mex Motors S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oU33mgBUx0os3tLNc4RpEZa1hb2.jpg'),
(106130, 7583, 'The Sheikh S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDQccdFBb4PJ8heVmUsgGu04a3F.jpg'),
(106131, 7583, 'The Sheikh S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shdGHz03qAFsfCqIwXQWQ18GXWX.jpg'),
(106132, 7583, 'The Sheikh S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qlrIyyVJEgbkavItSiTAtTnKAlW.jpg'),
(106133, 7583, 'The Sheikh S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/npLsJ0wHWaikdog0yFW4FnQxM58.jpg'),
(106134, 7583, 'The Sheikh S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3vrG3pZVBnlJi8UtHhGb5QTyCWD.jpg'),
(106135, 7583, 'The Sheikh S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7S1mW0swRhQyq1n27Y4zFobVbAP.jpg'),
(106136, 7583, 'The Sheikh S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4rZI36n5eKU3jVOfhhmkX17ndoX.jpg'),
(106137, 7583, 'The Sheikh S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Hy8WYVpKvCPeX2l4AAxYmH98mg.jpg'),
(106138, 7584, 'Tour de France: No Coração do Pelotão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c6R5CsRggPdUGCyEM4mdECVlbtx.jpg'),
(106139, 7584, 'Tour de France: No Coração do Pelotão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uXwLmk7LJ92TBiwGTjPqbjAmG9H.jpg'),
(106140, 7584, 'Tour de France: No Coração do Pelotão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/WTqkKs7SLPkwjkHyBsMGW8qZcX.jpg'),
(106141, 7584, 'Tour de France: No Coração do Pelotão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rVBq7Yl5T7hndhS5lQMKmGaNk1c.jpg'),
(106142, 7584, 'Tour de France: No Coração do Pelotão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tHFdLyId3693iORiSqYLr0Jeu2P.jpg'),
(106143, 7584, 'Tour de France: No Coração do Pelotão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnidRFaKUmzAIdVeiHVsDJE27Mc.jpg'),
(106144, 7584, 'Tour de France: No Coração do Pelotão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gs5GuNnjJNJDKRISClMgU2yboVm.jpg'),
(106145, 7584, 'Tour de France: No Coração do Pelotão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jSxttRvGx7nVwRMChB2t4SbKDhy.jpg'),
(106146, 7585, 'Tour de France: No Coração do Pelotão S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/383860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cOTvUTzhQGvwuIeSYGCIm35kadM.jpg'),
(106147, 7585, 'Tour de France: No Coração do Pelotão S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/383861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cOTvUTzhQGvwuIeSYGCIm35kadM.jpg'),
(106148, 7585, 'Tour de France: No Coração do Pelotão S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/383862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cOTvUTzhQGvwuIeSYGCIm35kadM.jpg'),
(106149, 7585, 'Tour de France: No Coração do Pelotão S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/383863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cOTvUTzhQGvwuIeSYGCIm35kadM.jpg'),
(106150, 7585, 'Tour de France: No Coração do Pelotão S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/383864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cOTvUTzhQGvwuIeSYGCIm35kadM.jpg'),
(106151, 7585, 'Tour de France: No Coração do Pelotão S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/383865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cOTvUTzhQGvwuIeSYGCIm35kadM.jpg'),
(106152, 7585, 'Tour de France: No Coração do Pelotão S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/383866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cOTvUTzhQGvwuIeSYGCIm35kadM.jpg'),
(106153, 7585, 'Tour de France: No Coração do Pelotão S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/383867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cOTvUTzhQGvwuIeSYGCIm35kadM.jpg'),
(106154, 7586, 'Ghost Whisperer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vcJ3ewbS6iJTXQR5UegxsE1tyP1.jpg'),
(106155, 7586, 'Ghost Whisperer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sESm50IJoutpTJZGLwdHsJNe7bY.jpg'),
(106156, 7586, 'Ghost Whisperer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/37Ptnm4SEj4VbM3tWL3AJNVnK6X.jpg'),
(106157, 7586, 'Ghost Whisperer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ayB4wimCO98J8XjyZfScaE2IiD.jpg'),
(106158, 7586, 'Ghost Whisperer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBQpCWiaDnOtkEP5UBxn26XJhKE.jpg'),
(106159, 7586, 'Ghost Whisperer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MuOo2neDMDyASZ8e2jvE7VPNkf.jpg'),
(106160, 7586, 'Ghost Whisperer S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lsukbRbkumgBmF9Vpyxv80QEgAe.jpg'),
(106161, 7586, 'Ghost Whisperer S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Ab0rILdorUnqUZt8y2LQ6ZqvNV.jpg'),
(106162, 7586, 'Ghost Whisperer S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hV9vgHnxj42lGIyGuEoYbBiGwJ7.jpg'),
(106163, 7586, 'Ghost Whisperer S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3CpCf2vfANf04sjQLTtgE5wuSx6.jpg'),
(106164, 7586, 'Ghost Whisperer S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bkPDZbr2eFOX9l91Y6QydXFjcGc.jpg'),
(106165, 7586, 'Ghost Whisperer S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mmMahbHi0Etj2x0OFxamtJNU8iJ.jpg'),
(106166, 7586, 'Ghost Whisperer S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5pJYn3xlu8ncIIF233C2nCteqF2.jpg'),
(106167, 7586, 'Ghost Whisperer S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lFa4uDWbAwmLIWCFjXW8Wr5rYvp.jpg'),
(106168, 7586, 'Ghost Whisperer S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b6xhTjpUCXuiwAuQVqvU2dvK9MZ.jpg'),
(106169, 7586, 'Ghost Whisperer S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sIupS3wJ3P5GHgzPF32mJ4l1Aka.jpg'),
(106170, 7586, 'Ghost Whisperer S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/215047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rRegzWdwHONegZuYaQUWCPKh9Am.jpg'),
(106171, 7586, 'Ghost Whisperer S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/215048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCLAHlUEPJiMZPreWdNhgzH48aK.jpg'),
(106172, 7586, 'Ghost Whisperer S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/215049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yZr0mwmlTaa8TYmJGL4QZpMG5bo.jpg'),
(106173, 7586, 'Ghost Whisperer S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/215050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8oOW1czhJNZpBlW3nPklrb9eTQ2.jpg'),
(106174, 7586, 'Ghost Whisperer S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/215051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9DLGprsXP6YTL1Pt0t7p8J8tV5S.jpg'),
(106175, 7586, 'Ghost Whisperer S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/215052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Kj5WZ7T7wC00i8bAhfIgOqLZFq.jpg'),
(106176, 7587, 'Ghost Whisperer S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1a3RWuOBT1nJ4y0ciYTWY6c97yh.jpg'),
(106177, 7587, 'Ghost Whisperer S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aHbYgsMDqifYe5TcBqsrzsmaB8o.jpg'),
(106178, 7587, 'Ghost Whisperer S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/81gKlqMwHXqXOpFpGvVqixLokic.jpg'),
(106179, 7587, 'Ghost Whisperer S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fWbi2AqR3l9lhAiTNRx0biyKymY.jpg'),
(106180, 7587, 'Ghost Whisperer S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ibo6RFkSsBCexZjHllYI7PKruSj.jpg'),
(106181, 7587, 'Ghost Whisperer S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2g6aQmpqM0TR68eaAeG6R0Tco0i.jpg'),
(106182, 7587, 'Ghost Whisperer S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lGdLQ2MpNMCOmHqTUozvvq1f1fF.jpg'),
(106183, 7587, 'Ghost Whisperer S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1W7e2c3GbiovRbtUftTkquUhwHG.jpg'),
(106184, 7587, 'Ghost Whisperer S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yS6H49nHgpPRPP7jBmAC6AIF5xK.jpg'),
(106185, 7587, 'Ghost Whisperer S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4hV0ebAby3jH9BtTdlJ2FBgg9Vb.jpg'),
(106186, 7587, 'Ghost Whisperer S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o6PdDljznD6lQ75jQq93mFV20eB.jpg'),
(106187, 7587, 'Ghost Whisperer S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Adg692igxYbpSAaUDpC9A9bkSHE.jpg'),
(106188, 7587, 'Ghost Whisperer S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lYz3gK3jceL1VWJiimuEltPPK4h.jpg'),
(106189, 7587, 'Ghost Whisperer S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/215066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4jbHyjWNUh0HpWiSS03FK0a3rLF.jpg'),
(106190, 7587, 'Ghost Whisperer S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/215067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xtAsrjZVQh4i9kmxIMs1qYr7wZL.jpg'),
(106191, 7587, 'Ghost Whisperer S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/215068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5fD4LlH8Kzcsu36UIgHwnv8GrUs.jpg'),
(106192, 7587, 'Ghost Whisperer S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/215069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2PfNVvL83OzeY1vxnt1HGV4LYSz.jpg'),
(106193, 7587, 'Ghost Whisperer S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/215070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZWU7sO299uvmYr2gMu5N1g4rA7.jpg'),
(106194, 7587, 'Ghost Whisperer S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/215071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Qb7wCCxa2ekFOSE0Z7Vg0keNPf.jpg'),
(106195, 7587, 'Ghost Whisperer S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/215072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ezWAqcJ5JujUGuLvgpU0MttIDNU.jpg'),
(106196, 7587, 'Ghost Whisperer S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/215073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tvzGnmMibQw9DwQgIgvs4bAaauE.jpg'),
(106197, 7587, 'Ghost Whisperer S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/215074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2GFbDFUX1NcgCNLjeRcEdvPqKR.jpg'),
(106198, 7588, 'Samurai Jack S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZjIAhMMB9qktNLOeC7WYYmDRLa.jpg'),
(106199, 7588, 'Samurai Jack S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5gdW1mxMEz9MjlVJ0GyAm0r9rHb.jpg'),
(106200, 7588, 'Samurai Jack S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ttaX1N3IZowomTYcPBt5ZmUzyeZ.jpg'),
(106201, 7588, 'Samurai Jack S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qqNHa9ZMzk8ML1Cit3yqkQYub5W.jpg'),
(106202, 7588, 'Samurai Jack S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vPCyFC4k5UEyTfMWZQYKIIrr6qj.jpg'),
(106203, 7588, 'Samurai Jack S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ZfFFL4WqJt1H4VUhojWCpYqk92.jpg'),
(106204, 7588, 'Samurai Jack S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uC5xj0cGSMlqcxcEsTVhw7uX22d.jpg'),
(106205, 7588, 'Samurai Jack S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w6979WDvNH3izeYQpfCHRxSFSz.jpg'),
(106206, 7588, 'Samurai Jack S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uSAtYLeeVhx3lu72MfN2UIx6wyX.jpg'),
(106207, 7588, 'Samurai Jack S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tBFIzSM9JXBhrdT2S9gVTWAxJRN.jpg'),
(106208, 7588, 'Samurai Jack S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a5MeNkIVOQDEskJcPpal4rilUZR.jpg'),
(106209, 7588, 'Samurai Jack S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qHj1cKTup5kLSHoaMXpOgbGsWPr.jpg'),
(106210, 7588, 'Samurai Jack S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Ep5bA06QjoaQ6oVuc7XUfGJKpH.jpg'),
(106211, 7589, 'Samurai Jack S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FEPfwi0f3uIV4O3u6LhY0FN1m0.jpg'),
(106212, 7589, 'Samurai Jack S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k45rE5BUHtFRhtYfk0FfmlVUfa5.jpg'),
(106213, 7589, 'Samurai Jack S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/riOZd6kINUlJgMxHRstKRe42QjX.jpg'),
(106214, 7589, 'Samurai Jack S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y70wL4K8Q46ADkGt50tyBm4qqYA.jpg'),
(106215, 7589, 'Samurai Jack S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m3R3uZfVEWccdlFLLUdpdCb0xN8.jpg'),
(106216, 7589, 'Samurai Jack S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7yawiyoiOmvYivzye36PDlouJIf.jpg'),
(106217, 7589, 'Samurai Jack S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fNDHBEh5sWsaOiQul6mvy9fS41o.jpg'),
(106218, 7589, 'Samurai Jack S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ilsncrXHUQGxoBSOn6vEYTwsr0u.jpg'),
(106219, 7589, 'Samurai Jack S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oOG1l7CQKf6Nh1YVoQ2CzklHTgs.jpg'),
(106220, 7589, 'Samurai Jack S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6vC3Zn2Hm0pskVcNg2fQjvVqEID.jpg'),
(106221, 7589, 'Samurai Jack S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aTVxhLMlbJCJoTo3jw1lQGXqS5V.jpg'),
(106222, 7589, 'Samurai Jack S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpP5XkLUlkmqLALtAB2YkorFAL6.jpg'),
(106223, 7589, 'Samurai Jack S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNmI7b0cRsM6cSipBaAdilAh1yh.jpg'),
(106224, 7590, 'Samurai Jack S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zE56lSQwwFbP8Ws4zFP8RjUWkL1.jpg'),
(106225, 7590, 'Samurai Jack S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4iJDLumXinFkNMdHy6SWEzljkyN.jpg'),
(106226, 7590, 'Samurai Jack S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wKxjVTdTX44ExAztYtI11hfHXmC.jpg'),
(106227, 7590, 'Samurai Jack S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/osLAKcZqRnauMojvvAT3rMC7C91.jpg'),
(106228, 7590, 'Samurai Jack S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/upZJH9oU2ZeV8VuD1Gmi2u3MhIa.jpg'),
(106229, 7590, 'Samurai Jack S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ja8itYQfPP5Re5j9D1aLqoR4SD6.jpg'),
(106230, 7590, 'Samurai Jack S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nKuXOwhCHDi24FtpSlCD1XhYZUj.jpg'),
(106231, 7590, 'Samurai Jack S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7vTvFnsUYFIWd3VjBJ85CC7uudv.jpg'),
(106232, 7590, 'Samurai Jack S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QxY96lKhl7cUayDrvDLQ1WtSBh.jpg'),
(106233, 7590, 'Samurai Jack S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vSyIbrYFxgkzX1bmEEJRBPs9Xfb.jpg'),
(106234, 7590, 'Samurai Jack S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hLw9olhLQwyCzYUOmnTWxgUUs0x.jpg'),
(106235, 7590, 'Samurai Jack S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aBig8NqD8IQrZ1OV258MqHvsAsF.jpg'),
(106236, 7590, 'Samurai Jack S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aBig8NqD8IQrZ1OV258MqHvsAsF.jpg'),
(106237, 7591, 'Samurai Jack S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/215018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oDAGUIAWJTG9AmwkTwIUEgql882.jpg'),
(106238, 7591, 'Samurai Jack S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/215019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cZaZaa3haeBSite8WimnKP6DSwe.jpg'),
(106239, 7591, 'Samurai Jack S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/215020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xafctgj0FHWZHLWS0IpGSVwv3Xr.jpg'),
(106240, 7591, 'Samurai Jack S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/215021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hp6LPNWOZz7a468MdQVFx4oV9s8.jpg'),
(106241, 7591, 'Samurai Jack S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/215022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJCSQ3wyhlaaD27pkWiLGOqv29H.jpg'),
(106242, 7591, 'Samurai Jack S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/215023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xXr02MCUEMv9EplyLAitrKBgdEn.jpg'),
(106243, 7591, 'Samurai Jack S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/215024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cq02g1kqAcTBLJer9OjabvEF7jt.jpg'),
(106244, 7591, 'Samurai Jack S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/215025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/haIJTgVTT9Ax2bXIDRvuzNZdyB2.jpg'),
(106245, 7591, 'Samurai Jack S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/215026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kem1LaBU9U8nszkNMGFc0nDLgt9.jpg'),
(106246, 7591, 'Samurai Jack S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/215027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cK7Jm3ARNO9h4IjO08dcK7BQi6m.jpg'),
(106247, 7591, 'Samurai Jack S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/215028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eJn28jCoSrXqQUAJKVCBIJbCzKr.jpg'),
(106248, 7591, 'Samurai Jack S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/215029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rADNtvqxlpx1ixT6EVn8IRGwXrL.jpg'),
(106249, 7591, 'Samurai Jack S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/215030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5HjTPjLjGRBTrw6RPQ5YcTgdRze.jpg'),
(106250, 7592, 'Samurai Jack S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/270872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aBig8NqD8IQrZ1OV258MqHvsAsF.jpg'),
(106251, 7592, 'Samurai Jack S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/270873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aBig8NqD8IQrZ1OV258MqHvsAsF.jpg'),
(106252, 7592, 'Samurai Jack S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/270874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aBig8NqD8IQrZ1OV258MqHvsAsF.jpg'),
(106253, 7592, 'Samurai Jack S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/270875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aBig8NqD8IQrZ1OV258MqHvsAsF.jpg'),
(106254, 7592, 'Samurai Jack S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/270876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aBig8NqD8IQrZ1OV258MqHvsAsF.jpg'),
(106255, 7592, 'Samurai Jack S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/270877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aBig8NqD8IQrZ1OV258MqHvsAsF.jpg'),
(106256, 7592, 'Samurai Jack S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/270878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aBig8NqD8IQrZ1OV258MqHvsAsF.jpg'),
(106257, 7592, 'Samurai Jack S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/270879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aBig8NqD8IQrZ1OV258MqHvsAsF.jpg'),
(106258, 7592, 'Samurai Jack S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/270880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aBig8NqD8IQrZ1OV258MqHvsAsF.jpg'),
(106259, 7592, 'Samurai Jack S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/270881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aBig8NqD8IQrZ1OV258MqHvsAsF.jpg'),
(106260, 7593, 'Os Sete Monstrinhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106261, 7593, 'Os Sete Monstrinhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106262, 7593, 'Os Sete Monstrinhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106263, 7593, 'Os Sete Monstrinhos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106264, 7593, 'Os Sete Monstrinhos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106265, 7593, 'Os Sete Monstrinhos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106266, 7593, 'Os Sete Monstrinhos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106267, 7593, 'Os Sete Monstrinhos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106268, 7593, 'Os Sete Monstrinhos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106269, 7593, 'Os Sete Monstrinhos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106270, 7593, 'Os Sete Monstrinhos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106271, 7593, 'Os Sete Monstrinhos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106272, 7593, 'Os Sete Monstrinhos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(106273, 7593, 'Os Sete Monstrinhos S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106274, 7593, 'Os Sete Monstrinhos S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106275, 7593, 'Os Sete Monstrinhos S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106276, 7593, 'Os Sete Monstrinhos S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106277, 7593, 'Os Sete Monstrinhos S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106278, 7593, 'Os Sete Monstrinhos S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106279, 7593, 'Os Sete Monstrinhos S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106280, 7593, 'Os Sete Monstrinhos S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106281, 7593, 'Os Sete Monstrinhos S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106282, 7593, 'Os Sete Monstrinhos S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/214711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106283, 7593, 'Os Sete Monstrinhos S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/214712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106284, 7593, 'Os Sete Monstrinhos S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/214713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106285, 7593, 'Os Sete Monstrinhos S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/214714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106286, 7593, 'Os Sete Monstrinhos S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/214715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106287, 7593, 'Os Sete Monstrinhos S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/214716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106288, 7593, 'Os Sete Monstrinhos S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/214717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106289, 7593, 'Os Sete Monstrinhos S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/214718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106290, 7593, 'Os Sete Monstrinhos S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/214719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106291, 7593, 'Os Sete Monstrinhos S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/214720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106292, 7593, 'Os Sete Monstrinhos S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/214721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106293, 7593, 'Os Sete Monstrinhos S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/214722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106294, 7593, 'Os Sete Monstrinhos S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/214723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106295, 7593, 'Os Sete Monstrinhos S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/214724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106296, 7593, 'Os Sete Monstrinhos S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/214725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106297, 7593, 'Os Sete Monstrinhos S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/214726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106298, 7593, 'Os Sete Monstrinhos S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/214727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106299, 7593, 'Os Sete Monstrinhos S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/214728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106300, 7593, 'Os Sete Monstrinhos S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/214729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106301, 7593, 'Os Sete Monstrinhos S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/214730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1G5rOq4q5WLHlSZBp34ibnjtXde.jpg'),
(106302, 7594, 'Tenchi Muyo! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cv72ndg4ptO5iwDAfdbTpmQFpr0.jpg'),
(106303, 7594, 'Tenchi Muyo! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tLZVDzFZgPYmh9TjqNjBRFYvaeV.jpg'),
(106304, 7594, 'Tenchi Muyo! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8jneb6YgNTZvkxG8O5rwQrJAyq7.jpg'),
(106305, 7594, 'Tenchi Muyo! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106306, 7594, 'Tenchi Muyo! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106307, 7594, 'Tenchi Muyo! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106308, 7594, 'Tenchi Muyo! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106309, 7594, 'Tenchi Muyo! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106310, 7594, 'Tenchi Muyo! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106311, 7594, 'Tenchi Muyo! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106312, 7594, 'Tenchi Muyo! S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106313, 7594, 'Tenchi Muyo! S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106314, 7594, 'Tenchi Muyo! S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106315, 7594, 'Tenchi Muyo! S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106316, 7594, 'Tenchi Muyo! S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106317, 7594, 'Tenchi Muyo! S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106318, 7594, 'Tenchi Muyo! S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106319, 7594, 'Tenchi Muyo! S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106320, 7594, 'Tenchi Muyo! S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106321, 7594, 'Tenchi Muyo! S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106322, 7594, 'Tenchi Muyo! S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106323, 7594, 'Tenchi Muyo! S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106324, 7594, 'Tenchi Muyo! S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/214149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106325, 7594, 'Tenchi Muyo! S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/214150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106326, 7594, 'Tenchi Muyo! S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/214151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106327, 7594, 'Tenchi Muyo! S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/214152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hNvusu5DLyA67YxHTAZGn9txacK.jpg'),
(106328, 7595, 'Laços Maternos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tB4THoHVKVWVlwcR1xs7wfbKc7q.jpg'),
(106329, 7595, 'Laços Maternos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jSPz9VaW6neB6EnKtoYfgGSm8iW.jpg'),
(106330, 7595, 'Laços Maternos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oX1tryCi2rdBPyiSo4PogWiSX6Y.jpg'),
(106331, 7595, 'Laços Maternos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qmNGvuC7NC96RZmSH7hH1VuDDc.jpg'),
(106332, 7595, 'Laços Maternos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qsgfTFAYlUdKUaOpLOTyKetppWW.jpg'),
(106333, 7595, 'Laços Maternos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2M58lEVv14AQVgDrcG2obAG0XD.jpg'),
(106334, 7595, 'Laços Maternos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5zOKixWwKgMddgjgUnCjr4t7ie.jpg'),
(106335, 7595, 'Laços Maternos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyNBonhHeg7psxWl8xUwNfuDrGh.jpg'),
(106336, 7595, 'Laços Maternos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/exZY2H0IIeJ7Adlbds787n4EgAn.jpg'),
(106337, 7595, 'Laços Maternos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5cU8NeEsZinyDwEqe0cGXH2dJmb.jpg'),
(106338, 7595, 'Laços Maternos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vkZYgR71piLsXzAEdoIZTkZi518.jpg'),
(106339, 7595, 'Laços Maternos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mA9gCMyotgzvtAAuDLsHzXlc4WA.jpg'),
(106340, 7595, 'Laços Maternos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3T54UlmhpwWDmdYZEznHiVUXv8i.jpg'),
(106341, 7595, 'Laços Maternos S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d8nNgWcMXRMMIYSacPjQQmnVeC6.jpg'),
(106342, 7595, 'Laços Maternos S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8rTYWgVfrfRBsX8yTQpOq77Z5dk.jpg'),
(106343, 7595, 'Laços Maternos S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9iyL2Rg5Mtd4iTQJP465aY4qRln.jpg'),
(106344, 7595, 'Laços Maternos S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ks8B0LQCHKw5MfY98AbXY4mB4pi.jpg'),
(106345, 7595, 'Laços Maternos S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e6jf8AZcq9CSo7tUdNCkhnMiKBf.jpg'),
(106346, 7595, 'Laços Maternos S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qoOuX2bIeKaBOeNMlbxNttmV545.jpg'),
(106347, 7595, 'Laços Maternos S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zkjAMcQom6tjFzzGrNCLktR2lJg.jpg'),
(106348, 7595, 'Laços Maternos S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2APYqHxDtSLGZ4xYDAkfxyfvQtD.jpg'),
(106349, 7595, 'Laços Maternos S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AcHOftalROw2Hm9bNHZ0BIVmxHl.jpg'),
(106350, 7595, 'Laços Maternos S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/214125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nRW7Iif1H3iPyxUx45URID5koEA.jpg'),
(106351, 7595, 'Laços Maternos S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/214126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pIAfZOMqWibOqy8sDOSY8nBX66a.jpg'),
(106352, 5986, 'Landscapers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214099.mp4', 'http://timg.bdta.pro/images/034eb7b810ee327600ceaf2ca9239627.jpg'),
(106353, 5986, 'Landscapers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214100.mp4', 'http://timg.bdta.pro/images/814712964c2c6c159886150c8ca162e6.jpg'),
(106354, 5986, 'Landscapers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214101.mp4', 'http://timg.bdta.pro/images/f7918c5a5b58de89ac226ad391c99642.jpg'),
(106355, 5986, 'Landscapers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214102.mp4', 'http://timg.bdta.pro/images/d0f70033df4196178e2892655fd7a568.jpg'),
(106356, 7596, 'Namoro no Sigilo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kd99h0hZmnJDiRkoLdHZkJBeRI0.jpg'),
(106357, 7596, 'Namoro no Sigilo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wxlCjkMhLhp7AieF9cGWDmCKO2N.jpg'),
(106358, 7596, 'Namoro no Sigilo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qwTeznPtUB0YESnYXtD6YH37bXF.jpg'),
(106359, 7596, 'Namoro no Sigilo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oyv1DS7jpTu0pb8B5hgsxRcoqOm.jpg'),
(106360, 7596, 'Namoro no Sigilo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9Fk5JLge3Ub9fotEBjZMvq85sf.jpg'),
(106361, 7596, 'Namoro no Sigilo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqyE3EJ9DIsWhEmUa2b63Dem5TG.jpg'),
(106362, 7596, 'Namoro no Sigilo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v6AfA9j1OqIg0hCC9G2UVCX5DTd.jpg'),
(106363, 7596, 'Namoro no Sigilo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/faHmkhhBJ3Zq5LpBvgCorkn8Ei3.jpg'),
(106364, 7596, 'Namoro no Sigilo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mBlOYRDfcGLJ4g6xU1YolDfhYDn.jpg'),
(106365, 7596, 'Namoro no Sigilo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dOinRI0E5W0i2knEip97ltPNMqk.jpg'),
(106366, 7597, 'Ou Tudo ou Nada de Novo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dyIoLVPp5xfRbQe4hFDkgXGmC3f.jpg'),
(106367, 7597, 'Ou Tudo ou Nada de Novo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fvFUP3ZQXd6kU4zMxA8z7sk3VVs.jpg'),
(106368, 7597, 'Ou Tudo ou Nada de Novo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dsY0zK6e6ggmYctm23GFu2o3efK.jpg'),
(106369, 7597, 'Ou Tudo ou Nada de Novo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cH5lIGOd8ut4iYjJkpUpklTgbF1.jpg'),
(106370, 7597, 'Ou Tudo ou Nada de Novo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/orJBFgeIoWVIBrzPqe5dl8iQHR9.jpg'),
(106371, 7597, 'Ou Tudo ou Nada de Novo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v5s9KWaItncSXMumzlYh9H1BOdu.jpg'),
(106372, 7597, 'Ou Tudo ou Nada de Novo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228365.mp4', 'http://image.tmdb.org/t/p/w1280/8cVVvoh1e69mUOZ4jtqgOgkLNdd.jpg'),
(106373, 7597, 'Ou Tudo ou Nada de Novo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228366.mp4', 'http://image.tmdb.org/t/p/w1280/kGJeaKCczSzzRwn5Uu9xan1AmB3.jpg'),
(106374, 7598, 'Sr. Errado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/56eu2AYEtuFN29Ji8fQqtDd8NMZ.jpg'),
(106375, 7598, 'Sr. Errado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nCExYydOgl7ViAuor4Kb5p3iUnC.jpg'),
(106376, 7598, 'Sr. Errado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kgWuAQ9hH5zqW1c6Ht9NOHN1t27.jpg'),
(106377, 7598, 'Sr. Errado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fz2RZ8MsdglBZzNqtOHVKeUMdOC.jpg'),
(106378, 7598, 'Sr. Errado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3JBJIjL7IEu2oI6T46inymKzT3d.jpg'),
(106379, 7598, 'Sr. Errado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hyRuCBK9TnxKbkg9pzcLAYzsqQd.jpg'),
(106380, 7598, 'Sr. Errado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ApJ2RSBQB8MMN9apJ1JnCLNR4lY.jpg'),
(106381, 7598, 'Sr. Errado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g3BbcjN9ZkhSKC5fgp77J6ZGEd6.jpg'),
(106382, 7598, 'Sr. Errado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3TUXiWgE7ALvg8SHxmyVgnJJoc1.jpg'),
(106383, 7598, 'Sr. Errado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cM4NhV8XOwb80aPmql9xHb1vjHD.jpg'),
(106384, 7598, 'Sr. Errado S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yZfWRlBHcgi44zuye6in7sJhPXX.jpg'),
(106385, 7598, 'Sr. Errado S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/227257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hBoXmlhHYkjZDx5cLSCVVFhsIrK.jpg'),
(106386, 7598, 'Sr. Errado S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/227258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ncu9d9yLCfXCR4lNuWiKzXDivnA.jpg'),
(106387, 7598, 'Sr. Errado S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/227259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7W95E1yMIE6fXrsqH0OQwn7texR.jpg'),
(106388, 7598, 'Sr. Errado S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/227260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106389, 7598, 'Sr. Errado S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/227261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106390, 7598, 'Sr. Errado S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/227262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106391, 7598, 'Sr. Errado S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/227263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106392, 7598, 'Sr. Errado S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/227264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106393, 7598, 'Sr. Errado S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/227265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106394, 7598, 'Sr. Errado S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/227266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106395, 7598, 'Sr. Errado S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/227267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106396, 7598, 'Sr. Errado S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/227268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106397, 7598, 'Sr. Errado S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/227269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106398, 7598, 'Sr. Errado S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/227270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106399, 7598, 'Sr. Errado S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/227271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106400, 7598, 'Sr. Errado S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/227272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106401, 7598, 'Sr. Errado S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/227273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106402, 7598, 'Sr. Errado S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/227274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106403, 7598, 'Sr. Errado S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/227275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106404, 7598, 'Sr. Errado S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/227276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106405, 7598, 'Sr. Errado S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/227277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106406, 7598, 'Sr. Errado S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/227278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106407, 7598, 'Sr. Errado S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/227279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106408, 7598, 'Sr. Errado S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/227280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106409, 7598, 'Sr. Errado S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/227281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106410, 7598, 'Sr. Errado S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/227282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106411, 7598, 'Sr. Errado S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/227283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106412, 7598, 'Sr. Errado S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/227284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106413, 7598, 'Sr. Errado S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/227285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106414, 7598, 'Sr. Errado S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/227286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106415, 7598, 'Sr. Errado S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/227287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106416, 7598, 'Sr. Errado S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/227288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uu7L7eNIoymPmRJdODf9fN6dW8.jpg'),
(106417, 7599, 'West Wing: Nos Bastidores do Poder S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dcGkNDGfBioSHH1of82LiNIZGQz.jpg'),
(106418, 7599, 'West Wing: Nos Bastidores do Poder S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJciFIkGwpPdXlke0RVK8Ea4mBK.jpg'),
(106419, 7599, 'West Wing: Nos Bastidores do Poder S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/75MpNc8SW7aq2HsBmKHSELinmha.jpg'),
(106420, 7599, 'West Wing: Nos Bastidores do Poder S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ho8uqw1wJkfiwvtgwSQHaRKE3Kx.jpg'),
(106421, 7599, 'West Wing: Nos Bastidores do Poder S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4vygb26BFSkblqIrpW2FUuYyHsU.jpg'),
(106422, 7599, 'West Wing: Nos Bastidores do Poder S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/74p6ri1h9xb0hvnanEwJv1kMvPt.jpg'),
(106423, 7599, 'West Wing: Nos Bastidores do Poder S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/27caH9ATo9f8eh5YJKMDQK5XPfk.jpg'),
(106424, 7599, 'West Wing: Nos Bastidores do Poder S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZXJdovxpKzsR5eKooOMYJBYtCL.jpg'),
(106425, 7599, 'West Wing: Nos Bastidores do Poder S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m0a33AtGyU8akpzWDpT4ALqooDC.jpg'),
(106426, 7599, 'West Wing: Nos Bastidores do Poder S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/631nPlejxz755a0eeL1jGgYmN9X.jpg'),
(106427, 7599, 'West Wing: Nos Bastidores do Poder S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/213967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fN6IB7KjqBkl70T8hAQWafKg5tV.jpg'),
(106428, 7599, 'West Wing: Nos Bastidores do Poder S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/213968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vEBO5t9WZXK9IksKpycrAncLgOf.jpg'),
(106429, 7599, 'West Wing: Nos Bastidores do Poder S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/213969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xjJEa7uEamJRZMuREaxLYXLWQU5.jpg'),
(106430, 7599, 'West Wing: Nos Bastidores do Poder S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/213970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fqY86wIig59pa6rg3RUOvxzBnX3.jpg'),
(106431, 7599, 'West Wing: Nos Bastidores do Poder S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/213971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/onGYEB9K17wwLlCaKCL0VJy5gD6.jpg'),
(106432, 7599, 'West Wing: Nos Bastidores do Poder S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/213972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z7gIjf3AkO3j7ADPJq2p8YPyZoy.jpg'),
(106433, 7599, 'West Wing: Nos Bastidores do Poder S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/213973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dGZVIRtUa6JSnTNk11weDR1x1Ys.jpg'),
(106434, 7599, 'West Wing: Nos Bastidores do Poder S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/213974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ci8IVEcuJSkV3B6wLNxEarfbTQj.jpg'),
(106435, 7599, 'West Wing: Nos Bastidores do Poder S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/213975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wctjKXylb3Yuw54nGtmYDcVZ2Pr.jpg'),
(106436, 7599, 'West Wing: Nos Bastidores do Poder S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/213976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQJG2MkmiRviUPdIiGrf0PO2Bed.jpg'),
(106437, 7599, 'West Wing: Nos Bastidores do Poder S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/213977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iQgaZKUPgDLJdd5nr455K9pkzFh.jpg'),
(106438, 7599, 'West Wing: Nos Bastidores do Poder S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/213978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24L7zyzTLi8YJu23W35TaRLgxTa.jpg'),
(106439, 7600, 'West Wing: Nos Bastidores do Poder S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/213979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7KDyfDBeJBxbXhEG8KWVBlCDaoD.jpg'),
(106440, 7600, 'West Wing: Nos Bastidores do Poder S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/213980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1psPu9IsPFBR7BHLkFTfZ8zMUWs.jpg'),
(106441, 7600, 'West Wing: Nos Bastidores do Poder S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/213981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/77c2iIBrzj02jlq72xyIuxkVFbv.jpg'),
(106442, 7600, 'West Wing: Nos Bastidores do Poder S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/213982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aXjjbTLgIlEvGmXohjcZPJvgWHQ.jpg'),
(106443, 7600, 'West Wing: Nos Bastidores do Poder S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/213983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sq2lSD0F9i68R7VQ3i31jrUCJW1.jpg'),
(106444, 7600, 'West Wing: Nos Bastidores do Poder S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/213984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pPhcLNko6QIa1EmojCkoyHF0nCo.jpg'),
(106445, 7600, 'West Wing: Nos Bastidores do Poder S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/213985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xRkfo63j0CUZZ9IXOseUD6NMGCN.jpg'),
(106446, 7600, 'West Wing: Nos Bastidores do Poder S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/213986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iaJQmM1IDau8q3SnxgUlCvWuUHN.jpg'),
(106447, 7600, 'West Wing: Nos Bastidores do Poder S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/213987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3xKc2sKNxvvh6IVa508dl1rJO1.jpg'),
(106448, 7600, 'West Wing: Nos Bastidores do Poder S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/213988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pA827iJyCveMT9sTCsSxLxPCoQO.jpg'),
(106449, 7600, 'West Wing: Nos Bastidores do Poder S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/213989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vb6fxkeU3REXZmhi6i0KhjwaQ9f.jpg'),
(106450, 7600, 'West Wing: Nos Bastidores do Poder S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/213990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBbQ3pQwVfc4tGOKGlfsJJGXRGq.jpg'),
(106451, 7600, 'West Wing: Nos Bastidores do Poder S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/213991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xF2wtI5kt6NuWt62FSVQ7RrEeuq.jpg'),
(106452, 7600, 'West Wing: Nos Bastidores do Poder S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/213992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQRDBcGsYjlaPgSeGybWyEIWmyx.jpg'),
(106453, 7600, 'West Wing: Nos Bastidores do Poder S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/213993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/chkQuQSAAr9itYQbo3o7HQPpyaz.jpg'),
(106454, 7600, 'West Wing: Nos Bastidores do Poder S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/213994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kEc1Fn2jjaFslO2wix778qQZ5mM.jpg'),
(106455, 7600, 'West Wing: Nos Bastidores do Poder S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/213995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4PLdAvyjquaOJbDoblDMJFlJodd.jpg'),
(106456, 7600, 'West Wing: Nos Bastidores do Poder S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/213996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qp1duyW9mUPT5fyya0bDvEdlSs2.jpg'),
(106457, 7600, 'West Wing: Nos Bastidores do Poder S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/213997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oywXaXDKYH51CVXMIoCAlMkzEQ3.jpg'),
(106458, 7600, 'West Wing: Nos Bastidores do Poder S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/213998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lBoascZ9xDSlmNJLmP0fA1NZPcj.jpg'),
(106459, 7600, 'West Wing: Nos Bastidores do Poder S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/213999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/abO2pD8DReBbjFsrJcOuksm76xi.jpg'),
(106460, 7600, 'West Wing: Nos Bastidores do Poder S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sKGlwZPC59seXrl4WgvyPiSVUFU.jpg'),
(106461, 7601, 'West Wing: Nos Bastidores do Poder S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/99eM8LFWYJYR9Reo3vKweWpJ9t7.jpg'),
(106462, 7601, 'West Wing: Nos Bastidores do Poder S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8wIlDvNhxhfEvM52BVDuugxvfJ2.jpg'),
(106463, 7601, 'West Wing: Nos Bastidores do Poder S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jUFU2gJEFdZlQ25Yj4TYRz7z63.jpg'),
(106464, 7601, 'West Wing: Nos Bastidores do Poder S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQG3qoeeFQp47b7ozuo0jfzuRSS.jpg'),
(106465, 7601, 'West Wing: Nos Bastidores do Poder S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pWEyesJDBwjWL0EB4QqviP01gz1.jpg'),
(106466, 7601, 'West Wing: Nos Bastidores do Poder S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kuGOwjrWD41LIwUjDAxIEgrneTf.jpg'),
(106467, 7601, 'West Wing: Nos Bastidores do Poder S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3ohIGl3QppK7poxYIai1oahBod.jpg'),
(106468, 7601, 'West Wing: Nos Bastidores do Poder S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xk0LnbIv0EMC16lI0DifOMqZCA0.jpg'),
(106469, 7601, 'West Wing: Nos Bastidores do Poder S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8ZUIeJlyCaHyjq7poCY7ca3Dbc.jpg'),
(106470, 7601, 'West Wing: Nos Bastidores do Poder S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wVbZEVbuNg0JmP1hY8vpj71SbWf.jpg'),
(106471, 7601, 'West Wing: Nos Bastidores do Poder S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nuFtUAyahil0rBvha0RP6DzhOA4.jpg'),
(106472, 7601, 'West Wing: Nos Bastidores do Poder S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xVoVQsKpjWNvQpzcn5HvfUDiWd4.jpg'),
(106473, 7601, 'West Wing: Nos Bastidores do Poder S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xFSctrIHZf7ktxCw1RiCVQcemtD.jpg'),
(106474, 7601, 'West Wing: Nos Bastidores do Poder S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wAGHYggaB1Bx2B8F6VoDnJ6B6WZ.jpg'),
(106475, 7601, 'West Wing: Nos Bastidores do Poder S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwY8oYwjT1SjwGzjAXu6MkFYENW.jpg'),
(106476, 7601, 'West Wing: Nos Bastidores do Poder S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5nDmr9E7BUJO6ut8HphC5irro3y.jpg'),
(106477, 7601, 'West Wing: Nos Bastidores do Poder S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ceGVawkE4m8MpreM7mvBXJBbtnJ.jpg'),
(106478, 7601, 'West Wing: Nos Bastidores do Poder S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nWPO8w9ZnU1JeFG4Ig9XHL2mkNa.jpg'),
(106479, 7601, 'West Wing: Nos Bastidores do Poder S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vkYJeDTMYIfWydMg9CHR0YjLIB0.jpg'),
(106480, 7601, 'West Wing: Nos Bastidores do Poder S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LAX1cqNNtaC8yGqosU2FTzzeHL.jpg'),
(106481, 7601, 'West Wing: Nos Bastidores do Poder S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aj941jckZgfeRcQAoaxCHd8mYh5.jpg'),
(106482, 7602, 'West Wing: Nos Bastidores do Poder S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iTOVNKYx9oXggzAdUlRtCI9416b.jpg'),
(106483, 7602, 'West Wing: Nos Bastidores do Poder S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g9U4eaX7ou2sA1hr2kTFoYpM4qz.jpg'),
(106484, 7602, 'West Wing: Nos Bastidores do Poder S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3lLvYt1428kZUOFrjHW14fjoNx6.jpg'),
(106485, 7602, 'West Wing: Nos Bastidores do Poder S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/puvhWCFS06280zk7ksJEaU1rkn3.jpg'),
(106486, 7602, 'West Wing: Nos Bastidores do Poder S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eq7jULPfh81Hrq4TB7MCSG1P2TX.jpg'),
(106487, 7602, 'West Wing: Nos Bastidores do Poder S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xou3XckiD7kAa76qsQuvxOweA9J.jpg'),
(106488, 7602, 'West Wing: Nos Bastidores do Poder S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6LJAzkYuuS03T3wES0Wf0akey78.jpg'),
(106489, 7602, 'West Wing: Nos Bastidores do Poder S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5pmgphiLmLq1aq4GJ8lSzJcZtKu.jpg'),
(106490, 7602, 'West Wing: Nos Bastidores do Poder S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h2kzjv40D2LNNntrrN538hvTyoP.jpg'),
(106491, 7602, 'West Wing: Nos Bastidores do Poder S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8qimKFfeq7EWY9r32ds0RXVNiWN.jpg'),
(106492, 7602, 'West Wing: Nos Bastidores do Poder S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5mYRjoNFrywXf3MM9IcvWNDJqjl.jpg'),
(106493, 7602, 'West Wing: Nos Bastidores do Poder S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4u5tg7qPNAyRsK17fA36tfQo75.jpg'),
(106494, 7602, 'West Wing: Nos Bastidores do Poder S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7xNCz2lzsEy1xg6yjuyKiovOVe5.jpg'),
(106495, 7602, 'West Wing: Nos Bastidores do Poder S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ihWEqEYuKcbHwR12toPAUORyb9.jpg'),
(106496, 7602, 'West Wing: Nos Bastidores do Poder S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3UQxgZ5aAmPTHMpKAgeuDjVi5Zl.jpg'),
(106497, 7602, 'West Wing: Nos Bastidores do Poder S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vLsGjbUusX2AhhCWUpQouXX50An.jpg'),
(106498, 7602, 'West Wing: Nos Bastidores do Poder S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nca1CqDS5nHl1lPYopKX3xIaJaA.jpg'),
(106499, 7602, 'West Wing: Nos Bastidores do Poder S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qjIogA3mCo1z4dtQwSB7gsCtmS7.jpg'),
(106500, 7602, 'West Wing: Nos Bastidores do Poder S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/25RhMv3J1AhfF8HYtCJ5Q3uxSjj.jpg'),
(106501, 7602, 'West Wing: Nos Bastidores do Poder S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aEzqUeg0IgKVM5LraEQwyau9Tn7.jpg'),
(106502, 7602, 'West Wing: Nos Bastidores do Poder S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Rm1KQrOumFNbxmJ8ec4RP4sRDu.jpg'),
(106503, 7602, 'West Wing: Nos Bastidores do Poder S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hPnXIJwWZr5JaGuY6uCzvfhi6BG.jpg'),
(106504, 7602, 'West Wing: Nos Bastidores do Poder S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/214044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3cqAi1joI9iwCn0lVaZt74wQgkT.jpg'),
(106505, 7603, 'West Wing: Nos Bastidores do Poder S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w1DjTzeIyscnmgxktyuSLP2fxYr.jpg'),
(106506, 7603, 'West Wing: Nos Bastidores do Poder S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pEJGHZspigfe5scLArJBFfjZ0W7.jpg'),
(106507, 7603, 'West Wing: Nos Bastidores do Poder S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A7Grm0ssbGkCc5dK6aOftKh8FDG.jpg'),
(106508, 7603, 'West Wing: Nos Bastidores do Poder S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i4l9HZwdymC6n00yWia6uopyUPV.jpg'),
(106509, 7603, 'West Wing: Nos Bastidores do Poder S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lmLZxMWrYFl9NqRdvUOI0ofEYmy.jpg'),
(106510, 7603, 'West Wing: Nos Bastidores do Poder S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eBwlLAS75gJvWAP76VmblEOL59T.jpg'),
(106511, 7603, 'West Wing: Nos Bastidores do Poder S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ypx5axORxIXUOw8wpZPon1lFP5U.jpg'),
(106512, 7603, 'West Wing: Nos Bastidores do Poder S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2tGSPlp1eJp8AsLpcghVFa9z3VZ.jpg'),
(106513, 7603, 'West Wing: Nos Bastidores do Poder S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pLMX9vc2TOKIsrvL4jhrN0FKDqa.jpg'),
(106514, 7603, 'West Wing: Nos Bastidores do Poder S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pF6gD2UApo92EbIPdpvYDCpFXaZ.jpg'),
(106515, 7603, 'West Wing: Nos Bastidores do Poder S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aEWhybnGI19rb1TMa7vREVJE0if.jpg'),
(106516, 7603, 'West Wing: Nos Bastidores do Poder S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wAsku22Hdf1hSbT9OuVM1p5hJJp.jpg'),
(106517, 7603, 'West Wing: Nos Bastidores do Poder S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8QAdg8Aq35MN2WYOkATHn4UDxLZ.jpg'),
(106518, 7603, 'West Wing: Nos Bastidores do Poder S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t91H9foHtk5eN0kjpLlkGlHtZhx.jpg'),
(106519, 7603, 'West Wing: Nos Bastidores do Poder S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ePaJUZbqinQW10S3I1Y9hx484bo.jpg'),
(106520, 7603, 'West Wing: Nos Bastidores do Poder S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u4FZpb7jM8ZZpeIxkXm8YIbT7ZV.jpg'),
(106521, 7603, 'West Wing: Nos Bastidores do Poder S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cBwJ91QYFtug7kZJwJGi3Ijs44Z.jpg'),
(106522, 7603, 'West Wing: Nos Bastidores do Poder S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hPKRG6HlXSEAhost6oM6aqQ5RIa.jpg'),
(106523, 7603, 'West Wing: Nos Bastidores do Poder S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6BdLo5dtVUbR7GEB1gL4rgJ0Hb3.jpg'),
(106524, 7603, 'West Wing: Nos Bastidores do Poder S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Mxk0oBFy2hZMFOco7QCIOA6IyU.jpg'),
(106525, 7603, 'West Wing: Nos Bastidores do Poder S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Z7zu2UjAsVrTC8kvG5TWfkHnJm.jpg'),
(106526, 7603, 'West Wing: Nos Bastidores do Poder S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5LJvjLva0muttSggnNFJVmvGL4g.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(106527, 7604, 'West Wing: Nos Bastidores do Poder S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/214067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k2UTYHPQVfvWfHJJA1duvyvLUlV.jpg'),
(106528, 7604, 'West Wing: Nos Bastidores do Poder S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/214068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hedcPKgII4xzM4Hbt1v9s39xaUF.jpg'),
(106529, 7604, 'West Wing: Nos Bastidores do Poder S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/214069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWtI8eUaAdydYzIL6pPCsh5rfZX.jpg'),
(106530, 7604, 'West Wing: Nos Bastidores do Poder S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/214070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7YdTrUIZoeOLdAGMRNXbbOLTCJ6.jpg'),
(106531, 7604, 'West Wing: Nos Bastidores do Poder S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/214071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8e66Y2Jxp3GdP1dAqt9Ll5uPWT7.jpg'),
(106532, 7604, 'West Wing: Nos Bastidores do Poder S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/214072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xAXf79Nb7FOI1rQ5mCTV95d18PI.jpg'),
(106533, 7604, 'West Wing: Nos Bastidores do Poder S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/214073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2unaDd0NGzkCZ5hMbQQjbDho90Y.jpg'),
(106534, 7604, 'West Wing: Nos Bastidores do Poder S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/214074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iCY66glcPRr4Wh78JLcrGNYFI7e.jpg'),
(106535, 7604, 'West Wing: Nos Bastidores do Poder S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/214075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nPVG7sJd4SR8i5KbhK3UgIgn6Sh.jpg'),
(106536, 7604, 'West Wing: Nos Bastidores do Poder S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/214076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yPKzZX7CCdRce87a5zqrNcPbtWU.jpg'),
(106537, 7604, 'West Wing: Nos Bastidores do Poder S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/214077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wd0fetpB0CL229kktY8Nrw5aOBx.jpg'),
(106538, 7604, 'West Wing: Nos Bastidores do Poder S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/214078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ofMFfybapxtPHChYLkHjNGESdDF.jpg'),
(106539, 7604, 'West Wing: Nos Bastidores do Poder S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/214079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cqMIrQfqHi16wlJJDTZxdkt1C72.jpg'),
(106540, 7604, 'West Wing: Nos Bastidores do Poder S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/214080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m6yO0KxCJtN4faFx6R3KNOUAbQ1.jpg'),
(106541, 7604, 'West Wing: Nos Bastidores do Poder S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/214081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jvRKbDGHxBVmOlsK8sqQ8jAlmsX.jpg'),
(106542, 7604, 'West Wing: Nos Bastidores do Poder S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/214082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k8T6FZIrwEn2wDinmY2TiKU8O3B.jpg'),
(106543, 7604, 'West Wing: Nos Bastidores do Poder S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/214083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yBqNrW1i8Wvd3ZgX4nhzkIzKfkD.jpg'),
(106544, 7604, 'West Wing: Nos Bastidores do Poder S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/214084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vuwcY3tYEuR1NpIeiaQM7h2nQkS.jpg'),
(106545, 7604, 'West Wing: Nos Bastidores do Poder S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/214085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iWZuMNihWmXD5FBAN0UpkNdRUv.jpg'),
(106546, 7604, 'West Wing: Nos Bastidores do Poder S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/214086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/481oiFJzBiS1KceDDLAXmDnCGcG.jpg'),
(106547, 7604, 'West Wing: Nos Bastidores do Poder S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/214087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLA4dckuK43w1lLST6j5w7V8tmO.jpg'),
(106548, 7604, 'West Wing: Nos Bastidores do Poder S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/214088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNWPnhGKhNljYv3THdetrH8tJnP.jpg'),
(106549, 7605, 'A Ilha da Caveira S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ad1ESg8gohlh0vKTzlkfTqESGJH.jpg'),
(106550, 7605, 'A Ilha da Caveira S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ad1ESg8gohlh0vKTzlkfTqESGJH.jpg'),
(106551, 7605, 'A Ilha da Caveira S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ad1ESg8gohlh0vKTzlkfTqESGJH.jpg'),
(106552, 7605, 'A Ilha da Caveira S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ad1ESg8gohlh0vKTzlkfTqESGJH.jpg'),
(106553, 7605, 'A Ilha da Caveira S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ad1ESg8gohlh0vKTzlkfTqESGJH.jpg'),
(106554, 7605, 'A Ilha da Caveira S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ad1ESg8gohlh0vKTzlkfTqESGJH.jpg'),
(106555, 7605, 'A Ilha da Caveira S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ad1ESg8gohlh0vKTzlkfTqESGJH.jpg'),
(106556, 7605, 'A Ilha da Caveira S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ad1ESg8gohlh0vKTzlkfTqESGJH.jpg'),
(106557, 7606, 'As Bruxas Mayfair de Anne Rice S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/99CIBf0x2sGJqntiv5EKbFQSOZd.jpg'),
(106558, 7606, 'As Bruxas Mayfair de Anne Rice S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224974.mp4', 'http://image.tmdb.org/t/p/w1280/pjcmbgwsAT9r5Tmfe7FO33wLfHT.jpg'),
(106559, 7606, 'As Bruxas Mayfair de Anne Rice S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224975.mp4', 'http://image.tmdb.org/t/p/w1280/cQiDxXIbAY5qVYTy0oozJjsmGRt.jpg'),
(106560, 7606, 'As Bruxas Mayfair de Anne Rice S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224976.mp4', 'http://image.tmdb.org/t/p/w1280/lhMMRbfv7fmL3Ct1OXexbTpv9M0.jpg'),
(106561, 7606, 'As Bruxas Mayfair de Anne Rice S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224977.mp4', 'http://image.tmdb.org/t/p/w1280/6PKiyDzynrHG9jpB8WBlzm5e31X.jpg'),
(106562, 7606, 'As Bruxas Mayfair de Anne Rice S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224978.mp4', 'http://image.tmdb.org/t/p/w1280/fjI9Mr8rTTYwYCOcp4bYjdXOF2Q.jpg'),
(106563, 7606, 'As Bruxas Mayfair de Anne Rice S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224979.mp4', 'http://image.tmdb.org/t/p/w1280/kuU69HWMuRZ9Ud4RA5yjDgQhbin.jpg'),
(106564, 7606, 'As Bruxas Mayfair de Anne Rice S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224980.mp4', 'http://image.tmdb.org/t/p/w1280/xQHEOcDbhIU3a1iYpRQXXKXtmiY.jpg'),
(106565, 7607, 'As Bruxas Mayfair de Anne Rice S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/707990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8TjwFIz5CfojrnUenDOEYIgJTjJ.jpg'),
(106566, 7607, 'As Bruxas Mayfair de Anne Rice S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/707991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8TjwFIz5CfojrnUenDOEYIgJTjJ.jpg'),
(106567, 7607, 'As Bruxas Mayfair de Anne Rice S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/707992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8TjwFIz5CfojrnUenDOEYIgJTjJ.jpg'),
(106568, 7607, 'As Bruxas Mayfair de Anne Rice S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/707993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8TjwFIz5CfojrnUenDOEYIgJTjJ.jpg'),
(106569, 7607, 'As Bruxas Mayfair de Anne Rice S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/707994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8TjwFIz5CfojrnUenDOEYIgJTjJ.jpg'),
(106570, 7607, 'As Bruxas Mayfair de Anne Rice S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/707995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8TjwFIz5CfojrnUenDOEYIgJTjJ.jpg'),
(106571, 7607, 'As Bruxas Mayfair de Anne Rice S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/707996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8TjwFIz5CfojrnUenDOEYIgJTjJ.jpg'),
(106572, 7607, 'As Bruxas Mayfair de Anne Rice S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/711714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8TjwFIz5CfojrnUenDOEYIgJTjJ.jpg'),
(106573, 7608, 'Bastidores de uma Conspiração S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jWrYOW1zwqoYZerPJKQNNIlREAv.jpg'),
(106574, 7608, 'Bastidores de uma Conspiração S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zOPUWsWwBl9TPZgTGnMvoENQV1H.jpg'),
(106575, 7608, 'Bastidores de uma Conspiração S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iVnnh0yqU3n7KiS3kI1FQHLyJIH.jpg'),
(106576, 7608, 'Bastidores de uma Conspiração S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uTpnaRTbw1rgpUzk322qay4skGa.jpg'),
(106577, 7608, 'Bastidores de uma Conspiração S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63ziBstLWvzTvMm4N3OWvxvgX3b.jpg'),
(106578, 7608, 'Bastidores de uma Conspiração S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tHDaXcV6HVSZdiqoHsd7mqot9cy.jpg'),
(106579, 7609, 'Casados com o Inimigo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/80m9Jh9KKohL7rtJ1XFnpLpxJcC.jpg'),
(106580, 7609, 'Casados com o Inimigo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/80m9Jh9KKohL7rtJ1XFnpLpxJcC.jpg'),
(106581, 7609, 'Casados com o Inimigo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/80m9Jh9KKohL7rtJ1XFnpLpxJcC.jpg'),
(106582, 7609, 'Casados com o Inimigo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/80m9Jh9KKohL7rtJ1XFnpLpxJcC.jpg'),
(106583, 7609, 'Casados com o Inimigo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222969.mp4', 'http://image.tmdb.org/t/p/w1280/8Li4DksTdaSIswPXTkBjUYuNIIS.jpg'),
(106584, 7609, 'Casados com o Inimigo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222970.mp4', 'http://image.tmdb.org/t/p/w1280/ayCdu3wae9aD4Qg0wmVjDMPuLnm.jpg'),
(106585, 7610, 'Casados com o Inimigo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/755786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/80m9Jh9KKohL7rtJ1XFnpLpxJcC.jpg'),
(106586, 7610, 'Casados com o Inimigo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/755787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/80m9Jh9KKohL7rtJ1XFnpLpxJcC.jpg'),
(106587, 7610, 'Casados com o Inimigo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/755788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/80m9Jh9KKohL7rtJ1XFnpLpxJcC.jpg'),
(106588, 7610, 'Casados com o Inimigo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/755789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/80m9Jh9KKohL7rtJ1XFnpLpxJcC.jpg'),
(106589, 7610, 'Casados com o Inimigo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/755790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/80m9Jh9KKohL7rtJ1XFnpLpxJcC.jpg'),
(106590, 7610, 'Casados com o Inimigo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/755791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/80m9Jh9KKohL7rtJ1XFnpLpxJcC.jpg'),
(106591, 7611, 'Glamorous S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f04hUeCCCmPTnIZ6h8ujItYmI7t.jpg'),
(106592, 7611, 'Glamorous S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f04hUeCCCmPTnIZ6h8ujItYmI7t.jpg'),
(106593, 7611, 'Glamorous S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f04hUeCCCmPTnIZ6h8ujItYmI7t.jpg'),
(106594, 7611, 'Glamorous S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f04hUeCCCmPTnIZ6h8ujItYmI7t.jpg'),
(106595, 7611, 'Glamorous S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f04hUeCCCmPTnIZ6h8ujItYmI7t.jpg'),
(106596, 7611, 'Glamorous S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f04hUeCCCmPTnIZ6h8ujItYmI7t.jpg'),
(106597, 7611, 'Glamorous S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f04hUeCCCmPTnIZ6h8ujItYmI7t.jpg'),
(106598, 7611, 'Glamorous S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f04hUeCCCmPTnIZ6h8ujItYmI7t.jpg'),
(106599, 7611, 'Glamorous S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f04hUeCCCmPTnIZ6h8ujItYmI7t.jpg'),
(106600, 7611, 'Glamorous S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f04hUeCCCmPTnIZ6h8ujItYmI7t.jpg'),
(106601, 7612, 'Invasão Secreta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bG2JzKQ3cqNCxPaLkFENhBcbE70.jpg'),
(106602, 7612, 'Invasão Secreta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227674.mp4', 'http://image.tmdb.org/t/p/w1280/fgZdDp3PRksanaEhrAne3ufVO3X.jpg'),
(106603, 7612, 'Invasão Secreta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227675.mp4', 'http://image.tmdb.org/t/p/w1280/1F3UCOXyAKGj0dRb338hhk7nABh.jpg'),
(106604, 7612, 'Invasão Secreta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227676.mp4', 'http://image.tmdb.org/t/p/w1280/pbQ9GEYrZ52Y4oV2RBiQPtSo6M3.jpg'),
(106605, 7612, 'Invasão Secreta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227677.mp4', 'http://image.tmdb.org/t/p/w1280/psEdUcyKqyFJA5QJkLDpsB5OaCI.jpg'),
(106606, 7612, 'Invasão Secreta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227678.mp4', 'http://image.tmdb.org/t/p/w1280/3RJU5QMdfz6ufTocIcLOzN0wM9M.jpg'),
(106607, 7613, 'Jeitos de Morar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/42NrI1Aiyh7CDISE7bYlphurhSp.jpg'),
(106608, 7613, 'Jeitos de Morar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z3WgjKwTT1DrYCbXr1uSXhYLPUl.jpg'),
(106609, 7613, 'Jeitos de Morar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s8QVM1bICuf80q5pzKUcW4eg1TH.jpg'),
(106610, 7613, 'Jeitos de Morar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4v7Dqnt0fhZ9RRISFcwBm88b0S5.jpg'),
(106611, 7613, 'Jeitos de Morar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6BfpyF9lywuEUYHSccgN4KfWkiM.jpg'),
(106612, 7614, 'O Detetive das Sombras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9nErYfGcBn3SixPqSWDS5pk0AOX.jpg'),
(106613, 7614, 'O Detetive das Sombras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzjy0Me2ZA47qcGqh6zEa9WZnGd.jpg'),
(106614, 7614, 'O Detetive das Sombras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sWLTzH1NW4CId8t3WpjF6C7mJBj.jpg'),
(106615, 7614, 'O Detetive das Sombras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fizi7OhDNnphHL34iyitquzfrDG.jpg'),
(106616, 7614, 'O Detetive das Sombras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/irUZgJzDpbX14kFdqhZr7zlvqat.jpg'),
(106617, 7614, 'O Detetive das Sombras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z8x1CnvkGYQCp1eXbgtqH2GPhwj.jpg'),
(106618, 7614, 'O Detetive das Sombras S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m8t63sHtJqyRe4EHO8cMsP8Ulpz.jpg'),
(106619, 7614, 'O Detetive das Sombras S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xFwoUsZURv6DoF7DInefRJq8RCy.jpg'),
(106620, 7615, 'O Detetive das Sombras S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AhVVfbXWPw6fGNFxvxp1puNyPj6.jpg'),
(106621, 7615, 'O Detetive das Sombras S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBc8N8zyZEGvQXqYKCDrVGyuhHl.jpg'),
(106622, 7615, 'O Detetive das Sombras S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227654.mp4', 'http://image.tmdb.org/t/p/w1280/fPQjs7eo1Y8foTeIfjrQDDA5aqj.jpg'),
(106623, 7615, 'O Detetive das Sombras S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227655.mp4', 'http://image.tmdb.org/t/p/w1280/83kTp5Qo2EGKmj3t0ykn1e4koIM.jpg'),
(106624, 7615, 'O Detetive das Sombras S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227656.mp4', 'http://image.tmdb.org/t/p/w1280/xnzzjZtevAFFJzX9F17Q1VEmQqs.jpg'),
(106625, 7615, 'O Detetive das Sombras S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227657.mp4', 'http://image.tmdb.org/t/p/w1280/u1Pik5TIrYr2SSwE5ffsJH8ji5Y.jpg'),
(106626, 7615, 'O Detetive das Sombras S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/51o8o4t0IfbTfqeLimRplkmnBr.jpg'),
(106627, 7615, 'O Detetive das Sombras S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/W9pJX3qeA0WZHH3VJ3vYbY2Hy2.jpg'),
(106628, 7616, 'O Extraordinário Observador de Pássaros com Christian Cooper S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m7vPKGoiRrqpJy3Od6lyjQHVxO.jpg'),
(106629, 7616, 'O Extraordinário Observador de Pássaros com Christian Cooper S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m7vPKGoiRrqpJy3Od6lyjQHVxO.jpg'),
(106630, 7616, 'O Extraordinário Observador de Pássaros com Christian Cooper S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m7vPKGoiRrqpJy3Od6lyjQHVxO.jpg'),
(106631, 7616, 'O Extraordinário Observador de Pássaros com Christian Cooper S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m7vPKGoiRrqpJy3Od6lyjQHVxO.jpg'),
(106632, 7616, 'O Extraordinário Observador de Pássaros com Christian Cooper S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m7vPKGoiRrqpJy3Od6lyjQHVxO.jpg'),
(106633, 7616, 'O Extraordinário Observador de Pássaros com Christian Cooper S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m7vPKGoiRrqpJy3Od6lyjQHVxO.jpg'),
(106634, 7617, 'Queremos o Divórcio! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AnGehoGpxvKirW4IeTAWvNg6k4V.jpg'),
(106635, 7617, 'Queremos o Divórcio! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/71jtxneutF3JEWJhlROq0L7Uc2P.jpg'),
(106636, 7617, 'Queremos o Divórcio! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ek0VRR4aueSyZb77jp5dJtgALqc.jpg'),
(106637, 7617, 'Queremos o Divórcio! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFLwrS5CFYvtoS422gedLW2Ta0A.jpg'),
(106638, 7617, 'Queremos o Divórcio! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zg8PasvlWlVO0InIS641YkGUT0a.jpg'),
(106639, 7617, 'Queremos o Divórcio! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kmr8MX1B4oqwYCC6l4FXKBvgBMi.jpg'),
(106640, 7617, 'Queremos o Divórcio! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/H8ylip2mBoCPFD4Wz9Q9qU7V5I.jpg'),
(106641, 7617, 'Queremos o Divórcio! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/moSeZCsU2uQXReNmIGrSF9O7vb2.jpg'),
(106642, 7617, 'Queremos o Divórcio! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vtfcPtICbSY6NMCujT2xuOV0rTQ.jpg'),
(106643, 7618, 'Restaurantes no Fim do Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8EAKi6NgTYyDhmKmhGQmL5QvHV1.jpg'),
(106644, 7618, 'Restaurantes no Fim do Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpbJSWdNtdqKYgbkazFWjmJsRzj.jpg'),
(106645, 7618, 'Restaurantes no Fim do Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cU6JnaAawU5rabn8shbuHmA5Kcl.jpg'),
(106646, 7618, 'Restaurantes no Fim do Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8qv4ap8KuF1d0EAAut3N5QranA7.jpg'),
(106647, 7619, 'Um Lar na Natureza S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rz6eICS43S0NJ4WAv3Q4QrymEb2.jpg'),
(106648, 7619, 'Um Lar na Natureza S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rz6eICS43S0NJ4WAv3Q4QrymEb2.jpg'),
(106649, 7619, 'Um Lar na Natureza S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rz6eICS43S0NJ4WAv3Q4QrymEb2.jpg'),
(106650, 7619, 'Um Lar na Natureza S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rz6eICS43S0NJ4WAv3Q4QrymEb2.jpg'),
(106651, 7620, 'The Walking Dead: Dead City [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmvvMZ9kcBxGp8xbLcKHnd0zMiv.jpg'),
(106652, 7620, 'The Walking Dead: Dead City [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nWGqb0jdS9fYOPPJ8D0zgX3kr28.jpg'),
(106653, 7620, 'The Walking Dead: Dead City [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h0TJtfHJ2GhMZbob2smz5tR8iVX.jpg'),
(106654, 7620, 'The Walking Dead: Dead City [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/es0lReTiNJ5GpGcHpOLupeoINZY.jpg'),
(106655, 7620, 'The Walking Dead: Dead City [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rhmylZsxRHx0zQrXfq9xzT8KzA.jpg'),
(106656, 7620, 'The Walking Dead: Dead City [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7WFtEr0Xcbwh5BxDljpQBdJUaEG.jpg'),
(106657, 7621, 'Barra Brava S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bcG1GiiPsZ2b6Xy2TovQJmX0zTm.jpg'),
(106658, 7621, 'Barra Brava S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bcG1GiiPsZ2b6Xy2TovQJmX0zTm.jpg'),
(106659, 7621, 'Barra Brava S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bcG1GiiPsZ2b6Xy2TovQJmX0zTm.jpg'),
(106660, 7621, 'Barra Brava S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bcG1GiiPsZ2b6Xy2TovQJmX0zTm.jpg'),
(106661, 7621, 'Barra Brava S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bcG1GiiPsZ2b6Xy2TovQJmX0zTm.jpg'),
(106662, 7621, 'Barra Brava S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bcG1GiiPsZ2b6Xy2TovQJmX0zTm.jpg'),
(106663, 7621, 'Barra Brava S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bcG1GiiPsZ2b6Xy2TovQJmX0zTm.jpg'),
(106664, 7621, 'Barra Brava S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bcG1GiiPsZ2b6Xy2TovQJmX0zTm.jpg'),
(106665, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dcfHKLYS55YXwZtOaLMe5YItjHg.jpg'),
(106666, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hN06377Q3OStGL6CyzhIgfw8ijr.jpg'),
(106667, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dNl5OFSTM5Qzf3MC0saS9ByytYa.jpg'),
(106668, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/IszJBgm0pAFpX71eNEh2ES1WIQ.jpg'),
(106669, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCzxOTNww05BhdpGzyq0P4GylYb.jpg'),
(106670, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sb88MaRO6hZtiRK8g9MX9uNG1AP.jpg'),
(106671, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sNM4HhBZJgTWjrSCUfsJWY5DAPd.jpg'),
(106672, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/220120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yo5IIz4VKasBR6TJe8mQqfTHyFX.jpg'),
(106673, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/220121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qFLzTrHB4D6nAjlVIoC6PI578sU.jpg'),
(106674, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/220122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tI1M6WdX9Lo6rvDZvEWp1q4Murq.jpg'),
(106675, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/220123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Af45VEdHadrthUJwSnruO42iDEZ.jpg'),
(106676, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/220124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fHiK7A5zOwYRz1ast5jMVeiwSm.jpg'),
(106677, 7623, 'Sou de Virgem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/220106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jDvZNpqzigID0JV0h6zAXNLu7Pv.jpg'),
(106678, 7623, 'Sou de Virgem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/220107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v1V52bv8n6vr1z09G5CBKSIiK2p.jpg'),
(106679, 7623, 'Sou de Virgem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/220108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1rf0GIPDHa9BRktbZeDhs0lG4wV.jpg'),
(106680, 7623, 'Sou de Virgem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/220109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hD96zHOcjEaCBh7bOSQDhSMdMoE.jpg'),
(106681, 7623, 'Sou de Virgem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/220110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6XjE6Rk06l2yePwhKH8vVftJZYF.jpg'),
(106682, 7623, 'Sou de Virgem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/220111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fihlInAF9Z419sNolW9lyZegq1e.jpg'),
(106683, 7623, 'Sou de Virgem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/220112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l2fif0wQr6tvN4R47pORMWFjfdv.jpg'),
(106684, 7624, 'Horóscopo do Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/soJvQR2IwJ5n7fnxIMxYA8YTNFX.jpg'),
(106685, 7624, 'Horóscopo do Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wl47v3mTeGLf3ssJiDo9yoL9ro7.jpg'),
(106686, 7624, 'Horóscopo do Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nhq1N4e9gN1etD6VZHytCrAwDld.jpg'),
(106687, 7624, 'Horóscopo do Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ufyxyavBdynicXcZhu8NWk3VeCw.jpg'),
(106688, 7624, 'Horóscopo do Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3yhqSqau0VrBfdtA0anRK89SjgP.jpg'),
(106689, 7624, 'Horóscopo do Amor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fqIPHqa4dndDs09oA7ViHzO3Mvz.jpg'),
(106690, 7624, 'Horóscopo do Amor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7pFhie0imCgRUAR6axNfBkosR4B.jpg'),
(106691, 7624, 'Horóscopo do Amor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nmKJN0O1mJYqcVBI4Cvz0MNEeKo.jpg'),
(106692, 7624, 'Horóscopo do Amor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ivsN0IRpMAypUkaHOp8EZ7Q6CUT.jpg'),
(106693, 7624, 'Horóscopo do Amor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qgmSogcAVWzH57rwXq7bThOHuRZ.jpg'),
(106694, 7625, 'Mobile Suit Gundam: The Witch from Mercury S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Ew6GXJ9moNOxrVHdmy5P7jiYNp.jpg'),
(106695, 7625, 'Mobile Suit Gundam: The Witch from Mercury S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gzHFWHXA7UKrQA7tzjH9XUSYu5C.jpg'),
(106696, 7625, 'Mobile Suit Gundam: The Witch from Mercury S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yPBX7tYvAaeV53HdfDB4bcT7FYv.jpg'),
(106697, 7625, 'Mobile Suit Gundam: The Witch from Mercury S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1YAQ5DoGQIzYzjVXtIwfi3K8Jwx.jpg'),
(106698, 7625, 'Mobile Suit Gundam: The Witch from Mercury S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ryJjXsb545hwJGApBjjwhIXM6h.jpg'),
(106699, 7625, 'Mobile Suit Gundam: The Witch from Mercury S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/blxgqrx5oUYW8SqFoA9p53Jvvxt.jpg'),
(106700, 7625, 'Mobile Suit Gundam: The Witch from Mercury S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AakN2u9If9NSqUF06EW0T0OKHFN.jpg'),
(106701, 7625, 'Mobile Suit Gundam: The Witch from Mercury S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nShEjqIRQddAq7r0pJanVCXrOKH.jpg'),
(106702, 7625, 'Mobile Suit Gundam: The Witch from Mercury S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cK1K3qQD1hqjAoAbSFzr631UdBp.jpg'),
(106703, 7625, 'Mobile Suit Gundam: The Witch from Mercury S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vQdOVrSzKbWKMOQyNesrvwPvCxO.jpg'),
(106704, 7625, 'Mobile Suit Gundam: The Witch from Mercury S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nYWlo9GiArnO47I37UcxSqtcPTY.jpg'),
(106705, 7625, 'Mobile Suit Gundam: The Witch from Mercury S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqRkvpO4EPZQxB1PGI6AZw9gPZq.jpg'),
(106706, 7626, 'The Ark S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/756782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nZhC1R0FcFiYWFd44xiEh3NASzo.jpg'),
(106707, 7626, 'The Ark S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/756783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mjBFZRhRS1Y9M9SWQRTwcwmsHbq.jpg'),
(106708, 7626, 'The Ark S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/756784.mp4', 'https://image.tmdb.org//t/p/w1280/czj6aB2mIPvrsI7HVTbnXbEzluB.jpg'),
(106709, 7626, 'The Ark S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/756785.mp4', 'https://image.tmdb.org//t/p/w1280/yO8zwhuKvvWX7zBWo14lLxtijI1.jpg'),
(106710, 7626, 'The Ark S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/756786.mp4', 'https://image.tmdb.org//t/p/w1280/ayYhkame4n7oFbUz2eIcuG5lVdE.jpg'),
(106711, 7626, 'The Ark S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/756787.mp4', 'https://image.tmdb.org//t/p/w1280/y7eCORtgYlND2vc59RgYd30c8It.jpg'),
(106712, 7626, 'The Ark S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/756788.mp4', 'https://image.tmdb.org//t/p/w1280/pWxEZgFNzyn5Jjg56YDzOU4b5ul.jpg'),
(106713, 7626, 'The Ark S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/756789.mp4', 'https://image.tmdb.org//t/p/w1280/tSnCNjpTHh2ceVmSOZpO3JgtsAF.jpg'),
(106714, 7626, 'The Ark S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/756790.mp4', 'https://image.tmdb.org//t/p/w1280/4MYaAFvf7htbT9IGrmI52VlIyf.jpg'),
(106715, 7626, 'The Ark S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/756791.mp4', 'https://image.tmdb.org//t/p/w1280/hnT9HZWzS8iysGISs4uRQDQY6h9.jpg'),
(106716, 7626, 'The Ark S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/756792.mp4', 'https://image.tmdb.org//t/p/w1280/k7U0DMU6Y5uc6L5ZgOnr8fGvfHR.jpg'),
(106717, 7626, 'The Ark S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/756793.mp4', 'https://image.tmdb.org//t/p/w1280/ywpM6AcoKDBvTj6a8ViBpGORpSI.jpg'),
(106718, 7627, 'The Ark S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/789219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6pGiYwbSAscG6YyNzxTR6FNtLnO.jpg'),
(106719, 7627, 'The Ark S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/797477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6pGiYwbSAscG6YyNzxTR6FNtLnO.jpg'),
(106720, 7627, 'The Ark S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/799365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6pGiYwbSAscG6YyNzxTR6FNtLnO.jpg'),
(106721, 7627, 'The Ark S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/826937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6pGiYwbSAscG6YyNzxTR6FNtLnO.jpg'),
(106722, 7627, 'The Ark S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/826938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6pGiYwbSAscG6YyNzxTR6FNtLnO.jpg'),
(106723, 7627, 'The Ark S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/841266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6pGiYwbSAscG6YyNzxTR6FNtLnO.jpg'),
(106724, 7627, 'The Ark S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/841267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6pGiYwbSAscG6YyNzxTR6FNtLnO.jpg'),
(106725, 7627, 'The Ark S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/864979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6pGiYwbSAscG6YyNzxTR6FNtLnO.jpg'),
(106726, 7627, 'The Ark S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/864980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6pGiYwbSAscG6YyNzxTR6FNtLnO.jpg'),
(106727, 7627, 'The Ark S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/864981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6pGiYwbSAscG6YyNzxTR6FNtLnO.jpg'),
(106728, 7627, 'The Ark S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/879394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6pGiYwbSAscG6YyNzxTR6FNtLnO.jpg'),
(106729, 7627, 'The Ark S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/879395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6pGiYwbSAscG6YyNzxTR6FNtLnO.jpg'),
(106730, 7628, 'Como Raeliana Foi Parar na Mansão do Duque S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i1EVBKnF0QcpwsO5GMOvA9lm1yA.jpg'),
(106731, 7628, 'Como Raeliana Foi Parar na Mansão do Duque S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lJdz3L85M0onq5PPgQifAkaWJy0.jpg'),
(106732, 7628, 'Como Raeliana Foi Parar na Mansão do Duque S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hkVp06rIN2JPW1EIwkFqeFyRNGk.jpg'),
(106733, 7628, 'Como Raeliana Foi Parar na Mansão do Duque S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/12Mb1UGTKSndefPDdGRniUAatWU.jpg'),
(106734, 7628, 'Como Raeliana Foi Parar na Mansão do Duque S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l0OfPJelzajeynGG2c3YY9keWry.jpg'),
(106735, 7628, 'Como Raeliana Foi Parar na Mansão do Duque S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xsD6Nz3Y2lJPFqdihGNT4KcylHl.jpg'),
(106736, 7628, 'Como Raeliana Foi Parar na Mansão do Duque S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4d0M62aw1eba0gbjZ2n5Qu1kmVZ.jpg'),
(106737, 7628, 'Como Raeliana Foi Parar na Mansão do Duque S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tfZJdTCuJatn9SZF8G0LWVt8pVN.jpg'),
(106738, 7628, 'Como Raeliana Foi Parar na Mansão do Duque S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2B8b3NdNhYajWapOMPLhAXcVtjS.jpg'),
(106739, 7628, 'Como Raeliana Foi Parar na Mansão do Duque S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nNP9S1wiHAAKkrbeBdLDD0wpSua.jpg'),
(106740, 7628, 'Como Raeliana Foi Parar na Mansão do Duque S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hwttOX7hdSOohhKcAEaco2sJTAu.jpg'),
(106741, 7628, 'Como Raeliana Foi Parar na Mansão do Duque S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hB3R4jo62Y8S4CFphunBSrNh8tc.jpg'),
(106742, 7629, 'Delete S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pG0C68eEUKZRDZnma7i1bFTHLJa.jpg'),
(106743, 7629, 'Delete S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tPYn9QT8st27EwpkI3cfnec7fr4.jpg'),
(106744, 7629, 'Delete S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7OZvpCJc5egtPgsSpAuw1Xwy0rl.jpg'),
(106745, 7629, 'Delete S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k8NA2BaS9Kudrxnad69pxpXcKkF.jpg'),
(106746, 7629, 'Delete S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pbJEOa2LbwhHV57rr0zaLiBhSMG.jpg'),
(106747, 7629, 'Delete S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vwgbH3rOMeNy1MUJFmMjIRgTx3e.jpg'),
(106748, 7629, 'Delete S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jwoSwcfFCV07rzy7ck0xISyU8Gp.jpg'),
(106749, 7629, 'Delete S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zHSrbRM4SWU89n7r02Pr9m4y4Mk.jpg'),
(106750, 7630, 'Drag Race Espanha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5rl1TXLDispi4WZIlsjuUHLPOZd.jpg'),
(106751, 7630, 'Drag Race Espanha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVVmxEAGiQu4QUfTHrf8FSaOI3.jpg'),
(106752, 7630, 'Drag Race Espanha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iCwZWm5Yc8bh3zU0AXlaY8jdPsH.jpg'),
(106753, 7630, 'Drag Race Espanha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iTsMCmUu2fOKxhdNGPzt2qnknmZ.jpg'),
(106754, 7630, 'Drag Race Espanha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259102.mp4', 'http://image.tmdb.org/t/p/w1280/mEqmNkuuhQPVuUiP2ry2Z3Z3wYW.jpg'),
(106755, 7630, 'Drag Race Espanha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259103.mp4', 'http://image.tmdb.org/t/p/w1280/eBVI9GDn9cOKTUGiF1pW5ypQGig.jpg'),
(106756, 7630, 'Drag Race Espanha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259104.mp4', 'http://image.tmdb.org/t/p/w1280/x5n8xpjervGEjgjDdC0YaaBmKBJ.jpg'),
(106757, 7630, 'Drag Race Espanha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259105.mp4', 'http://image.tmdb.org/t/p/w1280/9tlkH7n3xAdNgTEXB78SJMhse2b.jpg'),
(106758, 7630, 'Drag Race Espanha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259106.mp4', 'http://image.tmdb.org/t/p/w1280/v1A6y0LI2UAoAROnI9komsPXako.jpg'),
(106759, 7631, 'Drag Race Espanha S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gVZ71BYCjjnRMJih07MNE6Sv1R0.jpg'),
(106760, 7631, 'Drag Race Espanha S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gVZ71BYCjjnRMJih07MNE6Sv1R0.jpg'),
(106761, 7631, 'Drag Race Espanha S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gVZ71BYCjjnRMJih07MNE6Sv1R0.jpg'),
(106762, 7631, 'Drag Race Espanha S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gVZ71BYCjjnRMJih07MNE6Sv1R0.jpg'),
(106763, 7631, 'Drag Race Espanha S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gVZ71BYCjjnRMJih07MNE6Sv1R0.jpg'),
(106764, 7631, 'Drag Race Espanha S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gVZ71BYCjjnRMJih07MNE6Sv1R0.jpg'),
(106765, 7631, 'Drag Race Espanha S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gVZ71BYCjjnRMJih07MNE6Sv1R0.jpg'),
(106766, 7632, 'Sequestro no Ar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eJFtaSm9OybTyVx7KszpBd5DjDB.jpg'),
(106767, 7632, 'Sequestro no Ar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gfksbdZXI5lJch4uKOX6YVaQiCs.jpg'),
(106768, 7632, 'Sequestro no Ar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226585.mp4', 'http://image.tmdb.org/t/p/w1280/nfvs5t9ZhNdqGzM9xy1x690qQCu.jpg'),
(106769, 7632, 'Sequestro no Ar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226586.mp4', 'http://image.tmdb.org/t/p/w1280/lBYdBUUE02droTsU9m7sPrAMNZ.jpg'),
(106770, 7632, 'Sequestro no Ar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226587.mp4', 'http://image.tmdb.org/t/p/w1280/oj1owiW7T9aFvcbkLwFjI4XMTsI.jpg'),
(106771, 7632, 'Sequestro no Ar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226588.mp4', 'http://image.tmdb.org/t/p/w1280/zfoX4Mt6BUeWlq7wb8N9fM9Tcdo.jpg'),
(106772, 7632, 'Sequestro no Ar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226589.mp4', 'http://image.tmdb.org/t/p/w1280/f45gWvRxuIwBQOdG6uJxNzDPb9d.jpg'),
(106773, 7633, 'Swimming with Sharks S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/besCAxbbHnL389kyuJREIwxAf1O.jpg'),
(106774, 7633, 'Swimming with Sharks S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/38Eb8HL5s48zZBmebUoNvLKGpBp.jpg'),
(106775, 7633, 'Swimming with Sharks S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9EdHONhZq59GWareAtrz7DK5mt.jpg'),
(106776, 7633, 'Swimming with Sharks S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/unWe368jmzTg9k5Yuev3wcLTgu2.jpg'),
(106777, 7633, 'Swimming with Sharks S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/arsE1KtAA9yVynTPhfc1YFzfYgq.jpg'),
(106778, 7633, 'Swimming with Sharks S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qPj2Dpdkx9sHyXKJdv791a2jdBi.jpg'),
(106779, 7634, 'Vejo Você na Próxima Vida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cYDu2zog8rBlpBxgjrR4cB0uef2.jpg'),
(106780, 7634, 'Vejo Você na Próxima Vida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDlHwAP4CukzGXhATE4bZd6RBTT.jpg'),
(106781, 7634, 'Vejo Você na Próxima Vida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226208.mp4', 'http://image.tmdb.org/t/p/w1280/7AMJoTU5h8FQJACvzkeppVCCucT.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(106782, 7634, 'Vejo Você na Próxima Vida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226209.mp4', 'http://image.tmdb.org/t/p/w1280/zK7PhusdP9OqvC7rdvFrFkb0Ylu.jpg'),
(106783, 7634, 'Vejo Você na Próxima Vida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226210.mp4', 'http://image.tmdb.org/t/p/w1280/ouJPhdE2IIVDRy0tUhQGKIvldZs.jpg'),
(106784, 7634, 'Vejo Você na Próxima Vida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226211.mp4', 'http://image.tmdb.org/t/p/w1280/A9fjZ5lheRHSQn4PoYAP5iLyitK.jpg'),
(106785, 7634, 'Vejo Você na Próxima Vida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226212.mp4', 'http://image.tmdb.org/t/p/w1280/zH7PKKmgr1KUtWQcGpPKf4tEl4L.jpg'),
(106786, 7634, 'Vejo Você na Próxima Vida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226213.mp4', 'http://image.tmdb.org/t/p/w1280/ppptQgCXx71FgJMVTrkbkjTuWnW.jpg'),
(106787, 7634, 'Vejo Você na Próxima Vida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226214.mp4', 'http://image.tmdb.org/t/p/w1280/jmLZTp2NXL0WfAIcTriq8GBibdn.jpg'),
(106788, 7634, 'Vejo Você na Próxima Vida S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226215.mp4', 'http://image.tmdb.org/t/p/w1280/4LAHTwN9bIA4bqpSluyPiUEP2Xc.jpg'),
(106789, 7634, 'Vejo Você na Próxima Vida S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226216.mp4', 'http://image.tmdb.org/t/p/w1280/feLLG16t4PaxH3hq9OP6kaIwe9g.jpg'),
(106790, 7634, 'Vejo Você na Próxima Vida S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226217.mp4', 'http://image.tmdb.org/t/p/w1280/mPagdfEEnQmjXu6iBUGaJ4V7qKe.jpg'),
(106791, 7635, 'FreeKs S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nAwc1t9sJrBRD945hKFEmFZd4mz.jpg'),
(106792, 7635, 'FreeKs S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e5a7UGyv0vJgmiphH83JUlD31iR.jpg'),
(106793, 7635, 'FreeKs S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1NPVhIqOWJDLgOl9ZunBz78ZCy.jpg'),
(106794, 7635, 'FreeKs S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3iUSvZ4HW4z4aMKy9mhqB1fJHTi.jpg'),
(106795, 7635, 'FreeKs S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cPHstJYKkjc1XaQa7e6NmHgya0k.jpg'),
(106796, 7635, 'FreeKs S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oE6KAguOxJjKa1F6kLbyerN5Ycv.jpg'),
(106797, 7635, 'FreeKs S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mqavcksPPYiE3jSYSOXfmJtOic9.jpg'),
(106798, 7635, 'FreeKs S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vm84OoxIItqV6rZ9DJz2eUHrpKZ.jpg'),
(106799, 7635, 'FreeKs S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4t7gqi7xoa3K0PucZax9aZXks1B.jpg'),
(106800, 7635, 'FreeKs S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6q3IKihms45TI5Bt5mR1buUXDl9.jpg'),
(106801, 7635, 'FreeKs S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aMCp3sMhGUbGN0z5FXsNvedUyGR.jpg'),
(106802, 7635, 'FreeKs S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/icfCOHc009TLbBNUVZqIf9qWIWu.jpg'),
(106803, 7636, 'Família em Obras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106804, 7636, 'Família em Obras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106805, 7636, 'Família em Obras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106806, 7636, 'Família em Obras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106807, 7636, 'Família em Obras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106808, 7636, 'Família em Obras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106809, 7636, 'Família em Obras S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106810, 7636, 'Família em Obras S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106811, 7636, 'Família em Obras S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106812, 7636, 'Família em Obras S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106813, 7636, 'Família em Obras S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106814, 7636, 'Família em Obras S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106815, 7636, 'Família em Obras S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106816, 7636, 'Família em Obras S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/219588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106817, 7636, 'Família em Obras S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/219589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106818, 7636, 'Família em Obras S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/219590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106819, 7636, 'Família em Obras S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/219591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106820, 7636, 'Família em Obras S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/219592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106821, 7636, 'Família em Obras S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/219593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106822, 7636, 'Família em Obras S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/219594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106823, 7636, 'Família em Obras S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/219595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106824, 7636, 'Família em Obras S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/219596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106825, 7636, 'Família em Obras S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/219597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106826, 7636, 'Família em Obras S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/219598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106827, 7637, 'Família em Obras S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106828, 7637, 'Família em Obras S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106829, 7637, 'Família em Obras S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106830, 7637, 'Família em Obras S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106831, 7637, 'Família em Obras S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106832, 7637, 'Família em Obras S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106833, 7637, 'Família em Obras S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106834, 7637, 'Família em Obras S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106835, 7637, 'Família em Obras S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106836, 7637, 'Família em Obras S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106837, 7637, 'Família em Obras S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106838, 7637, 'Família em Obras S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106839, 7637, 'Família em Obras S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106840, 7637, 'Família em Obras S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/219612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106841, 7637, 'Família em Obras S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/219613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106842, 7637, 'Família em Obras S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/219614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106843, 7637, 'Família em Obras S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/219615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106844, 7637, 'Família em Obras S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/219616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106845, 7637, 'Família em Obras S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/219617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106846, 7637, 'Família em Obras S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/219618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106847, 7637, 'Família em Obras S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/219619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106848, 7637, 'Família em Obras S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/219620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106849, 7637, 'Família em Obras S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/219621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106850, 7637, 'Família em Obras S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/219622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106851, 7637, 'Família em Obras S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/219623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1I5dmwZOQaBqvStm6HdIB1nLbA0.jpg'),
(106852, 7638, 'Família em Obras S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kQUASfB1EZ5xpVvrAe3goIsohJG.jpg'),
(106853, 7638, 'Família em Obras S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gWAwwpWaJ2LhKm7wJkNZ0vJWW2Z.jpg'),
(106854, 7638, 'Família em Obras S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a7cFWJuP8IUboBGbyVPyu7rMFH5.jpg'),
(106855, 7638, 'Família em Obras S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybSwJ9bvhnHKstaLsIQpsUwwi1N.jpg'),
(106856, 7638, 'Família em Obras S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQGyMIWgI0iL38mXky12ZAik4qt.jpg'),
(106857, 7638, 'Família em Obras S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8vCpxxQ8ZTxtAaMYsPf8hMkK2xQ.jpg'),
(106858, 7638, 'Família em Obras S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rf7MNHl6e7phu0oYYyDIlorQsIe.jpg'),
(106859, 7638, 'Família em Obras S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mh7fxKaNSoahoICttAVe2gn0CVt.jpg'),
(106860, 7638, 'Família em Obras S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oC6qgum134XaKXkyGsGAJUSgElo.jpg'),
(106861, 7638, 'Família em Obras S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11iyExUZ8kBDd8bEf13YLvHeTiJ.jpg'),
(106862, 7638, 'Família em Obras S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Zelm4jc3cs3RQaFneLYrkLu79n.jpg'),
(106863, 7638, 'Família em Obras S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p9QUtylX1derFfcrQH1VLRr7bZZ.jpg'),
(106864, 7638, 'Família em Obras S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6p8ifRDgAVMUCBLr0moCUXOt5E4.jpg'),
(106865, 7638, 'Família em Obras S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/219637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tm3mJN72OyFqlO9Ow91mnJXT9VO.jpg'),
(106866, 7638, 'Família em Obras S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/219638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sqLtXsCRPNC4YxIRrTdzS29GcgM.jpg'),
(106867, 7638, 'Família em Obras S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/219639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnrG87tbfzXedFBmMooM2dcSduz.jpg'),
(106868, 7638, 'Família em Obras S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/219640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wHMZ2Yaxp6LbHFwiXGCJ79wrdww.jpg'),
(106869, 7638, 'Família em Obras S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/219641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7WI2x2MNLaDbpC6aei7cS1Dcc6f.jpg'),
(106870, 7638, 'Família em Obras S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/219642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t8FRVNSem2VxU23NuqXjxBhnqQh.jpg'),
(106871, 7638, 'Família em Obras S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/219643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fGPPRRrXWZtgpxbNqk0pOqFSwH5.jpg'),
(106872, 7638, 'Família em Obras S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/219644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rdazehSvcxGsJqq6qYxdIfQVGmw.jpg'),
(106873, 7638, 'Família em Obras S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/219645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kv2MhDQuAg63qQunaczwyuGEV5z.jpg'),
(106874, 7638, 'Família em Obras S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/219646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vCyEZBcxjoYYwHkgz2ymhRpb6Gl.jpg'),
(106875, 7638, 'Família em Obras S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/219647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9zy5CZm0yULPG3k79G57aaRaFH6.jpg'),
(106876, 7638, 'Família em Obras S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/219648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBPq5iM483Mk5SXXChuG6mftuIs.jpg'),
(106877, 7639, 'Família em Obras S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/60hWYcsv2qD4uM7zjYBKesW3geQ.jpg'),
(106878, 7639, 'Família em Obras S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9bAGqAJ42d74hb4GmJTwCEbGivb.jpg'),
(106879, 7639, 'Família em Obras S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fzP9WMkfmAkvSPNuT6Y0I5s3kO4.jpg'),
(106880, 7639, 'Família em Obras S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3DGxU3slnUs2MEEwBMTY9R2qrGG.jpg'),
(106881, 7639, 'Família em Obras S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yRVvyPiIrTH0Bvk9TB7RcVSUeaT.jpg'),
(106882, 7639, 'Família em Obras S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tuPznGmudo2h47BLz2eqBoJ4Diy.jpg'),
(106883, 7639, 'Família em Obras S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hO2sTLWOfVEjmShopw2vSonaRTf.jpg'),
(106884, 7639, 'Família em Obras S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tr2VfvyyzpOxLaEZeSjQmW15bue.jpg'),
(106885, 7639, 'Família em Obras S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7JYHrUo4z19BlmY5vb81vzoYdxO.jpg'),
(106886, 7639, 'Família em Obras S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eKwXwyUaq45XITOvAMLl6b6U7LM.jpg'),
(106887, 7639, 'Família em Obras S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fgbcjHQ4VZP87ioozaYQ872olYc.jpg'),
(106888, 7639, 'Família em Obras S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iof6zvTyVESXuAjKTGZvK6KyGHq.jpg'),
(106889, 7639, 'Família em Obras S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUMwNvmvZiOK7mZAGbEtYMGtmBg.jpg'),
(106890, 7639, 'Família em Obras S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/219662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/CToOGPLknmsDWZdwaUIrAH0QVa.jpg'),
(106891, 7639, 'Família em Obras S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/219663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xDLdwjzHDH9Xepz5ZR3cB5pivaz.jpg'),
(106892, 7639, 'Família em Obras S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/219664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h4elZdUBa17nPvt8tv3uw4heTzP.jpg'),
(106893, 7639, 'Família em Obras S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/219665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3tgH9xjOsdAc0UkwB20MI7a2wtD.jpg'),
(106894, 7639, 'Família em Obras S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/219666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJFXPeOTe7vVtp8aksuzj6vvX9F.jpg'),
(106895, 7639, 'Família em Obras S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/219667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dx8HKVGR5LwMAcNAIRwxuwSz0pQ.jpg'),
(106896, 7639, 'Família em Obras S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/219668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/riDJKsUO70mtOMGRLSLBU8j0nr4.jpg'),
(106897, 7639, 'Família em Obras S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/219669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJdJTZRfrMZ0Edn4eqK9uqutCVX.jpg'),
(106898, 7639, 'Família em Obras S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/219670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/znYHsGOu2Ad7DWjr1UQI69QhwfI.jpg'),
(106899, 7639, 'Família em Obras S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/219671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jpXiJihncrRhW0eaVDG8wSthJaJ.jpg'),
(106900, 7639, 'Família em Obras S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/219672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/todzwjhOmgKAOK9vGj7yPzhNONN.jpg'),
(106901, 7639, 'Família em Obras S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/219673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3vMhhY4pETpu7FHGexI0hT8AssX.jpg'),
(106902, 7639, 'Família em Obras S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/219674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qUOL70NmyljieaGywHHaLMfrxa3.jpg'),
(106903, 7640, 'Família em Obras S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c94BcSxfrW2LYlp9zzLuCBU9zXI.jpg'),
(106904, 7640, 'Família em Obras S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7erq2CTn4vg2wDb7s0cF2dr34Th.jpg'),
(106905, 7640, 'Família em Obras S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5oepfXCvAs0JY2RBAsG6TUEksSb.jpg'),
(106906, 7640, 'Família em Obras S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fiTQkF5FDS3UFXOyvmZfgP0EqaU.jpg'),
(106907, 7640, 'Família em Obras S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AhCoVd2RslAJQYaLNfvVJYwOEX3.jpg'),
(106908, 7640, 'Família em Obras S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f6Yg7H5yu3KWLcZgbIsXLG8a7i7.jpg'),
(106909, 7640, 'Família em Obras S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mRVvvFbtPuWipqmHBPH5HrA5jJS.jpg'),
(106910, 7640, 'Família em Obras S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dfkw7htvd4WrfotMnnbz0Grvg4q.jpg'),
(106911, 7640, 'Família em Obras S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fuBZNOnJY1eti6fxRCMfFNd4cLn.jpg'),
(106912, 7640, 'Família em Obras S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eF2AGxvoQ3RW4IE0aFr9kXBA1Z6.jpg'),
(106913, 7640, 'Família em Obras S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dlIDhVhD12G6DiUi4FZwlm8VbFE.jpg'),
(106914, 7640, 'Família em Obras S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWfvDkwRuXAEWehesBMQJ7x0Y35.jpg'),
(106915, 7640, 'Família em Obras S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cqnbNmpazfvV5OmvsDX5ivcfihn.jpg'),
(106916, 7640, 'Família em Obras S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/219688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lfjuV91gHezxgXB0Nt3ZVGg28xZ.jpg'),
(106917, 7640, 'Família em Obras S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/219689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wVV0vgf1ehv1JpsPIEpiyCUeuKj.jpg'),
(106918, 7640, 'Família em Obras S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/219690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kZwGeYgpVgfDeqYzgATRJtxNtqi.jpg'),
(106919, 7640, 'Família em Obras S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/219691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3edQSMX6TnWUWFaFXx8bX2R6Zlm.jpg'),
(106920, 7640, 'Família em Obras S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/219692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bIgdDOJW9GgVZiz1k2FZpzldORW.jpg'),
(106921, 7640, 'Família em Obras S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/219693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5xYJAKyS8nflEUV5tZzpEIeaYlG.jpg'),
(106922, 7640, 'Família em Obras S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/219694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9V1xpTOyd3cv9dHW8LnjE11luek.jpg'),
(106923, 7640, 'Família em Obras S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/219695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOuVmt5RmtAwDhCNgRb5DhrDHrD.jpg'),
(106924, 7640, 'Família em Obras S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/219696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ozNxBzhvhkpA2FeIYiK8BnlmBZ.jpg'),
(106925, 7640, 'Família em Obras S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/219697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2V7KMlR12EU5eG9ryXho7dxD0eK.jpg'),
(106926, 7640, 'Família em Obras S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/219698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2koxdRGxTGFKML5a6L1LFLtqRlL.jpg'),
(106927, 7640, 'Família em Obras S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/219699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e4RIRxPzoolqSABcjnmS5uDeA8j.jpg'),
(106928, 7640, 'Família em Obras S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/219700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9sjZMwlbTUn5tCGt73dZxepYdsJ.jpg'),
(106929, 7641, 'Família em Obras S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dsYnHZj8gzVrpuiNrEQDRBSrIUT.jpg'),
(106930, 7641, 'Família em Obras S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzzc1Ybk3ynXtn1fK7tv5IfGdYn.jpg'),
(106931, 7641, 'Família em Obras S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nQQRBbofjmroNzMS8yNOpQdY02R.jpg'),
(106932, 7641, 'Família em Obras S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/osHnveagqc2xlZOueD1fqUhaH7.jpg'),
(106933, 7641, 'Família em Obras S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wQZSp45DIMdMK6kdhTnJYFMX2GK.jpg'),
(106934, 7641, 'Família em Obras S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pI10em6pOJRNDIa7NzsRuroElrm.jpg'),
(106935, 7641, 'Família em Obras S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3QvbazvYTSf84WCWqvqBNvAmqvf.jpg'),
(106936, 7641, 'Família em Obras S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/veu9TCN0vzHaao4DAG3vB9jchxr.jpg'),
(106937, 7641, 'Família em Obras S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oQmAY1Ttt8AbBKoTNnQ1nzWahKM.jpg'),
(106938, 7641, 'Família em Obras S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/skx8bQTXqtQRmr9gJyXRsU4G1E6.jpg'),
(106939, 7641, 'Família em Obras S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBtk3ybqQTddth1VDe2vQvxXkS3.jpg'),
(106940, 7641, 'Família em Obras S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKVNAY69UP6JprXkR96w1XssBry.jpg'),
(106941, 7641, 'Família em Obras S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nQMdkU6HRNfFZ4B8vpjZyTYRb1B.jpg'),
(106942, 7641, 'Família em Obras S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/219714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pXJT0lT6hgMm5vbICWN1tCGTrpN.jpg'),
(106943, 7641, 'Família em Obras S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/219715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5iv2WJ0FjoF4t9NshWRNosFTjpb.jpg'),
(106944, 7641, 'Família em Obras S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/219716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3glRkB4SmEWPdnUeKyW5xZVOngd.jpg'),
(106945, 7641, 'Família em Obras S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/219717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kwk8iPjiKZ0LwR0YsLEz8NEudy8.jpg'),
(106946, 7641, 'Família em Obras S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/219718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xSvCQwjmGm9Cnb97mVFmG9u9Pbc.jpg'),
(106947, 7641, 'Família em Obras S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/219719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u6nrqas1wIPp7hIim2P5Yq2fxiK.jpg'),
(106948, 7641, 'Família em Obras S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/219720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4uBKmvqRKACvziMJeMDHXu0Iapp.jpg'),
(106949, 7641, 'Família em Obras S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/219721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lN7ufx4gyGhSNaW3uEwoQefSIJu.jpg'),
(106950, 7641, 'Família em Obras S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/219722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7MZUkTCN6cj59kxqW73WDVgxnhG.jpg'),
(106951, 7641, 'Família em Obras S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/219723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p7ZG52KlnXbTd3sjWUoFQycmWdc.jpg'),
(106952, 7641, 'Família em Obras S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/219724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qcbhqgWUFi6PsiSPtBZ1E4IfyoH.jpg'),
(106953, 7641, 'Família em Obras S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/219725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dTiqS7IIuq1Oy1ziTr28XK5z8SB.jpg'),
(106954, 7642, 'Família em Obras S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kkuw08Ke9sUF62pkyToF2njM4Bi.jpg'),
(106955, 7642, 'Família em Obras S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jmd5nGGvLmnVaphoWgEWvcKY6Xi.jpg'),
(106956, 7642, 'Família em Obras S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/igzhOn8QBiarmnaBoqxCuKYzcYq.jpg'),
(106957, 7642, 'Família em Obras S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uP2p7AMcjs3dE91Sazmwc0tCBAR.jpg'),
(106958, 7642, 'Família em Obras S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sWuPdjrF82VkIqpFPTcDKKMYOU5.jpg'),
(106959, 7642, 'Família em Obras S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/26pKBiOzCkGYwS6Z4QZrr8xOmAK.jpg'),
(106960, 7642, 'Família em Obras S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3XYujYhZTAyaQF9u0eyx6UEHfEc.jpg'),
(106961, 7642, 'Família em Obras S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wXLPeuhx5wVOiOVgv4qSVzmZPNV.jpg'),
(106962, 7642, 'Família em Obras S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o6LCC9AhvMQLGK60bQcGCCXAFPH.jpg'),
(106963, 7642, 'Família em Obras S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/znSk5F9Kz7CyRkCRSBOp0GEPPrS.jpg'),
(106964, 7642, 'Família em Obras S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1eMnCfDYBoohBAM1QglqmYDDWth.jpg'),
(106965, 7642, 'Família em Obras S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aiR8b5qCtTuFSKZWSA1hogkUIZe.jpg'),
(106966, 7642, 'Família em Obras S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7oOUDUKBwjwIahpEVtoGhOqTip.jpg'),
(106967, 7642, 'Família em Obras S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/219739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qyXLnnfvPcp0qm9LVERA9ZkWFm7.jpg'),
(106968, 7642, 'Família em Obras S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/219740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x3UydfFWHWHS0lIq0Urdd3f3isY.jpg'),
(106969, 7642, 'Família em Obras S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/219741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z4858OEXy9CJ9z33EFV6a1pzX6S.jpg'),
(106970, 7642, 'Família em Obras S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/219742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tAwBaW07y8mYAH9js0fawA9jnlK.jpg'),
(106971, 7642, 'Família em Obras S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/219743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ld05SywvPkV8nxkBdu4cgxLDlSH.jpg'),
(106972, 7642, 'Família em Obras S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/219744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/muy3eExGKv2Z9RHE1x7N8l3vBl0.jpg'),
(106973, 7642, 'Família em Obras S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/219745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mm1kuy8Yi5MStV7d2cz5VgT64IN.jpg'),
(106974, 7642, 'Família em Obras S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/219746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tBCViX0kukVDzma1qhkXSGsjpkf.jpg'),
(106975, 7642, 'Família em Obras S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/219747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3dQg0JKRibX1ndM5vp2VILqpPC6.jpg'),
(106976, 7642, 'Família em Obras S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/219748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pw0tIyj6o9U5X3DqjFuTMT9SBbK.jpg'),
(106977, 7642, 'Família em Obras S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/219749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1qLEmSaM3N7xbTaTk5HGJMaY9qX.jpg'),
(106978, 7642, 'Família em Obras S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/219750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/umwatOGO9QmIekfEYtopOypGJsH.jpg'),
(106979, 7643, 'Família em Obras S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qOjUlZBuxsREKPWZBBb3qGaTRTh.jpg'),
(106980, 7643, 'Família em Obras S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Zz82Lmm5rLmpKbYU8iujTpCLZ.jpg'),
(106981, 7643, 'Família em Obras S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3UTt0frpHKorh6vxaMZtXD93RNt.jpg'),
(106982, 7643, 'Família em Obras S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2CxVVTnZl1mwwuz1CdagPWwOS73.jpg'),
(106983, 7643, 'Família em Obras S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5def1rWjZYPamcpJnF9UQ4f3QsL.jpg'),
(106984, 7643, 'Família em Obras S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pahzIYqYGqeoN33JMQCgoU64gQg.jpg'),
(106985, 7643, 'Família em Obras S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1P8tv217798Y3YJc4BV9lfhzkL.jpg'),
(106986, 7643, 'Família em Obras S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6p0cDVEDnx61QKpoRmdMfkC9ExA.jpg'),
(106987, 7643, 'Família em Obras S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kMsmUUE7UXteuWnTH0lO5pkwARm.jpg'),
(106988, 7643, 'Família em Obras S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ALO0djIW1YSEZl4eNjg47v93uL.jpg'),
(106989, 7643, 'Família em Obras S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/acWs1t2XNS3VmkW8TjnginaVOGl.jpg'),
(106990, 7643, 'Família em Obras S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8KV4NtAsUmCGWqo1u6CgPy4YtJd.jpg'),
(106991, 7643, 'Família em Obras S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3vDiDuhzao2MpnppkGLhwLHOB9Z.jpg'),
(106992, 7643, 'Família em Obras S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/219764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tVPr8KK6rMLhcWO8C8RT88e7E4B.jpg'),
(106993, 7643, 'Família em Obras S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/219765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u1eYLZzBlndxOMjAxDgFRviphfJ.jpg'),
(106994, 7643, 'Família em Obras S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/219766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dPWUSE3ZVNtaeKi606kRMRVrlzI.jpg'),
(106995, 7643, 'Família em Obras S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/219767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/15qQgmwBpUTxPadOqFBHa08Emyo.jpg'),
(106996, 7643, 'Família em Obras S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/219768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZdJOcDIzkWUTHi0DXHoRo9yjOB.jpg'),
(106997, 7643, 'Família em Obras S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/219769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aS9hIMc2DlDUk2Xts8vOwRJpWGW.jpg'),
(106998, 7643, 'Família em Obras S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/219770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uxRXMILbMm9kY6J6C32W5LO7uCM.jpg'),
(106999, 7643, 'Família em Obras S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/219771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zuhoKpUntO0RfrBnf96UXkCfpKh.jpg'),
(107000, 7643, 'Família em Obras S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/219772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aROMyLJr2bCvX5SXMhfTIbUBKRv.jpg'),
(107001, 7643, 'Família em Obras S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/219773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wSCnXCvaeGwYhJB2snVaQNg1KE8.jpg'),
(107002, 7643, 'Família em Obras S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/219774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i0iGX6JQFdjLfckQz2T8fi31qwd.jpg'),
(107003, 7643, 'Família em Obras S08 E25', 'http://sinalprivado.info:80/series/1533784/1533784/219775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4XjlzA0BMAzm7vEEF4UoBwaxryH.jpg'),
(107004, 7643, 'Família em Obras S08 E26', 'http://sinalprivado.info:80/series/1533784/1533784/219776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6bAtU4HTdYgxWVlrfas3FeI6Yl3.jpg'),
(107005, 7643, 'Família em Obras S08 E27', 'http://sinalprivado.info:80/series/1533784/1533784/219777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tZgJo8Mf93XydnU79NrMA6sXWBF.jpg'),
(107006, 7643, 'Família em Obras S08 E28', 'http://sinalprivado.info:80/series/1533784/1533784/219778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ZLYwJuLGtI788bOPhw9ZNDJXqc.jpg'),
(107007, 7644, 'Ōoku: Por Dentro do Castelo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4G1xzjLfI9ZMNb3gSPm89fnEl3o.jpg'),
(107008, 7644, 'Ōoku: Por Dentro do Castelo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4G1xzjLfI9ZMNb3gSPm89fnEl3o.jpg'),
(107009, 7644, 'Ōoku: Por Dentro do Castelo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4G1xzjLfI9ZMNb3gSPm89fnEl3o.jpg'),
(107010, 7644, 'Ōoku: Por Dentro do Castelo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4G1xzjLfI9ZMNb3gSPm89fnEl3o.jpg'),
(107011, 7644, 'Ōoku: Por Dentro do Castelo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4G1xzjLfI9ZMNb3gSPm89fnEl3o.jpg'),
(107012, 7644, 'Ōoku: Por Dentro do Castelo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4G1xzjLfI9ZMNb3gSPm89fnEl3o.jpg'),
(107013, 7644, 'Ōoku: Por Dentro do Castelo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4G1xzjLfI9ZMNb3gSPm89fnEl3o.jpg'),
(107014, 7644, 'Ōoku: Por Dentro do Castelo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4G1xzjLfI9ZMNb3gSPm89fnEl3o.jpg'),
(107015, 7644, 'Ōoku: Por Dentro do Castelo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4G1xzjLfI9ZMNb3gSPm89fnEl3o.jpg'),
(107016, 7644, 'Ōoku: Por Dentro do Castelo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4G1xzjLfI9ZMNb3gSPm89fnEl3o.jpg'),
(107017, 7645, 'Yargi Segredos de Familia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107018, 7645, 'Yargi Segredos de Familia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107019, 7645, 'Yargi Segredos de Familia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107020, 7645, 'Yargi Segredos de Familia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107021, 7645, 'Yargi Segredos de Familia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107022, 7645, 'Yargi Segredos de Familia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107023, 7645, 'Yargi Segredos de Familia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107024, 7645, 'Yargi Segredos de Familia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107025, 7645, 'Yargi Segredos de Familia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107026, 7645, 'Yargi Segredos de Familia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107027, 7645, 'Yargi Segredos de Familia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107028, 7645, 'Yargi Segredos de Familia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107029, 7645, 'Yargi Segredos de Familia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107030, 7645, 'Yargi Segredos de Familia S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107031, 7645, 'Yargi Segredos de Familia S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107032, 7645, 'Yargi Segredos de Familia S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107033, 7645, 'Yargi Segredos de Familia S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/249517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107034, 7645, 'Yargi Segredos de Familia S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/249518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107035, 7645, 'Yargi Segredos de Familia S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/249519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107036, 7645, 'Yargi Segredos de Familia S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/249520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107037, 7645, 'Yargi Segredos de Familia S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/249521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107038, 7645, 'Yargi Segredos de Familia S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/249522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107039, 7645, 'Yargi Segredos de Familia S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/249523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107040, 7645, 'Yargi Segredos de Familia S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/249524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107041, 7645, 'Yargi Segredos de Familia S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/249525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107042, 7645, 'Yargi Segredos de Familia S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/249526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107043, 7645, 'Yargi Segredos de Familia S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/249527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(107044, 7645, 'Yargi Segredos de Familia S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/249528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107045, 7645, 'Yargi Segredos de Familia S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/249529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107046, 7645, 'Yargi Segredos de Familia S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/249530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107047, 7645, 'Yargi Segredos de Familia S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/249531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107048, 7645, 'Yargi Segredos de Familia S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/249532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107049, 7645, 'Yargi Segredos de Familia S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/249533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107050, 7645, 'Yargi Segredos de Familia S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/249534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107051, 7645, 'Yargi Segredos de Familia S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/249535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107052, 7645, 'Yargi Segredos de Familia S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/249536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107053, 7645, 'Yargi Segredos de Familia S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/249537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107054, 7645, 'Yargi Segredos de Familia S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/249538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107055, 7645, 'Yargi Segredos de Familia S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/249539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107056, 7645, 'Yargi Segredos de Familia S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/249540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107057, 7645, 'Yargi Segredos de Familia S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/249541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107058, 7645, 'Yargi Segredos de Familia S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/249542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107059, 7645, 'Yargi Segredos de Familia S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/249543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107060, 7645, 'Yargi Segredos de Familia S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/249544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107061, 7645, 'Yargi Segredos de Familia S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/249545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107062, 7645, 'Yargi Segredos de Familia S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/249546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107063, 7645, 'Yargi Segredos de Familia S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/249547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107064, 7645, 'Yargi Segredos de Familia S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/249548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107065, 7645, 'Yargi Segredos de Familia S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/249549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107066, 7645, 'Yargi Segredos de Familia S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/249550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107067, 7645, 'Yargi Segredos de Familia S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/249551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107068, 7645, 'Yargi Segredos de Familia S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/249552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107069, 7645, 'Yargi Segredos de Familia S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/249553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107070, 7645, 'Yargi Segredos de Familia S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/249554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107071, 7645, 'Yargi Segredos de Familia S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/249555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107072, 7645, 'Yargi Segredos de Familia S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/249556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107073, 7645, 'Yargi Segredos de Familia S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/249557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107074, 7645, 'Yargi Segredos de Familia S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/249558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107075, 7645, 'Yargi Segredos de Familia S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/249559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107076, 7645, 'Yargi Segredos de Familia S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/249560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107077, 7645, 'Yargi Segredos de Familia S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/249561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107078, 7645, 'Yargi Segredos de Familia S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/249562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107079, 7645, 'Yargi Segredos de Familia S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/249563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107080, 7645, 'Yargi Segredos de Familia S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/249564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107081, 7645, 'Yargi Segredos de Familia S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/249565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107082, 7645, 'Yargi Segredos de Familia S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/249566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107083, 7645, 'Yargi Segredos de Familia S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/249567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107084, 7645, 'Yargi Segredos de Familia S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/249568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107085, 7645, 'Yargi Segredos de Familia S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/249569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107086, 7645, 'Yargi Segredos de Familia S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/249570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107087, 7645, 'Yargi Segredos de Familia S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/249571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107088, 7645, 'Yargi Segredos de Familia S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/249572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107089, 7645, 'Yargi Segredos de Familia S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/249573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107090, 7645, 'Yargi Segredos de Familia S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/249574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107091, 7645, 'Yargi Segredos de Familia S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/249575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107092, 7645, 'Yargi Segredos de Familia S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/249576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107093, 7645, 'Yargi Segredos de Familia S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/249577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107094, 7645, 'Yargi Segredos de Familia S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/249578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107095, 7645, 'Yargi Segredos de Familia S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/249579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107096, 7645, 'Yargi Segredos de Familia S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/249580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107097, 7645, 'Yargi Segredos de Familia S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/249581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107098, 7645, 'Yargi Segredos de Familia S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/249582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107099, 7645, 'Yargi Segredos de Familia S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/249583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107100, 7645, 'Yargi Segredos de Familia S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/249584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107101, 7645, 'Yargi Segredos de Familia S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/249585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107102, 7645, 'Yargi Segredos de Familia S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/249586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107103, 7645, 'Yargi Segredos de Familia S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/249587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107104, 7645, 'Yargi Segredos de Familia S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/249588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107105, 7645, 'Yargi Segredos de Familia S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/249589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107106, 7645, 'Yargi Segredos de Familia S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/249590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107107, 7645, 'Yargi Segredos de Familia S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/249591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107108, 7645, 'Yargi Segredos de Familia S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/249592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107109, 7645, 'Yargi Segredos de Familia S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/249593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107110, 7645, 'Yargi Segredos de Familia S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/249594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107111, 7645, 'Yargi Segredos de Familia S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/249595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107112, 7645, 'Yargi Segredos de Familia S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/249596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107113, 7645, 'Yargi Segredos de Familia S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/249597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107114, 7645, 'Yargi Segredos de Familia S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/249598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107115, 7645, 'Yargi Segredos de Familia S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/249599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107116, 7645, 'Yargi Segredos de Familia S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/249600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107117, 7645, 'Yargi Segredos de Familia S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/249601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107118, 7645, 'Yargi Segredos de Familia S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/249602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107119, 7645, 'Yargi Segredos de Familia S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/249603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107120, 7645, 'Yargi Segredos de Familia S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/249604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107121, 7645, 'Yargi Segredos de Familia S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/249605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107122, 7645, 'Yargi Segredos de Familia S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/249606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107123, 7645, 'Yargi Segredos de Familia S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/249607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107124, 7645, 'Yargi Segredos de Familia S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/249608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107125, 7645, 'Yargi Segredos de Familia S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/249609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107126, 7645, 'Yargi Segredos de Familia S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/249610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107127, 7645, 'Yargi Segredos de Familia S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/249611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107128, 7646, 'Yargi Segredos de Familia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/826843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107129, 7646, 'Yargi Segredos de Familia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/826844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107130, 7646, 'Yargi Segredos de Familia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/826845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107131, 7646, 'Yargi Segredos de Familia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/826846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107132, 7646, 'Yargi Segredos de Familia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/826847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107133, 7646, 'Yargi Segredos de Familia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/826848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107134, 7646, 'Yargi Segredos de Familia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/826849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107135, 7646, 'Yargi Segredos de Familia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/826850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107136, 7646, 'Yargi Segredos de Familia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/826851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107137, 7646, 'Yargi Segredos de Familia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/826852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107138, 7646, 'Yargi Segredos de Familia S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/826853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107139, 7646, 'Yargi Segredos de Familia S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/826854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107140, 7646, 'Yargi Segredos de Familia S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/826855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107141, 7646, 'Yargi Segredos de Familia S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/826856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107142, 7646, 'Yargi Segredos de Familia S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/826857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107143, 7646, 'Yargi Segredos de Familia S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/826858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107144, 7646, 'Yargi Segredos de Familia S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/826859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107145, 7646, 'Yargi Segredos de Familia S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/826860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107146, 7646, 'Yargi Segredos de Familia S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/826861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107147, 7646, 'Yargi Segredos de Familia S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/826862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107148, 7646, 'Yargi Segredos de Familia S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/834676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107149, 7646, 'Yargi Segredos de Familia S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/834677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107150, 7646, 'Yargi Segredos de Familia S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/834678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107151, 7646, 'Yargi Segredos de Familia S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/834679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107152, 7646, 'Yargi Segredos de Familia S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/834680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107153, 7646, 'Yargi Segredos de Familia S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/834681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107154, 7646, 'Yargi Segredos de Familia S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/834682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107155, 7646, 'Yargi Segredos de Familia S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/834683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107156, 7646, 'Yargi Segredos de Familia S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/834684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107157, 7646, 'Yargi Segredos de Familia S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/834685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107158, 7646, 'Yargi Segredos de Familia S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/834686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107159, 7646, 'Yargi Segredos de Familia S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/834687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107160, 7646, 'Yargi Segredos de Familia S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/834688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107161, 7646, 'Yargi Segredos de Familia S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/834689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107162, 7646, 'Yargi Segredos de Familia S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/834690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107163, 7646, 'Yargi Segredos de Familia S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/834691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107164, 7646, 'Yargi Segredos de Familia S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/834692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107165, 7646, 'Yargi Segredos de Familia S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/834693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107166, 7646, 'Yargi Segredos de Familia S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/834694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107167, 7646, 'Yargi Segredos de Familia S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/834695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107168, 7646, 'Yargi Segredos de Familia S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/842587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107169, 7646, 'Yargi Segredos de Familia S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/842588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107170, 7646, 'Yargi Segredos de Familia S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/842589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107171, 7646, 'Yargi Segredos de Familia S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/842590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107172, 7646, 'Yargi Segredos de Familia S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/842591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107173, 7646, 'Yargi Segredos de Familia S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/842592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107174, 7646, 'Yargi Segredos de Familia S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/842593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107175, 7646, 'Yargi Segredos de Familia S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/842594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107176, 7646, 'Yargi Segredos de Familia S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/842595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107177, 7646, 'Yargi Segredos de Familia S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/842596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107178, 7646, 'Yargi Segredos de Familia S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/842597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107179, 7646, 'Yargi Segredos de Familia S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/842598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107180, 7646, 'Yargi Segredos de Familia S02 E53', 'http://sinalprivado.info:80/series/1533784/1533784/842599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107181, 7646, 'Yargi Segredos de Familia S02 E54', 'http://sinalprivado.info:80/series/1533784/1533784/842600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107182, 7646, 'Yargi Segredos de Familia S02 E55', 'http://sinalprivado.info:80/series/1533784/1533784/842601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107183, 7646, 'Yargi Segredos de Familia S02 E56', 'http://sinalprivado.info:80/series/1533784/1533784/842602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107184, 7646, 'Yargi Segredos de Familia S02 E57', 'http://sinalprivado.info:80/series/1533784/1533784/842603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107185, 7646, 'Yargi Segredos de Familia S02 E58', 'http://sinalprivado.info:80/series/1533784/1533784/842604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107186, 7646, 'Yargi Segredos de Familia S02 E59', 'http://sinalprivado.info:80/series/1533784/1533784/842605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107187, 7646, 'Yargi Segredos de Familia S02 E60', 'http://sinalprivado.info:80/series/1533784/1533784/842606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107188, 7646, 'Yargi Segredos de Familia S02 E61', 'http://sinalprivado.info:80/series/1533784/1533784/849575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107189, 7646, 'Yargi Segredos de Familia S02 E62', 'http://sinalprivado.info:80/series/1533784/1533784/849576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107190, 7646, 'Yargi Segredos de Familia S02 E63', 'http://sinalprivado.info:80/series/1533784/1533784/849577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107191, 7646, 'Yargi Segredos de Familia S02 E64', 'http://sinalprivado.info:80/series/1533784/1533784/849578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107192, 7646, 'Yargi Segredos de Familia S02 E65', 'http://sinalprivado.info:80/series/1533784/1533784/849579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107193, 7646, 'Yargi Segredos de Familia S02 E66', 'http://sinalprivado.info:80/series/1533784/1533784/849580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107194, 7646, 'Yargi Segredos de Familia S02 E67', 'http://sinalprivado.info:80/series/1533784/1533784/849581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107195, 7646, 'Yargi Segredos de Familia S02 E68', 'http://sinalprivado.info:80/series/1533784/1533784/849582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107196, 7646, 'Yargi Segredos de Familia S02 E69', 'http://sinalprivado.info:80/series/1533784/1533784/849583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107197, 7646, 'Yargi Segredos de Familia S02 E70', 'http://sinalprivado.info:80/series/1533784/1533784/849584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107198, 7646, 'Yargi Segredos de Familia S02 E71', 'http://sinalprivado.info:80/series/1533784/1533784/849585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107199, 7646, 'Yargi Segredos de Familia S02 E72', 'http://sinalprivado.info:80/series/1533784/1533784/849586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107200, 7646, 'Yargi Segredos de Familia S02 E73', 'http://sinalprivado.info:80/series/1533784/1533784/849587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107201, 7646, 'Yargi Segredos de Familia S02 E74', 'http://sinalprivado.info:80/series/1533784/1533784/849588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107202, 7646, 'Yargi Segredos de Familia S02 E75', 'http://sinalprivado.info:80/series/1533784/1533784/849589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107203, 7646, 'Yargi Segredos de Familia S02 E76', 'http://sinalprivado.info:80/series/1533784/1533784/849590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107204, 7646, 'Yargi Segredos de Familia S02 E77', 'http://sinalprivado.info:80/series/1533784/1533784/849591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107205, 7646, 'Yargi Segredos de Familia S02 E78', 'http://sinalprivado.info:80/series/1533784/1533784/849592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107206, 7646, 'Yargi Segredos de Familia S02 E79', 'http://sinalprivado.info:80/series/1533784/1533784/849593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107207, 7646, 'Yargi Segredos de Familia S02 E80', 'http://sinalprivado.info:80/series/1533784/1533784/849594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107208, 7646, 'Yargi Segredos de Familia S02 E81', 'http://sinalprivado.info:80/series/1533784/1533784/859160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107209, 7646, 'Yargi Segredos de Familia S02 E82', 'http://sinalprivado.info:80/series/1533784/1533784/859161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107210, 7646, 'Yargi Segredos de Familia S02 E83', 'http://sinalprivado.info:80/series/1533784/1533784/859162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107211, 7646, 'Yargi Segredos de Familia S02 E84', 'http://sinalprivado.info:80/series/1533784/1533784/859163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107212, 7646, 'Yargi Segredos de Familia S02 E85', 'http://sinalprivado.info:80/series/1533784/1533784/859164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107213, 7646, 'Yargi Segredos de Familia S02 E86', 'http://sinalprivado.info:80/series/1533784/1533784/859165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107214, 7646, 'Yargi Segredos de Familia S02 E87', 'http://sinalprivado.info:80/series/1533784/1533784/859166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107215, 7646, 'Yargi Segredos de Familia S02 E88', 'http://sinalprivado.info:80/series/1533784/1533784/859167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107216, 7646, 'Yargi Segredos de Familia S02 E89', 'http://sinalprivado.info:80/series/1533784/1533784/859168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107217, 7646, 'Yargi Segredos de Familia S02 E90', 'http://sinalprivado.info:80/series/1533784/1533784/859169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107218, 7646, 'Yargi Segredos de Familia S02 E91', 'http://sinalprivado.info:80/series/1533784/1533784/859170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107219, 7646, 'Yargi Segredos de Familia S02 E92', 'http://sinalprivado.info:80/series/1533784/1533784/859171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107220, 7646, 'Yargi Segredos de Familia S02 E93', 'http://sinalprivado.info:80/series/1533784/1533784/859172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107221, 7646, 'Yargi Segredos de Familia S02 E94', 'http://sinalprivado.info:80/series/1533784/1533784/859173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107222, 7646, 'Yargi Segredos de Familia S02 E95', 'http://sinalprivado.info:80/series/1533784/1533784/859174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107223, 7646, 'Yargi Segredos de Familia S02 E96', 'http://sinalprivado.info:80/series/1533784/1533784/859175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2oMk0CFflhAodqPJD1Kua9RKpDD.jpg'),
(107224, 7647, 'Adotada #TBT S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8C7Q3mxlFaQE6dniPbBNz977tXU.jpg'),
(107225, 7647, 'Adotada #TBT S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8C7Q3mxlFaQE6dniPbBNz977tXU.jpg'),
(107226, 7647, 'Adotada #TBT S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8C7Q3mxlFaQE6dniPbBNz977tXU.jpg'),
(107227, 7647, 'Adotada #TBT S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8C7Q3mxlFaQE6dniPbBNz977tXU.jpg'),
(107228, 7647, 'Adotada #TBT S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8C7Q3mxlFaQE6dniPbBNz977tXU.jpg'),
(107229, 7647, 'Adotada #TBT S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8C7Q3mxlFaQE6dniPbBNz977tXU.jpg'),
(107230, 7647, 'Adotada #TBT S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8C7Q3mxlFaQE6dniPbBNz977tXU.jpg'),
(107231, 7647, 'Adotada #TBT S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8C7Q3mxlFaQE6dniPbBNz977tXU.jpg'),
(107232, 7647, 'Adotada #TBT S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8C7Q3mxlFaQE6dniPbBNz977tXU.jpg'),
(107233, 7647, 'Adotada #TBT S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8C7Q3mxlFaQE6dniPbBNz977tXU.jpg'),
(107234, 7648, 'Celebrity S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ewWqhz1dfsBn6Ox4jo17BJbq4a.jpg'),
(107235, 7648, 'Celebrity S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6yFcCUmZCWLrMu6qGPFaJL8S6O.jpg'),
(107236, 7648, 'Celebrity S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iyeBNXiFNLxpobXHkRlyzDvXCQe.jpg'),
(107237, 7648, 'Celebrity S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w91zjaW65bbIgHInCxmvWOUnv1q.jpg'),
(107238, 7648, 'Celebrity S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ipx9VSWpGGmYc8XpHcCJlGtKhAb.jpg'),
(107239, 7648, 'Celebrity S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fWgBwGt0OfcPJzT8FqQyN9eC8L8.jpg'),
(107240, 7648, 'Celebrity S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w5cQDxCz772avGPkLsWYBAitZqk.jpg'),
(107241, 7648, 'Celebrity S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZ8rQSJbtSF0huqpw0y5E9OQXtv.jpg'),
(107242, 7648, 'Celebrity S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rz4alDFdMM1QGPrSpoKPaCA3PX8.jpg'),
(107243, 7648, 'Celebrity S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kCGzInOmAzcLisuVxtdDQGUCV1B.jpg'),
(107244, 7648, 'Celebrity S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nuYNZBXScPLbep7b71ogYr7YOxo.jpg'),
(107245, 7648, 'Celebrity S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/isvVVs7iy8RCXGKWLRRtNJ6pTUC.jpg'),
(107246, 7649, 'As Aventuras de Kid Danger S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JqQ473UkYpFBjvpGMydI5sjoCI.jpg'),
(107247, 7649, 'As Aventuras de Kid Danger S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JqQ473UkYpFBjvpGMydI5sjoCI.jpg'),
(107248, 7649, 'As Aventuras de Kid Danger S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JqQ473UkYpFBjvpGMydI5sjoCI.jpg'),
(107249, 7649, 'As Aventuras de Kid Danger S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JqQ473UkYpFBjvpGMydI5sjoCI.jpg'),
(107250, 7649, 'As Aventuras de Kid Danger S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JqQ473UkYpFBjvpGMydI5sjoCI.jpg'),
(107251, 7649, 'As Aventuras de Kid Danger S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JqQ473UkYpFBjvpGMydI5sjoCI.jpg'),
(107252, 7649, 'As Aventuras de Kid Danger S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JqQ473UkYpFBjvpGMydI5sjoCI.jpg'),
(107253, 7649, 'As Aventuras de Kid Danger S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JqQ473UkYpFBjvpGMydI5sjoCI.jpg'),
(107254, 7649, 'As Aventuras de Kid Danger S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JqQ473UkYpFBjvpGMydI5sjoCI.jpg'),
(107255, 7649, 'As Aventuras de Kid Danger S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3JqQ473UkYpFBjvpGMydI5sjoCI.jpg'),
(107256, 7650, 'Desgraça ao seu Dispor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/co5fCt4v4WlUzuzNmnPoiMiezBB.jpg'),
(107257, 7650, 'Desgraça ao seu Dispor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a4JeV9b8qZ9aX3FzCJhIodgUHRe.jpg'),
(107258, 7650, 'Desgraça ao seu Dispor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ny3JDy9xCmv3oKMlR505zX9eajz.jpg'),
(107259, 7650, 'Desgraça ao seu Dispor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kUlc7Z5NfM2yJ00VwjhT0EiGZJu.jpg'),
(107260, 7650, 'Desgraça ao seu Dispor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mHQtPHWRw1UPMAclaAQgmR7pUar.jpg'),
(107261, 7650, 'Desgraça ao seu Dispor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iBWravaPjFK5DWtb5eaQ1OeptaQ.jpg'),
(107262, 7650, 'Desgraça ao seu Dispor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8lrCioc2c4VcQmS7jL7lhl9HF7E.jpg'),
(107263, 7650, 'Desgraça ao seu Dispor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ty5Is2rtI3tgFlXLYiR0cS6o22j.jpg'),
(107264, 7650, 'Desgraça ao seu Dispor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eJIWyR0LvW2wi9aXV6CwYcjhhUA.jpg'),
(107265, 7650, 'Desgraça ao seu Dispor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1Fa7Q5Co2zVjNwfzYujFGdMYce.jpg'),
(107266, 7650, 'Desgraça ao seu Dispor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5utlsPsrywclhRbm1ifYs6nYfME.jpg'),
(107267, 7650, 'Desgraça ao seu Dispor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2nnAFExNWDPJQYw7aYxMwDWgdvm.jpg'),
(107268, 7650, 'Desgraça ao seu Dispor S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8LyWcB18jNBOJuTQP7tXJMZwDiQ.jpg'),
(107269, 7650, 'Desgraça ao seu Dispor S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/219210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uhI11077cpyQ26voTQJ5fVNmTGU.jpg'),
(107270, 7650, 'Desgraça ao seu Dispor S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/219211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vywy1gAq5uqri5IRNMFkDFzHqSP.jpg'),
(107271, 7650, 'Desgraça ao seu Dispor S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/219212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1p4EsXXLno0osPJGeXcz3keQvpz.jpg'),
(107272, 7651, 'Pelados e Solitários S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mrVLSQnSglpAiIgISzkRJWaYgu1.jpg'),
(107273, 7651, 'Pelados e Solitários S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSpnkLFAKwQLzjRayqV2CT3F5px.jpg'),
(107274, 7651, 'Pelados e Solitários S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSpnkLFAKwQLzjRayqV2CT3F5px.jpg'),
(107275, 7651, 'Pelados e Solitários S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSpnkLFAKwQLzjRayqV2CT3F5px.jpg'),
(107276, 7651, 'Pelados e Solitários S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSpnkLFAKwQLzjRayqV2CT3F5px.jpg'),
(107277, 7651, 'Pelados e Solitários S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSpnkLFAKwQLzjRayqV2CT3F5px.jpg'),
(107278, 7651, 'Pelados e Solitários S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSpnkLFAKwQLzjRayqV2CT3F5px.jpg'),
(107279, 7651, 'Pelados e Solitários S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSpnkLFAKwQLzjRayqV2CT3F5px.jpg'),
(107280, 7652, 'Onde Está Tim Lopes? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mk14xMusMf55er6nnWu5VfLdoBS.jpg'),
(107281, 7652, 'Onde Está Tim Lopes? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mk14xMusMf55er6nnWu5VfLdoBS.jpg'),
(107282, 7652, 'Onde Está Tim Lopes? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mk14xMusMf55er6nnWu5VfLdoBS.jpg'),
(107283, 7652, 'Onde Está Tim Lopes? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mk14xMusMf55er6nnWu5VfLdoBS.jpg'),
(107284, 7653, 'Petronix Defenders S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jCSnvmxwvr8UnjQb0zHvm0ibgXO.jpg'),
(107285, 7653, 'Petronix Defenders S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hZaiJGTEHe9Vgq5nhKtPvSKLfS3.jpg'),
(107286, 7653, 'Petronix Defenders S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ujmuaLra4azH4qQobJJGmTl6N6N.jpg'),
(107287, 7653, 'Petronix Defenders S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7GRIjWcOeXLe5kSpth7pGC3OTzG.jpg'),
(107288, 7653, 'Petronix Defenders S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e4DQsNEf5He3F9ZMWXuwDODUToX.jpg'),
(107289, 7653, 'Petronix Defenders S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8RYTwCc38H45SGyJDpD0awcQ6JN.jpg'),
(107290, 7653, 'Petronix Defenders S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o5Bk4wkz7OAZATzaWUATJSYtFuC.jpg'),
(107291, 7653, 'Petronix Defenders S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUswht52uKWODOT3T7kmwdD6117.jpg'),
(107292, 7653, 'Petronix Defenders S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/37ZvZLkT4FqfRP4CTPmRgPEW2Ha.jpg'),
(107293, 7653, 'Petronix Defenders S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nn1mkeURg10G1vOhJOFB50GxY5U.jpg'),
(107294, 7653, 'Petronix Defenders S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dtO1oRdgFrU9lefYyPSyT3ScwSz.jpg'),
(107295, 7653, 'Petronix Defenders S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6uPquvuS19CluSQBksxNnaroOwc.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(107296, 7653, 'Petronix Defenders S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13zlQ9xIYAwvZTNXljlucAIfgL5.jpg'),
(107297, 7653, 'Petronix Defenders S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/219157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lxd1Sus2r94e4gJshrakhVZgFbx.jpg'),
(107298, 7653, 'Petronix Defenders S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/219158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bdEFh3tpdZ9ekvDZNMTMerIs5v9.jpg'),
(107299, 7653, 'Petronix Defenders S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/219159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4JZY2m8B18Pq6z8zPBxNk9TCKXp.jpg'),
(107300, 7653, 'Petronix Defenders S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/219160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/30ZWyEwnzsTh7ykf1Tk7BC2AUfI.jpg'),
(107301, 7653, 'Petronix Defenders S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/219161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a5A0yyObYOeeuVQX97hqKypzTHK.jpg'),
(107302, 7653, 'Petronix Defenders S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/219162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s9wcI17sxA9JQHIoF1nL3tI5MJQ.jpg'),
(107303, 7653, 'Petronix Defenders S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/219163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nYTwerDB0pe81BSyFVxKNogTeuX.jpg'),
(107304, 7653, 'Petronix Defenders S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/219164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mI3Fy4yFpIPSjo3mEajCN8XHGBW.jpg'),
(107305, 7653, 'Petronix Defenders S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/219165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6NWrqnGADUGmrsms5Qej8gB290B.jpg'),
(107306, 7653, 'Petronix Defenders S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/219166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jCQkQujb6EnbWv2j7fEM2Ca1P7O.jpg'),
(107307, 7653, 'Petronix Defenders S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/219167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wLdgJmY5QCo5vO18jb2d2JO42yw.jpg'),
(107308, 7653, 'Petronix Defenders S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/219168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/buHztPCQON8rQFx34Qvc2o5ZdF1.jpg'),
(107309, 7653, 'Petronix Defenders S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/219169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6MJ8KrqBbGsE4AVxbyYI1b5jxZw.jpg'),
(107310, 7654, 'Quando os Tubarões Atacam 360° S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1kCjSiUqlJJJ0NNUVQSgvwXJJYa.jpg'),
(107311, 7654, 'Quando os Tubarões Atacam 360° S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1kCjSiUqlJJJ0NNUVQSgvwXJJYa.jpg'),
(107312, 7654, 'Quando os Tubarões Atacam 360° S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1kCjSiUqlJJJ0NNUVQSgvwXJJYa.jpg'),
(107313, 7654, 'Quando os Tubarões Atacam 360° S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1kCjSiUqlJJJ0NNUVQSgvwXJJYa.jpg'),
(107314, 7654, 'Quando os Tubarões Atacam 360° S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1kCjSiUqlJJJ0NNUVQSgvwXJJYa.jpg'),
(107315, 7654, 'Quando os Tubarões Atacam 360° S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1kCjSiUqlJJJ0NNUVQSgvwXJJYa.jpg'),
(107316, 7655, 'Garota da Lua e o Dinossauro Demônio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tRjKIJEbN6brNTJ0s2gjRgQvDcZ.jpg'),
(107317, 7655, 'Garota da Lua e o Dinossauro Demônio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aT5JDqVM5Zr0VBYUnM1Kjm4NbOy.jpg'),
(107318, 7655, 'Garota da Lua e o Dinossauro Demônio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zSFmLlFSIqMKGukXm5Hz3oSAA1j.jpg'),
(107319, 7655, 'Garota da Lua e o Dinossauro Demônio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/saE9bmEH7hVhvB8bhxJcW1xHOeX.jpg'),
(107320, 7655, 'Garota da Lua e o Dinossauro Demônio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oj8NZpU4XeEGJ0GzVLJA8KMng5B.jpg'),
(107321, 7655, 'Garota da Lua e o Dinossauro Demônio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h8ZeOOD5GrSJqhakEcng4pvLttB.jpg'),
(107322, 7655, 'Garota da Lua e o Dinossauro Demônio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gUtiIUTrh1ZRcMtu4tffnG7HlFD.jpg'),
(107323, 7655, 'Garota da Lua e o Dinossauro Demônio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kUmifZxPOaIT15Wd6n7ib1RdMBZ.jpg'),
(107324, 7655, 'Garota da Lua e o Dinossauro Demônio S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3nr68F7znxRTrZYruzVXCF0qzB3.jpg'),
(107325, 7655, 'Garota da Lua e o Dinossauro Demônio S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ka3ISdBuzfnRajoPDNn9sUZMAAr.jpg'),
(107326, 7655, 'Garota da Lua e o Dinossauro Demônio S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/219127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l8YuMqV9z0C5xCChQ84S3WmlR6G.jpg'),
(107327, 7655, 'Garota da Lua e o Dinossauro Demônio S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/219128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wPSkFpsQemyiNO9RkaWoDf5YKS6.jpg'),
(107328, 7655, 'Garota da Lua e o Dinossauro Demônio S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/219129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wPSkFpsQemyiNO9RkaWoDf5YKS6.jpg'),
(107329, 7655, 'Garota da Lua e o Dinossauro Demônio S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/219130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wPSkFpsQemyiNO9RkaWoDf5YKS6.jpg'),
(107330, 7655, 'Garota da Lua e o Dinossauro Demônio S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/219131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wPSkFpsQemyiNO9RkaWoDf5YKS6.jpg'),
(107331, 7655, 'Garota da Lua e o Dinossauro Demônio S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/219132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wPSkFpsQemyiNO9RkaWoDf5YKS6.jpg'),
(107332, 7656, 'Garota da Lua e o Dinossauro Demônio S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/509420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wPSkFpsQemyiNO9RkaWoDf5YKS6.jpg'),
(107333, 7656, 'Garota da Lua e o Dinossauro Demônio S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/509421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wPSkFpsQemyiNO9RkaWoDf5YKS6.jpg'),
(107334, 7656, 'Garota da Lua e o Dinossauro Demônio S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/509422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wPSkFpsQemyiNO9RkaWoDf5YKS6.jpg'),
(107335, 7656, 'Garota da Lua e o Dinossauro Demônio S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/509423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wPSkFpsQemyiNO9RkaWoDf5YKS6.jpg'),
(107336, 7656, 'Garota da Lua e o Dinossauro Demônio S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/509424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wPSkFpsQemyiNO9RkaWoDf5YKS6.jpg'),
(107337, 7656, 'Garota da Lua e o Dinossauro Demônio S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/509425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wPSkFpsQemyiNO9RkaWoDf5YKS6.jpg'),
(107338, 7656, 'Garota da Lua e o Dinossauro Demônio S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/509426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wPSkFpsQemyiNO9RkaWoDf5YKS6.jpg'),
(107339, 7656, 'Garota da Lua e o Dinossauro Demônio S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/509427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wPSkFpsQemyiNO9RkaWoDf5YKS6.jpg'),
(107340, 7656, 'Garota da Lua e o Dinossauro Demônio S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/509428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wPSkFpsQemyiNO9RkaWoDf5YKS6.jpg'),
(107341, 7656, 'Garota da Lua e o Dinossauro Demônio S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/509429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wPSkFpsQemyiNO9RkaWoDf5YKS6.jpg'),
(107342, 7656, 'Garota da Lua e o Dinossauro Demônio S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/509430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wPSkFpsQemyiNO9RkaWoDf5YKS6.jpg'),
(107343, 7656, 'Garota da Lua e o Dinossauro Demônio S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/509431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wPSkFpsQemyiNO9RkaWoDf5YKS6.jpg'),
(107344, 7656, 'Garota da Lua e o Dinossauro Demônio S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/509432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wPSkFpsQemyiNO9RkaWoDf5YKS6.jpg'),
(107345, 7656, 'Garota da Lua e o Dinossauro Demônio S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/509433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wPSkFpsQemyiNO9RkaWoDf5YKS6.jpg'),
(107346, 7657, 'Predadores Africanos S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oQJMSbglIDY3shesLDZl0HXRSyu.jpg'),
(107347, 7657, 'Predadores Africanos S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oQJMSbglIDY3shesLDZl0HXRSyu.jpg'),
(107348, 7657, 'Predadores Africanos S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oQJMSbglIDY3shesLDZl0HXRSyu.jpg'),
(107349, 7658, 'Day of the Dead S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/slHGgtFgOxxQO91TJotRNlV03g0.jpg'),
(107350, 7658, 'Day of the Dead S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2T5L7hyS1Tft5V8m4Qvvl0FX6Ie.jpg'),
(107351, 7658, 'Day of the Dead S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yJeyT68BXOe0pNAkekvQ25aEBI7.jpg'),
(107352, 7658, 'Day of the Dead S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/219087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AogBHeZClJ4SAXi74vu5QUtAlxR.jpg'),
(107353, 7658, 'Day of the Dead S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/219088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tK4iOPdSi5p9ZOWQbPwcN0APIRd.jpg'),
(107354, 7658, 'Day of the Dead S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/219089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTnWd81x9Bb8BDVjHLovCLiB1D8.jpg'),
(107355, 7658, 'Day of the Dead S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/219090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g98C5LDX3ractqd2t1y3nURg0uo.jpg'),
(107356, 7658, 'Day of the Dead S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/219091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hYoY2Tt4EeGP5DHryC83PQDhx2B.jpg'),
(107357, 7658, 'Day of the Dead S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/219092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3uWVB3XkxpaIeA8s6idzibOUUT5.jpg'),
(107358, 7658, 'Day of the Dead S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/219093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gkfmyuJ7lECKbVGBenALMkxSvfa.jpg'),
(107359, 7659, 'Do Que Riem? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b2tKBfphrDFeZ7sCcbPUjOa2Pls.jpg'),
(107360, 7659, 'Do Que Riem? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b2tKBfphrDFeZ7sCcbPUjOa2Pls.jpg'),
(107361, 7659, 'Do Que Riem? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b2tKBfphrDFeZ7sCcbPUjOa2Pls.jpg'),
(107362, 7659, 'Do Que Riem? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b2tKBfphrDFeZ7sCcbPUjOa2Pls.jpg'),
(107363, 7659, 'Do Que Riem? S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b2tKBfphrDFeZ7sCcbPUjOa2Pls.jpg'),
(107364, 7659, 'Do Que Riem? S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b2tKBfphrDFeZ7sCcbPUjOa2Pls.jpg'),
(107365, 7659, 'Do Que Riem? S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b2tKBfphrDFeZ7sCcbPUjOa2Pls.jpg'),
(107366, 7660, 'Filhos da Liberdade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/219081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nUmjoJfNLeR3TLxP3sZz5wP4nWg.jpg'),
(107367, 7660, 'Filhos da Liberdade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/219082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqZpt77IiFDnQmxunE41qaXYIQ1.jpg'),
(107368, 7660, 'Filhos da Liberdade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/219083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgbR5m9kb4iAtDMVdTZaRakRAx8.jpg'),
(107369, 7661, 'A Thin Line S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8aWRzJClwsPieNrKMB11B8mmqHg.jpg'),
(107370, 7661, 'A Thin Line S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8aWRzJClwsPieNrKMB11B8mmqHg.jpg'),
(107371, 7661, 'A Thin Line S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8aWRzJClwsPieNrKMB11B8mmqHg.jpg'),
(107372, 7661, 'A Thin Line S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8aWRzJClwsPieNrKMB11B8mmqHg.jpg'),
(107373, 7661, 'A Thin Line S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8aWRzJClwsPieNrKMB11B8mmqHg.jpg'),
(107374, 7661, 'A Thin Line S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8aWRzJClwsPieNrKMB11B8mmqHg.jpg'),
(107375, 7662, 'A Vida Pela Frente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVT9nnwKoLw2rIgva5uMqmX8SMD.jpg'),
(107376, 7662, 'A Vida Pela Frente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVT9nnwKoLw2rIgva5uMqmX8SMD.jpg'),
(107377, 7662, 'A Vida Pela Frente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVT9nnwKoLw2rIgva5uMqmX8SMD.jpg'),
(107378, 7662, 'A Vida Pela Frente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVT9nnwKoLw2rIgva5uMqmX8SMD.jpg'),
(107379, 7662, 'A Vida Pela Frente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVT9nnwKoLw2rIgva5uMqmX8SMD.jpg'),
(107380, 7662, 'A Vida Pela Frente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVT9nnwKoLw2rIgva5uMqmX8SMD.jpg'),
(107381, 7662, 'A Vida Pela Frente S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVT9nnwKoLw2rIgva5uMqmX8SMD.jpg'),
(107382, 7662, 'A Vida Pela Frente S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVT9nnwKoLw2rIgva5uMqmX8SMD.jpg'),
(107383, 7662, 'A Vida Pela Frente S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVT9nnwKoLw2rIgva5uMqmX8SMD.jpg'),
(107384, 7662, 'A Vida Pela Frente S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVT9nnwKoLw2rIgva5uMqmX8SMD.jpg'),
(107385, 7663, 'Carlo! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kNfgnkczmgrp6Bj9D8hoeCh2lJK.jpg'),
(107386, 7663, 'Carlo! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kNfgnkczmgrp6Bj9D8hoeCh2lJK.jpg'),
(107387, 7663, 'Carlo! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kNfgnkczmgrp6Bj9D8hoeCh2lJK.jpg'),
(107388, 7663, 'Carlo! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kNfgnkczmgrp6Bj9D8hoeCh2lJK.jpg'),
(107389, 7663, 'Carlo! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kNfgnkczmgrp6Bj9D8hoeCh2lJK.jpg'),
(107390, 7663, 'Carlo! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kNfgnkczmgrp6Bj9D8hoeCh2lJK.jpg'),
(107391, 7663, 'Carlo! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kNfgnkczmgrp6Bj9D8hoeCh2lJK.jpg'),
(107392, 7663, 'Carlo! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kNfgnkczmgrp6Bj9D8hoeCh2lJK.jpg'),
(107393, 7663, 'Carlo! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kNfgnkczmgrp6Bj9D8hoeCh2lJK.jpg'),
(107394, 7663, 'Carlo! S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kNfgnkczmgrp6Bj9D8hoeCh2lJK.jpg'),
(107395, 7663, 'Carlo! S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kNfgnkczmgrp6Bj9D8hoeCh2lJK.jpg'),
(107396, 7663, 'Carlo! S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kNfgnkczmgrp6Bj9D8hoeCh2lJK.jpg'),
(107397, 7663, 'Carlo! S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kNfgnkczmgrp6Bj9D8hoeCh2lJK.jpg'),
(107398, 7664, 'Aeroporto: Estados Unidos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107399, 7664, 'Aeroporto: Estados Unidos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107400, 7664, 'Aeroporto: Estados Unidos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107401, 7664, 'Aeroporto: Estados Unidos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107402, 7664, 'Aeroporto: Estados Unidos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107403, 7664, 'Aeroporto: Estados Unidos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107404, 7664, 'Aeroporto: Estados Unidos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107405, 7665, 'Aeroporto: Estados Unidos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107406, 7665, 'Aeroporto: Estados Unidos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107407, 7665, 'Aeroporto: Estados Unidos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107408, 7665, 'Aeroporto: Estados Unidos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107409, 7665, 'Aeroporto: Estados Unidos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107410, 7665, 'Aeroporto: Estados Unidos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107411, 7665, 'Aeroporto: Estados Unidos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107412, 7665, 'Aeroporto: Estados Unidos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107413, 7665, 'Aeroporto: Estados Unidos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107414, 7665, 'Aeroporto: Estados Unidos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107415, 7665, 'Aeroporto: Estados Unidos S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107416, 7665, 'Aeroporto: Estados Unidos S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107417, 7665, 'Aeroporto: Estados Unidos S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/246084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107418, 7665, 'Aeroporto: Estados Unidos S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/590272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107419, 7666, 'Aeroporto: Estados Unidos S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9wGZs6KQPzfW4l7wiArE8flfBHc.jpg'),
(107420, 7666, 'Aeroporto: Estados Unidos S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/XFC8Ntz371vMH048lVd4ve8bRf.jpg'),
(107421, 7666, 'Aeroporto: Estados Unidos S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ipZBQ3cJLb4Nn0tQaataRYfDBQ0.jpg'),
(107422, 7666, 'Aeroporto: Estados Unidos S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nmWkJ8uYm9wIl86KhQMxDm4Psgi.jpg'),
(107423, 7666, 'Aeroporto: Estados Unidos S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iiExPVhyX41ZacT38VJw37V1y6z.jpg'),
(107424, 7666, 'Aeroporto: Estados Unidos S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gOLV1DwdZUDY5z4yQGAKHPiZ93Q.jpg'),
(107425, 7666, 'Aeroporto: Estados Unidos S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vuOWvkiKgTcLzquv0XKzy3dBMYO.jpg'),
(107426, 7666, 'Aeroporto: Estados Unidos S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aVLCRaZRzMovsojbWXrAr8V0LA7.jpg'),
(107427, 7666, 'Aeroporto: Estados Unidos S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1AgsAxVKXjOEhSsj7sSCmyk3rfL.jpg'),
(107428, 7666, 'Aeroporto: Estados Unidos S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7NV5ttXqCyO39HNVVnu7DFZLhvi.jpg'),
(107429, 7666, 'Aeroporto: Estados Unidos S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bIb5idFHInYfvEBg19H93CB6ZYX.jpg'),
(107430, 7666, 'Aeroporto: Estados Unidos S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4X1xkTUiXQuk8bRIWbAVfKfbSUV.jpg'),
(107431, 7667, 'Aeroporto: Estados Unidos S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3xzAaBcuKkw1QGM7UrtpcnCyeaH.jpg'),
(107432, 7667, 'Aeroporto: Estados Unidos S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lsI1fj96c3VoJwKRRcBS2vKNZ2g.jpg'),
(107433, 7667, 'Aeroporto: Estados Unidos S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107434, 7667, 'Aeroporto: Estados Unidos S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107435, 7667, 'Aeroporto: Estados Unidos S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107436, 7667, 'Aeroporto: Estados Unidos S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107437, 7667, 'Aeroporto: Estados Unidos S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107438, 7667, 'Aeroporto: Estados Unidos S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107439, 7667, 'Aeroporto: Estados Unidos S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107440, 7667, 'Aeroporto: Estados Unidos S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107441, 7668, 'Aeroporto: Estados Unidos S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107442, 7668, 'Aeroporto: Estados Unidos S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107443, 7668, 'Aeroporto: Estados Unidos S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107444, 7668, 'Aeroporto: Estados Unidos S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107445, 7668, 'Aeroporto: Estados Unidos S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107446, 7668, 'Aeroporto: Estados Unidos S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107447, 7668, 'Aeroporto: Estados Unidos S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107448, 7668, 'Aeroporto: Estados Unidos S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107449, 7669, 'Aeroporto: Estados Unidos S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107450, 7669, 'Aeroporto: Estados Unidos S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107451, 7669, 'Aeroporto: Estados Unidos S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107452, 7669, 'Aeroporto: Estados Unidos S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107453, 7669, 'Aeroporto: Estados Unidos S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107454, 7669, 'Aeroporto: Estados Unidos S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107455, 7669, 'Aeroporto: Estados Unidos S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107456, 7669, 'Aeroporto: Estados Unidos S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107457, 7670, 'Aeroporto: Estados Unidos S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/271770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107458, 7670, 'Aeroporto: Estados Unidos S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/271771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107459, 7670, 'Aeroporto: Estados Unidos S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/271772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107460, 7670, 'Aeroporto: Estados Unidos S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/271773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107461, 7670, 'Aeroporto: Estados Unidos S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/271774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107462, 7670, 'Aeroporto: Estados Unidos S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/271775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107463, 7670, 'Aeroporto: Estados Unidos S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/271776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srltefAUWZsKtEF9dgkg4Ssgjsw.jpg'),
(107464, 7671, 'Urgente! S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107465, 7671, 'Urgente! S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107466, 7671, 'Urgente! S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107467, 7671, 'Urgente! S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107468, 7671, 'Urgente! S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107469, 7671, 'Urgente! S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107470, 7671, 'Urgente! S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107471, 7671, 'Urgente! S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107472, 7671, 'Urgente! S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107473, 7672, 'Urgente! S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107474, 7672, 'Urgente! S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107475, 7672, 'Urgente! S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107476, 7672, 'Urgente! S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107477, 7672, 'Urgente! S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107478, 7672, 'Urgente! S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107479, 7672, 'Urgente! S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107480, 7672, 'Urgente! S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107481, 7672, 'Urgente! S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107482, 7672, 'Urgente! S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107483, 7673, 'Urgente! S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107484, 7673, 'Urgente! S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107485, 7673, 'Urgente! S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107486, 7673, 'Urgente! S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107487, 7673, 'Urgente! S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107488, 7673, 'Urgente! S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107489, 7673, 'Urgente! S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107490, 7673, 'Urgente! S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107491, 7673, 'Urgente! S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107492, 7673, 'Urgente! S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107493, 7673, 'Urgente! S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107494, 7673, 'Urgente! S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107495, 7674, 'Urgente! S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107496, 7674, 'Urgente! S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107497, 7674, 'Urgente! S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107498, 7674, 'Urgente! S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107499, 7674, 'Urgente! S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107500, 7674, 'Urgente! S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107501, 7674, 'Urgente! S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107502, 7674, 'Urgente! S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107503, 7674, 'Urgente! S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107504, 7675, 'Urgente! S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107505, 7675, 'Urgente! S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107506, 7675, 'Urgente! S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107507, 7675, 'Urgente! S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107508, 7675, 'Urgente! S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107509, 7675, 'Urgente! S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107510, 7675, 'Urgente! S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107511, 7675, 'Urgente! S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107512, 7675, 'Urgente! S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AgiEHkS9rJHiQmkfpdLpfEmW9b2.jpg'),
(107513, 7676, 'Cleo & Cuquin S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7XnSw6OtRUvYCb9Niqi51NiKnTG.jpg'),
(107514, 7676, 'Cleo & Cuquin S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107515, 7676, 'Cleo & Cuquin S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107516, 7676, 'Cleo & Cuquin S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nkczMrOs13O9BOLHzfEgBLRdtkF.jpg'),
(107517, 7676, 'Cleo & Cuquin S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107518, 7676, 'Cleo & Cuquin S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107519, 7676, 'Cleo & Cuquin S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107520, 7676, 'Cleo & Cuquin S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107521, 7676, 'Cleo & Cuquin S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107522, 7676, 'Cleo & Cuquin S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107523, 7676, 'Cleo & Cuquin S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107524, 7676, 'Cleo & Cuquin S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107525, 7676, 'Cleo & Cuquin S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107526, 7676, 'Cleo & Cuquin S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107527, 7676, 'Cleo & Cuquin S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107528, 7676, 'Cleo & Cuquin S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107529, 7676, 'Cleo & Cuquin S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107530, 7676, 'Cleo & Cuquin S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107531, 7676, 'Cleo & Cuquin S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107532, 7676, 'Cleo & Cuquin S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107533, 7676, 'Cleo & Cuquin S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107534, 7676, 'Cleo & Cuquin S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/218172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107535, 7676, 'Cleo & Cuquin S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/218173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107536, 7676, 'Cleo & Cuquin S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/218174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107537, 7676, 'Cleo & Cuquin S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/218175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107538, 7676, 'Cleo & Cuquin S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/218176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107539, 7676, 'Cleo & Cuquin S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/218177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107540, 7676, 'Cleo & Cuquin S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/218178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107541, 7676, 'Cleo & Cuquin S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/218179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107542, 7676, 'Cleo & Cuquin S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/218180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107543, 7676, 'Cleo & Cuquin S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/218181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107544, 7676, 'Cleo & Cuquin S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/218182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107545, 7676, 'Cleo & Cuquin S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/218183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107546, 7676, 'Cleo & Cuquin S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/218184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107547, 7676, 'Cleo & Cuquin S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/218185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107548, 7676, 'Cleo & Cuquin S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/218186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107549, 7676, 'Cleo & Cuquin S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/218187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107550, 7676, 'Cleo & Cuquin S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/218188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107551, 7676, 'Cleo & Cuquin S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/218189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107552, 7676, 'Cleo & Cuquin S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/218190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107553, 7676, 'Cleo & Cuquin S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/218191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(107554, 7676, 'Cleo & Cuquin S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/218192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107555, 7676, 'Cleo & Cuquin S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/218193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107556, 7676, 'Cleo & Cuquin S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/218194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107557, 7676, 'Cleo & Cuquin S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/218195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107558, 7676, 'Cleo & Cuquin S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/218196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107559, 7676, 'Cleo & Cuquin S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/218197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107560, 7676, 'Cleo & Cuquin S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/218198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107561, 7676, 'Cleo & Cuquin S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/218199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107562, 7676, 'Cleo & Cuquin S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/218200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107563, 7676, 'Cleo & Cuquin S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/218201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107564, 7676, 'Cleo & Cuquin S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/218202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107565, 7677, 'Cleo & Cuquin S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107566, 7677, 'Cleo & Cuquin S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107567, 7677, 'Cleo & Cuquin S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107568, 7677, 'Cleo & Cuquin S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107569, 7677, 'Cleo & Cuquin S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107570, 7677, 'Cleo & Cuquin S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107571, 7677, 'Cleo & Cuquin S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107572, 7677, 'Cleo & Cuquin S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107573, 7677, 'Cleo & Cuquin S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107574, 7677, 'Cleo & Cuquin S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107575, 7677, 'Cleo & Cuquin S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107576, 7677, 'Cleo & Cuquin S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107577, 7677, 'Cleo & Cuquin S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107578, 7677, 'Cleo & Cuquin S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107579, 7677, 'Cleo & Cuquin S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107580, 7677, 'Cleo & Cuquin S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107581, 7677, 'Cleo & Cuquin S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107582, 7677, 'Cleo & Cuquin S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107583, 7677, 'Cleo & Cuquin S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107584, 7677, 'Cleo & Cuquin S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107585, 7677, 'Cleo & Cuquin S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107586, 7677, 'Cleo & Cuquin S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/218224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107587, 7677, 'Cleo & Cuquin S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/218225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107588, 7677, 'Cleo & Cuquin S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/218226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107589, 7677, 'Cleo & Cuquin S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/218227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107590, 7677, 'Cleo & Cuquin S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/218228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3C1rt8mSL1jvafiSOIXx9MDmV0O.jpg'),
(107591, 7678, 'Coroas em Crise S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rRgM7A3sr6zltpwKejxzSbMLTni.jpg'),
(107592, 7678, 'Coroas em Crise S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rRgM7A3sr6zltpwKejxzSbMLTni.jpg'),
(107593, 7678, 'Coroas em Crise S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rRgM7A3sr6zltpwKejxzSbMLTni.jpg'),
(107594, 7678, 'Coroas em Crise S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rRgM7A3sr6zltpwKejxzSbMLTni.jpg'),
(107595, 7678, 'Coroas em Crise S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rRgM7A3sr6zltpwKejxzSbMLTni.jpg'),
(107596, 7678, 'Coroas em Crise S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rRgM7A3sr6zltpwKejxzSbMLTni.jpg'),
(107597, 7678, 'Coroas em Crise S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rRgM7A3sr6zltpwKejxzSbMLTni.jpg'),
(107598, 7678, 'Coroas em Crise S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rRgM7A3sr6zltpwKejxzSbMLTni.jpg'),
(107599, 7679, 'Desejo Fatal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gPIBBjBdQuZWaEHXY62gBEls0Pu.jpg'),
(107600, 7679, 'Desejo Fatal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9GKbJZlrNTVS7PS2kvBczFCnMRY.jpg'),
(107601, 7679, 'Desejo Fatal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AvvSEjt1SPlOK1VtKi07urvvjw9.jpg'),
(107602, 7679, 'Desejo Fatal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A4l7T08QKlAIC6ypX2VVQHlXAkR.jpg'),
(107603, 7679, 'Desejo Fatal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h471l0rN3yPWULpc4Y7OLqGKKrM.jpg'),
(107604, 7679, 'Desejo Fatal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mHoFBoac56T2nwBqNXDe9FpY9jh.jpg'),
(107605, 7679, 'Desejo Fatal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gbU2XOo4JTNRCKSEkQyeBpJhlId.jpg'),
(107606, 7679, 'Desejo Fatal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sbiSNhyuLWHeOtzDb4Zo8Ji3Kv6.jpg'),
(107607, 7679, 'Desejo Fatal S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8qKhXqoJF1Ah7ull6x0QWteAFoR.jpg'),
(107608, 7679, 'Desejo Fatal S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yjUUlIg8D3yccuFL0xJfiHPcWio.jpg'),
(107609, 7679, 'Desejo Fatal S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jPVclLZaBZMcK8un3VcDSPjgtjm.jpg'),
(107610, 7679, 'Desejo Fatal S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3cK10RPnvaIPCh9LQHpV3Sj8B2R.jpg'),
(107611, 7679, 'Desejo Fatal S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wgvvbGbwql4MoU9QG5GBcPLaTfh.jpg'),
(107612, 7679, 'Desejo Fatal S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1PBkESN82sNZHP9dncZ9N52pa0I.jpg'),
(107613, 7680, 'Dra. Sandra Lee: A Rainha dos Cravos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hbYfeTpO9ljrXopJRz0aDM3YfNS.jpg'),
(107614, 7680, 'Dra. Sandra Lee: A Rainha dos Cravos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJ597IhsUBORzXNOhXZ55zHPjVb.jpg'),
(107615, 7680, 'Dra. Sandra Lee: A Rainha dos Cravos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bWXLIcaSJ2gHcI7DpQyBduoZh2U.jpg'),
(107616, 7680, 'Dra. Sandra Lee: A Rainha dos Cravos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Atyyv1AhU5Qvl6Dyq8nbzORk2w.jpg'),
(107617, 7680, 'Dra. Sandra Lee: A Rainha dos Cravos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rkD1fI5m71prRUNtP4vtyuholol.jpg'),
(107618, 7680, 'Dra. Sandra Lee: A Rainha dos Cravos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzC55upcN0U7q72yF65kWn9W3FT.jpg'),
(107619, 7680, 'Dra. Sandra Lee: A Rainha dos Cravos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xdJV80stAo6LuJuRY0Yz0tXh2ql.jpg'),
(107620, 7681, 'Dra. Sandra Lee: A Rainha dos Cravos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8DiYyxWDaNd1pstWTSTqhZi2o1j.jpg'),
(107621, 7681, 'Dra. Sandra Lee: A Rainha dos Cravos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/95CfG0ca4KhVK4Wa2nfY1YPkjca.jpg'),
(107622, 7681, 'Dra. Sandra Lee: A Rainha dos Cravos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bDgrVtaxLq5npL5N7oWoyeONtvE.jpg'),
(107623, 7681, 'Dra. Sandra Lee: A Rainha dos Cravos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eZuzdcNBfYY4umBPBK3fF7qZWdY.jpg'),
(107624, 7681, 'Dra. Sandra Lee: A Rainha dos Cravos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bKhfYa8B5wkHFDqszHx0pv0YTUI.jpg'),
(107625, 7681, 'Dra. Sandra Lee: A Rainha dos Cravos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/omysVGxdr3PutmFOP9OkIo5KfyD.jpg'),
(107626, 7681, 'Dra. Sandra Lee: A Rainha dos Cravos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hb08sBvo4M6qkfIw5RfRjgzM3B0.jpg'),
(107627, 7681, 'Dra. Sandra Lee: A Rainha dos Cravos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x68HqI8uoiVfp8qFdw5LPfUQSSs.jpg'),
(107628, 7681, 'Dra. Sandra Lee: A Rainha dos Cravos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uaSpvTzzeoZAkKjmBuVAp8GMYXS.jpg'),
(107629, 7681, 'Dra. Sandra Lee: A Rainha dos Cravos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AnY9ebaIJwACzzXVaFFe671d34F.jpg'),
(107630, 7682, 'Dra. Sandra Lee: A Rainha dos Cravos S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/txgXCrXAwrtmLJ4GHOHn9V2KVSG.jpg'),
(107631, 7682, 'Dra. Sandra Lee: A Rainha dos Cravos S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gvkxQJhSCNwPOUFDOZhYOEOobHb.jpg'),
(107632, 7682, 'Dra. Sandra Lee: A Rainha dos Cravos S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ly91LibbDDHQMah8azRnU9M9AAS.jpg'),
(107633, 7682, 'Dra. Sandra Lee: A Rainha dos Cravos S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mj4uExO0DBVgC81K9hNwqGIz2QT.jpg'),
(107634, 7683, 'Dra. Sandra Lee: A Rainha dos Cravos S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uTZj8V88BL0VPT7CbALASN9dKtW.jpg'),
(107635, 7683, 'Dra. Sandra Lee: A Rainha dos Cravos S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dM9O1WH5DxjmOEsaba2HpPoqraw.jpg'),
(107636, 7683, 'Dra. Sandra Lee: A Rainha dos Cravos S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7FYCeieR39XF4GKzcut8pt7s0en.jpg'),
(107637, 7683, 'Dra. Sandra Lee: A Rainha dos Cravos S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/86S0URjCD3CE5XngqroJ3xXKYgT.jpg'),
(107638, 7683, 'Dra. Sandra Lee: A Rainha dos Cravos S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vB2m2Wkmc2IX6zA9mQNUAWvNmyQ.jpg'),
(107639, 7683, 'Dra. Sandra Lee: A Rainha dos Cravos S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/juiC2jlfiKCkklfwv4zBb0QzID5.jpg'),
(107640, 7684, 'Dra. Sandra Lee: A Rainha dos Cravos S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4h3KQSShjRUyXC7lIWUyl7OpRV1.jpg'),
(107641, 7684, 'Dra. Sandra Lee: A Rainha dos Cravos S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/agYpmr0s9nWUUEBupnMZDSaiaE2.jpg'),
(107642, 7684, 'Dra. Sandra Lee: A Rainha dos Cravos S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ebDm5IVFg7PijedPBmEDUydZMNL.jpg'),
(107643, 7684, 'Dra. Sandra Lee: A Rainha dos Cravos S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5DCccXu1KfJT5wqQJgYVME1sywk.jpg'),
(107644, 7684, 'Dra. Sandra Lee: A Rainha dos Cravos S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Z4fgYIKpJ7ntj68bv3KTOLe8SF.jpg'),
(107645, 7684, 'Dra. Sandra Lee: A Rainha dos Cravos S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mB1jIjsyTJViHso2ID78OSSKZX4.jpg'),
(107646, 7684, 'Dra. Sandra Lee: A Rainha dos Cravos S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bia2NEFzyE09CCR0ZnzuM0nbIhA.jpg'),
(107647, 7684, 'Dra. Sandra Lee: A Rainha dos Cravos S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUTafmDgjoS3VQbRGaT7RuOt7Pr.jpg'),
(107648, 7684, 'Dra. Sandra Lee: A Rainha dos Cravos S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEOb1es6Tmi1KP7p5etmFQHHYUc.jpg'),
(107649, 7684, 'Dra. Sandra Lee: A Rainha dos Cravos S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tCbfScyLSq21H3jYtXiC3EEJtic.jpg'),
(107650, 7685, 'Dra. Sandra Lee: A Rainha dos Cravos S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hbYfeTpO9ljrXopJRz0aDM3YfNS.jpg'),
(107651, 7685, 'Dra. Sandra Lee: A Rainha dos Cravos S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dEzUCC7RObfjIBTOxrCLvLmY14f.jpg'),
(107652, 7685, 'Dra. Sandra Lee: A Rainha dos Cravos S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rQxKXHrMflm6BCqZoqNNHXbvWwO.jpg'),
(107653, 7685, 'Dra. Sandra Lee: A Rainha dos Cravos S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zAJAEpE5zF4nBimSIRhC1OdsRT8.jpg'),
(107654, 7685, 'Dra. Sandra Lee: A Rainha dos Cravos S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybDx80JsGNQNiRblESyEy8Qb2IB.jpg'),
(107655, 7685, 'Dra. Sandra Lee: A Rainha dos Cravos S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vdisJ3Nbt4Ma0uxbWOxTYBUwM0I.jpg'),
(107656, 7685, 'Dra. Sandra Lee: A Rainha dos Cravos S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vDgmnkOluXZ00QCoLMgemCuZC0j.jpg'),
(107657, 7685, 'Dra. Sandra Lee: A Rainha dos Cravos S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ViYtdvbnBrwMCJICs70JE64jHx.jpg'),
(107658, 7685, 'Dra. Sandra Lee: A Rainha dos Cravos S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j4SR6P8MPcYCZ39WHezgCIUvdOl.jpg'),
(107659, 7685, 'Dra. Sandra Lee: A Rainha dos Cravos S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6iCawvL83n3a25kfQ1622f6kF0d.jpg'),
(107660, 7685, 'Dra. Sandra Lee: A Rainha dos Cravos S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkwiYMDpXHnNu2PdtWRON8hG8UX.jpg'),
(107661, 7686, 'Dra. Sandra Lee: A Rainha dos Cravos S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4N7kI0dtVCQKKjC4tcU6JUXZXsO.jpg'),
(107662, 7686, 'Dra. Sandra Lee: A Rainha dos Cravos S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/njqGXI3oJ7cT0XOgFgGagvwDEpD.jpg'),
(107663, 7686, 'Dra. Sandra Lee: A Rainha dos Cravos S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9IMNAqQo5lx2dADzpRNFRP2SNfX.jpg'),
(107664, 7686, 'Dra. Sandra Lee: A Rainha dos Cravos S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t51iGo9sPeVEAmia4PcA85QaMut.jpg'),
(107665, 7686, 'Dra. Sandra Lee: A Rainha dos Cravos S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sIx7aiVwCJbWxBJLMfWJvB7vfUf.jpg'),
(107666, 7686, 'Dra. Sandra Lee: A Rainha dos Cravos S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bNb8A9XgKCU3N7NxyfgjRbIgJFv.jpg'),
(107667, 7686, 'Dra. Sandra Lee: A Rainha dos Cravos S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xrN1Xymd48pAGGV4OXZaqP7HJqj.jpg'),
(107668, 7686, 'Dra. Sandra Lee: A Rainha dos Cravos S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aiI5BpB3ZmblOCUfTvhDaO9ee3m.jpg'),
(107669, 7686, 'Dra. Sandra Lee: A Rainha dos Cravos S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pSYGS2iY24n6PKRg7Nj38i094rs.jpg'),
(107670, 7686, 'Dra. Sandra Lee: A Rainha dos Cravos S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpZRFGsx964lOJUqEDAC1QKbrLi.jpg'),
(107671, 7687, 'Dra. Sandra Lee: A Rainha dos Cravos S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ptLV5p7ZXTQ0nFwNUUZmG0HkCEy.jpg'),
(107672, 7687, 'Dra. Sandra Lee: A Rainha dos Cravos S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1iWtFoWkEfsFpVkNp1CkfXlTjs6.jpg'),
(107673, 7687, 'Dra. Sandra Lee: A Rainha dos Cravos S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fJPacb9MLa0ihkxvMYss1A8AXMk.jpg'),
(107674, 7687, 'Dra. Sandra Lee: A Rainha dos Cravos S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yBZuRGSQ6HoxABul5t4KNxbISgP.jpg'),
(107675, 7687, 'Dra. Sandra Lee: A Rainha dos Cravos S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hIbXaXNTqEGmhhrXqUmuJETWnj1.jpg'),
(107676, 7687, 'Dra. Sandra Lee: A Rainha dos Cravos S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kJvkchs9zi3yHddwUruR4nPzerK.jpg'),
(107677, 7687, 'Dra. Sandra Lee: A Rainha dos Cravos S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qm8gdMhQDPyFqjSpdq7n6OfVIIw.jpg'),
(107678, 7687, 'Dra. Sandra Lee: A Rainha dos Cravos S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9adxe1x3pjyKd3I0UNO3L2Yf8pc.jpg'),
(107679, 7687, 'Dra. Sandra Lee: A Rainha dos Cravos S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hbYfeTpO9ljrXopJRz0aDM3YfNS.jpg'),
(107680, 7687, 'Dra. Sandra Lee: A Rainha dos Cravos S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hbYfeTpO9ljrXopJRz0aDM3YfNS.jpg'),
(107681, 7688, 'Dra. Sandra Lee: A Rainha dos Cravos S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1PXlX6BiJ2ka0ShXQ1c4dsghjC5.jpg'),
(107682, 7688, 'Dra. Sandra Lee: A Rainha dos Cravos S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/erE5dYt0eaQpz7lT9ukr7cr7P1a.jpg'),
(107683, 7688, 'Dra. Sandra Lee: A Rainha dos Cravos S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nb0ExiqxjyyEZgs0xT7n96A38pr.jpg'),
(107684, 7688, 'Dra. Sandra Lee: A Rainha dos Cravos S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l8tcMJ4PF5iW4FoWuDnjPYjuIqT.jpg'),
(107685, 7688, 'Dra. Sandra Lee: A Rainha dos Cravos S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Lk3isYR5oDMk9Wo0Y04Bc9iDDH.jpg'),
(107686, 7688, 'Dra. Sandra Lee: A Rainha dos Cravos S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230726.mp4', 'http://image.tmdb.org/t/p/w1280/2dWrC9PJm9Bh3qthvkDq1ptk1dy.jpg'),
(107687, 7688, 'Dra. Sandra Lee: A Rainha dos Cravos S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230727.mp4', 'http://image.tmdb.org/t/p/w1280/wCUktyPXfctMSgS25cAVB9Omgje.jpg'),
(107688, 7688, 'Dra. Sandra Lee: A Rainha dos Cravos S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230728.mp4', 'http://image.tmdb.org/t/p/w1280/hXwGXVbLUQFO85tyyyssyl1BdQQ.jpg'),
(107689, 7688, 'Dra. Sandra Lee: A Rainha dos Cravos S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230729.mp4', 'http://image.tmdb.org/t/p/w1280/yQML1Sxhd3hEkBZhcKqJaLDKQpC.jpg'),
(107690, 7688, 'Dra. Sandra Lee: A Rainha dos Cravos S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230730.mp4', 'http://image.tmdb.org/t/p/w1280/aU5SpRzbSeblHjAY5a2AzJbhiJF.jpg'),
(107691, 7689, 'É Amor ou Falsidade? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nGZiB1vJmLOipAcZpfsoRab5K8t.jpg'),
(107692, 7689, 'É Amor ou Falsidade? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6vPIdTsnbOIdgk6cm7QSeDV6RW7.jpg'),
(107693, 7689, 'É Amor ou Falsidade? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zrqvTGnyi40j5HDbaxW7ZinAoQt.jpg'),
(107694, 7689, 'É Amor ou Falsidade? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8oCzVHl3zwiwM66bzcDfeADevhB.jpg'),
(107695, 7689, 'É Amor ou Falsidade? S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vGbB4pvwJxNOxEiiwVxgf53bl4f.jpg'),
(107696, 7689, 'É Amor ou Falsidade? S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jbl3dbvdipCD6pUnEO2zZT8uesZ.jpg'),
(107697, 7689, 'É Amor ou Falsidade? S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rxx93VssszTvC3tt1yRKRSqQ9cI.jpg'),
(107698, 7689, 'É Amor ou Falsidade? S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223380.mp4', 'http://image.tmdb.org/t/p/w1280/8Z8oJNzh6kdzhZppHkOlNhzEUFe.jpg'),
(107699, 7690, 'East New York: Uma Nova Lei S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j1wxPL6IvWkCMRBDqKMYfKfpE5Z.jpg'),
(107700, 7690, 'East New York: Uma Nova Lei S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pnR5AB3Lk32PUcUX5trG8jmuRje.jpg'),
(107701, 7690, 'East New York: Uma Nova Lei S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xmnA3NYxjgOzFNLzEgCTkeNoaOs.jpg'),
(107702, 7690, 'East New York: Uma Nova Lei S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2tUH9O3IzlbhSO9yCLVByyb3JBL.jpg'),
(107703, 7690, 'East New York: Uma Nova Lei S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aDTNycBu9Bu4X0Z19G9nZANCXyU.jpg'),
(107704, 7690, 'East New York: Uma Nova Lei S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tBhI4C8dJsn6rs5XHJ9v8ARjCp2.jpg'),
(107705, 7690, 'East New York: Uma Nova Lei S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zfogohlqlu5oNyBslljyKeiJsZj.jpg'),
(107706, 7690, 'East New York: Uma Nova Lei S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/acT0UDkNkLYTmvNiu78nyZM7fTN.jpg'),
(107707, 7690, 'East New York: Uma Nova Lei S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTKyYKKXU46MN1HZcvowEfracdg.jpg'),
(107708, 7690, 'East New York: Uma Nova Lei S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uLLJyKgLIubajmtWSBgfJ2t4eCW.jpg'),
(107709, 7690, 'East New York: Uma Nova Lei S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rnTN5YoamQOgaGaTXeRoB4mNdaq.jpg'),
(107710, 7690, 'East New York: Uma Nova Lei S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/59e3gQDwDTUUuoyCjVEMqFLYYc6.jpg'),
(107711, 7690, 'East New York: Uma Nova Lei S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wTXl8h3YrNdJTzk6cMD7FiDZYK2.jpg'),
(107712, 7690, 'East New York: Uma Nova Lei S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7i9Rxk6JzcV3f86nzr62DFBqgl.jpg'),
(107713, 7690, 'East New York: Uma Nova Lei S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aAVcS79isSCq9Dtm93frl7JhNjX.jpg'),
(107714, 7690, 'East New York: Uma Nova Lei S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gHAUmykugMpDVkQZsFKKggFszfm.jpg'),
(107715, 7690, 'East New York: Uma Nova Lei S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rwp63aWxjALuzToluXk7vkkEGHD.jpg'),
(107716, 7690, 'East New York: Uma Nova Lei S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AbhPk71iHWY6zYWkzWwLp7HzNhu.jpg'),
(107717, 7690, 'East New York: Uma Nova Lei S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/stPMwCRfEdMiUYd8bpdwnhBQAeQ.jpg'),
(107718, 7690, 'East New York: Uma Nova Lei S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sdjefUqEdDtLP69YrgF9oGt0zvm.jpg'),
(107719, 7690, 'East New York: Uma Nova Lei S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hPaLGG14aaZ3ekdAPUv27eZ2oXm.jpg'),
(107720, 7691, 'Joe Pickett S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzTKR171qsX3ADmwqgA48K9hkgA.jpg'),
(107721, 7691, 'Joe Pickett S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xlF1ZRhlgb2lb9MmXX1yTuU24WH.jpg'),
(107722, 7691, 'Joe Pickett S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Y6fmM2od9dm0cUnMgPjPvGd2Yx.jpg'),
(107723, 7691, 'Joe Pickett S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/evCEIKDi6y1ASlshvUPvZ3mioGM.jpg'),
(107724, 7691, 'Joe Pickett S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pjaZFjVWwD4GfpiGVEGHSsb9XfB.jpg'),
(107725, 7691, 'Joe Pickett S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/70vI2cwnnpItR5vV8K7wHanWw7D.jpg'),
(107726, 7691, 'Joe Pickett S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q45488MAalGkUl4KnJxsASIM7OR.jpg'),
(107727, 7691, 'Joe Pickett S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ldv2mt6qFMaghkSPMV1kqtzdd3G.jpg'),
(107728, 7691, 'Joe Pickett S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1yfos9P1zmiEWFNmBdeMUBtJuCT.jpg'),
(107729, 7691, 'Joe Pickett S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AmfO1A4YpAb448hnjwpAnam9acZ.jpg'),
(107730, 7692, 'Joe Pickett S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zbG8aJ7AFIrRxORQdPTcrUBMWWM.jpg'),
(107731, 7692, 'Joe Pickett S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jGpYoDKVj4uIyqjiw1JKjR33Hdc.jpg'),
(107732, 7692, 'Joe Pickett S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/faphK8v8gOOUcm93gT2mSh6KtYq.jpg'),
(107733, 7692, 'Joe Pickett S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWErWXgqgpZCLW3hVi4rixh2Qea.jpg'),
(107734, 7692, 'Joe Pickett S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9VrdJP6gd6EfcwmgEDUBJGjjuCB.jpg'),
(107735, 7692, 'Joe Pickett S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eprP4mz2SX8hYRttLDlF0FLatyd.jpg'),
(107736, 7692, 'Joe Pickett S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aIUuNIUjtaaYo1Y88OFXCP9BmeU.jpg'),
(107737, 7692, 'Joe Pickett S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8kbLUohy3Ytybb139u2zCohOuGb.jpg'),
(107738, 7692, 'Joe Pickett S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8zPUr3MMViBGyPElCvqtXKKe8hS.jpg'),
(107739, 7692, 'Joe Pickett S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/crUzm6pvGVExebkAEYHxhPtJa0M.jpg'),
(107740, 7693, 'Minha Casa Repaginada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jY2K7HINL5ff0gaxtpKaGP3ty95.jpg'),
(107741, 7693, 'Minha Casa Repaginada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jY2K7HINL5ff0gaxtpKaGP3ty95.jpg'),
(107742, 7693, 'Minha Casa Repaginada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jY2K7HINL5ff0gaxtpKaGP3ty95.jpg'),
(107743, 7693, 'Minha Casa Repaginada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jY2K7HINL5ff0gaxtpKaGP3ty95.jpg'),
(107744, 7693, 'Minha Casa Repaginada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jY2K7HINL5ff0gaxtpKaGP3ty95.jpg'),
(107745, 7693, 'Minha Casa Repaginada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jY2K7HINL5ff0gaxtpKaGP3ty95.jpg'),
(107746, 7693, 'Minha Casa Repaginada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jY2K7HINL5ff0gaxtpKaGP3ty95.jpg'),
(107747, 7693, 'Minha Casa Repaginada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jY2K7HINL5ff0gaxtpKaGP3ty95.jpg'),
(107748, 7694, 'Nashville: No Ritmo da Fama S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9m5eJn295nOluBMReiaHKdO8Qq7.jpg'),
(107749, 7694, 'Nashville: No Ritmo da Fama S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7OxctPPII3TwcqeYASbb0GiHpBU.jpg'),
(107750, 7694, 'Nashville: No Ritmo da Fama S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2X8p0NqxBWjABXGJOg9UEnn3HaD.jpg'),
(107751, 7694, 'Nashville: No Ritmo da Fama S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNqa0Dhx6IW9ew0TxrIKdvFV1zr.jpg'),
(107752, 7694, 'Nashville: No Ritmo da Fama S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/61f3T6vSMmPWJHX2kIjZipF6XUX.jpg'),
(107753, 7694, 'Nashville: No Ritmo da Fama S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8dWC3d8sX9WOcgQpWhwHHRPysjQ.jpg'),
(107754, 7694, 'Nashville: No Ritmo da Fama S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v2iSeFFyZ0G5spd8a1z1dGTlg6B.jpg'),
(107755, 7694, 'Nashville: No Ritmo da Fama S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDIRpqKvm6Eep6trlxRxVFDIYHR.jpg'),
(107756, 7694, 'Nashville: No Ritmo da Fama S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lNiUeAo3IuTnTNIKo06RIsFQPPN.jpg'),
(107757, 7694, 'Nashville: No Ritmo da Fama S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qIvveY6QmsS2U3yEf8JNPz9VYol.jpg'),
(107758, 7694, 'Nashville: No Ritmo da Fama S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d0J9KwJAq99OYwXKxzbv4QJvKRl.jpg'),
(107759, 7694, 'Nashville: No Ritmo da Fama S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zwefNrAlNZ7tSClodGoduV9ERn4.jpg'),
(107760, 7694, 'Nashville: No Ritmo da Fama S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xkJeWTzeZEQN92C7P3GS3lu67YO.jpg'),
(107761, 7694, 'Nashville: No Ritmo da Fama S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zflm4DmOTvv7ZBk2RTHWpQ8rO9B.jpg'),
(107762, 7694, 'Nashville: No Ritmo da Fama S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bIobDCHHzwnA7UiFhfmzXuj5OPQ.jpg'),
(107763, 7694, 'Nashville: No Ritmo da Fama S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cty0d6q789kPi93pyc1Zc5WwncM.jpg'),
(107764, 7694, 'Nashville: No Ritmo da Fama S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3URF5oKhtibkgYe9vTxqyM5rnpU.jpg'),
(107765, 7694, 'Nashville: No Ritmo da Fama S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zS4SjWYnc2xi7t4sfc8zHpgw19q.jpg'),
(107766, 7694, 'Nashville: No Ritmo da Fama S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fwbu5VoejQOvv496iMzqvJiM2dU.jpg'),
(107767, 7694, 'Nashville: No Ritmo da Fama S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g38stVJbYYpfSYbsaHP20nLz1RS.jpg'),
(107768, 7694, 'Nashville: No Ritmo da Fama S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yep7ktJOAdVIoae0qLBl9Q4rVji.jpg'),
(107769, 7695, 'Nashville: No Ritmo da Fama S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lkIpS2QLu0jKjLIMfSXg03hUS2L.jpg'),
(107770, 7695, 'Nashville: No Ritmo da Fama S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x03SSpdFYbKtyP8vGEMPwGtaCHP.jpg'),
(107771, 7695, 'Nashville: No Ritmo da Fama S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dbSoF29AsodIssG7pvzz96XDz8E.jpg'),
(107772, 7695, 'Nashville: No Ritmo da Fama S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nPd4AJxq0Tz0xgpNTMc09K378p0.jpg'),
(107773, 7695, 'Nashville: No Ritmo da Fama S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qrClHujTQOmWs58BmUmISTmtxok.jpg'),
(107774, 7695, 'Nashville: No Ritmo da Fama S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vnpRJmEPGN5Kh28yzXYVfqWaDDP.jpg'),
(107775, 7695, 'Nashville: No Ritmo da Fama S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t5d1FS4oERkiIq2aYVcsm1RvQbh.jpg'),
(107776, 7695, 'Nashville: No Ritmo da Fama S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/E9OmL91lbps4QQZS8v9Hmd3UZn.jpg'),
(107777, 7695, 'Nashville: No Ritmo da Fama S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dbm1baNfQP0VYKxev6cbt2GpTMi.jpg'),
(107778, 7695, 'Nashville: No Ritmo da Fama S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qK6eIHefkh0bY5nG7q14RH6ZG2H.jpg'),
(107779, 7695, 'Nashville: No Ritmo da Fama S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v1Kk2Vx9GEboaiLvjZSiGAUtYVq.jpg'),
(107780, 7695, 'Nashville: No Ritmo da Fama S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDQVtEPTX4GxYnL1ZqyjgQA368n.jpg'),
(107781, 7695, 'Nashville: No Ritmo da Fama S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oYO4rcZVASK2aT1PBmgmFpmf8LN.jpg'),
(107782, 7695, 'Nashville: No Ritmo da Fama S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z7iZBO6EXVL97VEE5Fpmsowq6Qe.jpg'),
(107783, 7695, 'Nashville: No Ritmo da Fama S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vWzgH4fmREXvlH9bZ1e3PuZDXxc.jpg'),
(107784, 7695, 'Nashville: No Ritmo da Fama S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cRGvKNNqVRmjbbS5OlNQbUBdtz4.jpg'),
(107785, 7695, 'Nashville: No Ritmo da Fama S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bTo8ZqwojY7IrANUw3JMY8nc13D.jpg'),
(107786, 7695, 'Nashville: No Ritmo da Fama S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wdzpgZOy1cQMy7kNOKuBXwwnZRC.jpg'),
(107787, 7695, 'Nashville: No Ritmo da Fama S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ebI2S3ApVLfojdxhjEhqQvua50P.jpg'),
(107788, 7695, 'Nashville: No Ritmo da Fama S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iQY35cQQVYJCnLaMkbOOtKkhTzk.jpg'),
(107789, 7695, 'Nashville: No Ritmo da Fama S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6V1HeI9hJ3iv4cCTzQxTchY5byx.jpg'),
(107790, 7695, 'Nashville: No Ritmo da Fama S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/218034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wAXSM4gHvHiGj2ffbMSbLCBZ7uO.jpg'),
(107791, 7696, 'Nashville: No Ritmo da Fama S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y1DqaNBH9T2RAiXLLv1TjxwlWNH.jpg'),
(107792, 7696, 'Nashville: No Ritmo da Fama S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/12lEpffJUgrLPThvyGpwrdCbO4K.jpg'),
(107793, 7696, 'Nashville: No Ritmo da Fama S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/poCb792veDB4aGXLDjYPnlcKLLT.jpg'),
(107794, 7696, 'Nashville: No Ritmo da Fama S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnbA1pNnKjuUQi6RwV3SNKJT5V0.jpg'),
(107795, 7696, 'Nashville: No Ritmo da Fama S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9GlFsH0lt6EQeK1QZgjdHHYZSO2.jpg'),
(107796, 7696, 'Nashville: No Ritmo da Fama S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j8fJiuxzVLSpbZr6dshBHbphwoN.jpg'),
(107797, 7696, 'Nashville: No Ritmo da Fama S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eIJ67MwRbJebPfM7BpnAL2dJcKh.jpg'),
(107798, 7696, 'Nashville: No Ritmo da Fama S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4UUAPgDBE19lvytnHcaypdsnIyF.jpg'),
(107799, 7696, 'Nashville: No Ritmo da Fama S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2gvvDq2GSjB4KwLkQnVqik5Td1A.jpg'),
(107800, 7696, 'Nashville: No Ritmo da Fama S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cHZ2EUeINtjOVaSOHGnZG5vjtq9.jpg'),
(107801, 7696, 'Nashville: No Ritmo da Fama S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rchsEQseMzOkrxzGgVIFoIX21Jy.jpg'),
(107802, 7696, 'Nashville: No Ritmo da Fama S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZGCVaGVY4L6m81Y69YOijhgtER.jpg'),
(107803, 7696, 'Nashville: No Ritmo da Fama S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cJKxFBBa7I8kxxlzUF3upeclD9a.jpg'),
(107804, 7696, 'Nashville: No Ritmo da Fama S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sSGe0bMI0DIAnZZewZDUgkJxzjf.jpg'),
(107805, 7696, 'Nashville: No Ritmo da Fama S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e6C1MlyZce9ctOcdCPqXlfbUpoK.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(107806, 7696, 'Nashville: No Ritmo da Fama S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkOpxRFRqsRIIMvQUVYX2na9bTf.jpg'),
(107807, 7696, 'Nashville: No Ritmo da Fama S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tUtzHIEevDG04ki3Azo4FhBv7KK.jpg'),
(107808, 7696, 'Nashville: No Ritmo da Fama S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wu9A4LPfXfYxwVHx0Y5JyATTeMM.jpg'),
(107809, 7696, 'Nashville: No Ritmo da Fama S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p8i8zhVSkz7elDJ0PtQ7i27Ikpz.jpg'),
(107810, 7696, 'Nashville: No Ritmo da Fama S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tXD7uGXm3I6TyrIfVObkNVzyvFO.jpg'),
(107811, 7696, 'Nashville: No Ritmo da Fama S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qSh2rUXOGHS7QTmkvsySy2EN9sa.jpg'),
(107812, 7697, 'Nashville: No Ritmo da Fama S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4oRRlkuHMC8XrrFOMrgUXPCVhIV.jpg'),
(107813, 7697, 'Nashville: No Ritmo da Fama S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqnlywzowwF4R94SKynyrBdsfWz.jpg'),
(107814, 7697, 'Nashville: No Ritmo da Fama S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ougfaGxR6DzFNlDQBuZN5SCpFJy.jpg'),
(107815, 7697, 'Nashville: No Ritmo da Fama S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sYlQ9LaIKCVz7bRaMZuphKqYlYt.jpg'),
(107816, 7697, 'Nashville: No Ritmo da Fama S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dbKwATVjaLm87sBDsn6wKzdSguU.jpg'),
(107817, 7697, 'Nashville: No Ritmo da Fama S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jbo2DtL7NPBbHNZ3FXbPUjEgzul.jpg'),
(107818, 7697, 'Nashville: No Ritmo da Fama S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jqV3XSKlOhu2KXFdEq0g7StR2SM.jpg'),
(107819, 7697, 'Nashville: No Ritmo da Fama S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/syXmvOCLwRtzXJoULa5sW0vV5UA.jpg'),
(107820, 7697, 'Nashville: No Ritmo da Fama S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/EAYHaRONYbFzL7HytTNic9IyDB.jpg'),
(107821, 7697, 'Nashville: No Ritmo da Fama S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yhfTA6LrdW3faaZhMF5iwXLNmT0.jpg'),
(107822, 7697, 'Nashville: No Ritmo da Fama S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gfIzgfuTkdCMsaweUs9L4WH2Adn.jpg'),
(107823, 7697, 'Nashville: No Ritmo da Fama S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e0PMHI9nCvqnmTDqYZOezqhOgoP.jpg'),
(107824, 7697, 'Nashville: No Ritmo da Fama S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kOaKZmu3EWHzTOWRmLsag8WShnR.jpg'),
(107825, 7697, 'Nashville: No Ritmo da Fama S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5R37rDRWi90Vbo6XEQW2zjupUAB.jpg'),
(107826, 7697, 'Nashville: No Ritmo da Fama S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xoRY30e1DykF3rHTa27Wff0BCek.jpg'),
(107827, 7697, 'Nashville: No Ritmo da Fama S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pO1tVxEfSOUx61sKEEuchivmdKz.jpg'),
(107828, 7697, 'Nashville: No Ritmo da Fama S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dAmshg367aOytURoFbKXNMv8R8e.jpg'),
(107829, 7697, 'Nashville: No Ritmo da Fama S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pgXaGE7RJtRAmt5nDRpWVXgrRtg.jpg'),
(107830, 7697, 'Nashville: No Ritmo da Fama S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dHtS2TYBsEm1wJQvGpUtvJ2htQr.jpg'),
(107831, 7697, 'Nashville: No Ritmo da Fama S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5JOY7ObWNAHSfVblHSH8fcphzzl.jpg'),
(107832, 7697, 'Nashville: No Ritmo da Fama S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ydivek9YErPRNYWEGuKgM8yy9WY.jpg'),
(107833, 7698, 'Nashville: No Ritmo da Fama S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nyNd1eylDXXlEPz2atMe3ekFm6R.jpg'),
(107834, 7698, 'Nashville: No Ritmo da Fama S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hvpn1WNlAcfRU6gocSkYiFaD5C3.jpg'),
(107835, 7698, 'Nashville: No Ritmo da Fama S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o58VfQZoubeCfx7yVBecDagtdIg.jpg'),
(107836, 7698, 'Nashville: No Ritmo da Fama S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFs9bHKErL8PhovPD5GR3eOkq3S.jpg'),
(107837, 7698, 'Nashville: No Ritmo da Fama S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/86KMy6mefNR9K53syEFLdtxprdQ.jpg'),
(107838, 7698, 'Nashville: No Ritmo da Fama S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uuZoAwo2SJpE7RoMbE1R7OJQAEb.jpg'),
(107839, 7698, 'Nashville: No Ritmo da Fama S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jjCSUeCIrU0dQ2cWnD9FOUbxu0k.jpg'),
(107840, 7698, 'Nashville: No Ritmo da Fama S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xI9Kg6OAnPh9Y7nHUrfCwvqC299.jpg'),
(107841, 7698, 'Nashville: No Ritmo da Fama S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJWtNy63Z6EEES3PmR8auV09N4r.jpg'),
(107842, 7698, 'Nashville: No Ritmo da Fama S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zKpa3DP3tDjWqpP5cGdpaYcs0UN.jpg'),
(107843, 7698, 'Nashville: No Ritmo da Fama S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qYfH6oX1LOKQ55xfvkzGCvGuxK0.jpg'),
(107844, 7698, 'Nashville: No Ritmo da Fama S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k2WxnMnd9SUX9vHBx5cHAnkWlWi.jpg'),
(107845, 7698, 'Nashville: No Ritmo da Fama S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nyQ7lK6xROv8zIL9fddDxVYz99t.jpg'),
(107846, 7698, 'Nashville: No Ritmo da Fama S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5y0p1gJ6dvmUV7RwevjH5DbAJGg.jpg'),
(107847, 7698, 'Nashville: No Ritmo da Fama S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/22iUaa58UNId0RzgQXK9uPfrWvU.jpg'),
(107848, 7698, 'Nashville: No Ritmo da Fama S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4zRjDgJVFp3KUMv1ZKk1uwEaAHA.jpg'),
(107849, 7698, 'Nashville: No Ritmo da Fama S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/218093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nox8cRYolsRIKer6fFRjS4MpuBI.jpg'),
(107850, 7698, 'Nashville: No Ritmo da Fama S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/218094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tNDzjjDdir8J0AGRn5bDA36LJ0n.jpg'),
(107851, 7698, 'Nashville: No Ritmo da Fama S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/218095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3s49TvIYuI9ISMuT4Ix2zLIWDHb.jpg'),
(107852, 7698, 'Nashville: No Ritmo da Fama S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/218096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sNTplQ7KzidZatrqP846v4uVry1.jpg'),
(107853, 7698, 'Nashville: No Ritmo da Fama S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/218097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzicRpZ9HvjPACWPQ8WUUZ4pLVO.jpg'),
(107854, 7699, 'Nashville: No Ritmo da Fama S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/218098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gHmCyXz331WdXtlu468nRdQDJ5Z.jpg'),
(107855, 7699, 'Nashville: No Ritmo da Fama S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/218099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lAg6b4ZaX5nSeXOnhC4OrUwZYLx.jpg'),
(107856, 7699, 'Nashville: No Ritmo da Fama S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/218100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yJGNB4Ixwp3fDNFK5zXTtk9SEZA.jpg'),
(107857, 7699, 'Nashville: No Ritmo da Fama S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/218101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kLzJc9oivmyNGz1sURbxpQHxFDh.jpg'),
(107858, 7699, 'Nashville: No Ritmo da Fama S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/218102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1cLhosh8sa4188tPU0ezQDLwYdx.jpg'),
(107859, 7699, 'Nashville: No Ritmo da Fama S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/218103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBefoFbgrCBSDZ0j92UMVDEu7xU.jpg'),
(107860, 7699, 'Nashville: No Ritmo da Fama S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/218104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gtsZAVmsAUC9J1oTjywlN8OKBcW.jpg'),
(107861, 7699, 'Nashville: No Ritmo da Fama S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/218105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xwkWZFLgcIqzkpFTulPtECwQOxt.jpg'),
(107862, 7699, 'Nashville: No Ritmo da Fama S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/218106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJpuuMpmG1y9ezjquWVWn8atG5E.jpg'),
(107863, 7699, 'Nashville: No Ritmo da Fama S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/218107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pp6ggRM3V1pCCh7DTmDWhDspCl4.jpg'),
(107864, 7699, 'Nashville: No Ritmo da Fama S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/218108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1EPbi8LGd7M3jfz53SXNWZ35J9S.jpg'),
(107865, 7699, 'Nashville: No Ritmo da Fama S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/218109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mIlJhpT0lj6bmTguuwOBTjIZ9u0.jpg'),
(107866, 7699, 'Nashville: No Ritmo da Fama S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/218110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lrkL31kBbTgAs3YrMkiZYGV5EYZ.jpg'),
(107867, 7699, 'Nashville: No Ritmo da Fama S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/218111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s4sAkFHq3sX59awNDV7UjPhNhEi.jpg'),
(107868, 7699, 'Nashville: No Ritmo da Fama S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/218112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tqKxndA2pCu4HNRYpFaTwYKDzDE.jpg'),
(107869, 7699, 'Nashville: No Ritmo da Fama S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/218113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vX04Vk40x8u2v10jyE4YC0lPsds.jpg'),
(107870, 7700, 'Os Horrores de Dolores Roach S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zH06lxd8DHSAPih4xLqcPfT9xrM.jpg'),
(107871, 7700, 'Os Horrores de Dolores Roach S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ysrE8pFaKLLMFzITyMyV3ynxnNX.jpg'),
(107872, 7700, 'Os Horrores de Dolores Roach S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/67sQVG8pGcuZT69krJdOuDKpNey.jpg'),
(107873, 7700, 'Os Horrores de Dolores Roach S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/af3KjxuzIv5AAwXIJ0z37UdJGuE.jpg'),
(107874, 7700, 'Os Horrores de Dolores Roach S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lZgaKbgGsSeKhzaQNn8125tC9Fj.jpg'),
(107875, 7700, 'Os Horrores de Dolores Roach S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4WLbdntxRA5faqqpvmBDzxN7QvK.jpg'),
(107876, 7700, 'Os Horrores de Dolores Roach S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJdJD7JehZMDqwE4claFxROXBF9.jpg'),
(107877, 7700, 'Os Horrores de Dolores Roach S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7wwJY2nqveoXVqYUQ9o6C0E1Cvj.jpg'),
(107878, 7701, 'Os Pequenos Johnstons S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107879, 7701, 'Os Pequenos Johnstons S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107880, 7701, 'Os Pequenos Johnstons S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107881, 7701, 'Os Pequenos Johnstons S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107882, 7701, 'Os Pequenos Johnstons S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107883, 7701, 'Os Pequenos Johnstons S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107884, 7701, 'Os Pequenos Johnstons S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107885, 7701, 'Os Pequenos Johnstons S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107886, 7702, 'Os Pequenos Johnstons S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107887, 7702, 'Os Pequenos Johnstons S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107888, 7702, 'Os Pequenos Johnstons S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107889, 7702, 'Os Pequenos Johnstons S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107890, 7702, 'Os Pequenos Johnstons S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107891, 7702, 'Os Pequenos Johnstons S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107892, 7702, 'Os Pequenos Johnstons S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107893, 7702, 'Os Pequenos Johnstons S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107894, 7702, 'Os Pequenos Johnstons S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107895, 7702, 'Os Pequenos Johnstons S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107896, 7702, 'Os Pequenos Johnstons S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107897, 7703, 'Os Pequenos Johnstons S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107898, 7703, 'Os Pequenos Johnstons S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107899, 7703, 'Os Pequenos Johnstons S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107900, 7703, 'Os Pequenos Johnstons S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107901, 7703, 'Os Pequenos Johnstons S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107902, 7703, 'Os Pequenos Johnstons S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107903, 7703, 'Os Pequenos Johnstons S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107904, 7703, 'Os Pequenos Johnstons S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107905, 7704, 'Os Pequenos Johnstons S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107906, 7704, 'Os Pequenos Johnstons S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107907, 7704, 'Os Pequenos Johnstons S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107908, 7704, 'Os Pequenos Johnstons S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107909, 7704, 'Os Pequenos Johnstons S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107910, 7704, 'Os Pequenos Johnstons S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107911, 7705, 'Os Pequenos Johnstons S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107912, 7705, 'Os Pequenos Johnstons S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107913, 7705, 'Os Pequenos Johnstons S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107914, 7705, 'Os Pequenos Johnstons S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107915, 7705, 'Os Pequenos Johnstons S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107916, 7705, 'Os Pequenos Johnstons S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107917, 7705, 'Os Pequenos Johnstons S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107918, 7705, 'Os Pequenos Johnstons S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107919, 7705, 'Os Pequenos Johnstons S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107920, 7705, 'Os Pequenos Johnstons S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107921, 7706, 'Os Pequenos Johnstons S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107922, 7706, 'Os Pequenos Johnstons S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107923, 7706, 'Os Pequenos Johnstons S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107924, 7706, 'Os Pequenos Johnstons S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107925, 7706, 'Os Pequenos Johnstons S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107926, 7706, 'Os Pequenos Johnstons S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107927, 7706, 'Os Pequenos Johnstons S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107928, 7706, 'Os Pequenos Johnstons S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107929, 7707, 'Os Pequenos Johnstons S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107930, 7707, 'Os Pequenos Johnstons S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107931, 7707, 'Os Pequenos Johnstons S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107932, 7707, 'Os Pequenos Johnstons S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107933, 7707, 'Os Pequenos Johnstons S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107934, 7707, 'Os Pequenos Johnstons S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107935, 7707, 'Os Pequenos Johnstons S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107936, 7707, 'Os Pequenos Johnstons S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107937, 7707, 'Os Pequenos Johnstons S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107938, 7707, 'Os Pequenos Johnstons S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107939, 7708, 'Os Pequenos Johnstons S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107940, 7708, 'Os Pequenos Johnstons S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107941, 7708, 'Os Pequenos Johnstons S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107942, 7708, 'Os Pequenos Johnstons S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107943, 7708, 'Os Pequenos Johnstons S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107944, 7708, 'Os Pequenos Johnstons S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107945, 7708, 'Os Pequenos Johnstons S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107946, 7708, 'Os Pequenos Johnstons S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107947, 7709, 'Os Pequenos Johnstons S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107948, 7709, 'Os Pequenos Johnstons S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107949, 7709, 'Os Pequenos Johnstons S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107950, 7709, 'Os Pequenos Johnstons S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107951, 7709, 'Os Pequenos Johnstons S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107952, 7709, 'Os Pequenos Johnstons S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107953, 7709, 'Os Pequenos Johnstons S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107954, 7709, 'Os Pequenos Johnstons S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107955, 7710, 'Os Pequenos Johnstons S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107956, 7710, 'Os Pequenos Johnstons S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107957, 7710, 'Os Pequenos Johnstons S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107958, 7710, 'Os Pequenos Johnstons S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107959, 7710, 'Os Pequenos Johnstons S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107960, 7710, 'Os Pequenos Johnstons S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107961, 7710, 'Os Pequenos Johnstons S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107962, 7710, 'Os Pequenos Johnstons S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107963, 7711, 'Os Pequenos Johnstons S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107964, 7711, 'Os Pequenos Johnstons S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107965, 7711, 'Os Pequenos Johnstons S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107966, 7711, 'Os Pequenos Johnstons S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107967, 7711, 'Os Pequenos Johnstons S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107968, 7711, 'Os Pequenos Johnstons S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107969, 7711, 'Os Pequenos Johnstons S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107970, 7711, 'Os Pequenos Johnstons S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107971, 7712, 'Os Pequenos Johnstons S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107972, 7712, 'Os Pequenos Johnstons S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107973, 7712, 'Os Pequenos Johnstons S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107974, 7712, 'Os Pequenos Johnstons S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107975, 7712, 'Os Pequenos Johnstons S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107976, 7712, 'Os Pequenos Johnstons S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107977, 7712, 'Os Pequenos Johnstons S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107978, 7712, 'Os Pequenos Johnstons S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107979, 7712, 'Os Pequenos Johnstons S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107980, 7712, 'Os Pequenos Johnstons S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCQrPnMdvytlfp4EvbGGvFOv6ty.jpg'),
(107981, 7713, 'Schooled S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3jaAeNVh8uXY7lmoDaEOKh8ENay.jpg'),
(107982, 7713, 'Schooled S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l8YEsl4RF2XWv2K93vGaih7cQux.jpg'),
(107983, 7713, 'Schooled S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d5RDYW7dyqASSBeEjdUGIdFActR.jpg'),
(107984, 7713, 'Schooled S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xtGBJpLWumffStjDnWQlvXYoHwc.jpg'),
(107985, 7713, 'Schooled S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bpjZAA1RFikByPL8cOQfhFQwqd9.jpg'),
(107986, 7713, 'Schooled S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2PFyxBVoyUd0Klyuwzuxd3AwgaQ.jpg'),
(107987, 7713, 'Schooled S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/okbi4HzIprduHvsPsn0j7UlEO8x.jpg'),
(107988, 7713, 'Schooled S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j0vfAJaeiH2R37j7GWcvXkWXKgb.jpg'),
(107989, 7713, 'Schooled S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rBft9Kvu9gXCtqPG8P6dvyVctKb.jpg'),
(107990, 7713, 'Schooled S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cSu4qKyYiQigQhNI9tN7fZcz8yj.jpg'),
(107991, 7713, 'Schooled S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2RD6Aacebrez5M7gVhHf79bEQd.jpg'),
(107992, 7713, 'Schooled S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nq3XmhKKezJHApL6CQj59uSjs7T.jpg'),
(107993, 7713, 'Schooled S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yqK2alODZlbV7nklXNpRbN3jqB0.jpg'),
(107994, 7714, 'Schooled S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yM3VSgraJBaGYRAS0MqnNFxGGf8.jpg'),
(107995, 7714, 'Schooled S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PkSAKAkGQQGfkdmODPoPeQnmWC.jpg'),
(107996, 7714, 'Schooled S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gkFAHmEjNVk3dolTWePLrp9bWvN.jpg'),
(107997, 7714, 'Schooled S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vpNDVMVFb8Suih7S6WU768JB2Rl.jpg'),
(107998, 7714, 'Schooled S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/apxPlhHevIx4drHmtiyAtRd8TQx.jpg'),
(107999, 7714, 'Schooled S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5TBJ610sbQyFy60qpnbRm4LOzih.jpg'),
(108000, 7714, 'Schooled S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z5sXwJJcp755sQ4aRFLsp5KavsS.jpg'),
(108001, 7714, 'Schooled S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ohtQ4Uygoy1o7X0ORTH8CW9Wlrk.jpg'),
(108002, 7714, 'Schooled S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fqK8FVKWfvjtHSiGzXn0nkSISfU.jpg'),
(108003, 7714, 'Schooled S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mumslOmi1w4UqkAXI5AHGkNl2cy.jpg'),
(108004, 7714, 'Schooled S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/217973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iUhUcgl2SPe2GC2Xu3xP0AhwP0n.jpg'),
(108005, 7714, 'Schooled S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/217974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o99CjXU3csakouXyxJFJ4tAfRZM.jpg'),
(108006, 7714, 'Schooled S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/217975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8CTMYq5hKvMaw8DLag3PU4ZuED1.jpg'),
(108007, 7714, 'Schooled S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/217976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kqnQIML4zuVp1oLTHjrlb2FZAi3.jpg'),
(108008, 7714, 'Schooled S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/217977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jwFuhf4bWHp4rCl2xd5XIk7V2yZ.jpg'),
(108009, 7714, 'Schooled S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/217978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kOWy0o0JhSnoVmGhVOyFrgEAdH3.jpg'),
(108010, 7714, 'Schooled S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/217979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vGuYleqdGSSqhXMuvA633XxhSh4.jpg'),
(108011, 7714, 'Schooled S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/217980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wDAcFiVX3YJxdRMMT6e5Cum3x2A.jpg'),
(108012, 7714, 'Schooled S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/217981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kLu65TKYGWK6I582an0FB2hCkY6.jpg'),
(108013, 7714, 'Schooled S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/217982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fq3TiZpd4z9OBlz1OUCqGH8BhTz.jpg'),
(108014, 7714, 'Schooled S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/217983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ahNKPrX09LQDIcmpcM6uXHKOhwo.jpg'),
(108015, 7715, 'The Other Two S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lUYHQTLJJxCcqe4ASp1zX7DvPMl.jpg'),
(108016, 7715, 'The Other Two S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iR02nmYVZdgiOIldG7fL73r9GCS.jpg'),
(108017, 7715, 'The Other Two S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bTbyC9p8boDGhMcC0KUzNWQbYLr.jpg'),
(108018, 7715, 'The Other Two S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ezrhCPQr5ZZ50uuUrIbugohBfY.jpg'),
(108019, 7715, 'The Other Two S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c51xWoT4zpTMv05RgkIyf72Bn3h.jpg'),
(108020, 7715, 'The Other Two S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bjQOuWdaLWbdS24t0t890HSw1VH.jpg'),
(108021, 7715, 'The Other Two S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tOa4Y2ss1CNTwOML8RNRRKu3jNf.jpg'),
(108022, 7715, 'The Other Two S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y9tk7cC6rKAbtlFiDi9cQT2VMIV.jpg'),
(108023, 7715, 'The Other Two S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u451qEX3GBQOxh4WruzHm2g7GBF.jpg'),
(108024, 7715, 'The Other Two S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gtreV7FSxZExEs4TNTIlV7U3dR.jpg'),
(108025, 7716, 'The Other Two S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yREqISBECl0G5nSb2pxaPEh4gTw.jpg'),
(108026, 7716, 'The Other Two S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6hyAKpRM0tuWuAu5fr98OG5tqjG.jpg'),
(108027, 7716, 'The Other Two S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7rEjaOMMoD4tcs9YbUqERr4RemH.jpg'),
(108028, 7716, 'The Other Two S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e5e5F8AJVS3VFUAj4IPbNGY46M8.jpg'),
(108029, 7716, 'The Other Two S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ewKROhAKQYACfD4QjmxuDkLKOyj.jpg'),
(108030, 7716, 'The Other Two S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9K7nlD70cKbuBUkZy90J3ibQuW0.jpg'),
(108031, 7716, 'The Other Two S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mwp9o4L8cdZt7HyQmbEdwwbOkL6.jpg'),
(108032, 7716, 'The Other Two S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVOwL6AQNHsT2t3J3lAKPC1vl7i.jpg'),
(108033, 7716, 'The Other Two S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LesMDp2yFZDtdGwF3dFtUS9icM.jpg'),
(108034, 7716, 'The Other Two S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gdKvwzNVgGgfzn5uyIt9sYWUuQd.jpg'),
(108035, 7717, 'The Other Two S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/217940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6VKqN56TA2kd2VdLW3l52Fr1g85.jpg'),
(108036, 7717, 'The Other Two S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/217941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rZJx2CrgLTMf3r6DpHW9kND0t6T.jpg'),
(108037, 7717, 'The Other Two S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/217942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1FyySNW8H7uU5wErsjyMXsEs1sp.jpg'),
(108038, 7717, 'The Other Two S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/217943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yzWjG7fJ7sGCxiKEBifyIq0TOa1.jpg'),
(108039, 7717, 'The Other Two S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/217944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1lkjRiVby6CxZZk99ikNOGV1kqV.jpg'),
(108040, 7717, 'The Other Two S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/217945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qtKOGt587etXqihybFSgJVlmMcA.jpg'),
(108041, 7717, 'The Other Two S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/217946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uzpepDjPv1b09Z70pqKNevW1wTo.jpg'),
(108042, 7717, 'The Other Two S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/217947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xaa3wroWkwzrUV0ZVPAPdtlL78X.jpg'),
(108043, 7717, 'The Other Two S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/217948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l6pGYs35TGivE9GFrr1wOvtkWrG.jpg'),
(108044, 7717, 'The Other Two S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/217949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fhLCU9kf7xQKRL7s0TvWa6WMPVB.jpg'),
(108045, 7718, 'The Righteous Gemstones S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGYSCRn4R0AzCcCLbgYuTeeh0hY.jpg'),
(108046, 7718, 'The Righteous Gemstones S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cakRptoMjZb0itNKl4OtkY8X4Wf.jpg'),
(108047, 7718, 'The Righteous Gemstones S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dxLBTUHuRz0Ff4dgijcWTlxoFAP.jpg'),
(108048, 7718, 'The Righteous Gemstones S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6CdyRsdXSfz06aVHytrGuhX790L.jpg'),
(108049, 7718, 'The Righteous Gemstones S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sv2eWZz7zYpYe1PAXu8Nsbv0KmA.jpg'),
(108050, 7718, 'The Righteous Gemstones S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8sOSG95kMZ7JxYHuDpvrul0Q18H.jpg'),
(108051, 7718, 'The Righteous Gemstones S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/81Si1dhZXWUdPHQ9DFSgFoFpZyh.jpg'),
(108052, 7718, 'The Righteous Gemstones S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w2C1npQMqlM5vSeOfvIGlzYbZZH.jpg'),
(108053, 7718, 'The Righteous Gemstones S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzC64aqTIBwd9GBHk7NJQwwllBp.jpg'),
(108054, 7719, 'The Righteous Gemstones S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3LgHZBX1T91ebZupw2DSg7f2mf0.jpg'),
(108055, 7719, 'The Righteous Gemstones S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uCXoi1dKW4KCcEyJlbtWSur09Q.jpg'),
(108056, 7719, 'The Righteous Gemstones S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s7xAVTKAPidYu84J7KH8i3AqgoP.jpg'),
(108057, 7719, 'The Righteous Gemstones S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v0mKOmOHh0liC3RVJ3QudkT0yRh.jpg'),
(108058, 7719, 'The Righteous Gemstones S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lOaG6g0kLJZPZpUUPgRSi8jjkQg.jpg'),
(108059, 7719, 'The Righteous Gemstones S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ivybmfOyEXpYDF0gfTQ8Y6xjqTj.jpg'),
(108060, 7719, 'The Righteous Gemstones S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/35yPOiqC9d7FaeVwWuUz9Io8L0d.jpg'),
(108061, 7719, 'The Righteous Gemstones S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wHi03AzgDpzzbAa56BAhv0Ia9Ch.jpg'),
(108062, 7719, 'The Righteous Gemstones S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A9iFbgxKyZGz1QVsYydXGMbIn1x.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(108063, 7720, 'The Righteous Gemstones S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uN9RIXBr0SwzmvTi7GOwcZ4BWEr.jpg'),
(108064, 7720, 'The Righteous Gemstones S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ppE9Xw0KVjxrA0sFo7vLLfcRang.jpg'),
(108065, 7720, 'The Righteous Gemstones S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gyqSxkR49ttb6c7yFCs23EYmFW5.jpg'),
(108066, 7720, 'The Righteous Gemstones S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gHwWFx5YCXW6zD0PWLSBHhrkw6j.jpg'),
(108067, 7720, 'The Righteous Gemstones S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226359.mp4', 'http://image.tmdb.org/t/p/w1280/uXtOGCuNH8vm6aXBDf19m1xJCuI.jpg'),
(108068, 7720, 'The Righteous Gemstones S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226360.mp4', 'http://image.tmdb.org/t/p/w1280/nB4nhyWPtNkvqNIhdoSR8Nbhmbd.jpg'),
(108069, 7720, 'The Righteous Gemstones S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226361.mp4', 'http://image.tmdb.org/t/p/w1280/fp49A0ICLxI20z0bHhLL9ybqiRP.jpg'),
(108070, 7720, 'The Righteous Gemstones S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226362.mp4', 'http://image.tmdb.org/t/p/w1280/6BjjPDVYLw4Z20dNY24BndjkpQW.jpg'),
(108071, 7720, 'The Righteous Gemstones S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226363.mp4', 'http://image.tmdb.org/t/p/w1280/gJfHO8n8hwukzF6YIhD1JOEtEjH.jpg'),
(108072, 7721, 'The Righteous Gemstones S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/720815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lbkYq13TM6b2nM33fxQDVs210J0.jpg'),
(108073, 7721, 'The Righteous Gemstones S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/728418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lbkYq13TM6b2nM33fxQDVs210J0.jpg'),
(108074, 7721, 'The Righteous Gemstones S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/737136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lbkYq13TM6b2nM33fxQDVs210J0.jpg'),
(108075, 7721, 'The Righteous Gemstones S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/750040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lbkYq13TM6b2nM33fxQDVs210J0.jpg'),
(108076, 7721, 'The Righteous Gemstones S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/757800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lbkYq13TM6b2nM33fxQDVs210J0.jpg'),
(108077, 7721, 'The Righteous Gemstones S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/763219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lbkYq13TM6b2nM33fxQDVs210J0.jpg'),
(108078, 7721, 'The Righteous Gemstones S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/771655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lbkYq13TM6b2nM33fxQDVs210J0.jpg'),
(108079, 7721, 'The Righteous Gemstones S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/783841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lbkYq13TM6b2nM33fxQDVs210J0.jpg'),
(108080, 7721, 'The Righteous Gemstones S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/793126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lbkYq13TM6b2nM33fxQDVs210J0.jpg'),
(108081, 7722, 'A Disputa dos Confeiteiros: Primavera S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108082, 7722, 'A Disputa dos Confeiteiros: Primavera S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108083, 7722, 'A Disputa dos Confeiteiros: Primavera S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108084, 7722, 'A Disputa dos Confeiteiros: Primavera S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108085, 7722, 'A Disputa dos Confeiteiros: Primavera S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108086, 7722, 'A Disputa dos Confeiteiros: Primavera S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108087, 7723, 'A Disputa dos Confeiteiros: Primavera S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108088, 7723, 'A Disputa dos Confeiteiros: Primavera S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108089, 7723, 'A Disputa dos Confeiteiros: Primavera S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108090, 7723, 'A Disputa dos Confeiteiros: Primavera S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108091, 7723, 'A Disputa dos Confeiteiros: Primavera S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108092, 7723, 'A Disputa dos Confeiteiros: Primavera S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108093, 7724, 'A Disputa dos Confeiteiros: Primavera S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108094, 7724, 'A Disputa dos Confeiteiros: Primavera S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108095, 7724, 'A Disputa dos Confeiteiros: Primavera S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108096, 7724, 'A Disputa dos Confeiteiros: Primavera S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108097, 7724, 'A Disputa dos Confeiteiros: Primavera S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108098, 7724, 'A Disputa dos Confeiteiros: Primavera S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108099, 7724, 'A Disputa dos Confeiteiros: Primavera S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108100, 7725, 'A Disputa dos Confeiteiros: Primavera S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108101, 7725, 'A Disputa dos Confeiteiros: Primavera S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108102, 7725, 'A Disputa dos Confeiteiros: Primavera S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108103, 7725, 'A Disputa dos Confeiteiros: Primavera S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108104, 7725, 'A Disputa dos Confeiteiros: Primavera S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108105, 7725, 'A Disputa dos Confeiteiros: Primavera S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108106, 7725, 'A Disputa dos Confeiteiros: Primavera S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108107, 7725, 'A Disputa dos Confeiteiros: Primavera S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108108, 7726, 'A Disputa dos Confeiteiros: Primavera S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108109, 7726, 'A Disputa dos Confeiteiros: Primavera S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108110, 7726, 'A Disputa dos Confeiteiros: Primavera S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108111, 7726, 'A Disputa dos Confeiteiros: Primavera S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108112, 7726, 'A Disputa dos Confeiteiros: Primavera S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108113, 7726, 'A Disputa dos Confeiteiros: Primavera S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108114, 7726, 'A Disputa dos Confeiteiros: Primavera S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108115, 7726, 'A Disputa dos Confeiteiros: Primavera S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108116, 7727, 'A Disputa dos Confeiteiros: Primavera S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108117, 7727, 'A Disputa dos Confeiteiros: Primavera S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108118, 7727, 'A Disputa dos Confeiteiros: Primavera S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108119, 7727, 'A Disputa dos Confeiteiros: Primavera S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108120, 7727, 'A Disputa dos Confeiteiros: Primavera S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108121, 7727, 'A Disputa dos Confeiteiros: Primavera S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108122, 7727, 'A Disputa dos Confeiteiros: Primavera S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108123, 7727, 'A Disputa dos Confeiteiros: Primavera S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108124, 7727, 'A Disputa dos Confeiteiros: Primavera S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108125, 7728, 'A Disputa dos Confeiteiros: Primavera S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108126, 7728, 'A Disputa dos Confeiteiros: Primavera S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108127, 7728, 'A Disputa dos Confeiteiros: Primavera S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108128, 7728, 'A Disputa dos Confeiteiros: Primavera S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108129, 7728, 'A Disputa dos Confeiteiros: Primavera S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108130, 7728, 'A Disputa dos Confeiteiros: Primavera S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108131, 7728, 'A Disputa dos Confeiteiros: Primavera S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/409857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108132, 7728, 'A Disputa dos Confeiteiros: Primavera S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/409858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108133, 7728, 'A Disputa dos Confeiteiros: Primavera S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/409859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108134, 7728, 'A Disputa dos Confeiteiros: Primavera S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/409860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108135, 7729, 'A Disputa dos Confeiteiros: Primavera S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtO1U0M9nLFxUw2H10eQKfFEtYp.jpg'),
(108136, 7729, 'A Disputa dos Confeiteiros: Primavera S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lkE5ShCBOKbdNwzhmXn03YhWNCG.jpg'),
(108137, 7729, 'A Disputa dos Confeiteiros: Primavera S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eC4Zb9TkMah4cWeuZr8KWEDRnDy.jpg'),
(108138, 7729, 'A Disputa dos Confeiteiros: Primavera S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/izquotMVmI9Enw6YRYfdYSVGSkA.jpg'),
(108139, 7729, 'A Disputa dos Confeiteiros: Primavera S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108140, 7729, 'A Disputa dos Confeiteiros: Primavera S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108141, 7729, 'A Disputa dos Confeiteiros: Primavera S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/409873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108142, 7729, 'A Disputa dos Confeiteiros: Primavera S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/409874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108143, 7729, 'A Disputa dos Confeiteiros: Primavera S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/409875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108144, 7729, 'A Disputa dos Confeiteiros: Primavera S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/409876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108145, 7729, 'A Disputa dos Confeiteiros: Primavera S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/409877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108146, 7729, 'A Disputa dos Confeiteiros: Primavera S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/409878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108147, 7729, 'A Disputa dos Confeiteiros: Primavera S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/409879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108148, 7729, 'A Disputa dos Confeiteiros: Primavera S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/409880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108149, 7729, 'A Disputa dos Confeiteiros: Primavera S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/409881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hs8lAFNPuW1UxS0z0hLRIpj3DZm.jpg'),
(108150, 7730, 'Crônicas de um Aristocrata em Outro Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pzY1GtvMx7Gax8LG37GM6FnKKn5.jpg'),
(108151, 7730, 'Crônicas de um Aristocrata em Outro Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkENKN9yVtYYU5tpIURrJiJ4JrN.jpg'),
(108152, 7730, 'Crônicas de um Aristocrata em Outro Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3PfbAScRckdUmCBRGJArxrxwKf.jpg'),
(108153, 7730, 'Crônicas de um Aristocrata em Outro Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PtRxKcnULTO10sOA0udVBDejVc.jpg'),
(108154, 7730, 'Crônicas de um Aristocrata em Outro Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ve4oPMoFOkZcp2AWEPv4yyDdPXI.jpg'),
(108155, 7730, 'Crônicas de um Aristocrata em Outro Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nKd70LVlp6fBRqcBHTw6DMblqGk.jpg'),
(108156, 7730, 'Crônicas de um Aristocrata em Outro Mundo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/prlS0S6dah9bOoxu7S06LCsjIuW.jpg'),
(108157, 7730, 'Crônicas de um Aristocrata em Outro Mundo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ve6Pnlmhx2rlzMY2L9ka8MurFjY.jpg'),
(108158, 7730, 'Crônicas de um Aristocrata em Outro Mundo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FS8HGkheCuUw8ww5RIz1i6xl8m.jpg'),
(108159, 7730, 'Crônicas de um Aristocrata em Outro Mundo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qeU92i3I7GpW996pBh0cOSnGIBn.jpg'),
(108160, 7730, 'Crônicas de um Aristocrata em Outro Mundo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3r6sCDCV1T0E9tKHPf5xGzdIBBf.jpg'),
(108161, 7730, 'Crônicas de um Aristocrata em Outro Mundo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xrw781ggu8uCztCtKuwu0EUd3T8.jpg'),
(108162, 7731, 'Minhas Aventuras com o Superman S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QmV72WQgujO3SAqz3Z2vfMPDSc.jpg'),
(108163, 7731, 'Minhas Aventuras com o Superman S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2y0u4CCzuFctOLqwWrHWmJwf795.jpg'),
(108164, 7731, 'Minhas Aventuras com o Superman S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232995.mp4', 'http://image.tmdb.org/t/p/w1280/1FM9HlxYFGWMc4b9bzhLZMHdTVN.jpg'),
(108165, 7731, 'Minhas Aventuras com o Superman S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232996.mp4', 'http://image.tmdb.org/t/p/w1280/dsS6xuMBGr83Jvu5gegZOfCBojo.jpg'),
(108166, 7731, 'Minhas Aventuras com o Superman S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232997.mp4', 'http://image.tmdb.org/t/p/w1280/eVHTeQKfuTxkEpo8yNb9suAeCvM.jpg'),
(108167, 7731, 'Minhas Aventuras com o Superman S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232998.mp4', 'http://image.tmdb.org/t/p/w1280/dtzGqPr6DxLnZt8qAossTQyycyQ.jpg'),
(108168, 7731, 'Minhas Aventuras com o Superman S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232999.mp4', 'http://image.tmdb.org/t/p/w1280/8BtIQ2wuj5MEbvu4vhnTqUDo98u.jpg'),
(108169, 7731, 'Minhas Aventuras com o Superman S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233000.mp4', 'http://image.tmdb.org/t/p/w1280/4HAArQRUMsf1bzfb50lBWMcztdF.jpg'),
(108170, 7731, 'Minhas Aventuras com o Superman S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233001.mp4', 'http://image.tmdb.org/t/p/w1280/z3O1ZryylQT85bosdr1x9YknOpW.jpg'),
(108171, 7731, 'Minhas Aventuras com o Superman S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233002.mp4', 'http://image.tmdb.org/t/p/w1280/xJNQWbDdeYAHKrNd9uKW9tcjVbI.jpg'),
(108172, 7732, 'Minhas Aventuras com o Superman S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/363245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jiJpmCWFvGwJd3URX8RopMOx7Bc.jpg'),
(108173, 7732, 'Minhas Aventuras com o Superman S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/363246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jiJpmCWFvGwJd3URX8RopMOx7Bc.jpg'),
(108174, 7732, 'Minhas Aventuras com o Superman S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/368025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jiJpmCWFvGwJd3URX8RopMOx7Bc.jpg'),
(108175, 7732, 'Minhas Aventuras com o Superman S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/379790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jiJpmCWFvGwJd3URX8RopMOx7Bc.jpg'),
(108176, 7732, 'Minhas Aventuras com o Superman S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/387386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jiJpmCWFvGwJd3URX8RopMOx7Bc.jpg'),
(108177, 7732, 'Minhas Aventuras com o Superman S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/392378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jiJpmCWFvGwJd3URX8RopMOx7Bc.jpg'),
(108178, 7732, 'Minhas Aventuras com o Superman S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/396429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jiJpmCWFvGwJd3URX8RopMOx7Bc.jpg'),
(108179, 7732, 'Minhas Aventuras com o Superman S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/402975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jiJpmCWFvGwJd3URX8RopMOx7Bc.jpg'),
(108180, 7732, 'Minhas Aventuras com o Superman S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/408532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jiJpmCWFvGwJd3URX8RopMOx7Bc.jpg'),
(108181, 7732, 'Minhas Aventuras com o Superman S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/415682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jiJpmCWFvGwJd3URX8RopMOx7Bc.jpg'),
(108182, 7733, 'Os Segredos do Everest S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223876.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/1r2Gksf4e4aagr1kNOKxhZOYX2S.jpg'),
(108183, 7733, 'Os Segredos do Everest S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223877.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/1r2Gksf4e4aagr1kNOKxhZOYX2S.jpg'),
(108184, 7734, 'Sorriso Real S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bM1v73KEFfCtucy1uyqku8dOv9J.jpg'),
(108185, 7734, 'Sorriso Real S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dlcuCNuNbnVDmitqXARhnwhXD6P.jpg'),
(108186, 7734, 'Sorriso Real S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233258.mp4', 'http://image.tmdb.org/t/p/w1280/sVUf2Q6MMUwJwHJJZamC4s2H5Yc.jpg'),
(108187, 7734, 'Sorriso Real S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233259.mp4', 'http://image.tmdb.org/t/p/w1280/nZSP4qOY66vR6LqdhZXzWhCO0i4.jpg'),
(108188, 7734, 'Sorriso Real S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233260.mp4', 'http://image.tmdb.org/t/p/w1280/yxg1EahRR55bENuFEEDiMjYEAS3.jpg'),
(108189, 7734, 'Sorriso Real S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233261.mp4', 'http://image.tmdb.org/t/p/w1280/nrxpFV45J32g5Y3enBRzwqcKpjJ.jpg'),
(108190, 7734, 'Sorriso Real S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233262.mp4', 'http://image.tmdb.org/t/p/w1280/ps55YJL2Nj7tv4JnPc5F3rXgVNM.jpg'),
(108191, 7734, 'Sorriso Real S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233263.mp4', 'http://image.tmdb.org/t/p/w1280/5jSEl0hkmeKtQy5KAGNe4BNE1fN.jpg'),
(108192, 7734, 'Sorriso Real S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233264.mp4', 'http://image.tmdb.org/t/p/w1280/qEXwDz1GxgOPwIUFw4W3lpi6tJo.jpg'),
(108193, 7734, 'Sorriso Real S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233265.mp4', 'http://image.tmdb.org/t/p/w1280/glcbHBhvFE9l63yZ6EvUvzLC60E.jpg'),
(108194, 7734, 'Sorriso Real S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233266.mp4', 'http://image.tmdb.org/t/p/w1280/hjcFlX1i3lySPD5tIda2C5Kp3o0.jpg'),
(108195, 7734, 'Sorriso Real S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233267.mp4', 'http://image.tmdb.org/t/p/w1280/259UXMb8RMAxgg9vfvSIgcKTa8Q.jpg'),
(108196, 7734, 'Sorriso Real S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/233268.mp4', 'http://image.tmdb.org/t/p/w1280/5UTCirAUupuYmBdx1qqVxZjcJvV.jpg'),
(108197, 7734, 'Sorriso Real S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/233269.mp4', 'http://image.tmdb.org/t/p/w1280/7RZibRlDRP3FovPaGWf7LsUl51g.jpg'),
(108198, 7734, 'Sorriso Real S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/233270.mp4', 'http://image.tmdb.org/t/p/w1280/g7lvGiXEbAWWPsKk68IaqZDAwDR.jpg'),
(108199, 7734, 'Sorriso Real S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/233271.mp4', 'http://image.tmdb.org/t/p/w1280/ocIgeluor5wP9qrRasWv4MCq5xM.jpg'),
(108200, 7735, 'Use Sua Voz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aMIbfLwTD2OHBXbdZqlJzqMjeTj.jpg'),
(108201, 7735, 'Use Sua Voz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pN86z0spfsOJfqRwxqAjL6N6NUG.jpg'),
(108202, 7735, 'Use Sua Voz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bjHNNOKmINpJHrcSY7bhkCzpVms.jpg'),
(108203, 7736, 'Hoje é Dia de Maria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPXzJLl1zkSM1dT3jrv2K6qNi8q.jpg'),
(108204, 7736, 'Hoje é Dia de Maria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPXzJLl1zkSM1dT3jrv2K6qNi8q.jpg'),
(108205, 7736, 'Hoje é Dia de Maria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPXzJLl1zkSM1dT3jrv2K6qNi8q.jpg'),
(108206, 7736, 'Hoje é Dia de Maria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPXzJLl1zkSM1dT3jrv2K6qNi8q.jpg'),
(108207, 7736, 'Hoje é Dia de Maria S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPXzJLl1zkSM1dT3jrv2K6qNi8q.jpg'),
(108208, 7736, 'Hoje é Dia de Maria S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPXzJLl1zkSM1dT3jrv2K6qNi8q.jpg'),
(108209, 7736, 'Hoje é Dia de Maria S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPXzJLl1zkSM1dT3jrv2K6qNi8q.jpg'),
(108210, 7736, 'Hoje é Dia de Maria S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPXzJLl1zkSM1dT3jrv2K6qNi8q.jpg'),
(108211, 7737, 'Hoje é Dia de Maria S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPXzJLl1zkSM1dT3jrv2K6qNi8q.jpg'),
(108212, 7737, 'Hoje é Dia de Maria S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPXzJLl1zkSM1dT3jrv2K6qNi8q.jpg'),
(108213, 7737, 'Hoje é Dia de Maria S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPXzJLl1zkSM1dT3jrv2K6qNi8q.jpg'),
(108214, 7737, 'Hoje é Dia de Maria S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPXzJLl1zkSM1dT3jrv2K6qNi8q.jpg'),
(108215, 7737, 'Hoje é Dia de Maria S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPXzJLl1zkSM1dT3jrv2K6qNi8q.jpg'),
(108216, 7738, 'Lu & the Bally Bunch S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108217, 7738, 'Lu & the Bally Bunch S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108218, 7738, 'Lu & the Bally Bunch S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108219, 7738, 'Lu & the Bally Bunch S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108220, 7738, 'Lu & the Bally Bunch S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108221, 7738, 'Lu & the Bally Bunch S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108222, 7738, 'Lu & the Bally Bunch S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108223, 7738, 'Lu & the Bally Bunch S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108224, 7738, 'Lu & the Bally Bunch S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108225, 7738, 'Lu & the Bally Bunch S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108226, 7738, 'Lu & the Bally Bunch S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108227, 7738, 'Lu & the Bally Bunch S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108228, 7738, 'Lu & the Bally Bunch S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/223729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108229, 7738, 'Lu & the Bally Bunch S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/223730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108230, 7738, 'Lu & the Bally Bunch S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/223731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108231, 7738, 'Lu & the Bally Bunch S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/223732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108232, 7738, 'Lu & the Bally Bunch S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/223733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108233, 7738, 'Lu & the Bally Bunch S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/223734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108234, 7738, 'Lu & the Bally Bunch S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/223735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108235, 7738, 'Lu & the Bally Bunch S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/223736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108236, 7738, 'Lu & the Bally Bunch S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/223737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108237, 7738, 'Lu & the Bally Bunch S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/223738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108238, 7738, 'Lu & the Bally Bunch S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/223739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108239, 7738, 'Lu & the Bally Bunch S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/223740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108240, 7738, 'Lu & the Bally Bunch S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/223741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108241, 7738, 'Lu & the Bally Bunch S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/223742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2yy0AkGfxUGPljNeyZRk2pBV3Hh.jpg'),
(108242, 7739, 'Martelo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0hJGwue4SZlBIy33SXprTgPw1g.jpg'),
(108243, 7739, 'Martelo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0hJGwue4SZlBIy33SXprTgPw1g.jpg'),
(108244, 7739, 'Martelo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0hJGwue4SZlBIy33SXprTgPw1g.jpg'),
(108245, 7739, 'Martelo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0hJGwue4SZlBIy33SXprTgPw1g.jpg'),
(108246, 7739, 'Martelo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0hJGwue4SZlBIy33SXprTgPw1g.jpg'),
(108247, 7739, 'Martelo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0hJGwue4SZlBIy33SXprTgPw1g.jpg'),
(108248, 7739, 'Martelo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0hJGwue4SZlBIy33SXprTgPw1g.jpg'),
(108249, 7739, 'Martelo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0hJGwue4SZlBIy33SXprTgPw1g.jpg'),
(108250, 7739, 'Martelo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0hJGwue4SZlBIy33SXprTgPw1g.jpg'),
(108251, 7739, 'Martelo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0hJGwue4SZlBIy33SXprTgPw1g.jpg'),
(108252, 7739, 'Martelo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0hJGwue4SZlBIy33SXprTgPw1g.jpg'),
(108253, 7739, 'Martelo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0hJGwue4SZlBIy33SXprTgPw1g.jpg'),
(108254, 7739, 'Martelo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/223716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0hJGwue4SZlBIy33SXprTgPw1g.jpg'),
(108255, 7740, 'Masamune-kun no Revenge S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ypao02HbgZWver1kbyuaK9vtoT.jpg'),
(108256, 7740, 'Masamune-kun no Revenge S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bkGu3e1pbTVEArN6Hd58qIUDSFr.jpg'),
(108257, 7740, 'Masamune-kun no Revenge S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dDWgRChuZBa0M3VVOXXUb0cWsBW.jpg'),
(108258, 7740, 'Masamune-kun no Revenge S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r94yEI63jp8Ujo5lqPboDjd5lnM.jpg'),
(108259, 7740, 'Masamune-kun no Revenge S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVVQmYWoZdmeSpwqnvSZT6kjrwi.jpg'),
(108260, 7740, 'Masamune-kun no Revenge S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2wfl5SkDOUDgTCj9Cqp6ZjoOoyp.jpg'),
(108261, 7740, 'Masamune-kun no Revenge S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fj5kIxb5F4fNv9GBlGyTCBMSUhJ.jpg'),
(108262, 7740, 'Masamune-kun no Revenge S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8L9A07Efez0vnnrn1hBfgJB4Z2b.jpg'),
(108263, 7740, 'Masamune-kun no Revenge S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZosPU9DqtjYq3uFQHvGw7p5mT5.jpg'),
(108264, 7740, 'Masamune-kun no Revenge S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ueWvu7ptwAhK1Ex7ihye5G8hie9.jpg'),
(108265, 7740, 'Masamune-kun no Revenge S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/242281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mJ6jdODmXFzLbWotjvhFtmtwnaw.jpg'),
(108266, 7740, 'Masamune-kun no Revenge S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/242282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tA1pz20AmeksECutNxwSgPxZNDz.jpg'),
(108267, 7741, 'Masamune-kun no Revenge S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242283.mp4', 'http://image.tmdb.org/t/p/w1280/als8A2fV825q3AtEsr1lmxwU1QA.jpg'),
(108268, 7741, 'Masamune-kun no Revenge S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242284.mp4', 'http://image.tmdb.org/t/p/w1280/vF1C9Hwm22fSNdeok8zAsTKB9ee.jpg'),
(108269, 7741, 'Masamune-kun no Revenge S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242285.mp4', 'http://image.tmdb.org/t/p/w1280/2wGhWK8hqmsHNX44lLJL7FTafsr.jpg'),
(108270, 7741, 'Masamune-kun no Revenge S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242286.mp4', 'http://image.tmdb.org/t/p/w1280/rsRp9KdB6A7rAdl7XMe6V9lgIej.jpg'),
(108271, 7741, 'Masamune-kun no Revenge S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242287.mp4', 'http://image.tmdb.org/t/p/w1280/9V4z3qJK2VczTiKx7bjgLXRMF5r.jpg'),
(108272, 7741, 'Masamune-kun no Revenge S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242288.mp4', 'http://image.tmdb.org/t/p/w1280/8hdeonB7q9aaEMIBityikuDLLXG.jpg'),
(108273, 7741, 'Masamune-kun no Revenge S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242289.mp4', 'http://image.tmdb.org/t/p/w1280/qQrnIFc3noPmUOG7Xc4XBF5tmvz.jpg'),
(108274, 7741, 'Masamune-kun no Revenge S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oWbkaF8oZ8AqNbm61e3uXR35qxg.jpg'),
(108275, 7741, 'Masamune-kun no Revenge S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oWbkaF8oZ8AqNbm61e3uXR35qxg.jpg'),
(108276, 7741, 'Masamune-kun no Revenge S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oWbkaF8oZ8AqNbm61e3uXR35qxg.jpg'),
(108277, 7741, 'Masamune-kun no Revenge S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/242293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oWbkaF8oZ8AqNbm61e3uXR35qxg.jpg'),
(108278, 7741, 'Masamune-kun no Revenge S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/242294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oWbkaF8oZ8AqNbm61e3uXR35qxg.jpg'),
(108279, 7742, 'Massacre na Escola - A Tragédia das Meninas de Realengo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mqMF9JhkqdGRadU2OsloVR6p7WU.jpg'),
(108280, 7742, 'Massacre na Escola - A Tragédia das Meninas de Realengo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xMx1BlXKXkjAbzvu0Wpn3HoQb2D.jpg'),
(108281, 7742, 'Massacre na Escola - A Tragédia das Meninas de Realengo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223188.mp4', 'http://image.tmdb.org/t/p/w1280/8mywd4rNSn1UZtwOhQTEYDuwLsi.jpg'),
(108282, 7742, 'Massacre na Escola - A Tragédia das Meninas de Realengo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223189.mp4', 'http://image.tmdb.org/t/p/w1280/9IBG3qGNoen0rhyIxYynELwxV7e.jpg'),
(108283, 7743, 'O Mistério do Pico Victorio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1mtD6uhoqFbZnVAkI5E0itjG6Yk.jpg'),
(108284, 7743, 'O Mistério do Pico Victorio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYOjVfqLAn4tVdx8T7UPSCivieW.jpg'),
(108285, 7743, 'O Mistério do Pico Victorio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYOjVfqLAn4tVdx8T7UPSCivieW.jpg'),
(108286, 7743, 'O Mistério do Pico Victorio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYOjVfqLAn4tVdx8T7UPSCivieW.jpg'),
(108287, 7743, 'O Mistério do Pico Victorio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYOjVfqLAn4tVdx8T7UPSCivieW.jpg'),
(108288, 7743, 'O Mistério do Pico Victorio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYOjVfqLAn4tVdx8T7UPSCivieW.jpg'),
(108289, 7744, 'The Rookie: Feds S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFXrX5SO843bqc8RQyJlvQTIglO.jpg'),
(108290, 7744, 'The Rookie: Feds S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bFAbomRvtIOeVyAt87YQAymVIrh.jpg'),
(108291, 7744, 'The Rookie: Feds S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kMoHc5Uy7OIjKdanUMcUpctinzD.jpg'),
(108292, 7744, 'The Rookie: Feds S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5kcxs6mQ0FIMO40TYLahxdOjUIg.jpg'),
(108293, 7744, 'The Rookie: Feds S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yZOap0kHfpBiMIuECXqbataLZbz.jpg'),
(108294, 7744, 'The Rookie: Feds S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Pk6to091hFHqDJ8UD0BECwWLrp.jpg'),
(108295, 7744, 'The Rookie: Feds S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/84dfQufgo9ABSogf4FW0G6V7i7S.jpg'),
(108296, 7744, 'The Rookie: Feds S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSsoPthuC9WLZAlSo5J8zH99A45.jpg'),
(108297, 7744, 'The Rookie: Feds S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9rBwjSJTysTsxZssXXc3ynnu8Ab.jpg'),
(108298, 7744, 'The Rookie: Feds S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kahmnoCmHXGyfVM8tOv9Nnv8srL.jpg'),
(108299, 7744, 'The Rookie: Feds S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/anLAI1gYScdJCQzPfD6kVAEO9Dy.jpg'),
(108300, 7744, 'The Rookie: Feds S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3A0kZ7tLzW1qOZtpuiFyYrbJ5Bq.jpg'),
(108301, 7744, 'The Rookie: Feds S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/223688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6pmDKb8StQdFRuNzD2i3F0HFZ7X.jpg'),
(108302, 7744, 'The Rookie: Feds S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/223689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pwwwnLM92leLjLiBM2sj0p5E7G.jpg'),
(108303, 7744, 'The Rookie: Feds S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/223690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vi6Vkf9pRri7AKv2UPwK6duXzfl.jpg'),
(108304, 7744, 'The Rookie: Feds S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/223691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iv4oGIbQZx4Tvz8CUvK8Vwde3q4.jpg'),
(108305, 7744, 'The Rookie: Feds S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/223692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v4vcVzLeimleT5KyM2PyCMpN4V6.jpg'),
(108306, 7744, 'The Rookie: Feds S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/223693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6uZEGhPidcU9sXotB2iv4Ck2r2h.jpg'),
(108307, 7744, 'The Rookie: Feds S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/223694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bSZ27gUdYiNfhlQ1lG3z2iS2V5O.jpg'),
(108308, 7744, 'The Rookie: Feds S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/223695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ahXRphqxWFy3D12f95YRghdFp2.jpg'),
(108309, 7744, 'The Rookie: Feds S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/223696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oi0jAXONoJS6zE5hvfn0fMlXqok.jpg'),
(108310, 7744, 'The Rookie: Feds S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/223697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lrBK9VRoxetn1kUcu1rTgenUY6v.jpg'),
(108311, 7745, 'Titã Simbiônico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iiIGUZNtQbsOmgUoLcOmptBAdFd.jpg'),
(108312, 7745, 'Titã Simbiônico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8S3e7P9zjAOAULE6N19jxwSH2oG.jpg'),
(108313, 7745, 'Titã Simbiônico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2jEvZSMioYBMaaFB9hFbIYX9wSi.jpg'),
(108314, 7745, 'Titã Simbiônico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5FhR46miWchPZdDYLHhebWoYCye.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(108315, 7745, 'Titã Simbiônico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cj2j8d7K3Wc6ug2k7TGQQ1gIGXw.jpg'),
(108316, 7745, 'Titã Simbiônico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r1MVEEsytqE7fmzCBcd5fH0WgQ4.jpg'),
(108317, 7745, 'Titã Simbiônico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v89G1IObVkCJ8jKsqsh1kEebLxu.jpg'),
(108318, 7745, 'Titã Simbiônico S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cYdS1nNlhM1zZQ1C82AgvrtoIQO.jpg'),
(108319, 7745, 'Titã Simbiônico S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kxOYGXwSkt992gSZzINrqYdvnpL.jpg'),
(108320, 7745, 'Titã Simbiônico S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3zFGGY6HG62Yt7zEOCO9iuzkz0z.jpg'),
(108321, 7745, 'Titã Simbiônico S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6CjyFe9gXEDmsyi6l00TNku2CHX.jpg'),
(108322, 7745, 'Titã Simbiônico S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJLenyPQlxzaIGecIViU3Jy0IJu.jpg'),
(108323, 7745, 'Titã Simbiônico S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/223668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rjf9Q3xEtjORPPpNWMJDZHX5OOT.jpg'),
(108324, 7745, 'Titã Simbiônico S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/223669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/giwlmeHMFzkgxJSLO0FTA7ZrNgy.jpg'),
(108325, 7745, 'Titã Simbiônico S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/223670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7drZi8hMnHc02DO4mR1XjsXiWcc.jpg'),
(108326, 7745, 'Titã Simbiônico S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/223671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lcuuglT407i4ZNO21S1CtyBrOqW.jpg'),
(108327, 7745, 'Titã Simbiônico S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/223672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j1PDvJJHNSpYrDCFujDobNVG1yH.jpg'),
(108328, 7745, 'Titã Simbiônico S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/223673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bxk1sLS4qZDleL9vQ0e6Cf7LjMY.jpg'),
(108329, 7745, 'Titã Simbiônico S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/223674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rW1SKIMyrsyGgnVYbjLJqqTC448.jpg'),
(108330, 7745, 'Titã Simbiônico S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/223675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2JZ9B0WtosMh1M9MedpNX2g14d8.jpg'),
(108331, 7746, 'Investigação Paralela S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108332, 7746, 'Investigação Paralela S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108333, 7746, 'Investigação Paralela S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108334, 7746, 'Investigação Paralela S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108335, 7746, 'Investigação Paralela S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108336, 7746, 'Investigação Paralela S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108337, 7746, 'Investigação Paralela S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108338, 7746, 'Investigação Paralela S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108339, 7746, 'Investigação Paralela S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108340, 7746, 'Investigação Paralela S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108341, 7747, 'Investigação Paralela S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108342, 7747, 'Investigação Paralela S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108343, 7747, 'Investigação Paralela S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108344, 7747, 'Investigação Paralela S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108345, 7747, 'Investigação Paralela S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108346, 7747, 'Investigação Paralela S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108347, 7747, 'Investigação Paralela S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108348, 7747, 'Investigação Paralela S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108349, 7748, 'Investigação Paralela S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108350, 7748, 'Investigação Paralela S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108351, 7748, 'Investigação Paralela S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108352, 7748, 'Investigação Paralela S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9CNnHdDWbgAijNsoDjSH5IdoyNZ.jpg'),
(108353, 7749, 'Quarterback S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKdElEIyuwrbdochxCXwlaUBFaR.jpg'),
(108354, 7749, 'Quarterback S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKdElEIyuwrbdochxCXwlaUBFaR.jpg'),
(108355, 7749, 'Quarterback S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKdElEIyuwrbdochxCXwlaUBFaR.jpg'),
(108356, 7749, 'Quarterback S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKdElEIyuwrbdochxCXwlaUBFaR.jpg'),
(108357, 7749, 'Quarterback S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKdElEIyuwrbdochxCXwlaUBFaR.jpg'),
(108358, 7749, 'Quarterback S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKdElEIyuwrbdochxCXwlaUBFaR.jpg'),
(108359, 7749, 'Quarterback S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKdElEIyuwrbdochxCXwlaUBFaR.jpg'),
(108360, 7749, 'Quarterback S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKdElEIyuwrbdochxCXwlaUBFaR.jpg'),
(108361, 7750, 'Sugar Rush: The Baking Point S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cSr8pYlPh4jOxAtXegXwpXI6jP.jpg'),
(108362, 7750, 'Sugar Rush: The Baking Point S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lPbGuALDkNBsC4X5pN0BvTHKc4F.jpg'),
(108363, 7750, 'Sugar Rush: The Baking Point S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1m4XL7hPZPRZy4w4fMmEVkDPsF.jpg'),
(108364, 7750, 'Sugar Rush: The Baking Point S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vav74mYbfEJtuWKYCjamzeL9ep8.jpg'),
(108365, 7750, 'Sugar Rush: The Baking Point S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sHG6R1P0k9nYT93Een5zF55npAY.jpg'),
(108366, 7751, 'Sugar Rush: The Baking Point S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/404127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rzNM1JFQviIc9u0PBDgqGk1TPRg.jpg'),
(108367, 7751, 'Sugar Rush: The Baking Point S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/404128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rzNM1JFQviIc9u0PBDgqGk1TPRg.jpg'),
(108368, 7751, 'Sugar Rush: The Baking Point S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/404129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rzNM1JFQviIc9u0PBDgqGk1TPRg.jpg'),
(108369, 7751, 'Sugar Rush: The Baking Point S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/404130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rzNM1JFQviIc9u0PBDgqGk1TPRg.jpg'),
(108370, 7751, 'Sugar Rush: The Baking Point S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/404131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rzNM1JFQviIc9u0PBDgqGk1TPRg.jpg'),
(108371, 7751, 'Sugar Rush: The Baking Point S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/404132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rzNM1JFQviIc9u0PBDgqGk1TPRg.jpg'),
(108372, 7752, 'A Crise dos Três Poderes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nms3eo2UWY6C9wuW3SkGBwJdqCz.jpg'),
(108373, 7752, 'A Crise dos Três Poderes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nms3eo2UWY6C9wuW3SkGBwJdqCz.jpg'),
(108374, 7752, 'A Crise dos Três Poderes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nms3eo2UWY6C9wuW3SkGBwJdqCz.jpg'),
(108375, 7752, 'A Crise dos Três Poderes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nms3eo2UWY6C9wuW3SkGBwJdqCz.jpg'),
(108376, 7753, 'A Fantastica Fábrica da Sanidade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rrgSnVbUO7EeK3otr41cCSjgO3J.jpg'),
(108377, 7753, 'A Fantastica Fábrica da Sanidade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kWBYOOplihgP4WLVva3AWrc5BZf.jpg'),
(108378, 7753, 'A Fantastica Fábrica da Sanidade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7pT2OLwbIXoDbtDndqKoEp59pbv.jpg'),
(108379, 7754, 'A Superfantástica História do Balão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/niCogAEQNjWPLaghwlYxlD9Hf6C.jpg'),
(108380, 7754, 'A Superfantástica História do Balão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3mIj9XW8uqlJ8wh8LNj9aOFLRu.jpg'),
(108381, 7754, 'A Superfantástica História do Balão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g2c0jP1AlNdR95Qzw0B6vFMKNzv.jpg'),
(108382, 7755, 'O Dia Depois da Eleição S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvMoIMpVB2uOhWNvk5nPauwymoD.jpg'),
(108383, 7755, 'O Dia Depois da Eleição S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvMoIMpVB2uOhWNvk5nPauwymoD.jpg'),
(108384, 7755, 'O Dia Depois da Eleição S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvMoIMpVB2uOhWNvk5nPauwymoD.jpg'),
(108385, 7755, 'O Dia Depois da Eleição S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvMoIMpVB2uOhWNvk5nPauwymoD.jpg'),
(108386, 7755, 'O Dia Depois da Eleição S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvMoIMpVB2uOhWNvk5nPauwymoD.jpg'),
(108387, 7756, 'O Teatro das Tesouras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/SIJ2LAae2JlFrfzH3BxkLmLS3H.jpg'),
(108388, 7756, 'O Teatro das Tesouras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/SIJ2LAae2JlFrfzH3BxkLmLS3H.jpg'),
(108389, 7756, 'O Teatro das Tesouras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/SIJ2LAae2JlFrfzH3BxkLmLS3H.jpg'),
(108390, 7756, 'O Teatro das Tesouras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/SIJ2LAae2JlFrfzH3BxkLmLS3H.jpg'),
(108391, 7756, 'O Teatro das Tesouras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/SIJ2LAae2JlFrfzH3BxkLmLS3H.jpg'),
(108392, 7756, 'O Teatro das Tesouras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/SIJ2LAae2JlFrfzH3BxkLmLS3H.jpg'),
(108393, 7756, 'O Teatro das Tesouras S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/SIJ2LAae2JlFrfzH3BxkLmLS3H.jpg'),
(108394, 7756, 'O Teatro das Tesouras S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/SIJ2LAae2JlFrfzH3BxkLmLS3H.jpg'),
(108395, 7757, 'A Fabrica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/79gZ9H2i8n43BKUQ7rLqObXyodE.jpg'),
(108396, 7757, 'A Fabrica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aj5X5YquzeWdeLXBkDr1jSnspkM.jpg'),
(108397, 7757, 'A Fabrica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFbbYTpPUb2E06P9ChknHg49sLo.jpg'),
(108398, 7757, 'A Fabrica S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5pOz7Hcjsv3CzxcpS9nwniIfqWN.jpg'),
(108399, 7758, 'A Fabrica S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/keYGR1XkvR9XseIsd8oLPh2jjmo.jpg'),
(108400, 7758, 'A Fabrica S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qiWuYVGYO4OpdAUP4qP5YIMzUS7.jpg'),
(108401, 7758, 'A Fabrica S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1tulNOLzmECfhr5v6VD7KYSL84y.jpg'),
(108402, 7758, 'A Fabrica S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dFEdLf6OqussQevwxem542KciGM.jpg'),
(108403, 7758, 'A Fabrica S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWdjT8vSRe5kQItapU9cRPHOQjL.jpg'),
(108404, 7758, 'A Fabrica S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xIXaacnWNDscTn6eBdFyK8H6RZL.jpg'),
(108405, 7759, 'C.H.U.E.C.O S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108406, 7759, 'C.H.U.E.C.O S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108407, 7759, 'C.H.U.E.C.O S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108408, 7759, 'C.H.U.E.C.O S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108409, 7759, 'C.H.U.E.C.O S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108410, 7759, 'C.H.U.E.C.O S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108411, 7759, 'C.H.U.E.C.O S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108412, 7759, 'C.H.U.E.C.O S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108413, 7759, 'C.H.U.E.C.O S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108414, 7759, 'C.H.U.E.C.O S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108415, 7759, 'C.H.U.E.C.O S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108416, 7759, 'C.H.U.E.C.O S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108417, 7759, 'C.H.U.E.C.O S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/223320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108418, 7760, 'C.H.U.E.C.O S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108419, 7760, 'C.H.U.E.C.O S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108420, 7760, 'C.H.U.E.C.O S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108421, 7760, 'C.H.U.E.C.O S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108422, 7760, 'C.H.U.E.C.O S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108423, 7760, 'C.H.U.E.C.O S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108424, 7760, 'C.H.U.E.C.O S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108425, 7760, 'C.H.U.E.C.O S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108426, 7760, 'C.H.U.E.C.O S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108427, 7760, 'C.H.U.E.C.O S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108428, 7760, 'C.H.U.E.C.O S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108429, 7760, 'C.H.U.E.C.O S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWTd0ustqZ8Wp4EpuAM1pmCvG4b.jpg'),
(108430, 7761, 'Chef 5 Estrelas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cfJkQQpD9rsHwLXfecCpvUoLHkm.jpg'),
(108431, 7761, 'Chef 5 Estrelas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r3UvYHyV5ZJa4b8B3nCnCAJPh7b.jpg'),
(108432, 7761, 'Chef 5 Estrelas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r3UvYHyV5ZJa4b8B3nCnCAJPh7b.jpg'),
(108433, 7761, 'Chef 5 Estrelas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r3UvYHyV5ZJa4b8B3nCnCAJPh7b.jpg'),
(108434, 7761, 'Chef 5 Estrelas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r3UvYHyV5ZJa4b8B3nCnCAJPh7b.jpg'),
(108435, 7761, 'Chef 5 Estrelas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r3UvYHyV5ZJa4b8B3nCnCAJPh7b.jpg'),
(108436, 7762, 'Círculo Fechado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ulpwIEfK2XVZBls5H96Wevd95.jpg'),
(108437, 7762, 'Círculo Fechado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qp6Lk65uT8XZDZXHSedSy5ZdU1Q.jpg'),
(108438, 7762, 'Círculo Fechado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227681.mp4', 'http://image.tmdb.org/t/p/w1280/leRIxUkuQS9iNYbeZdCESsFBwSW.jpg'),
(108439, 7762, 'Círculo Fechado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227682.mp4', 'http://image.tmdb.org/t/p/w1280/6Joy7gwdUr3dTWxeuTy6qG6g5ro.jpg'),
(108440, 7762, 'Círculo Fechado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fb87LfDdtM22gh4V9Jp6349AZgz.jpg'),
(108441, 7762, 'Círculo Fechado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0BT0bjyd4CYRKXAU7XtrKgRWUC.jpg'),
(108442, 7763, 'Consumidas pelo Fogo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qKenXQJ3oy0bHEHVtX2E9M6a6Gf.jpg'),
(108443, 7763, 'Consumidas pelo Fogo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rG3gcRJ8XwAdCsqViU7zG8af8d3.jpg'),
(108444, 7763, 'Consumidas pelo Fogo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cinqCjnIcp2jZGncuOFJnEaghTa.jpg'),
(108445, 7763, 'Consumidas pelo Fogo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kRs8uKWXXgzTt5xWuzi2ZzU6UoH.jpg'),
(108446, 7763, 'Consumidas pelo Fogo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fek8MwGDnIcRgtNu7LcmlAAIlay.jpg'),
(108447, 7763, 'Consumidas pelo Fogo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jDCOWLSPp2wYMQOpWEoplgEOomt.jpg'),
(108448, 7763, 'Consumidas pelo Fogo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLdJaPw3ZzYsfZaE4UdrKC6QS7a.jpg'),
(108449, 7763, 'Consumidas pelo Fogo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eQ4gbdf71uAufNsldSjXRYRO4PG.jpg'),
(108450, 7764, 'Meu Casamento Feliz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/580251.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xZ8A6dDTyH4xqBWmOV29X2PsvcC.jpg'),
(108451, 7764, 'Meu Casamento Feliz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/580253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aaxTlygMSwywNvJT9BaZ59yFNv2.jpg'),
(108452, 7764, 'Meu Casamento Feliz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/580255.mp4', 'http://image.tmdb.org//t/p/w1280/aMhz3HJ7TttfaeVYB1eGYI9NUxW.jpg'),
(108453, 7764, 'Meu Casamento Feliz S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/580257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aaxTlygMSwywNvJT9BaZ59yFNv2.jpg'),
(108454, 7764, 'Meu Casamento Feliz S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/580259.mp4', 'http://image.tmdb.org//t/p/w1280/hthcbyEwPtvsl8jQyTFrlJFgJPk.jpg'),
(108455, 7764, 'Meu Casamento Feliz S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236405.mp4', 'http://image.tmdb.org/t/p/w1280/hsEzuzDmI1rESaAAedbe0GwHLEY.jpg'),
(108456, 7764, 'Meu Casamento Feliz S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236406.mp4', 'http://image.tmdb.org/t/p/w1280/s21dYLFdJzhGG1OX5XUDboxhdlR.jpg'),
(108457, 7764, 'Meu Casamento Feliz S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236407.mp4', 'http://image.tmdb.org/t/p/w1280/tpS3gqxam5vyFIrRC1eEMZRQQDp.jpg'),
(108458, 7764, 'Meu Casamento Feliz S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236408.mp4', 'http://image.tmdb.org/t/p/w1280/AhU2XhYgeaBHwJKwY9iYfoHye0J.jpg'),
(108459, 7764, 'Meu Casamento Feliz S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236409.mp4', 'http://image.tmdb.org/t/p/w1280/kqU1QKhEWdAadJN4M4lRI5v4QXl.jpg'),
(108460, 7764, 'Meu Casamento Feliz S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aaxTlygMSwywNvJT9BaZ59yFNv2.jpg'),
(108461, 7764, 'Meu Casamento Feliz S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aaxTlygMSwywNvJT9BaZ59yFNv2.jpg'),
(108462, 7765, 'Meu Casamento Feliz S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aaxTlygMSwywNvJT9BaZ59yFNv2.jpg'),
(108463, 7765, 'Meu Casamento Feliz S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/668520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aaxTlygMSwywNvJT9BaZ59yFNv2.jpg'),
(108464, 7765, 'Meu Casamento Feliz S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/671823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aaxTlygMSwywNvJT9BaZ59yFNv2.jpg'),
(108465, 7765, 'Meu Casamento Feliz S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/679109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aaxTlygMSwywNvJT9BaZ59yFNv2.jpg'),
(108466, 7765, 'Meu Casamento Feliz S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/682592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aaxTlygMSwywNvJT9BaZ59yFNv2.jpg'),
(108467, 7765, 'Meu Casamento Feliz S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/692868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aaxTlygMSwywNvJT9BaZ59yFNv2.jpg'),
(108468, 7765, 'Meu Casamento Feliz S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/700121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aaxTlygMSwywNvJT9BaZ59yFNv2.jpg'),
(108469, 7765, 'Meu Casamento Feliz S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/709012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aaxTlygMSwywNvJT9BaZ59yFNv2.jpg'),
(108470, 7765, 'Meu Casamento Feliz S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/716588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aaxTlygMSwywNvJT9BaZ59yFNv2.jpg'),
(108471, 7765, 'Meu Casamento Feliz S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/727737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aaxTlygMSwywNvJT9BaZ59yFNv2.jpg'),
(108472, 7765, 'Meu Casamento Feliz S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/734173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aaxTlygMSwywNvJT9BaZ59yFNv2.jpg'),
(108473, 7765, 'Meu Casamento Feliz S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/765670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aaxTlygMSwywNvJT9BaZ59yFNv2.jpg'),
(108474, 7765, 'Meu Casamento Feliz S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/774558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aaxTlygMSwywNvJT9BaZ59yFNv2.jpg'),
(108475, 7766, 'Sovrevivendo Em Grande Estilo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ni0zbhMTDgoQ5RFRVH6N0oGiqyl.jpg'),
(108476, 7766, 'Sovrevivendo Em Grande Estilo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oFE60843dDHYPdLDiMUFP5IobN2.jpg'),
(108477, 7766, 'Sovrevivendo Em Grande Estilo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xvLj6jnFC8yyHG6wknrpIHLoI9I.jpg'),
(108478, 7766, 'Sovrevivendo Em Grande Estilo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/57a7t9rKTVuLEjDYZHRSEhURGbw.jpg'),
(108479, 7766, 'Sovrevivendo Em Grande Estilo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hPYp0QRbp9lAitZIJgnBKjIHKXG.jpg'),
(108480, 7766, 'Sovrevivendo Em Grande Estilo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Ghmj9jFTPHXj54YwDsQdYzu1X.jpg'),
(108481, 7766, 'Sovrevivendo Em Grande Estilo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t0dwYSPmVZHkKkurVo9LdHDHzJq.jpg'),
(108482, 7766, 'Sovrevivendo Em Grande Estilo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vq3IwAl79v3Tl8ZAYUPqp45PrWC.jpg'),
(108483, 7767, 'Vamos Brincar com a Turma da Mônica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ubDIp4UyigyrrxcF4zWHwCSffjB.jpg'),
(108484, 7767, 'Vamos Brincar com a Turma da Mônica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ubDIp4UyigyrrxcF4zWHwCSffjB.jpg'),
(108485, 7767, 'Vamos Brincar com a Turma da Mônica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ubDIp4UyigyrrxcF4zWHwCSffjB.jpg'),
(108486, 7767, 'Vamos Brincar com a Turma da Mônica S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ubDIp4UyigyrrxcF4zWHwCSffjB.jpg'),
(108487, 7767, 'Vamos Brincar com a Turma da Mônica S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ubDIp4UyigyrrxcF4zWHwCSffjB.jpg'),
(108488, 7767, 'Vamos Brincar com a Turma da Mônica S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ubDIp4UyigyrrxcF4zWHwCSffjB.jpg'),
(108489, 7767, 'Vamos Brincar com a Turma da Mônica S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ubDIp4UyigyrrxcF4zWHwCSffjB.jpg'),
(108490, 7767, 'Vamos Brincar com a Turma da Mônica S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ubDIp4UyigyrrxcF4zWHwCSffjB.jpg'),
(108491, 7767, 'Vamos Brincar com a Turma da Mônica S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ubDIp4UyigyrrxcF4zWHwCSffjB.jpg'),
(108492, 7767, 'Vamos Brincar com a Turma da Mônica S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ubDIp4UyigyrrxcF4zWHwCSffjB.jpg'),
(108493, 7768, 'O Documentário S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qipTK01uopUMKmgNRKLdf9b6E7b.jpg'),
(108494, 7768, 'O Documentário S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230093.mp4', 'http://image.tmdb.org/t/p/w1280/xcqlSY8hqOKek3SiT5SGqyQgPIT.jpg'),
(108495, 7768, 'O Documentário S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0766HNvljZ4PY6ghG57h2hva6x.jpg'),
(108496, 7768, 'O Documentário S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230095.mp4', 'http://image.tmdb.org/t/p/w1280/3CZPDVKy46NboBuiOdyoVj7eTqr.jpg'),
(108497, 7768, 'O Documentário S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230096.mp4', 'http://image.tmdb.org/t/p/w1280/7D4mlGz3FWjKIOltbuNdqnPTY9a.jpg'),
(108498, 7769, 'Bodycam - Registros Criminosos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fyqOROS9qYKXSebK415j2BIknPn.jpg'),
(108499, 7769, 'Bodycam - Registros Criminosos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQt8Rc2k4Kkym5gOqTvvB4iVBrm.jpg'),
(108500, 7769, 'Bodycam - Registros Criminosos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rAkAtsni7EcVQDlVY5NNb7PMxn.jpg'),
(108501, 7769, 'Bodycam - Registros Criminosos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x9UQMi038aLHt5UTYrKmgXAGAeU.jpg'),
(108502, 7769, 'Bodycam - Registros Criminosos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eCZccpoQ1Y6as6kXZWX0tLYvjwB.jpg'),
(108503, 7769, 'Bodycam - Registros Criminosos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/upakqzRrVpsT1Sstc5QxYSFuiAj.jpg'),
(108504, 7769, 'Bodycam - Registros Criminosos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eIl7YUhuKA28DivXr8KIhYIjVmP.jpg'),
(108505, 7769, 'Bodycam - Registros Criminosos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/umZ7J9WCZncqGE2qED3rg47uZI0.jpg'),
(108506, 7769, 'Bodycam - Registros Criminosos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tFU3qJbC5whuovMjIfUEAZlY91U.jpg'),
(108507, 7769, 'Bodycam - Registros Criminosos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bWSaqFott41Tpfj2dKSq1CRJj4f.jpg'),
(108508, 7770, 'Bodycam - Registros Criminosos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108509, 7770, 'Bodycam - Registros Criminosos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108510, 7770, 'Bodycam - Registros Criminosos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108511, 7770, 'Bodycam - Registros Criminosos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108512, 7770, 'Bodycam - Registros Criminosos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108513, 7770, 'Bodycam - Registros Criminosos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108514, 7770, 'Bodycam - Registros Criminosos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108515, 7770, 'Bodycam - Registros Criminosos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108516, 7770, 'Bodycam - Registros Criminosos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108517, 7770, 'Bodycam - Registros Criminosos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108518, 7771, 'Bodycam - Registros Criminosos S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108519, 7771, 'Bodycam - Registros Criminosos S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108520, 7771, 'Bodycam - Registros Criminosos S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108521, 7771, 'Bodycam - Registros Criminosos S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108522, 7771, 'Bodycam - Registros Criminosos S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108523, 7771, 'Bodycam - Registros Criminosos S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108524, 7771, 'Bodycam - Registros Criminosos S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108525, 7771, 'Bodycam - Registros Criminosos S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108526, 7771, 'Bodycam - Registros Criminosos S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108527, 7771, 'Bodycam - Registros Criminosos S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108528, 7772, 'Bodycam - Registros Criminosos S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108529, 7772, 'Bodycam - Registros Criminosos S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108530, 7772, 'Bodycam - Registros Criminosos S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108531, 7772, 'Bodycam - Registros Criminosos S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108532, 7772, 'Bodycam - Registros Criminosos S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108533, 7772, 'Bodycam - Registros Criminosos S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108534, 7772, 'Bodycam - Registros Criminosos S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108535, 7772, 'Bodycam - Registros Criminosos S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108536, 7772, 'Bodycam - Registros Criminosos S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108537, 7772, 'Bodycam - Registros Criminosos S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108538, 7773, 'Bodycam - Registros Criminosos S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108539, 7773, 'Bodycam - Registros Criminosos S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108540, 7773, 'Bodycam - Registros Criminosos S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108541, 7773, 'Bodycam - Registros Criminosos S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108542, 7773, 'Bodycam - Registros Criminosos S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108543, 7773, 'Bodycam - Registros Criminosos S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108544, 7773, 'Bodycam - Registros Criminosos S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108545, 7773, 'Bodycam - Registros Criminosos S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108546, 7773, 'Bodycam - Registros Criminosos S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108547, 7773, 'Bodycam - Registros Criminosos S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1y8H5lmowJH4iVzNZGWAvggKf.jpg'),
(108548, 7774, 'Minha Babá é Uma Vampira S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTDSdlZRix8oGiSBiZHlu344cO0.jpg'),
(108549, 7774, 'Minha Babá é Uma Vampira S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xrKN4fanHrw4mUEqAtP2Lim2UpP.jpg'),
(108550, 7774, 'Minha Babá é Uma Vampira S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gD7jcPEJXg6dhm4USYMzL63tft0.jpg'),
(108551, 7774, 'Minha Babá é Uma Vampira S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rtMAHIVjoaF71e2sDAygKIR6yPd.jpg'),
(108552, 7774, 'Minha Babá é Uma Vampira S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wUJgBKbAVW9P3ueGg6Qh4Lwulno.jpg'),
(108553, 7774, 'Minha Babá é Uma Vampira S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qHdgwpkDZqiIasm5LyjkT6aR5ES.jpg'),
(108554, 7774, 'Minha Babá é Uma Vampira S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/RgCYk0VMdpNZ5e309n3xvf0URc.jpg'),
(108555, 7774, 'Minha Babá é Uma Vampira S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ompPhvzJ6PzMAyO9qdWeSfl9BpG.jpg'),
(108556, 7774, 'Minha Babá é Uma Vampira S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y3kTzgnlozwh78mSogvg3UkmOZc.jpg'),
(108557, 7774, 'Minha Babá é Uma Vampira S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8i7HsucpdbSh5aKPNdgHuDk2s3H.jpg'),
(108558, 7774, 'Minha Babá é Uma Vampira S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bs8oKIUdGXma1MQhBAYKcVX5XFg.jpg'),
(108559, 7774, 'Minha Babá é Uma Vampira S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nyfahZowLsGoDTRFpkByDEz6IjR.jpg'),
(108560, 7774, 'Minha Babá é Uma Vampira S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/223130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1zijbDpqUBBduD9KhxgbQ0tlDWF.jpg'),
(108561, 7775, 'Minha Babá é Uma Vampira S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lfaPy7cx3jevmCNkaVaUkC5Aqnj.jpg'),
(108562, 7775, 'Minha Babá é Uma Vampira S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zbQyYODHTiAu7gMc5hv9UdQad3T.jpg'),
(108563, 7775, 'Minha Babá é Uma Vampira S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j2iXuuZN3YzMMyLhtPlaVSf6C2J.jpg'),
(108564, 7775, 'Minha Babá é Uma Vampira S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k1dELItVlrc0Yr2kh8uEfWVHYnG.jpg'),
(108565, 7775, 'Minha Babá é Uma Vampira S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3aSzMjTqcAGAihG0AyJtV5yu8rj.jpg'),
(108566, 7775, 'Minha Babá é Uma Vampira S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lfiRahdEc75rMHMDz9ZQOumDZgt.jpg'),
(108567, 7775, 'Minha Babá é Uma Vampira S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/16F0BF5XAI3oInigHSSjhscWeNW.jpg'),
(108568, 7775, 'Minha Babá é Uma Vampira S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vPX3le9pIbBm5sXydneoYVkXwFx.jpg'),
(108569, 7775, 'Minha Babá é Uma Vampira S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sxC1KqH7x5baIHOzdErW5zKUl0J.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(108570, 7775, 'Minha Babá é Uma Vampira S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5XifV6jdLCWopUbqaewHKUnscDG.jpg'),
(108571, 7775, 'Minha Babá é Uma Vampira S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aqi80eW866rEB53Bc7ijNYy9MIm.jpg'),
(108572, 7775, 'Minha Babá é Uma Vampira S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iGudOkVM47VBZqgB9dJsWMbXwvb.jpg'),
(108573, 7775, 'Minha Babá é Uma Vampira S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/223143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtuVnpcoqolpcqoMOta7kj8IFCd.jpg'),
(108574, 7776, 'Impulse [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3H4jw4dzx6vqWvfYFUYody2ED0.jpg'),
(108575, 7776, 'Impulse [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8I8rco7LNDKF665qz48uyebf4pq.jpg'),
(108576, 7776, 'Impulse [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pWuFiN8hcYH9LIt67ZyscB1OPRY.jpg'),
(108577, 7776, 'Impulse [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8pdOGIBuIFI39qVzw394KE3VLI.jpg'),
(108578, 7776, 'Impulse [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9CmCenWbtGEBxoew7XgMikcoXUg.jpg'),
(108579, 7776, 'Impulse [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hN8SZRml69tDZ8BdJDmFqKQJ7yq.jpg'),
(108580, 7776, 'Impulse [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jp0G67wAgjhuoR1q3M64o3MoYJl.jpg'),
(108581, 7776, 'Impulse [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWlt1uuyQYKQd1gfkiGRBeX63H0.jpg'),
(108582, 7776, 'Impulse [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wdM6E4YWhKlEYiGHLnl6dGWtaCN.jpg'),
(108583, 7776, 'Impulse [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5p7FfuDrTXoCD3kMDsnSHGTePg1.jpg'),
(108584, 7777, 'Impulse [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1j6UjujA9HRnnz2ONqcFJEkhoyS.jpg'),
(108585, 7777, 'Impulse [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bisf5XxUPnpaHpf4kuZEtzeBMmd.jpg'),
(108586, 7777, 'Impulse [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sRfcGWGjKdgYlJLAAMRVFbD29oQ.jpg'),
(108587, 7777, 'Impulse [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xlMVnHMmvo1AYtbVHvfcTN1pdbu.jpg'),
(108588, 7777, 'Impulse [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sind46PbqUWT2s88DHWIZEesBVg.jpg'),
(108589, 7777, 'Impulse [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJaMdip7laPvg4nvdZDRS4z2u7v.jpg'),
(108590, 7777, 'Impulse [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yapyDBFD1NKANM3m7ymOPojdSBU.jpg'),
(108591, 7777, 'Impulse [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Y614TAiKueaIZIMNGIU7JaQUOh.jpg'),
(108592, 7777, 'Impulse [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6XOAaABYOzJjj5hKXP0DzqOu2YU.jpg'),
(108593, 7777, 'Impulse [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4LumSnfEnbpGkrikYNMA7jEyxvk.jpg'),
(108594, 7778, 'Finalmente Adultos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gNLrnxo9oCTTxbZktgpySGml34L.jpg'),
(108595, 7778, 'Finalmente Adultos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/butZM6bhgjLXtucHT0kUosczktv.jpg'),
(108596, 7778, 'Finalmente Adultos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Y8om6jDtyOrGb3jIxYHwXQ2ahY.jpg'),
(108597, 7778, 'Finalmente Adultos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJtQW0loEH5AeAZIEjzHhvlyf4X.jpg'),
(108598, 7778, 'Finalmente Adultos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGBkVrYnfa5fssKIz3O7X6nUmDo.jpg'),
(108599, 7778, 'Finalmente Adultos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wLiWRxXzLABZHBhln97q5bSlo34.jpg'),
(108600, 7778, 'Finalmente Adultos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nNSsoxogMa3jTuCgAvR7s2b400G.jpg'),
(108601, 7778, 'Finalmente Adultos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AiZgX21WGIJqhaI6nUdOplGIJGV.jpg'),
(108602, 7778, 'Finalmente Adultos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vIeInVwLNv5yB87QhfNR2V2todz.jpg'),
(108603, 7778, 'Finalmente Adultos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zgMcvgfgXc5wJrxaN0nejrbDpWH.jpg'),
(108604, 7778, 'Finalmente Adultos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wG4pEFxFRnqBqcwcwoG7Hxb7ypc.jpg'),
(108605, 7778, 'Finalmente Adultos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZBQfZWslhRkRqGl1DB7oxAElG9.jpg'),
(108606, 7778, 'Finalmente Adultos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nC58Qq6veELeU04AlZqb4gzd5Ku.jpg'),
(108607, 7779, 'Mr. Bean: A Série Animada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v2GalSg1QUN7pUKd474eIJl0YTz.jpg'),
(108608, 7779, 'Mr. Bean: A Série Animada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/23f8yJlxDNo89uhFDAoMS6WWayo.jpg'),
(108609, 7779, 'Mr. Bean: A Série Animada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wjsVfESzMNtvNd90bNJLte5EUSf.jpg'),
(108610, 7779, 'Mr. Bean: A Série Animada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBdoSfBwy7S3DF3AFCwmfoTWaUb.jpg'),
(108611, 7779, 'Mr. Bean: A Série Animada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hoUmLwy3E1Kjtof707sTLVp4nID.jpg'),
(108612, 7779, 'Mr. Bean: A Série Animada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7FBEdYEulaVbuhZVYLQyi7wSj4G.jpg'),
(108613, 7779, 'Mr. Bean: A Série Animada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v74b35v6zpz1HdyzuOW3RZlg8KH.jpg'),
(108614, 7779, 'Mr. Bean: A Série Animada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9bXMSeObmZW0DmixRcRIZOemKaF.jpg'),
(108615, 7779, 'Mr. Bean: A Série Animada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/10uZzA3b4tFTgsFK1E8ec5w79lQ.jpg'),
(108616, 7779, 'Mr. Bean: A Série Animada S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gywMIWvUbRJS1mTiSI5ErONvS8r.jpg'),
(108617, 7779, 'Mr. Bean: A Série Animada S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wjuxBddtHTinQ2oJyeKexFfaMu8.jpg'),
(108618, 7779, 'Mr. Bean: A Série Animada S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wMd2gP6WXgPV2y5DC2Su0bJ9fQE.jpg'),
(108619, 7779, 'Mr. Bean: A Série Animada S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/swH9DW7zg3Rcw7B6LTMIHUjOvkP.jpg'),
(108620, 7779, 'Mr. Bean: A Série Animada S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2jjsTMrMsSXXxoqV6SBLKKj3sB9.jpg'),
(108621, 7779, 'Mr. Bean: A Série Animada S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wE8XosDj5vBEuUY4YH8xAq3aQlP.jpg'),
(108622, 7779, 'Mr. Bean: A Série Animada S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pEUK4E3RszLvHxl04eukqSumS8k.jpg'),
(108623, 7779, 'Mr. Bean: A Série Animada S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8pUGYT8uUs5KOx2rjmiWVdYw6G5.jpg'),
(108624, 7779, 'Mr. Bean: A Série Animada S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nKntx2CX0LEhSNzqtwDbCOKY6GO.jpg'),
(108625, 7779, 'Mr. Bean: A Série Animada S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108626, 7779, 'Mr. Bean: A Série Animada S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108627, 7779, 'Mr. Bean: A Série Animada S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108628, 7779, 'Mr. Bean: A Série Animada S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108629, 7779, 'Mr. Bean: A Série Animada S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/222993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108630, 7779, 'Mr. Bean: A Série Animada S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/222994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108631, 7779, 'Mr. Bean: A Série Animada S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/222995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108632, 7779, 'Mr. Bean: A Série Animada S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/222996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108633, 7779, 'Mr. Bean: A Série Animada S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/222997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108634, 7779, 'Mr. Bean: A Série Animada S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/222998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108635, 7779, 'Mr. Bean: A Série Animada S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/222999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108636, 7779, 'Mr. Bean: A Série Animada S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/223000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108637, 7779, 'Mr. Bean: A Série Animada S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/223001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108638, 7779, 'Mr. Bean: A Série Animada S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/223002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108639, 7779, 'Mr. Bean: A Série Animada S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/223003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108640, 7779, 'Mr. Bean: A Série Animada S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/223004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108641, 7779, 'Mr. Bean: A Série Animada S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/223005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108642, 7779, 'Mr. Bean: A Série Animada S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/223006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108643, 7779, 'Mr. Bean: A Série Animada S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/223007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108644, 7779, 'Mr. Bean: A Série Animada S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/223008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108645, 7779, 'Mr. Bean: A Série Animada S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/223009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108646, 7779, 'Mr. Bean: A Série Animada S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/223010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108647, 7779, 'Mr. Bean: A Série Animada S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/223011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108648, 7779, 'Mr. Bean: A Série Animada S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/223012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108649, 7779, 'Mr. Bean: A Série Animada S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/223013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108650, 7779, 'Mr. Bean: A Série Animada S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/223014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108651, 7779, 'Mr. Bean: A Série Animada S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/223015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108652, 7779, 'Mr. Bean: A Série Animada S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/223016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108653, 7779, 'Mr. Bean: A Série Animada S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/223017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108654, 7779, 'Mr. Bean: A Série Animada S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/223018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108655, 7779, 'Mr. Bean: A Série Animada S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/223019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108656, 7780, 'Mr. Bean: A Série Animada S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5q9NXeOBuZenxTmD5ZqMwWWxtwj.jpg'),
(108657, 7780, 'Mr. Bean: A Série Animada S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uLgVYXKCJWc4tpOciw58OAAo2wL.jpg'),
(108658, 7780, 'Mr. Bean: A Série Animada S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ctjOmhNemWtsyLpeO2e2YIEPYG.jpg'),
(108659, 7780, 'Mr. Bean: A Série Animada S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tcbY7x2SgrouuQfy5MkATeOIrSy.jpg'),
(108660, 7780, 'Mr. Bean: A Série Animada S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b9ceNKPHQlQNxirIEk9klNqfBrb.jpg'),
(108661, 7780, 'Mr. Bean: A Série Animada S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3AhXRn9N8FKCU8isZ013EAvCDyG.jpg'),
(108662, 7780, 'Mr. Bean: A Série Animada S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1wu9WzMmUDIYSkRbtLTYUzWI2U.jpg'),
(108663, 7780, 'Mr. Bean: A Série Animada S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rs7Fpy2H3gXwIMsQPv7O5jcnIat.jpg'),
(108664, 7780, 'Mr. Bean: A Série Animada S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QqjcUuUB8G2FU7pQQWSpI78or3.jpg'),
(108665, 7780, 'Mr. Bean: A Série Animada S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9y0EwSnKDksFKqosZaeE3YH3DUD.jpg'),
(108666, 7780, 'Mr. Bean: A Série Animada S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gTSUpwZ2axSUV1Py43mN3xYZmKl.jpg'),
(108667, 7780, 'Mr. Bean: A Série Animada S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2zt2jpRBW4YO4G0YjAyfNcocCig.jpg'),
(108668, 7780, 'Mr. Bean: A Série Animada S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/223032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/109UMJTXTPAUY1PWXhu1LSFYNYa.jpg'),
(108669, 7780, 'Mr. Bean: A Série Animada S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/223033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h2bY8jd9JUu0FfEZw07uncXAOWv.jpg'),
(108670, 7780, 'Mr. Bean: A Série Animada S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/223034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2B65obJwEJA8KcF3BDYOnuBwGL.jpg'),
(108671, 7780, 'Mr. Bean: A Série Animada S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/223035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ixeQzAaSIPrueI7CVIOA8VD0cho.jpg'),
(108672, 7780, 'Mr. Bean: A Série Animada S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/223036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108673, 7780, 'Mr. Bean: A Série Animada S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/223037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108674, 7780, 'Mr. Bean: A Série Animada S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/223038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108675, 7780, 'Mr. Bean: A Série Animada S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/223039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108676, 7780, 'Mr. Bean: A Série Animada S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/223040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108677, 7780, 'Mr. Bean: A Série Animada S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/223041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108678, 7780, 'Mr. Bean: A Série Animada S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/223042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108679, 7780, 'Mr. Bean: A Série Animada S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/223043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108680, 7780, 'Mr. Bean: A Série Animada S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/223044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108681, 7780, 'Mr. Bean: A Série Animada S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/223045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108682, 7780, 'Mr. Bean: A Série Animada S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/223046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108683, 7780, 'Mr. Bean: A Série Animada S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/223047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108684, 7780, 'Mr. Bean: A Série Animada S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/223048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108685, 7780, 'Mr. Bean: A Série Animada S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/223049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108686, 7780, 'Mr. Bean: A Série Animada S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/223050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108687, 7780, 'Mr. Bean: A Série Animada S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/223051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108688, 7780, 'Mr. Bean: A Série Animada S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/223052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108689, 7780, 'Mr. Bean: A Série Animada S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/223053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108690, 7780, 'Mr. Bean: A Série Animada S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/223054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108691, 7780, 'Mr. Bean: A Série Animada S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/223055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108692, 7780, 'Mr. Bean: A Série Animada S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/223056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108693, 7780, 'Mr. Bean: A Série Animada S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/223057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108694, 7780, 'Mr. Bean: A Série Animada S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/223058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108695, 7780, 'Mr. Bean: A Série Animada S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/223059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108696, 7780, 'Mr. Bean: A Série Animada S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/223060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108697, 7780, 'Mr. Bean: A Série Animada S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/223061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108698, 7780, 'Mr. Bean: A Série Animada S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/223062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108699, 7780, 'Mr. Bean: A Série Animada S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/223063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108700, 7780, 'Mr. Bean: A Série Animada S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/223064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108701, 7780, 'Mr. Bean: A Série Animada S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/223065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108702, 7780, 'Mr. Bean: A Série Animada S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/223066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108703, 7780, 'Mr. Bean: A Série Animada S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/223067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108704, 7780, 'Mr. Bean: A Série Animada S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/223068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108705, 7780, 'Mr. Bean: A Série Animada S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/223069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108706, 7780, 'Mr. Bean: A Série Animada S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/223070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108707, 7780, 'Mr. Bean: A Série Animada S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/223071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108708, 7781, 'Mr. Bean: A Série Animada S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/223072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ftQWrEgMrUIekUXqFbJElGF8zfY.jpg'),
(108709, 7781, 'Mr. Bean: A Série Animada S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/223073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zmT4zYX0tOdwbntB2AGgVuS8Yuf.jpg'),
(108710, 7781, 'Mr. Bean: A Série Animada S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/223074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cGc8wsxsANwaNy4Hw4m6PB2cU7y.jpg'),
(108711, 7781, 'Mr. Bean: A Série Animada S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/223075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gy7gXTVUH9kItA9y5R9RDHY3nUY.jpg'),
(108712, 7781, 'Mr. Bean: A Série Animada S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/223076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1yBnmkEiIvPx8t48WDEjTRqq05o.jpg'),
(108713, 7781, 'Mr. Bean: A Série Animada S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/223077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t59sis7M84Ej8GWdaqX2hBYGvg5.jpg'),
(108714, 7781, 'Mr. Bean: A Série Animada S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/223078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ZxhS67iPLpIBQzW7zTEqoqGJA.jpg'),
(108715, 7781, 'Mr. Bean: A Série Animada S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/223079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rR7lJbFlL5726WneuaLaKv1HnhN.jpg'),
(108716, 7781, 'Mr. Bean: A Série Animada S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/223080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/itiSFZpBhtE1c8ws87tEQKLQsvj.jpg'),
(108717, 7781, 'Mr. Bean: A Série Animada S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/223081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iX8cSbBKGuBGEwLMk7lc61NIY9x.jpg'),
(108718, 7781, 'Mr. Bean: A Série Animada S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/223082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hrExrCTXivOAH3TJWognU7uN6FC.jpg'),
(108719, 7781, 'Mr. Bean: A Série Animada S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/223083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dureHq1QO2xns0n0tfAeOzRsRWy.jpg'),
(108720, 7781, 'Mr. Bean: A Série Animada S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/223084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fCSraUrJIySTwXvK0MqdV9VNH2E.jpg'),
(108721, 7781, 'Mr. Bean: A Série Animada S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/223085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2BKUBF5cAV3fY9CFrjVjXtfW889.jpg'),
(108722, 7781, 'Mr. Bean: A Série Animada S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/223086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wYBEYU73xc4PruKZy7p2dOFttN3.jpg'),
(108723, 7781, 'Mr. Bean: A Série Animada S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/223087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a26OhGWOStd5DgtpjB4GGhp1hg.jpg'),
(108724, 7781, 'Mr. Bean: A Série Animada S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/223088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ebs0QhdFsgVYWlSum2vjmAJLvmY.jpg'),
(108725, 7781, 'Mr. Bean: A Série Animada S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/223089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aeoqiBhxMbinyx3RIL9a2H8dnuN.jpg'),
(108726, 7781, 'Mr. Bean: A Série Animada S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/223090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108727, 7781, 'Mr. Bean: A Série Animada S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/223091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108728, 7781, 'Mr. Bean: A Série Animada S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/223092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108729, 7781, 'Mr. Bean: A Série Animada S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/223093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108730, 7781, 'Mr. Bean: A Série Animada S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/223094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108731, 7781, 'Mr. Bean: A Série Animada S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/223095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108732, 7781, 'Mr. Bean: A Série Animada S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/223096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108733, 7781, 'Mr. Bean: A Série Animada S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/223097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1V2PSez4pNZ9a4Bbomm7KZiQJ44.jpg'),
(108734, 7782, 'Além do Guarda-Roupa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/la05C5Aoot5xB31hEaxwacPGald.jpg'),
(108735, 7782, 'Além do Guarda-Roupa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/la05C5Aoot5xB31hEaxwacPGald.jpg'),
(108736, 7782, 'Além do Guarda-Roupa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/la05C5Aoot5xB31hEaxwacPGald.jpg'),
(108737, 7782, 'Além do Guarda-Roupa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/la05C5Aoot5xB31hEaxwacPGald.jpg'),
(108738, 7782, 'Além do Guarda-Roupa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/la05C5Aoot5xB31hEaxwacPGald.jpg'),
(108739, 7782, 'Além do Guarda-Roupa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/la05C5Aoot5xB31hEaxwacPGald.jpg'),
(108740, 7782, 'Além do Guarda-Roupa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/la05C5Aoot5xB31hEaxwacPGald.jpg'),
(108741, 7782, 'Além do Guarda-Roupa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/la05C5Aoot5xB31hEaxwacPGald.jpg'),
(108742, 7782, 'Além do Guarda-Roupa S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230739.mp4', 'http://image.tmdb.org/t/p/w1280/nzDAqjyQ3G49DlLSzCnEfbcCUHQ.jpg'),
(108743, 7782, 'Além do Guarda-Roupa S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230740.mp4', 'http://image.tmdb.org/t/p/w1280/cH8alH0Wl3Jc6kFo9JfrhpW2uyf.jpg'),
(108744, 7783, 'Barão 40 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCFvYAbhkyLSJfiObHgQ5eUHqnf.jpg'),
(108745, 7783, 'Barão 40 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZqC9W9TjcUhngsMgUM1cJttetC.jpg'),
(108746, 7783, 'Barão 40 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gjxnOZZzHsTPtVKszJsVnN6Dezf.jpg'),
(108747, 7783, 'Barão 40 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ZhDswnR6XULA28upuhJu3iFerF.jpg'),
(108748, 7784, 'Desculpas Pelo Incômodo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d3zygYcBGbX8uT62aF5iFc8TWZQ.jpg'),
(108749, 7784, 'Desculpas Pelo Incômodo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d8GtHlPW5hwR5Q8u0m9BN4znTIZ.jpg'),
(108750, 7784, 'Desculpas Pelo Incômodo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yEfbsF9tXjxu1fhPEOVtRkpn95x.jpg'),
(108751, 7784, 'Desculpas Pelo Incômodo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mTgTFSI89SZ8P6bQJdFEfaeU8sJ.jpg'),
(108752, 7784, 'Desculpas Pelo Incômodo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zU8xaBtNAl5O2bLhYiiPx7OxItp.jpg'),
(108753, 7784, 'Desculpas Pelo Incômodo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6G0bZRbbstXYwDFHfIFhRpMvOWL.jpg'),
(108754, 7785, 'Desculpas Pelo Incômodo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dvHuhsdfPRVIo95DXU0ZVdM2igg.jpg'),
(108755, 7785, 'Desculpas Pelo Incômodo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wgKSIR10O5ovNK3gFMv1U1g1mVS.jpg'),
(108756, 7785, 'Desculpas Pelo Incômodo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2zIUehfH0tzT8YG7tYabemBy1dF.jpg'),
(108757, 7785, 'Desculpas Pelo Incômodo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uBycqHSvVR06klR69WIW7p7m7Ub.jpg'),
(108758, 7785, 'Desculpas Pelo Incômodo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/br4OOPmLpJloJ83wLFOzwKRfLsu.jpg'),
(108759, 7785, 'Desculpas Pelo Incômodo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nujDKQ1tMsgwpct8sMKLyeeHzaP.jpg'),
(108760, 7786, 'Justified: Cidade Primitiva S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yqsVbBttq84L1J2GMKTs6FbZIJI.jpg'),
(108761, 7786, 'Justified: Cidade Primitiva S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/peiXOvM5ApS7zdy703tITMszTK7.jpg'),
(108762, 7786, 'Justified: Cidade Primitiva S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233463.mp4', 'http://image.tmdb.org/t/p/w1280/rYEfdkRJInmtUUxY72YXyEfJFD8.jpg'),
(108763, 7786, 'Justified: Cidade Primitiva S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233464.mp4', 'http://image.tmdb.org/t/p/w1280/tClYz1EjI79iSPgYLdWbVqlQKUz.jpg'),
(108764, 7786, 'Justified: Cidade Primitiva S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233465.mp4', 'http://image.tmdb.org/t/p/w1280/qmp4dYOgNG34Ym3BJ8a6zQveXwS.jpg'),
(108765, 7786, 'Justified: Cidade Primitiva S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233466.mp4', 'http://image.tmdb.org/t/p/w1280/tGkRj7Jkypgopit6vTxNuzS3qF9.jpg'),
(108766, 7786, 'Justified: Cidade Primitiva S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233467.mp4', 'http://image.tmdb.org/t/p/w1280/mPRXnGqwbW1rnwkWP6t6uPy7CvK.jpg'),
(108767, 7786, 'Justified: Cidade Primitiva S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233468.mp4', 'http://image.tmdb.org/t/p/w1280/oM2JB54fdnjmw2aO2auCZa3u9uv.jpg'),
(108768, 7787, 'O Vidente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jmsADORrXLe7EqCV2vA4PWQ3Bjj.jpg'),
(108769, 7787, 'O Vidente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qNfNsUXAUnoJmjc2RKyyhLmLmOw.jpg'),
(108770, 7787, 'O Vidente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/54uWkC1VeSfiN6zmTPWyauCTlMe.jpg'),
(108771, 7787, 'O Vidente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7poAUOzUnBG8kF6mH9vOfTtwujN.jpg'),
(108772, 7787, 'O Vidente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqBYQBHWQKd47fnnAKZvrd1xqyH.jpg'),
(108773, 7787, 'O Vidente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ikaJAeWAul6N2GELVDV5gQLDQGD.jpg'),
(108774, 7787, 'O Vidente S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMVsnvjBAVTUcODyav4RQQBRgKM.jpg'),
(108775, 7787, 'O Vidente S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ehJBKLfXmcnol3M1uyZmXKuR3Gq.jpg'),
(108776, 7787, 'O Vidente S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yO9YwCfCu4QyL5iGlbHb6U8F8HX.jpg'),
(108777, 7787, 'O Vidente S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ymxQk5to3tokVd1xjY8LU395UB.jpg'),
(108778, 7787, 'O Vidente S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qREU1iiHIGukC4SPXtJvrrWCpL3.jpg'),
(108779, 7787, 'O Vidente S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c6i9urJzHdP1yqQWBU9fEQK2WKn.jpg'),
(108780, 7787, 'O Vidente S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7PNZrwPImJSOHuEbVY79nlXOzj8.jpg'),
(108781, 7788, 'O Vidente S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bmnNEKWR5Gq30D5jjkVgSW4xL6Z.jpg'),
(108782, 7788, 'O Vidente S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3LvqIWLUelmapNGltKb0pp8UoJq.jpg'),
(108783, 7788, 'O Vidente S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aA6IsRbxRNZWxIiRNIqschxMyAN.jpg'),
(108784, 7788, 'O Vidente S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6VegZkNnPEeRe689u40Lb5L6jpg.jpg'),
(108785, 7788, 'O Vidente S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8p01swOGeGmGQvlmp59a2Iu8GNC.jpg'),
(108786, 7788, 'O Vidente S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p5eSKPyRG4Lrj9xdQtEmcE3LD7h.jpg'),
(108787, 7788, 'O Vidente S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nsniXr0oNHTTwbw8Y5H5pLTXkRf.jpg'),
(108788, 7788, 'O Vidente S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3EmK4AH9pGCxpbeOs48UXHTslej.jpg'),
(108789, 7788, 'O Vidente S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/96XPCaiO30HNSujRWO1eP0sLtxG.jpg'),
(108790, 7788, 'O Vidente S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/CdElA1BxlZESeC03JNGe8cFSIt.jpg'),
(108791, 7788, 'O Vidente S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8VK5lr0zFhRHx7TnzM2WOpvQDRg.jpg'),
(108792, 7788, 'O Vidente S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z6WLXd0ZXI8ElDIbzaNEowzUA5Y.jpg'),
(108793, 7788, 'O Vidente S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m4jt14rqMphLr6mVdBvUt2bomT1.jpg'),
(108794, 7788, 'O Vidente S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Rh6wscpyGRPloiI4QtR2KuBQDD.jpg'),
(108795, 7788, 'O Vidente S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/htx6UQOsgfXVMRtEcs9SmKGWLbX.jpg'),
(108796, 7788, 'O Vidente S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A1Rp1dMBoMfyeLf7oWvSuW0WYHX.jpg'),
(108797, 7788, 'O Vidente S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o75AbUYwT6QAqcxWZTpRAjZm7BI.jpg'),
(108798, 7788, 'O Vidente S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Kx7MyDWdD76T4GnvxFxxOkkm0j.jpg'),
(108799, 7788, 'O Vidente S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uG2WfPu7NmrRQI8PIWQzoYQy9uA.jpg'),
(108800, 7789, 'O Vidente S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fWVE1ojcGudpMXwpxbwcKmuVuPF.jpg'),
(108801, 7789, 'O Vidente S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fCCPy1LY3K1NfTWTJIXfpouzbhu.jpg'),
(108802, 7789, 'O Vidente S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jAfyd1ybZjInsAGBQTiPUw8EcHw.jpg'),
(108803, 7789, 'O Vidente S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCjlxUYWQD6aBnUbFoTuYqqKLdY.jpg'),
(108804, 7789, 'O Vidente S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dy5AGVJAmk67L8hM7dB7d60kqTH.jpg'),
(108805, 7789, 'O Vidente S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gyJteFiHqZioTxGcZRLivovyzvK.jpg'),
(108806, 7789, 'O Vidente S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTeJL3v3yl3in2OiZ3wYBoZdL8v.jpg'),
(108807, 7789, 'O Vidente S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xBvFgpZ9SeYi3EC0wEKQgxvNmFv.jpg'),
(108808, 7789, 'O Vidente S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jxilvjbMahAdeDS6qJVZg23bRIa.jpg'),
(108809, 7789, 'O Vidente S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kbJ7Q2fbDwLsozHnbseb51thXYx.jpg'),
(108810, 7789, 'O Vidente S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tkjoHB5nOfKXO2tew8aK2fMfex9.jpg'),
(108811, 7789, 'O Vidente S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qMOwd1mY3T7zDi6qc8mNTODQxcI.jpg'),
(108812, 7790, 'O Vidente S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dLmjcihGCxliaNp1pdWm53ml6ef.jpg'),
(108813, 7790, 'O Vidente S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bJGkUMhpLMUxcLBkhsaUadniPkW.jpg'),
(108814, 7790, 'O Vidente S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Q0UAvjUBgkoDGjREjboHqTgiPH.jpg'),
(108815, 7790, 'O Vidente S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qR84CypR2GAsVUZQJrhg7FSN5gc.jpg'),
(108816, 7790, 'O Vidente S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tzBWv8wsnavUhVM03BT7PIeCVgE.jpg'),
(108817, 7790, 'O Vidente S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yeQGynIfGsLT9lBfAqYAruQOOdw.jpg'),
(108818, 7790, 'O Vidente S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3HWoAWk7m7XDY3F6lPaa7Tfe4DE.jpg'),
(108819, 7790, 'O Vidente S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ePLHshe0GImbClpykTJFyR1ZAAd.jpg'),
(108820, 7790, 'O Vidente S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8hVbhGvkxy3SRzprPUwa9kpljTB.jpg'),
(108821, 7790, 'O Vidente S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/91z8nUB6sLRBOSblh0JAQ3lNY9h.jpg'),
(108822, 7790, 'O Vidente S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9RyQnS7Cmb4UzaN1llUSS57ZXKY.jpg'),
(108823, 7790, 'O Vidente S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Gshg0s1Yo3kBEcMwlKVcUWeyRC.jpg'),
(108824, 7791, 'O Vidente S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lM091PMvDvPiCFCGnXuspCxx17r.jpg'),
(108825, 7791, 'O Vidente S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qGAT61QjEE04ciR2WnX26ToFLZo.jpg'),
(108826, 7791, 'O Vidente S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lTgu3M7h4K1RvU7ErAWGZrqoU9r.jpg'),
(108827, 7791, 'O Vidente S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lWm9TBmXYIJeydeDBICjNohIUK.jpg'),
(108828, 7791, 'O Vidente S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cirnEiBv2fEkbDy0ncyv1S0rThu.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(108829, 7791, 'O Vidente S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11vKYV3pu8ooHTRZG0t6MwlaXwJ.jpg'),
(108830, 7791, 'O Vidente S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s0KG8D0jVQNEJT0lqyjWN0n7dGU.jpg'),
(108831, 7791, 'O Vidente S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/16CaWMVfzMwa9mZwH3xuNmKXx8R.jpg'),
(108832, 7791, 'O Vidente S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kMTFjeUvrtpn6jQntDb7pXU6FGm.jpg'),
(108833, 7791, 'O Vidente S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sBAGdvNUycyQoGO7VO4lqf27ssu.jpg'),
(108834, 7791, 'O Vidente S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vxjmpizwQwcZa0eD1z9cdAoqC5g.jpg'),
(108835, 7792, 'O Vidente S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rzXNSvIfB1xwHxfuW57Y9QRIXFe.jpg'),
(108836, 7792, 'O Vidente S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p22XEP7IODKhMVtotyrZHa8Doop.jpg'),
(108837, 7792, 'O Vidente S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eN0fvaSfiRhM6FrxruWtP3SocuF.jpg'),
(108838, 7792, 'O Vidente S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cxdB0c23vT0QQd0dj3Cp6jAELyY.jpg'),
(108839, 7792, 'O Vidente S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lY8LsZVeENZKpoVWPXtheJ7bwxR.jpg'),
(108840, 7792, 'O Vidente S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mLuAHFDHmZudZ2xHxANuTOyewVY.jpg'),
(108841, 7792, 'O Vidente S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tVohYTznV8BlrdmBNx8GZap7kSU.jpg'),
(108842, 7792, 'O Vidente S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4I9F0qDSOo1ufkVutn64FJmV5mK.jpg'),
(108843, 7792, 'O Vidente S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AkLXlnCD8D9RBJLXug7sdt8rl6o.jpg'),
(108844, 7792, 'O Vidente S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/47fO0PzshxDXovTnr2wVwKm7ECa.jpg'),
(108845, 7792, 'O Vidente S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1BKpsNJ9yb4zDigg9Iq70d8jzJp.jpg'),
(108846, 7792, 'O Vidente S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/881SEXeSfhqaIXOTNYiuinwGxoX.jpg'),
(108847, 7792, 'O Vidente S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uI6LJSmcHnjSWa6XJP69xLWa82z.jpg'),
(108848, 7793, 'Super-Heroínas Da Equipe 4 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8RD65BQx1uSy5vjMkveiOL4ii6.jpg'),
(108849, 7793, 'Super-Heroínas Da Equipe 4 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8RD65BQx1uSy5vjMkveiOL4ii6.jpg'),
(108850, 7793, 'Super-Heroínas Da Equipe 4 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8RD65BQx1uSy5vjMkveiOL4ii6.jpg'),
(108851, 7793, 'Super-Heroínas Da Equipe 4 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8RD65BQx1uSy5vjMkveiOL4ii6.jpg'),
(108852, 7793, 'Super-Heroínas Da Equipe 4 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8RD65BQx1uSy5vjMkveiOL4ii6.jpg'),
(108853, 7793, 'Super-Heroínas Da Equipe 4 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8RD65BQx1uSy5vjMkveiOL4ii6.jpg'),
(108854, 7793, 'Super-Heroínas Da Equipe 4 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8RD65BQx1uSy5vjMkveiOL4ii6.jpg'),
(108855, 7793, 'Super-Heroínas Da Equipe 4 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8RD65BQx1uSy5vjMkveiOL4ii6.jpg'),
(108856, 7794, 'Super-Heroínas Da Equipe 4 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8RD65BQx1uSy5vjMkveiOL4ii6.jpg'),
(108857, 7794, 'Super-Heroínas Da Equipe 4 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8RD65BQx1uSy5vjMkveiOL4ii6.jpg'),
(108858, 7794, 'Super-Heroínas Da Equipe 4 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8RD65BQx1uSy5vjMkveiOL4ii6.jpg'),
(108859, 7794, 'Super-Heroínas Da Equipe 4 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8RD65BQx1uSy5vjMkveiOL4ii6.jpg'),
(108860, 7794, 'Super-Heroínas Da Equipe 4 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8RD65BQx1uSy5vjMkveiOL4ii6.jpg'),
(108861, 7794, 'Super-Heroínas Da Equipe 4 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8RD65BQx1uSy5vjMkveiOL4ii6.jpg'),
(108862, 7794, 'Super-Heroínas Da Equipe 4 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8RD65BQx1uSy5vjMkveiOL4ii6.jpg'),
(108863, 7794, 'Super-Heroínas Da Equipe 4 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d8RD65BQx1uSy5vjMkveiOL4ii6.jpg'),
(108864, 7795, 'Vicky e a Musa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kesX6QlujL0cSZJVwllD6XNo5kZ.jpg'),
(108865, 7795, 'Vicky e a Musa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gmTS5dvVmtp09N3gobOQh6V8KCA.jpg'),
(108866, 7795, 'Vicky e a Musa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t6k5yokONC5xBgmo7O04iBRhT1Y.jpg'),
(108867, 7795, 'Vicky e a Musa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vilSXnxtSu5Yer2ryyY1zN6YMNL.jpg'),
(108868, 7795, 'Vicky e a Musa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3hFaJHa9MAQ2rGfg0dho6sDuPmN.jpg'),
(108869, 7795, 'Vicky e a Musa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7LYINbcNk1HojhmLq1hQF6TSl8M.jpg'),
(108870, 7795, 'Vicky e a Musa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSLiEK4cbFWQEDGapRH9ijQM5PI.jpg'),
(108871, 7795, 'Vicky e a Musa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzjQaOCdXjpJRt1D0S83YJYQ8Ws.jpg'),
(108872, 7795, 'Vicky e a Musa S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzjQaOCdXjpJRt1D0S83YJYQ8Ws.jpg'),
(108873, 7795, 'Vicky e a Musa S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzjQaOCdXjpJRt1D0S83YJYQ8Ws.jpg'),
(108874, 7795, 'Vicky e a Musa S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzjQaOCdXjpJRt1D0S83YJYQ8Ws.jpg'),
(108875, 7795, 'Vicky e a Musa S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzjQaOCdXjpJRt1D0S83YJYQ8Ws.jpg'),
(108876, 7795, 'Vicky e a Musa S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzjQaOCdXjpJRt1D0S83YJYQ8Ws.jpg'),
(108877, 7796, 'Vicky e a Musa S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzjQaOCdXjpJRt1D0S83YJYQ8Ws.jpg'),
(108878, 7796, 'Vicky e a Musa S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzjQaOCdXjpJRt1D0S83YJYQ8Ws.jpg'),
(108879, 7796, 'Vicky e a Musa S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzjQaOCdXjpJRt1D0S83YJYQ8Ws.jpg'),
(108880, 7796, 'Vicky e a Musa S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzjQaOCdXjpJRt1D0S83YJYQ8Ws.jpg'),
(108881, 7796, 'Vicky e a Musa S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzjQaOCdXjpJRt1D0S83YJYQ8Ws.jpg'),
(108882, 7796, 'Vicky e a Musa S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzjQaOCdXjpJRt1D0S83YJYQ8Ws.jpg'),
(108883, 7796, 'Vicky e a Musa S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzjQaOCdXjpJRt1D0S83YJYQ8Ws.jpg'),
(108884, 7796, 'Vicky e a Musa S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzjQaOCdXjpJRt1D0S83YJYQ8Ws.jpg'),
(108885, 7796, 'Vicky e a Musa S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzjQaOCdXjpJRt1D0S83YJYQ8Ws.jpg'),
(108886, 7796, 'Vicky e a Musa S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzjQaOCdXjpJRt1D0S83YJYQ8Ws.jpg'),
(108887, 7796, 'Vicky e a Musa S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzjQaOCdXjpJRt1D0S83YJYQ8Ws.jpg'),
(108888, 7796, 'Vicky e a Musa S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzjQaOCdXjpJRt1D0S83YJYQ8Ws.jpg'),
(108889, 7796, 'Vicky e a Musa S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzjQaOCdXjpJRt1D0S83YJYQ8Ws.jpg'),
(108890, 7797, 'Sissi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249732.mp4', 'http://timg.bdta.pro/images/3c7fea39d997e0df3dda3e2c88e80776.jpg'),
(108891, 7797, 'Sissi S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249733.mp4', 'http://timg.bdta.pro/images/85f8a1f31e730384243447e8ef405d06.jpg'),
(108892, 7797, 'Sissi S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249734.mp4', 'http://timg.bdta.pro/images/d8e0f626e02e4c21c30c7bbe95a46518.jpg'),
(108893, 7797, 'Sissi S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249735.mp4', 'http://timg.bdta.pro/images/46ca523b885958979b5d733294c4a5eb.jpg'),
(108894, 7797, 'Sissi S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249736.mp4', 'http://timg.bdta.pro/images/d797461c3ce53d97d28f48ac242c4239.jpg'),
(108895, 7797, 'Sissi S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249737.mp4', 'http://timg.bdta.pro/images/5f9d3941c3148def2262bf26ff82e616.jpg'),
(108896, 7798, 'Sissi S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tf7iEHEmnJelr8gEZWAhkg3ErXz.jpg'),
(108897, 7798, 'Sissi S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tf7iEHEmnJelr8gEZWAhkg3ErXz.jpg'),
(108898, 7798, 'Sissi S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tf7iEHEmnJelr8gEZWAhkg3ErXz.jpg'),
(108899, 7798, 'Sissi S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tf7iEHEmnJelr8gEZWAhkg3ErXz.jpg'),
(108900, 7798, 'Sissi S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tf7iEHEmnJelr8gEZWAhkg3ErXz.jpg'),
(108901, 7798, 'Sissi S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tf7iEHEmnJelr8gEZWAhkg3ErXz.jpg'),
(108902, 7799, 'Go! Go! Cory Carson S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b7vdUC4CHCBT6VDTV3EurxTVCpR.jpg'),
(108903, 7799, 'Go! Go! Cory Carson S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k92gNcW5Qo1iaeTGValCxsHQUrj.jpg'),
(108904, 7799, 'Go! Go! Cory Carson S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rqhQ1iPz67KQBQebfRVnw4BHvG0.jpg'),
(108905, 7799, 'Go! Go! Cory Carson S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ANR6tCp8s2cCKDFE9rAtkRnJPi.jpg'),
(108906, 7799, 'Go! Go! Cory Carson S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lOFaG2nzQlHWN0IfbHbc2GOYVaD.jpg'),
(108907, 7799, 'Go! Go! Cory Carson S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iwNhpflJmQlBZOmYhXTXiyO32Ke.jpg'),
(108908, 7799, 'Go! Go! Cory Carson S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qTCQLxVdPUWUOfvMb6SYhY9Fpes.jpg'),
(108909, 7800, 'Go! Go! Cory Carson S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r3JLvgT3lmGwR6AhGNqwZpE9TuI.jpg'),
(108910, 7800, 'Go! Go! Cory Carson S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g5yJ89LqeIzhxg5AUETtbjg3aSO.jpg'),
(108911, 7800, 'Go! Go! Cory Carson S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ydFOqk3UMHuSiyuVRoi9NkDCRDw.jpg'),
(108912, 7800, 'Go! Go! Cory Carson S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mGYroLJIxNf2a9TI5tvPL9tDhAZ.jpg'),
(108913, 7800, 'Go! Go! Cory Carson S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sOLRXSPQulnBllb6s7XOuKXTX6A.jpg'),
(108914, 7800, 'Go! Go! Cory Carson S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3K3PqCyttOftlyOFwXkTZlV52kk.jpg'),
(108915, 7800, 'Go! Go! Cory Carson S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yfYyKMhsITWLgvfJe22dqkinJ7Q.jpg'),
(108916, 7801, 'Go! Go! Cory Carson S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/heeC6oBBfIfjYPGSd2Iyn4ewa1s.jpg'),
(108917, 7801, 'Go! Go! Cory Carson S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fSCsIxPgxarCnQhFILbzliSlghW.jpg'),
(108918, 7801, 'Go! Go! Cory Carson S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lXNCQZ6FJowEAVvsEHupeAw27P1.jpg'),
(108919, 7801, 'Go! Go! Cory Carson S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s9ZgWlh789axtDU59Cn7TaSzetq.jpg'),
(108920, 7801, 'Go! Go! Cory Carson S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vAlYVkRhyPHM9ahVwZzTs4Jy4Rn.jpg'),
(108921, 7801, 'Go! Go! Cory Carson S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJSjzctcRhKkVpVNajdILu9i7Z.jpg'),
(108922, 7801, 'Go! Go! Cory Carson S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzRiBriJ0VQ7c3i5gulwneOAJIu.jpg'),
(108923, 7802, 'Go! Go! Cory Carson S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJugNaWjCogyCgoRlOWlcy8k0RG.jpg'),
(108924, 7802, 'Go! Go! Cory Carson S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8e0PxjtGptdAydH4UXsHKOFMjUe.jpg'),
(108925, 7802, 'Go! Go! Cory Carson S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xqpD9VcgzqLsbQtAOQrd8Q7jr8U.jpg'),
(108926, 7802, 'Go! Go! Cory Carson S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5QQUi8s3vOSQEqu5eRkVEN9oBWi.jpg'),
(108927, 7802, 'Go! Go! Cory Carson S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xl8PwvTBp1x4d7lU2VfpLxiGVsn.jpg'),
(108928, 7802, 'Go! Go! Cory Carson S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e17gcVXMEyPDf0OeltImgPus4bq.jpg'),
(108929, 7802, 'Go! Go! Cory Carson S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gz9BAzm1AAw7ul8soDUsQPNj66g.jpg'),
(108930, 7803, 'Go! Go! Cory Carson S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/njqkqM0kmIyDFcXYb42iPy1ByDN.jpg'),
(108931, 7803, 'Go! Go! Cory Carson S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9TW2dumjKNrmk7KawV2W9YTJiQ.jpg'),
(108932, 7803, 'Go! Go! Cory Carson S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sibsv4zkwISsUZna0FN0Bb9ILIF.jpg'),
(108933, 7803, 'Go! Go! Cory Carson S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bbWImQWaTxADGT2VeX9KmevOdeR.jpg'),
(108934, 7803, 'Go! Go! Cory Carson S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pqntT2reUAvOVDEcekXovcbah5z.jpg'),
(108935, 7803, 'Go! Go! Cory Carson S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y7icv6YEwOWRQK3IuxcCkhGkvBL.jpg'),
(108936, 7803, 'Go! Go! Cory Carson S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bPfsmKvp2piMRIh8om8vVWHnOVC.jpg'),
(108937, 7803, 'Go! Go! Cory Carson S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4lnFhBp7onHWJOX4PRsntYrGetY.jpg'),
(108938, 7803, 'Go! Go! Cory Carson S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mkHT6mG0wEE8MNSlxfzZhMFPPGd.jpg'),
(108939, 7803, 'Go! Go! Cory Carson S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/80LQGlFuj1KRJPO9okFH46btzaQ.jpg'),
(108940, 7803, 'Go! Go! Cory Carson S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5MyuznYDQ1YMPjZ4Zrs6sOhHyQe.jpg'),
(108941, 7803, 'Go! Go! Cory Carson S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vWSfhuqgajTdWJXI0Kn5HkM2cVb.jpg'),
(108942, 7803, 'Go! Go! Cory Carson S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bnJWykUulajeQb9iVRQrIuSBPcW.jpg'),
(108943, 7803, 'Go! Go! Cory Carson S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ljQi8PKstkWYzQDZVQXZqSIaQLA.jpg'),
(108944, 7803, 'Go! Go! Cory Carson S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ly2DgcMkxgNPtdw0IWsrQeAljdQ.jpg'),
(108945, 7803, 'Go! Go! Cory Carson S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vKLqzTBqXXy3VwApBjoQO8MNxQH.jpg'),
(108946, 7803, 'Go! Go! Cory Carson S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wqiVkQwybid3p9RNo6Hzo4o3cBj.jpg'),
(108947, 7804, 'Go! Go! Cory Carson S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oP0S0q33rizpTg5Si5z4YZKpl79.jpg'),
(108948, 7804, 'Go! Go! Cory Carson S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWIkbWEIB764cnoFLIwhXrjZKRR.jpg'),
(108949, 7804, 'Go! Go! Cory Carson S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A66kAvAowCCg2gdUwMN0tPY7yMj.jpg'),
(108950, 7804, 'Go! Go! Cory Carson S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ibJsk1uWeHn6NTiygdwXBQjEIMo.jpg'),
(108951, 7804, 'Go! Go! Cory Carson S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pcUUOZEuQBFx5gNAJlX4nVG03Yz.jpg'),
(108952, 7804, 'Go! Go! Cory Carson S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d2dm03bKfSVXMF0a4lqrB58Tnln.jpg'),
(108953, 7804, 'Go! Go! Cory Carson S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jD9U2AQZtIf44snTgMQLnIuUJA.jpg'),
(108954, 7804, 'Go! Go! Cory Carson S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLzSR6mjKlx1wY4OSH7yelGY6rU.jpg'),
(108955, 7804, 'Go! Go! Cory Carson S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bU0Qeujl0cMddmrISOvZ5sanamb.jpg'),
(108956, 7804, 'Go! Go! Cory Carson S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lv9wmKE1dGX56cKnWCaosD89OLA.jpg'),
(108957, 7804, 'Go! Go! Cory Carson S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Dv2rmx89gO83YfuypcsxXmY3CI.jpg'),
(108958, 7804, 'Go! Go! Cory Carson S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l3TL7o1dwRuRk2Wr5TV6ayPZKyb.jpg'),
(108959, 7804, 'Go! Go! Cory Carson S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ihAtsAiFTBkM8KPrRaNjD6EBdxa.jpg'),
(108960, 7804, 'Go! Go! Cory Carson S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gBgaN2XbjziljAVrSMJ52cE08lp.jpg'),
(108961, 7804, 'Go! Go! Cory Carson S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3m7xbbNS7NCT7rQSG5MS2BHM0xH.jpg'),
(108962, 7804, 'Go! Go! Cory Carson S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hDZKJUGTa9XQmTTEorEOzAIdzza.jpg'),
(108963, 7804, 'Go! Go! Cory Carson S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/infJQjVqTOL4rkJmvNtkUqxt8hc.jpg'),
(108964, 7804, 'Go! Go! Cory Carson S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iaL0feaxxSurBXJmAPfjiQ44CsC.jpg'),
(108965, 7805, 'Negociador S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uxPQOefwkQvKOOSP2aDFFWLnD9R.jpg'),
(108966, 7805, 'Negociador S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bIvv7oUo5w1AmaWP7rTWbQ2oYZZ.jpg'),
(108967, 7805, 'Negociador S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6DZvdFwMcFFXQCiQhh9etIx9bAa.jpg'),
(108968, 7805, 'Negociador S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hWLH4MoBhyu9NB4vVhdt7FuTmfk.jpg'),
(108969, 7805, 'Negociador S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lJenJOPZTCvVEuKaJgnHyS1Qzyz.jpg'),
(108970, 7805, 'Negociador S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tHweeFM4SKlAvZ1hVrHPvCOY3TK.jpg'),
(108971, 7805, 'Negociador S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/noFQLvekrKLbb9qCy9TewnDwJn5.jpg'),
(108972, 7805, 'Negociador S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3gZWfomaE1Bb8Vr1tDYhG3FqafY.jpg'),
(108973, 7806, 'O Mundo de Greg S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/I2mwm8KhhQum75v7aANTiQweBT.jpg'),
(108974, 7806, 'O Mundo de Greg S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aCgsx4IFT6Ixn7uv35CFpqD20df.jpg'),
(108975, 7806, 'O Mundo de Greg S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mF1OnVVVwC9uYLEYjxXpana2Caq.jpg'),
(108976, 7806, 'O Mundo de Greg S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dySXEcJ98RvCkAzghouxk9TfD5o.jpg'),
(108977, 7806, 'O Mundo de Greg S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mOiTQiL33xLr2ECIftFSa2a0eQ7.jpg'),
(108978, 7806, 'O Mundo de Greg S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tcP3I9BnPXcLwr6RNXaA4XoATIA.jpg'),
(108979, 7806, 'O Mundo de Greg S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nGVH9587CHjIshSyoObBlcgkYV9.jpg'),
(108980, 7806, 'O Mundo de Greg S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vrHzFETfpaYYPNTJIxwElA863n9.jpg'),
(108981, 7806, 'O Mundo de Greg S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7BnNfLFukEYMj9jhetr2jCTxcxy.jpg'),
(108982, 7806, 'O Mundo de Greg S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/clM3vllr2RJ4Pi8fu7cpWgcgQKO.jpg'),
(108983, 7806, 'O Mundo de Greg S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLfgWxesUEsI0k6rTPpN7PfF1Wq.jpg'),
(108984, 7806, 'O Mundo de Greg S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/saHMg9izw912O9YZU5O4K5Kzxvw.jpg'),
(108985, 7806, 'O Mundo de Greg S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ccP7rbxOx0riy9T0KySImeacbNx.jpg'),
(108986, 7806, 'O Mundo de Greg S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/221957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bRL9zRkfcBILRtmESVAMs4AZNIq.jpg'),
(108987, 7806, 'O Mundo de Greg S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/221958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/19FtYQ5GzJWIu3Nr8UZpRKTV0ty.jpg'),
(108988, 7806, 'O Mundo de Greg S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/221959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tS0JKVT6SHadgI7TJeoGCr56YiR.jpg'),
(108989, 7806, 'O Mundo de Greg S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/221960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFKyV8dcdDodVsJe8lPgrEGQijA.jpg'),
(108990, 7806, 'O Mundo de Greg S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/221961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9zKOpB7Osi1GLcy8EPEuTS9w9c6.jpg'),
(108991, 7806, 'O Mundo de Greg S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/221962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5TmmVCtmNARtd8auaqFHApwYUiF.jpg'),
(108992, 7806, 'O Mundo de Greg S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/221963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wiwhSaqZULeB1PDMCw6o0z67aCt.jpg'),
(108993, 7806, 'O Mundo de Greg S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/221964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jiGiH7JRhrepJEjtsDYH699d9wl.jpg'),
(108994, 7806, 'O Mundo de Greg S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/221965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jKVWHY1dhWcSaoM6ec8ERNGBv7T.jpg'),
(108995, 7806, 'O Mundo de Greg S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/221966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nG1CxsgYgS75cleZfZmVpUTm2sX.jpg'),
(108996, 7806, 'O Mundo de Greg S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/221967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9dXiczrNI3Hgy4CcVLWza9LkJWq.jpg'),
(108997, 7806, 'O Mundo de Greg S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/221968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qzcB0rVmeNVbrAzxIucbvOPj0lS.jpg'),
(108998, 7806, 'O Mundo de Greg S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/221969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yIPcPokEuRmSGXkoPDCRbrJkV9Y.jpg'),
(108999, 7806, 'O Mundo de Greg S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/221970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hjo9yOc5Bm2BxVyoCZ8KolTY3xo.jpg'),
(109000, 7806, 'O Mundo de Greg S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/221971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a5aHntjjozL4SYvvkpiQiKUCsPJ.jpg'),
(109001, 7806, 'O Mundo de Greg S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/221972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qt0vT4Dq1cmC1dR8gDI2s7e3LXw.jpg'),
(109002, 7806, 'O Mundo de Greg S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/221973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qShNtcNGwqvESPW5H8wmu0KMCU4.jpg'),
(109003, 7806, 'O Mundo de Greg S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/221974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eCRQtrZdvgOmb56dBg2SDpfY1N6.jpg'),
(109004, 7806, 'O Mundo de Greg S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/221975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vN7jKIvQsoxXaTImPvD5W3nDVZB.jpg'),
(109005, 7806, 'O Mundo de Greg S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/221976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hga1ye9Ya3E14lhi6ajG3g1ky01.jpg'),
(109006, 7806, 'O Mundo de Greg S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/221977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bnuWJmqflwKTap8j2DydXt1LpJb.jpg'),
(109007, 7806, 'O Mundo de Greg S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/221978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Oi2SOMDkmK0tF3iQo35WLrNMer.jpg'),
(109008, 7806, 'O Mundo de Greg S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/221979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ftjTX75OJYGED2KojZcLmLPvGEz.jpg'),
(109009, 7806, 'O Mundo de Greg S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/221980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cBPTwZ4KykIArxcL3ZYAYg9KU6r.jpg'),
(109010, 7806, 'O Mundo de Greg S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/221981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xrNO85fvnyx5Vmzj6cwM9SP6VwB.jpg'),
(109011, 7806, 'O Mundo de Greg S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/221982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kEwErsEYDZx4tEsFC0Uvvzei9NY.jpg'),
(109012, 7806, 'O Mundo de Greg S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/221983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uEwBOcYZenBdAgJiGUYk5GMBATo.jpg'),
(109013, 7807, 'O Mundo de Greg S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aLokIGAOWDxshI4IaxFC8AMoQae.jpg'),
(109014, 7807, 'O Mundo de Greg S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yaW9faNW9LdKhkp3dJbCOTZByQ9.jpg'),
(109015, 7807, 'O Mundo de Greg S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lebbwJ5NbwP9L7HCJZvDuLeW2Gf.jpg'),
(109016, 7807, 'O Mundo de Greg S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uCeUn3clSoNEkU2eS7wOYc6YaEn.jpg'),
(109017, 7807, 'O Mundo de Greg S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eomsmp6BGRrmGSIQWyCjA6177M6.jpg'),
(109018, 7807, 'O Mundo de Greg S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t1u4PLdebmSeF9PW11aLpFyxS8x.jpg'),
(109019, 7807, 'O Mundo de Greg S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6GkLxORNwmbayCgKzRNVd9llHLg.jpg'),
(109020, 7807, 'O Mundo de Greg S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hNoDATeltzLpqPu3ivrx1EGM7Wu.jpg'),
(109021, 7807, 'O Mundo de Greg S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1dygqRhTqIRrzJGKZfR10rMq4R.jpg'),
(109022, 7807, 'O Mundo de Greg S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dNC6y8XZjiRr14esgvR913atgyx.jpg'),
(109023, 7807, 'O Mundo de Greg S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kLV1s0MpKsJCpa8RwvBuI8XaRRw.jpg'),
(109024, 7807, 'O Mundo de Greg S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a7LrzEK1tPJ9nIv3TfCqW2k9DRm.jpg'),
(109025, 7807, 'O Mundo de Greg S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5jnG6tF6L5nHvwgx0giIYtCTOct.jpg'),
(109026, 7807, 'O Mundo de Greg S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/221997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bPhRRMO9wpY9VttriyELATvfq9D.jpg'),
(109027, 7807, 'O Mundo de Greg S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/221998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHC2uV7hTa9YhfXmBh94PPABwum.jpg'),
(109028, 7807, 'O Mundo de Greg S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/221999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUX3lgYOYmMFzOVKlDtVrZPCXu5.jpg'),
(109029, 7807, 'O Mundo de Greg S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJvbu1CiAEcBWM568oA0eSphm2j.jpg'),
(109030, 7807, 'O Mundo de Greg S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rbVwPyABoWLDQGn7um3lYd8ARd4.jpg'),
(109031, 7807, 'O Mundo de Greg S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0cmNyBngmjsPvfVv3ocLjme5fE.jpg'),
(109032, 7807, 'O Mundo de Greg S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzz9XQVKoIOhn4Jnjryy5AT0L5D.jpg'),
(109033, 7807, 'O Mundo de Greg S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZVC11IRFWlc67LhAsFMaYKvS1q.jpg'),
(109034, 7807, 'O Mundo de Greg S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uRjfka2lUBdbWjaya7OEeuwqMPm.jpg'),
(109035, 7807, 'O Mundo de Greg S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/222006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pCPxW1ufwe6TVig0ATKmJirEu3v.jpg'),
(109036, 7807, 'O Mundo de Greg S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/222007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y736oSknEKX533aqAfnX5l3nk27.jpg'),
(109037, 7807, 'O Mundo de Greg S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/222008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i0H11KoMNwgzf9oiu7KVL1DtM13.jpg'),
(109038, 7807, 'O Mundo de Greg S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/222009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iquWaraMQrAD5JCgt9hiftC0Cbn.jpg'),
(109039, 7807, 'O Mundo de Greg S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/222010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zYXuuwAORkMxEbgLsjFyN5aHy3x.jpg'),
(109040, 7807, 'O Mundo de Greg S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/222011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l0wiXWLaolq29d0jAdLRPV8dOmi.jpg'),
(109041, 7807, 'O Mundo de Greg S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/222012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/syw2hmSfm1dQDzVNRsk5ziXh1QP.jpg'),
(109042, 7807, 'O Mundo de Greg S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/222013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aw4tU2DxZ9PQCFtnIs3C7UEkaxO.jpg'),
(109043, 7807, 'O Mundo de Greg S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/222014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ax9wyhN3BQkkVFxoCfPN3Ziouuw.jpg'),
(109044, 7807, 'O Mundo de Greg S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/222015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tAy5P2POg5DjhmUZKsHg0FOLvPk.jpg'),
(109045, 7807, 'O Mundo de Greg S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/222016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8lp60o8oXfloqKpu3D8eoui530X.jpg'),
(109046, 7807, 'O Mundo de Greg S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/222017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9aKXXV8L6rOfaKvVfrqgFeunLh0.jpg'),
(109047, 7807, 'O Mundo de Greg S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/222018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJwC8fd4BOWhfsnEqAeSZlJCMKb.jpg'),
(109048, 7807, 'O Mundo de Greg S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/222019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3qjZoxIetPegRkl4GXRVxAFGr8s.jpg'),
(109049, 7807, 'O Mundo de Greg S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/222020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Yi9dc6afyMq18UHZBr3Goo2a93.jpg'),
(109050, 7807, 'O Mundo de Greg S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/222021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yD5qxFWG6YounIm4uJ5HrT9H0xM.jpg'),
(109051, 7808, 'O Mundo de Greg S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ucWeff16iBNzU0XiW2f7j5TE0Ua.jpg'),
(109052, 7808, 'O Mundo de Greg S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o71Ht0NSHCCMZnEUuXYCYRrEaQ8.jpg'),
(109053, 7808, 'O Mundo de Greg S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pBRsuy0ZPK3w77jIuLBDM1O0D1D.jpg'),
(109054, 7808, 'O Mundo de Greg S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rWcrUexloQViG7gwv7uWcAJc902.jpg'),
(109055, 7808, 'O Mundo de Greg S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJjUROEC2wzD8kVGYbgyvdeuxpC.jpg'),
(109056, 7808, 'O Mundo de Greg S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nmN4no4mDqPbeJD8dPatLTun0HZ.jpg'),
(109057, 7808, 'O Mundo de Greg S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5S2Clq5ec6Kv2RBSvNuXPzE5nlf.jpg'),
(109058, 7808, 'O Mundo de Greg S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4FhzYNFJzdYDAjvohHcGlO5XhKW.jpg'),
(109059, 7808, 'O Mundo de Greg S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zvH0eCHoeGGuRRBzAyasuewpDrf.jpg'),
(109060, 7808, 'O Mundo de Greg S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2m8Pi2dnySPbXIhWiBwTXboZtF.jpg'),
(109061, 7808, 'O Mundo de Greg S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uX9k6J48xxIQI99GZpakH78wEoZ.jpg'),
(109062, 7808, 'O Mundo de Greg S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e81JsAtjALm5R8uZrOlp3gV4YWE.jpg'),
(109063, 7808, 'O Mundo de Greg S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pFJKTBst3zocq1C0v75HWATeYIj.jpg'),
(109064, 7808, 'O Mundo de Greg S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cNdmpzhwkigiTGd5RwSUivVvruz.jpg'),
(109065, 7808, 'O Mundo de Greg S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/duhwvV3cXszQkMS26JOEeSrKiZ5.jpg'),
(109066, 7808, 'O Mundo de Greg S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o7wiuMffID7k75xIO7Qd5zAuOva.jpg'),
(109067, 7808, 'O Mundo de Greg S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kPpzXwgleAcSLkxPWmW5xbUuiTy.jpg'),
(109068, 7808, 'O Mundo de Greg S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dfr71YusyjfuV7XzxBw4Th5jU9O.jpg'),
(109069, 7808, 'O Mundo de Greg S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vd04a6W8xg34sQCV0uil4CILKuk.jpg'),
(109070, 7808, 'O Mundo de Greg S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AjGOD9DCxeYA2sPvmzDk2bBWkWQ.jpg'),
(109071, 7808, 'O Mundo de Greg S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5nox7mVSOfdK8735F8b5nf1zndF.jpg'),
(109072, 7808, 'O Mundo de Greg S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dljX4O5B9seMowTsFXAducEFQrh.jpg'),
(109073, 7808, 'O Mundo de Greg S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/222044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g25mNWLznatIY3OmmrbSyUEiUns.jpg'),
(109074, 7808, 'O Mundo de Greg S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/222045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zARsgKy2ZAfn2bMCKNtfDQQO6kI.jpg'),
(109075, 7808, 'O Mundo de Greg S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/222046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2QXfnYNM9YPTsl0a9r3aSAWnOd.jpg'),
(109076, 7808, 'O Mundo de Greg S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/222047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Av93oCmrGll4HgfPqF9onE5IRF.jpg'),
(109077, 7808, 'O Mundo de Greg S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/222048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7eZxqK5PrRFcbHWbS0JdW32RFJN.jpg'),
(109078, 7808, 'O Mundo de Greg S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/222049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4WAH7rv3IODiA9MxAIX9D6qfOtB.jpg'),
(109079, 7808, 'O Mundo de Greg S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/222050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vW8YePEZ79B0TypZvvOrWUhCbyT.jpg'),
(109080, 7808, 'O Mundo de Greg S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/222051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jABFpWHwrb7MsQfSFgSkdPvm6Ya.jpg'),
(109081, 7808, 'O Mundo de Greg S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/222052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9DXgIJUHByDEn9KlwKR5Ax7qHF6.jpg'),
(109082, 7808, 'O Mundo de Greg S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/222053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rNSmHspaF04f26t9kEYHm7tYU0r.jpg'),
(109083, 7808, 'O Mundo de Greg S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/222054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/op77mmJvoAxAbFgIZ5aR90oQpVa.jpg'),
(109084, 7808, 'O Mundo de Greg S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/222055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kW090KveOlEn8Tl5LyOSVt5q3Wr.jpg'),
(109085, 7808, 'O Mundo de Greg S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/222056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odFj1rgJoRH6xJ51yCWJ9hqIbsk.jpg'),
(109086, 7808, 'O Mundo de Greg S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/222057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u2eKO5Zj5wHyXBRO8AWo61wXPg9.jpg'),
(109087, 7808, 'O Mundo de Greg S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/222058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7megRhsimzH1LLJFxOyqwtlbH7.jpg'),
(109088, 7809, 'O Mundo de Greg S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ch4vOuLvqvR4RjyYeSUqrJQj21z.jpg'),
(109089, 7809, 'O Mundo de Greg S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1j9SXtWjP9yTp23TjxMwPZdQiJW.jpg'),
(109090, 7809, 'O Mundo de Greg S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i3HbwiYumRVKHLNLY9dikujOG16.jpg'),
(109091, 7809, 'O Mundo de Greg S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xaS2sLJlwyzQ2Ep1O4fsmxNWiTt.jpg'),
(109092, 7809, 'O Mundo de Greg S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4fU84nrTjWf4QHNT26vU2aafA51.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(109093, 7809, 'O Mundo de Greg S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ReYQTIMaDRlwwU8xcmOm9dznxn.jpg'),
(109094, 7809, 'O Mundo de Greg S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/olYxWs1jn1Ronj9w2HWcAI8oITg.jpg'),
(109095, 7809, 'O Mundo de Greg S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JNkMH0wCJXaDHCZpAbfZDkoCY4.jpg'),
(109096, 7809, 'O Mundo de Greg S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/222067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dAh8giPceJuW17GnAS1eBVNzBiX.jpg'),
(109097, 7809, 'O Mundo de Greg S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/222068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nNVSHTgdoTjHwY7IHgwoTLfU2dS.jpg'),
(109098, 7809, 'O Mundo de Greg S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/222069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gVWmRcjH3XGW3mFw5b30OlQFZBX.jpg'),
(109099, 7809, 'O Mundo de Greg S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/222070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fa1q9fEaL7vzTbVjjH72tzLjXMt.jpg'),
(109100, 7809, 'O Mundo de Greg S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/222071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t1Uqnzneb9lnFsOIbwWxiwq8D73.jpg'),
(109101, 7809, 'O Mundo de Greg S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/222072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cG7F4UeezsGpi9pWj7C2ADH8vIs.jpg'),
(109102, 7809, 'O Mundo de Greg S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/222073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/An0mhUcmaqpc25jStbeQ8hZyjHl.jpg'),
(109103, 7809, 'O Mundo de Greg S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/222074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDMg8vFdnBJMXp2ox4F3HYm29tr.jpg'),
(109104, 7809, 'O Mundo de Greg S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/222075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7pVoiPDZMDSEslauuG3CgnJ4yJa.jpg'),
(109105, 7809, 'O Mundo de Greg S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/222076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t3lnSSm6g9Pwf2viitWMpIC673A.jpg'),
(109106, 7809, 'O Mundo de Greg S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/222077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eYJMdnfyfaxNehTQdemcMl6hTqv.jpg'),
(109107, 7809, 'O Mundo de Greg S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/222078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3NCQ1MBFnBGBekkQn8rEAJdQ2q.jpg'),
(109108, 7809, 'O Mundo de Greg S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/222079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ue7sTXL6wqpp1r1WRUS6Y15DSPE.jpg'),
(109109, 7809, 'O Mundo de Greg S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/222080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bbT7VkiYzoyKJoaTUhsn7ihUEhm.jpg'),
(109110, 7809, 'O Mundo de Greg S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/222081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZqjj2qWIVaCF468FKq6t48mopq.jpg'),
(109111, 7809, 'O Mundo de Greg S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/222082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rIfan195sczlv4ARhoeZ1AXI2F6.jpg'),
(109112, 7809, 'O Mundo de Greg S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/222083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jyCXDSi2XQwIj8BmNqgFX8AbWId.jpg'),
(109113, 7809, 'O Mundo de Greg S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/222084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r3zniicyjQJxrRKw7R0nK8RlEyZ.jpg'),
(109114, 7809, 'O Mundo de Greg S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/222085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5zlTTSIAFR95uaNmdQ5tr0WJySa.jpg'),
(109115, 7809, 'O Mundo de Greg S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/222086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4aqwy2b085Pn70FttZxxhu6ex6v.jpg'),
(109116, 7809, 'O Mundo de Greg S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/222087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Q75ynGjlEnp28sy0Q6uthmhwAS.jpg'),
(109117, 7809, 'O Mundo de Greg S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/222088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o955kEWAC2ApxrwrgYQbrUmG24M.jpg'),
(109118, 7809, 'O Mundo de Greg S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/222089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bI3tvnVcHnEWV1vLISSUfHLS5ex.jpg'),
(109119, 7809, 'O Mundo de Greg S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/222090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ejFil8MxN8KwsOW7xKRLdhakNNR.jpg'),
(109120, 7809, 'O Mundo de Greg S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/222091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rwy4COQuttiob16eDWHaSflosXN.jpg'),
(109121, 7809, 'O Mundo de Greg S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/222092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xOR84ixgyRggVhis1gHk77a7Dwu.jpg'),
(109122, 7809, 'O Mundo de Greg S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/222093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ln5d40HsxrGCbcuLB1rDeBBGmFX.jpg'),
(109123, 7809, 'O Mundo de Greg S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/222094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ymx9UaeLAjghmcZabu80S2HsWJ2.jpg'),
(109124, 7809, 'O Mundo de Greg S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/222095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j5zUdA6Tq3a9rUReQtrGm2YYnGD.jpg'),
(109125, 7809, 'O Mundo de Greg S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/222096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyYgQ1n28SRk3w5hDE6yE063BuU.jpg'),
(109126, 7809, 'O Mundo de Greg S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/222097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2VDaK3ymQBfMEiOXslLJyLie7Ot.jpg'),
(109127, 7809, 'O Mundo de Greg S04 E40', 'http://sinalprivado.info:80/series/1533784/1533784/222098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xO8UlCyT5K14QfiIG5OXq541t7b.jpg'),
(109128, 7810, 'O Mundo de Greg S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/222099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wSm0zLzIId5f7XI0AGxanvVaoKT.jpg'),
(109129, 7810, 'O Mundo de Greg S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/222100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rlyQNBqf2PAFQbRzzbgqfJZ4xW9.jpg'),
(109130, 7810, 'O Mundo de Greg S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/222101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bDWzY2hVDLTGvuJgD79wXbaKBuB.jpg'),
(109131, 7810, 'O Mundo de Greg S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/222102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tiXRENpPAIjuebXOygUOmI9jvbS.jpg'),
(109132, 7810, 'O Mundo de Greg S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/222103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nqWMyFiIXgYz07H84TJscpIfhY6.jpg'),
(109133, 7810, 'O Mundo de Greg S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/222104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vLMb1Guw2MzdK9FMY0XVcjPeVtv.jpg'),
(109134, 7810, 'O Mundo de Greg S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/222105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5UviJnsSEIAcWZso0IQYKyvwNxI.jpg'),
(109135, 7810, 'O Mundo de Greg S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/222106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kYsPaxNmpS0KUd1rMigl8NTuxW.jpg'),
(109136, 7811, 'Slip S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fasAM7PSenAIhxk2pUOWWuVYwRf.jpg'),
(109137, 7811, 'Slip S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pnMMXwVhBO6TKcwpE1IVxB0Dqlm.jpg'),
(109138, 7811, 'Slip S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2pjbiZRt3RJV0J0KeLL68lP6Jhv.jpg'),
(109139, 7811, 'Slip S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDleIIm2ivo3r2UaGDPxkMbSDTv.jpg'),
(109140, 7811, 'Slip S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mgoyPmHnjEmCI77fKNCvX8Zbndh.jpg'),
(109141, 7811, 'Slip S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iXTTkm890lMA3gMoTI93wW27E9U.jpg'),
(109142, 7811, 'Slip S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qXzzKnaauz5dqTpOS1t9dFJ7zUx.jpg'),
(109143, 7812, 'O Príncipe Dragão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7edKFWqUIRbK6AtaHKIkwIuWhtL.jpg'),
(109144, 7812, 'O Príncipe Dragão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9lhqWx6cNoOcdbpjLxbVkEcgLhx.jpg'),
(109145, 7812, 'O Príncipe Dragão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uBvvjFKNvESJsiVnJPSxEgpHMvr.jpg'),
(109146, 7812, 'O Príncipe Dragão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bQgfV0aGcTmHLBW0bXJ0vuOT0sI.jpg'),
(109147, 7812, 'O Príncipe Dragão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bfNBduxL6WpQR5YhiiaNLogMNAC.jpg'),
(109148, 7812, 'O Príncipe Dragão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQLFhtafB9hLvFtC8ieeOngRBpT.jpg'),
(109149, 7812, 'O Príncipe Dragão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSxDkn8k3O2wfbRZr40Al44cxu8.jpg'),
(109150, 7812, 'O Príncipe Dragão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bWKMLLBNewR7khgLjwsxx9UWKRB.jpg'),
(109151, 7812, 'O Príncipe Dragão S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f3CVwjdMCXgumXaHLEUw6jZNxCl.jpg'),
(109152, 7813, 'O Príncipe Dragão S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ftaefq44Fe7OtdSRyJMmkZlaWR2.jpg'),
(109153, 7813, 'O Príncipe Dragão S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bKRJvBNhDVDSxChYQiuMpiB477H.jpg'),
(109154, 7813, 'O Príncipe Dragão S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTq18kf9nVi6iQe3k7GvHGtdRpH.jpg'),
(109155, 7813, 'O Príncipe Dragão S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/utDF1tj1DqTOBZl42DOtHpQtA27.jpg'),
(109156, 7813, 'O Príncipe Dragão S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gVfjTyFExVaFdaSCk0Cad0XfQRW.jpg'),
(109157, 7813, 'O Príncipe Dragão S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jvMUY29iqKQhQ8j8UqRbtNBuJF6.jpg'),
(109158, 7813, 'O Príncipe Dragão S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9V49xuGluMDLk50jSKuHmBFXb9H.jpg'),
(109159, 7813, 'O Príncipe Dragão S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dXWAfA5kKlsBGt5jWH2MtmunCbs.jpg'),
(109160, 7813, 'O Príncipe Dragão S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t8Bk7zIGzr4xYJQHMQRdkoKD7SY.jpg'),
(109161, 7814, 'O Príncipe Dragão S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3wayXERiMxhH892pu3LcnpmCTb9.jpg'),
(109162, 7814, 'O Príncipe Dragão S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fs69goq4y0JED63wOMpe5rn9BAl.jpg'),
(109163, 7814, 'O Príncipe Dragão S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHRveG628NjMKY5j3ehtEznA2Rm.jpg'),
(109164, 7814, 'O Príncipe Dragão S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/csPJIvRAk7WJBAsSz5nDoqk46c7.jpg'),
(109165, 7814, 'O Príncipe Dragão S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/skv5CsULYQ2RS3U9VGR80MJYMQU.jpg'),
(109166, 7814, 'O Príncipe Dragão S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vaDWycxdrAaIbx8HX40vxJya72A.jpg'),
(109167, 7814, 'O Príncipe Dragão S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sne7Dlyk0ndFnfWdKMpeXCJkj5L.jpg'),
(109168, 7814, 'O Príncipe Dragão S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wRYhcdOqJE7LWTtO8f256T6aRCK.jpg'),
(109169, 7814, 'O Príncipe Dragão S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ezRx4bmFntnebNrAuiFflYCRApM.jpg'),
(109170, 7815, 'O Príncipe Dragão S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Ze4elMC8Lfl3nso03Bl4p31aSM.jpg'),
(109171, 7815, 'O Príncipe Dragão S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xxXm9Nz76SxqLD0uyWJebDX0pZK.jpg'),
(109172, 7815, 'O Príncipe Dragão S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j1E61ECw1akuMti1DcVpw5AkZNH.jpg'),
(109173, 7815, 'O Príncipe Dragão S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xbgx8fzMZsSZF7CXltouOrts1BK.jpg'),
(109174, 7815, 'O Príncipe Dragão S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7t7SJsyjcgRU0q6CddmrHUZGx2i.jpg'),
(109175, 7815, 'O Príncipe Dragão S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQ2IU2HU2WlyECmiue0KaZgn1E5.jpg'),
(109176, 7815, 'O Príncipe Dragão S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ejeW9PYcAS7x3BwP6fgZN70c9Gf.jpg'),
(109177, 7815, 'O Príncipe Dragão S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dW8smo7jrOySQKWF5lGXBPZHJdq.jpg'),
(109178, 7815, 'O Príncipe Dragão S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXizQL9Oqf9fbep8WeBsyiHhAgN.jpg'),
(109179, 7816, 'O Príncipe Dragão S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/toU4TDWAdP6PEkyozFgiFoVzb5U.jpg'),
(109180, 7816, 'O Príncipe Dragão S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/toU4TDWAdP6PEkyozFgiFoVzb5U.jpg'),
(109181, 7816, 'O Príncipe Dragão S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/toU4TDWAdP6PEkyozFgiFoVzb5U.jpg'),
(109182, 7816, 'O Príncipe Dragão S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/toU4TDWAdP6PEkyozFgiFoVzb5U.jpg'),
(109183, 7816, 'O Príncipe Dragão S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/toU4TDWAdP6PEkyozFgiFoVzb5U.jpg'),
(109184, 7816, 'O Príncipe Dragão S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/toU4TDWAdP6PEkyozFgiFoVzb5U.jpg'),
(109185, 7816, 'O Príncipe Dragão S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/toU4TDWAdP6PEkyozFgiFoVzb5U.jpg'),
(109186, 7816, 'O Príncipe Dragão S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/toU4TDWAdP6PEkyozFgiFoVzb5U.jpg'),
(109187, 7816, 'O Príncipe Dragão S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/toU4TDWAdP6PEkyozFgiFoVzb5U.jpg'),
(109188, 7817, 'O Príncipe Dragão S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/456993.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A6O313iozkUedAvvvb1eafXbGyN.jpg'),
(109189, 7817, 'O Príncipe Dragão S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/456994.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hNtTZm6SzV0qbbZvROkFrIRB5cV.jpg'),
(109190, 7817, 'O Príncipe Dragão S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/456995.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6GwvvAtMJy2tAZzyrn70iSzYvI8.jpg'),
(109191, 7817, 'O Príncipe Dragão S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/456996.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1m1e1WMoOzzpF8K0Yhn4rbuesKw.jpg'),
(109192, 7817, 'O Príncipe Dragão S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/456997.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/izTe8g0qp4nytNOpYr5Bm245Iu.jpg'),
(109193, 7817, 'O Príncipe Dragão S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/456998.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pmPgAl6BgpVXS4HqAJnHMHdk3wg.jpg'),
(109194, 7817, 'O Príncipe Dragão S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/456999.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yTiQvjOEvBZsEtK2fEkxAKGETsu.jpg'),
(109195, 7817, 'O Príncipe Dragão S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/457000.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iI9pipuyRMqC4vErZggHliVAyeS.jpg'),
(109196, 7817, 'O Príncipe Dragão S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/457001.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rFph6V9ttF2Y20LH0oIiNl68Zii.jpg'),
(109197, 7818, 'O Príncipe Dragão S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/638927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/toU4TDWAdP6PEkyozFgiFoVzb5U.jpg'),
(109198, 7818, 'O Príncipe Dragão S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/638928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/toU4TDWAdP6PEkyozFgiFoVzb5U.jpg'),
(109199, 7818, 'O Príncipe Dragão S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/638929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/toU4TDWAdP6PEkyozFgiFoVzb5U.jpg'),
(109200, 7818, 'O Príncipe Dragão S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/638930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/toU4TDWAdP6PEkyozFgiFoVzb5U.jpg'),
(109201, 7818, 'O Príncipe Dragão S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/638931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/toU4TDWAdP6PEkyozFgiFoVzb5U.jpg'),
(109202, 7818, 'O Príncipe Dragão S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/638932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/toU4TDWAdP6PEkyozFgiFoVzb5U.jpg'),
(109203, 7818, 'O Príncipe Dragão S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/638933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/toU4TDWAdP6PEkyozFgiFoVzb5U.jpg'),
(109204, 7818, 'O Príncipe Dragão S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/638934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/toU4TDWAdP6PEkyozFgiFoVzb5U.jpg'),
(109205, 7818, 'O Príncipe Dragão S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/638935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/toU4TDWAdP6PEkyozFgiFoVzb5U.jpg'),
(109206, 7819, 'Operação: Lioness S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nmQp2GT1T2mK4YoLWcMl1FsoZC.jpg'),
(109207, 7819, 'Operação: Lioness S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/di206uwVZtjGe02fqkTPvdRKKrH.jpg'),
(109208, 7819, 'Operação: Lioness S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232949.mp4', 'http://image.tmdb.org/t/p/w1280/9X1pfnHfZx0wlPvW1cH3t4yaerN.jpg'),
(109209, 7819, 'Operação: Lioness S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232950.mp4', 'http://image.tmdb.org/t/p/w1280/kJS9ycUt3hzBahLcrFhNxp76wAp.jpg'),
(109210, 7819, 'Operação: Lioness S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232951.mp4', 'http://image.tmdb.org/t/p/w1280/ciYRv08dxwk1idonANAUKEXZHI6.jpg'),
(109211, 7819, 'Operação: Lioness S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232952.mp4', 'http://image.tmdb.org/t/p/w1280/lExmqddOuKqtXbxzSKqwQZLxh7C.jpg'),
(109212, 7819, 'Operação: Lioness S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232953.mp4', 'http://image.tmdb.org/t/p/w1280/v7IY9eLPc2c9N0MYSppFTO7COZk.jpg'),
(109213, 7819, 'Operação: Lioness S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232954.mp4', 'http://image.tmdb.org/t/p/w1280/3ndiiSM8sWMclfS123YaVIBOtsw.jpg'),
(109214, 7820, 'Operação: Lioness S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/493533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fAd0dCaoSvJdGi4K4RxDfzhqXL7.jpg'),
(109215, 7820, 'Operação: Lioness S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/496386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fAd0dCaoSvJdGi4K4RxDfzhqXL7.jpg'),
(109216, 7820, 'Operação: Lioness S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/498928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fAd0dCaoSvJdGi4K4RxDfzhqXL7.jpg'),
(109217, 7820, 'Operação: Lioness S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/505410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fAd0dCaoSvJdGi4K4RxDfzhqXL7.jpg'),
(109218, 7820, 'Operação: Lioness S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/511422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fAd0dCaoSvJdGi4K4RxDfzhqXL7.jpg'),
(109219, 7820, 'Operação: Lioness S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/511423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fAd0dCaoSvJdGi4K4RxDfzhqXL7.jpg'),
(109220, 7820, 'Operação: Lioness S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/514228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fAd0dCaoSvJdGi4K4RxDfzhqXL7.jpg'),
(109221, 7820, 'Operação: Lioness S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/525138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fAd0dCaoSvJdGi4K4RxDfzhqXL7.jpg'),
(109222, 7821, 'Origem [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221866.mp4', 'http://timg.bdta.pro/images/226152ecc6e88062076d2459edd7908b.jpg'),
(109223, 7821, 'Origem [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221867.mp4', 'http://timg.bdta.pro/images/496fcce8ac498890924514d02d5d70a1.jpg'),
(109224, 7821, 'Origem [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221868.mp4', 'http://timg.bdta.pro/images/ab4dbaa505477f1b98b98d8abbceb3c7.jpg'),
(109225, 7821, 'Origem [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221869.mp4', 'http://timg.bdta.pro/images/279e6b35a42980dd4294e78153455430.jpg'),
(109226, 7821, 'Origem [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221870.mp4', 'http://timg.bdta.pro/images/cbcbf4d3ba6a2244a5d47fc989e13508.jpg'),
(109227, 7821, 'Origem [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221871.mp4', 'http://timg.bdta.pro/images/3ff8e16a7c6e60d7a3d651fe988cdcf4.jpg'),
(109228, 7821, 'Origem [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221872.mp4', 'http://timg.bdta.pro/images/4ff7be471edcbdc5a0949fd4a616eed1.jpg'),
(109229, 7821, 'Origem [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221873.mp4', 'http://timg.bdta.pro/images/138e026dbe26d547d155d0b92b25502c.jpg'),
(109230, 7821, 'Origem [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221874.mp4', 'http://timg.bdta.pro/images/c3dd66daf6bf721f47820f9797237296.jpg'),
(109231, 7821, 'Origem [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221875.mp4', 'http://timg.bdta.pro/images/2e6057e2bed10cf70897b7ad1548eeb9.jpg'),
(109232, 7822, 'Origem [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vC9VdhwuRoyDrLyRV4XNzS7GtRz.jpg'),
(109233, 7822, 'Origem [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uNq3gsv1ICLr2QoftudE6p3jpzr.jpg'),
(109234, 7822, 'Origem [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6brHsA7Qw0qlxvauJSSiCJztnR.jpg'),
(109235, 7822, 'Origem [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g6u3DalL6ZVCQDYCQg6yTza6ixH.jpg'),
(109236, 7822, 'Origem [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Pp2mY6qhD0WALyl59s6Ycp3UqN.jpg'),
(109237, 7822, 'Origem [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sTntBpyqrbbNQ7FBboRdWZxQPNa.jpg'),
(109238, 7822, 'Origem [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z0ZYPKarFLmfCVRwaysG2J8Q272.jpg'),
(109239, 7822, 'Origem [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vXfZgFkHMwjMoNzFbZKxYmOqELr.jpg'),
(109240, 7822, 'Origem [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cuZj10ovQX8w5w08JevlwtNcC4v.jpg'),
(109241, 7822, 'Origem [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3d7vWOnFRWG9pObG4KxueABjeyV.jpg'),
(109242, 7823, 'Origem [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/467031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(109243, 7823, 'Origem [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/467032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(109244, 7823, 'Origem [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/476054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(109245, 7823, 'Origem [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/476055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(109246, 7823, 'Origem [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/490495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(109247, 7823, 'Origem [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/493523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(109248, 7823, 'Origem [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/496376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(109249, 7823, 'Origem [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/503056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(109250, 7823, 'Origem [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/507643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(109251, 7823, 'Origem [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/511409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kYf47t1tcSmhH714NTvSS8udIC9.jpg'),
(109252, 7824, '(A)mar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AqVJr0JJ3cP00vZ8fjheHCJZeV5.jpg'),
(109253, 7824, '(A)mar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7DefQkNo4SoK817IHZ1Jv9xYUOt.jpg'),
(109254, 7824, '(A)mar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/haccRnczL7tGzem3pBn5K7DKUOC.jpg'),
(109255, 7824, '(A)mar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJw5h1TJvlBpHaJWLIw2iV6Uqd3.jpg'),
(109256, 7824, '(A)mar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5iQEaGZLA9pPzBCc5d98MJVQxij.jpg'),
(109257, 7824, '(A)mar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/daR3dKLZIZM3asJGOoP24eFHwBm.jpg'),
(109258, 7824, '(A)mar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/erSI7RhW36MmGIqepCjPXtYQJhX.jpg'),
(109259, 7824, '(A)mar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/28lE3GPweAjDWSZRNxXbcXgtVRl.jpg'),
(109260, 7824, '(A)mar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4MPkHhE0KMBZGsJh3n016ploU7q.jpg'),
(109261, 7824, '(A)mar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnOR5vN8dKY7HY4IDmp1KOo7qzJ.jpg'),
(109262, 7824, '(A)mar S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fBPZBqxi9lRloOLC2In5ml2luoL.jpg'),
(109263, 7824, '(A)mar S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/akI9BDCvqIsfX8GnqwcjYUzMFFw.jpg'),
(109264, 7824, '(A)mar S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2izcKLRlDlqzIHXO8riwO8Okfkm.jpg'),
(109265, 7824, '(A)mar S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/221511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bpCRQH8xmA9TnoxZ7MjR95w6hHC.jpg'),
(109266, 7824, '(A)mar S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/221512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6XCBpS7hkRO7KEGgO0wYGzWtApS.jpg'),
(109267, 7825, 'Armas de Mulher S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221490.mp4', 'http://timg.bdta.pro/images/89517976113ad06ce0ef9789e37ef434.jpg'),
(109268, 7825, 'Armas de Mulher S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221491.mp4', 'http://timg.bdta.pro/images/5941ee79d086ab6729c327542a93e8ba.jpg'),
(109269, 7825, 'Armas de Mulher S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221492.mp4', 'http://timg.bdta.pro/images/48e0913b8e80d4deff81596c40fa22c2.jpg'),
(109270, 7825, 'Armas de Mulher S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221493.mp4', 'http://timg.bdta.pro/images/982e4b8e1fbba88a1b411f51d555e1ac.jpg'),
(109271, 7825, 'Armas de Mulher S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221494.mp4', 'http://timg.bdta.pro/images/e0da3b521cedd50e20be804130e99fb6.jpg'),
(109272, 7825, 'Armas de Mulher S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221495.mp4', 'http://timg.bdta.pro/images/02927e06ee2fade5b46af706c4ee1fd8.jpg'),
(109273, 7825, 'Armas de Mulher S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221496.mp4', 'http://timg.bdta.pro/images/288f991810eb81bceda86af7a2ca02fc.jpg'),
(109274, 7825, 'Armas de Mulher S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221497.mp4', 'http://timg.bdta.pro/images/bc9a106ebff542dcbd265e9f8d599cb0.jpg'),
(109275, 7826, 'Fantasmas de Beirute S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/evelrjazX9OUT6kvDri0iGQQPoo.jpg'),
(109276, 7826, 'Fantasmas de Beirute S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/quOL0yqforRZkEUIGUnbAzTxvLv.jpg'),
(109277, 7826, 'Fantasmas de Beirute S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fiWppDumAhpfGr2MZ91kERFOelS.jpg'),
(109278, 7826, 'Fantasmas de Beirute S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aWmezbEzlxEDoNQM9ZiiwYF9Gkb.jpg'),
(109279, 7827, 'Alert: Missing Persons Unit [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jDqO6QRfXJ1kf8rCM8o32O4gWYl.jpg'),
(109280, 7827, 'Alert: Missing Persons Unit [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rayWjcB4mC5Cl1onYA1RiuMuTDI.jpg'),
(109281, 7827, 'Alert: Missing Persons Unit [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/30eVb8LlXRo7GQjTvwKmcf9JiWm.jpg'),
(109282, 7827, 'Alert: Missing Persons Unit [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p754eeE5L0o3w5llvJfbxRY824m.jpg'),
(109283, 7827, 'Alert: Missing Persons Unit [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1HFbrvZyPE2mkhXvH7tkyfo0WYI.jpg'),
(109284, 7827, 'Alert: Missing Persons Unit [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A5yxfdJ0XWqEFPXmNdkeZKqyQr2.jpg'),
(109285, 7827, 'Alert: Missing Persons Unit [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQWB5R3RYtJoyPTnjwJrbKAe1yt.jpg'),
(109286, 7827, 'Alert: Missing Persons Unit [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fgVnL0FuiZcX65zXY5fvgTP3PrQ.jpg'),
(109287, 7828, 'Alert: Missing Persons Unit [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/298535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaxfgCsJ8LR6jYCsRsMWlZOmvZr.jpg'),
(109288, 7828, 'Alert: Missing Persons Unit [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/303528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaxfgCsJ8LR6jYCsRsMWlZOmvZr.jpg'),
(109289, 7828, 'Alert: Missing Persons Unit [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/310795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaxfgCsJ8LR6jYCsRsMWlZOmvZr.jpg'),
(109290, 7828, 'Alert: Missing Persons Unit [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/319057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaxfgCsJ8LR6jYCsRsMWlZOmvZr.jpg'),
(109291, 7828, 'Alert: Missing Persons Unit [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaxfgCsJ8LR6jYCsRsMWlZOmvZr.jpg'),
(109292, 7828, 'Alert: Missing Persons Unit [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/329100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaxfgCsJ8LR6jYCsRsMWlZOmvZr.jpg'),
(109293, 7828, 'Alert: Missing Persons Unit [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/334002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaxfgCsJ8LR6jYCsRsMWlZOmvZr.jpg'),
(109294, 7828, 'Alert: Missing Persons Unit [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/350425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaxfgCsJ8LR6jYCsRsMWlZOmvZr.jpg'),
(109295, 7828, 'Alert: Missing Persons Unit [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/350426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaxfgCsJ8LR6jYCsRsMWlZOmvZr.jpg'),
(109296, 7828, 'Alert: Missing Persons Unit [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/360976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaxfgCsJ8LR6jYCsRsMWlZOmvZr.jpg'),
(109297, 7829, 'Alert: Missing Persons Unit [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/820052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaxfgCsJ8LR6jYCsRsMWlZOmvZr.jpg'),
(109298, 7829, 'Alert: Missing Persons Unit [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/820053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaxfgCsJ8LR6jYCsRsMWlZOmvZr.jpg'),
(109299, 7829, 'Alert: Missing Persons Unit [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/820054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaxfgCsJ8LR6jYCsRsMWlZOmvZr.jpg'),
(109300, 7829, 'Alert: Missing Persons Unit [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/820055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaxfgCsJ8LR6jYCsRsMWlZOmvZr.jpg'),
(109301, 7829, 'Alert: Missing Persons Unit [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/820056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaxfgCsJ8LR6jYCsRsMWlZOmvZr.jpg'),
(109302, 7829, 'Alert: Missing Persons Unit [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/820057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaxfgCsJ8LR6jYCsRsMWlZOmvZr.jpg'),
(109303, 7830, 'No Escape [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9juPUz3qVPqo4rzYqSIPng1c0Uj.jpg'),
(109304, 7830, 'No Escape [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6EI4pcLJU3YDO6sMW1U0oVVRnn9.jpg'),
(109305, 7830, 'No Escape [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y5IZRJxFuKVWvVSKPsqhV4I1BKi.jpg'),
(109306, 7830, 'No Escape [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6LTCy8EJZIwnvKiwnfEaAsZ9E99.jpg'),
(109307, 7830, 'No Escape [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tlOwnB7tnrRmOj0S8zFjvbXFv7N.jpg'),
(109308, 7830, 'No Escape [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wsqusGLLoeJVjKnqzhAsnvpgY5x.jpg'),
(109309, 7830, 'No Escape [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vvSN5akBTIQU2GkxDu9H38egbA6.jpg'),
(109310, 7831, 'Numbers [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6BpLDitO0YezJScFjtcB2f1rxo.jpg'),
(109311, 7831, 'Numbers [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bROSFj13L67A2oktHOIStekJAA8.jpg'),
(109312, 7831, 'Numbers [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3BvqWoZaW3fDWwYc95sgS81rzze.jpg'),
(109313, 7831, 'Numbers [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9509Rmocyy4Sc2rIaxbAgs0Qybd.jpg'),
(109314, 7831, 'Numbers [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ourGqqxXb4Kh2OZBHjf52cfOeh.jpg'),
(109315, 7831, 'Numbers [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mzesRSXTzCMNJK9TfGMpE6Ifslp.jpg'),
(109316, 7831, 'Numbers [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r3dTYcaF4eRdM9EeJLhLltxytVV.jpg'),
(109317, 7831, 'Numbers [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3sGkyFZOa4yvGfHrJcpf2eSZWdT.jpg'),
(109318, 7831, 'Numbers [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dL3HAbwKBQh2SMdC4jFJApic263.jpg'),
(109319, 7831, 'Numbers [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iC8IXonzxT8zuOnGqWXN8VWcXHy.jpg'),
(109320, 7831, 'Numbers [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/656631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iC8IXonzxT8zuOnGqWXN8VWcXHy.jpg'),
(109321, 7831, 'Numbers [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/656632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iC8IXonzxT8zuOnGqWXN8VWcXHy.jpg'),
(109322, 7832, 'O Caso Ashley Madison [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3zntTmnIr8NcZO35Vn3CkUkjfNQ.jpg'),
(109323, 7832, 'O Caso Ashley Madison [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mgjOVSjsZjenOvoaQ2tuZHZ4iOD.jpg'),
(109324, 7832, 'O Caso Ashley Madison [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yIQQ5Eri7HvnNnJ8Ufqsbo3zy9p.jpg'),
(109325, 7833, 'Pancho Villa: O Centauro do Norte [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ef7x5G6LaSoLOl1PbpdKMn2sLYK.jpg'),
(109326, 7833, 'Pancho Villa: O Centauro do Norte [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2rg4GtUCAsjsycju0BIErmWElM.jpg'),
(109327, 7833, 'Pancho Villa: O Centauro do Norte [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qJjGoUk0kPHUBjnfYrFneR7gHwf.jpg'),
(109328, 7833, 'Pancho Villa: O Centauro do Norte [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1wNkNKpsiNthRXJlmTBWsRrzYPM.jpg'),
(109329, 7833, 'Pancho Villa: O Centauro do Norte [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tqzIZ2RnnD3NVDubP0ZgVra6Hls.jpg'),
(109330, 7833, 'Pancho Villa: O Centauro do Norte [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/or6yEBbm959VL4n4HbxOQPcoU9y.jpg'),
(109331, 7833, 'Pancho Villa: O Centauro do Norte [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aE62OWTIfacDekd0bFJ2N5YhcYv.jpg'),
(109332, 7833, 'Pancho Villa: O Centauro do Norte [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lNQpwHSE898EWE2T6FQ7aYlBHLK.jpg'),
(109333, 7833, 'Pancho Villa: O Centauro do Norte [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yhW0XQuvWZ4x5PlPrSk7dVOJQWF.jpg'),
(109334, 7833, 'Pancho Villa: O Centauro do Norte [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rO7KSHiR3iph92u9fnLpz1wqoJq.jpg'),
(109335, 7834, 'Por Trás da Névoa [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y4q1v3e5HQPiOeD9TnORROn4YVW.jpg'),
(109336, 7834, 'Por Trás da Névoa [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/btMhGJ04rjzNNDIN9XvMwTzCbJ5.jpg'),
(109337, 7834, 'Por Trás da Névoa [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kjVtnFMvbM6O31yEHZ8DMUypd6X.jpg'),
(109338, 7834, 'Por Trás da Névoa [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yiFNyhcKJOUCI9u9iA8uXbpAgQX.jpg'),
(109339, 7834, 'Por Trás da Névoa [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4KdLOTAIIvK4qJ0Zz5rOMdKNccI.jpg'),
(109340, 7834, 'Por Trás da Névoa [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hAoP4NrKgyrxIkzZDwwvR0nOLhL.jpg'),
(109341, 7835, 'Superpoderosos: A História da DC [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9XtnjDcCU8fuRHwpa5OsGlrcZsI.jpg'),
(109342, 7835, 'Superpoderosos: A História da DC [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pX7Ufwlbdqw5HESiSWxns0vjVtC.jpg'),
(109343, 7835, 'Superpoderosos: A História da DC [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6KMc3Z9hDcziPdiw7XNwUgr3uRP.jpg'),
(109344, 7836, '1985 [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9VFkaiHE3bVWIYIC3gp4cxlaUiC.jpg'),
(109345, 7836, '1985 [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2tFznGc0k9m77imaFMqHvYOxuqu.jpg'),
(109346, 7836, '1985 [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236576.mp4', 'http://image.tmdb.org/t/p/w1280/10As4j4ucYiFYyXMj2nQk4lLXnm.jpg'),
(109347, 7836, '1985 [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236577.mp4', 'http://image.tmdb.org/t/p/w1280/lo4urrU6jrMS6PriCZK5tTwtedZ.jpg'),
(109348, 7836, '1985 [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236578.mp4', 'http://image.tmdb.org/t/p/w1280/jirNEHGMLlC6z9jpuBzt07oTqX7.jpg'),
(109349, 7836, '1985 [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ma1FtkhQ1mQRbyYUTWY5ngi4Xne.jpg'),
(109350, 7836, '1985 [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ma1FtkhQ1mQRbyYUTWY5ngi4Xne.jpg'),
(109351, 7836, '1985 [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ma1FtkhQ1mQRbyYUTWY5ngi4Xne.jpg'),
(109352, 7837, '2 Dope Queens [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AuRRYvgatOMCQcsWOEiCjZkXQXX.jpg'),
(109353, 7837, '2 Dope Queens [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t73xThETg2IhtI6akDECYLQqEeF.jpg'),
(109354, 7837, '2 Dope Queens [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLQ2bLF2ALWJRMfApZV9d2QRPGg.jpg'),
(109355, 7837, '2 Dope Queens [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A5UDQ6tkhb7z5tB9Xd3M3kICScI.jpg'),
(109356, 7838, '2 Dope Queens [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/69sI8Ocg7wAE8v12Qg6nA2viWXo.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(109357, 7838, '2 Dope Queens [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Ky2UgzMEGpEL7WRnSKm3hlos1r.jpg'),
(109358, 7838, '2 Dope Queens [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m8Pd2UHm7WEkXgDbElszSvu0GWd.jpg'),
(109359, 7838, '2 Dope Queens [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m8Pd2UHm7WEkXgDbElszSvu0GWd.jpg'),
(109360, 7839, '548 Dias: Capturada por uma Seita [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n3O2Qcs57q1adivdRN7KZPOqrPh.jpg'),
(109361, 7839, '548 Dias: Capturada por uma Seita [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wJLTwejtljPQvoYrViprCDJmuvD.jpg'),
(109362, 7839, '548 Dias: Capturada por uma Seita [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dovBr2s3TdJFYE3ulRLwTyZUKY.jpg'),
(109363, 7840, 'A Autonomia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yrA8WfUyKf5Skno1XMyo78LpHlm.jpg'),
(109364, 7840, 'A Autonomia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/che2DITXSJlwlaKsQOZugXPwGy3.jpg'),
(109365, 7840, 'A Autonomia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h57QoEjaqeRtiwDHLvo4ds9oF1Z.jpg'),
(109366, 7840, 'A Autonomia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/edcrCHfmo5c9pOhmRK0VgQpfBFC.jpg'),
(109367, 7840, 'A Autonomia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ao5PtSroiYneLC8Z8rOo3WUC5YU.jpg'),
(109368, 7841, 'A Cúmplice do Mal: Monique Olivier [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tarhtjSppWa0pOykDft1JJaIWfF.jpg'),
(109369, 7842, 'Adamas: O Diamante Assassino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mSF3EzobLklRQFpJoZeBLKb0o9J.jpg'),
(109370, 7842, 'Adamas: O Diamante Assassino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sOksyMtKAnbOc0qWaxbYhNY3T1W.jpg'),
(109371, 7842, 'Adamas: O Diamante Assassino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/miKM3GVPaN9WHR6XCUxTkmzsL1T.jpg'),
(109372, 7842, 'Adamas: O Diamante Assassino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/TM76VNya1IhAYAbYmI81NWxFmM.jpg'),
(109373, 7842, 'Adamas: O Diamante Assassino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cA5VKkkhQCT7Gs0vYcmszmtzEB9.jpg'),
(109374, 7842, 'Adamas: O Diamante Assassino S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sKdFMXK0QA7SiBHBCTE2RbxHfLn.jpg'),
(109375, 7842, 'Adamas: O Diamante Assassino S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tnmdx3uFzpdpgmDDLPlMKXhO6Zd.jpg'),
(109376, 7842, 'Adamas: O Diamante Assassino S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0YuDcDeRu0u9Na9754gR19l87C.jpg'),
(109377, 7842, 'Adamas: O Diamante Assassino S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wJsecna5BYEFWx3IeqmwobcdBoP.jpg'),
(109378, 7842, 'Adamas: O Diamante Assassino S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4R2PV1Gm0ywZkQADi4vwdMybd25.jpg'),
(109379, 7842, 'Adamas: O Diamante Assassino S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vSvd4B2TsavUGPSHKKkJ4tVIdcQ.jpg'),
(109380, 7842, 'Adamas: O Diamante Assassino S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wkTXrrNS7grbEkM5qPiqyYhreT3.jpg'),
(109381, 7842, 'Adamas: O Diamante Assassino S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zJ1aTPgxg4icjSSFQi1aQysTJlK.jpg'),
(109382, 7842, 'Adamas: O Diamante Assassino S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/221354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hyQazXb3vUA453Vnuz8BitITzC4.jpg'),
(109383, 7842, 'Adamas: O Diamante Assassino S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/221355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lcR6zjZoGFjPZI2zY5zGPoalii0.jpg'),
(109384, 7842, 'Adamas: O Diamante Assassino S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/221356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHtThl6obTykjO8gcIc6FQKLXbr.jpg'),
(109385, 7843, 'Adhura [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3XVacyt6VpL6f1tOrppiMPJ7UHZ.jpg'),
(109386, 7843, 'Adhura [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnI1dCzb3fygNvwmytBKU5pcNTE.jpg'),
(109387, 7843, 'Adhura [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iqcEZCCuy4lsN4mDS97g7Gh2XOu.jpg'),
(109388, 7843, 'Adhura [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qpH4J3ICLSnycMBCrjeI2uTgI9F.jpg'),
(109389, 7843, 'Adhura [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vyYQZIjc0qKziWP0Mr9cL6kDqF0.jpg'),
(109390, 7843, 'Adhura [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqjw8cvIUHTjn8rSNc7N6gziVIN.jpg'),
(109391, 7843, 'Adhura [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fogAShpFg229SYohqnGsL2j0CM8.jpg'),
(109392, 7844, 'Andy e Seu Esquilo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uXvidpAzdu3a0qzsTDPEhtdx3rQ.jpg'),
(109393, 7844, 'Andy e Seu Esquilo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A63sPRVifAdDDnjEQkYyAlYVUmT.jpg'),
(109394, 7844, 'Andy e Seu Esquilo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqOBPJxWKefU5dsPEyIivSDpsea.jpg'),
(109395, 7844, 'Andy e Seu Esquilo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqOBPJxWKefU5dsPEyIivSDpsea.jpg'),
(109396, 7844, 'Andy e Seu Esquilo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qUF3HgZwgq4S4mHztzyKTt5u1GK.jpg'),
(109397, 7844, 'Andy e Seu Esquilo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qUF3HgZwgq4S4mHztzyKTt5u1GK.jpg'),
(109398, 7844, 'Andy e Seu Esquilo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kEv5GWDZQsafboxEun2Ua17xaSZ.jpg'),
(109399, 7844, 'Andy e Seu Esquilo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kEv5GWDZQsafboxEun2Ua17xaSZ.jpg'),
(109400, 7844, 'Andy e Seu Esquilo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3brroJ7KK08oSEFypsLeZVCXemo.jpg'),
(109401, 7844, 'Andy e Seu Esquilo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3brroJ7KK08oSEFypsLeZVCXemo.jpg'),
(109402, 7844, 'Andy e Seu Esquilo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/WmLeIe3W8lltumKK7g9CK0BCyN.jpg'),
(109403, 7844, 'Andy e Seu Esquilo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/WmLeIe3W8lltumKK7g9CK0BCyN.jpg'),
(109404, 7844, 'Andy e Seu Esquilo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nhRfx6SldfwaunaB7I4IrAEDHui.jpg'),
(109405, 7845, 'Andy e Seu Esquilo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l776ySwJFFA6ZUh9KVr3tkLXqKa.jpg'),
(109406, 7845, 'Andy e Seu Esquilo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l776ySwJFFA6ZUh9KVr3tkLXqKa.jpg'),
(109407, 7845, 'Andy e Seu Esquilo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJuxf90ZnDunJ7Doq0Y8KiIy1dM.jpg'),
(109408, 7845, 'Andy e Seu Esquilo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJuxf90ZnDunJ7Doq0Y8KiIy1dM.jpg'),
(109409, 7845, 'Andy e Seu Esquilo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/38wE92prlvwHo0OMaH7xlShy4hV.jpg'),
(109410, 7845, 'Andy e Seu Esquilo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/38wE92prlvwHo0OMaH7xlShy4hV.jpg'),
(109411, 7845, 'Andy e Seu Esquilo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Jdv66HCVv6GTsqqZnIoknRHVpy.jpg'),
(109412, 7845, 'Andy e Seu Esquilo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Jdv66HCVv6GTsqqZnIoknRHVpy.jpg'),
(109413, 7845, 'Andy e Seu Esquilo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dPeCofiuiAleK165QdQqOmtFz6h.jpg'),
(109414, 7845, 'Andy e Seu Esquilo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dPeCofiuiAleK165QdQqOmtFz6h.jpg'),
(109415, 7845, 'Andy e Seu Esquilo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWcBF5AQ3HHImE49EJwINvVQ2Hd.jpg'),
(109416, 7845, 'Andy e Seu Esquilo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWcBF5AQ3HHImE49EJwINvVQ2Hd.jpg'),
(109417, 7845, 'Andy e Seu Esquilo S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/frQwHEqcAbmN56agVNzj2NFnbKZ.jpg'),
(109418, 7846, 'Art Attack: Modo Desafio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10CTxuKTyxkCbx8pbIk1NKLSro5.jpg'),
(109419, 7846, 'Art Attack: Modo Desafio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10CTxuKTyxkCbx8pbIk1NKLSro5.jpg'),
(109420, 7846, 'Art Attack: Modo Desafio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10CTxuKTyxkCbx8pbIk1NKLSro5.jpg'),
(109421, 7846, 'Art Attack: Modo Desafio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10CTxuKTyxkCbx8pbIk1NKLSro5.jpg'),
(109422, 7846, 'Art Attack: Modo Desafio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10CTxuKTyxkCbx8pbIk1NKLSro5.jpg'),
(109423, 7846, 'Art Attack: Modo Desafio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10CTxuKTyxkCbx8pbIk1NKLSro5.jpg'),
(109424, 7846, 'Art Attack: Modo Desafio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10CTxuKTyxkCbx8pbIk1NKLSro5.jpg'),
(109425, 7846, 'Art Attack: Modo Desafio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10CTxuKTyxkCbx8pbIk1NKLSro5.jpg'),
(109426, 7846, 'Art Attack: Modo Desafio S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10CTxuKTyxkCbx8pbIk1NKLSro5.jpg'),
(109427, 7846, 'Art Attack: Modo Desafio S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10CTxuKTyxkCbx8pbIk1NKLSro5.jpg'),
(109428, 7846, 'Art Attack: Modo Desafio S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10CTxuKTyxkCbx8pbIk1NKLSro5.jpg'),
(109429, 7846, 'Art Attack: Modo Desafio S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10CTxuKTyxkCbx8pbIk1NKLSro5.jpg'),
(109430, 7847, 'Batwheels S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/221274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aXVqlyjFZjRQ033GRhLK90qcRs4.jpg'),
(109431, 7847, 'Batwheels S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/221275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jrhr3HFh8CwDYDsG3uQDM9O6zos.jpg'),
(109432, 7847, 'Batwheels S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/221276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bpnhiXRUu6om5vtJlEtau8dIP4F.jpg'),
(109433, 7847, 'Batwheels S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/221277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5psG7GUVYUHs9Ftvzm7X54SvshI.jpg'),
(109434, 7847, 'Batwheels S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/221278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7GeiT95n9FfvP5BYfrQPL5dqaeh.jpg'),
(109435, 7847, 'Batwheels S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/221279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xdw0GEjOrDex7canbvnRFf6ozEH.jpg'),
(109436, 7847, 'Batwheels S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/221280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMkT4U503nQXL8XMOJpPI5jyZby.jpg'),
(109437, 7847, 'Batwheels S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/221281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qT4AS6c4QhMWl2wjsfQkdDIciYq.jpg'),
(109438, 7847, 'Batwheels S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/221282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/39WkxKgixuNaxOQo27BFhzk4Pe7.jpg'),
(109439, 7847, 'Batwheels S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/221283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sjDQHdVWAD6BgmNCrUNyIcj5AwU.jpg'),
(109440, 7847, 'Batwheels S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/221284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nEb8rN46cG2vdeR6UHqZAp9VHYW.jpg'),
(109441, 7847, 'Batwheels S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/221285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vBkAIi0RrOHKqdgXDuIYLW9ekx2.jpg'),
(109442, 7847, 'Batwheels S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/221286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q4vRiFLmwWfCyNIJoYwhqxK2SR8.jpg'),
(109443, 7847, 'Batwheels S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/221287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dm7ekArFvtRLWYnOYFvLv7G16ru.jpg'),
(109444, 7847, 'Batwheels S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/221288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oMeq9rDYY2ztHf0Mx7oJVustQbB.jpg'),
(109445, 7847, 'Batwheels S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/221289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jrgJVCie2IugxzpQ4ODINQS2LGf.jpg'),
(109446, 7847, 'Batwheels S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/221290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mQ7uvtK4E3LxnuXpqSoH6FdLr0l.jpg'),
(109447, 7847, 'Batwheels S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/221291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbkVGj483e3SMyjyvTrArUVZDBp.jpg'),
(109448, 7847, 'Batwheels S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/221292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cxGFWJxTQYaqLlspXTg7fVdePPz.jpg'),
(109449, 7847, 'Batwheels S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/221293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n9LJUbAOARY4v2dgmlP6KbIX67Z.jpg'),
(109450, 7847, 'Batwheels S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/221294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kUFxusy91EnLcdQl85mjjaymwN.jpg'),
(109451, 7847, 'Batwheels S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/221295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Gl1McchlZl8LJ0TiGgccTAa1gT.jpg'),
(109452, 7848, 'Beleza Interior [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWS8oilya6vbaZWKIJf4U0DIDGS.jpg'),
(109453, 7848, 'Beleza Interior [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r9RiuDVUrklryCjQWoC93ddWfjm.jpg'),
(109454, 7848, 'Beleza Interior [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2c6XDPUWP2mslzmQdaAx8Thbpxw.jpg'),
(109455, 7848, 'Beleza Interior [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1AispMPPNkzwV3YREunP1j1wE2b.jpg'),
(109456, 7848, 'Beleza Interior [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2spnPyDiGZJt8Ot9Iiw2gb5Q8BW.jpg'),
(109457, 7848, 'Beleza Interior [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pEplw2Y8MAbCWYFgtB90E00GwLe.jpg'),
(109458, 7848, 'Beleza Interior [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gKgbzWU1P0Svx8rGyWy8V5v6omD.jpg'),
(109459, 7848, 'Beleza Interior [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cdKmlSJ9icfoMBtcL4mlYGeYSKy.jpg'),
(109460, 7848, 'Beleza Interior [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/olOrfapdJSMlnxnWJy4DFvgC4zv.jpg'),
(109461, 7848, 'Beleza Interior [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xkaEe6JYDMeYKTkr6DRofNKq8OI.jpg'),
(109462, 7848, 'Beleza Interior [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLevAWtsKg1TNthgVP3Hw3Nq2Yu.jpg'),
(109463, 7848, 'Beleza Interior [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/227842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mrCXJfOolkguoLQToDZCHnMmCfP.jpg'),
(109464, 7848, 'Beleza Interior [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/227843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6hM1rCgUz18FPJVPG8AtdEsoZmk.jpg'),
(109465, 7848, 'Beleza Interior [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/227844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qWNtsvvySOHYnqDnLclbOkK8fq3.jpg'),
(109466, 7848, 'Beleza Interior [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/227845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rrKwk5MO9Ef3AYZGw7Kewpx03Kh.jpg'),
(109467, 7848, 'Beleza Interior [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/227846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhSyEMQMwE1TafCbhrnON3QVXCs.jpg'),
(109468, 7849, 'Božena [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bh1Fz0J9uyOmuAgYEYFoGL8nB5j.jpg'),
(109469, 7849, 'Božena [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bh1Fz0J9uyOmuAgYEYFoGL8nB5j.jpg'),
(109470, 7849, 'Božena [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bh1Fz0J9uyOmuAgYEYFoGL8nB5j.jpg'),
(109471, 7849, 'Božena [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bh1Fz0J9uyOmuAgYEYFoGL8nB5j.jpg'),
(109472, 7850, 'Calle e Poche: Sem Filtro [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7YY7iTUtg5ylpvZ8t7Azrk5jEv7.jpg'),
(109473, 7850, 'Calle e Poche: Sem Filtro [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wdWP2D9xFmi57KgD5L3IymkPfrp.jpg'),
(109474, 7850, 'Calle e Poche: Sem Filtro [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lagMxnYfpkvHpJRwgoO3BSmwXst.jpg'),
(109475, 7850, 'Calle e Poche: Sem Filtro [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Jsz1Kq32nPdvxZXB7hSpOXDYkW.jpg'),
(109476, 7850, 'Calle e Poche: Sem Filtro [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1pcquWCMx2bKeq92ASQXV4TsiTw.jpg'),
(109477, 7850, 'Calle e Poche: Sem Filtro [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yRg9xLQJ4yIFGf6Eh95tJ5HmqDZ.jpg'),
(109478, 7850, 'Calle e Poche: Sem Filtro [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zlHyQnS3smU7PJR10XoqXb9DOAf.jpg'),
(109479, 7850, 'Calle e Poche: Sem Filtro [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6veKv0o6SGumlXpD9ETTAbLMwxh.jpg'),
(109480, 7851, 'Casa dos Sonhos da Barbie: O Desafio [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1EsUzTQQPV41B1Bwk9vzHZTXxfW.jpg'),
(109481, 7852, 'Delightfully Deceitful [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1si5dJGcISJw7VKDvEZSWJYVdjy.jpg'),
(109482, 7852, 'Delightfully Deceitful [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dG1KZ9DyRpjHcsiTcvj6Qe4GPGh.jpg'),
(109483, 7852, 'Delightfully Deceitful [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nc7oRQriKKEjz51oeBZMpTwckxc.jpg'),
(109484, 7852, 'Delightfully Deceitful [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b2OGlM4iIT5nlglC5cJL3DWODwC.jpg'),
(109485, 7852, 'Delightfully Deceitful [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dP1ZM6ogVYiAYrwsYrC7gWkPlXc.jpg'),
(109486, 7852, 'Delightfully Deceitful [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7d8neZB1zYEcmGzUV2js4yk9rW4.jpg'),
(109487, 7852, 'Delightfully Deceitful [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zcgASe5rHNrdDSWfV6J3mhE3Ssr.jpg'),
(109488, 7852, 'Delightfully Deceitful [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pssgmsKGogdd1e10vqpXbV5GDE1.jpg'),
(109489, 7852, 'Delightfully Deceitful [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wwJLjIJIyBJp3PbJcNtvbk3b2Fy.jpg'),
(109490, 7852, 'Delightfully Deceitful [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqbNOjf6dTt5KNCAMjco5oWt8QZ.jpg'),
(109491, 7852, 'Delightfully Deceitful [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2JvWDzs74vDR4Nuf5ZNqAiRjap.jpg'),
(109492, 7852, 'Delightfully Deceitful [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/227813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tyccclybIcqRlJDHyu60g0HRm2x.jpg'),
(109493, 7852, 'Delightfully Deceitful [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/227814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7KEreoWIKFdMCSj9L7suzJ0mZXb.jpg'),
(109494, 7852, 'Delightfully Deceitful [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/227815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/676VqEORowDjl4Kyd3xzcQnqLLk.jpg'),
(109495, 7852, 'Delightfully Deceitful [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/227816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/as2XgA8c2aoXnMg460v6YRbBwcT.jpg'),
(109496, 7852, 'Delightfully Deceitful [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/227817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6KaCJSxL4vdjZZMoANhsCeg62bx.jpg'),
(109497, 7853, 'Dr. Romântico [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2bVHGFzX4xXcnehSQ9DZOZ59gpI.jpg'),
(109498, 7853, 'Dr. Romântico [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3K1eixXj9fn7QWStZ3DwOIVlWI6.jpg'),
(109499, 7853, 'Dr. Romântico [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h0DcGOxiOHbMnm6xrxXahDvBZ9E.jpg'),
(109500, 7853, 'Dr. Romântico [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1n5dOiQIRzHeiLdcep2TTfK19YQ.jpg'),
(109501, 7853, 'Dr. Romântico [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/foJF8wK5OFRdwIZUkdd29YSzkuv.jpg'),
(109502, 7853, 'Dr. Romântico [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ctJURN5kIh4xmMh05SDOeDtNCIx.jpg'),
(109503, 7853, 'Dr. Romântico [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lxeifZ7OZQLzkdFnWqGj7vNHnB6.jpg'),
(109504, 7853, 'Dr. Romântico [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJwfwIHlggdWFZxmc4FhhJbKYpg.jpg'),
(109505, 7853, 'Dr. Romântico [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2PY4VvdOg06ewFYKMds8OQO5dK.jpg'),
(109506, 7853, 'Dr. Romântico [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6YZj70NCEjN0UlvEYY1u5T3Ttja.jpg'),
(109507, 7853, 'Dr. Romântico [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c36QlyfgPtXsldxSMuZ4oD6tBET.jpg'),
(109508, 7853, 'Dr. Romântico [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/227760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v4rPBtzptocvanmKmH0ukhWNMq4.jpg'),
(109509, 7853, 'Dr. Romântico [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/227761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8gGj5MkL8GlAmguLyKYF3l1RMaZ.jpg'),
(109510, 7853, 'Dr. Romântico [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/227762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zJ9kupEf9A6TUmMpesexlNxwky3.jpg'),
(109511, 7853, 'Dr. Romântico [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/227763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yJiN1Wyz374CE2M0Z5K3ncWnRhV.jpg'),
(109512, 7853, 'Dr. Romântico [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/227764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sNwwpnfsJUl33iISucM7ekvU07l.jpg'),
(109513, 7853, 'Dr. Romântico [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/227765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xIwM5mAMkWlYrAxScTyhsWLQNOc.jpg'),
(109514, 7853, 'Dr. Romântico [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/227766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fMdiAGQp7wIg6qYRQP8gkQiMyph.jpg'),
(109515, 7853, 'Dr. Romântico [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/227767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ahygPfMDswvyAwPPooTXjMXXq91.jpg'),
(109516, 7853, 'Dr. Romântico [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/227768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iukqY3nWyZ2rWwxjMpnONxbwKG3.jpg'),
(109517, 7853, 'Dr. Romântico [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/227769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eBbxLx6Gzz7sG1oE8FXNQPjYOV7.jpg'),
(109518, 7854, 'Dr. Romântico [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x4dNx1qTUOfGQz3LLJ6i9NcSlWd.jpg'),
(109519, 7854, 'Dr. Romântico [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lsKMzL6O3wLQ0llLE2LfdVCNa14.jpg'),
(109520, 7854, 'Dr. Romântico [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cebsLZ8nnVGPM23lgr1mbmXlEbw.jpg'),
(109521, 7854, 'Dr. Romântico [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/giju16GI0asZBBBt8yt61w152CB.jpg'),
(109522, 7854, 'Dr. Romântico [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3FHYRNmg1P7JcHYvcnSpOsSNNJV.jpg'),
(109523, 7854, 'Dr. Romântico [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ovwcSwPBWGch1KzItOkHPREONsl.jpg'),
(109524, 7854, 'Dr. Romântico [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJrg1ikOdfPrBubmsGJglcu0OzU.jpg'),
(109525, 7854, 'Dr. Romântico [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uifxwvkImGZ63CdFMJ6GSFUkFCn.jpg'),
(109526, 7854, 'Dr. Romântico [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8e3WOKMq1QrpQl0cDgJZa4UUoKR.jpg'),
(109527, 7854, 'Dr. Romântico [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s9Ey3vzfQfunH0HQd8GIzcALEcz.jpg'),
(109528, 7854, 'Dr. Romântico [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xu4XwICPYiP981MbOq8onHZftjN.jpg'),
(109529, 7854, 'Dr. Romântico [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/227781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qtqqeItmwGepPk03D5g72gEwo0.jpg'),
(109530, 7854, 'Dr. Romântico [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/227782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/el9uOC8f7q7NX75NXflK09fFJpi.jpg'),
(109531, 7854, 'Dr. Romântico [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/227783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pTK873jIgg7gXAITAX6zPcLHqNK.jpg'),
(109532, 7854, 'Dr. Romântico [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/227784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/skuFEl71G6mKQGUxWIMfQQAB46n.jpg'),
(109533, 7854, 'Dr. Romântico [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/227785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8DyzAYJlSx00dT6X6iq7xQN9J8m.jpg'),
(109534, 7855, 'Dr. Romântico [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5TUSzlE7cbZali344CAI5GEoQzF.jpg'),
(109535, 7855, 'Dr. Romântico [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9HLicvEdlK2YpPA3DPc1snkAIjU.jpg'),
(109536, 7855, 'Dr. Romântico [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8uUjPaFT8bA9zBunNxFlizLj7K6.jpg'),
(109537, 7855, 'Dr. Romântico [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nd0i19pLbLKEZK4zJ8uauOE3KCq.jpg'),
(109538, 7855, 'Dr. Romântico [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Ln3KSr4BTId9o3OTeNmEQyM3a5.jpg'),
(109539, 7855, 'Dr. Romântico [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a8ZEbHSJvqYyHPAfb7SU6prP6EL.jpg'),
(109540, 7855, 'Dr. Romântico [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l53E2PP7TC0VKBoKHaGNPSk6GlW.jpg'),
(109541, 7855, 'Dr. Romântico [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8A8NDAOWKCUxIy2FbQS3uiUdLu.jpg'),
(109542, 7855, 'Dr. Romântico [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5lFrMTVSKmH86QnriZwc6PovAT8.jpg'),
(109543, 7855, 'Dr. Romântico [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qcn6mmqvI0lwcRuR3RrXBJSkyg0.jpg'),
(109544, 7855, 'Dr. Romântico [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d70kcZYkJWJvYNqr7pjIgl02Ngy.jpg'),
(109545, 7855, 'Dr. Romântico [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/227797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tA21p21HCmml0816RMurBSTMIDw.jpg'),
(109546, 7855, 'Dr. Romântico [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/227798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jJX9nIgU63hU8q9ozC9zc5bCXqU.jpg'),
(109547, 7855, 'Dr. Romântico [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/227799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bcDqPTYU82Y2xhmzVWmOQHAqsiE.jpg'),
(109548, 7855, 'Dr. Romântico [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/227800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/30GX8pKGEmY9kKSsNtyii0wDc8h.jpg'),
(109549, 7855, 'Dr. Romântico [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/227801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6D2Yz9foBBmADRJEjKevDj5kZD5.jpg'),
(109550, 7856, 'Durians Affair [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzAaXZQH6dQIUBKnCnYBsBjxNMU.jpg'),
(109551, 7856, 'Durians Affair [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zKo9qCjzRIyQiys9qIYSKQZsbq8.jpg'),
(109552, 7856, 'Durians Affair [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7bqIWajg1C2wlWI81qN4NFWC2yO.jpg'),
(109553, 7856, 'Durians Affair [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231977.mp4', 'http://image.tmdb.org/t/p/w1280/n8M1OBHdtZ5d9zt4KCrY93Cj9xE.jpg'),
(109554, 7856, 'Durians Affair [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7GDQF0JuPsKVPiwK4SrpZXeqQKJ.jpg'),
(109555, 7856, 'Durians Affair [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gwt1xhJSoBjtO7dJ9aR9PZQSowM.jpg'),
(109556, 7856, 'Durians Affair [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9wVeYzOyAHlEvFxqobyafO2xN5h.jpg'),
(109557, 7856, 'Durians Affair [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ls3ai0Q14KcHc7Z6GhZUYSvcLEt.jpg'),
(109558, 7856, 'Durians Affair [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/20oHvvjIo8Tt4fyd202OP6MQIqZ.jpg'),
(109559, 7856, 'Durians Affair [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2oBEHi7eej3FPXFpWoTy2zEeCdm.jpg'),
(109560, 7856, 'Durians Affair [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/231984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2IvrFzYK5IsC3Q6lU3qrr4Ca2xI.jpg'),
(109561, 7856, 'Durians Affair [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/231985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a7FW2niCOfHPVai1myEasvPwEs3.jpg'),
(109562, 7856, 'Durians Affair [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/231986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2xpZb4nC011XldN4MtaDc6RtYWU.jpg'),
(109563, 7856, 'Durians Affair [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/231987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cXozhjIEFdEWstA1pYsEC1DONg1.jpg'),
(109564, 7856, 'Durians Affair [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/231988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1mJZRNw1HD9wrYUrtNvByo4X4L.jpg'),
(109565, 7856, 'Durians Affair [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/231989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hG9GC3iL0cMyZkR6eLkhZMPEgb3.jpg'),
(109566, 7857, 'Fiel ao Amor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rcZWU4PFTpchF15nliEwaIw2PWp.jpg'),
(109567, 7857, 'Fiel ao Amor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aaTuZfYH2xtMVVt2byVDpDgqWv3.jpg'),
(109568, 7857, 'Fiel ao Amor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sqrFxezAkyycYNbvH9Zf130JAdW.jpg'),
(109569, 7857, 'Fiel ao Amor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c51EBLAj5S1krNuHcwDdnA333l4.jpg'),
(109570, 7857, 'Fiel ao Amor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dKp7ueIouLScHGqFdeta8u8ptFg.jpg'),
(109571, 7857, 'Fiel ao Amor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gGMaFfY5WDJQLs1y6Wp8EPnTcso.jpg'),
(109572, 7857, 'Fiel ao Amor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ewDmNVqVyWwfXG8e78JrDQWRY0H.jpg'),
(109573, 7857, 'Fiel ao Amor [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v6nWMdgD8YkyQybZB4a2pCY7Vt3.jpg'),
(109574, 7857, 'Fiel ao Amor [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6c0yFZgyPw6SjTtufDcWuTSArcT.jpg'),
(109575, 7857, 'Fiel ao Amor [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uV6nh8QJUkOjNdXaaT1xu1Xc8SJ.jpg'),
(109576, 7857, 'Fiel ao Amor [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h26dBoHez7qtpFHnJYcuE5a7A5B.jpg'),
(109577, 7857, 'Fiel ao Amor [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/227745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dNYrfMKITcKa9bwS5CiNudOwJhe.jpg'),
(109578, 7857, 'Fiel ao Amor [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/227746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1evW2cLEFUqV4pYHmwJsmLZ3lCi.jpg'),
(109579, 7857, 'Fiel ao Amor [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/227747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bOGi9TBECpzWEzDgasN3V45gZxE.jpg'),
(109580, 7857, 'Fiel ao Amor [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/227748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/875RjqCYWZJMi59OVUnKEhNFJDz.jpg'),
(109581, 7858, 'Gigantes da Era do Gelo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v1R2vN1ZmxFLaqBJFNoJB4phMT6.jpg'),
(109582, 7858, 'Gigantes da Era do Gelo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v1R2vN1ZmxFLaqBJFNoJB4phMT6.jpg'),
(109583, 7858, 'Gigantes da Era do Gelo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v1R2vN1ZmxFLaqBJFNoJB4phMT6.jpg'),
(109584, 7859, 'Heartbeat [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gj8WaswEa4LY8dZcSGCKmw0SjmL.jpg'),
(109585, 7859, 'Heartbeat [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wiNa9n1eBNrZ7AiF6oPEeUMt3Qt.jpg'),
(109586, 7859, 'Heartbeat [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dVD1g98Wc21FJWCqBj466hWnz7w.jpg'),
(109587, 7859, 'Heartbeat [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/94Cs8qy3C9ki4dSuVgtymnZKjJP.jpg'),
(109588, 7859, 'Heartbeat [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7DnFWD3AfvXr3Ny5i9OIUYNAHv.jpg'),
(109589, 7859, 'Heartbeat [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zfNg1PBorRzICe0BsaMXPayTaVD.jpg'),
(109590, 7859, 'Heartbeat [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzVYPNYg1qLuyP8xKu5A4cPu4P6.jpg'),
(109591, 7859, 'Heartbeat [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cjmSkKDDtggmrlHvaKMq74xep90.jpg'),
(109592, 7859, 'Heartbeat [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nPaOgdPigmMR7yAUN1eYzxkxjhx.jpg'),
(109593, 7859, 'Heartbeat [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hhKfprCv2ViQQS8Kr8NCQB9O7Cw.jpg'),
(109594, 7859, 'Heartbeat [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqAoVTAJc3CjWWvDmfd9Sjq5rV6.jpg'),
(109595, 7859, 'Heartbeat [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqAoVTAJc3CjWWvDmfd9Sjq5rV6.jpg'),
(109596, 7859, 'Heartbeat [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqAoVTAJc3CjWWvDmfd9Sjq5rV6.jpg'),
(109597, 7859, 'Heartbeat [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/235504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqAoVTAJc3CjWWvDmfd9Sjq5rV6.jpg'),
(109598, 7859, 'Heartbeat [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/235505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqAoVTAJc3CjWWvDmfd9Sjq5rV6.jpg'),
(109599, 7859, 'Heartbeat [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/235506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kqAoVTAJc3CjWWvDmfd9Sjq5rV6.jpg'),
(109600, 7860, 'KAMEN RIDER GEATS [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109601, 7860, 'KAMEN RIDER GEATS [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109602, 7860, 'KAMEN RIDER GEATS [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109603, 7860, 'KAMEN RIDER GEATS [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109604, 7860, 'KAMEN RIDER GEATS [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109605, 7860, 'KAMEN RIDER GEATS [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109606, 7860, 'KAMEN RIDER GEATS [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109607, 7860, 'KAMEN RIDER GEATS [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109608, 7860, 'KAMEN RIDER GEATS [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109609, 7860, 'KAMEN RIDER GEATS [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109610, 7860, 'KAMEN RIDER GEATS [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109611, 7860, 'KAMEN RIDER GEATS [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109612, 7860, 'KAMEN RIDER GEATS [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109613, 7860, 'KAMEN RIDER GEATS [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109614, 7860, 'KAMEN RIDER GEATS [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109615, 7860, 'KAMEN RIDER GEATS [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109616, 7860, 'KAMEN RIDER GEATS [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(109617, 7860, 'KAMEN RIDER GEATS [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/234016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109618, 7860, 'KAMEN RIDER GEATS [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/234017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109619, 7860, 'KAMEN RIDER GEATS [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/234018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109620, 7860, 'KAMEN RIDER GEATS [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/234019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109621, 7860, 'KAMEN RIDER GEATS [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/234020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109622, 7860, 'KAMEN RIDER GEATS [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/234021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109623, 7860, 'KAMEN RIDER GEATS [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/234022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109624, 7860, 'KAMEN RIDER GEATS [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/234023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109625, 7860, 'KAMEN RIDER GEATS [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/234024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109626, 7860, 'KAMEN RIDER GEATS [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/234025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109627, 7860, 'KAMEN RIDER GEATS [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/234026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109628, 7860, 'KAMEN RIDER GEATS [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/234027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109629, 7860, 'KAMEN RIDER GEATS [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/234028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109630, 7860, 'KAMEN RIDER GEATS [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/234029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109631, 7860, 'KAMEN RIDER GEATS [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/234030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109632, 7860, 'KAMEN RIDER GEATS [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/234031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109633, 7860, 'KAMEN RIDER GEATS [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/234032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109634, 7860, 'KAMEN RIDER GEATS [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/234033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109635, 7860, 'KAMEN RIDER GEATS [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/234034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109636, 7860, 'KAMEN RIDER GEATS [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/234035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109637, 7860, 'KAMEN RIDER GEATS [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/234036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109638, 7860, 'KAMEN RIDER GEATS [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/234037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109639, 7860, 'KAMEN RIDER GEATS [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/234038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109640, 7860, 'KAMEN RIDER GEATS [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/234039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109641, 7860, 'KAMEN RIDER GEATS [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/234040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109642, 7860, 'KAMEN RIDER GEATS [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/234041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109643, 7860, 'KAMEN RIDER GEATS [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/234042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109644, 7860, 'KAMEN RIDER GEATS [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/234043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109645, 7860, 'KAMEN RIDER GEATS [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/234044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109646, 7860, 'KAMEN RIDER GEATS [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/234045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109647, 7860, 'KAMEN RIDER GEATS [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/234046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109648, 7860, 'KAMEN RIDER GEATS [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/234047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nQYMDroqzAatxwIV3tABQHzZJSl.jpg'),
(109649, 7861, 'Kizazi Moto: Geração Fogo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pilsYOtqw9tDs6bhml7Nb2JjhKU.jpg'),
(109650, 7861, 'Kizazi Moto: Geração Fogo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pilsYOtqw9tDs6bhml7Nb2JjhKU.jpg'),
(109651, 7861, 'Kizazi Moto: Geração Fogo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pilsYOtqw9tDs6bhml7Nb2JjhKU.jpg'),
(109652, 7861, 'Kizazi Moto: Geração Fogo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pilsYOtqw9tDs6bhml7Nb2JjhKU.jpg'),
(109653, 7861, 'Kizazi Moto: Geração Fogo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pilsYOtqw9tDs6bhml7Nb2JjhKU.jpg'),
(109654, 7861, 'Kizazi Moto: Geração Fogo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pilsYOtqw9tDs6bhml7Nb2JjhKU.jpg'),
(109655, 7861, 'Kizazi Moto: Geração Fogo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pilsYOtqw9tDs6bhml7Nb2JjhKU.jpg'),
(109656, 7861, 'Kizazi Moto: Geração Fogo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pilsYOtqw9tDs6bhml7Nb2JjhKU.jpg'),
(109657, 7861, 'Kizazi Moto: Geração Fogo [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pilsYOtqw9tDs6bhml7Nb2JjhKU.jpg'),
(109658, 7861, 'Kizazi Moto: Geração Fogo [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pilsYOtqw9tDs6bhml7Nb2JjhKU.jpg'),
(109659, 7862, 'Lies Hidden in My Garden [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oXNfda83J39KXogZQmbLCyqgZPp.jpg'),
(109660, 7862, 'Lies Hidden in My Garden [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ztaMOGu7QpUGXCpZyvKLKCqC3N.jpg'),
(109661, 7862, 'Lies Hidden in My Garden [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/altakRSA7KDzHztbtQF8et8znCi.jpg'),
(109662, 7862, 'Lies Hidden in My Garden [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gkh3epVw6LAwLTwhpltMOLDWQUw.jpg'),
(109663, 7862, 'Lies Hidden in My Garden [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ooFsK3pDVTzl0jhIWL2aWHufPbD.jpg'),
(109664, 7862, 'Lies Hidden in My Garden [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9BJVqAnFA2e8qrLXGGGC8AdIVwC.jpg'),
(109665, 7862, 'Lies Hidden in My Garden [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/klWfWP7G6bjVXnVikHT6O2Xdk1v.jpg'),
(109666, 7862, 'Lies Hidden in My Garden [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/72RmuL9quXLW8FZoad9OsoRiYty.jpg'),
(109667, 7863, 'Ludmilla: Rainha da Favela S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eo3ABcLUULuJW6jcdjb9ooP4K7o.jpg'),
(109668, 7863, 'Ludmilla: Rainha da Favela S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x7Dna3PuG1SSmMgSc4TTHupoi9M.jpg'),
(109669, 7863, 'Ludmilla: Rainha da Favela S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gkwhrJQacCCcj6ZlP4V5rXxEeiz.jpg'),
(109670, 7863, 'Ludmilla: Rainha da Favela S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hbNoxPssRmbFVAD17nfZIlWP59R.jpg'),
(109671, 7863, 'Ludmilla: Rainha da Favela S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gxX8RWGKiXstfuT9SVC8xesuZEb.jpg'),
(109672, 7863, 'Ludmilla: Rainha da Favela S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/27YSb9SRnl1pOMmXOTzWTZplq8M.jpg'),
(109673, 7864, 'Miraculous Brothers [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4kAX6j3UXoYBfpo0YryTEp38DgJ.jpg'),
(109674, 7864, 'Miraculous Brothers [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5KxoIYMtLbLVCSejW822Z4c0JcK.jpg'),
(109675, 7864, 'Miraculous Brothers [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sCue20M66VJaLHCqOvsqFXkXzYT.jpg'),
(109676, 7865, 'North Shore [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9BR0IZjo0Xe6q7eXh8IFDTleGhC.jpg'),
(109677, 7865, 'North Shore [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6EANabbhNn66GTiN3Vh7mBhGKmd.jpg'),
(109678, 7865, 'North Shore [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wWXc58NSs1gn7roJqBU5KqecIg4.jpg'),
(109679, 7865, 'North Shore [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdUf7Cdqbl41bLuXh0BMH21WnKM.jpg'),
(109680, 7865, 'North Shore [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hOcmtFiOoZVwoQLC7ZWb0aXR5BW.jpg'),
(109681, 7865, 'North Shore [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3NleEb2rbrI7RNj5g5pbNiSEB5E.jpg'),
(109682, 7866, 'Not Others [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWVyyDnu9tr2jZLPMEPyDpErday.jpg'),
(109683, 7866, 'Not Others [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7awDDiT8UdgDeS6JGrfRaaJncZV.jpg'),
(109684, 7866, 'Not Others [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k50fmXlx46jJxNH9OZkZyofcGir.jpg'),
(109685, 7866, 'Not Others [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ovIqiAqhMu0N2VxPDpiO1136Zv.jpg'),
(109686, 7866, 'Not Others [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r0d8Xsy1m15CZTBnY3c5cpldLQ0.jpg'),
(109687, 7866, 'Not Others [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9iAyl8D7OGRCopDssEZFW2voUl0.jpg'),
(109688, 7866, 'Not Others [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jD6allq5XsVv5y2N8UVM2LnaWTk.jpg'),
(109689, 7866, 'Not Others [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/djjH8fhPeI7pY5rBKmvC9yIjK3i.jpg'),
(109690, 7866, 'Not Others [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oaq5l5B2WiIcXUdoo75BqHBjCZo.jpg'),
(109691, 7866, 'Not Others [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ggRACQGcC51Ckyo9uSpTkDMtZ9m.jpg'),
(109692, 7866, 'Not Others [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/231888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qD7MqUKzqZjKHOSRMwcXnGjS5qa.jpg'),
(109693, 7866, 'Not Others [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/231889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uA9BCWwLZ5KklUKhG9sDuMCHTP.jpg'),
(109694, 2674, 'Pátria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qy9VEufLjGkdwo7eSIedCljyZXX.jpg'),
(109695, 2674, 'Pátria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gRLg0ZxIidZD1A9fWDN97FpVFKV.jpg'),
(109696, 2674, 'Pátria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3th2JHniM9EMWRnFUptBpdxX4ae.jpg'),
(109697, 2674, 'Pátria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svh1patkAG2sXqd7s8ixNMKiJcC.jpg'),
(109698, 2674, 'Pátria S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xAkRy8K5oi0SbCeydqfReISRtyP.jpg'),
(109699, 2674, 'Pátria S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/liIwNo6efzp2R5EVHEXB5FOXdf.jpg'),
(109700, 2674, 'Pátria S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gHtwDWZ7PvCIJb8ttg2EY1LoFj8.jpg'),
(109701, 2674, 'Pátria S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kpnIC5oOtVMSD5BX8irumVTn5Yn.jpg'),
(109702, 7867, 'Querida Mamãe [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zCGEbe8q5f1FQSe1OwAkfviIvje.jpg'),
(109703, 7867, 'Querida Mamãe [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tyiSWIqbjfuWSpdxUMq9LPSJDue.jpg'),
(109704, 7867, 'Querida Mamãe [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ibqBa0o8AdXAt9HT1M8CM7Tvgg7.jpg'),
(109705, 7867, 'Querida Mamãe [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eduqoSdRM77GX2gYF1dj0JFMgbw.jpg'),
(109706, 7867, 'Querida Mamãe [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A1FQv0BmXLrFqpKWWazFrHg1wN9.jpg'),
(109707, 7868, 'Revenant [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ik2VgtQTFbUJNILVeRhRCRV8f0G.jpg'),
(109708, 7868, 'Revenant [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h6r4l54duZlTxLx9yTR8zmF7i9H.jpg'),
(109709, 7868, 'Revenant [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jGSAdFzXCPNCsY9NHdAy7EVmMgH.jpg'),
(109710, 7868, 'Revenant [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uLuG6UuJMhvo3jbZCTeLe6JmucW.jpg'),
(109711, 7868, 'Revenant [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nK9ZfTTyy7lUIHrOM8nGXVIa66Z.jpg'),
(109712, 7868, 'Revenant [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uRmjkE7wkfA3UMmv0ERdS61UMAt.jpg'),
(109713, 7868, 'Revenant [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zeQrejbmAzpcjCBRRxSVHSERhUA.jpg'),
(109714, 7868, 'Revenant [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9VEPuubIy3CjhlvbUEzykneKjfd.jpg'),
(109715, 7868, 'Revenant [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7UTiCKu7EvYWK1ee89blNUbYLsE.jpg'),
(109716, 7868, 'Revenant [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3n8gtqFm9vdSTJhb0gS2UNHekwQ.jpg'),
(109717, 7868, 'Revenant [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227643.mp4', 'http://image.tmdb.org/t/p/w1280/rYHNI4tqDXxUk1nGuexxQBc0OOT.jpg'),
(109718, 7868, 'Revenant [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/896193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8KGTljku7ZT9H3vHLe8e5ofybo9.jpg'),
(109719, 7869, 'The Calling [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aA3VOqnQU78LGBrfhOvCl2lvdfu.jpg'),
(109720, 7869, 'The Calling [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7UQkdxz3tvc1KgRdvSeng0H4TCZ.jpg'),
(109721, 7869, 'The Calling [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gpj2srBpkLpaIRzBnjsR62Bdlib.jpg'),
(109722, 7869, 'The Calling [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMUCG3Si16dM6arGPsShgitMANd.jpg'),
(109723, 7869, 'The Calling [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230514.mp4', 'http://image.tmdb.org/t/p/w1280/8TCs236jmLc3qhBU1RSor2kFDVw.jpg'),
(109724, 7869, 'The Calling [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gwGh0rJyeIBohdos4p72lFvq5A6.jpg'),
(109725, 7869, 'The Calling [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ezA9jm5HuzfKmaj4nRAUCRPlRf5.jpg'),
(109726, 7869, 'The Calling [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/54EmUxZ1ywpCPPy65FeygLd0TyQ.jpg'),
(109727, 7841, 'A Cúmplice do Mal: Monique Olivier [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tarhtjSppWa0pOykDft1JJaIWfF.jpg'),
(109728, 7841, 'A Cúmplice do Mal: Monique Olivier [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ZkPVAiGX4fAthoIyoK2pjUfRQ4.jpg'),
(109729, 7841, 'A Cúmplice do Mal: Monique Olivier [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a8hl6Q0xPnsElhSjnfJdUXogEgH.jpg'),
(109730, 7841, 'A Cúmplice do Mal: Monique Olivier [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lOyNjJ6qvZAeZE8q1u5d4UFiLzn.jpg'),
(109731, 7841, 'A Cúmplice do Mal: Monique Olivier [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cdPcY6tJNcLQPCxLbeMqwGnsQgW.jpg'),
(109732, 7870, 'A Geração Golpista [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dtlduUv3IpOEDuo44jVLsjpmkDI.jpg'),
(109733, 7870, 'A Geração Golpista [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1X5X3c90MIHmpSqlKSpDy8sbaTI.jpg'),
(109734, 7870, 'A Geração Golpista [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqbNI21j57aATy7tuGuC5PhLFlO.jpg'),
(109735, 7870, 'A Geração Golpista [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1qEoGZC6LKV6T7FtWmHbSiOv7Eh.jpg'),
(109736, 7870, 'A Geração Golpista [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4LGKad2vfJiiZ0ve1ec1pxaHbUz.jpg'),
(109737, 7870, 'A Geração Golpista [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tkjvlFzzA2DmW8M0byTcmP7XHVg.jpg'),
(109738, 7871, 'Capitão Fall S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i1WVnaGJRBFI5DOWOd5aTXMtQbp.jpg'),
(109739, 7871, 'Capitão Fall S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFzFNC592rpjmmb8Zx5F8EwAERq.jpg'),
(109740, 7871, 'Capitão Fall S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mRV0QlVzIEv9JSREcSKgpkjRZoC.jpg'),
(109741, 7871, 'Capitão Fall S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n2CHulkjPVhAL4orgT82owucKgw.jpg'),
(109742, 7871, 'Capitão Fall S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4omTGTVbGD1e9MQVGnsmbgbnzGO.jpg'),
(109743, 7871, 'Capitão Fall S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4qxyJ8Q9ANPDZdgQXQyJDFudLmG.jpg'),
(109744, 7871, 'Capitão Fall S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sAIzLu5FHMUl9Khj4aWJoaurMwy.jpg'),
(109745, 7871, 'Capitão Fall S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/toHDxkB4PLA6fqa3acKBXXmS1Px.jpg'),
(109746, 7871, 'Capitão Fall S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lRFHaeSYLvS5XszszNDXYfigNr.jpg'),
(109747, 7871, 'Capitão Fall S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jaVEjBJ2poLHzdwytxd9pvD4PZy.jpg'),
(109748, 7872, 'Como Se Tornar um Líder de Seita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qOGaQjm7bfGACiwBqzf7v5j1tyD.jpg'),
(109749, 7872, 'Como Se Tornar um Líder de Seita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AbCAhbj84hMOLalmBx5VxLHuyKv.jpg'),
(109750, 7872, 'Como Se Tornar um Líder de Seita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1fS2ATbKZe2LuBOoOEj46BDRzpC.jpg'),
(109751, 7872, 'Como Se Tornar um Líder de Seita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oDlzSkGkFTLCJcv72DyQoAzQs2C.jpg'),
(109752, 7872, 'Como Se Tornar um Líder de Seita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ZgkcycTjtCg7CuATwVcglpL7Zq.jpg'),
(109753, 7872, 'Como Se Tornar um Líder de Seita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rl07OU71pofpCZ8TH1VyzJvKkF9.jpg'),
(109754, 7873, 'Jantar com Drags [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rd0Ep85LsjgLAmfVYICO5WrlvMA.jpg'),
(109755, 7873, 'Jantar com Drags [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8WuqW3gqN7LeFDDLaqZtFSdTV1x.jpg'),
(109756, 7873, 'Jantar com Drags [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glx0LxezTMw7lA2LrBWwEzP6sht.jpg'),
(109757, 7873, 'Jantar com Drags [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ySQ1Kaj3MQiEZxSGwRptk9ZVfqC.jpg'),
(109758, 7873, 'Jantar com Drags [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9js2EOVWy5sahpg35RhHlk7gdlH.jpg'),
(109759, 7873, 'Jantar com Drags [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xnySI9nT1HMJ3CHxmFXGcu6gQgY.jpg'),
(109760, 7873, 'Jantar com Drags [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bpjz8dXDySwwNfJQwiekzIBJ40w.jpg'),
(109761, 7873, 'Jantar com Drags [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wofpm37NI9dfa4YftQbPRNQtcmt.jpg'),
(109762, 7873, 'Jantar com Drags [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AvUOTxxgzPNcB90FBVI1Kh1raMm.jpg'),
(109763, 7873, 'Jantar com Drags [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PfhvfzwtLcMWAM3rPtHo4TrlQN.jpg'),
(109764, 7874, 'Jovens Herdeiros [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hzVNXctRJMikx1cnSHsjZGe5dek.jpg'),
(109765, 7874, 'Jovens Herdeiros [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ziFDS0zEUX6v6jcg09VBRmos1AZ.jpg'),
(109766, 7874, 'Jovens Herdeiros [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYlGFGZXtPgbV9mMxJy0oXIk5F6.jpg'),
(109767, 7874, 'Jovens Herdeiros [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1yUjCskblG5eGIPfryAdzoywQen.jpg'),
(109768, 7874, 'Jovens Herdeiros [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vidWbHEqB6TEgW3pCAMzAfXiUwj.jpg'),
(109769, 7874, 'Jovens Herdeiros [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aAgP1wOkzTgOg0W6LGxf6wV2k5K.jpg'),
(109770, 7874, 'Jovens Herdeiros [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3JpMWZFFxraw4aBjEZbLPYCCJmo.jpg'),
(109771, 7874, 'Jovens Herdeiros [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qznO88CKRsc5hCi6qkP0Jn9aV3e.jpg'),
(109772, 7874, 'Jovens Herdeiros [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r26L9JCbAkk5LnwK7ajUQNE4BeU.jpg'),
(109773, 7874, 'Jovens Herdeiros [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rp9zlFAq4ubtsd6kAOqcd1ijgiC.jpg'),
(109774, 7874, 'Jovens Herdeiros [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ttyPWKLwyXkfvKbhkeBJHbOofKp.jpg'),
(109775, 7874, 'Jovens Herdeiros [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/227591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/it8LQiCLCHTyMIowC2SxCvL1Tq3.jpg'),
(109776, 7874, 'Jovens Herdeiros [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/227592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bK79jz9Ys79RMqEGdm9uU6kOPHL.jpg'),
(109777, 7874, 'Jovens Herdeiros [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/227593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rOGN2GKJ5wPJSgYGVLTWDOclx3O.jpg'),
(109778, 7874, 'Jovens Herdeiros [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/227594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vLRbR6Tg24Ej8LHBbN7arS7TJUn.jpg'),
(109779, 7874, 'Jovens Herdeiros [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/227595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1wEJKJQFhUxGLaTkdomgXTI2zXX.jpg'),
(109780, 7875, 'Missão Sobrevivência [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/drfPDvov3xBnjGO3JtPh52eeaQC.jpg'),
(109781, 7875, 'Missão Sobrevivência [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sb6i31pxVaeAR2by0CZuI67CZxD.jpg'),
(109782, 7875, 'Missão Sobrevivência [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kU4Z2wNDpGyQT8Y54hlBrC1TLLZ.jpg'),
(109783, 7875, 'Missão Sobrevivência [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Vv5Sgo9N9WGYu01A6KnAJq4GjD.jpg'),
(109784, 7875, 'Missão Sobrevivência [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iapLnoIkjyCjNc2RD0gE01aQj4S.jpg'),
(109785, 7875, 'Missão Sobrevivência [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nxbxwFNltC1L2sZBtducVrVpPbC.jpg'),
(109786, 7875, 'Missão Sobrevivência [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3qSXQRmIAF9aTBLCZqheFgwUx.jpg'),
(109787, 7875, 'Missão Sobrevivência [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8EIXIDzysSVSHb9ZrImestnEW2a.jpg'),
(109788, 7876, 'Missão Sobrevivência [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h3f0hD5mcdLW7XXLqy2KEsgIALb.jpg'),
(109789, 7876, 'Missão Sobrevivência [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rmxEmHqjWPyNLi9O2TI6Hi5zJkF.jpg'),
(109790, 7876, 'Missão Sobrevivência [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ch9qvOFHUOBZXhaG90bFZ5AJNup.jpg'),
(109791, 7876, 'Missão Sobrevivência [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vHgAd0V7OXcdrTH6WUEDcVoJe3O.jpg'),
(109792, 7876, 'Missão Sobrevivência [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iCNSn9H3n5YpaNv3kGS1xmXqFEy.jpg'),
(109793, 7876, 'Missão Sobrevivência [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWjJzgoqx3Mcd2Ssn49u5IVw0eg.jpg'),
(109794, 7876, 'Missão Sobrevivência [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6KYdtiHehIBU4vvaCR3GoZs6VH.jpg'),
(109795, 7876, 'Missão Sobrevivência [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iXoPfpWAxodZDx17ackzCyf5Npt.jpg'),
(109796, 7877, 'Missão Sobrevivência [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/441882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eRVM7PVrOn2ty8g8mHGDV0DEVp5.jpg'),
(109797, 7877, 'Missão Sobrevivência [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/441883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eRVM7PVrOn2ty8g8mHGDV0DEVp5.jpg'),
(109798, 7877, 'Missão Sobrevivência [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/441884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eRVM7PVrOn2ty8g8mHGDV0DEVp5.jpg'),
(109799, 7877, 'Missão Sobrevivência [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/441885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eRVM7PVrOn2ty8g8mHGDV0DEVp5.jpg'),
(109800, 7877, 'Missão Sobrevivência [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/441886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eRVM7PVrOn2ty8g8mHGDV0DEVp5.jpg'),
(109801, 7877, 'Missão Sobrevivência [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/441887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eRVM7PVrOn2ty8g8mHGDV0DEVp5.jpg'),
(109802, 7877, 'Missão Sobrevivência [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/447354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eRVM7PVrOn2ty8g8mHGDV0DEVp5.jpg'),
(109803, 7877, 'Missão Sobrevivência [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/452325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eRVM7PVrOn2ty8g8mHGDV0DEVp5.jpg'),
(109804, 7878, 'My Lethal Man [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109805, 7878, 'My Lethal Man [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109806, 7878, 'My Lethal Man [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109807, 7878, 'My Lethal Man [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109808, 7878, 'My Lethal Man [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109809, 7878, 'My Lethal Man [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109810, 7878, 'My Lethal Man [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109811, 7878, 'My Lethal Man [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109812, 7878, 'My Lethal Man [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109813, 7878, 'My Lethal Man [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109814, 7878, 'My Lethal Man [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109815, 7878, 'My Lethal Man [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/227551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109816, 7878, 'My Lethal Man [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/227552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109817, 7878, 'My Lethal Man [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/227553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109818, 7878, 'My Lethal Man [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/227554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109819, 7878, 'My Lethal Man [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/227555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109820, 7878, 'My Lethal Man [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/227556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109821, 7878, 'My Lethal Man [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/227557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109822, 7878, 'My Lethal Man [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/227558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109823, 7878, 'My Lethal Man [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/227559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109824, 7878, 'My Lethal Man [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/227560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109825, 7878, 'My Lethal Man [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/227561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109826, 7878, 'My Lethal Man [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/227562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109827, 7878, 'My Lethal Man [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/227563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ko2P0fsMUlUlapojxPppHDJ9BYF.jpg'),
(109828, 7879, 'Novela S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8hyCc2CWKuCITIo7zwn4ki2n4C.jpg'),
(109829, 7879, 'Novela S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yzRHZh9ZGvkcoaJtahFyUcvJeVl.jpg'),
(109830, 7879, 'Novela S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7rtUtUT3sqkgp76EGjLGYfKA3Tg.jpg'),
(109831, 7879, 'Novela S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ykr0BgDX9AcZdj2qW8komyBWBVJ.jpg'),
(109832, 7879, 'Novela S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zNodchtSgWWzXSvRvkqrCzGKjLW.jpg'),
(109833, 7879, 'Novela S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jUJ25xLx9Rr7EEBhuEPiNDHO0zB.jpg'),
(109834, 7879, 'Novela S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/629Qam6S3YSF1MF5E9gnqjmeKRS.jpg'),
(109835, 7879, 'Novela S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/608hmOjrNI2wQdTq6KNi7Npmn8n.jpg'),
(109836, 7880, 'O Conto da Raposa de Nove Caudas [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zuDz4DIqYXsk7ovKpq0291gDQFe.jpg'),
(109837, 7880, 'O Conto da Raposa de Nove Caudas [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w2n0TgjT70uMhDd6mFzcDTgST8Q.jpg'),
(109838, 7880, 'O Conto da Raposa de Nove Caudas [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uvoOCe8dJ8WBEti0AleqGajPH42.jpg'),
(109839, 7880, 'O Conto da Raposa de Nove Caudas [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wRFmKTugX3F2mvftrjWkJgsCGjW.jpg'),
(109840, 7880, 'O Conto da Raposa de Nove Caudas [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lZMKk3hbWSvK5EdWlL1xpJotewX.jpg'),
(109841, 7880, 'O Conto da Raposa de Nove Caudas [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t9swd6z3Oclwvc4sG6ViT9ueyC.jpg'),
(109842, 7880, 'O Conto da Raposa de Nove Caudas [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aE4qTZgbeqQiKcczNw0bZ2xDpsB.jpg'),
(109843, 7880, 'O Conto da Raposa de Nove Caudas [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hITtNqRS6oVTxjJujiwkwj9UT26.jpg'),
(109844, 7880, 'O Conto da Raposa de Nove Caudas [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pSMrQIDm9rdrXKEmRRUyOG473WW.jpg'),
(109845, 7880, 'O Conto da Raposa de Nove Caudas [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k55rGWro18bAjuA6g9lYTH7kkXg.jpg'),
(109846, 7880, 'O Conto da Raposa de Nove Caudas [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j6UL0apdlTMyqKSsgA0BIZ58qnJ.jpg'),
(109847, 7880, 'O Conto da Raposa de Nove Caudas [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/227514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fN4bBRovSgOV7RB1MKHQSlQTkVx.jpg'),
(109848, 7880, 'O Conto da Raposa de Nove Caudas [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/227515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/luVFgXLAifVPvCeRAL6MOo1XiEf.jpg'),
(109849, 7880, 'O Conto da Raposa de Nove Caudas [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/227516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dxbA6NIfop0k7ZUKjhUOLEE6588.jpg'),
(109850, 7880, 'O Conto da Raposa de Nove Caudas [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/227517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wp3nUdm5P515INm1iq8pXflwmBc.jpg'),
(109851, 7880, 'O Conto da Raposa de Nove Caudas [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/227518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1QZZTS6vb56RGisi8nhLLLTLfdf.jpg'),
(109852, 7880, 'O Conto da Raposa de Nove Caudas [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/227519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61OTnrKWaJ4n5aZTdNXvt80t8nv.jpg'),
(109853, 7881, 'O Conto da Raposa de Nove Caudas [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61OTnrKWaJ4n5aZTdNXvt80t8nv.jpg'),
(109854, 7881, 'O Conto da Raposa de Nove Caudas [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61OTnrKWaJ4n5aZTdNXvt80t8nv.jpg'),
(109855, 7881, 'O Conto da Raposa de Nove Caudas [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61OTnrKWaJ4n5aZTdNXvt80t8nv.jpg'),
(109856, 7881, 'O Conto da Raposa de Nove Caudas [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61OTnrKWaJ4n5aZTdNXvt80t8nv.jpg'),
(109857, 7881, 'O Conto da Raposa de Nove Caudas [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61OTnrKWaJ4n5aZTdNXvt80t8nv.jpg'),
(109858, 7881, 'O Conto da Raposa de Nove Caudas [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61OTnrKWaJ4n5aZTdNXvt80t8nv.jpg'),
(109859, 7881, 'O Conto da Raposa de Nove Caudas [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61OTnrKWaJ4n5aZTdNXvt80t8nv.jpg'),
(109860, 7881, 'O Conto da Raposa de Nove Caudas [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61OTnrKWaJ4n5aZTdNXvt80t8nv.jpg'),
(109861, 7881, 'O Conto da Raposa de Nove Caudas [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61OTnrKWaJ4n5aZTdNXvt80t8nv.jpg'),
(109862, 7881, 'O Conto da Raposa de Nove Caudas [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61OTnrKWaJ4n5aZTdNXvt80t8nv.jpg'),
(109863, 7881, 'O Conto da Raposa de Nove Caudas [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61OTnrKWaJ4n5aZTdNXvt80t8nv.jpg'),
(109864, 7881, 'O Conto da Raposa de Nove Caudas [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/227531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/61OTnrKWaJ4n5aZTdNXvt80t8nv.jpg'),
(109865, 7882, 'O Herdeiro: A Dinastia do Freestyle [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rp9Eoke2Hbq9Ovr3IzRSRfS6Js7.jpg'),
(109866, 7882, 'O Herdeiro: A Dinastia do Freestyle [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f5g1W0mQGFLOraq3dqZO09SIlJP.jpg'),
(109867, 7882, 'O Herdeiro: A Dinastia do Freestyle [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5oKwceKgv0Bv8CdQhS8Nall0ZcO.jpg'),
(109868, 7882, 'O Herdeiro: A Dinastia do Freestyle [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9evbAk35HjrstLFr5WpA0YKcfQS.jpg'),
(109869, 7883, 'Ônus da Prova [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jttVa1Xo0bnmy12C3VhxnROQZYP.jpg'),
(109870, 7883, 'Ônus da Prova [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7zJ6u4ElTCfD0oJhlSTVWFKbt1N.jpg'),
(109871, 7883, 'Ônus da Prova [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6aNMd1o42IH08EQvbRqBc6fu1Qk.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(109872, 7883, 'Ônus da Prova [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wXybPH7iP0ivZVqc7KtfnsLoZ9C.jpg'),
(109873, 7883, 'Ônus da Prova [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uoyOkRIBfwT9n7WfPcWx1fYJFTX.jpg'),
(109874, 7883, 'Ônus da Prova [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uoyOkRIBfwT9n7WfPcWx1fYJFTX.jpg'),
(109875, 7883, 'Ônus da Prova [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uoyOkRIBfwT9n7WfPcWx1fYJFTX.jpg'),
(109876, 7883, 'Ônus da Prova [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uoyOkRIBfwT9n7WfPcWx1fYJFTX.jpg'),
(109877, 7883, 'Ônus da Prova [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uoyOkRIBfwT9n7WfPcWx1fYJFTX.jpg'),
(109878, 7883, 'Ônus da Prova [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uoyOkRIBfwT9n7WfPcWx1fYJFTX.jpg'),
(109879, 7883, 'Ônus da Prova [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uoyOkRIBfwT9n7WfPcWx1fYJFTX.jpg'),
(109880, 7883, 'Ônus da Prova [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/227489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uoyOkRIBfwT9n7WfPcWx1fYJFTX.jpg'),
(109881, 7883, 'Ônus da Prova [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/227490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uoyOkRIBfwT9n7WfPcWx1fYJFTX.jpg'),
(109882, 7883, 'Ônus da Prova [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/227491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uoyOkRIBfwT9n7WfPcWx1fYJFTX.jpg'),
(109883, 7883, 'Ônus da Prova [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/227492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uoyOkRIBfwT9n7WfPcWx1fYJFTX.jpg'),
(109884, 7883, 'Ônus da Prova [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/227493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uoyOkRIBfwT9n7WfPcWx1fYJFTX.jpg'),
(109885, 7883, 'Ônus da Prova [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/227494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uoyOkRIBfwT9n7WfPcWx1fYJFTX.jpg'),
(109886, 7883, 'Ônus da Prova [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/227495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uoyOkRIBfwT9n7WfPcWx1fYJFTX.jpg'),
(109887, 7883, 'Ônus da Prova [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/227496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uoyOkRIBfwT9n7WfPcWx1fYJFTX.jpg'),
(109888, 7883, 'Ônus da Prova [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/227497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uoyOkRIBfwT9n7WfPcWx1fYJFTX.jpg'),
(109889, 7883, 'Ônus da Prova [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/227498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uoyOkRIBfwT9n7WfPcWx1fYJFTX.jpg'),
(109890, 7884, 'Pending Train [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mNobfmS6unE8FzVaw2JduPRhcOE.jpg'),
(109891, 7884, 'Pending Train [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nvFmd6a2CBmnhWCOJx5cl8HatMI.jpg'),
(109892, 7884, 'Pending Train [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xpxqqDS9lq7waaSkNHCgnkgBDAN.jpg'),
(109893, 7884, 'Pending Train [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tQuYU7n60DNr5Ihm9FmQvl84PGe.jpg'),
(109894, 7884, 'Pending Train [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7RSTeNZLxvG2RPpsnPIdlFGp2lB.jpg'),
(109895, 7884, 'Pending Train [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ehRIzDWeLQkW0PlBwaVkrJIFDPv.jpg'),
(109896, 7884, 'Pending Train [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udRMZyr8FHcMUnh19erlIr1UcfY.jpg'),
(109897, 7884, 'Pending Train [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cIgrxJrJ1JwesRGYpgtGpWczBJL.jpg'),
(109898, 7884, 'Pending Train [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/poa995jdw6WG305yg7KwZsfyxsY.jpg'),
(109899, 7884, 'Pending Train [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3d9NteFVYhyDQRUx7nkGPd8k99z.jpg'),
(109900, 7885, 'SÓ VOCÊ: Uma Coleção de Curtas de Animação S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dAY2AdTiy6b1Hp4xgsAUTUWhJ4u.jpg'),
(109901, 7885, 'SÓ VOCÊ: Uma Coleção de Curtas de Animação S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qAgWVEDPVb0ij3XalFhnHB7bOph.jpg'),
(109902, 7885, 'SÓ VOCÊ: Uma Coleção de Curtas de Animação S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AtdpR1ubeF4LVqaKNyjQyHhnTCL.jpg'),
(109903, 7885, 'SÓ VOCÊ: Uma Coleção de Curtas de Animação S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/puWuFFGTf5W5ugLi8pNkjAzOxiT.jpg'),
(109904, 7885, 'SÓ VOCÊ: Uma Coleção de Curtas de Animação S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xG03NwYKT4uRDTXcK8aN87pvshp.jpg'),
(109905, 7885, 'SÓ VOCÊ: Uma Coleção de Curtas de Animação S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eRyEFqZ3D9m9wmG5fYaGre1Axdl.jpg'),
(109906, 7885, 'SÓ VOCÊ: Uma Coleção de Curtas de Animação S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0u4lrDLHIkcvuyVA91SsNkhoPv.jpg'),
(109907, 7885, 'SÓ VOCÊ: Uma Coleção de Curtas de Animação S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/14uNGPW9KXbLn9iy49BFfy7kpCn.jpg'),
(109908, 7886, 'The Devil Judge [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zu6V4qEvuLPcIfxwu95iPLXXLRn.jpg'),
(109909, 7886, 'The Devil Judge [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5tpWdQuTdqOBP5ReCqQwSDoAgij.jpg'),
(109910, 7886, 'The Devil Judge [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rVPu7Vlux0J3smgZmmWFJOsiK7F.jpg'),
(109911, 7886, 'The Devil Judge [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mThYiRZuULuScNVynjgx0OC5kw0.jpg'),
(109912, 7886, 'The Devil Judge [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wV0FO46ofuh84H7URMWn4ctcXEu.jpg'),
(109913, 7886, 'The Devil Judge [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jXUcaSazdsv4baf1ubsnceBsNGe.jpg'),
(109914, 7886, 'The Devil Judge [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zsy7gopxfuREQ3takyK5b7w5pTq.jpg'),
(109915, 7886, 'The Devil Judge [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/seg2hzfTsnvWzo0ScpKEN8yizb6.jpg'),
(109916, 7886, 'The Devil Judge [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/utIbiMAhpNrnFn372MZzNRWGoV5.jpg'),
(109917, 7886, 'The Devil Judge [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7h815MjZHvKGnrcWR9fAJnAraq6.jpg'),
(109918, 7886, 'The Devil Judge [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6NcLyihHMLJotT8o3BHuu8Hcta.jpg'),
(109919, 7886, 'The Devil Judge [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/227455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jSzSBUEumqwKUlIzdGj77t8Madk.jpg'),
(109920, 7886, 'The Devil Judge [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/227456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5lZsX4KthhHPBq7FLXOaQsEt0P6.jpg'),
(109921, 7886, 'The Devil Judge [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/227457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9hDHS0TVbts26bADbsuQ6YTgt4S.jpg'),
(109922, 7886, 'The Devil Judge [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/227458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u1o4oG5ofbnJC2tvr3qE7UxhDgY.jpg'),
(109923, 7886, 'The Devil Judge [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/227459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l53fYkCI8sF4rMaomCjExxn5M7W.jpg'),
(109924, 7887, 'The Third Finger Offered to a King [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iwtXKXUVXrCSVkqce1MLRiAFiLp.jpg'),
(109925, 7887, 'The Third Finger Offered to a King [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iwtXKXUVXrCSVkqce1MLRiAFiLp.jpg'),
(109926, 7887, 'The Third Finger Offered to a King [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iwtXKXUVXrCSVkqce1MLRiAFiLp.jpg'),
(109927, 7887, 'The Third Finger Offered to a King [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iwtXKXUVXrCSVkqce1MLRiAFiLp.jpg'),
(109928, 7887, 'The Third Finger Offered to a King [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iwtXKXUVXrCSVkqce1MLRiAFiLp.jpg'),
(109929, 7887, 'The Third Finger Offered to a King [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iwtXKXUVXrCSVkqce1MLRiAFiLp.jpg'),
(109930, 7887, 'The Third Finger Offered to a King [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iwtXKXUVXrCSVkqce1MLRiAFiLp.jpg'),
(109931, 7887, 'The Third Finger Offered to a King [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iwtXKXUVXrCSVkqce1MLRiAFiLp.jpg'),
(109932, 7887, 'The Third Finger Offered to a King [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iwtXKXUVXrCSVkqce1MLRiAFiLp.jpg'),
(109933, 7887, 'The Third Finger Offered to a King [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iwtXKXUVXrCSVkqce1MLRiAFiLp.jpg'),
(109934, 7888, 'Um Conto de Fadas Perfeito S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7DFbDzQ6PwCdOetgqpXDFh1cjbQ.jpg'),
(109935, 7888, 'Um Conto de Fadas Perfeito S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bu7zDQXA30pu7zzxDYI7jaDXX68.jpg'),
(109936, 7888, 'Um Conto de Fadas Perfeito S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ketI1GgiGwnGcFgPjKe27AwobCv.jpg'),
(109937, 7888, 'Um Conto de Fadas Perfeito S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6BjOaQxlCmqty6ZfGMT5zYaK5Vl.jpg'),
(109938, 7888, 'Um Conto de Fadas Perfeito S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bOKyoNvnbNiDKbynnHZA1qRq2d2.jpg'),
(109939, 7889, 'Boruto: Naruto Next Generations [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226811.mp4', 'http://timg.bdta.pro/images/e2afe9a8b6c54e8473aee0a7305e6a8c.jpg'),
(109940, 7889, 'Boruto: Naruto Next Generations [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226812.mp4', 'http://timg.bdta.pro/images/b2a2becf4f715659b0b7b211b83eb7fb.jpg'),
(109941, 7889, 'Boruto: Naruto Next Generations [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226813.mp4', 'http://timg.bdta.pro/images/fd59a0afb8561175257553b67ac5fc57.jpg'),
(109942, 7889, 'Boruto: Naruto Next Generations [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226814.mp4', 'http://timg.bdta.pro/images/410cf0edd91df3a0b705456a1734d3c3.jpg'),
(109943, 7889, 'Boruto: Naruto Next Generations [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226815.mp4', 'http://timg.bdta.pro/images/de934e9cf4abc823603a0db11942a19e.jpg'),
(109944, 7889, 'Boruto: Naruto Next Generations [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226816.mp4', 'http://timg.bdta.pro/images/8208379f126d2e611ed87cbe50b67d65.jpg'),
(109945, 7889, 'Boruto: Naruto Next Generations [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226817.mp4', 'http://timg.bdta.pro/images/ded2a2b9053fee8e180ef91cb2943fa0.jpg'),
(109946, 7889, 'Boruto: Naruto Next Generations [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226818.mp4', 'http://timg.bdta.pro/images/976dd850b745e09a2c22c39382c80bb8.jpg'),
(109947, 7889, 'Boruto: Naruto Next Generations [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226819.mp4', 'http://timg.bdta.pro/images/838639b5a0a9efa319afe7d4eb3328ed.jpg'),
(109948, 7889, 'Boruto: Naruto Next Generations [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226820.mp4', 'http://timg.bdta.pro/images/bd1ab2d3be7fc922c3d2cff5e60d28a8.jpg'),
(109949, 7889, 'Boruto: Naruto Next Generations [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226821.mp4', 'http://timg.bdta.pro/images/f4f512469919ae4e6d85eb866edaac8e.jpg'),
(109950, 7889, 'Boruto: Naruto Next Generations [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226822.mp4', 'http://timg.bdta.pro/images/515fa65eed958c71af3576bf9ae4edb4.jpg'),
(109951, 7889, 'Boruto: Naruto Next Generations [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226823.mp4', 'http://timg.bdta.pro/images/3e6cf7898e1a1d2c471f95ea753881ec.jpg'),
(109952, 7889, 'Boruto: Naruto Next Generations [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226824.mp4', 'http://timg.bdta.pro/images/a606ca81f6faa3d402d9ded7eb03b41c.jpg'),
(109953, 7889, 'Boruto: Naruto Next Generations [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226825.mp4', 'http://timg.bdta.pro/images/85b411c235dad434e9666c89a6a41218.jpg'),
(109954, 7889, 'Boruto: Naruto Next Generations [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/226826.mp4', 'http://timg.bdta.pro/images/58c8d60c862b2bc65f3bf36047334649.jpg'),
(109955, 7889, 'Boruto: Naruto Next Generations [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/226827.mp4', 'http://timg.bdta.pro/images/ca8533592fcbe714f73c3986b4e7257e.jpg'),
(109956, 7889, 'Boruto: Naruto Next Generations [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/226828.mp4', 'http://timg.bdta.pro/images/f6bae80bb4becef9d324751fb5e6e002.jpg'),
(109957, 7889, 'Boruto: Naruto Next Generations [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/226829.mp4', 'http://timg.bdta.pro/images/2e546d2bf4945c5e69fd15c520cae842.jpg'),
(109958, 7889, 'Boruto: Naruto Next Generations [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/226830.mp4', 'http://timg.bdta.pro/images/1f294d892f7474376595d44510e76330.jpg'),
(109959, 7889, 'Boruto: Naruto Next Generations [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/226831.mp4', 'http://timg.bdta.pro/images/fd12eecb6a209948d78aca73c70dbc5d.jpg'),
(109960, 7889, 'Boruto: Naruto Next Generations [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/226832.mp4', 'http://timg.bdta.pro/images/57f57815d75e3302c277ce700eb1b517.jpg'),
(109961, 7889, 'Boruto: Naruto Next Generations [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/226833.mp4', 'http://timg.bdta.pro/images/485e17d1a44b9c3d533571069713b9dc.jpg'),
(109962, 7889, 'Boruto: Naruto Next Generations [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/226834.mp4', 'http://timg.bdta.pro/images/de03b335a48942a0dcc12f26a2d0bafb.jpg'),
(109963, 7889, 'Boruto: Naruto Next Generations [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/226835.mp4', 'http://timg.bdta.pro/images/edbc16eaef56b664469101a019aad85a.jpg'),
(109964, 7889, 'Boruto: Naruto Next Generations [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/226836.mp4', 'http://timg.bdta.pro/images/94e4880f4821c5271157b4957e8ab009.jpg'),
(109965, 7890, 'Boruto: Naruto Next Generations [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109966, 7890, 'Boruto: Naruto Next Generations [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109967, 7890, 'Boruto: Naruto Next Generations [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109968, 7890, 'Boruto: Naruto Next Generations [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109969, 7890, 'Boruto: Naruto Next Generations [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109970, 7890, 'Boruto: Naruto Next Generations [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109971, 7890, 'Boruto: Naruto Next Generations [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109972, 7890, 'Boruto: Naruto Next Generations [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109973, 7890, 'Boruto: Naruto Next Generations [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109974, 7890, 'Boruto: Naruto Next Generations [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109975, 7890, 'Boruto: Naruto Next Generations [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109976, 7890, 'Boruto: Naruto Next Generations [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109977, 7890, 'Boruto: Naruto Next Generations [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109978, 7890, 'Boruto: Naruto Next Generations [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109979, 7890, 'Boruto: Naruto Next Generations [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109980, 7890, 'Boruto: Naruto Next Generations [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/226852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109981, 7890, 'Boruto: Naruto Next Generations [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/226853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109982, 7890, 'Boruto: Naruto Next Generations [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/226854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109983, 7890, 'Boruto: Naruto Next Generations [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/226855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109984, 7890, 'Boruto: Naruto Next Generations [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/226856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109985, 7890, 'Boruto: Naruto Next Generations [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/226857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109986, 7890, 'Boruto: Naruto Next Generations [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/226858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109987, 7890, 'Boruto: Naruto Next Generations [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/226859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109988, 7890, 'Boruto: Naruto Next Generations [L] S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/226860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109989, 7890, 'Boruto: Naruto Next Generations [L] S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/226861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109990, 7891, 'Boruto: Naruto Next Generations [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109991, 7891, 'Boruto: Naruto Next Generations [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109992, 7891, 'Boruto: Naruto Next Generations [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109993, 7891, 'Boruto: Naruto Next Generations [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109994, 7891, 'Boruto: Naruto Next Generations [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109995, 7891, 'Boruto: Naruto Next Generations [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109996, 7891, 'Boruto: Naruto Next Generations [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109997, 7891, 'Boruto: Naruto Next Generations [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109998, 7891, 'Boruto: Naruto Next Generations [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(109999, 7891, 'Boruto: Naruto Next Generations [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110000, 7891, 'Boruto: Naruto Next Generations [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110001, 7891, 'Boruto: Naruto Next Generations [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110002, 7891, 'Boruto: Naruto Next Generations [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110003, 7891, 'Boruto: Naruto Next Generations [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110004, 7891, 'Boruto: Naruto Next Generations [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110005, 7891, 'Boruto: Naruto Next Generations [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/226877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110006, 7891, 'Boruto: Naruto Next Generations [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/226878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110007, 7891, 'Boruto: Naruto Next Generations [L] S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/226879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110008, 7891, 'Boruto: Naruto Next Generations [L] S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/226880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110009, 7891, 'Boruto: Naruto Next Generations [L] S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/226881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110010, 7891, 'Boruto: Naruto Next Generations [L] S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/226882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110011, 7891, 'Boruto: Naruto Next Generations [L] S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/226883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110012, 7891, 'Boruto: Naruto Next Generations [L] S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/226884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110013, 7891, 'Boruto: Naruto Next Generations [L] S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/226885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110014, 7892, 'Boruto: Naruto Next Generations [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110015, 7892, 'Boruto: Naruto Next Generations [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110016, 7892, 'Boruto: Naruto Next Generations [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110017, 7892, 'Boruto: Naruto Next Generations [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110018, 7892, 'Boruto: Naruto Next Generations [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110019, 7892, 'Boruto: Naruto Next Generations [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110020, 7892, 'Boruto: Naruto Next Generations [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110021, 7892, 'Boruto: Naruto Next Generations [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110022, 7892, 'Boruto: Naruto Next Generations [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110023, 7892, 'Boruto: Naruto Next Generations [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110024, 7892, 'Boruto: Naruto Next Generations [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110025, 7892, 'Boruto: Naruto Next Generations [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110026, 7892, 'Boruto: Naruto Next Generations [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110027, 7892, 'Boruto: Naruto Next Generations [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110028, 7892, 'Boruto: Naruto Next Generations [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110029, 7892, 'Boruto: Naruto Next Generations [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/226901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110030, 7892, 'Boruto: Naruto Next Generations [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/226902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110031, 7892, 'Boruto: Naruto Next Generations [L] S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/226903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110032, 7892, 'Boruto: Naruto Next Generations [L] S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/226904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110033, 7892, 'Boruto: Naruto Next Generations [L] S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/226905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110034, 7892, 'Boruto: Naruto Next Generations [L] S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/226906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110035, 7892, 'Boruto: Naruto Next Generations [L] S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/226907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110036, 7892, 'Boruto: Naruto Next Generations [L] S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/226908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110037, 7892, 'Boruto: Naruto Next Generations [L] S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/226909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110038, 7892, 'Boruto: Naruto Next Generations [L] S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/226910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110039, 7893, 'Boruto: Naruto Next Generations [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110040, 7893, 'Boruto: Naruto Next Generations [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110041, 7893, 'Boruto: Naruto Next Generations [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110042, 7893, 'Boruto: Naruto Next Generations [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110043, 7893, 'Boruto: Naruto Next Generations [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110044, 7893, 'Boruto: Naruto Next Generations [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110045, 7893, 'Boruto: Naruto Next Generations [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110046, 7893, 'Boruto: Naruto Next Generations [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110047, 7893, 'Boruto: Naruto Next Generations [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110048, 7893, 'Boruto: Naruto Next Generations [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110049, 7893, 'Boruto: Naruto Next Generations [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110050, 7893, 'Boruto: Naruto Next Generations [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110051, 7893, 'Boruto: Naruto Next Generations [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110052, 7893, 'Boruto: Naruto Next Generations [L] S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110053, 7893, 'Boruto: Naruto Next Generations [L] S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110054, 7893, 'Boruto: Naruto Next Generations [L] S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/226926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110055, 7893, 'Boruto: Naruto Next Generations [L] S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/226927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110056, 7893, 'Boruto: Naruto Next Generations [L] S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/226928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110057, 7893, 'Boruto: Naruto Next Generations [L] S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/226929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110058, 7893, 'Boruto: Naruto Next Generations [L] S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/226930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110059, 7893, 'Boruto: Naruto Next Generations [L] S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/226931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110060, 7893, 'Boruto: Naruto Next Generations [L] S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/226932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110061, 7893, 'Boruto: Naruto Next Generations [L] S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/226933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110062, 7893, 'Boruto: Naruto Next Generations [L] S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/226934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110063, 7893, 'Boruto: Naruto Next Generations [L] S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/226935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110064, 7893, 'Boruto: Naruto Next Generations [L] S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/226936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110065, 7894, 'Boruto: Naruto Next Generations [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110066, 7894, 'Boruto: Naruto Next Generations [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110067, 7894, 'Boruto: Naruto Next Generations [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110068, 7894, 'Boruto: Naruto Next Generations [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110069, 7894, 'Boruto: Naruto Next Generations [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110070, 7894, 'Boruto: Naruto Next Generations [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110071, 7894, 'Boruto: Naruto Next Generations [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110072, 7894, 'Boruto: Naruto Next Generations [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110073, 7894, 'Boruto: Naruto Next Generations [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110074, 7894, 'Boruto: Naruto Next Generations [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110075, 7894, 'Boruto: Naruto Next Generations [L] S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110076, 7894, 'Boruto: Naruto Next Generations [L] S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110077, 7894, 'Boruto: Naruto Next Generations [L] S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110078, 7894, 'Boruto: Naruto Next Generations [L] S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110079, 7894, 'Boruto: Naruto Next Generations [L] S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110080, 7894, 'Boruto: Naruto Next Generations [L] S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/226952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110081, 7894, 'Boruto: Naruto Next Generations [L] S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/226953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110082, 7894, 'Boruto: Naruto Next Generations [L] S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/226954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110083, 7894, 'Boruto: Naruto Next Generations [L] S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/226955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110084, 7894, 'Boruto: Naruto Next Generations [L] S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/226956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110085, 7894, 'Boruto: Naruto Next Generations [L] S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/226957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110086, 7894, 'Boruto: Naruto Next Generations [L] S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/226958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110087, 7894, 'Boruto: Naruto Next Generations [L] S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/226959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110088, 7894, 'Boruto: Naruto Next Generations [L] S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/226960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110089, 7895, 'Boruto: Naruto Next Generations [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110090, 7895, 'Boruto: Naruto Next Generations [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110091, 7895, 'Boruto: Naruto Next Generations [L] S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110092, 7895, 'Boruto: Naruto Next Generations [L] S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110093, 7895, 'Boruto: Naruto Next Generations [L] S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110094, 7895, 'Boruto: Naruto Next Generations [L] S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110095, 7895, 'Boruto: Naruto Next Generations [L] S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110096, 7895, 'Boruto: Naruto Next Generations [L] S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110097, 7895, 'Boruto: Naruto Next Generations [L] S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110098, 7895, 'Boruto: Naruto Next Generations [L] S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110099, 7895, 'Boruto: Naruto Next Generations [L] S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110100, 7895, 'Boruto: Naruto Next Generations [L] S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110101, 7895, 'Boruto: Naruto Next Generations [L] S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110102, 7895, 'Boruto: Naruto Next Generations [L] S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110103, 7895, 'Boruto: Naruto Next Generations [L] S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110104, 7895, 'Boruto: Naruto Next Generations [L] S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/226976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110105, 7895, 'Boruto: Naruto Next Generations [L] S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/226977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110106, 7895, 'Boruto: Naruto Next Generations [L] S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/226978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110107, 7895, 'Boruto: Naruto Next Generations [L] S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/226979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110108, 7895, 'Boruto: Naruto Next Generations [L] S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/226980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110109, 7895, 'Boruto: Naruto Next Generations [L] S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/226981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110110, 7895, 'Boruto: Naruto Next Generations [L] S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/226982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110111, 7895, 'Boruto: Naruto Next Generations [L] S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/226983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110112, 7895, 'Boruto: Naruto Next Generations [L] S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/226984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110113, 7895, 'Boruto: Naruto Next Generations [L] S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/226985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110114, 7895, 'Boruto: Naruto Next Generations [L] S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/226986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(110115, 7896, 'Boruto: Naruto Next Generations [L] S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110116, 7896, 'Boruto: Naruto Next Generations [L] S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110117, 7896, 'Boruto: Naruto Next Generations [L] S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110118, 7896, 'Boruto: Naruto Next Generations [L] S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110119, 7896, 'Boruto: Naruto Next Generations [L] S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110120, 7896, 'Boruto: Naruto Next Generations [L] S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110121, 7896, 'Boruto: Naruto Next Generations [L] S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110122, 7896, 'Boruto: Naruto Next Generations [L] S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110123, 7896, 'Boruto: Naruto Next Generations [L] S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110124, 7896, 'Boruto: Naruto Next Generations [L] S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110125, 7896, 'Boruto: Naruto Next Generations [L] S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110126, 7896, 'Boruto: Naruto Next Generations [L] S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110127, 7896, 'Boruto: Naruto Next Generations [L] S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110128, 7896, 'Boruto: Naruto Next Generations [L] S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/227000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110129, 7896, 'Boruto: Naruto Next Generations [L] S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/227001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110130, 7896, 'Boruto: Naruto Next Generations [L] S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/227002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110131, 7896, 'Boruto: Naruto Next Generations [L] S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/227003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110132, 7896, 'Boruto: Naruto Next Generations [L] S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/227004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110133, 7896, 'Boruto: Naruto Next Generations [L] S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/227005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110134, 7896, 'Boruto: Naruto Next Generations [L] S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/227006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110135, 7896, 'Boruto: Naruto Next Generations [L] S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/227007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110136, 7896, 'Boruto: Naruto Next Generations [L] S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/227008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110137, 7896, 'Boruto: Naruto Next Generations [L] S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/227009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110138, 7897, 'Boruto: Naruto Next Generations [L] S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110139, 7897, 'Boruto: Naruto Next Generations [L] S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110140, 7897, 'Boruto: Naruto Next Generations [L] S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110141, 7897, 'Boruto: Naruto Next Generations [L] S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110142, 7897, 'Boruto: Naruto Next Generations [L] S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110143, 7897, 'Boruto: Naruto Next Generations [L] S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110144, 7897, 'Boruto: Naruto Next Generations [L] S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110145, 7897, 'Boruto: Naruto Next Generations [L] S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110146, 7897, 'Boruto: Naruto Next Generations [L] S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110147, 7897, 'Boruto: Naruto Next Generations [L] S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110148, 7897, 'Boruto: Naruto Next Generations [L] S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110149, 7897, 'Boruto: Naruto Next Generations [L] S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/227021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110150, 7897, 'Boruto: Naruto Next Generations [L] S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/227022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110151, 7897, 'Boruto: Naruto Next Generations [L] S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/227023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110152, 7897, 'Boruto: Naruto Next Generations [L] S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/227024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110153, 7897, 'Boruto: Naruto Next Generations [L] S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/227025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110154, 7897, 'Boruto: Naruto Next Generations [L] S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/227026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110155, 7897, 'Boruto: Naruto Next Generations [L] S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/227027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110156, 7897, 'Boruto: Naruto Next Generations [L] S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/227028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110157, 7897, 'Boruto: Naruto Next Generations [L] S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/227029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110158, 7897, 'Boruto: Naruto Next Generations [L] S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/227030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110159, 7897, 'Boruto: Naruto Next Generations [L] S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/227031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110160, 7897, 'Boruto: Naruto Next Generations [L] S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/227032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110161, 7897, 'Boruto: Naruto Next Generations [L] S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/227033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110162, 7898, 'Boruto: Naruto Next Generations [L] S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110163, 7898, 'Boruto: Naruto Next Generations [L] S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110164, 7898, 'Boruto: Naruto Next Generations [L] S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110165, 7898, 'Boruto: Naruto Next Generations [L] S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110166, 7898, 'Boruto: Naruto Next Generations [L] S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110167, 7898, 'Boruto: Naruto Next Generations [L] S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110168, 7898, 'Boruto: Naruto Next Generations [L] S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110169, 7898, 'Boruto: Naruto Next Generations [L] S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110170, 7898, 'Boruto: Naruto Next Generations [L] S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110171, 7898, 'Boruto: Naruto Next Generations [L] S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110172, 7898, 'Boruto: Naruto Next Generations [L] S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110173, 7898, 'Boruto: Naruto Next Generations [L] S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/227045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110174, 7898, 'Boruto: Naruto Next Generations [L] S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/227046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110175, 7898, 'Boruto: Naruto Next Generations [L] S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/227047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110176, 7898, 'Boruto: Naruto Next Generations [L] S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/227048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110177, 7898, 'Boruto: Naruto Next Generations [L] S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/227049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110178, 7898, 'Boruto: Naruto Next Generations [L] S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/227050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110179, 7898, 'Boruto: Naruto Next Generations [L] S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/227051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110180, 7898, 'Boruto: Naruto Next Generations [L] S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/227052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110181, 7898, 'Boruto: Naruto Next Generations [L] S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/227053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110182, 7898, 'Boruto: Naruto Next Generations [L] S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/227054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110183, 7898, 'Boruto: Naruto Next Generations [L] S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/227055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110184, 7898, 'Boruto: Naruto Next Generations [L] S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/227056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110185, 7898, 'Boruto: Naruto Next Generations [L] S10 E24', 'http://sinalprivado.info:80/series/1533784/1533784/227057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110186, 7898, 'Boruto: Naruto Next Generations [L] S10 E25', 'http://sinalprivado.info:80/series/1533784/1533784/227058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110187, 7898, 'Boruto: Naruto Next Generations [L] S10 E26', 'http://sinalprivado.info:80/series/1533784/1533784/227059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110188, 7898, 'Boruto: Naruto Next Generations [L] S10 E27', 'http://sinalprivado.info:80/series/1533784/1533784/227060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110189, 7898, 'Boruto: Naruto Next Generations [L] S10 E28', 'http://sinalprivado.info:80/series/1533784/1533784/227061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110190, 7898, 'Boruto: Naruto Next Generations [L] S10 E29', 'http://sinalprivado.info:80/series/1533784/1533784/227062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110191, 7898, 'Boruto: Naruto Next Generations [L] S10 E30', 'http://sinalprivado.info:80/series/1533784/1533784/227063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110192, 7898, 'Boruto: Naruto Next Generations [L] S10 E31', 'http://sinalprivado.info:80/series/1533784/1533784/227064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110193, 7898, 'Boruto: Naruto Next Generations [L] S10 E32', 'http://sinalprivado.info:80/series/1533784/1533784/227065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110194, 7899, 'Boruto: Naruto Next Generations [L] S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/227066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110195, 7899, 'Boruto: Naruto Next Generations [L] S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/227067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110196, 7899, 'Boruto: Naruto Next Generations [L] S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/227068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110197, 7899, 'Boruto: Naruto Next Generations [L] S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/227069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110198, 7899, 'Boruto: Naruto Next Generations [L] S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/227070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110199, 7899, 'Boruto: Naruto Next Generations [L] S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/227071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110200, 7899, 'Boruto: Naruto Next Generations [L] S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/227072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110201, 7899, 'Boruto: Naruto Next Generations [L] S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/227073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110202, 7899, 'Boruto: Naruto Next Generations [L] S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/227074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110203, 7899, 'Boruto: Naruto Next Generations [L] S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/227075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110204, 7899, 'Boruto: Naruto Next Generations [L] S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/227076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110205, 7899, 'Boruto: Naruto Next Generations [L] S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/227077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110206, 7899, 'Boruto: Naruto Next Generations [L] S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/227078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110207, 7899, 'Boruto: Naruto Next Generations [L] S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/227079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110208, 7899, 'Boruto: Naruto Next Generations [L] S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/227080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110209, 7899, 'Boruto: Naruto Next Generations [L] S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/227081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110210, 7899, 'Boruto: Naruto Next Generations [L] S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/227082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110211, 7899, 'Boruto: Naruto Next Generations [L] S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/227083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110212, 7899, 'Boruto: Naruto Next Generations [L] S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/227084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110213, 7899, 'Boruto: Naruto Next Generations [L] S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/227085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110214, 7899, 'Boruto: Naruto Next Generations [L] S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/227086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110215, 7899, 'Boruto: Naruto Next Generations [L] S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/227087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110216, 7899, 'Boruto: Naruto Next Generations [L] S11 E23', 'http://sinalprivado.info:80/series/1533784/1533784/227088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110217, 7899, 'Boruto: Naruto Next Generations [L] S11 E24', 'http://sinalprivado.info:80/series/1533784/1533784/227089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110218, 7899, 'Boruto: Naruto Next Generations [L] S11 E25', 'http://sinalprivado.info:80/series/1533784/1533784/227090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110219, 7899, 'Boruto: Naruto Next Generations [L] S11 E26', 'http://sinalprivado.info:80/series/1533784/1533784/227091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110220, 7899, 'Boruto: Naruto Next Generations [L] S11 E27', 'http://sinalprivado.info:80/series/1533784/1533784/227092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110221, 7899, 'Boruto: Naruto Next Generations [L] S11 E28', 'http://sinalprivado.info:80/series/1533784/1533784/227093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110222, 7899, 'Boruto: Naruto Next Generations [L] S11 E29', 'http://sinalprivado.info:80/series/1533784/1533784/227094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110223, 7899, 'Boruto: Naruto Next Generations [L] S11 E30', 'http://sinalprivado.info:80/series/1533784/1533784/227095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110224, 7899, 'Boruto: Naruto Next Generations [L] S11 E31', 'http://sinalprivado.info:80/series/1533784/1533784/227096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110225, 7899, 'Boruto: Naruto Next Generations [L] S11 E32', 'http://sinalprivado.info:80/series/1533784/1533784/227097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110226, 7899, 'Boruto: Naruto Next Generations [L] S11 E33', 'http://sinalprivado.info:80/series/1533784/1533784/227098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110227, 7899, 'Boruto: Naruto Next Generations [L] S11 E34', 'http://sinalprivado.info:80/series/1533784/1533784/227099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110228, 7899, 'Boruto: Naruto Next Generations [L] S11 E35', 'http://sinalprivado.info:80/series/1533784/1533784/227100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110229, 7899, 'Boruto: Naruto Next Generations [L] S11 E36', 'http://sinalprivado.info:80/series/1533784/1533784/227101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110230, 7899, 'Boruto: Naruto Next Generations [L] S11 E37', 'http://sinalprivado.info:80/series/1533784/1533784/227102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110231, 7899, 'Boruto: Naruto Next Generations [L] S11 E38', 'http://sinalprivado.info:80/series/1533784/1533784/227103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AicBR8KLvKUNcRCoWjDmwSXeClT.jpg'),
(110232, 7900, 'Osama Sentai Kingu Oja [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/269095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dzXXqaigGpftKwvfXJZMFJXvuio.jpg'),
(110233, 7900, 'Osama Sentai Kingu Oja [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/269096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zGvPOpCRrnkVhSICUA8wedc2c2a.jpg'),
(110234, 7900, 'Osama Sentai Kingu Oja [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/269097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/50Z2sN9Uzk8Qz65AGSrBbZr1Upn.jpg'),
(110235, 7900, 'Osama Sentai Kingu Oja [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/269098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3P5CZMizod2VciUhXFP7Gll3Wb1.jpg'),
(110236, 7900, 'Osama Sentai Kingu Oja [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/269099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1s6sAJ9PfkY5XslCNOviMbJl6Bg.jpg'),
(110237, 7900, 'Osama Sentai Kingu Oja [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/269100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jjZ5QWl8YXtMQIj2FENiXVkR8O9.jpg'),
(110238, 7900, 'Osama Sentai Kingu Oja [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/269101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d7jAsaGrvvGqytusAc2DLbe8zXV.jpg'),
(110239, 7900, 'Osama Sentai Kingu Oja [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/269102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/36JOylcnFEP5Yd28Cx5aLied8uV.jpg'),
(110240, 7900, 'Osama Sentai Kingu Oja [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/269103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1vFIoyUIOa2tN86nhjOpCB8gkIX.jpg'),
(110241, 7900, 'Osama Sentai Kingu Oja [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/269104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wKZBi0uNT2T34YLBAac18VtKgOS.jpg'),
(110242, 7900, 'Osama Sentai Kingu Oja [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/269105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7zuHMqKahClUIj6rVj2Y0S4o8cP.jpg'),
(110243, 7900, 'Osama Sentai Kingu Oja [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/269106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aPAs2fc8DrCUxp6yjR9UJF1vf2q.jpg'),
(110244, 7900, 'Osama Sentai Kingu Oja [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/269107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lTOyTiqaWPpnLXTGSUMh76wYuXG.jpg'),
(110245, 7900, 'Osama Sentai Kingu Oja [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/269108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZvGGovQacYKYH4NDnkHKv4sJDe.jpg'),
(110246, 7900, 'Osama Sentai Kingu Oja [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/269109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/64P7AS3RsoLqXVuzMmBjjsn3pTa.jpg'),
(110247, 7900, 'Osama Sentai Kingu Oja [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/269110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wwDsempF9StHCZ3dLxZE6cMmck0.jpg'),
(110248, 7900, 'Osama Sentai Kingu Oja [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/269111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMLsPLOLCtpjCWNw4MxvUDF9lwl.jpg'),
(110249, 7900, 'Osama Sentai Kingu Oja [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/269112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Mry5Q6rNBSomEFt2ZIzInYc1LW.jpg'),
(110250, 7900, 'Osama Sentai Kingu Oja [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/269113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d1dJ5C04LvUcBc3WqMbqwrWS6ev.jpg'),
(110251, 7900, 'Osama Sentai Kingu Oja [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/269114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/RWSsUubzbMcGCcGoczvB0PZDXC.jpg'),
(110252, 7900, 'Osama Sentai Kingu Oja [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/269115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3ZvO2oa6fIwGDEoP7ummZJBRCM.jpg'),
(110253, 7900, 'Osama Sentai Kingu Oja [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/269116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nOzRA6QaPjg0rOfEpa0QXGWwPLp.jpg'),
(110254, 7900, 'Osama Sentai Kingu Oja [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/269117.mp4', 'http://image.tmdb.org/t/p/w1280/jS6QESfce4aswIc88vaN6YOXHZ0.jpg'),
(110255, 7900, 'Osama Sentai Kingu Oja [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/269118.mp4', 'http://image.tmdb.org/t/p/w1280/60IcDH63IKDNYV1r73xGwcfTwbw.jpg'),
(110256, 7900, 'Osama Sentai Kingu Oja [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/269119.mp4', 'http://image.tmdb.org/t/p/w1280/oI5RQxP0E0NsL8emeY4apPjvZvG.jpg'),
(110257, 7900, 'Osama Sentai Kingu Oja [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/269120.mp4', 'http://image.tmdb.org/t/p/w1280/4ixqIRoFm1ejhBLV6kDdl1OWBmV.jpg'),
(110258, 7900, 'Osama Sentai Kingu Oja [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/269121.mp4', 'http://image.tmdb.org/t/p/w1280/67vYoWoqWA5ntbBi2TDCqmeSX0l.jpg'),
(110259, 7900, 'Osama Sentai Kingu Oja [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/269122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110260, 7900, 'Osama Sentai Kingu Oja [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/269123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110261, 7900, 'Osama Sentai Kingu Oja [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/269124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110262, 7900, 'Osama Sentai Kingu Oja [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/269125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110263, 7900, 'Osama Sentai Kingu Oja [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/269126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110264, 7900, 'Osama Sentai Kingu Oja [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/269127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110265, 7900, 'Osama Sentai Kingu Oja [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/269128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110266, 7900, 'Osama Sentai Kingu Oja [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/269129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110267, 7900, 'Osama Sentai Kingu Oja [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/269130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110268, 7900, 'Osama Sentai Kingu Oja [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/269131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110269, 7900, 'Osama Sentai Kingu Oja [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/269132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110270, 7900, 'Osama Sentai Kingu Oja [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/269133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110271, 7900, 'Osama Sentai Kingu Oja [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/269134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110272, 7900, 'Osama Sentai Kingu Oja [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/269135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110273, 7900, 'Osama Sentai Kingu Oja [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/269136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110274, 7900, 'Osama Sentai Kingu Oja [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/269137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110275, 7900, 'Osama Sentai Kingu Oja [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/269138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110276, 7900, 'Osama Sentai Kingu Oja [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/269139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110277, 7900, 'Osama Sentai Kingu Oja [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/269140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110278, 7900, 'Osama Sentai Kingu Oja [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/272745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110279, 7900, 'Osama Sentai Kingu Oja [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/272746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110280, 7900, 'Osama Sentai Kingu Oja [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/277668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110281, 7900, 'Osama Sentai Kingu Oja [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/288658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bekHqhMZn5XWJjvNs4k3y7N2zzj.jpg'),
(110282, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aPPwUAriS4bIm9mrnJIX034YMeA.jpg'),
(110283, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ZXUZEf30ysF9tgZy7pnNQIDW7V.jpg'),
(110284, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cqpeIJTV4sglkCYbkXwkT7eohgP.jpg'),
(110285, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gGSbAImNWoHQz4SXHX08TNjEHEv.jpg'),
(110286, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9xINGopgieLtkqLFZLxS1Cf3jlQ.jpg'),
(110287, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uKihubuakXuILGSzpdtzQjwTzJZ.jpg'),
(110288, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1sEJXYppm3F9jfzmfONDc3r9sZM.jpg'),
(110289, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ZKsq9VvOq2cXVVRdfAuV7OQ4uO.jpg'),
(110290, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1DV0YHtS5E340EJ6bea5keRLckC.jpg'),
(110291, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p35rj3825jg0LR3D3RaZTkDLfGb.jpg'),
(110292, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/238652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/arMEtMgByamnrbYtymrOMAPpNPq.jpg'),
(110293, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/238653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x1zCUJalfdMGswdFFajVyBec9Pv.jpg'),
(110294, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/238654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hV2skt2Yyk5SFfpD4QlTrVwzi0J.jpg'),
(110295, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/238655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qXWqs6Jnmudy7raYwYaXfdzLPpU.jpg'),
(110296, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/238656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZKy9BmjIzNN1M0l7s8GPiHuCnH.jpg'),
(110297, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/238657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JfQ8HdvyCEsmKQhRZylXX0zR2h.jpg'),
(110298, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/238658.mp4', 'http://image.tmdb.org/t/p/w1280/qIewcTAnzTQ0SRJhJJ4UoLIkm5.jpg'),
(110299, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/238659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qmu5Ry16ZcqLyCZS8sWGEBxeGWT.jpg'),
(110300, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/238660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qmu5Ry16ZcqLyCZS8sWGEBxeGWT.jpg'),
(110301, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/238661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qmu5Ry16ZcqLyCZS8sWGEBxeGWT.jpg'),
(110302, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/238662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qmu5Ry16ZcqLyCZS8sWGEBxeGWT.jpg'),
(110303, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/238663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qmu5Ry16ZcqLyCZS8sWGEBxeGWT.jpg'),
(110304, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/238664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qmu5Ry16ZcqLyCZS8sWGEBxeGWT.jpg'),
(110305, 7901, 'A Princesa Oferenda e o Rei das Feras [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/238665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qmu5Ry16ZcqLyCZS8sWGEBxeGWT.jpg'),
(110306, 7902, 'A Química da Morte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vBO2IP4BGNIPthnnj71b1DW8m1p.jpg'),
(110307, 7902, 'A Química da Morte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oFnc2JikW9A4AN4m6kem78cAqJ2.jpg'),
(110308, 7902, 'A Química da Morte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fQrOZz3W4die6G0UW2Lx6s4Rw3Q.jpg'),
(110309, 7902, 'A Química da Morte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUyS8zmfjH6yldb3GOVrfziXCmx.jpg'),
(110310, 7902, 'A Química da Morte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1r7BbpMvZu74AtlF0u8NddJJkE3.jpg'),
(110311, 7902, 'A Química da Morte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNQBIIHmfdBV9PZDXCbHUeuriDb.jpg'),
(110312, 7903, 'As Flores Perdidas de Alice Hart S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sNeGAamuke1a2I4ndcaE0bnukh4.jpg'),
(110313, 7903, 'As Flores Perdidas de Alice Hart S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sNeGAamuke1a2I4ndcaE0bnukh4.jpg'),
(110314, 7903, 'As Flores Perdidas de Alice Hart S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sNeGAamuke1a2I4ndcaE0bnukh4.jpg'),
(110315, 7903, 'As Flores Perdidas de Alice Hart S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233330.mp4', 'http://image.tmdb.org/t/p/w1280/y4JzRxyA32u6t83G4LLb0dVEW0C.jpg'),
(110316, 7903, 'As Flores Perdidas de Alice Hart S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233331.mp4', 'http://image.tmdb.org/t/p/w1280/7ap1gGvBBXO9SdqBTg1qmU5n8R.jpg'),
(110317, 7903, 'As Flores Perdidas de Alice Hart S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233332.mp4', 'http://image.tmdb.org/t/p/w1280/fVKxn979fyS2RwtufOH9yMUenU7.jpg'),
(110318, 7903, 'As Flores Perdidas de Alice Hart S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sNeGAamuke1a2I4ndcaE0bnukh4.jpg'),
(110319, 7904, 'Choque de Cultura S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110320, 7904, 'Choque de Cultura S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110321, 7904, 'Choque de Cultura S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110322, 7904, 'Choque de Cultura S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110323, 7904, 'Choque de Cultura S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110324, 7904, 'Choque de Cultura S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110325, 7904, 'Choque de Cultura S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110326, 7904, 'Choque de Cultura S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110327, 7904, 'Choque de Cultura S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110328, 7904, 'Choque de Cultura S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110329, 7904, 'Choque de Cultura S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110330, 7904, 'Choque de Cultura S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110331, 7904, 'Choque de Cultura S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110332, 7904, 'Choque de Cultura S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110333, 7904, 'Choque de Cultura S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110334, 7904, 'Choque de Cultura S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110335, 7904, 'Choque de Cultura S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110336, 7904, 'Choque de Cultura S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110337, 7904, 'Choque de Cultura S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110338, 7904, 'Choque de Cultura S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110339, 7904, 'Choque de Cultura S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110340, 7905, 'Choque de Cultura S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110341, 7905, 'Choque de Cultura S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110342, 7905, 'Choque de Cultura S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110343, 7905, 'Choque de Cultura S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110344, 7905, 'Choque de Cultura S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110345, 7905, 'Choque de Cultura S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110346, 7905, 'Choque de Cultura S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110347, 7905, 'Choque de Cultura S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110348, 7905, 'Choque de Cultura S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110349, 7905, 'Choque de Cultura S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110350, 7905, 'Choque de Cultura S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110351, 7905, 'Choque de Cultura S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110352, 7905, 'Choque de Cultura S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBzm8P5VUmgdUmehxuAWnBIZwvp.jpg'),
(110353, 7906, 'Condenados pela Mídia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ocD50T4GKmxBVFHkkiEHzfHJJuC.jpg'),
(110354, 7906, 'Condenados pela Mídia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ll2dAhNNeAT3n7w7fexIYGWrOj2.jpg'),
(110355, 7906, 'Condenados pela Mídia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tUQ3FoqstmNO5xPBl0a8pI6QmA8.jpg'),
(110356, 7906, 'Condenados pela Mídia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5MQkOShibcEnTsgVd1pHKayuFel.jpg'),
(110357, 7906, 'Condenados pela Mídia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zgvrGKFagTEpOQ3o0dFGvY4pmyt.jpg'),
(110358, 7906, 'Condenados pela Mídia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dIvvnrrS2PzvgHBgPtVLmJf4gT9.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(110359, 7907, 'De Volta ao Mundo Amish S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110360, 7907, 'De Volta ao Mundo Amish S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110361, 7907, 'De Volta ao Mundo Amish S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110362, 7907, 'De Volta ao Mundo Amish S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110363, 7907, 'De Volta ao Mundo Amish S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110364, 7907, 'De Volta ao Mundo Amish S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110365, 7907, 'De Volta ao Mundo Amish S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110366, 7907, 'De Volta ao Mundo Amish S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110367, 7908, 'De Volta ao Mundo Amish S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110368, 7908, 'De Volta ao Mundo Amish S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110369, 7908, 'De Volta ao Mundo Amish S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110370, 7908, 'De Volta ao Mundo Amish S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110371, 7908, 'De Volta ao Mundo Amish S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110372, 7908, 'De Volta ao Mundo Amish S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110373, 7908, 'De Volta ao Mundo Amish S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110374, 7908, 'De Volta ao Mundo Amish S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110375, 7909, 'De Volta ao Mundo Amish S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110376, 7909, 'De Volta ao Mundo Amish S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110377, 7909, 'De Volta ao Mundo Amish S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110378, 7909, 'De Volta ao Mundo Amish S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110379, 7909, 'De Volta ao Mundo Amish S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110380, 7909, 'De Volta ao Mundo Amish S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110381, 7909, 'De Volta ao Mundo Amish S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110382, 7909, 'De Volta ao Mundo Amish S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110383, 7910, 'De Volta ao Mundo Amish S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110384, 7910, 'De Volta ao Mundo Amish S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110385, 7910, 'De Volta ao Mundo Amish S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110386, 7910, 'De Volta ao Mundo Amish S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110387, 7910, 'De Volta ao Mundo Amish S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110388, 7910, 'De Volta ao Mundo Amish S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110389, 7910, 'De Volta ao Mundo Amish S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110390, 7910, 'De Volta ao Mundo Amish S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110391, 7910, 'De Volta ao Mundo Amish S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110392, 7910, 'De Volta ao Mundo Amish S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110393, 7910, 'De Volta ao Mundo Amish S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110394, 7910, 'De Volta ao Mundo Amish S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110395, 7911, 'De Volta ao Mundo Amish S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110396, 7911, 'De Volta ao Mundo Amish S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110397, 7911, 'De Volta ao Mundo Amish S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110398, 7911, 'De Volta ao Mundo Amish S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110399, 7911, 'De Volta ao Mundo Amish S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110400, 7911, 'De Volta ao Mundo Amish S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110401, 7911, 'De Volta ao Mundo Amish S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110402, 7911, 'De Volta ao Mundo Amish S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110403, 7912, 'De Volta ao Mundo Amish S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110404, 7912, 'De Volta ao Mundo Amish S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110405, 7912, 'De Volta ao Mundo Amish S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110406, 7912, 'De Volta ao Mundo Amish S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110407, 7912, 'De Volta ao Mundo Amish S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110408, 7912, 'De Volta ao Mundo Amish S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110409, 7912, 'De Volta ao Mundo Amish S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110410, 7912, 'De Volta ao Mundo Amish S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110411, 7912, 'De Volta ao Mundo Amish S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110412, 7912, 'De Volta ao Mundo Amish S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j89s6mETypixSn1mc1pciN7f1aW.jpg'),
(110413, 7913, 'Diário das Fadas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110414, 7913, 'Diário das Fadas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110415, 7913, 'Diário das Fadas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110416, 7913, 'Diário das Fadas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110417, 7913, 'Diário das Fadas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110418, 7913, 'Diário das Fadas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110419, 7913, 'Diário das Fadas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110420, 7913, 'Diário das Fadas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110421, 7913, 'Diário das Fadas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110422, 7913, 'Diário das Fadas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110423, 7913, 'Diário das Fadas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110424, 7913, 'Diário das Fadas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110425, 7913, 'Diário das Fadas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110426, 7913, 'Diário das Fadas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110427, 7913, 'Diário das Fadas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110428, 7913, 'Diário das Fadas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/226127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110429, 7913, 'Diário das Fadas S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/226128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110430, 7913, 'Diário das Fadas S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/226129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110431, 7913, 'Diário das Fadas S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/226130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110432, 7913, 'Diário das Fadas S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/226131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110433, 7913, 'Diário das Fadas S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/226132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110434, 7913, 'Diário das Fadas S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/226133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110435, 7913, 'Diário das Fadas S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/226134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110436, 7913, 'Diário das Fadas S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/226135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110437, 7913, 'Diário das Fadas S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/226136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110438, 7913, 'Diário das Fadas S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/226137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110439, 7913, 'Diário das Fadas S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/226138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110440, 7913, 'Diário das Fadas S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/226139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d95JvETMEPJHyFysJQrKTg8MxIX.jpg'),
(110441, 7914, 'Grizzy e os Lemmings S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/neMnQJymxUrlVIy21cyfJYnFTXG.jpg'),
(110442, 7914, 'Grizzy e os Lemmings S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w0r0iaXwEwTO7MQkmRmT6773bak.jpg'),
(110443, 7914, 'Grizzy e os Lemmings S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7G9zyIYFYc6NrCi0Z1hXEwQlkBd.jpg'),
(110444, 7914, 'Grizzy e os Lemmings S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jLWKtV704QVSxRNnHrLrFUmQi3I.jpg'),
(110445, 7914, 'Grizzy e os Lemmings S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCr1lsUoCTHThhLUuFWabuhiVxU.jpg'),
(110446, 7914, 'Grizzy e os Lemmings S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cPU0JEHj4ebVxkK1aXPwTefypkl.jpg'),
(110447, 7914, 'Grizzy e os Lemmings S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSYY74qvy1QIyhlx7Eqm5R43JpH.jpg'),
(110448, 7914, 'Grizzy e os Lemmings S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ya8m8VaKJjKUMrGYEtPyiyltTtH.jpg'),
(110449, 7914, 'Grizzy e os Lemmings S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tKiGjjLRcxvrNvz8WTpDwfCHxzF.jpg'),
(110450, 7914, 'Grizzy e os Lemmings S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pSZSHC8jy2B5Sr1vOpcYxLnwfkw.jpg'),
(110451, 7914, 'Grizzy e os Lemmings S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j6pYo58ydgtOHhH3Hqs3UjEUBmM.jpg'),
(110452, 7914, 'Grizzy e os Lemmings S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/PSW2MVBx2WQpg4tUtj6D7ydbIE.jpg'),
(110453, 7914, 'Grizzy e os Lemmings S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nyqP01u90iZfyjRbO5rICrDskEj.jpg'),
(110454, 7914, 'Grizzy e os Lemmings S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/225891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2m1xWPjETeuqRXRA6NVb6OMjaqD.jpg'),
(110455, 7914, 'Grizzy e os Lemmings S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/225892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ltXNNH0DxABe4UESNyRrTOlmSfZ.jpg'),
(110456, 7914, 'Grizzy e os Lemmings S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/225893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u89z8ECjpPgksMNNUgzr2LPqJDt.jpg'),
(110457, 7914, 'Grizzy e os Lemmings S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/225894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ipHwyaGJzcJICITZFoj5Bu4TwL.jpg'),
(110458, 7914, 'Grizzy e os Lemmings S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/225895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zjSTmxy5ifbnDncUgCuCiBp1468.jpg'),
(110459, 7914, 'Grizzy e os Lemmings S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/225896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tnoGzgkHpv9xCGjE8hY4SeqNUzO.jpg'),
(110460, 7914, 'Grizzy e os Lemmings S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/225897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3gpzENge432ICXXVgrq1f57RBoV.jpg'),
(110461, 7914, 'Grizzy e os Lemmings S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/225898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qA14j0aKtpelFNFz9owzxgpvcSA.jpg'),
(110462, 7914, 'Grizzy e os Lemmings S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/225899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sOqY960pETjcnLDVank3havCxU3.jpg'),
(110463, 7914, 'Grizzy e os Lemmings S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/225900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w0wBP2rXWlRr36z0tdUM88lxThy.jpg'),
(110464, 7914, 'Grizzy e os Lemmings S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/225901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p5otitIAUAHINKn93Fy1FOwa4re.jpg'),
(110465, 7914, 'Grizzy e os Lemmings S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/225902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aSWlYwp3ket0Cv4eqli1iPAV57O.jpg'),
(110466, 7914, 'Grizzy e os Lemmings S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/225903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8YvHLpyUW1FTcs8KiqUtnZN4YQe.jpg'),
(110467, 7914, 'Grizzy e os Lemmings S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/225904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nAKVIxINW7gXpc1eX1SuPJmF7mb.jpg'),
(110468, 7914, 'Grizzy e os Lemmings S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/225905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9fAjjAmLd51fWbIJovyIV9ZAuXM.jpg'),
(110469, 7914, 'Grizzy e os Lemmings S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/225906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9W1kCuxRtWtZKpWWDrLS2cbywZA.jpg'),
(110470, 7914, 'Grizzy e os Lemmings S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/225907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ei1thZWbrJjBhNiPeSZyDHtNEUf.jpg'),
(110471, 7914, 'Grizzy e os Lemmings S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/225908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g5tjOIWmxmHcXnwycLwwpJChBEb.jpg'),
(110472, 7914, 'Grizzy e os Lemmings S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/225909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jq5a00SVeKnPwVCn33lRf6T6Jwb.jpg'),
(110473, 7914, 'Grizzy e os Lemmings S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/225910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mMt32jLHQ50DCVwJ7qJrhVDLtFE.jpg'),
(110474, 7914, 'Grizzy e os Lemmings S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/225911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fKwCYm0feDKAsyxxFU543WLXvCw.jpg'),
(110475, 7914, 'Grizzy e os Lemmings S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/225912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e0egeX3MlM6W5w7jHpeb1u8TRJg.jpg'),
(110476, 7914, 'Grizzy e os Lemmings S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/225913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4v7s4kPV8WtG1FARZSQcknIgTnK.jpg'),
(110477, 7914, 'Grizzy e os Lemmings S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/225914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g2bKFCWoqzxd0P9uHQ2M1h5Ddru.jpg'),
(110478, 7914, 'Grizzy e os Lemmings S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/225915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h6f9e4rrxYhCZdZlTFna0qwu2b0.jpg'),
(110479, 7914, 'Grizzy e os Lemmings S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/225916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pwz6loX5oeGIH7ljx2kgniBaMqL.jpg'),
(110480, 7914, 'Grizzy e os Lemmings S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/225917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/miGJKBTnEoogBjz55oKX9uaXUF2.jpg'),
(110481, 7914, 'Grizzy e os Lemmings S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/225918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Yh64yVR1RV8P2qiVeZDrEqcCcn.jpg'),
(110482, 7914, 'Grizzy e os Lemmings S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/225919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n4Ap38SBryVIGubupYtITKHB3CT.jpg'),
(110483, 7914, 'Grizzy e os Lemmings S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/225920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yrvSWvH0DrNzKIkNcm94PXbp5Lt.jpg'),
(110484, 7914, 'Grizzy e os Lemmings S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/225921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgDk7WOHQgnFny6XjkjjAskp8h7.jpg'),
(110485, 7914, 'Grizzy e os Lemmings S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/225922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ceNaC5YfB8ouVulEGcArFd1jsx.jpg'),
(110486, 7914, 'Grizzy e os Lemmings S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/225923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aoRZ7q6ei5Oj3WYTGLdmhKnEcIn.jpg'),
(110487, 7914, 'Grizzy e os Lemmings S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/225924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4bOTkyWVOCEWA9ltlUgfKxkZtsN.jpg'),
(110488, 7914, 'Grizzy e os Lemmings S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/225925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qvnQdrUynCX6eGOGwSotdaIP1Jo.jpg'),
(110489, 7914, 'Grizzy e os Lemmings S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/225926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9O8n125igT2lvbXA7CO40J40YhW.jpg'),
(110490, 7914, 'Grizzy e os Lemmings S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/225927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xLjLMWvNR4GX0BlBXABhtsagZcw.jpg'),
(110491, 7914, 'Grizzy e os Lemmings S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/225928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8bKTzDCfy80VIaiavMYgjIKTQMV.jpg'),
(110492, 7914, 'Grizzy e os Lemmings S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/225929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nu53TwAGUo9Jzbcvjm6KmS0D7qk.jpg'),
(110493, 7914, 'Grizzy e os Lemmings S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/225930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oIeJraETrXJRET49bDquqmHTr6k.jpg'),
(110494, 7914, 'Grizzy e os Lemmings S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/225931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gd4qSxr3AoW16ZkS1Lc6w8vHBr.jpg'),
(110495, 7914, 'Grizzy e os Lemmings S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/225932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oSstO827Cbauf8ho0q7Dx8L86iP.jpg'),
(110496, 7914, 'Grizzy e os Lemmings S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/225933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aVhnO9w8yL69ojvIHjswdoaELCn.jpg'),
(110497, 7914, 'Grizzy e os Lemmings S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/225934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qx4hN2FsQh2WpwpgXbMFLp3Bh9U.jpg'),
(110498, 7914, 'Grizzy e os Lemmings S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/225935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4xZVFuZHKRdJZaURB5v5JFfifgp.jpg'),
(110499, 7914, 'Grizzy e os Lemmings S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/225936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8vhj0xDnWyVhRZuxkzOOsCC7GYV.jpg'),
(110500, 7914, 'Grizzy e os Lemmings S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/225937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hKIMD03xIxbc6kIfXgRuBndurw8.jpg'),
(110501, 7914, 'Grizzy e os Lemmings S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/225938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8XdrT7DTF1zdyIq0wwAYezf4M2.jpg'),
(110502, 7914, 'Grizzy e os Lemmings S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/225939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m5A2sUMbqufEZdFba8SSrtK4kuS.jpg'),
(110503, 7914, 'Grizzy e os Lemmings S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/225940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ntVY5sivIvKSzRfipAbYJ1N6OKM.jpg'),
(110504, 7914, 'Grizzy e os Lemmings S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/225941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w9ofFqK63W1xDJPuPy3bKCIXcPQ.jpg'),
(110505, 7914, 'Grizzy e os Lemmings S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/225942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5k0JCfVAScXV4WTHrsDzw2myKav.jpg'),
(110506, 7914, 'Grizzy e os Lemmings S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/225943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cWJLUSovS1ukFqvLoB717Q8fg3n.jpg'),
(110507, 7914, 'Grizzy e os Lemmings S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/225944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pGvvqxYaoOtlgVGxSGXEDBRl6dn.jpg'),
(110508, 7914, 'Grizzy e os Lemmings S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/225945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8X3Dc7bHlZ1Bt79nktBUAAYiVQq.jpg'),
(110509, 7914, 'Grizzy e os Lemmings S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/225946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9dyDUdW0q2TTl6ApgP0SXgYv0j.jpg'),
(110510, 7914, 'Grizzy e os Lemmings S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/225947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PApGkN3zd0tOtwa2PJ9hOQph95.jpg'),
(110511, 7914, 'Grizzy e os Lemmings S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/225948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dYcrw8UqdtdBEj3EEcHvAwbuS81.jpg'),
(110512, 7914, 'Grizzy e os Lemmings S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/225949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDsc1XJ8FfyTDBuSgMboopV6DVs.jpg'),
(110513, 7914, 'Grizzy e os Lemmings S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/225950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pxVp9UOFUheL1hDKIaWkvVXzSM8.jpg'),
(110514, 7914, 'Grizzy e os Lemmings S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/225951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ea77owBteC2WzVsU145fNOPlGX5.jpg'),
(110515, 7914, 'Grizzy e os Lemmings S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/225952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wRo1g466ynNCpZGFMaZPFHqPKNQ.jpg'),
(110516, 7914, 'Grizzy e os Lemmings S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/225953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/msnlZO7HqGLefRHcrkNJgJwyhHl.jpg'),
(110517, 7914, 'Grizzy e os Lemmings S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/225954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r3IvuR78sSewgqXIr54t6TbpxsH.jpg'),
(110518, 7914, 'Grizzy e os Lemmings S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/225955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5OCEKWMoGl98U42RZNOREe48NGG.jpg'),
(110519, 7915, 'Grizzy e os Lemmings S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cfjo63069Wx0VINqnovYWv2zuUU.jpg'),
(110520, 7915, 'Grizzy e os Lemmings S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zQVbPTyyRm0Jm0ZQgWNVIUk6TrL.jpg'),
(110521, 7915, 'Grizzy e os Lemmings S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/162jPYLUBDtygaBMV6csv6zszC3.jpg'),
(110522, 7915, 'Grizzy e os Lemmings S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Yz1o6oKn2CYuF0bK8XJun3xuan.jpg'),
(110523, 7915, 'Grizzy e os Lemmings S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/senjdMjeLD7j5THHAbkl06d3x7Z.jpg'),
(110524, 7915, 'Grizzy e os Lemmings S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9lTIXIUeONOSRjfnVRvelORzbbw.jpg'),
(110525, 7915, 'Grizzy e os Lemmings S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h9I90FC0hRjqWIQPkU8zcLwyTrj.jpg'),
(110526, 7915, 'Grizzy e os Lemmings S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fcdF1ixyS8NVVhTLNFHdDwaZ7ku.jpg'),
(110527, 7915, 'Grizzy e os Lemmings S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wqXFfsEAEkkR3LDoquA24nZKxhA.jpg'),
(110528, 7915, 'Grizzy e os Lemmings S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5TXcrpWsqd7iIGhNRgN588ceyLa.jpg'),
(110529, 7915, 'Grizzy e os Lemmings S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2FV9nlfx9NgRcRoq5Yn6epthib4.jpg'),
(110530, 7915, 'Grizzy e os Lemmings S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A1X5k2lRPGs7FeZD6ZjLiXNv1zr.jpg'),
(110531, 7915, 'Grizzy e os Lemmings S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yzRpI83CSgAlhSr0xxcUikKqt87.jpg'),
(110532, 7915, 'Grizzy e os Lemmings S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/225969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/niZqJqybjcBAhDohXqBrk9XUiy2.jpg'),
(110533, 7915, 'Grizzy e os Lemmings S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/225970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ArcA9kXHHJntMiX6rzFfgMT3QU2.jpg'),
(110534, 7915, 'Grizzy e os Lemmings S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/225971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5YYgrRydasn7MVWG4HqRo6ScpAd.jpg'),
(110535, 7915, 'Grizzy e os Lemmings S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/225972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eRxtVz5qAqcIgEwQdea5gqLhwDa.jpg'),
(110536, 7915, 'Grizzy e os Lemmings S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/225973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qxdHHpyciRlt5cSXRhPY61ysriu.jpg'),
(110537, 7915, 'Grizzy e os Lemmings S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/225974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c9juNv8GmZEac8QSmM5rhK3eQnO.jpg'),
(110538, 7915, 'Grizzy e os Lemmings S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/225975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wIW1ygU8O1zKtKAHb40npwVLy5t.jpg'),
(110539, 7915, 'Grizzy e os Lemmings S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/225976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zJr1tf7PIZImN85okPFjaiZfYtt.jpg'),
(110540, 7915, 'Grizzy e os Lemmings S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/225977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/38kXYrFU7xyXVvtjgwrX8PBf1x7.jpg'),
(110541, 7915, 'Grizzy e os Lemmings S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/225978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gUNSdZXojwrUMugE0PQ2Olq3uHJ.jpg'),
(110542, 7915, 'Grizzy e os Lemmings S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/225979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBzi1NvMRZXkxJvPtUvzX8PuMhF.jpg'),
(110543, 7915, 'Grizzy e os Lemmings S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/225980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Ll37gOc0v780jLjXpDJ9V7LbnJ.jpg'),
(110544, 7915, 'Grizzy e os Lemmings S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/225981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/syM1Hria8NUcWbxYTi3wFLMl0We.jpg'),
(110545, 7915, 'Grizzy e os Lemmings S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/225982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kAikdcYGa1WCxlOm9bukFemL0ij.jpg'),
(110546, 7915, 'Grizzy e os Lemmings S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/225983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3xePCK8KvP3gnhdhxBQfh6MqGI6.jpg'),
(110547, 7915, 'Grizzy e os Lemmings S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/225984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FLZSFUpyYtyvhumDlVn2hcSLpr.jpg'),
(110548, 7915, 'Grizzy e os Lemmings S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/225985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/otmPFnEIHIFNSI4yUwMNrQF6F49.jpg'),
(110549, 7915, 'Grizzy e os Lemmings S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/225986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l4I5r5qw1qoMX15rxgQs1QEQb5s.jpg'),
(110550, 7915, 'Grizzy e os Lemmings S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/225987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qOLIDd9AE3GY7APsGWlCpsRbYNJ.jpg'),
(110551, 7915, 'Grizzy e os Lemmings S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/225988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hg6KEYiBsTnjmjwVf7DrefdAlxs.jpg'),
(110552, 7915, 'Grizzy e os Lemmings S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/225989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sYEQ2gJD3ZXC4ZAKWVGjxmpdwXG.jpg'),
(110553, 7915, 'Grizzy e os Lemmings S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/225990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3TmsFVIG1tsyZUWISgo7h2410Yf.jpg'),
(110554, 7915, 'Grizzy e os Lemmings S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/225991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/astecKGbKf78BtsHDoizVqijZP5.jpg'),
(110555, 7915, 'Grizzy e os Lemmings S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/225992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vxRyBlt0WaMraSQPE18jMMOWa5a.jpg'),
(110556, 7915, 'Grizzy e os Lemmings S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/225993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8gkcWcfY7ujCljYNqJRkMtOEjvc.jpg'),
(110557, 7915, 'Grizzy e os Lemmings S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/225994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zUpEWA54uZ2izkReDw13ilhrdUp.jpg'),
(110558, 7915, 'Grizzy e os Lemmings S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/225995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jjY9YzL7A7yLcs0Yya8WcruXwyk.jpg'),
(110559, 7915, 'Grizzy e os Lemmings S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/225996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1F4mYeZCyGxyNhpPa4SFkWFPWe9.jpg'),
(110560, 7915, 'Grizzy e os Lemmings S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/225997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wtFfw7OeeDUWP6SCJZrEHDmkA5f.jpg'),
(110561, 7915, 'Grizzy e os Lemmings S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/225998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j4bnLleAlbWj6lDcg3lVSW2DBc9.jpg'),
(110562, 7915, 'Grizzy e os Lemmings S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/225999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCuJowNz2wZWzlNXMX4vwh9dIEV.jpg'),
(110563, 7915, 'Grizzy e os Lemmings S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/226000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/seGbBOPk04rRTT7d2nPOUjtAbot.jpg'),
(110564, 7915, 'Grizzy e os Lemmings S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/226001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zpjxXnWE4qzNhmZHh4ZrY3aSNG6.jpg'),
(110565, 7915, 'Grizzy e os Lemmings S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/226002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gM5OWtGmvUt09dE3ULeZTvZGUvH.jpg'),
(110566, 7915, 'Grizzy e os Lemmings S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/226003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n2biMeO70ODYq9Oge141AhETtxg.jpg'),
(110567, 7915, 'Grizzy e os Lemmings S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/226004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8leEYA9OwL8CmOUGwPxwesZnWF5.jpg'),
(110568, 7915, 'Grizzy e os Lemmings S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/226005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJcQoyzHApfGY6WaC7W1TEDbdMn.jpg'),
(110569, 7915, 'Grizzy e os Lemmings S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/226006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xyStHQj7FqSn2st8WaBB7Ukyr3M.jpg'),
(110570, 7915, 'Grizzy e os Lemmings S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/226007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/md0fKcDoKjEPsebai6sTg0x30zC.jpg'),
(110571, 7915, 'Grizzy e os Lemmings S02 E53', 'http://sinalprivado.info:80/series/1533784/1533784/226008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3XqAYu3wu38CXJ5ZOiNJyq9I8Q.jpg'),
(110572, 7915, 'Grizzy e os Lemmings S02 E54', 'http://sinalprivado.info:80/series/1533784/1533784/226009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n0fmSf6srLOPhuuyzcOARF7WPf.jpg'),
(110573, 7915, 'Grizzy e os Lemmings S02 E55', 'http://sinalprivado.info:80/series/1533784/1533784/226010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aONx5hOUPbpNXRdOJpj3geS4vnt.jpg'),
(110574, 7915, 'Grizzy e os Lemmings S02 E56', 'http://sinalprivado.info:80/series/1533784/1533784/226011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p35C97P7Csxi9nBZ3jzZ8RBNhc8.jpg'),
(110575, 7915, 'Grizzy e os Lemmings S02 E57', 'http://sinalprivado.info:80/series/1533784/1533784/226012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uCF1oBtkj7vOxHpMuEW2s5M1VlX.jpg'),
(110576, 7915, 'Grizzy e os Lemmings S02 E58', 'http://sinalprivado.info:80/series/1533784/1533784/226013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n1kJm6BlDcpHnwWlyGNyJH6hrSu.jpg'),
(110577, 7915, 'Grizzy e os Lemmings S02 E59', 'http://sinalprivado.info:80/series/1533784/1533784/226014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eWcY6XjIQK7S7suhBSnb4OVIaEH.jpg'),
(110578, 7915, 'Grizzy e os Lemmings S02 E60', 'http://sinalprivado.info:80/series/1533784/1533784/226015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Zer8y2zOTijVgZl8jHcexYxSns.jpg'),
(110579, 7915, 'Grizzy e os Lemmings S02 E61', 'http://sinalprivado.info:80/series/1533784/1533784/226016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3sQHsedtcWjmZuCwIii8dc8UqN9.jpg'),
(110580, 7915, 'Grizzy e os Lemmings S02 E62', 'http://sinalprivado.info:80/series/1533784/1533784/226017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x0W7mOZ9vJRyC7tFKHLr7Pr1d1U.jpg'),
(110581, 7915, 'Grizzy e os Lemmings S02 E63', 'http://sinalprivado.info:80/series/1533784/1533784/226018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c4Y19B5UXIkE7VUosgfVjHNcycX.jpg'),
(110582, 7915, 'Grizzy e os Lemmings S02 E64', 'http://sinalprivado.info:80/series/1533784/1533784/226019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJVbsBiqnItsRyAQLvkUcV6txqU.jpg'),
(110583, 7915, 'Grizzy e os Lemmings S02 E65', 'http://sinalprivado.info:80/series/1533784/1533784/226020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hBVsl7Bq4ZOqLuBD5Hgi4hlEwwT.jpg'),
(110584, 7915, 'Grizzy e os Lemmings S02 E66', 'http://sinalprivado.info:80/series/1533784/1533784/226021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yPtRiwMq4RdEf0ia5FBA4geVHR3.jpg'),
(110585, 7915, 'Grizzy e os Lemmings S02 E67', 'http://sinalprivado.info:80/series/1533784/1533784/226022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xEPUEGF7emSfHW7W3jtEDM5OxMO.jpg'),
(110586, 7915, 'Grizzy e os Lemmings S02 E68', 'http://sinalprivado.info:80/series/1533784/1533784/226023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9jZ6s62kZNPhtMS0OIwslBcBkLP.jpg'),
(110587, 7915, 'Grizzy e os Lemmings S02 E69', 'http://sinalprivado.info:80/series/1533784/1533784/226024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mDsYfmLwxCcg5o3gUWTTCB3FjCU.jpg'),
(110588, 7915, 'Grizzy e os Lemmings S02 E70', 'http://sinalprivado.info:80/series/1533784/1533784/226025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i6NJAVjni39F0lYpNQ10rI3yXxz.jpg'),
(110589, 7915, 'Grizzy e os Lemmings S02 E71', 'http://sinalprivado.info:80/series/1533784/1533784/226026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kQqfIGYnbgPndQmEPHAigZtbVEb.jpg'),
(110590, 7915, 'Grizzy e os Lemmings S02 E72', 'http://sinalprivado.info:80/series/1533784/1533784/226027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c759rfyq9Lx3AYouNe4iDNIxJKw.jpg'),
(110591, 7915, 'Grizzy e os Lemmings S02 E73', 'http://sinalprivado.info:80/series/1533784/1533784/226028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8W6P1d9n3kH883TDqe3DJtyS8lo.jpg'),
(110592, 7915, 'Grizzy e os Lemmings S02 E74', 'http://sinalprivado.info:80/series/1533784/1533784/226029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2eBuiknYv357jT3oF0xKqtQCCKV.jpg'),
(110593, 7915, 'Grizzy e os Lemmings S02 E75', 'http://sinalprivado.info:80/series/1533784/1533784/226030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rdhgXZGHc3vTX5qGAN7k0eKzOhy.jpg'),
(110594, 7915, 'Grizzy e os Lemmings S02 E76', 'http://sinalprivado.info:80/series/1533784/1533784/226031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8GNFzCFMlMXV18pUgDjUH0wpl1u.jpg'),
(110595, 7915, 'Grizzy e os Lemmings S02 E77', 'http://sinalprivado.info:80/series/1533784/1533784/226032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hjgBA37e8o1CyCxYJiIEVkquicB.jpg'),
(110596, 7915, 'Grizzy e os Lemmings S02 E78', 'http://sinalprivado.info:80/series/1533784/1533784/226033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tubUtutjtJm9m8G3nBhAFCiVI57.jpg'),
(110597, 7916, 'Grizzy e os Lemmings S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/226034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBADqRwExeoBUXEJ96joTt73Qh.jpg'),
(110598, 7916, 'Grizzy e os Lemmings S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/226035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6muhLOiu0rBGSv6Ykgd4kPJKdaP.jpg'),
(110599, 7916, 'Grizzy e os Lemmings S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/226036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s2cIrFKwRdR3DjayE9h65dsLEiv.jpg'),
(110600, 7916, 'Grizzy e os Lemmings S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/226037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sCRJgOoxjbiCvpc2ecMfmcBrzBX.jpg'),
(110601, 7916, 'Grizzy e os Lemmings S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/226038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nO4fIVp8Omp6wrwTN6DsdiooZpQ.jpg'),
(110602, 7916, 'Grizzy e os Lemmings S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/226039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ppcZLQZRvyoBJfnmyclWE6ooc3H.jpg'),
(110603, 7916, 'Grizzy e os Lemmings S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/226040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s0v1cgTURcIa8tYrJ7fLjvegj7A.jpg'),
(110604, 7916, 'Grizzy e os Lemmings S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/226041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sRKK7ak0eCw6g7M6u2kdAg6Elac.jpg'),
(110605, 7916, 'Grizzy e os Lemmings S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/226042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/itXhWkqKmAOfdruoUzlRV2WncF.jpg'),
(110606, 7916, 'Grizzy e os Lemmings S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/226043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sML0Pbr4TNhJvVYQtTEz4lxIEvq.jpg'),
(110607, 7916, 'Grizzy e os Lemmings S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/226044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5TKjTlm1MjA6s3isrAFHNZGHtd8.jpg'),
(110608, 7916, 'Grizzy e os Lemmings S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/226045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2L0oiaiB5YM0L2B5pvlSeodEMNS.jpg'),
(110609, 7916, 'Grizzy e os Lemmings S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/226046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uLVZHi3DTEkA2AX8hrF4wZUU0zB.jpg'),
(110610, 7916, 'Grizzy e os Lemmings S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/226047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s95lTjHztZLnncy4bTuV9z7f1Rc.jpg'),
(110611, 7916, 'Grizzy e os Lemmings S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/226048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o4CrrYrnGkt9SUYDvQHz4iVWjnr.jpg'),
(110612, 7916, 'Grizzy e os Lemmings S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/226049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l6SxELBUY8fvcNzI0wj0ddJphiM.jpg'),
(110613, 7916, 'Grizzy e os Lemmings S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/226050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g3n2rL2fFHHAlDKk4pn8sxd2o5o.jpg'),
(110614, 7916, 'Grizzy e os Lemmings S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/226051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5OFb4iMlOqMaW38AsnUuhWD5wgf.jpg'),
(110615, 7916, 'Grizzy e os Lemmings S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/226052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tvS001DPbO6PsdvlnJTEtRHgDlH.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(110616, 7916, 'Grizzy e os Lemmings S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/226053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8QWsPodqn5nNYhmhDfXWjoM89Rm.jpg'),
(110617, 7916, 'Grizzy e os Lemmings S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/226054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wdC2e9fa7ChuNxwOOW1cXGeN7XV.jpg'),
(110618, 7916, 'Grizzy e os Lemmings S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/226055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lhMC2UET4rOKk11l2S9QUyqmpyt.jpg'),
(110619, 7916, 'Grizzy e os Lemmings S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/226056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hn5iOtnPDuxjsE3EVTWIAg1oelz.jpg'),
(110620, 7916, 'Grizzy e os Lemmings S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/226057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gpL8RhRRJEH6YT3aU2Eto94lqbB.jpg'),
(110621, 7916, 'Grizzy e os Lemmings S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/226058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dgboipzi82l55h7704l8Fc3KE4W.jpg'),
(110622, 7916, 'Grizzy e os Lemmings S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/226059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkB3Dn03SoCtqxavmldkvHwKnt2.jpg'),
(110623, 7916, 'Grizzy e os Lemmings S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/226060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tkZWbmJtx1QJBaqWHsiLDlQl1Lb.jpg'),
(110624, 7916, 'Grizzy e os Lemmings S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/226061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/czRo7dQEsL0xZEdSHSvqLI90GQA.jpg'),
(110625, 7916, 'Grizzy e os Lemmings S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/226062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kWOHrpCRLpJwSD69thxVJX6XORG.jpg'),
(110626, 7916, 'Grizzy e os Lemmings S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/226063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e4SAonUNw8Iooad81ObwXZIvHr6.jpg'),
(110627, 7916, 'Grizzy e os Lemmings S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/226064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qIDYHTgLtoXoAkxKHvwTDyQgE92.jpg'),
(110628, 7916, 'Grizzy e os Lemmings S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/226065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eKSydXd4UiueZ6nvi63gazord6Q.jpg'),
(110629, 7916, 'Grizzy e os Lemmings S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/226066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lUQnguULCI1pC2Kf5chnEXSgD7O.jpg'),
(110630, 7916, 'Grizzy e os Lemmings S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/226067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/S5BV7TzloApYtCorzUiv619E3k.jpg'),
(110631, 7916, 'Grizzy e os Lemmings S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/226068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3HOqG3j6TbD6hHYPtqEmMZWbFFg.jpg'),
(110632, 7916, 'Grizzy e os Lemmings S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/226069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/haOFqPIGp8GfupOCtabprah98lY.jpg'),
(110633, 7916, 'Grizzy e os Lemmings S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/226070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7bBhjrB1O7BZYkhURXbYjdqClKz.jpg'),
(110634, 7916, 'Grizzy e os Lemmings S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/226071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rUzb2KklnhBv1u2B2oueuvGUFQd.jpg'),
(110635, 7916, 'Grizzy e os Lemmings S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/226072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qgCAiLsQHk4a7ON77sy9Ha8xyDr.jpg'),
(110636, 7916, 'Grizzy e os Lemmings S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/226073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h5JTG7ulgSZ9iLPlBgI9wDleIp7.jpg'),
(110637, 7916, 'Grizzy e os Lemmings S03 E41', 'http://sinalprivado.info:80/series/1533784/1533784/226074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kobrjuQsbYsnIQwyzLLpz9Vfg44.jpg'),
(110638, 7916, 'Grizzy e os Lemmings S03 E42', 'http://sinalprivado.info:80/series/1533784/1533784/226075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iupYsSbaueYufC0g7QbNZUXT7wq.jpg'),
(110639, 7916, 'Grizzy e os Lemmings S03 E43', 'http://sinalprivado.info:80/series/1533784/1533784/226076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tL5tk2BcJRFtnctWz0BlgLf8QDQ.jpg'),
(110640, 7916, 'Grizzy e os Lemmings S03 E44', 'http://sinalprivado.info:80/series/1533784/1533784/226077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1x35OzhR8GwxPuuPyl4MTj4lNwm.jpg'),
(110641, 7916, 'Grizzy e os Lemmings S03 E45', 'http://sinalprivado.info:80/series/1533784/1533784/226078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c27JQm9nlx2UuAHXYvN6GJ8nDfu.jpg'),
(110642, 7916, 'Grizzy e os Lemmings S03 E46', 'http://sinalprivado.info:80/series/1533784/1533784/226079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sddog9XQ6F9Snr7iKbQ4AMglRq6.jpg'),
(110643, 7916, 'Grizzy e os Lemmings S03 E47', 'http://sinalprivado.info:80/series/1533784/1533784/226080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ZsJ7Mob8VLA1B7DLN8KZ1y3KTu.jpg'),
(110644, 7916, 'Grizzy e os Lemmings S03 E48', 'http://sinalprivado.info:80/series/1533784/1533784/226081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wWpmCUFZrDSegUGp9Sv9h2hyET.jpg'),
(110645, 7916, 'Grizzy e os Lemmings S03 E49', 'http://sinalprivado.info:80/series/1533784/1533784/226082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uA3Lhkm2dKBMYV48pvpSnBIr64w.jpg'),
(110646, 7916, 'Grizzy e os Lemmings S03 E50', 'http://sinalprivado.info:80/series/1533784/1533784/226083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uFCrXk7hKwFZwy9KGuxV6R9IF6M.jpg'),
(110647, 7916, 'Grizzy e os Lemmings S03 E51', 'http://sinalprivado.info:80/series/1533784/1533784/226084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8GmXVc2vWsWhz8ZhZC9ewJ2HzeU.jpg'),
(110648, 7916, 'Grizzy e os Lemmings S03 E52', 'http://sinalprivado.info:80/series/1533784/1533784/226085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9VWewt7UYUhrg3c9Whb4osjefme.jpg'),
(110649, 7916, 'Grizzy e os Lemmings S03 E53', 'http://sinalprivado.info:80/series/1533784/1533784/226086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n8T1wR9aiFfHfKZDHb5bIyzKTw8.jpg'),
(110650, 7916, 'Grizzy e os Lemmings S03 E54', 'http://sinalprivado.info:80/series/1533784/1533784/226087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tPcvLZpvWuai4zNeE5mA7vCwJ9h.jpg'),
(110651, 7916, 'Grizzy e os Lemmings S03 E55', 'http://sinalprivado.info:80/series/1533784/1533784/226088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zfN2UowBmUpIdnYoDBRA8rAwUQF.jpg'),
(110652, 7916, 'Grizzy e os Lemmings S03 E56', 'http://sinalprivado.info:80/series/1533784/1533784/226089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJVn2DknolcuFYxsiEcBqLiTk3a.jpg'),
(110653, 7916, 'Grizzy e os Lemmings S03 E57', 'http://sinalprivado.info:80/series/1533784/1533784/226090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c9ZaQitLjIakdvyNUTpCVm4jIPU.jpg'),
(110654, 7916, 'Grizzy e os Lemmings S03 E58', 'http://sinalprivado.info:80/series/1533784/1533784/226091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pL9zxicpsCKbXLjxNS2RkJY411h.jpg'),
(110655, 7916, 'Grizzy e os Lemmings S03 E59', 'http://sinalprivado.info:80/series/1533784/1533784/226092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cAWgfesjZ2sA2c0LxTzYOXYpnzr.jpg'),
(110656, 7916, 'Grizzy e os Lemmings S03 E60', 'http://sinalprivado.info:80/series/1533784/1533784/226093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kl7q2KJ3KMHogqeFPuBj38WCI5S.jpg'),
(110657, 7916, 'Grizzy e os Lemmings S03 E61', 'http://sinalprivado.info:80/series/1533784/1533784/226094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/akIUeY8naIofB6Dus2NY4DneAbP.jpg'),
(110658, 7916, 'Grizzy e os Lemmings S03 E62', 'http://sinalprivado.info:80/series/1533784/1533784/226095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lgAeaYaqE89w5eUKRrXbh0VMr1g.jpg'),
(110659, 7916, 'Grizzy e os Lemmings S03 E63', 'http://sinalprivado.info:80/series/1533784/1533784/226096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/604hMY5zulmqzjAK6ehKqJAtl4B.jpg'),
(110660, 7916, 'Grizzy e os Lemmings S03 E64', 'http://sinalprivado.info:80/series/1533784/1533784/226097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/naoXvKKwudayA5tW3as3qhkfhzY.jpg'),
(110661, 7916, 'Grizzy e os Lemmings S03 E65', 'http://sinalprivado.info:80/series/1533784/1533784/226098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6fk4wDo6c7jdbx02HxDyfUJl38d.jpg'),
(110662, 7916, 'Grizzy e os Lemmings S03 E66', 'http://sinalprivado.info:80/series/1533784/1533784/226099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ec3OdQshgbkUSBdhGdSP5UYOCfq.jpg'),
(110663, 7916, 'Grizzy e os Lemmings S03 E67', 'http://sinalprivado.info:80/series/1533784/1533784/226100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/84AErfumFLYGg9LNUsuJKEcsu13.jpg'),
(110664, 7916, 'Grizzy e os Lemmings S03 E68', 'http://sinalprivado.info:80/series/1533784/1533784/226101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tGvGsYb79MnbNfdFxZimr7X92T8.jpg'),
(110665, 7916, 'Grizzy e os Lemmings S03 E69', 'http://sinalprivado.info:80/series/1533784/1533784/226102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3zzSMtXGVaSEq4o1dcPEwcJEZEu.jpg'),
(110666, 7916, 'Grizzy e os Lemmings S03 E70', 'http://sinalprivado.info:80/series/1533784/1533784/226103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wk82FSadhRVD1nanCA1l0Cg73dT.jpg'),
(110667, 7916, 'Grizzy e os Lemmings S03 E71', 'http://sinalprivado.info:80/series/1533784/1533784/226104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cUxz1UdaMXSC5xfaP5HQW3zwEPS.jpg'),
(110668, 7916, 'Grizzy e os Lemmings S03 E72', 'http://sinalprivado.info:80/series/1533784/1533784/226105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n2anNfqAsMKxIbaK2ZbOV1Sz6m9.jpg'),
(110669, 7916, 'Grizzy e os Lemmings S03 E73', 'http://sinalprivado.info:80/series/1533784/1533784/226106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6wBMWrPxCDetsXdlOZ9tHG4zc6R.jpg'),
(110670, 7916, 'Grizzy e os Lemmings S03 E74', 'http://sinalprivado.info:80/series/1533784/1533784/226107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lcR5ixaMCWjvorstCFatbWHq2S4.jpg'),
(110671, 7916, 'Grizzy e os Lemmings S03 E75', 'http://sinalprivado.info:80/series/1533784/1533784/226108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tbl3gvGRNDlqbsZ250n4Y8OM3oM.jpg'),
(110672, 7916, 'Grizzy e os Lemmings S03 E76', 'http://sinalprivado.info:80/series/1533784/1533784/226109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lTCvVlyZu5zBA0ud2pR4oi6TLxW.jpg'),
(110673, 7916, 'Grizzy e os Lemmings S03 E77', 'http://sinalprivado.info:80/series/1533784/1533784/226110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qA3NM3luPVFqSpjxtK8de8Foe7M.jpg'),
(110674, 7916, 'Grizzy e os Lemmings S03 E78', 'http://sinalprivado.info:80/series/1533784/1533784/226111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qA3NM3luPVFqSpjxtK8de8Foe7M.jpg'),
(110675, 7917, 'Joe Pickett [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzTKR171qsX3ADmwqgA48K9hkgA.jpg'),
(110676, 7917, 'Joe Pickett [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xlF1ZRhlgb2lb9MmXX1yTuU24WH.jpg'),
(110677, 7917, 'Joe Pickett [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Y6fmM2od9dm0cUnMgPjPvGd2Yx.jpg'),
(110678, 7917, 'Joe Pickett [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/evCEIKDi6y1ASlshvUPvZ3mioGM.jpg'),
(110679, 7917, 'Joe Pickett [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pjaZFjVWwD4GfpiGVEGHSsb9XfB.jpg'),
(110680, 7917, 'Joe Pickett [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/70vI2cwnnpItR5vV8K7wHanWw7D.jpg'),
(110681, 7917, 'Joe Pickett [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q45488MAalGkUl4KnJxsASIM7OR.jpg'),
(110682, 7917, 'Joe Pickett [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ldv2mt6qFMaghkSPMV1kqtzdd3G.jpg'),
(110683, 7917, 'Joe Pickett [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1yfos9P1zmiEWFNmBdeMUBtJuCT.jpg'),
(110684, 7917, 'Joe Pickett [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AmfO1A4YpAb448hnjwpAnam9acZ.jpg'),
(110685, 7918, 'Joe Pickett [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zbG8aJ7AFIrRxORQdPTcrUBMWWM.jpg'),
(110686, 7918, 'Joe Pickett [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jGpYoDKVj4uIyqjiw1JKjR33Hdc.jpg'),
(110687, 7918, 'Joe Pickett [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/faphK8v8gOOUcm93gT2mSh6KtYq.jpg'),
(110688, 7918, 'Joe Pickett [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWErWXgqgpZCLW3hVi4rixh2Qea.jpg'),
(110689, 7918, 'Joe Pickett [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9VrdJP6gd6EfcwmgEDUBJGjjuCB.jpg'),
(110690, 7918, 'Joe Pickett [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eprP4mz2SX8hYRttLDlF0FLatyd.jpg'),
(110691, 7918, 'Joe Pickett [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aIUuNIUjtaaYo1Y88OFXCP9BmeU.jpg'),
(110692, 7918, 'Joe Pickett [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8kbLUohy3Ytybb139u2zCohOuGb.jpg'),
(110693, 7918, 'Joe Pickett [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rOXnFFVw5rZCB0RvRq0tYIKjM7y.jpg'),
(110694, 7918, 'Joe Pickett [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zZrsIImn5cTfmGYT4PrP7Xqgens.jpg'),
(110695, 7919, 'Longing for You [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uP3tBwX4NXhkd74JN50ZF1vkMID.jpg'),
(110696, 7919, 'Longing for You [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/U6YWqlTCxb4J4SO9oTHTXgvxUO.jpg'),
(110697, 7919, 'Longing for You [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xCdNv54f6uXcVB52qdoYXgglB7c.jpg'),
(110698, 7919, 'Longing for You [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sdrzd34kHQsK11TRbYhzCCWNbNU.jpg'),
(110699, 7919, 'Longing for You [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231904.mp4', 'http://image.tmdb.org/t/p/w1280/5bXg4QJmxArNgqt6FzITvMIDaiM.jpg'),
(110700, 7919, 'Longing for You [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231905.mp4', 'http://image.tmdb.org/t/p/w1280/p6LOkVmFEF65Bgt79wXeohz1N7c.jpg'),
(110701, 7919, 'Longing for You [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wPMm4UXcBKRBvIqzWESxhOSOrEt.jpg'),
(110702, 7919, 'Longing for You [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rRn0ikSxGY14nYvxJd5tfaQOK3p.jpg'),
(110703, 7919, 'Longing for You [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8P4XiEodFAuZvH9NvBwJlXbs7E.jpg'),
(110704, 7919, 'Longing for You [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v4AHp3sUgqOdNYZr5gqEd1pM6j2.jpg'),
(110705, 7919, 'Longing for You [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/231910.mp4', 'http://image.tmdb.org/t/p/w1280/8dgbUoSmARcFrIpmZ2LCgsX5g9r.jpg'),
(110706, 7919, 'Longing for You [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/231911.mp4', 'http://image.tmdb.org/t/p/w1280/8vwCRcW2gOKjI6fN3i4hUEiRkkF.jpg'),
(110707, 7919, 'Longing for You [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/231912.mp4', 'http://image.tmdb.org/t/p/w1280/3TsxjqbIKrGdvf01lYcPqLmodt8.jpg'),
(110708, 7919, 'Longing for You [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/231913.mp4', 'http://image.tmdb.org/t/p/w1280/7A5YbhJAGWocsZzjzyqK6LLDAMj.jpg'),
(110709, 7920, 'a Aranha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110710, 7920, 'a Aranha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110711, 7920, 'a Aranha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110712, 7920, 'a Aranha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110713, 7920, 'a Aranha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110714, 7920, 'a Aranha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110715, 7920, 'a Aranha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110716, 7920, 'a Aranha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110717, 7920, 'a Aranha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110718, 7920, 'a Aranha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110719, 7920, 'a Aranha S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110720, 7920, 'a Aranha S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110721, 7920, 'a Aranha S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110722, 7920, 'a Aranha S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/225845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110723, 7920, 'a Aranha S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/225846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110724, 7920, 'a Aranha S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/225847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110725, 7920, 'a Aranha S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/225848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110726, 7920, 'a Aranha S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/225849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110727, 7920, 'a Aranha S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/225850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110728, 7920, 'a Aranha S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/225851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110729, 7920, 'a Aranha S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/225852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110730, 7920, 'a Aranha S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/225853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110731, 7920, 'a Aranha S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/225854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110732, 7920, 'a Aranha S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/225855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110733, 7920, 'a Aranha S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/225856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110734, 7920, 'a Aranha S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/225857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYDJtKzQpjeNyaVyhRzS6WL4OU1.jpg'),
(110735, 7921, 'Monster but Wild [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/76CTkEUi5kc3UquozreWRCLYflv.jpg'),
(110736, 7921, 'Monster but Wild [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fYdCWy6awzFC4Mt7teVg010Ys9M.jpg'),
(110737, 7921, 'Monster but Wild [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Hdcgh3j2TMMq23bvn66XBducDI.jpg'),
(110738, 7921, 'Monster but Wild [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jG1TjYj60ktXha4IBNwG5nzkIP1.jpg'),
(110739, 7921, 'Monster but Wild [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oeZT0ERmgTMAwbW5xpzghqlIyzN.jpg'),
(110740, 7921, 'Monster but Wild [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jhTguIz2HCaLE0UMBO8tOVoEeDR.jpg'),
(110741, 7921, 'Monster but Wild [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tq7dY1Civ9LbFsuOb3JJAIl6MG4.jpg'),
(110742, 7921, 'Monster but Wild [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nHlu1f50zVY3P38Blc1zIByOmHC.jpg'),
(110743, 7921, 'Monster but Wild [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hGWgazxAl31scZQtFAYj6LAWyO.jpg'),
(110744, 7921, 'Monster but Wild [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sj5xyk9Tj8holGrw4TOcHL0LVM2.jpg'),
(110745, 7921, 'Monster but Wild [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hL91BPjwGfCsAPJz2Jq3oOS4rhV.jpg'),
(110746, 7921, 'Monster but Wild [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1N3uUZift33WJ3SEvJ1xim7CHaD.jpg'),
(110747, 7922, 'Monster but Wild [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7b468FaxXwaTD8jevK2BmxxZ7NT.jpg'),
(110748, 7922, 'Monster but Wild [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ITcXLBrg7Fhutem465hjaMKcVw.jpg'),
(110749, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225795.mp4', 'http://timg.bdta.pro/images/d285584a73f62aed1e37343727cc0386.jpg'),
(110750, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225796.mp4', 'http://timg.bdta.pro/images/24c9e8fb46230ff77c9f182b50dd0ad7.jpg'),
(110751, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225797.mp4', 'http://timg.bdta.pro/images/2816a36937e8ad6d8d9891ebc841de74.jpg'),
(110752, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225798.mp4', 'http://timg.bdta.pro/images/025ade189912ef02e60855f5ac83fca4.jpg'),
(110753, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNLFfBpSqjzO9JMthZ7ynCAPLsa.jpg'),
(110754, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225800.mp4', 'http://timg.bdta.pro/images/b630c327ca8f6c0c2029fa5e028439cd.jpg'),
(110755, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225801.mp4', 'http://timg.bdta.pro/images/4a8b3901bd402e7b66a05af5018a0bac.jpg'),
(110756, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A68qEBAuk5ubUWdt6zTqiT2NiAB.jpg'),
(110757, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225803.mp4', 'http://timg.bdta.pro/images/2be39bdfb2e67031298446a142ec2c65.jpg'),
(110758, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225804.mp4', 'http://timg.bdta.pro/images/4ec76b6b4d9ef2f7238f3977eba33d11.jpg'),
(110759, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7vmXt3meVy6zkQ3clj5ilgasS93.jpg'),
(110760, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m30WM42H36PsnmHTmX9bhJDeBRA.jpg'),
(110761, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ql4HhRdHbHhskgkz3LnghlVE9PT.jpg'),
(110762, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/225808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cx0Kk2gVD0ddq3PAdxPKs91C5qp.jpg'),
(110763, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/225809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g09JoU3CJLSvQWkcjdEKShdodMq.jpg'),
(110764, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/225810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8T9XwbUCSowWYPKpak3HCBoOc8i.jpg'),
(110765, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/225811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1lHIF2yab9NQPVUFHdjmjfClfTI.jpg'),
(110766, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/225812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k4UNFqOhrnlOaNc718ardTSM2Kz.jpg'),
(110767, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/225813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2bDtXehgL6TxDfbAB2lj88uggPo.jpg'),
(110768, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/225814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/69yWIHRVl8QPzxqYg7rB6zY8hMu.jpg'),
(110769, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/225815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5oDEM3hfvVMdkWuOshxe5YcGU7.jpg'),
(110770, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/225816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4EApeJZhmxtbzrbUv9LT906t1pT.jpg'),
(110771, 7923, 'Mushoku Tensei: Jobless Reincarnation S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/225817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Wen3Widg6xKNbZOqSME2Y5NBKr.jpg'),
(110772, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/360566.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110773, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/360567.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110774, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/360568.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110775, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/360569.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110776, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/360570.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110777, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/360571.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110778, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/360572.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110779, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/360573.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110780, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/360574.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110781, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/360575.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110782, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/360576.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110783, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/360577.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110784, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/360578.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110785, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/360579.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110786, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/360580.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110787, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/360581.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110788, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/360582.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110789, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/360583.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110790, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/367996.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110791, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/387371.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110792, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/411918.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110793, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/411919.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110794, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/411920.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110795, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/411921.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110796, 7924, 'Mushoku Tensei: Jobless Reincarnation S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/415662.mp4', 'http://gstaticontent.com/images/8e58eedcf8dc76194e3069a1b622699c.jpg'),
(110797, 7925, 'NieR:Automata Ver1.1a [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pa25WRD3GxD7p5EeRCuAZ99N3RB.jpg'),
(110798, 7925, 'NieR:Automata Ver1.1a [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o6q6Z1D9PWrabPfQKTTttpooEku.jpg'),
(110799, 7925, 'NieR:Automata Ver1.1a [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBAH1JFQf9eMxDcr81AAk8slCdr.jpg'),
(110800, 7925, 'NieR:Automata Ver1.1a [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/22Cx4MHykJ88Utkv3VK7RxCWa4h.jpg'),
(110801, 7925, 'NieR:Automata Ver1.1a [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8FpJSPliOdMF9rIiD8Z2Gp099lS.jpg'),
(110802, 7925, 'NieR:Automata Ver1.1a [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fF4y2Hix8ahU816JO7nU7TASnww.jpg'),
(110803, 7925, 'NieR:Automata Ver1.1a [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zHa4FL9ibB24RPvf4LlCsghnOXB.jpg'),
(110804, 7925, 'NieR:Automata Ver1.1a [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4HerYWjHGpDCnku5XplrcUSe9QE.jpg'),
(110805, 7925, 'NieR:Automata Ver1.1a [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/buMa6cKACsV3oDnc2s7qiflDi0b.jpg'),
(110806, 7925, 'NieR:Automata Ver1.1a [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bQXlf9i34JaWLeDoTSl0JalXBdk.jpg'),
(110807, 7925, 'NieR:Automata Ver1.1a [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ieM9qsXi9d998laCseovT9NiT4D.jpg'),
(110808, 7925, 'NieR:Automata Ver1.1a [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jK5k5qPICWLKHkl9DiDxsGyog1p.jpg'),
(110809, 7925, 'NieR:Automata Ver1.1a [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/432091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qHSCYOXHV3EKXKkMxUvC9rGx4Av.jpg'),
(110810, 7925, 'NieR:Automata Ver1.1a [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/408513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qHSCYOXHV3EKXKkMxUvC9rGx4Av.jpg'),
(110811, 7925, 'NieR:Automata Ver1.1a [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/415614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qHSCYOXHV3EKXKkMxUvC9rGx4Av.jpg'),
(110812, 7925, 'NieR:Automata Ver1.1a [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/419463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qHSCYOXHV3EKXKkMxUvC9rGx4Av.jpg'),
(110813, 7925, 'NieR:Automata Ver1.1a [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/424577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qHSCYOXHV3EKXKkMxUvC9rGx4Av.jpg'),
(110814, 7925, 'NieR:Automata Ver1.1a [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/427094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qHSCYOXHV3EKXKkMxUvC9rGx4Av.jpg'),
(110815, 7925, 'NieR:Automata Ver1.1a [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/436089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qHSCYOXHV3EKXKkMxUvC9rGx4Av.jpg'),
(110816, 7925, 'NieR:Automata Ver1.1a [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/441859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qHSCYOXHV3EKXKkMxUvC9rGx4Av.jpg'),
(110817, 7925, 'NieR:Automata Ver1.1a [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/447290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qHSCYOXHV3EKXKkMxUvC9rGx4Av.jpg'),
(110818, 7925, 'NieR:Automata Ver1.1a [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/456063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qHSCYOXHV3EKXKkMxUvC9rGx4Av.jpg'),
(110819, 7925, 'NieR:Automata Ver1.1a [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/460816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qHSCYOXHV3EKXKkMxUvC9rGx4Av.jpg'),
(110820, 7925, 'NieR:Automata Ver1.1a [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/467277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qHSCYOXHV3EKXKkMxUvC9rGx4Av.jpg'),
(110821, 7926, 'Nilba e os Desastronautas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110822, 7926, 'Nilba e os Desastronautas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110823, 7926, 'Nilba e os Desastronautas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110824, 7926, 'Nilba e os Desastronautas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110825, 7926, 'Nilba e os Desastronautas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110826, 7926, 'Nilba e os Desastronautas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110827, 7926, 'Nilba e os Desastronautas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110828, 7926, 'Nilba e os Desastronautas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110829, 7926, 'Nilba e os Desastronautas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110830, 7926, 'Nilba e os Desastronautas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110831, 7926, 'Nilba e os Desastronautas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110832, 7926, 'Nilba e os Desastronautas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110833, 7926, 'Nilba e os Desastronautas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110834, 7926, 'Nilba e os Desastronautas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/225757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110835, 7926, 'Nilba e os Desastronautas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/225758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110836, 7926, 'Nilba e os Desastronautas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/225759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110837, 7926, 'Nilba e os Desastronautas S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/225760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110838, 7926, 'Nilba e os Desastronautas S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/225761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110839, 7926, 'Nilba e os Desastronautas S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/225762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110840, 7926, 'Nilba e os Desastronautas S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/225763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110841, 7926, 'Nilba e os Desastronautas S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/225764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110842, 7926, 'Nilba e os Desastronautas S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/225765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110843, 7926, 'Nilba e os Desastronautas S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/225766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110844, 7926, 'Nilba e os Desastronautas S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/225767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110845, 7926, 'Nilba e os Desastronautas S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/225768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110846, 7926, 'Nilba e os Desastronautas S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/225769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110847, 7926, 'Nilba e os Desastronautas S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/225770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110848, 7926, 'Nilba e os Desastronautas S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/225771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110849, 7926, 'Nilba e os Desastronautas S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/225772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110850, 7926, 'Nilba e os Desastronautas S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/225773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110851, 7926, 'Nilba e os Desastronautas S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/225774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110852, 7926, 'Nilba e os Desastronautas S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/225775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110853, 7926, 'Nilba e os Desastronautas S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/225776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110854, 7926, 'Nilba e os Desastronautas S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/225777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110855, 7926, 'Nilba e os Desastronautas S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/225778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110856, 7926, 'Nilba e os Desastronautas S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/225779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110857, 7926, 'Nilba e os Desastronautas S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/225780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110858, 7926, 'Nilba e os Desastronautas S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/225781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110859, 7926, 'Nilba e os Desastronautas S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/225782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lu66hhUxE19uaoFw0BzwuOTjl7.jpg'),
(110860, 7927, 'O Show de Tom e Jerry S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k28ZbjpR0zcsZO1RzXRewQeEoN4.jpg'),
(110861, 7927, 'O Show de Tom e Jerry S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8LshjOprRlRwZckhWU0HqwJ5qgf.jpg'),
(110862, 7927, 'O Show de Tom e Jerry S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xmwfVOeTowjQLxkjg7QsS24ELu8.jpg'),
(110863, 7927, 'O Show de Tom e Jerry S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Dntp5efU8vh5a4dJEYCahIujOF.jpg'),
(110864, 7927, 'O Show de Tom e Jerry S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/49btfOLLU2rufuZLddHhVeZne9z.jpg'),
(110865, 7927, 'O Show de Tom e Jerry S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svnV5YUcm9WPsovP2nYBjblr87G.jpg'),
(110866, 7927, 'O Show de Tom e Jerry S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dPtyQMzndobJIbwjPor2XDD1Zh2.jpg'),
(110867, 7927, 'O Show de Tom e Jerry S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/71tapEcdbGyzY54eUyEW7RMs0SG.jpg'),
(110868, 7927, 'O Show de Tom e Jerry S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4qHi6OUPKOdXrPbIgqzRBPjbIlb.jpg'),
(110869, 7927, 'O Show de Tom e Jerry S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7AzxPvCFOXuwm4I2cAJIDStM8JA.jpg'),
(110870, 7927, 'O Show de Tom e Jerry S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nCQAKpfZGUEexSFtDAibK9hYuyp.jpg'),
(110871, 7927, 'O Show de Tom e Jerry S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iViWRwVH3RWPXWNEy8Wom3GpY1q.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(110872, 7927, 'O Show de Tom e Jerry S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eyaVaaYTfF3cKQ5UgIO4i6F9miA.jpg'),
(110873, 7927, 'O Show de Tom e Jerry S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/225433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jNXFecAOnyU8DRqaH7wIFx5903Z.jpg'),
(110874, 7927, 'O Show de Tom e Jerry S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/225434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/raUblFsPhCHpAGZ1YnrbAsbb5Fv.jpg'),
(110875, 7927, 'O Show de Tom e Jerry S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/225435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fLlL2CrMtClmQXMi0oCRydSMdI5.jpg'),
(110876, 7927, 'O Show de Tom e Jerry S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/225436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qtsOafYtGHAXyKduweSWLgy1yk5.jpg'),
(110877, 7927, 'O Show de Tom e Jerry S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/225437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aiqb1SMNHJLxChKT4ajIrtsktw3.jpg'),
(110878, 7927, 'O Show de Tom e Jerry S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/225438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tYUqWzMtiUgKjgKn3moUoQj1cTL.jpg'),
(110879, 7927, 'O Show de Tom e Jerry S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/225439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qS09QZHU4qL5rhRLvrlClWLZCtX.jpg'),
(110880, 7927, 'O Show de Tom e Jerry S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/225440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fviSnJLpKyFygoSd0JSUGIe6u8Y.jpg'),
(110881, 7927, 'O Show de Tom e Jerry S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/225441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nqy9SE4WEpy5CAJOE2sUCnnKRjh.jpg'),
(110882, 7927, 'O Show de Tom e Jerry S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/225442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/90VNj1gNwUhOx1eVAEiMFpv4eXJ.jpg'),
(110883, 7927, 'O Show de Tom e Jerry S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/225443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kojBAT6ifhAYPomSWyNacxUGipK.jpg'),
(110884, 7927, 'O Show de Tom e Jerry S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/225444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wNPQYVowfWhkwsNyDT2Pahx4H2C.jpg'),
(110885, 7927, 'O Show de Tom e Jerry S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/225445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDypMUwIzMqWj0K6sNt90HeZn3c.jpg'),
(110886, 7927, 'O Show de Tom e Jerry S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/225446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bFaJzliVjflzjewdJm4ku2fPHjw.jpg'),
(110887, 7927, 'O Show de Tom e Jerry S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/225447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yH8nD2OOpmBjWm9QIZ1IYfcOeRC.jpg'),
(110888, 7927, 'O Show de Tom e Jerry S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/225448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPEoaaeJcNwNyfazl5gPiLsuBPq.jpg'),
(110889, 7927, 'O Show de Tom e Jerry S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/225449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xeA98idAqPfSCxir1N0msjpOeDL.jpg'),
(110890, 7927, 'O Show de Tom e Jerry S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/225450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Rh477enVtVQiyiyob0EvMecJN2.jpg'),
(110891, 7927, 'O Show de Tom e Jerry S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/225451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A9djLnAHomdUcaUAZLRLcIoE2Fk.jpg'),
(110892, 7927, 'O Show de Tom e Jerry S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/225452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cZcAWZViQglSwaOBDn7kA7QMh48.jpg'),
(110893, 7927, 'O Show de Tom e Jerry S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/225453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uisPcrZqI8GsvEUB0O480YxjPik.jpg'),
(110894, 7927, 'O Show de Tom e Jerry S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/225454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yjA8NLX0UESNYkCprs4eCP5yJR7.jpg'),
(110895, 7927, 'O Show de Tom e Jerry S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/225455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v1yzyyx1GlNwdCCay6FHRcK18rp.jpg'),
(110896, 7927, 'O Show de Tom e Jerry S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/225456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1gLmfTF9WEFhe6gopHm7YqRegpA.jpg'),
(110897, 7927, 'O Show de Tom e Jerry S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/225457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ojRxCby1m5FAmr8X0C6C0YcHBV7.jpg'),
(110898, 7927, 'O Show de Tom e Jerry S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/225458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AetJBRk2dUZ5H9wJiYZVcPZgOOT.jpg'),
(110899, 7927, 'O Show de Tom e Jerry S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/225459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Tuc3RcOddjifE1SLZ5dGgQGxAP.jpg'),
(110900, 7927, 'O Show de Tom e Jerry S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/225460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pAA7re6RzmdMb3Nj1oY9fxs2rSH.jpg'),
(110901, 7927, 'O Show de Tom e Jerry S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/225461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rH92Qastkg2dfCHKWSlNE5wSfUr.jpg'),
(110902, 7927, 'O Show de Tom e Jerry S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/225462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h0N3ay6joIbzQZxhO1dFm8uMaqi.jpg'),
(110903, 7927, 'O Show de Tom e Jerry S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/225463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q4p0CEsx8GQzI1MPWnezusPdWxX.jpg'),
(110904, 7927, 'O Show de Tom e Jerry S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/225464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZjwPSVvBn40UiBQ1G95Zx8DRS9.jpg'),
(110905, 7927, 'O Show de Tom e Jerry S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/225465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/plPU05eiArtSuybqS0KYvTdtF4B.jpg'),
(110906, 7927, 'O Show de Tom e Jerry S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/225466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m6sir8YVeSpiuKmMvOasXjp5Eb8.jpg'),
(110907, 7927, 'O Show de Tom e Jerry S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/225467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tNwodsWlgvcfUNAXauwz1jJocJv.jpg'),
(110908, 7927, 'O Show de Tom e Jerry S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/225468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJfTk1rPdLBmopI4hV1yuntnR1I.jpg'),
(110909, 7927, 'O Show de Tom e Jerry S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/225469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nCGDxyo8GqApP3aX7m4X6FG4NpF.jpg'),
(110910, 7927, 'O Show de Tom e Jerry S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/225470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lOPB2oevlsp5XaH6bPkPhIh3r6p.jpg'),
(110911, 7928, 'O Show de Tom e Jerry S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110912, 7928, 'O Show de Tom e Jerry S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110913, 7928, 'O Show de Tom e Jerry S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110914, 7928, 'O Show de Tom e Jerry S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110915, 7928, 'O Show de Tom e Jerry S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110916, 7928, 'O Show de Tom e Jerry S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110917, 7928, 'O Show de Tom e Jerry S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110918, 7928, 'O Show de Tom e Jerry S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110919, 7928, 'O Show de Tom e Jerry S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110920, 7928, 'O Show de Tom e Jerry S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110921, 7928, 'O Show de Tom e Jerry S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110922, 7928, 'O Show de Tom e Jerry S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110923, 7928, 'O Show de Tom e Jerry S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110924, 7928, 'O Show de Tom e Jerry S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/225484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110925, 7928, 'O Show de Tom e Jerry S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/225485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110926, 7928, 'O Show de Tom e Jerry S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/225486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110927, 7928, 'O Show de Tom e Jerry S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/225487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110928, 7928, 'O Show de Tom e Jerry S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/225488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110929, 7928, 'O Show de Tom e Jerry S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/225489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110930, 7928, 'O Show de Tom e Jerry S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/225490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110931, 7928, 'O Show de Tom e Jerry S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/225491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110932, 7928, 'O Show de Tom e Jerry S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/225492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110933, 7928, 'O Show de Tom e Jerry S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/225493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110934, 7928, 'O Show de Tom e Jerry S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/225494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110935, 7928, 'O Show de Tom e Jerry S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/225495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110936, 7928, 'O Show de Tom e Jerry S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/225496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110937, 7928, 'O Show de Tom e Jerry S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/225497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110938, 7928, 'O Show de Tom e Jerry S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/225498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110939, 7928, 'O Show de Tom e Jerry S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/225499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110940, 7928, 'O Show de Tom e Jerry S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/225500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110941, 7928, 'O Show de Tom e Jerry S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/225501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110942, 7928, 'O Show de Tom e Jerry S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/225502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110943, 7928, 'O Show de Tom e Jerry S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/225503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110944, 7928, 'O Show de Tom e Jerry S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/225504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110945, 7928, 'O Show de Tom e Jerry S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/225505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110946, 7928, 'O Show de Tom e Jerry S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/225506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110947, 7928, 'O Show de Tom e Jerry S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/225507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110948, 7928, 'O Show de Tom e Jerry S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/225508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110949, 7928, 'O Show de Tom e Jerry S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/225509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110950, 7928, 'O Show de Tom e Jerry S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/225510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110951, 7928, 'O Show de Tom e Jerry S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/225511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110952, 7928, 'O Show de Tom e Jerry S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/225512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110953, 7928, 'O Show de Tom e Jerry S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/225513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110954, 7928, 'O Show de Tom e Jerry S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/225514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110955, 7928, 'O Show de Tom e Jerry S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/225515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110956, 7928, 'O Show de Tom e Jerry S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/225516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110957, 7928, 'O Show de Tom e Jerry S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/225517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110958, 7928, 'O Show de Tom e Jerry S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/225518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110959, 7928, 'O Show de Tom e Jerry S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/225519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110960, 7928, 'O Show de Tom e Jerry S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/225520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110961, 7928, 'O Show de Tom e Jerry S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/225521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110962, 7928, 'O Show de Tom e Jerry S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/225522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110963, 7928, 'O Show de Tom e Jerry S02 E53', 'http://sinalprivado.info:80/series/1533784/1533784/225523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110964, 7928, 'O Show de Tom e Jerry S02 E54', 'http://sinalprivado.info:80/series/1533784/1533784/225524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110965, 7928, 'O Show de Tom e Jerry S02 E55', 'http://sinalprivado.info:80/series/1533784/1533784/225525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110966, 7928, 'O Show de Tom e Jerry S02 E56', 'http://sinalprivado.info:80/series/1533784/1533784/225526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110967, 7928, 'O Show de Tom e Jerry S02 E57', 'http://sinalprivado.info:80/series/1533784/1533784/225527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110968, 7928, 'O Show de Tom e Jerry S02 E58', 'http://sinalprivado.info:80/series/1533784/1533784/225528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110969, 7928, 'O Show de Tom e Jerry S02 E59', 'http://sinalprivado.info:80/series/1533784/1533784/225529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110970, 7928, 'O Show de Tom e Jerry S02 E60', 'http://sinalprivado.info:80/series/1533784/1533784/225530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110971, 7928, 'O Show de Tom e Jerry S02 E61', 'http://sinalprivado.info:80/series/1533784/1533784/225531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110972, 7928, 'O Show de Tom e Jerry S02 E62', 'http://sinalprivado.info:80/series/1533784/1533784/225532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110973, 7928, 'O Show de Tom e Jerry S02 E63', 'http://sinalprivado.info:80/series/1533784/1533784/225533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110974, 7928, 'O Show de Tom e Jerry S02 E64', 'http://sinalprivado.info:80/series/1533784/1533784/225534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110975, 7928, 'O Show de Tom e Jerry S02 E65', 'http://sinalprivado.info:80/series/1533784/1533784/225535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110976, 7928, 'O Show de Tom e Jerry S02 E66', 'http://sinalprivado.info:80/series/1533784/1533784/225536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110977, 7928, 'O Show de Tom e Jerry S02 E67', 'http://sinalprivado.info:80/series/1533784/1533784/225537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110978, 7928, 'O Show de Tom e Jerry S02 E68', 'http://sinalprivado.info:80/series/1533784/1533784/225538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110979, 7928, 'O Show de Tom e Jerry S02 E69', 'http://sinalprivado.info:80/series/1533784/1533784/225539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110980, 7928, 'O Show de Tom e Jerry S02 E70', 'http://sinalprivado.info:80/series/1533784/1533784/225540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110981, 7928, 'O Show de Tom e Jerry S02 E71', 'http://sinalprivado.info:80/series/1533784/1533784/225541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110982, 7928, 'O Show de Tom e Jerry S02 E72', 'http://sinalprivado.info:80/series/1533784/1533784/225542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110983, 7928, 'O Show de Tom e Jerry S02 E73', 'http://sinalprivado.info:80/series/1533784/1533784/225543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110984, 7928, 'O Show de Tom e Jerry S02 E74', 'http://sinalprivado.info:80/series/1533784/1533784/225544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110985, 7928, 'O Show de Tom e Jerry S02 E75', 'http://sinalprivado.info:80/series/1533784/1533784/225545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110986, 7928, 'O Show de Tom e Jerry S02 E76', 'http://sinalprivado.info:80/series/1533784/1533784/225546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110987, 7928, 'O Show de Tom e Jerry S02 E77', 'http://sinalprivado.info:80/series/1533784/1533784/225547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110988, 7928, 'O Show de Tom e Jerry S02 E78', 'http://sinalprivado.info:80/series/1533784/1533784/225548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110989, 7929, 'O Show de Tom e Jerry S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dOY3Xyz8rY2wxZbkoFEOv5vW9B0.jpg'),
(110990, 7929, 'O Show de Tom e Jerry S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110991, 7929, 'O Show de Tom e Jerry S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110992, 7929, 'O Show de Tom e Jerry S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110993, 7929, 'O Show de Tom e Jerry S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110994, 7929, 'O Show de Tom e Jerry S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110995, 7929, 'O Show de Tom e Jerry S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110996, 7929, 'O Show de Tom e Jerry S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110997, 7929, 'O Show de Tom e Jerry S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110998, 7929, 'O Show de Tom e Jerry S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(110999, 7929, 'O Show de Tom e Jerry S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111000, 7929, 'O Show de Tom e Jerry S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111001, 7929, 'O Show de Tom e Jerry S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111002, 7929, 'O Show de Tom e Jerry S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/225562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111003, 7929, 'O Show de Tom e Jerry S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/225563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111004, 7929, 'O Show de Tom e Jerry S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/225564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111005, 7929, 'O Show de Tom e Jerry S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/225565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111006, 7929, 'O Show de Tom e Jerry S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/225566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111007, 7929, 'O Show de Tom e Jerry S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/225567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111008, 7929, 'O Show de Tom e Jerry S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/225568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111009, 7929, 'O Show de Tom e Jerry S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/225569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111010, 7929, 'O Show de Tom e Jerry S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/225570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111011, 7929, 'O Show de Tom e Jerry S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/225571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111012, 7929, 'O Show de Tom e Jerry S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/225572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111013, 7929, 'O Show de Tom e Jerry S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/225573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111014, 7929, 'O Show de Tom e Jerry S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/225574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111015, 7929, 'O Show de Tom e Jerry S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/225575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111016, 7929, 'O Show de Tom e Jerry S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/225576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111017, 7929, 'O Show de Tom e Jerry S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/225577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111018, 7929, 'O Show de Tom e Jerry S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/225578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111019, 7929, 'O Show de Tom e Jerry S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/225579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111020, 7929, 'O Show de Tom e Jerry S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/225580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111021, 7929, 'O Show de Tom e Jerry S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/225581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111022, 7929, 'O Show de Tom e Jerry S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/225582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111023, 7929, 'O Show de Tom e Jerry S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/225583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111024, 7929, 'O Show de Tom e Jerry S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/225584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111025, 7929, 'O Show de Tom e Jerry S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/225585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111026, 7929, 'O Show de Tom e Jerry S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/225586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111027, 7929, 'O Show de Tom e Jerry S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/225587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111028, 7929, 'O Show de Tom e Jerry S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/225588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111029, 7929, 'O Show de Tom e Jerry S03 E41', 'http://sinalprivado.info:80/series/1533784/1533784/225589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111030, 7929, 'O Show de Tom e Jerry S03 E42', 'http://sinalprivado.info:80/series/1533784/1533784/225590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111031, 7929, 'O Show de Tom e Jerry S03 E43', 'http://sinalprivado.info:80/series/1533784/1533784/225591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111032, 7929, 'O Show de Tom e Jerry S03 E44', 'http://sinalprivado.info:80/series/1533784/1533784/225592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111033, 7929, 'O Show de Tom e Jerry S03 E45', 'http://sinalprivado.info:80/series/1533784/1533784/225593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111034, 7929, 'O Show de Tom e Jerry S03 E46', 'http://sinalprivado.info:80/series/1533784/1533784/225594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111035, 7929, 'O Show de Tom e Jerry S03 E47', 'http://sinalprivado.info:80/series/1533784/1533784/225595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111036, 7929, 'O Show de Tom e Jerry S03 E48', 'http://sinalprivado.info:80/series/1533784/1533784/225596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111037, 7929, 'O Show de Tom e Jerry S03 E49', 'http://sinalprivado.info:80/series/1533784/1533784/225597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111038, 7929, 'O Show de Tom e Jerry S03 E50', 'http://sinalprivado.info:80/series/1533784/1533784/225598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111039, 7929, 'O Show de Tom e Jerry S03 E51', 'http://sinalprivado.info:80/series/1533784/1533784/225599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111040, 7929, 'O Show de Tom e Jerry S03 E52', 'http://sinalprivado.info:80/series/1533784/1533784/225600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111041, 7929, 'O Show de Tom e Jerry S03 E53', 'http://sinalprivado.info:80/series/1533784/1533784/225601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111042, 7929, 'O Show de Tom e Jerry S03 E54', 'http://sinalprivado.info:80/series/1533784/1533784/225602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111043, 7929, 'O Show de Tom e Jerry S03 E55', 'http://sinalprivado.info:80/series/1533784/1533784/225603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111044, 7929, 'O Show de Tom e Jerry S03 E56', 'http://sinalprivado.info:80/series/1533784/1533784/225604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111045, 7929, 'O Show de Tom e Jerry S03 E57', 'http://sinalprivado.info:80/series/1533784/1533784/225605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111046, 7929, 'O Show de Tom e Jerry S03 E58', 'http://sinalprivado.info:80/series/1533784/1533784/225606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111047, 7929, 'O Show de Tom e Jerry S03 E59', 'http://sinalprivado.info:80/series/1533784/1533784/225607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111048, 7929, 'O Show de Tom e Jerry S03 E60', 'http://sinalprivado.info:80/series/1533784/1533784/225608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111049, 7929, 'O Show de Tom e Jerry S03 E61', 'http://sinalprivado.info:80/series/1533784/1533784/225609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111050, 7929, 'O Show de Tom e Jerry S03 E62', 'http://sinalprivado.info:80/series/1533784/1533784/225610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111051, 7929, 'O Show de Tom e Jerry S03 E63', 'http://sinalprivado.info:80/series/1533784/1533784/225611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111052, 7929, 'O Show de Tom e Jerry S03 E64', 'http://sinalprivado.info:80/series/1533784/1533784/225612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111053, 7929, 'O Show de Tom e Jerry S03 E65', 'http://sinalprivado.info:80/series/1533784/1533784/225613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111054, 7929, 'O Show de Tom e Jerry S03 E66', 'http://sinalprivado.info:80/series/1533784/1533784/225614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111055, 7929, 'O Show de Tom e Jerry S03 E67', 'http://sinalprivado.info:80/series/1533784/1533784/225615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111056, 7929, 'O Show de Tom e Jerry S03 E68', 'http://sinalprivado.info:80/series/1533784/1533784/225616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111057, 7929, 'O Show de Tom e Jerry S03 E69', 'http://sinalprivado.info:80/series/1533784/1533784/225617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111058, 7929, 'O Show de Tom e Jerry S03 E70', 'http://sinalprivado.info:80/series/1533784/1533784/225618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111059, 7929, 'O Show de Tom e Jerry S03 E71', 'http://sinalprivado.info:80/series/1533784/1533784/225619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111060, 7929, 'O Show de Tom e Jerry S03 E72', 'http://sinalprivado.info:80/series/1533784/1533784/225620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111061, 7929, 'O Show de Tom e Jerry S03 E73', 'http://sinalprivado.info:80/series/1533784/1533784/225621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111062, 7929, 'O Show de Tom e Jerry S03 E74', 'http://sinalprivado.info:80/series/1533784/1533784/225622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111063, 7929, 'O Show de Tom e Jerry S03 E75', 'http://sinalprivado.info:80/series/1533784/1533784/225623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111064, 7929, 'O Show de Tom e Jerry S03 E76', 'http://sinalprivado.info:80/series/1533784/1533784/225624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111065, 7929, 'O Show de Tom e Jerry S03 E77', 'http://sinalprivado.info:80/series/1533784/1533784/225625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111066, 7929, 'O Show de Tom e Jerry S03 E78', 'http://sinalprivado.info:80/series/1533784/1533784/225626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111067, 7930, 'O Show de Tom e Jerry S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6j5SeK8gVstVvqCx0qTEZ3w0NV7.jpg'),
(111068, 7930, 'O Show de Tom e Jerry S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBhqIgkLUEaYEzUyhB6BgFTLD1x.jpg'),
(111069, 7930, 'O Show de Tom e Jerry S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o32MM4ibVtp3qLNldtDUd7Yyro8.jpg'),
(111070, 7930, 'O Show de Tom e Jerry S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aqH7N26dtMluOMiYQ6AnKW8p3Qa.jpg'),
(111071, 7930, 'O Show de Tom e Jerry S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gzauYyUY9VqoUtpGWAa1uxtKwsx.jpg'),
(111072, 7930, 'O Show de Tom e Jerry S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/750i4OZlI7bzDFukvOMnfXobm3d.jpg'),
(111073, 7930, 'O Show de Tom e Jerry S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/anOy5BINd6dKycJne9wjkXHN1r0.jpg'),
(111074, 7930, 'O Show de Tom e Jerry S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bXljKCao4BdixUkP8Y3dzLFLk3K.jpg'),
(111075, 7930, 'O Show de Tom e Jerry S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/snHIbpEN4Nfw0JLimprQZKi0b0w.jpg'),
(111076, 7930, 'O Show de Tom e Jerry S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ClXIYlDKi4N7oeQJynDaAxHoa6.jpg'),
(111077, 7930, 'O Show de Tom e Jerry S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n49XFIrGyey8EHCmh693Pkx9N5z.jpg'),
(111078, 7930, 'O Show de Tom e Jerry S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5EhATTXrsPi8Cgra7NJt5V0RNVc.jpg'),
(111079, 7930, 'O Show de Tom e Jerry S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gr3xASGrxRUB01OEjVtPYoJpJKz.jpg'),
(111080, 7930, 'O Show de Tom e Jerry S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/225640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2JRcayfDmENMJoUgJNS9erCXWtJ.jpg'),
(111081, 7930, 'O Show de Tom e Jerry S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/225641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kN2oWZcWhiQrb6HZpAHSh0DP8HW.jpg'),
(111082, 7930, 'O Show de Tom e Jerry S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/225642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nf4sik4ONidqUWubfCrEjVShUAK.jpg'),
(111083, 7930, 'O Show de Tom e Jerry S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/225643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/18wiNRWcBigb3FwvbwG0qshBnz4.jpg'),
(111084, 7930, 'O Show de Tom e Jerry S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/225644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/logoXAYUS1wy8cQX3sVQRhXfEom.jpg'),
(111085, 7930, 'O Show de Tom e Jerry S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/225645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zVAIYCfdw17uTbELej6tykDUpMx.jpg'),
(111086, 7930, 'O Show de Tom e Jerry S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/225646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gwYKnkmD4O9w937o008zjtSJHsd.jpg'),
(111087, 7930, 'O Show de Tom e Jerry S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/225647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sdBOo5Y4kQT06IyE9ehxCExSvl.jpg'),
(111088, 7930, 'O Show de Tom e Jerry S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/225648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wsfFfZoXfPhXBJ3lJs8vgeR0EeP.jpg'),
(111089, 7930, 'O Show de Tom e Jerry S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/225649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i5vkAs188PDYOSzZ7IplHbRYhMt.jpg'),
(111090, 7930, 'O Show de Tom e Jerry S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/225650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bU40AMLGnjSCPvocJShhdtadA0L.jpg'),
(111091, 7930, 'O Show de Tom e Jerry S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/225651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hkbq0seEWP8AgAFPxKOyPsz5NSY.jpg'),
(111092, 7930, 'O Show de Tom e Jerry S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/225652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nhmaOPiF0RPpHXdRZIqD8ClZebc.jpg'),
(111093, 7930, 'O Show de Tom e Jerry S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/225653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111094, 7930, 'O Show de Tom e Jerry S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/225654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111095, 7930, 'O Show de Tom e Jerry S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/225655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111096, 7930, 'O Show de Tom e Jerry S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/225656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111097, 7930, 'O Show de Tom e Jerry S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/225657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111098, 7930, 'O Show de Tom e Jerry S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/225658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111099, 7930, 'O Show de Tom e Jerry S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/225659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111100, 7930, 'O Show de Tom e Jerry S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/225660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111101, 7930, 'O Show de Tom e Jerry S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/225661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111102, 7930, 'O Show de Tom e Jerry S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/225662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111103, 7930, 'O Show de Tom e Jerry S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/225663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111104, 7930, 'O Show de Tom e Jerry S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/225664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111105, 7930, 'O Show de Tom e Jerry S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/225665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111106, 7930, 'O Show de Tom e Jerry S04 E40', 'http://sinalprivado.info:80/series/1533784/1533784/225666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111107, 7930, 'O Show de Tom e Jerry S04 E41', 'http://sinalprivado.info:80/series/1533784/1533784/225667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111108, 7930, 'O Show de Tom e Jerry S04 E42', 'http://sinalprivado.info:80/series/1533784/1533784/225668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111109, 7930, 'O Show de Tom e Jerry S04 E43', 'http://sinalprivado.info:80/series/1533784/1533784/225669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111110, 7930, 'O Show de Tom e Jerry S04 E44', 'http://sinalprivado.info:80/series/1533784/1533784/225670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111111, 7930, 'O Show de Tom e Jerry S04 E45', 'http://sinalprivado.info:80/series/1533784/1533784/225671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111112, 7930, 'O Show de Tom e Jerry S04 E46', 'http://sinalprivado.info:80/series/1533784/1533784/225672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111113, 7930, 'O Show de Tom e Jerry S04 E47', 'http://sinalprivado.info:80/series/1533784/1533784/225673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111114, 7930, 'O Show de Tom e Jerry S04 E48', 'http://sinalprivado.info:80/series/1533784/1533784/225674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111115, 7930, 'O Show de Tom e Jerry S04 E49', 'http://sinalprivado.info:80/series/1533784/1533784/225675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111116, 7930, 'O Show de Tom e Jerry S04 E50', 'http://sinalprivado.info:80/series/1533784/1533784/225676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111117, 7930, 'O Show de Tom e Jerry S04 E51', 'http://sinalprivado.info:80/series/1533784/1533784/225677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111118, 7930, 'O Show de Tom e Jerry S04 E52', 'http://sinalprivado.info:80/series/1533784/1533784/225678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111119, 7930, 'O Show de Tom e Jerry S04 E53', 'http://sinalprivado.info:80/series/1533784/1533784/225679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111120, 7930, 'O Show de Tom e Jerry S04 E54', 'http://sinalprivado.info:80/series/1533784/1533784/225680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111121, 7930, 'O Show de Tom e Jerry S04 E55', 'http://sinalprivado.info:80/series/1533784/1533784/225681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111122, 7930, 'O Show de Tom e Jerry S04 E56', 'http://sinalprivado.info:80/series/1533784/1533784/225682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111123, 7930, 'O Show de Tom e Jerry S04 E57', 'http://sinalprivado.info:80/series/1533784/1533784/225683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111124, 7930, 'O Show de Tom e Jerry S04 E58', 'http://sinalprivado.info:80/series/1533784/1533784/225684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111125, 7930, 'O Show de Tom e Jerry S04 E59', 'http://sinalprivado.info:80/series/1533784/1533784/225685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111126, 7930, 'O Show de Tom e Jerry S04 E60', 'http://sinalprivado.info:80/series/1533784/1533784/225686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(111127, 7930, 'O Show de Tom e Jerry S04 E61', 'http://sinalprivado.info:80/series/1533784/1533784/225687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111128, 7930, 'O Show de Tom e Jerry S04 E62', 'http://sinalprivado.info:80/series/1533784/1533784/225688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111129, 7930, 'O Show de Tom e Jerry S04 E63', 'http://sinalprivado.info:80/series/1533784/1533784/225689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111130, 7930, 'O Show de Tom e Jerry S04 E64', 'http://sinalprivado.info:80/series/1533784/1533784/225690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111131, 7930, 'O Show de Tom e Jerry S04 E65', 'http://sinalprivado.info:80/series/1533784/1533784/225691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111132, 7930, 'O Show de Tom e Jerry S04 E66', 'http://sinalprivado.info:80/series/1533784/1533784/225692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111133, 7930, 'O Show de Tom e Jerry S04 E67', 'http://sinalprivado.info:80/series/1533784/1533784/225693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111134, 7930, 'O Show de Tom e Jerry S04 E68', 'http://sinalprivado.info:80/series/1533784/1533784/225694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111135, 7930, 'O Show de Tom e Jerry S04 E69', 'http://sinalprivado.info:80/series/1533784/1533784/225695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111136, 7930, 'O Show de Tom e Jerry S04 E70', 'http://sinalprivado.info:80/series/1533784/1533784/225696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111137, 7930, 'O Show de Tom e Jerry S04 E71', 'http://sinalprivado.info:80/series/1533784/1533784/225697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111138, 7930, 'O Show de Tom e Jerry S04 E72', 'http://sinalprivado.info:80/series/1533784/1533784/225698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111139, 7930, 'O Show de Tom e Jerry S04 E73', 'http://sinalprivado.info:80/series/1533784/1533784/225699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111140, 7930, 'O Show de Tom e Jerry S04 E74', 'http://sinalprivado.info:80/series/1533784/1533784/225700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111141, 7930, 'O Show de Tom e Jerry S04 E75', 'http://sinalprivado.info:80/series/1533784/1533784/225701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111142, 7930, 'O Show de Tom e Jerry S04 E76', 'http://sinalprivado.info:80/series/1533784/1533784/225702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111143, 7930, 'O Show de Tom e Jerry S04 E77', 'http://sinalprivado.info:80/series/1533784/1533784/225703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111144, 7930, 'O Show de Tom e Jerry S04 E78', 'http://sinalprivado.info:80/series/1533784/1533784/225704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111145, 7931, 'O Show de Tom e Jerry S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111146, 7931, 'O Show de Tom e Jerry S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111147, 7931, 'O Show de Tom e Jerry S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111148, 7931, 'O Show de Tom e Jerry S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111149, 7931, 'O Show de Tom e Jerry S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111150, 7931, 'O Show de Tom e Jerry S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111151, 7931, 'O Show de Tom e Jerry S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111152, 7931, 'O Show de Tom e Jerry S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111153, 7931, 'O Show de Tom e Jerry S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111154, 7931, 'O Show de Tom e Jerry S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111155, 7931, 'O Show de Tom e Jerry S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111156, 7931, 'O Show de Tom e Jerry S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111157, 7931, 'O Show de Tom e Jerry S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111158, 7931, 'O Show de Tom e Jerry S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/225718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111159, 7931, 'O Show de Tom e Jerry S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/225719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111160, 7931, 'O Show de Tom e Jerry S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/225720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111161, 7931, 'O Show de Tom e Jerry S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/225721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111162, 7931, 'O Show de Tom e Jerry S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/225722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111163, 7931, 'O Show de Tom e Jerry S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/225723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111164, 7931, 'O Show de Tom e Jerry S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/225724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111165, 7931, 'O Show de Tom e Jerry S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/225725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111166, 7931, 'O Show de Tom e Jerry S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/225726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111167, 7931, 'O Show de Tom e Jerry S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/225727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111168, 7931, 'O Show de Tom e Jerry S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/225728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111169, 7931, 'O Show de Tom e Jerry S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/225729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111170, 7931, 'O Show de Tom e Jerry S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/225730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111171, 7931, 'O Show de Tom e Jerry S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/225731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111172, 7931, 'O Show de Tom e Jerry S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/225732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111173, 7931, 'O Show de Tom e Jerry S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/225733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111174, 7931, 'O Show de Tom e Jerry S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/225734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111175, 7931, 'O Show de Tom e Jerry S05 E31', 'http://sinalprivado.info:80/series/1533784/1533784/225735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111176, 7931, 'O Show de Tom e Jerry S05 E32', 'http://sinalprivado.info:80/series/1533784/1533784/225736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111177, 7931, 'O Show de Tom e Jerry S05 E33', 'http://sinalprivado.info:80/series/1533784/1533784/225737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111178, 7931, 'O Show de Tom e Jerry S05 E34', 'http://sinalprivado.info:80/series/1533784/1533784/225738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111179, 7931, 'O Show de Tom e Jerry S05 E35', 'http://sinalprivado.info:80/series/1533784/1533784/225739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111180, 7931, 'O Show de Tom e Jerry S05 E36', 'http://sinalprivado.info:80/series/1533784/1533784/225740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111181, 7931, 'O Show de Tom e Jerry S05 E37', 'http://sinalprivado.info:80/series/1533784/1533784/225741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111182, 7931, 'O Show de Tom e Jerry S05 E38', 'http://sinalprivado.info:80/series/1533784/1533784/225742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111183, 7931, 'O Show de Tom e Jerry S05 E39', 'http://sinalprivado.info:80/series/1533784/1533784/225743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0VTMU4UI8XlaryymvNKjnD1TXc.jpg'),
(111184, 7932, 'Os Segredos da Igreja Hillsong [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bzAX5ttM5yYVgZ9Ebum14TMMq1C.jpg'),
(111185, 7932, 'Os Segredos da Igreja Hillsong [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sWJLvsAUeZ3wm50Cz6VmvNXyNTs.jpg'),
(111186, 7932, 'Os Segredos da Igreja Hillsong [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mVnDb4eoOFTy4OXO5SIr18AtbV.jpg'),
(111187, 7932, 'Os Segredos da Igreja Hillsong [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mVnDb4eoOFTy4OXO5SIr18AtbV.jpg'),
(111188, 7933, 'Pocoyo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5niEtH8bHnyvmUgbaF0heryJKJL.jpg'),
(111189, 7933, 'Pocoyo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5yvWiCOeNR31fEiSjel4PQlJvBk.jpg'),
(111190, 7933, 'Pocoyo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kntdFirX2oEig3D6bP79HgDYC5y.jpg'),
(111191, 7933, 'Pocoyo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kRxDqSa78yhgb8givaX7qgZFFSd.jpg'),
(111192, 7933, 'Pocoyo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/asSX7HEAV5Ezg6f7ALiztCS40Le.jpg'),
(111193, 7933, 'Pocoyo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uAfn1Vq7kjy5d5MZR1pgPV0BgrM.jpg'),
(111194, 7933, 'Pocoyo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJ3I79PaOVudD3AkmcQ5oeWMuDi.jpg'),
(111195, 7933, 'Pocoyo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j4mRGa5SuQsZiaFy21Ysqwv01hE.jpg'),
(111196, 7933, 'Pocoyo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0aQkcLJ0Wf8EpszayaDgvlJ4G8.jpg'),
(111197, 7933, 'Pocoyo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yGq3ojXat7nwmsIH6JTEXt8Uoak.jpg'),
(111198, 7933, 'Pocoyo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1mrr1xtFMqgogv7j3crmJ8Pbi17.jpg'),
(111199, 7933, 'Pocoyo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sAyDGUizh3s67BW7GV9TcIgCC3C.jpg'),
(111200, 7933, 'Pocoyo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e2OZmEcafSMeT1N3RYSs5Z8Z1No.jpg'),
(111201, 7933, 'Pocoyo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/225220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mmKfyuRRfRYSAUcJNN4JLybB6gV.jpg'),
(111202, 7933, 'Pocoyo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/225221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2nTh98q6Dq3wkWSJ78uJON5waR7.jpg'),
(111203, 7933, 'Pocoyo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/225222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5jLhXQKHWYFHZo9QC1IGwJektL3.jpg'),
(111204, 7933, 'Pocoyo S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/225223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zJhv9uUHwG8U4MAMs8ZyTcEKBFy.jpg'),
(111205, 7933, 'Pocoyo S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/225224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8LpsBqP3Up7XcClWYQLwEyMUKsy.jpg'),
(111206, 7933, 'Pocoyo S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/225225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4IWtEs0SMEUSvaDlwPRi4rHk6IC.jpg'),
(111207, 7933, 'Pocoyo S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/225226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/as1T8tatAGNS0pJ8ROte3MtP8CF.jpg'),
(111208, 7933, 'Pocoyo S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/225227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/khnjFYB3CNMQtSH2Z9C7RsPShnl.jpg'),
(111209, 7933, 'Pocoyo S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/225228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aniYRkk9faW8RPbCuoUir3n3HPN.jpg'),
(111210, 7933, 'Pocoyo S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/225229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/411ULrwrbX0QxhpFKEilZffoM4V.jpg'),
(111211, 7933, 'Pocoyo S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/225230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l3FLLuvFuDKgVO03NAT8O8kEyKa.jpg'),
(111212, 7933, 'Pocoyo S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/225231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rqGSpj23Ls005rODGD5Ie3GGxuC.jpg'),
(111213, 7933, 'Pocoyo S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/225232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uY1ioljtpmmeR6n3gjoIOo0uVxp.jpg'),
(111214, 7933, 'Pocoyo S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/225233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x9Afb3hw86W3wREgNujEVpEO5ZL.jpg'),
(111215, 7933, 'Pocoyo S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/225234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lEE2AWSpb81bb3G3ZqFceefvhVR.jpg'),
(111216, 7933, 'Pocoyo S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/225235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cBIQgk8okO59W0YBmLEGkxjvaQK.jpg'),
(111217, 7933, 'Pocoyo S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/225236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3uWveyiNq7W1LDqZ1vLPlYP1vgw.jpg'),
(111218, 7933, 'Pocoyo S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/225237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vNwhcPhCECtgAbuOSg3hCJXwVrd.jpg'),
(111219, 7933, 'Pocoyo S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/225238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3hf9vDY1RLMw0MfJwKzEAj7TJnl.jpg'),
(111220, 7933, 'Pocoyo S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/225239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6pzVcSEoqWWcacObz5P4DuKBmJj.jpg'),
(111221, 7933, 'Pocoyo S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/225240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OcJJwsfOfdKrBLfkPO61sVZt8t.jpg'),
(111222, 7933, 'Pocoyo S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/225241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7eY557cq3Vz50AfBOGi3Ac1Yy3j.jpg'),
(111223, 7933, 'Pocoyo S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/225242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qSh0Qh31QPDRnvEylBNRiFaLqnH.jpg'),
(111224, 7933, 'Pocoyo S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/225243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/queGBeRFlJG4rMWs7iGBDeDqhGt.jpg'),
(111225, 7933, 'Pocoyo S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/225244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tNwxI8NjS4zmHOeHvJhOhz4L4rw.jpg'),
(111226, 7933, 'Pocoyo S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/225245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QGaXuk56xGIqEhCfJQsu1wWwMH.jpg'),
(111227, 7933, 'Pocoyo S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/225246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jyhLgPBlArUNcJUDNs5maIuIpuV.jpg'),
(111228, 7933, 'Pocoyo S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/225247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfONRyTFaWD0HTsXSuoMLfFjr8z.jpg'),
(111229, 7933, 'Pocoyo S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/225248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyNU5cXXlnnSyCMBLht8j4y2SxR.jpg'),
(111230, 7933, 'Pocoyo S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/225249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfONRyTFaWD0HTsXSuoMLfFjr8z.jpg'),
(111231, 7933, 'Pocoyo S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/225250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/UBOVBTC9kSfEXxdZ5EgsOwt144.jpg'),
(111232, 7933, 'Pocoyo S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/225251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x9D4rTX2mlimSMgYECG4JtbZJx4.jpg'),
(111233, 7933, 'Pocoyo S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/225252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8k9ShILfUfbRSWShXNaNSuDgndM.jpg'),
(111234, 7933, 'Pocoyo S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/225253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jY9Xz60GUWKxKg09LMdlmwuvZ9z.jpg'),
(111235, 7933, 'Pocoyo S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/225254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q3ajIFPpO0MuzDP8amWBGtsTYjP.jpg'),
(111236, 7933, 'Pocoyo S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/225255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ce4BKfFguGgyfxixLeCVKYonft.jpg'),
(111237, 7933, 'Pocoyo S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/225256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oYkMXZmRodD1jUKgoZuS65ZKCVk.jpg'),
(111238, 7933, 'Pocoyo S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/225257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2YB9xB8bAlWJQkdBFVSymRusSMr.jpg'),
(111239, 7933, 'Pocoyo S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/225258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6xGWrgBqKev04NXSyVb7nR8CwY3.jpg'),
(111240, 7934, 'Pocoyo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uAfn1Vq7kjy5d5MZR1pgPV0BgrM.jpg'),
(111241, 7934, 'Pocoyo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zJGefIC8Ejm8MyL6yYpqY40C7lm.jpg'),
(111242, 7934, 'Pocoyo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/55qC9kzCTEx5ozoAjLmIMTS7EMn.jpg'),
(111243, 7934, 'Pocoyo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/moTgA1xlHYF5Dymh0Kcatyk77Fv.jpg'),
(111244, 7934, 'Pocoyo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nHA7kGnyt3fhWKCA4eeNC2pFKXM.jpg'),
(111245, 7934, 'Pocoyo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rjzB1qJVBmdexoCEPDVegCsYRJl.jpg'),
(111246, 7934, 'Pocoyo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dpaCOgxEqD85mtEVgW5ges8un6o.jpg'),
(111247, 7934, 'Pocoyo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uNY3r7GAH6YRVPaAYftdKv6OUuW.jpg'),
(111248, 7934, 'Pocoyo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d3RqNhsZj9gFemm9p93QzsXCnaq.jpg'),
(111249, 7934, 'Pocoyo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w0AiAWjVFobzmQsddRogSbCJ7K2.jpg'),
(111250, 7934, 'Pocoyo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3swxyk7ARaYk5yP35ihA2anjEy8.jpg'),
(111251, 7934, 'Pocoyo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o96sOPk5aU2WKxV1hFqYvQFllv4.jpg'),
(111252, 7934, 'Pocoyo S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kArpiG9JFkW9ZRut6Fkbf7OVZ0M.jpg'),
(111253, 7934, 'Pocoyo S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/225272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iBky3ANHJHOqEQbBW1TwfgsE4Lp.jpg'),
(111254, 7934, 'Pocoyo S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/225273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oyfw0d0yEb8tb6lzRIPri9qDl84.jpg'),
(111255, 7934, 'Pocoyo S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/225274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eOpUBzKGMKPZ2rl23lQPa7WHmbS.jpg'),
(111256, 7934, 'Pocoyo S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/225275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wM7h33J8x8YpWW6HbVQlu4bZte6.jpg'),
(111257, 7934, 'Pocoyo S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/225276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qti2ZSCf5HcQtrstV6hS4pKltrY.jpg'),
(111258, 7934, 'Pocoyo S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/225277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/izy3fjitazMw58WHec4H5oIZlo2.jpg'),
(111259, 7934, 'Pocoyo S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/225278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vh7vnbI4QfX2OWUwngn6Qj2ssTI.jpg'),
(111260, 7934, 'Pocoyo S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/225279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ubvJOfOzgVxoXCIzRMcTjRbHbAQ.jpg'),
(111261, 7934, 'Pocoyo S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/225280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZm2yUcsjOvrVWNDuyhF9Ri6JYA.jpg'),
(111262, 7934, 'Pocoyo S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/225281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y4FjFJRdJwgmni0y7Lg9L69jvCp.jpg'),
(111263, 7934, 'Pocoyo S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/225282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Jzsdkp6H0Z9XgQ9UfNLuuZmzkZ.jpg'),
(111264, 7934, 'Pocoyo S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/225283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cZoGPMGvDgCLnDhcIWYM8UwCmNr.jpg'),
(111265, 7934, 'Pocoyo S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/225284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r14artoLQ52Hp3gV0vxwwPcFYOK.jpg'),
(111266, 7934, 'Pocoyo S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/225285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3hDr2XyDLiw7C2HUtVqsBdxPBdb.jpg'),
(111267, 7934, 'Pocoyo S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/225286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p18pJeO7EpWUfwdjmESR38KnpSx.jpg'),
(111268, 7934, 'Pocoyo S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/225287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fFEPSMTnFrkEGDD4mNfFWG7l0mZ.jpg'),
(111269, 7934, 'Pocoyo S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/225288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wurDCvJWjA2vfSsHZ0EDukXaffQ.jpg'),
(111270, 7934, 'Pocoyo S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/225289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o7gpFLRzbNWQbk2apSUzc7eJmuk.jpg'),
(111271, 7934, 'Pocoyo S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/225290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x45UXkDPpBjG5ptJf3XDbJDyX6J.jpg'),
(111272, 7934, 'Pocoyo S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/225291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ilZu5rq8mYNAxoMdikhIYm6U65d.jpg'),
(111273, 7934, 'Pocoyo S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/225292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cIRbapStWduHuOlrbFEmD4PveCH.jpg'),
(111274, 7934, 'Pocoyo S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/225293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZQOY1Pxn12W8fuvxChZP0XF7Gd.jpg'),
(111275, 7934, 'Pocoyo S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/225294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mY3YJCcmp4gWaL61Anq3TWsIonl.jpg'),
(111276, 7934, 'Pocoyo S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/225295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xXyjrA36ye1cCj3Vc6W5m6qHKa1.jpg'),
(111277, 7934, 'Pocoyo S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/225296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jWuN2wb9J2CIeGtZrrXagLVJRfr.jpg'),
(111278, 7934, 'Pocoyo S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/225297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/73twS5EFOAYlNiQ81gfBKbtfxwo.jpg'),
(111279, 7934, 'Pocoyo S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/225298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sV5vVlniB5FPaYvY7ma6zx5Lca3.jpg'),
(111280, 7934, 'Pocoyo S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/225299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gEDTtC7lQfhApQCnWyAQQN6Yon2.jpg'),
(111281, 7934, 'Pocoyo S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/225300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p7OlQx5DgFyQODmYQaAQvfVApqc.jpg'),
(111282, 7934, 'Pocoyo S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/225301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uVEWrGOuPecGoBqic91v9khKxqh.jpg'),
(111283, 7934, 'Pocoyo S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/225302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n4zAhEqfpxEgYPdM7KbN7FqmXCk.jpg'),
(111284, 7934, 'Pocoyo S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/225303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/euQhEOl2AnH4gfk82COl03M9c9Q.jpg'),
(111285, 7934, 'Pocoyo S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/225304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aj3afKGIQniEo34t4CLtipQQ1HM.jpg'),
(111286, 7934, 'Pocoyo S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/225305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4zDzbCz889dioHIPPEq0ot6UUlU.jpg'),
(111287, 7934, 'Pocoyo S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/225306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8lIjb7O9fRlfGIbEQnfwgpOqGRU.jpg'),
(111288, 7934, 'Pocoyo S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/225307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g2fwl4vhRkRvZWIb4nn8bnhDLGS.jpg'),
(111289, 7934, 'Pocoyo S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/225308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9whtp7NOoMtkPgGk7JhCDaFLiyE.jpg'),
(111290, 7934, 'Pocoyo S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/225309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5eTe6YANPPwANnAoOPLmNVqcJ2R.jpg'),
(111291, 7934, 'Pocoyo S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/225310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iE2fD95uhJHCnLBBgSRhhudQGyt.jpg'),
(111292, 7935, 'Pocoyo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4KISpFsYdFpdYTSabgpdhaTjO31.jpg'),
(111293, 7935, 'Pocoyo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eTHVvnYc6EeG2YehXa90sAEzQ5q.jpg'),
(111294, 7935, 'Pocoyo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dxtsXFZvbEbzsXSgOCsqBp2qUWc.jpg'),
(111295, 7935, 'Pocoyo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nd84WRWYFoxBT2sMUCjPiQzNCch.jpg'),
(111296, 7935, 'Pocoyo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6Y4g8Y0AIgAeFdXcZUdmRjqj6p.jpg'),
(111297, 7935, 'Pocoyo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yqr3dc7Uc74BZ2Z6Y1IP3Zaes9r.jpg'),
(111298, 7935, 'Pocoyo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/37r3Onj25sMUxolHvmdwng4pn6D.jpg'),
(111299, 7935, 'Pocoyo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/np6YfhqZMoLfyaKGOwEMMUMVcUI.jpg'),
(111300, 7935, 'Pocoyo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7R1fqX2N9DMlkumAVIgMj9ajXgZ.jpg'),
(111301, 7935, 'Pocoyo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1tWnP3Cp8TslZuAh7jn9oKKC4pC.jpg'),
(111302, 7935, 'Pocoyo S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gD4TGBpz0wSFTXFY5bKDU7ckhm8.jpg'),
(111303, 7935, 'Pocoyo S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9FrdObBsWioJ91DAuV7MPEHhIWM.jpg'),
(111304, 7935, 'Pocoyo S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111305, 7935, 'Pocoyo S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/225324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/loK0QmMBTz6jrADfLAHAAwr2oUh.jpg'),
(111306, 7935, 'Pocoyo S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/225325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bDjWDUwuGoFnBFAl3R2uwmrBlKm.jpg'),
(111307, 7935, 'Pocoyo S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/225326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l87Nyb1pphUp0PXId3MthA6cXIi.jpg'),
(111308, 7935, 'Pocoyo S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/225327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v3S7JtANf4oMtti1qPDDKbeAFJ2.jpg'),
(111309, 7935, 'Pocoyo S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/225328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r9p9dlh7zI3jZoY5eo41YgdF9jC.jpg'),
(111310, 7935, 'Pocoyo S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/225329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1nMn8Q1Ntwi5LYkNr90LpYJdJQr.jpg'),
(111311, 7935, 'Pocoyo S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/225330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBZvEBBlmpu0mEIdrDknxxeJIsC.jpg'),
(111312, 7935, 'Pocoyo S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/225331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFkt7K7s2dW89XniiDuUAs1Fp0A.jpg'),
(111313, 7935, 'Pocoyo S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/225332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y8gDpyIenm9LU2W2JglZV5vZHYg.jpg'),
(111314, 7935, 'Pocoyo S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/225333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1nsZSiu4TUD5Hg99zlahK8HASZM.jpg'),
(111315, 7935, 'Pocoyo S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/225334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111316, 7935, 'Pocoyo S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/225335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111317, 7935, 'Pocoyo S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/225336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111318, 7935, 'Pocoyo S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/225337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111319, 7935, 'Pocoyo S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/225338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111320, 7935, 'Pocoyo S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/225339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111321, 7935, 'Pocoyo S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/225340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111322, 7935, 'Pocoyo S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/225341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111323, 7935, 'Pocoyo S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/225342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111324, 7935, 'Pocoyo S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/225343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111325, 7935, 'Pocoyo S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/225344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111326, 7935, 'Pocoyo S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/225345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111327, 7935, 'Pocoyo S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/225346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111328, 7935, 'Pocoyo S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/225347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111329, 7935, 'Pocoyo S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/225348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111330, 7935, 'Pocoyo S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/225349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111331, 7935, 'Pocoyo S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/225350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111332, 7935, 'Pocoyo S03 E41', 'http://sinalprivado.info:80/series/1533784/1533784/225351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111333, 7935, 'Pocoyo S03 E42', 'http://sinalprivado.info:80/series/1533784/1533784/225352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111334, 7935, 'Pocoyo S03 E43', 'http://sinalprivado.info:80/series/1533784/1533784/225353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111335, 7935, 'Pocoyo S03 E44', 'http://sinalprivado.info:80/series/1533784/1533784/225354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111336, 7935, 'Pocoyo S03 E45', 'http://sinalprivado.info:80/series/1533784/1533784/225355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111337, 7935, 'Pocoyo S03 E46', 'http://sinalprivado.info:80/series/1533784/1533784/225356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111338, 7935, 'Pocoyo S03 E47', 'http://sinalprivado.info:80/series/1533784/1533784/225357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111339, 7935, 'Pocoyo S03 E48', 'http://sinalprivado.info:80/series/1533784/1533784/225358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111340, 7935, 'Pocoyo S03 E49', 'http://sinalprivado.info:80/series/1533784/1533784/225359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111341, 7935, 'Pocoyo S03 E50', 'http://sinalprivado.info:80/series/1533784/1533784/225360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111342, 7935, 'Pocoyo S03 E51', 'http://sinalprivado.info:80/series/1533784/1533784/225361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111343, 7935, 'Pocoyo S03 E52', 'http://sinalprivado.info:80/series/1533784/1533784/225362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLniYJhx20jihqd0pO25BmmMG8F.jpg'),
(111344, 7936, 'Pocoyo S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111345, 7936, 'Pocoyo S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111346, 7936, 'Pocoyo S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111347, 7936, 'Pocoyo S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111348, 7936, 'Pocoyo S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111349, 7936, 'Pocoyo S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111350, 7936, 'Pocoyo S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111351, 7936, 'Pocoyo S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111352, 7936, 'Pocoyo S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111353, 7936, 'Pocoyo S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111354, 7936, 'Pocoyo S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111355, 7936, 'Pocoyo S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111356, 7936, 'Pocoyo S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111357, 7936, 'Pocoyo S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/225376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111358, 7936, 'Pocoyo S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/225377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111359, 7936, 'Pocoyo S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/225378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111360, 7936, 'Pocoyo S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/225379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111361, 7936, 'Pocoyo S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/225380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111362, 7936, 'Pocoyo S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/225381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111363, 7936, 'Pocoyo S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/225382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111364, 7936, 'Pocoyo S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/225383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111365, 7936, 'Pocoyo S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/225384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111366, 7936, 'Pocoyo S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/225385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111367, 7936, 'Pocoyo S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/225386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111368, 7936, 'Pocoyo S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/225387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111369, 7936, 'Pocoyo S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/225388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111370, 7936, 'Pocoyo S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/225389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111371, 7936, 'Pocoyo S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/225390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111372, 7936, 'Pocoyo S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/225391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111373, 7936, 'Pocoyo S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/225392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111374, 7936, 'Pocoyo S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/225393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111375, 7936, 'Pocoyo S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/225394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111376, 7936, 'Pocoyo S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/225395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111377, 7936, 'Pocoyo S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/225396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111378, 7936, 'Pocoyo S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/225397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111379, 7936, 'Pocoyo S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/225398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111380, 7936, 'Pocoyo S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/225399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111381, 7936, 'Pocoyo S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/225400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111382, 7936, 'Pocoyo S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/225401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111383, 7936, 'Pocoyo S04 E40', 'http://sinalprivado.info:80/series/1533784/1533784/225402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111384, 7936, 'Pocoyo S04 E41', 'http://sinalprivado.info:80/series/1533784/1533784/225403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111385, 7936, 'Pocoyo S04 E42', 'http://sinalprivado.info:80/series/1533784/1533784/225404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111386, 7936, 'Pocoyo S04 E43', 'http://sinalprivado.info:80/series/1533784/1533784/225405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111387, 7936, 'Pocoyo S04 E44', 'http://sinalprivado.info:80/series/1533784/1533784/225406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111388, 7936, 'Pocoyo S04 E45', 'http://sinalprivado.info:80/series/1533784/1533784/225407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111389, 7936, 'Pocoyo S04 E46', 'http://sinalprivado.info:80/series/1533784/1533784/225408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111390, 7936, 'Pocoyo S04 E47', 'http://sinalprivado.info:80/series/1533784/1533784/225409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111391, 7936, 'Pocoyo S04 E48', 'http://sinalprivado.info:80/series/1533784/1533784/225410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111392, 7936, 'Pocoyo S04 E49', 'http://sinalprivado.info:80/series/1533784/1533784/225411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111393, 7936, 'Pocoyo S04 E50', 'http://sinalprivado.info:80/series/1533784/1533784/225412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111394, 7936, 'Pocoyo S04 E51', 'http://sinalprivado.info:80/series/1533784/1533784/225413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111395, 7936, 'Pocoyo S04 E52', 'http://sinalprivado.info:80/series/1533784/1533784/225414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111396, 7936, 'Pocoyo S04 E53', 'http://sinalprivado.info:80/series/1533784/1533784/225415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1fmaC3t96Napg7TR9SsfOX8q11X.jpg'),
(111397, 7937, 'Agora Exploro a Masmorra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ruHd27xIc5rvipM5YdIiVHM2yI8.jpg'),
(111398, 7937, 'Agora Exploro a Masmorra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/103Z7mr9u2LYpMjlool68m3QZle.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(111399, 7937, 'Agora Exploro a Masmorra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241428.mp4', 'http://image.tmdb.org/t/p/w1280/vLkDfh2mwNQS0DV37isEpkqqFwR.jpg'),
(111400, 7937, 'Agora Exploro a Masmorra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eSQrTyg8Zvz7Ymy5oXFkuYu5ZIr.jpg'),
(111401, 7937, 'Agora Exploro a Masmorra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eSQrTyg8Zvz7Ymy5oXFkuYu5ZIr.jpg'),
(111402, 7937, 'Agora Exploro a Masmorra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eSQrTyg8Zvz7Ymy5oXFkuYu5ZIr.jpg'),
(111403, 7937, 'Agora Exploro a Masmorra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eSQrTyg8Zvz7Ymy5oXFkuYu5ZIr.jpg'),
(111404, 7937, 'Agora Exploro a Masmorra S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eSQrTyg8Zvz7Ymy5oXFkuYu5ZIr.jpg'),
(111405, 7937, 'Agora Exploro a Masmorra S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eSQrTyg8Zvz7Ymy5oXFkuYu5ZIr.jpg'),
(111406, 7937, 'Agora Exploro a Masmorra S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eSQrTyg8Zvz7Ymy5oXFkuYu5ZIr.jpg'),
(111407, 7937, 'Agora Exploro a Masmorra S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eSQrTyg8Zvz7Ymy5oXFkuYu5ZIr.jpg'),
(111408, 7937, 'Agora Exploro a Masmorra S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eSQrTyg8Zvz7Ymy5oXFkuYu5ZIr.jpg'),
(111409, 7938, 'Agora Exploro a Masmorra S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/873074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eSQrTyg8Zvz7Ymy5oXFkuYu5ZIr.jpg'),
(111410, 7938, 'Agora Exploro a Masmorra S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/879405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eSQrTyg8Zvz7Ymy5oXFkuYu5ZIr.jpg'),
(111411, 7938, 'Agora Exploro a Masmorra S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/879881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eSQrTyg8Zvz7Ymy5oXFkuYu5ZIr.jpg'),
(111412, 7938, 'Agora Exploro a Masmorra S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/881162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eSQrTyg8Zvz7Ymy5oXFkuYu5ZIr.jpg'),
(111413, 7938, 'Agora Exploro a Masmorra S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/881163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eSQrTyg8Zvz7Ymy5oXFkuYu5ZIr.jpg'),
(111414, 7938, 'Agora Exploro a Masmorra S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/881287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eSQrTyg8Zvz7Ymy5oXFkuYu5ZIr.jpg'),
(111415, 7938, 'Agora Exploro a Masmorra S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/883025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eSQrTyg8Zvz7Ymy5oXFkuYu5ZIr.jpg'),
(111416, 7938, 'Agora Exploro a Masmorra S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/883782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eSQrTyg8Zvz7Ymy5oXFkuYu5ZIr.jpg'),
(111417, 7938, 'Agora Exploro a Masmorra S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/885309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eSQrTyg8Zvz7Ymy5oXFkuYu5ZIr.jpg'),
(111418, 7938, 'Agora Exploro a Masmorra S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/886061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eSQrTyg8Zvz7Ymy5oXFkuYu5ZIr.jpg'),
(111419, 7938, 'Agora Exploro a Masmorra S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/888144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eSQrTyg8Zvz7Ymy5oXFkuYu5ZIr.jpg'),
(111420, 7938, 'Agora Exploro a Masmorra S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/888145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eSQrTyg8Zvz7Ymy5oXFkuYu5ZIr.jpg'),
(111421, 7939, 'Sem Saída S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k2Mu6OVKxETazpgsl7guLvZcXmk.jpg'),
(111422, 7939, 'Sem Saída S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pN0oRMAVKr0ymmHFL5BqqyW8VQ9.jpg'),
(111423, 7939, 'Sem Saída S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w7liDVTPhmu1TZJKBdEnxqwukmc.jpg'),
(111424, 7939, 'Sem Saída S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vCammHOkUhfplLDp6hkCGWJAptY.jpg'),
(111425, 7939, 'Sem Saída S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hrS6g5XegAIPmSN0hIjP5MQodCn.jpg'),
(111426, 7939, 'Sem Saída S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Vq96tlQiqRZSwohbCsVlztqEKL.jpg'),
(111427, 7940, 'Sem Saída S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8n8KafYevR7po8P010Ajb6iGwZ0.jpg'),
(111428, 7940, 'Sem Saída S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ZneliS7MbdXt97jnXAagT4MdJg.jpg'),
(111429, 7940, 'Sem Saída S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tUlHFQS4Os1gTkZNHFBJS8s3A15.jpg'),
(111430, 7940, 'Sem Saída S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nmoBdtadD6hDFJUQRm1bwkaTWUb.jpg'),
(111431, 7940, 'Sem Saída S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/myMoXZ8p20AQ5TQ5skwlGM6xv7B.jpg'),
(111432, 7940, 'Sem Saída S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/amUs8YypAxtNdMf1zTPGIL7xNu8.jpg'),
(111433, 7941, 'Sem Saída S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pBRuiHShTGWJhDFWtZ4QQJyXpUI.jpg'),
(111434, 7941, 'Sem Saída S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mmxpBsE6DgwP8DzVCNZDmqU6SLQ.jpg'),
(111435, 7941, 'Sem Saída S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dUxnrIG0VCO38a2vudJ5FPAwhfo.jpg'),
(111436, 7941, 'Sem Saída S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/L8P1SNzhkjnEyTSnwy4F5McODE.jpg'),
(111437, 7941, 'Sem Saída S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/20WwtjKbIpBE7Rn7jlTGZxPxfDx.jpg'),
(111438, 7941, 'Sem Saída S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rPvRXj86WR3fnLaA2kgtQzBP1m1.jpg'),
(111439, 7942, 'Show do Elmo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2IZNM9O3B93JScQO8TdsYn4kPmi.jpg'),
(111440, 7942, 'Show do Elmo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/26nFoTs0uZMajF5eEBb8lPj2Rph.jpg'),
(111441, 7942, 'Show do Elmo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kT3KKdPaI0Z1voY8vJa7VOhcmi7.jpg'),
(111442, 7942, 'Show do Elmo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c2H6dOq9iB9VvRCJxCZ8wOaUu08.jpg'),
(111443, 7942, 'Show do Elmo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXC70V6AeY7T37uvjVYtBDhBtTx.jpg'),
(111444, 7942, 'Show do Elmo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k377QDBy6XvfITuVncPeMYertCU.jpg'),
(111445, 7942, 'Show do Elmo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wfimI4UKVGKnWOHxi9sYyMXSDhW.jpg'),
(111446, 7942, 'Show do Elmo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oU5GZzCU88Didmh6O53RhcH84j8.jpg'),
(111447, 7942, 'Show do Elmo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqJxiiZuO1lKz3k26YL49S7pBBl.jpg'),
(111448, 7942, 'Show do Elmo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqJxiiZuO1lKz3k26YL49S7pBBl.jpg'),
(111449, 7942, 'Show do Elmo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqJxiiZuO1lKz3k26YL49S7pBBl.jpg'),
(111450, 7942, 'Show do Elmo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqJxiiZuO1lKz3k26YL49S7pBBl.jpg'),
(111451, 7942, 'Show do Elmo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqJxiiZuO1lKz3k26YL49S7pBBl.jpg'),
(111452, 7943, 'Show do Elmo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqJxiiZuO1lKz3k26YL49S7pBBl.jpg'),
(111453, 7943, 'Show do Elmo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqJxiiZuO1lKz3k26YL49S7pBBl.jpg'),
(111454, 7943, 'Show do Elmo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqJxiiZuO1lKz3k26YL49S7pBBl.jpg'),
(111455, 7943, 'Show do Elmo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqJxiiZuO1lKz3k26YL49S7pBBl.jpg'),
(111456, 7943, 'Show do Elmo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqJxiiZuO1lKz3k26YL49S7pBBl.jpg'),
(111457, 7943, 'Show do Elmo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqJxiiZuO1lKz3k26YL49S7pBBl.jpg'),
(111458, 7943, 'Show do Elmo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqJxiiZuO1lKz3k26YL49S7pBBl.jpg'),
(111459, 7943, 'Show do Elmo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqJxiiZuO1lKz3k26YL49S7pBBl.jpg'),
(111460, 7943, 'Show do Elmo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqJxiiZuO1lKz3k26YL49S7pBBl.jpg'),
(111461, 7943, 'Show do Elmo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqJxiiZuO1lKz3k26YL49S7pBBl.jpg'),
(111462, 7943, 'Show do Elmo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqJxiiZuO1lKz3k26YL49S7pBBl.jpg'),
(111463, 7943, 'Show do Elmo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqJxiiZuO1lKz3k26YL49S7pBBl.jpg'),
(111464, 7943, 'Show do Elmo S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqJxiiZuO1lKz3k26YL49S7pBBl.jpg'),
(111465, 7943, 'Show do Elmo S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/225186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqJxiiZuO1lKz3k26YL49S7pBBl.jpg'),
(111466, 7943, 'Show do Elmo S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/225187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqJxiiZuO1lKz3k26YL49S7pBBl.jpg'),
(111467, 7943, 'Show do Elmo S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/225188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqJxiiZuO1lKz3k26YL49S7pBBl.jpg'),
(111468, 7944, 'So Help Me Todd [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oFTFLYIkmfMDfjXDT3l9lXC5lvG.jpg'),
(111469, 7944, 'So Help Me Todd [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ZNPDA6yFIg2ShfF9Gb6DXgcxAn.jpg'),
(111470, 7944, 'So Help Me Todd [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNVXZHFKZyAu1HWgwKfqrIV5sx4.jpg'),
(111471, 7944, 'So Help Me Todd [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q4hDzCo3hnUfhXUxet4egpJheEd.jpg'),
(111472, 7944, 'So Help Me Todd [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lGeqB64T0i9gwv1aAKW4tNtO0xv.jpg'),
(111473, 7944, 'So Help Me Todd [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111474, 7944, 'So Help Me Todd [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111475, 7944, 'So Help Me Todd [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111476, 7944, 'So Help Me Todd [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111477, 7944, 'So Help Me Todd [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/245687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111478, 7944, 'So Help Me Todd [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/245688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111479, 7944, 'So Help Me Todd [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/245689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111480, 7944, 'So Help Me Todd [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/245690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111481, 7944, 'So Help Me Todd [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/245691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111482, 7944, 'So Help Me Todd [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/245692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111483, 7944, 'So Help Me Todd [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/245693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111484, 7944, 'So Help Me Todd [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/245694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111485, 7944, 'So Help Me Todd [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/245695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111486, 7944, 'So Help Me Todd [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/245696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111487, 7944, 'So Help Me Todd [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/245697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111488, 7945, 'So Help Me Todd [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111489, 7945, 'So Help Me Todd [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/288601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111490, 7945, 'So Help Me Todd [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111491, 7945, 'So Help Me Todd [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/305846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111492, 7945, 'So Help Me Todd [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/343016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111493, 7945, 'So Help Me Todd [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/332172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111494, 7945, 'So Help Me Todd [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/343018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111495, 7945, 'So Help Me Todd [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/343019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111496, 7945, 'So Help Me Todd [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/354076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111497, 7945, 'So Help Me Todd [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/354077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7q8EKVJjUofnlP3k2uVP0oRNtER.jpg'),
(111498, 7946, 'The Good Doctor: O Bom Doutor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eeNYnyVdAGdBzVDCIspxlFHNAtb.jpg'),
(111499, 7946, 'The Good Doctor: O Bom Doutor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1g3CuVBgFOOH12Sth6UjLInF2CK.jpg'),
(111500, 7946, 'The Good Doctor: O Bom Doutor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tmqwU2w2K6013xPkowDx4I0FFM5.jpg'),
(111501, 7946, 'The Good Doctor: O Bom Doutor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fVjVylVNKoWENfT33mpB6fhuAFm.jpg'),
(111502, 7946, 'The Good Doctor: O Bom Doutor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/MzfgLX9JNTKWVvWRFC2kgjB2xz.jpg'),
(111503, 7946, 'The Good Doctor: O Bom Doutor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s8GYwVwdLtKI1bAVJnJ68SJOgaz.jpg'),
(111504, 7946, 'The Good Doctor: O Bom Doutor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aj1VKYlk0FjLNH2ViWG7kzgsLT9.jpg'),
(111505, 7946, 'The Good Doctor: O Bom Doutor [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pwYRmXPu2MHXDYizfE9JNEUXi4A.jpg'),
(111506, 7946, 'The Good Doctor: O Bom Doutor [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qTy5ccl2GOAXENEMGjV9C2qTpqq.jpg'),
(111507, 7946, 'The Good Doctor: O Bom Doutor [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vCS4jTC0zJinFJy1Y5gHuw32esN.jpg'),
(111508, 7946, 'The Good Doctor: O Bom Doutor [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9szrl9sxMictoWjo7SlbvX2qcvh.jpg'),
(111509, 7946, 'The Good Doctor: O Bom Doutor [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/skCS4v00DeeePf2hBYN3UFvAVlw.jpg'),
(111510, 7946, 'The Good Doctor: O Bom Doutor [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ql96ISN6nrRQsz9lxQ62zfFaH60.jpg'),
(111511, 7946, 'The Good Doctor: O Bom Doutor [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/225057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/izihXlq8haa5wTtFFII8XAkYuDV.jpg'),
(111512, 7946, 'The Good Doctor: O Bom Doutor [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/225058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cuic2bVKE5BT66yYMtHiPZclCoG.jpg'),
(111513, 7946, 'The Good Doctor: O Bom Doutor [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/225059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rMli43YcMKvlRLYize0XIjSoDKZ.jpg'),
(111514, 7946, 'The Good Doctor: O Bom Doutor [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/225060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6KABs1NArkaKKtUFiUjcLSm30LS.jpg'),
(111515, 7946, 'The Good Doctor: O Bom Doutor [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/225061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9DxI3ECB5aMI0SScQvWttaqZz9V.jpg'),
(111516, 7947, 'The Good Doctor: O Bom Doutor [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ZglVukhrTwm1RH0LkO6ROYv3wa.jpg'),
(111517, 7947, 'The Good Doctor: O Bom Doutor [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Zx9JcW2xMU4yQoP1XllMgK3sdU.jpg'),
(111518, 7947, 'The Good Doctor: O Bom Doutor [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/30UtIcRk4lVhA7LvXYsM4cYvYfV.jpg'),
(111519, 7947, 'The Good Doctor: O Bom Doutor [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pnib9F3EN6c2owmvmDM1AfMuayK.jpg'),
(111520, 7947, 'The Good Doctor: O Bom Doutor [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tNx2eyqe89VuwOdVO9uEkY27giR.jpg'),
(111521, 7947, 'The Good Doctor: O Bom Doutor [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rYySW84keeCSMfhieUBxUVwB38D.jpg'),
(111522, 7947, 'The Good Doctor: O Bom Doutor [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xvPkfgJHpZdzkDoradB3edVmprb.jpg'),
(111523, 7947, 'The Good Doctor: O Bom Doutor [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7k0AYaJxys9k2M18oEAHQzdZK6s.jpg'),
(111524, 7947, 'The Good Doctor: O Bom Doutor [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9LMfoGDqSqMsNFp7t0ewbk4oN50.jpg'),
(111525, 7947, 'The Good Doctor: O Bom Doutor [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2i4oeJ5xK2iwXLQK5p3tqfgoUEM.jpg'),
(111526, 7947, 'The Good Doctor: O Bom Doutor [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZQtq2nq9KpBZfUKOXOZkZkzcnV.jpg'),
(111527, 7947, 'The Good Doctor: O Bom Doutor [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nz5c2HNi8cCMPVvVEjv71ztvWDj.jpg'),
(111528, 7947, 'The Good Doctor: O Bom Doutor [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/47sASSrkQfJ5TbmPbla9z6cH2QE.jpg'),
(111529, 7947, 'The Good Doctor: O Bom Doutor [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/225075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r53Egw7b19g05Vf04jnmdxNB7XF.jpg'),
(111530, 7947, 'The Good Doctor: O Bom Doutor [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/225076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oUttc8Yz384YCsm98Mgh6y4v9DK.jpg'),
(111531, 7947, 'The Good Doctor: O Bom Doutor [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/225077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vkRtaPQuLYDYTiyu6P2xQv1zTvX.jpg'),
(111532, 7947, 'The Good Doctor: O Bom Doutor [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/225078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9iy4jWhd1sZNUiDJ2HuHf9VplFQ.jpg'),
(111533, 7947, 'The Good Doctor: O Bom Doutor [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/225079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yqTwIiuCTjcdIyppV8MGqjWVJOj.jpg'),
(111534, 7948, 'The Good Doctor: O Bom Doutor [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bRvMRjxMQRs1gbn9XObAsXXf4BG.jpg'),
(111535, 7948, 'The Good Doctor: O Bom Doutor [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tckW2kXaUbin3mSKvBhbsMgK5Q7.jpg'),
(111536, 7948, 'The Good Doctor: O Bom Doutor [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xM9NM136u1NUkHD1vMdPxfn5XCa.jpg'),
(111537, 7948, 'The Good Doctor: O Bom Doutor [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bOjLyaf1CFrMNQG5EN22yKc3U2s.jpg'),
(111538, 7948, 'The Good Doctor: O Bom Doutor [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u9qobQlMlKrNed6ejeuoV6LlRTB.jpg'),
(111539, 7948, 'The Good Doctor: O Bom Doutor [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s8B8KPPlW9mgA5UfG29vwfucXfN.jpg'),
(111540, 7948, 'The Good Doctor: O Bom Doutor [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9sldAOBfQmZsXsYWPHzLwrOnKIC.jpg'),
(111541, 7948, 'The Good Doctor: O Bom Doutor [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l2lr119HgjtxJJOm3lezrdCFciJ.jpg'),
(111542, 7948, 'The Good Doctor: O Bom Doutor [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uNdE6iIceSkkY9wvBk58A3PSl5p.jpg'),
(111543, 7948, 'The Good Doctor: O Bom Doutor [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e3XFLZwQteHLJCMsnDjCqHWMQns.jpg'),
(111544, 7948, 'The Good Doctor: O Bom Doutor [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8rHbtHqhwVP0MP5ky74lIH101Bq.jpg'),
(111545, 7948, 'The Good Doctor: O Bom Doutor [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v1VVZEt7hO2dyQ8O1xXPwwqbcvM.jpg'),
(111546, 7948, 'The Good Doctor: O Bom Doutor [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zenYa5rbRJF7LxAnnvIoKB3erbN.jpg'),
(111547, 7948, 'The Good Doctor: O Bom Doutor [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/225093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xR00XdgbhNn6VALVJXqq46gYc2r.jpg'),
(111548, 7948, 'The Good Doctor: O Bom Doutor [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/225094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmOtYFJ1fBJdCpRz3Gj7WsyUR1B.jpg'),
(111549, 7948, 'The Good Doctor: O Bom Doutor [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/225095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ulAq86H8sdSl3ZdZjtmRajspLRO.jpg'),
(111550, 7948, 'The Good Doctor: O Bom Doutor [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/225096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fYH8ki5p0JXGzLab06cNNe4S08n.jpg'),
(111551, 7948, 'The Good Doctor: O Bom Doutor [L] S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/225097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ujSK9Y2Jp2SLc5LULkCJInCMRJl.jpg'),
(111552, 7948, 'The Good Doctor: O Bom Doutor [L] S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/225098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5IIUBAcngWNFxNb813Lms0CZ65Q.jpg'),
(111553, 7948, 'The Good Doctor: O Bom Doutor [L] S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/225099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bbV4bHdzLZ7jp3z9aWvVLFPSAAu.jpg'),
(111554, 7949, 'The Good Doctor: O Bom Doutor [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225100.mp4', 'http://timg.bdta.pro/images/5c562cbe6e795b955e0c917e549080e8.jpg'),
(111555, 7949, 'The Good Doctor: O Bom Doutor [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225101.mp4', 'http://timg.bdta.pro/images/7d7865f2d79151eb82b91be5c23622ae.jpg'),
(111556, 7949, 'The Good Doctor: O Bom Doutor [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225102.mp4', 'http://timg.bdta.pro/images/5b7e60c9b9975e67b4396f0d4cf5106c.jpg'),
(111557, 7949, 'The Good Doctor: O Bom Doutor [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225103.mp4', 'http://timg.bdta.pro/images/8ae3a22d26724f60fd3dba033df64325.jpg'),
(111558, 7949, 'The Good Doctor: O Bom Doutor [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225104.mp4', 'http://timg.bdta.pro/images/831e7f1c114233a3d38e4bc384aa2690.jpg'),
(111559, 7949, 'The Good Doctor: O Bom Doutor [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225105.mp4', 'http://timg.bdta.pro/images/f758904117698e09713a58d63b28ae06.jpg'),
(111560, 7949, 'The Good Doctor: O Bom Doutor [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225106.mp4', 'http://timg.bdta.pro/images/84045d8cbe3238e37cba4bcedc6b9228.jpg'),
(111561, 7949, 'The Good Doctor: O Bom Doutor [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225107.mp4', 'http://timg.bdta.pro/images/989fa7b4772504174370838329ff2a5c.jpg'),
(111562, 7949, 'The Good Doctor: O Bom Doutor [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225108.mp4', 'http://timg.bdta.pro/images/3f76b7dbc17871cf72f1d0cd008eca0e.jpg'),
(111563, 7949, 'The Good Doctor: O Bom Doutor [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225109.mp4', 'http://timg.bdta.pro/images/8773af5948761e8577ed542e1f57d012.jpg'),
(111564, 7949, 'The Good Doctor: O Bom Doutor [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225110.mp4', 'http://timg.bdta.pro/images/c48716afb38fc07ac3cd68080808ffcf.jpg'),
(111565, 7949, 'The Good Doctor: O Bom Doutor [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225111.mp4', 'http://timg.bdta.pro/images/e32fe5c866ec5fc569636663e80d3249.jpg'),
(111566, 7949, 'The Good Doctor: O Bom Doutor [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225112.mp4', 'http://timg.bdta.pro/images/f80a04886450b413cb0323d256538792.jpg'),
(111567, 7949, 'The Good Doctor: O Bom Doutor [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/225113.mp4', 'http://timg.bdta.pro/images/249e20b08cb16228cf66684a1b617d55.jpg'),
(111568, 7949, 'The Good Doctor: O Bom Doutor [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/225114.mp4', 'http://timg.bdta.pro/images/4f263d3ef098f39a1078278b221d87f4.jpg'),
(111569, 7949, 'The Good Doctor: O Bom Doutor [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/225115.mp4', 'http://timg.bdta.pro/images/a26ad88596089a655557c83f81128ecd.jpg'),
(111570, 7949, 'The Good Doctor: O Bom Doutor [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/225116.mp4', 'http://timg.bdta.pro/images/3cd13b242751271bd7234be3af94d1f5.jpg'),
(111571, 7949, 'The Good Doctor: O Bom Doutor [L] S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/225117.mp4', 'http://timg.bdta.pro/images/deeb2ab5c8230beb9df409393399be22.jpg'),
(111572, 7949, 'The Good Doctor: O Bom Doutor [L] S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/225118.mp4', 'http://timg.bdta.pro/images/8e61bd0aa981356e973e0140ca561f0d.jpg'),
(111573, 7949, 'The Good Doctor: O Bom Doutor [L] S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/225119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m1Wq6KKMOEGfcM643U90uhEM3Du.jpg'),
(111574, 7950, 'The Good Doctor: O Bom Doutor [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225120.mp4', 'http://timg.bdta.pro/images/14562bb329281d7b9c9e239e988e1811.jpg'),
(111575, 7950, 'The Good Doctor: O Bom Doutor [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225121.mp4', 'http://timg.bdta.pro/images/06d86c01ec0bb835da47951ae11365ac.jpg'),
(111576, 7950, 'The Good Doctor: O Bom Doutor [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225122.mp4', 'http://timg.bdta.pro/images/94c832fc47c1fb69154adcfd04447a2d.jpg'),
(111577, 7950, 'The Good Doctor: O Bom Doutor [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225123.mp4', 'http://timg.bdta.pro/images/6e2c1b02b5f91652b988bafb9a6387c9.jpg'),
(111578, 7950, 'The Good Doctor: O Bom Doutor [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225124.mp4', 'http://timg.bdta.pro/images/846374c9dfc3fca05159f025b37a56b7.jpg'),
(111579, 7950, 'The Good Doctor: O Bom Doutor [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225125.mp4', 'http://timg.bdta.pro/images/2af7dc368ab9a79523f2ac20c2e58d54.jpg'),
(111580, 7950, 'The Good Doctor: O Bom Doutor [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225126.mp4', 'http://timg.bdta.pro/images/ea43fb77f33950865657ae5e39382015.jpg'),
(111581, 7950, 'The Good Doctor: O Bom Doutor [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225127.mp4', 'http://timg.bdta.pro/images/966718c9515a4cf7bb64197e137c762a.jpg'),
(111582, 7950, 'The Good Doctor: O Bom Doutor [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225128.mp4', 'http://timg.bdta.pro/images/d0aee0e747f1412e3d516a8973261875.jpg'),
(111583, 7950, 'The Good Doctor: O Bom Doutor [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225129.mp4', 'http://timg.bdta.pro/images/fada14d3b5562b0e35c294d4f2ca7368.jpg'),
(111584, 7950, 'The Good Doctor: O Bom Doutor [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225130.mp4', 'http://timg.bdta.pro/images/8930504f459676791c29df4aaa6d9b31.jpg'),
(111585, 7950, 'The Good Doctor: O Bom Doutor [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225131.mp4', 'http://timg.bdta.pro/images/dc155495a7975a8ee7aa215d1f836950.jpg'),
(111586, 7950, 'The Good Doctor: O Bom Doutor [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225132.mp4', 'http://timg.bdta.pro/images/6f34966ed725649b649f4869086964c5.jpg'),
(111587, 7950, 'The Good Doctor: O Bom Doutor [L] S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/225133.mp4', 'http://timg.bdta.pro/images/cd6177292224b177cf6ec78aab349c19.jpg'),
(111588, 7950, 'The Good Doctor: O Bom Doutor [L] S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/225134.mp4', 'http://timg.bdta.pro/images/735d011fd852b4ae6958a3c138c04773.jpg'),
(111589, 7950, 'The Good Doctor: O Bom Doutor [L] S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/225135.mp4', 'http://timg.bdta.pro/images/0309e8e2508175813f597334bb4089e0.jpg'),
(111590, 7950, 'The Good Doctor: O Bom Doutor [L] S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/225136.mp4', 'http://timg.bdta.pro/images/b93ee49ecfec660cefac95a55ae37365.jpg'),
(111591, 7950, 'The Good Doctor: O Bom Doutor [L] S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/225137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wSXFfKqM00CZFpBVrADDU2tEMef.jpg'),
(111592, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jiwfFwM6DyEGMsq86n6WotqEML3.jpg'),
(111593, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tVtGgTvlpk0uOBFU3zpSdtFjn6Q.jpg'),
(111594, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/roCnOVshIkgrOdpJpk7FX2wPyDa.jpg'),
(111595, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8AIjk2dNEOOOfpRxvVsC8smg0Ev.jpg'),
(111596, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xAdcwwUGBMLSDK7AmNYbCq7vDQR.jpg'),
(111597, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pEBWrz8eMp0SZeO96z1hl7WVkyP.jpg'),
(111598, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x8oyBQ0Sfbo7jeaQQDYGqtjApOJ.jpg'),
(111599, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bnDUPqjGoyzFoJZyGfX95TcdDWp.jpg'),
(111600, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/92Aw0sMgAj5XZX4vk31DoZDncog.jpg'),
(111601, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9P8zlBNkQ4oERto8PsZnMnGz84a.jpg'),
(111602, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/225148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qAomSd7S1zBH1kWwVbL94C6gDGM.jpg'),
(111603, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/225149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c89TFgf83HSraviE9YbmZvtjmN8.jpg'),
(111604, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/225150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tuvIcoj0DJuCa2kerep7xI2sOZG.jpg'),
(111605, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/225151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ju3zBjl7LlD90Folv3x5TOpufvX.jpg'),
(111606, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/225152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rYntD3a03AaxMqZTCr5Mcp8VcHw.jpg'),
(111607, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/225153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pA7MkVTnrNK0XJaNKBsXKm2kJ6B.jpg'),
(111608, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/225154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gc5JpYJkn4fYdExZ2OY9dUi79e5.jpg'),
(111609, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/225155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Iiby3IdZOKdzhRgIqvOUHeyaOT.jpg'),
(111610, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/225156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kRGCgXsdUnPn8SKJWzRsBdchjHZ.jpg'),
(111611, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/225157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1M5FZrfir7fJsAqt3wi3sCTDGw.jpg'),
(111612, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/225158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qkLddujNxwsxYz9chhnU7mqWFGZ.jpg'),
(111613, 7951, 'The Good Doctor: O Bom Doutor [L] S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/225159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kFG84C5AmvenUzkL2pX6m0lh3Ke.jpg'),
(111614, 7952, 'The Good Doctor: O Bom Doutor [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/295095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9WYk0nigzR9NAEjeSmfI6s4XA2.jpg'),
(111615, 7952, 'The Good Doctor: O Bom Doutor [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/295096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9WYk0nigzR9NAEjeSmfI6s4XA2.jpg'),
(111616, 7952, 'The Good Doctor: O Bom Doutor [L] S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/317114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9WYk0nigzR9NAEjeSmfI6s4XA2.jpg'),
(111617, 7952, 'The Good Doctor: O Bom Doutor [L] S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/317115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9WYk0nigzR9NAEjeSmfI6s4XA2.jpg'),
(111618, 7952, 'The Good Doctor: O Bom Doutor [L] S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/321108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9WYk0nigzR9NAEjeSmfI6s4XA2.jpg'),
(111619, 7952, 'The Good Doctor: O Bom Doutor [L] S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/327492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9WYk0nigzR9NAEjeSmfI6s4XA2.jpg'),
(111620, 7952, 'The Good Doctor: O Bom Doutor [L] S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/342961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9WYk0nigzR9NAEjeSmfI6s4XA2.jpg'),
(111621, 7952, 'The Good Doctor: O Bom Doutor [L] S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/351216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9WYk0nigzR9NAEjeSmfI6s4XA2.jpg'),
(111622, 7952, 'The Good Doctor: O Bom Doutor [L] S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/358536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9WYk0nigzR9NAEjeSmfI6s4XA2.jpg'),
(111623, 7952, 'The Good Doctor: O Bom Doutor [L] S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/358537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9WYk0nigzR9NAEjeSmfI6s4XA2.jpg'),
(111624, 7953, 'The Jellies S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7nFwzy6h1WOhEkETWRwqV4Pei75.jpg'),
(111625, 7953, 'The Jellies S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u0Z3elejXEAkyVNzZrCJ7OdC77A.jpg'),
(111626, 7953, 'The Jellies S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iZqzRzZR32zLcJ47JGr0ufCoiP3.jpg'),
(111627, 7953, 'The Jellies S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kir6YFP7NEJRhFkjsQtSmwyVZre.jpg'),
(111628, 7953, 'The Jellies S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2BFWdjtMhVzVUCSRvYvrTOAtf5V.jpg'),
(111629, 7953, 'The Jellies S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ythUo3VgY4umPMxsMaIlIUx8WJ5.jpg'),
(111630, 7953, 'The Jellies S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bOBWT8HeHS2L5Pg9EoguDd9Te48.jpg'),
(111631, 7953, 'The Jellies S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kAYTV6gqIRMttpDuTnPORU5yHmk.jpg'),
(111632, 7953, 'The Jellies S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/clBYBIAd2n1hbLoCliZMkeGs0KR.jpg'),
(111633, 7953, 'The Jellies S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WqtVGBtV1WzxVMTANZVRuvjm5r.jpg'),
(111634, 7954, 'The Jellies S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m20IMkJEXGwywh4I2CGsvZKFrCv.jpg'),
(111635, 7954, 'The Jellies S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tkURBNNR0oodJWU2Ibrm2dlP8IT.jpg'),
(111636, 7954, 'The Jellies S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9kH75uZWvdw3zNUmsVKmFQZKYYy.jpg'),
(111637, 7954, 'The Jellies S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mQhxMgpndW17JMXplWCWLFsip5w.jpg'),
(111638, 7954, 'The Jellies S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wLUv7Lb4r6qxjFVMx2bQ9NlMHzs.jpg'),
(111639, 7954, 'The Jellies S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCUwxSSveKzR2pqK2pgcgHfb0an.jpg'),
(111640, 7954, 'The Jellies S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/erxv25cOmaiaJ2gRap8jMHrTMuO.jpg'),
(111641, 7954, 'The Jellies S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r0lgUD1PgGDlukJ6lRtXpSlmoPk.jpg'),
(111642, 7954, 'The Jellies S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/225042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xp6bC6jT9uvPuoyUQEOejXeJxpV.jpg'),
(111643, 7954, 'The Jellies S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/225043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oXsoUbMEK1VinT9m9BgXmdY1Dwh.jpg'),
(111644, 7955, 'The King Who Never Was [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5yg4EKHbfl3C9bETEai0mHGG5hN.jpg'),
(111645, 7955, 'The King Who Never Was [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nvUmfDS9ytqlYMBMIdyf5moQkVV.jpg'),
(111646, 7955, 'The King Who Never Was [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5sms6M32of7bKTqRr5PC87vNYPP.jpg'),
(111647, 7956, 'The Shivering Truth [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tdIFfr7PPvCu9GhNPEz7GpRLrzZ.jpg'),
(111648, 7956, 'The Shivering Truth [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1qiMrj2z6RW4U6pVgvQ0PK2kEER.jpg'),
(111649, 7956, 'The Shivering Truth [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s1Ybr6RZ0kiSj7DZYNWNuhklvsY.jpg'),
(111650, 7956, 'The Shivering Truth [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yCcxTWSvB6XclQicXLpRSn0DtEv.jpg'),
(111651, 7956, 'The Shivering Truth [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mKU8cH96nTM2tyx5n6Z3rQe1t4Y.jpg'),
(111652, 7956, 'The Shivering Truth [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m36Sns1SQrTCwZ7wy7o7UeoyPkT.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(111653, 7956, 'The Shivering Truth [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/41r0yzrZOrnL1U8v5I19F0hXWlF.jpg'),
(111654, 7957, 'The Shivering Truth [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aHWDPHooA1c7fwe6mKYimbeNqtZ.jpg'),
(111655, 7957, 'The Shivering Truth [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ldylf0SkvWGX8KrqU2tXX7appQJ.jpg'),
(111656, 7957, 'The Shivering Truth [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tuXakxEXRoTh1znV0jK1XV1y2OE.jpg'),
(111657, 7957, 'The Shivering Truth [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8J85GZl5CRqPMIMcN9Wi2w8FiKK.jpg'),
(111658, 7957, 'The Shivering Truth [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y0gqwvwWzxL9EYnRaFqE7mqPwDb.jpg'),
(111659, 7957, 'The Shivering Truth [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yeGycPndIVArrvE2YXgTkoHVKjI.jpg'),
(111660, 7958, 'Trom [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/225002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/80dRlKRqLuHD8hAQgCe1XOVJJeU.jpg'),
(111661, 7958, 'Trom [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/225003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzTgplKA87i6BKwIU6ufngrkeks.jpg'),
(111662, 7958, 'Trom [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/225004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fsq4eQA7qbvFEhIyATB1TZTsKEr.jpg'),
(111663, 7958, 'Trom [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/225005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/76SAD3gsWwy1OzGb48dKAZpXyNE.jpg'),
(111664, 7958, 'Trom [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/225006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nkagxke0bgqFiBqE6wL1HHXOyzy.jpg'),
(111665, 7958, 'Trom [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/225007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1eKq33sTZap60UyRRa4PVvuzUBk.jpg'),
(111666, 7958, 'Trom [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/892558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bj4aUYJtFJaD2PvLjdzMd88xmbb.jpg'),
(111667, 7958, 'Trom [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/892559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bj4aUYJtFJaD2PvLjdzMd88xmbb.jpg'),
(111668, 7958, 'Trom [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/892560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bj4aUYJtFJaD2PvLjdzMd88xmbb.jpg'),
(111669, 7958, 'Trom [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/892561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bj4aUYJtFJaD2PvLjdzMd88xmbb.jpg'),
(111670, 7959, 'Ultraman Blazar [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6C9JG2MnRfyTpuV5PNriVFFAkwg.jpg'),
(111671, 7959, 'Ultraman Blazar [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ztzueaJLodv21lWKnSYiOkboiaq.jpg'),
(111672, 7959, 'Ultraman Blazar [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jkphDlSegus8o3lJQtTFYyEqY8Q.jpg'),
(111673, 7959, 'Ultraman Blazar [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241815.mp4', 'http://image.tmdb.org/t/p/w1280/2vKitxmPpa8cH34acIuTbRvHtLT.jpg'),
(111674, 7959, 'Ultraman Blazar [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2y2NqFToJffmwxM3W6aLDiro82P.jpg'),
(111675, 7959, 'Ultraman Blazar [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2y2NqFToJffmwxM3W6aLDiro82P.jpg'),
(111676, 7959, 'Ultraman Blazar [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2y2NqFToJffmwxM3W6aLDiro82P.jpg'),
(111677, 7959, 'Ultraman Blazar [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2y2NqFToJffmwxM3W6aLDiro82P.jpg'),
(111678, 7959, 'Ultraman Blazar [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2y2NqFToJffmwxM3W6aLDiro82P.jpg'),
(111679, 7959, 'Ultraman Blazar [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2y2NqFToJffmwxM3W6aLDiro82P.jpg'),
(111680, 7959, 'Ultraman Blazar [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2y2NqFToJffmwxM3W6aLDiro82P.jpg'),
(111681, 7959, 'Ultraman Blazar [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2y2NqFToJffmwxM3W6aLDiro82P.jpg'),
(111682, 7959, 'Ultraman Blazar [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2y2NqFToJffmwxM3W6aLDiro82P.jpg'),
(111683, 7959, 'Ultraman Blazar [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2y2NqFToJffmwxM3W6aLDiro82P.jpg'),
(111684, 7959, 'Ultraman Blazar [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2y2NqFToJffmwxM3W6aLDiro82P.jpg'),
(111685, 7959, 'Ultraman Blazar [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/883995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2y2NqFToJffmwxM3W6aLDiro82P.jpg'),
(111686, 7959, 'Ultraman Blazar [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/883996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2y2NqFToJffmwxM3W6aLDiro82P.jpg'),
(111687, 7959, 'Ultraman Blazar [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/883997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2y2NqFToJffmwxM3W6aLDiro82P.jpg'),
(111688, 7959, 'Ultraman Blazar [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/883998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2y2NqFToJffmwxM3W6aLDiro82P.jpg'),
(111689, 7959, 'Ultraman Blazar [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/883999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2y2NqFToJffmwxM3W6aLDiro82P.jpg'),
(111690, 7959, 'Ultraman Blazar [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/884000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2y2NqFToJffmwxM3W6aLDiro82P.jpg'),
(111691, 7959, 'Ultraman Blazar [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/884001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2y2NqFToJffmwxM3W6aLDiro82P.jpg'),
(111692, 7959, 'Ultraman Blazar [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/884002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2y2NqFToJffmwxM3W6aLDiro82P.jpg'),
(111693, 7959, 'Ultraman Blazar [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/884003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2y2NqFToJffmwxM3W6aLDiro82P.jpg'),
(111694, 7959, 'Ultraman Blazar [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/884004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2y2NqFToJffmwxM3W6aLDiro82P.jpg'),
(111695, 7960, 'Undead Girl Murder Farce [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nK2p82SzGh7H83dS5ww89U3zpjO.jpg'),
(111696, 7960, 'Undead Girl Murder Farce [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uxJbaklCILLBu7l1icE2rZ1qa4c.jpg'),
(111697, 7960, 'Undead Girl Murder Farce [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/60BTebVo8vr96yv3PW6yaIv0Qv.jpg'),
(111698, 7960, 'Undead Girl Murder Farce [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z5hjwDZ0ZxIZfsm2e3xHl54SK3H.jpg'),
(111699, 7960, 'Undead Girl Murder Farce [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237502.mp4', 'http://image.tmdb.org/t/p/w1280/4wqrxUVmkv8H26nEtOCXhN3UK1G.jpg'),
(111700, 7960, 'Undead Girl Murder Farce [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237503.mp4', 'http://image.tmdb.org/t/p/w1280/c2hg7web8RKOc1ngI0GGcid0h1g.jpg'),
(111701, 7960, 'Undead Girl Murder Farce [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mDLMFBx6h6y2hBLmyfyMKLCgTeb.jpg'),
(111702, 7960, 'Undead Girl Murder Farce [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mDLMFBx6h6y2hBLmyfyMKLCgTeb.jpg'),
(111703, 7960, 'Undead Girl Murder Farce [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mDLMFBx6h6y2hBLmyfyMKLCgTeb.jpg'),
(111704, 7960, 'Undead Girl Murder Farce [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mDLMFBx6h6y2hBLmyfyMKLCgTeb.jpg'),
(111705, 7960, 'Undead Girl Murder Farce [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mDLMFBx6h6y2hBLmyfyMKLCgTeb.jpg'),
(111706, 7960, 'Undead Girl Murder Farce [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mDLMFBx6h6y2hBLmyfyMKLCgTeb.jpg'),
(111707, 7960, 'Undead Girl Murder Farce [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mDLMFBx6h6y2hBLmyfyMKLCgTeb.jpg'),
(111708, 7961, 'Vida Perfeita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ng5Lkgs9U8sbELCrH5dQZf7AJY5.jpg'),
(111709, 7961, 'Vida Perfeita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5lPvl0Jazg1eI09HAUrGV6euTBM.jpg'),
(111710, 7961, 'Vida Perfeita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ABMaKrnuE3Fq2mOS25pvZ8He2h.jpg'),
(111711, 7961, 'Vida Perfeita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4OKdukj7iZdIECqqnodws3fZiUp.jpg'),
(111712, 7961, 'Vida Perfeita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/khKzbGGwzNT6Y1PQgFNFws635K4.jpg'),
(111713, 7961, 'Vida Perfeita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3zxtje3Fm8fKvRKTs1aQO5SI8PQ.jpg'),
(111714, 7961, 'Vida Perfeita S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/225000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fkJp7snsaWecy41tekYsPHUfjLI.jpg'),
(111715, 7961, 'Vida Perfeita S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/225001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8AGEy2jTAwC0A6nIZ7n20kjvH5y.jpg'),
(111716, 7962, 'YOLO S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/unzSqcfAqb0036dKiSMa5fMQANi.jpg'),
(111717, 7962, 'YOLO S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wAAgHa0PkJNxCQhwlcTJ1kxdQRF.jpg'),
(111718, 7962, 'YOLO S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7l8xIYt4EpUBdbCG98aVL5tDTdw.jpg'),
(111719, 7962, 'YOLO S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gjt8zuOopBYBiDngr0oEMqty3Og.jpg'),
(111720, 7962, 'YOLO S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w438J2MB2B7a4x7e3pZFASehAe1.jpg'),
(111721, 7963, 'YOLO S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8R9zJPBVzo85QGcsPor7Wxx6OVO.jpg'),
(111722, 7963, 'YOLO S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6dgC2HDlCr2n0x3FLAVs6gQlgvW.jpg'),
(111723, 7963, 'YOLO S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8H5Ndz94unTA8ZAIP2KmOVtsYgk.jpg'),
(111724, 7963, 'YOLO S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zN4vfxWmznkvEgt3WJ6FqI2Ctdp.jpg'),
(111725, 7963, 'YOLO S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qxXdbxt0eecFuJJ8d7EabkGJ9Cc.jpg'),
(111726, 7963, 'YOLO S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/erg7U0zUgrp5BPy8yrkgroWpSUY.jpg'),
(111727, 7963, 'YOLO S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wfW1lGCPRVnjReHFbjUg0r7uYUO.jpg'),
(111728, 7963, 'YOLO S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gisy9oHPmt6iLFOEpGP2uPAkvit.jpg'),
(111729, 7964, 'YOLO S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/720627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zjVOFnXzo5GDP2LFSHK3umrxXn8.jpg'),
(111730, 7964, 'YOLO S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/733247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zjVOFnXzo5GDP2LFSHK3umrxXn8.jpg'),
(111731, 7964, 'YOLO S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/736492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zjVOFnXzo5GDP2LFSHK3umrxXn8.jpg'),
(111732, 7964, 'YOLO S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/749922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zjVOFnXzo5GDP2LFSHK3umrxXn8.jpg'),
(111733, 7964, 'YOLO S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/757670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zjVOFnXzo5GDP2LFSHK3umrxXn8.jpg'),
(111734, 7964, 'YOLO S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/777077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zjVOFnXzo5GDP2LFSHK3umrxXn8.jpg'),
(111735, 7964, 'YOLO S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/778319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zjVOFnXzo5GDP2LFSHK3umrxXn8.jpg'),
(111736, 7964, 'YOLO S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/783603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zjVOFnXzo5GDP2LFSHK3umrxXn8.jpg'),
(111737, 7965, 'Avareza e o Culto de Gwen Shamblin [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ow7LRxn9ZQBM6XHsRMdYHVkXw5H.jpg'),
(111738, 7965, 'Avareza e o Culto de Gwen Shamblin [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5NlcataVJ7tK9iYbRi1e5MRty9o.jpg'),
(111739, 7965, 'Avareza e o Culto de Gwen Shamblin [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6QglNcGvz0QzPlgXI7ZFLYDhFeB.jpg'),
(111740, 7965, 'Avareza e o Culto de Gwen Shamblin [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d031AV9butXr3UQz5JrWUDlqnTH.jpg'),
(111741, 7965, 'Avareza e o Culto de Gwen Shamblin [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A5f1zPubpddRthH9NOlcfH8JKut.jpg'),
(111742, 7966, 'A Revolucao das Spice Girls [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/SrsOiUEGjoL7djJKJ2P202MYdr.jpg'),
(111743, 7966, 'A Revolucao das Spice Girls [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f5bSR6bwv66DAoqWorTb7IudU00.jpg'),
(111744, 7966, 'A Revolucao das Spice Girls [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8bsB2pN5gbhyHfexrdOWJEKB0q.jpg'),
(111745, 7967, 'A Última Rodada: Um Assassino Serial na NY Queer [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xFxAwoKqImc9kfgd7FFNjeSmvxU.jpg'),
(111746, 7967, 'A Última Rodada: Um Assassino Serial na NY Queer [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9RQaVhsMSaUpouCnAAoitu5YSYY.jpg'),
(111747, 7967, 'A Última Rodada: Um Assassino Serial na NY Queer [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZnQvV9Ao4Z52cVJp7MYszv5J4P.jpg'),
(111748, 7967, 'A Última Rodada: Um Assassino Serial na NY Queer [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jhiP7G3F2VbN3ck2m7XSTaI8v8R.jpg'),
(111749, 7968, 'A World of Calm [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8RlWgkQvLLvKIHALZEKXO0rMDh3.jpg'),
(111750, 7968, 'A World of Calm [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bAh5JlHpvXOTOpaLSSXycyoTKAV.jpg'),
(111751, 7968, 'A World of Calm [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/upsRyhj8FMhPJ5c9U515lp0H1dr.jpg'),
(111752, 7968, 'A World of Calm [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sNABGPbLYOyfWa1cknYCjzsrPbI.jpg'),
(111753, 7968, 'A World of Calm [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/244RWKrHqbGI1cJ5RMsuwAZqRMU.jpg'),
(111754, 7968, 'A World of Calm [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c0IQZHw0KEvgF7UItUYNdkyAUi9.jpg'),
(111755, 7968, 'A World of Calm [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUmgxR8Mes13nddbNPTZTqfEndg.jpg'),
(111756, 7968, 'A World of Calm [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/21STifilm4fx35HJPmLc9guIorc.jpg'),
(111757, 7968, 'A World of Calm [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uHeFKwSbsu4XWv9jNGShwx2tu6g.jpg'),
(111758, 7968, 'A World of Calm [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4gHoMF9iodAjub92FcjYVF5U2Tz.jpg'),
(111759, 7969, 'Abominável e a Cidade Escondida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6nbWxjFYUtgcHTONJxOdifREupk.jpg'),
(111760, 7969, 'Abominável e a Cidade Escondida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jSflAscdYKCjJgKtNxvk1vHNJjL.jpg'),
(111761, 7969, 'Abominável e a Cidade Escondida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ltqf9fDRdSg9Cc6D3LPDXlupuiC.jpg'),
(111762, 7969, 'Abominável e a Cidade Escondida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jRHjPptIAFiMNUwV7INzGtmxqWl.jpg'),
(111763, 7969, 'Abominável e a Cidade Escondida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9vJ8azPod6xLWrVL5W3ahJa8Lr0.jpg'),
(111764, 7969, 'Abominável e a Cidade Escondida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5upkU8zdmBlbg22ElEq6eo4Vtq6.jpg'),
(111765, 7970, 'Amor Oculto [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7gvGYFee669XjX4lwsCIKbZB83Z.jpg'),
(111766, 7970, 'Amor Oculto [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/meMxlvBklKwMLbsXNI4pqtocsRU.jpg'),
(111767, 7970, 'Amor Oculto [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yF3GwtWJN8rqCrkDcuMjdR7Wcp8.jpg'),
(111768, 7970, 'Amor Oculto [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3xiDJIIYw1T48Epk7K87s1e9NA.jpg'),
(111769, 7970, 'Amor Oculto [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rLDNLNR3zy7hOccAtOQ02Kwc9xD.jpg'),
(111770, 7970, 'Amor Oculto [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3aipSA7lnGaHUvTtZl8r9BYdT6y.jpg'),
(111771, 7970, 'Amor Oculto [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ya03dzxoldH85mCzDnLYLxY20l9.jpg'),
(111772, 7970, 'Amor Oculto [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zfQpNrqS57rkCCKgqYkkL5ghmln.jpg'),
(111773, 7970, 'Amor Oculto [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zUl4ELgk5HqFm2rdriGcAKUsUKh.jpg'),
(111774, 7970, 'Amor Oculto [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uLx54JUaO7Gv3ap2GcqMCkVqX4E.jpg'),
(111775, 7970, 'Amor Oculto [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/adyF9bxDSb2IWQIhqtpQnZjgqw4.jpg'),
(111776, 7970, 'Amor Oculto [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aPiNY6SoRsYuo9WPI2XIDvKSnIn.jpg'),
(111777, 7970, 'Amor Oculto [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/maQX8wIJSs4wXJ0LZh0GsmrfEOk.jpg'),
(111778, 7970, 'Amor Oculto [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMlFZPe0iTLZYzStON06iajP0Np.jpg'),
(111779, 7970, 'Amor Oculto [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rHrOIy7Dh1dMh1phL6iw5DDK64U.jpg'),
(111780, 7970, 'Amor Oculto [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4hel83fIMGBqXnUOAKZp2ofnQ8W.jpg'),
(111781, 7970, 'Amor Oculto [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7MBigpu0AT6ek7HINxlq41RZLVR.jpg'),
(111782, 7970, 'Amor Oculto [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cGfbWRm7WZSiKFL2QkRrxlUbqAX.jpg'),
(111783, 7970, 'Amor Oculto [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xgue1yE91tBCt7hfrJl3Z6AgLdw.jpg'),
(111784, 7970, 'Amor Oculto [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9amMJ5EKXCbAStlZ8AjHK8OTvWV.jpg'),
(111785, 7970, 'Amor Oculto [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7WrFhjS08FOMQoNvK5er7X1PKfl.jpg'),
(111786, 7970, 'Amor Oculto [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jmylO6u0Jx1DJy3UiOXgnTpfEae.jpg'),
(111787, 7970, 'Amor Oculto [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/224894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/44KXc52hEkAzyt7t69anbYVfuKI.jpg'),
(111788, 7970, 'Amor Oculto [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/224895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gu3gqFUQk9VZn4IdVg1tKZ4w4T7.jpg'),
(111789, 7970, 'Amor Oculto [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/224896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kUaDPqP6KNPvACFWrM5eggApqdY.jpg'),
(111790, 7971, 'Dark Winds [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ksg3x4uJPuqpZRvYYMqSzfkPLSC.jpg'),
(111791, 7971, 'Dark Winds [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cHcK8FrS6Oenh9H0foVYcsJvyC6.jpg'),
(111792, 7971, 'Dark Winds [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ykBwRKdu76vFYd2r9TZ1pp75dGx.jpg'),
(111793, 7971, 'Dark Winds [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iNEBD1984pFgGR3A7TfjDKLlNyF.jpg'),
(111794, 7971, 'Dark Winds [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yg1gaKE9CROYCbSlGA2rKoQ4ITL.jpg'),
(111795, 7971, 'Dark Winds [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qvwXg9B0v9f9PbnvNmTihIAr8be.jpg'),
(111796, 7972, 'Dark Winds [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iGBzIavW3dzhMezIQLQI5hOPWRL.jpg'),
(111797, 7972, 'Dark Winds [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232015.mp4', 'http://image.tmdb.org/t/p/w1280/spqpPbiVueiUeNNkPuhlWZQFQv3.jpg'),
(111798, 7972, 'Dark Winds [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232016.mp4', 'http://image.tmdb.org/t/p/w1280/8EOyhG9OkXetJ0aDltk7RlwpzOD.jpg'),
(111799, 7972, 'Dark Winds [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232017.mp4', 'http://image.tmdb.org/t/p/w1280/kcFOXKYOq9cVtRT00VGQmKHR9FM.jpg'),
(111800, 7972, 'Dark Winds [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232018.mp4', 'http://image.tmdb.org/t/p/w1280/Ap4x2gbtFDpZ5Xn1I4Ty1mrxK9t.jpg'),
(111801, 7972, 'Dark Winds [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232019.mp4', 'http://image.tmdb.org/t/p/w1280/isVKxz2yIkRp7YCqo1RLG4v9noQ.jpg'),
(111802, 7973, 'Dark Winds [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/890977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yXqengcZnjoWJlns0Guv9Svg7nv.jpg'),
(111803, 7973, 'Dark Winds [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/890978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yXqengcZnjoWJlns0Guv9Svg7nv.jpg'),
(111804, 7973, 'Dark Winds [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/890979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yXqengcZnjoWJlns0Guv9Svg7nv.jpg'),
(111805, 7973, 'Dark Winds [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/890980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yXqengcZnjoWJlns0Guv9Svg7nv.jpg'),
(111806, 7973, 'Dark Winds [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/890981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yXqengcZnjoWJlns0Guv9Svg7nv.jpg'),
(111807, 7973, 'Dark Winds [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/890982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yXqengcZnjoWJlns0Guv9Svg7nv.jpg'),
(111808, 7973, 'Dark Winds [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/890983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yXqengcZnjoWJlns0Guv9Svg7nv.jpg'),
(111809, 7973, 'Dark Winds [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/890984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yXqengcZnjoWJlns0Guv9Svg7nv.jpg'),
(111810, 7974, 'Hercai: Amor e Vingança S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cu9HrG41OMfz2t5kxilLBNp6ZA3.jpg'),
(111811, 7974, 'Hercai: Amor e Vingança S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x10KvnmXH17D9ucTabCTV1VFZE7.jpg'),
(111812, 7974, 'Hercai: Amor e Vingança S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1BHCrVNQDwV5nBCN1iTsRMQiRIK.jpg'),
(111813, 7974, 'Hercai: Amor e Vingança S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fc71NYPrmQZ3wtzCpPR82MLj2Hr.jpg'),
(111814, 7974, 'Hercai: Amor e Vingança S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5GuUIQQ7ubZzyeFV3ymPnSDciOK.jpg'),
(111815, 7974, 'Hercai: Amor e Vingança S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u0eI1dHXdfBM1XTjxfE7E778gq8.jpg'),
(111816, 7974, 'Hercai: Amor e Vingança S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ynjNMWzlV08zPz83jmSkNGTCwbc.jpg'),
(111817, 7974, 'Hercai: Amor e Vingança S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/601332.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i5y5kMuVa6x8ocVaGSwOnXKSSGi.jpg'),
(111818, 7974, 'Hercai: Amor e Vingança S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231374.mp4', 'http://image.tmdb.org/t/p/w1280/AeND4ECfZ4WvrtGWNgwR1Qufpk6.jpg'),
(111819, 7974, 'Hercai: Amor e Vingança S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231375.mp4', 'http://image.tmdb.org/t/p/w1280/nDP7ajSrK4aYUm2kTPiYnaVwLJa.jpg'),
(111820, 7974, 'Hercai: Amor e Vingança S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/231376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kIT1ubW36EKPdkhK1QP14GJ7Y5K.jpg'),
(111821, 7974, 'Hercai: Amor e Vingança S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/231377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fHD1ZNnHSc8JIzOomJ5XPnsyCuT.jpg'),
(111822, 7974, 'Hercai: Amor e Vingança S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/231378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111823, 7974, 'Hercai: Amor e Vingança S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/231379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111824, 7974, 'Hercai: Amor e Vingança S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/231380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111825, 7974, 'Hercai: Amor e Vingança S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/231381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111826, 7974, 'Hercai: Amor e Vingança S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/231382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111827, 7974, 'Hercai: Amor e Vingança S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/231383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111828, 7974, 'Hercai: Amor e Vingança S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/231384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111829, 7974, 'Hercai: Amor e Vingança S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/231385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111830, 7974, 'Hercai: Amor e Vingança S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/231386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111831, 7974, 'Hercai: Amor e Vingança S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/231387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111832, 7974, 'Hercai: Amor e Vingança S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/231388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111833, 7974, 'Hercai: Amor e Vingança S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/231389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111834, 7974, 'Hercai: Amor e Vingança S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/231390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111835, 7974, 'Hercai: Amor e Vingança S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/231391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111836, 7974, 'Hercai: Amor e Vingança S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/231392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111837, 7974, 'Hercai: Amor e Vingança S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/231393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111838, 7974, 'Hercai: Amor e Vingança S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/231394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111839, 7974, 'Hercai: Amor e Vingança S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/231395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111840, 7974, 'Hercai: Amor e Vingança S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/231396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111841, 7974, 'Hercai: Amor e Vingança S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/231397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111842, 7974, 'Hercai: Amor e Vingança S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/231398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111843, 7974, 'Hercai: Amor e Vingança S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/231399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111844, 7974, 'Hercai: Amor e Vingança S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/231400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111845, 7974, 'Hercai: Amor e Vingança S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/231401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111846, 7974, 'Hercai: Amor e Vingança S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/231402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111847, 7974, 'Hercai: Amor e Vingança S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/231403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111848, 7974, 'Hercai: Amor e Vingança S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/231404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111849, 7974, 'Hercai: Amor e Vingança S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/231405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111850, 7974, 'Hercai: Amor e Vingança S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/231406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111851, 7974, 'Hercai: Amor e Vingança S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/231407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111852, 7974, 'Hercai: Amor e Vingança S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/231408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111853, 7975, 'Hercai: Amor e Vingança S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/317661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111854, 7975, 'Hercai: Amor e Vingança S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/317662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111855, 7975, 'Hercai: Amor e Vingança S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/317663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111856, 7975, 'Hercai: Amor e Vingança S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/317664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111857, 7975, 'Hercai: Amor e Vingança S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/317665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111858, 7975, 'Hercai: Amor e Vingança S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/317666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111859, 7975, 'Hercai: Amor e Vingança S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/317667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111860, 7975, 'Hercai: Amor e Vingança S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/317668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111861, 7975, 'Hercai: Amor e Vingança S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/317669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111862, 7975, 'Hercai: Amor e Vingança S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/317670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111863, 7975, 'Hercai: Amor e Vingança S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/317671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111864, 7975, 'Hercai: Amor e Vingança S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/317672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111865, 7975, 'Hercai: Amor e Vingança S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/317673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111866, 7975, 'Hercai: Amor e Vingança S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/317674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111867, 7975, 'Hercai: Amor e Vingança S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/317675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111868, 7975, 'Hercai: Amor e Vingança S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/323969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111869, 7975, 'Hercai: Amor e Vingança S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/323970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111870, 7975, 'Hercai: Amor e Vingança S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/323971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111871, 7975, 'Hercai: Amor e Vingança S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/323972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111872, 7975, 'Hercai: Amor e Vingança S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/323973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111873, 7975, 'Hercai: Amor e Vingança S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/323974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111874, 7975, 'Hercai: Amor e Vingança S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/323975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111875, 7975, 'Hercai: Amor e Vingança S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/323976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111876, 7975, 'Hercai: Amor e Vingança S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/323977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111877, 7975, 'Hercai: Amor e Vingança S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/323978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111878, 7975, 'Hercai: Amor e Vingança S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/323979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111879, 7975, 'Hercai: Amor e Vingança S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/323980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111880, 7975, 'Hercai: Amor e Vingança S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/323981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111881, 7975, 'Hercai: Amor e Vingança S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/323982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111882, 7975, 'Hercai: Amor e Vingança S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/323983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111883, 7975, 'Hercai: Amor e Vingança S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/327840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111884, 7975, 'Hercai: Amor e Vingança S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/327841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111885, 7975, 'Hercai: Amor e Vingança S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/327842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111886, 7975, 'Hercai: Amor e Vingança S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/327843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111887, 7975, 'Hercai: Amor e Vingança S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/327844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111888, 7975, 'Hercai: Amor e Vingança S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/327845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111889, 7975, 'Hercai: Amor e Vingança S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/327846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111890, 7975, 'Hercai: Amor e Vingança S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/327847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111891, 7975, 'Hercai: Amor e Vingança S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/327848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111892, 7975, 'Hercai: Amor e Vingança S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/327849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111893, 7975, 'Hercai: Amor e Vingança S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/327850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111894, 7975, 'Hercai: Amor e Vingança S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/327851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111895, 7975, 'Hercai: Amor e Vingança S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/327852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111896, 7975, 'Hercai: Amor e Vingança S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/327853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111897, 7975, 'Hercai: Amor e Vingança S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/327854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111898, 7975, 'Hercai: Amor e Vingança S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/332718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111899, 7975, 'Hercai: Amor e Vingança S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/332719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111900, 7975, 'Hercai: Amor e Vingança S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/332720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111901, 7975, 'Hercai: Amor e Vingança S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/332721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111902, 7975, 'Hercai: Amor e Vingança S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/332722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111903, 7975, 'Hercai: Amor e Vingança S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/332723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111904, 7975, 'Hercai: Amor e Vingança S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/332724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111905, 7975, 'Hercai: Amor e Vingança S02 E53', 'http://sinalprivado.info:80/series/1533784/1533784/332725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111906, 7975, 'Hercai: Amor e Vingança S02 E54', 'http://sinalprivado.info:80/series/1533784/1533784/332726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111907, 7975, 'Hercai: Amor e Vingança S02 E55', 'http://sinalprivado.info:80/series/1533784/1533784/332727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111908, 7975, 'Hercai: Amor e Vingança S02 E56', 'http://sinalprivado.info:80/series/1533784/1533784/332728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111909, 7975, 'Hercai: Amor e Vingança S02 E57', 'http://sinalprivado.info:80/series/1533784/1533784/332729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111910, 7975, 'Hercai: Amor e Vingança S02 E58', 'http://sinalprivado.info:80/series/1533784/1533784/332730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(111911, 7975, 'Hercai: Amor e Vingança S02 E59', 'http://sinalprivado.info:80/series/1533784/1533784/332731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111912, 7975, 'Hercai: Amor e Vingança S02 E60', 'http://sinalprivado.info:80/series/1533784/1533784/332732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111913, 7975, 'Hercai: Amor e Vingança S02 E61', 'http://sinalprivado.info:80/series/1533784/1533784/341029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111914, 7975, 'Hercai: Amor e Vingança S02 E62', 'http://sinalprivado.info:80/series/1533784/1533784/341030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111915, 7975, 'Hercai: Amor e Vingança S02 E63', 'http://sinalprivado.info:80/series/1533784/1533784/341031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111916, 7975, 'Hercai: Amor e Vingança S02 E64', 'http://sinalprivado.info:80/series/1533784/1533784/341032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111917, 7975, 'Hercai: Amor e Vingança S02 E65', 'http://sinalprivado.info:80/series/1533784/1533784/341033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111918, 7975, 'Hercai: Amor e Vingança S02 E66', 'http://sinalprivado.info:80/series/1533784/1533784/341034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111919, 7975, 'Hercai: Amor e Vingança S02 E67', 'http://sinalprivado.info:80/series/1533784/1533784/341035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111920, 7975, 'Hercai: Amor e Vingança S02 E68', 'http://sinalprivado.info:80/series/1533784/1533784/341036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111921, 7975, 'Hercai: Amor e Vingança S02 E69', 'http://sinalprivado.info:80/series/1533784/1533784/341037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111922, 7975, 'Hercai: Amor e Vingança S02 E70', 'http://sinalprivado.info:80/series/1533784/1533784/341038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111923, 7975, 'Hercai: Amor e Vingança S02 E71', 'http://sinalprivado.info:80/series/1533784/1533784/341039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111924, 7975, 'Hercai: Amor e Vingança S02 E72', 'http://sinalprivado.info:80/series/1533784/1533784/341040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111925, 7975, 'Hercai: Amor e Vingança S02 E73', 'http://sinalprivado.info:80/series/1533784/1533784/341041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111926, 7975, 'Hercai: Amor e Vingança S02 E74', 'http://sinalprivado.info:80/series/1533784/1533784/341042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111927, 7975, 'Hercai: Amor e Vingança S02 E75', 'http://sinalprivado.info:80/series/1533784/1533784/341043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111928, 7975, 'Hercai: Amor e Vingança S02 E76', 'http://sinalprivado.info:80/series/1533784/1533784/349412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111929, 7975, 'Hercai: Amor e Vingança S02 E77', 'http://sinalprivado.info:80/series/1533784/1533784/349413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111930, 7975, 'Hercai: Amor e Vingança S02 E78', 'http://sinalprivado.info:80/series/1533784/1533784/349414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111931, 7975, 'Hercai: Amor e Vingança S02 E79', 'http://sinalprivado.info:80/series/1533784/1533784/349415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111932, 7975, 'Hercai: Amor e Vingança S02 E80', 'http://sinalprivado.info:80/series/1533784/1533784/349416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111933, 7975, 'Hercai: Amor e Vingança S02 E81', 'http://sinalprivado.info:80/series/1533784/1533784/349417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111934, 7975, 'Hercai: Amor e Vingança S02 E82', 'http://sinalprivado.info:80/series/1533784/1533784/349418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111935, 7975, 'Hercai: Amor e Vingança S02 E83', 'http://sinalprivado.info:80/series/1533784/1533784/349419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111936, 7975, 'Hercai: Amor e Vingança S02 E84', 'http://sinalprivado.info:80/series/1533784/1533784/349420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111937, 7975, 'Hercai: Amor e Vingança S02 E85', 'http://sinalprivado.info:80/series/1533784/1533784/349421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111938, 7975, 'Hercai: Amor e Vingança S02 E86', 'http://sinalprivado.info:80/series/1533784/1533784/349422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111939, 7975, 'Hercai: Amor e Vingança S02 E87', 'http://sinalprivado.info:80/series/1533784/1533784/349423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111940, 7975, 'Hercai: Amor e Vingança S02 E88', 'http://sinalprivado.info:80/series/1533784/1533784/349424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111941, 7975, 'Hercai: Amor e Vingança S02 E89', 'http://sinalprivado.info:80/series/1533784/1533784/349425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111942, 7975, 'Hercai: Amor e Vingança S02 E90', 'http://sinalprivado.info:80/series/1533784/1533784/349426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111943, 7975, 'Hercai: Amor e Vingança S02 E91', 'http://sinalprivado.info:80/series/1533784/1533784/349427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111944, 7975, 'Hercai: Amor e Vingança S02 E92', 'http://sinalprivado.info:80/series/1533784/1533784/349428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111945, 7975, 'Hercai: Amor e Vingança S02 E93', 'http://sinalprivado.info:80/series/1533784/1533784/349429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111946, 7975, 'Hercai: Amor e Vingança S02 E94', 'http://sinalprivado.info:80/series/1533784/1533784/349430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111947, 7975, 'Hercai: Amor e Vingança S02 E95', 'http://sinalprivado.info:80/series/1533784/1533784/349431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111948, 7975, 'Hercai: Amor e Vingança S02 E96', 'http://sinalprivado.info:80/series/1533784/1533784/349432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111949, 7975, 'Hercai: Amor e Vingança S02 E97', 'http://sinalprivado.info:80/series/1533784/1533784/349433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111950, 7975, 'Hercai: Amor e Vingança S02 E98', 'http://sinalprivado.info:80/series/1533784/1533784/349434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111951, 7975, 'Hercai: Amor e Vingança S02 E99', 'http://sinalprivado.info:80/series/1533784/1533784/349435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111952, 7976, 'Hercai: Amor e Vingança S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/888314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111953, 7976, 'Hercai: Amor e Vingança S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/888315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111954, 7976, 'Hercai: Amor e Vingança S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/888316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111955, 7976, 'Hercai: Amor e Vingança S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/888317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111956, 7976, 'Hercai: Amor e Vingança S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/888318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111957, 7976, 'Hercai: Amor e Vingança S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/888319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111958, 7976, 'Hercai: Amor e Vingança S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/888320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111959, 7976, 'Hercai: Amor e Vingança S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/888321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111960, 7976, 'Hercai: Amor e Vingança S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/888322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111961, 7976, 'Hercai: Amor e Vingança S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/888323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111962, 7976, 'Hercai: Amor e Vingança S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/888324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111963, 7976, 'Hercai: Amor e Vingança S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/888325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111964, 7976, 'Hercai: Amor e Vingança S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/888326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111965, 7976, 'Hercai: Amor e Vingança S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/888327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111966, 7976, 'Hercai: Amor e Vingança S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/888328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111967, 7976, 'Hercai: Amor e Vingança S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/888329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111968, 7976, 'Hercai: Amor e Vingança S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/888330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111969, 7976, 'Hercai: Amor e Vingança S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/888331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111970, 7976, 'Hercai: Amor e Vingança S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/888332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111971, 7976, 'Hercai: Amor e Vingança S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/888333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111972, 7976, 'Hercai: Amor e Vingança S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/888334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111973, 7976, 'Hercai: Amor e Vingança S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/888335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111974, 7976, 'Hercai: Amor e Vingança S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/888336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111975, 7976, 'Hercai: Amor e Vingança S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/888337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111976, 7976, 'Hercai: Amor e Vingança S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/888338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111977, 7976, 'Hercai: Amor e Vingança S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/888339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111978, 7976, 'Hercai: Amor e Vingança S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/888340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111979, 7976, 'Hercai: Amor e Vingança S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/888341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111980, 7976, 'Hercai: Amor e Vingança S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/888342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111981, 7976, 'Hercai: Amor e Vingança S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/888343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111982, 7976, 'Hercai: Amor e Vingança S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/888344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111983, 7976, 'Hercai: Amor e Vingança S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/888345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111984, 7976, 'Hercai: Amor e Vingança S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/888346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111985, 7976, 'Hercai: Amor e Vingança S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/888347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111986, 7976, 'Hercai: Amor e Vingança S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/888348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111987, 7976, 'Hercai: Amor e Vingança S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/890083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111988, 7976, 'Hercai: Amor e Vingança S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/890084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111989, 7976, 'Hercai: Amor e Vingança S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/890085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111990, 7976, 'Hercai: Amor e Vingança S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/890086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111991, 7976, 'Hercai: Amor e Vingança S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/890087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111992, 7976, 'Hercai: Amor e Vingança S03 E41', 'http://sinalprivado.info:80/series/1533784/1533784/890088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111993, 7976, 'Hercai: Amor e Vingança S03 E42', 'http://sinalprivado.info:80/series/1533784/1533784/890089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111994, 7976, 'Hercai: Amor e Vingança S03 E43', 'http://sinalprivado.info:80/series/1533784/1533784/890090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111995, 7976, 'Hercai: Amor e Vingança S03 E44', 'http://sinalprivado.info:80/series/1533784/1533784/890091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111996, 7976, 'Hercai: Amor e Vingança S03 E45', 'http://sinalprivado.info:80/series/1533784/1533784/890092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111997, 7976, 'Hercai: Amor e Vingança S03 E46', 'http://sinalprivado.info:80/series/1533784/1533784/890093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111998, 7976, 'Hercai: Amor e Vingança S03 E47', 'http://sinalprivado.info:80/series/1533784/1533784/890094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(111999, 7976, 'Hercai: Amor e Vingança S03 E48', 'http://sinalprivado.info:80/series/1533784/1533784/890095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112000, 7976, 'Hercai: Amor e Vingança S03 E49', 'http://sinalprivado.info:80/series/1533784/1533784/890096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112001, 7976, 'Hercai: Amor e Vingança S03 E50', 'http://sinalprivado.info:80/series/1533784/1533784/890097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112002, 7976, 'Hercai: Amor e Vingança S03 E51', 'http://sinalprivado.info:80/series/1533784/1533784/890098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112003, 7976, 'Hercai: Amor e Vingança S03 E52', 'http://sinalprivado.info:80/series/1533784/1533784/890099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112004, 7976, 'Hercai: Amor e Vingança S03 E53', 'http://sinalprivado.info:80/series/1533784/1533784/890100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112005, 7976, 'Hercai: Amor e Vingança S03 E54', 'http://sinalprivado.info:80/series/1533784/1533784/890101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112006, 7976, 'Hercai: Amor e Vingança S03 E55', 'http://sinalprivado.info:80/series/1533784/1533784/890102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112007, 7976, 'Hercai: Amor e Vingança S03 E56', 'http://sinalprivado.info:80/series/1533784/1533784/890103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112008, 7976, 'Hercai: Amor e Vingança S03 E57', 'http://sinalprivado.info:80/series/1533784/1533784/890104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112009, 7976, 'Hercai: Amor e Vingança S03 E58', 'http://sinalprivado.info:80/series/1533784/1533784/890105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112010, 7976, 'Hercai: Amor e Vingança S03 E59', 'http://sinalprivado.info:80/series/1533784/1533784/890106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112011, 7976, 'Hercai: Amor e Vingança S03 E60', 'http://sinalprivado.info:80/series/1533784/1533784/890107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112012, 7976, 'Hercai: Amor e Vingança S03 E61', 'http://sinalprivado.info:80/series/1533784/1533784/890108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112013, 7976, 'Hercai: Amor e Vingança S03 E62', 'http://sinalprivado.info:80/series/1533784/1533784/890109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112014, 7976, 'Hercai: Amor e Vingança S03 E63', 'http://sinalprivado.info:80/series/1533784/1533784/890110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112015, 7976, 'Hercai: Amor e Vingança S03 E64', 'http://sinalprivado.info:80/series/1533784/1533784/890111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112016, 7976, 'Hercai: Amor e Vingança S03 E65', 'http://sinalprivado.info:80/series/1533784/1533784/890112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112017, 7976, 'Hercai: Amor e Vingança S03 E66', 'http://sinalprivado.info:80/series/1533784/1533784/891861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112018, 7976, 'Hercai: Amor e Vingança S03 E67', 'http://sinalprivado.info:80/series/1533784/1533784/891862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112019, 7976, 'Hercai: Amor e Vingança S03 E68', 'http://sinalprivado.info:80/series/1533784/1533784/891863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112020, 7976, 'Hercai: Amor e Vingança S03 E69', 'http://sinalprivado.info:80/series/1533784/1533784/891864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112021, 7976, 'Hercai: Amor e Vingança S03 E70', 'http://sinalprivado.info:80/series/1533784/1533784/891865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112022, 7976, 'Hercai: Amor e Vingança S03 E71', 'http://sinalprivado.info:80/series/1533784/1533784/891866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112023, 7976, 'Hercai: Amor e Vingança S03 E72', 'http://sinalprivado.info:80/series/1533784/1533784/891867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112024, 7976, 'Hercai: Amor e Vingança S03 E73', 'http://sinalprivado.info:80/series/1533784/1533784/891868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112025, 7976, 'Hercai: Amor e Vingança S03 E74', 'http://sinalprivado.info:80/series/1533784/1533784/891869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112026, 7976, 'Hercai: Amor e Vingança S03 E75', 'http://sinalprivado.info:80/series/1533784/1533784/891870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112027, 7976, 'Hercai: Amor e Vingança S03 E76', 'http://sinalprivado.info:80/series/1533784/1533784/891871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112028, 7976, 'Hercai: Amor e Vingança S03 E77', 'http://sinalprivado.info:80/series/1533784/1533784/891872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112029, 7976, 'Hercai: Amor e Vingança S03 E78', 'http://sinalprivado.info:80/series/1533784/1533784/891873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112030, 7976, 'Hercai: Amor e Vingança S03 E79', 'http://sinalprivado.info:80/series/1533784/1533784/891874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112031, 7976, 'Hercai: Amor e Vingança S03 E80', 'http://sinalprivado.info:80/series/1533784/1533784/891875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112032, 7976, 'Hercai: Amor e Vingança S03 E81', 'http://sinalprivado.info:80/series/1533784/1533784/892445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112033, 7976, 'Hercai: Amor e Vingança S03 E82', 'http://sinalprivado.info:80/series/1533784/1533784/892446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112034, 7976, 'Hercai: Amor e Vingança S03 E83', 'http://sinalprivado.info:80/series/1533784/1533784/892447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112035, 7976, 'Hercai: Amor e Vingança S03 E84', 'http://sinalprivado.info:80/series/1533784/1533784/892448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112036, 7976, 'Hercai: Amor e Vingança S03 E85', 'http://sinalprivado.info:80/series/1533784/1533784/892449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112037, 7976, 'Hercai: Amor e Vingança S03 E86', 'http://sinalprivado.info:80/series/1533784/1533784/892450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112038, 7976, 'Hercai: Amor e Vingança S03 E87', 'http://sinalprivado.info:80/series/1533784/1533784/892451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112039, 7976, 'Hercai: Amor e Vingança S03 E88', 'http://sinalprivado.info:80/series/1533784/1533784/892452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112040, 7976, 'Hercai: Amor e Vingança S03 E89', 'http://sinalprivado.info:80/series/1533784/1533784/892453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112041, 7976, 'Hercai: Amor e Vingança S03 E90', 'http://sinalprivado.info:80/series/1533784/1533784/892454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112042, 7976, 'Hercai: Amor e Vingança S03 E91', 'http://sinalprivado.info:80/series/1533784/1533784/892455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112043, 7976, 'Hercai: Amor e Vingança S03 E92', 'http://sinalprivado.info:80/series/1533784/1533784/892456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112044, 7976, 'Hercai: Amor e Vingança S03 E93', 'http://sinalprivado.info:80/series/1533784/1533784/892457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112045, 7976, 'Hercai: Amor e Vingança S03 E94', 'http://sinalprivado.info:80/series/1533784/1533784/892458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112046, 7976, 'Hercai: Amor e Vingança S03 E95', 'http://sinalprivado.info:80/series/1533784/1533784/892459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112047, 7976, 'Hercai: Amor e Vingança S03 E96', 'http://sinalprivado.info:80/series/1533784/1533784/893132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112048, 7976, 'Hercai: Amor e Vingança S03 E97', 'http://sinalprivado.info:80/series/1533784/1533784/893133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112049, 7976, 'Hercai: Amor e Vingança S03 E98', 'http://sinalprivado.info:80/series/1533784/1533784/893134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112050, 7976, 'Hercai: Amor e Vingança S03 E99', 'http://sinalprivado.info:80/series/1533784/1533784/893135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112051, 7976, 'Hercai: Amor e Vingança S03 E100', 'http://sinalprivado.info:80/series/1533784/1533784/893136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112052, 7976, 'Hercai: Amor e Vingança S03 E101', 'http://sinalprivado.info:80/series/1533784/1533784/893137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112053, 7976, 'Hercai: Amor e Vingança S03 E102', 'http://sinalprivado.info:80/series/1533784/1533784/893138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112054, 7976, 'Hercai: Amor e Vingança S03 E103', 'http://sinalprivado.info:80/series/1533784/1533784/893139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112055, 7976, 'Hercai: Amor e Vingança S03 E104', 'http://sinalprivado.info:80/series/1533784/1533784/893140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112056, 7976, 'Hercai: Amor e Vingança S03 E105', 'http://sinalprivado.info:80/series/1533784/1533784/893141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112057, 7976, 'Hercai: Amor e Vingança S03 E106', 'http://sinalprivado.info:80/series/1533784/1533784/893142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112058, 7976, 'Hercai: Amor e Vingança S03 E107', 'http://sinalprivado.info:80/series/1533784/1533784/893143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112059, 7976, 'Hercai: Amor e Vingança S03 E108', 'http://sinalprivado.info:80/series/1533784/1533784/893144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112060, 7976, 'Hercai: Amor e Vingança S03 E109', 'http://sinalprivado.info:80/series/1533784/1533784/893145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112061, 7976, 'Hercai: Amor e Vingança S03 E110', 'http://sinalprivado.info:80/series/1533784/1533784/893146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112062, 7976, 'Hercai: Amor e Vingança S03 E111', 'http://sinalprivado.info:80/series/1533784/1533784/893147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112063, 7976, 'Hercai: Amor e Vingança S03 E112', 'http://sinalprivado.info:80/series/1533784/1533784/893148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iilYRWFCXwv4zKC96QkFwpIxbfg.jpg'),
(112064, 7977, 'Life on Mars [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2MyjXfPDhkJ7dyMYusVNc8xuo7V.jpg'),
(112065, 7977, 'Life on Mars [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fYBHEbJyLUsoJCrDa2wy6Q6Yujo.jpg'),
(112066, 7977, 'Life on Mars [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wVlHgHpgFu7vCAsGlT3Z3LRO0v4.jpg'),
(112067, 7977, 'Life on Mars [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6D2Iq90gjLbSo5E8t6qzKclW1h8.jpg'),
(112068, 7977, 'Life on Mars [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bU6p9jGJEhCQLaX7u5yD7unMHx5.jpg'),
(112069, 7977, 'Life on Mars [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/opP6O99cWRZ9tfdPaLsWefbcPRs.jpg'),
(112070, 7977, 'Life on Mars [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/opP6O99cWRZ9tfdPaLsWefbcPRs.jpg'),
(112071, 7977, 'Life on Mars [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/opP6O99cWRZ9tfdPaLsWefbcPRs.jpg'),
(112072, 7977, 'Life on Mars [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/opP6O99cWRZ9tfdPaLsWefbcPRs.jpg'),
(112073, 7977, 'Life on Mars [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1V9hjZxllK8b0XCiUHXez3Xz272.jpg'),
(112074, 7977, 'Life on Mars [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/opP6O99cWRZ9tfdPaLsWefbcPRs.jpg'),
(112075, 7977, 'Life on Mars [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lkyobiwgvZEMghuq0iQH7VKc17O.jpg'),
(112076, 7977, 'Life on Mars [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5D7fosjETa8KFSejWwzssYOyU41.jpg'),
(112077, 7977, 'Life on Mars [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ie0H1TfR6s5gkk0xXTD2cBlkIG.jpg'),
(112078, 7977, 'Life on Mars [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBfJp0WEx04BZTtDorL5oa0i1TZ.jpg'),
(112079, 7977, 'Life on Mars [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kg0CicmM4oCMMWm8neaXN7dphAF.jpg'),
(112080, 7977, 'Life on Mars [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/opP6O99cWRZ9tfdPaLsWefbcPRs.jpg'),
(112081, 7978, 'Mandou Bem: Desafio dos Confeiteiros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kQasMDIk3B8ECA4DK21DNVLxOfQ.jpg'),
(112082, 7978, 'Mandou Bem: Desafio dos Confeiteiros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kQasMDIk3B8ECA4DK21DNVLxOfQ.jpg'),
(112083, 7978, 'Mandou Bem: Desafio dos Confeiteiros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kQasMDIk3B8ECA4DK21DNVLxOfQ.jpg'),
(112084, 7978, 'Mandou Bem: Desafio dos Confeiteiros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kQasMDIk3B8ECA4DK21DNVLxOfQ.jpg'),
(112085, 7978, 'Mandou Bem: Desafio dos Confeiteiros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kQasMDIk3B8ECA4DK21DNVLxOfQ.jpg'),
(112086, 7978, 'Mandou Bem: Desafio dos Confeiteiros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kQasMDIk3B8ECA4DK21DNVLxOfQ.jpg'),
(112087, 7978, 'Mandou Bem: Desafio dos Confeiteiros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kQasMDIk3B8ECA4DK21DNVLxOfQ.jpg'),
(112088, 7978, 'Mandou Bem: Desafio dos Confeiteiros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kQasMDIk3B8ECA4DK21DNVLxOfQ.jpg'),
(112089, 7978, 'Mandou Bem: Desafio dos Confeiteiros S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kQasMDIk3B8ECA4DK21DNVLxOfQ.jpg'),
(112090, 7978, 'Mandou Bem: Desafio dos Confeiteiros S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kQasMDIk3B8ECA4DK21DNVLxOfQ.jpg'),
(112091, 7979, 'O Garoto de Cada Dia [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224838.mp4', 'https://i.mydramalist.com/RBYr06_4f.jpg'),
(112092, 7979, 'O Garoto de Cada Dia [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224839.mp4', 'https://i.mydramalist.com/RBYr06_4f.jpg'),
(112093, 7979, 'O Garoto de Cada Dia [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224840.mp4', 'https://i.mydramalist.com/RBYr06_4f.jpg'),
(112094, 7979, 'O Garoto de Cada Dia [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224841.mp4', 'https://i.mydramalist.com/RBYr06_4f.jpg'),
(112095, 7979, 'O Garoto de Cada Dia [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224842.mp4', 'https://i.mydramalist.com/RBYr06_4f.jpg'),
(112096, 7979, 'O Garoto de Cada Dia [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224843.mp4', 'https://i.mydramalist.com/RBYr06_4f.jpg'),
(112097, 7979, 'O Garoto de Cada Dia [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224844.mp4', 'https://i.mydramalist.com/RBYr06_4f.jpg'),
(112098, 7980, 'Primo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9ECEwyPBkyQQK7PlPNvMcp7ZoC.jpg'),
(112099, 7980, 'Primo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/34Sa3I27782YFQnmo69Cw4BvuxM.jpg'),
(112100, 7980, 'Primo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fpnBDbXR0s2zSY6bwPHomNgKXNy.jpg'),
(112101, 7980, 'Primo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9gBSXPR2chcrCf82aBMnW4iW7q5.jpg'),
(112102, 7980, 'Primo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9iJyPr5o7SO02orgHfNaa6VvHP9.jpg'),
(112103, 7980, 'Primo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lvscNWfgB3WrCt8KJ5jm97T8pGp.jpg'),
(112104, 7980, 'Primo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u72ZfBEyMLgvijvDP1mFjaXBTSY.jpg'),
(112105, 7980, 'Primo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ppOHmtVLs1SNDFUItkWczAQ7rv.jpg'),
(112106, 7981, 'Nattryttarna [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fCvu3DVzyq7D0ok5N7N8yKUrdPL.jpg'),
(112107, 7981, 'Nattryttarna [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mDgJfafZ3AVkmZVtOrwSAsyWgMv.jpg'),
(112108, 7981, 'Nattryttarna [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cUet9DJaBQuimHR8pFuIMskEB5i.jpg'),
(112109, 7981, 'Nattryttarna [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnh1S73awUNAWUWniblP0xjT56Y.jpg'),
(112110, 7981, 'Nattryttarna [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2yBQUTk5KX8EKfsQOrHHjRCc6Wo.jpg'),
(112111, 7981, 'Nattryttarna [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rNQkkDCXWp22ikyqfjDBitlz0tF.jpg'),
(112112, 7981, 'Nattryttarna [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/baDKWStC9JySOIV0gKKQlHlX9rC.jpg'),
(112113, 7981, 'Nattryttarna [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yc0vdqIfPWNZWeAyNZj2GaSj7gi.jpg'),
(112114, 6656, 'Rumo ao Desconhecido S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fpuig9TaVV6iAZ2UNAvMnWzKkS3.jpg'),
(112115, 6656, 'Rumo ao Desconhecido S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QUylBp5cCTVmQMZdE0w0SU1tSj.jpg'),
(112116, 6656, 'Rumo ao Desconhecido S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2q7RF8zD3kJ3UWcb4Rw4NCzZiv.jpg'),
(112117, 6656, 'Rumo ao Desconhecido S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1xntqRsx1NAYmIiu1Gjx6qrbaXl.jpg'),
(112118, 6656, 'Rumo ao Desconhecido S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jVaI4grw7A9ZdkE7fLzHg0XFMFu.jpg'),
(112119, 6656, 'Rumo ao Desconhecido S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bRnoZppEZXhUVL3gpMgkCX3B5fN.jpg'),
(112120, 6656, 'Rumo ao Desconhecido S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vLQEDWOW0RCLijILewz2QBrDLxD.jpg'),
(112121, 6656, 'Rumo ao Desconhecido S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uvJfCK6y73uQvSGN3uoQUrtRnhv.jpg'),
(112122, 6656, 'Rumo ao Desconhecido S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8lIzQ90fz4XvUdzfFwQEkSHSb0l.jpg'),
(112123, 6656, 'Rumo ao Desconhecido S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mYJwn6ySxx0Y2D47FSe6r3orS5h.jpg'),
(112124, 6656, 'Rumo ao Desconhecido S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/atc6D3iJRHn3zQBYwTMNWjdjMtL.jpg'),
(112125, 6656, 'Rumo ao Desconhecido S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zQxjJcny1VFZRMhAhadyyn4bLGA.jpg'),
(112126, 7982, 'Rumo ao Desconhecido S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bdugrwjAPjozkLxiMzkdqCeJ7FX.jpg'),
(112127, 7982, 'Rumo ao Desconhecido S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cC8Txx4jvMjT3XdxXJ82nsQncPB.jpg'),
(112128, 7982, 'Rumo ao Desconhecido S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iu5xM9Wie1Au2wE32QuxHlMdsCW.jpg'),
(112129, 7982, 'Rumo ao Desconhecido S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q00Fzc5dh2FYHIFpw2u5m1WCDaQ.jpg'),
(112130, 7982, 'Rumo ao Desconhecido S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3PNWMUzFK8q1V06uTWLIVfWJ0D7.jpg'),
(112131, 7982, 'Rumo ao Desconhecido S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sLvqRooKmF3qoqHTwVMyPhNJQtN.jpg'),
(112132, 7982, 'Rumo ao Desconhecido S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/weii9vZN1mG7Zcoi8t2E4vAgRyb.jpg'),
(112133, 7982, 'Rumo ao Desconhecido S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/txEClDpsoOlqNFCvlKPA9WHL9e.jpg'),
(112134, 7982, 'Rumo ao Desconhecido S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/av5YBf6Ld4NHFqKtVg1e2MznKQL.jpg'),
(112135, 7982, 'Rumo ao Desconhecido S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2i3RZtVrqSJrWv5nWvPPjZR9Yt2.jpg'),
(112136, 7982, 'Rumo ao Desconhecido S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8XHRl2WKw1q00rL4pBjn4CS08FE.jpg'),
(112137, 7982, 'Rumo ao Desconhecido S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dpdpTC3NOre4AkY8s47n5FdoPjq.jpg'),
(112138, 7982, 'Rumo ao Desconhecido S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpqgedY2DQPxtsIWehKP7fqCdRD.jpg'),
(112139, 7982, 'Rumo ao Desconhecido S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/235593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1vQ08ZGUlTDa2NZvPliDtqziv1s.jpg'),
(112140, 7982, 'Rumo ao Desconhecido S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/235594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yVsHFnOR6qvPWSAdChVUWQcEVHb.jpg'),
(112141, 7982, 'Rumo ao Desconhecido S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/235595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5xKLgfCmzJxuF22y4DbyfNqylyt.jpg'),
(112142, 7983, 'Rumo ao Desconhecido S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cSpeoiI6Iv0ENRCo8lqDDegL53Q.jpg'),
(112143, 7983, 'Rumo ao Desconhecido S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3djAneWnl8hOK6PcJ29QOtS2Ksf.jpg'),
(112144, 7983, 'Rumo ao Desconhecido S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kaJsffD201gqu5m9MD0jCdlb65q.jpg'),
(112145, 7984, 'Rumo ao Desconhecido S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112146, 7984, 'Rumo ao Desconhecido S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112147, 7984, 'Rumo ao Desconhecido S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112148, 7984, 'Rumo ao Desconhecido S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112149, 7984, 'Rumo ao Desconhecido S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112150, 7984, 'Rumo ao Desconhecido S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112151, 7984, 'Rumo ao Desconhecido S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112152, 7984, 'Rumo ao Desconhecido S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112153, 7984, 'Rumo ao Desconhecido S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112154, 7984, 'Rumo ao Desconhecido S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112155, 7984, 'Rumo ao Desconhecido S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112156, 7984, 'Rumo ao Desconhecido S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112157, 7984, 'Rumo ao Desconhecido S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112158, 7984, 'Rumo ao Desconhecido S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/235612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112159, 7984, 'Rumo ao Desconhecido S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/235613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112160, 7984, 'Rumo ao Desconhecido S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/235614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112161, 7984, 'Rumo ao Desconhecido S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/235615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112162, 7984, 'Rumo ao Desconhecido S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/235616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112163, 7985, 'Rumo ao Desconhecido S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112164, 7985, 'Rumo ao Desconhecido S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112165, 7985, 'Rumo ao Desconhecido S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(112166, 7985, 'Rumo ao Desconhecido S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112167, 7985, 'Rumo ao Desconhecido S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112168, 7985, 'Rumo ao Desconhecido S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112169, 7985, 'Rumo ao Desconhecido S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112170, 7985, 'Rumo ao Desconhecido S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112171, 7985, 'Rumo ao Desconhecido S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112172, 7985, 'Rumo ao Desconhecido S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112173, 7985, 'Rumo ao Desconhecido S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112174, 7985, 'Rumo ao Desconhecido S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112175, 7985, 'Rumo ao Desconhecido S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112176, 7985, 'Rumo ao Desconhecido S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/235630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112177, 7986, 'Rumo ao Desconhecido S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112178, 7986, 'Rumo ao Desconhecido S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112179, 7986, 'Rumo ao Desconhecido S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112180, 7986, 'Rumo ao Desconhecido S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112181, 7986, 'Rumo ao Desconhecido S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112182, 7986, 'Rumo ao Desconhecido S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112183, 7986, 'Rumo ao Desconhecido S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112184, 7986, 'Rumo ao Desconhecido S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112185, 7987, 'Rumo ao Desconhecido S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112186, 7987, 'Rumo ao Desconhecido S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112187, 7987, 'Rumo ao Desconhecido S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112188, 7987, 'Rumo ao Desconhecido S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112189, 7987, 'Rumo ao Desconhecido S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112190, 7987, 'Rumo ao Desconhecido S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112191, 7987, 'Rumo ao Desconhecido S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112192, 7987, 'Rumo ao Desconhecido S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112193, 7987, 'Rumo ao Desconhecido S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112194, 7987, 'Rumo ao Desconhecido S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112195, 7987, 'Rumo ao Desconhecido S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112196, 7987, 'Rumo ao Desconhecido S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112197, 7987, 'Rumo ao Desconhecido S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112198, 7988, 'Rumo ao Desconhecido S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112199, 7988, 'Rumo ao Desconhecido S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112200, 7988, 'Rumo ao Desconhecido S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112201, 7988, 'Rumo ao Desconhecido S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112202, 7988, 'Rumo ao Desconhecido S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112203, 7988, 'Rumo ao Desconhecido S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112204, 7989, 'Rumo ao Desconhecido S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4lqCL858Oncn1MPGJUX6no46oF2.jpg'),
(112205, 7989, 'Rumo ao Desconhecido S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oCp4yAg68FaJ29AaXaHVQvTaL2K.jpg'),
(112206, 7989, 'Rumo ao Desconhecido S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4f8MSgd6kjrcubiqCcEwSJYg9Ci.jpg'),
(112207, 7989, 'Rumo ao Desconhecido S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112208, 7989, 'Rumo ao Desconhecido S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112209, 7989, 'Rumo ao Desconhecido S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112210, 7990, 'Rumo ao Desconhecido S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/50duEpcMxNkBNvZcsvi3QrQlVl6.jpg'),
(112211, 7990, 'Rumo ao Desconhecido S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ao9x5Gu3GU9REwN55utXnxCUNjG.jpg'),
(112212, 7990, 'Rumo ao Desconhecido S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5EQsPzJeoGTAF3nEpz47SQjm6yw.jpg'),
(112213, 7990, 'Rumo ao Desconhecido S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7vJvsH06pex97OGGWjLKX08VQgy.jpg'),
(112214, 7990, 'Rumo ao Desconhecido S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3yJvavfgVoVymjQHDLW96Kqe8dR.jpg'),
(112215, 7990, 'Rumo ao Desconhecido S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13bP5eBcoHoV0JlVK45DrwDJqZp.jpg'),
(112216, 7990, 'Rumo ao Desconhecido S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112217, 7990, 'Rumo ao Desconhecido S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112218, 7990, 'Rumo ao Desconhecido S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112219, 7990, 'Rumo ao Desconhecido S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112220, 7990, 'Rumo ao Desconhecido S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112221, 7990, 'Rumo ao Desconhecido S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112222, 7990, 'Rumo ao Desconhecido S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112223, 7990, 'Rumo ao Desconhecido S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/235677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112224, 7991, 'Rumo ao Desconhecido S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/604936.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kUgqyrjISjunkf8lDYmyFJMa6G5.jpg'),
(112225, 7991, 'Rumo ao Desconhecido S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/604938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112226, 7991, 'Rumo ao Desconhecido S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/604940.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zbgVHmRqWMeofLnUd6hSeaHjhhA.jpg'),
(112227, 7991, 'Rumo ao Desconhecido S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/604942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112228, 7991, 'Rumo ao Desconhecido S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/604944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112229, 7991, 'Rumo ao Desconhecido S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112230, 7991, 'Rumo ao Desconhecido S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112231, 7991, 'Rumo ao Desconhecido S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112232, 7992, 'Rumo ao Desconhecido S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/354480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112233, 7992, 'Rumo ao Desconhecido S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/354481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112234, 7992, 'Rumo ao Desconhecido S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/354483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112235, 7992, 'Rumo ao Desconhecido S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/363082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112236, 7992, 'Rumo ao Desconhecido S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/604953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112237, 7992, 'Rumo ao Desconhecido S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/379673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112238, 7992, 'Rumo ao Desconhecido S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/386072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112239, 7992, 'Rumo ao Desconhecido S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/391079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112240, 7993, 'Rumo ao Desconhecido S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/827105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112241, 7993, 'Rumo ao Desconhecido S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/827106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112242, 7993, 'Rumo ao Desconhecido S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/827107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112243, 7993, 'Rumo ao Desconhecido S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/827108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112244, 7993, 'Rumo ao Desconhecido S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/827109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112245, 7993, 'Rumo ao Desconhecido S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/827110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112246, 7994, 'Rumo ao Desconhecido S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/827111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112247, 7994, 'Rumo ao Desconhecido S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/827112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112248, 7994, 'Rumo ao Desconhecido S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/827113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112249, 7994, 'Rumo ao Desconhecido S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/827114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112250, 7994, 'Rumo ao Desconhecido S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/827115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112251, 7994, 'Rumo ao Desconhecido S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/827116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112252, 7995, 'Rumo ao Desconhecido S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/891827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112253, 7995, 'Rumo ao Desconhecido S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/891828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112254, 7995, 'Rumo ao Desconhecido S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/891829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112255, 7995, 'Rumo ao Desconhecido S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/891830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112256, 7995, 'Rumo ao Desconhecido S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/891831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112257, 7995, 'Rumo ao Desconhecido S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/891832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112258, 7995, 'Rumo ao Desconhecido S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/891833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUs9CIB3kgYbiJgumHULy95IU4s.jpg'),
(112259, 7996, 'Scarlet Heart [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112260, 7996, 'Scarlet Heart [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112261, 7996, 'Scarlet Heart [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112262, 7996, 'Scarlet Heart [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112263, 7996, 'Scarlet Heart [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112264, 7996, 'Scarlet Heart [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112265, 7996, 'Scarlet Heart [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112266, 7996, 'Scarlet Heart [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112267, 7996, 'Scarlet Heart [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/224795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112268, 7996, 'Scarlet Heart [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/224796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112269, 7996, 'Scarlet Heart [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/224797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112270, 7996, 'Scarlet Heart [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/224798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112271, 7996, 'Scarlet Heart [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/224799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112272, 7996, 'Scarlet Heart [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/224800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112273, 7996, 'Scarlet Heart [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/224801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112274, 7996, 'Scarlet Heart [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/224802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112275, 7996, 'Scarlet Heart [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/224803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112276, 7996, 'Scarlet Heart [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/224804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112277, 7996, 'Scarlet Heart [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/224805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112278, 7996, 'Scarlet Heart [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/224806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112279, 7996, 'Scarlet Heart [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/224807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112280, 7996, 'Scarlet Heart [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/224808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112281, 7996, 'Scarlet Heart [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/224809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112282, 7996, 'Scarlet Heart [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/224810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112283, 7996, 'Scarlet Heart [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/224811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112284, 7996, 'Scarlet Heart [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/224812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112285, 7996, 'Scarlet Heart [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/224813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112286, 7996, 'Scarlet Heart [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/224814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112287, 7996, 'Scarlet Heart [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/224815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112288, 7996, 'Scarlet Heart [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/224816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112289, 7996, 'Scarlet Heart [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/224817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112290, 7996, 'Scarlet Heart [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/224818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112291, 7996, 'Scarlet Heart [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/224819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112292, 7996, 'Scarlet Heart [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/224820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112293, 7996, 'Scarlet Heart [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/224821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kFFnOTW5ufmfyq0GT6IAIdydRku.jpg'),
(112294, 7997, 'Twisted Metal [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gX5QnIbzg0N0BDAcJwdUMYISe80.jpg'),
(112295, 7997, 'Twisted Metal [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6JpV4e8KT2MHxZw6hwZWCuKwpaA.jpg'),
(112296, 7997, 'Twisted Metal [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qAsKUjMKminSesQYlB4qjT8sqq8.jpg'),
(112297, 7997, 'Twisted Metal [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rN6r7OTsKEHjc5rrwgSmfOcFQHt.jpg'),
(112298, 7997, 'Twisted Metal [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wUsgEvn7VEk2oxpK9zWjjpQ6Z6T.jpg'),
(112299, 7997, 'Twisted Metal [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpZDGYf40Bu44pVz5dkPevUkNLn.jpg'),
(112300, 7997, 'Twisted Metal [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uGR5A9wfwUsgvPEGqqoKIaB0XCu.jpg'),
(112301, 7997, 'Twisted Metal [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230104.mp4', 'http://image.tmdb.org/t/p/w1280/y6RSEFXgP4jHBtuTl0DKw1YPEWI.jpg'),
(112302, 7997, 'Twisted Metal [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230105.mp4', 'http://image.tmdb.org/t/p/w1280/cSjEDOj5e0OrU1FIAw7x0fZjAOp.jpg'),
(112303, 7997, 'Twisted Metal [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230106.mp4', 'http://image.tmdb.org/t/p/w1280/kic5oiiezmSlB3DsJxszCv4WKPM.jpg'),
(112304, 7998, 'Twisted Metal [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/879929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(112305, 7998, 'Twisted Metal [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/879930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(112306, 7998, 'Twisted Metal [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/879931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(112307, 7998, 'Twisted Metal [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/880327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(112308, 7998, 'Twisted Metal [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/880328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(112309, 7998, 'Twisted Metal [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/880329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(112310, 7998, 'Twisted Metal [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/883006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(112311, 7998, 'Twisted Metal [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/883007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(112312, 7998, 'Twisted Metal [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/883008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(112313, 7998, 'Twisted Metal [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/883009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(112314, 7998, 'Twisted Metal [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/883010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(112315, 7998, 'Twisted Metal [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/883011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(112316, 7999, 'Wolf [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xwzOuqlssceNUFgnBx0NTvfzW9Y.jpg'),
(112317, 7999, 'Wolf [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fYslBQiQHcUcGYKb8apZ6eeBsML.jpg'),
(112318, 7999, 'Wolf [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rzFu30hX7IxNEkUwwAXTfl6zipz.jpg'),
(112319, 7999, 'Wolf [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/txZ6j26qtmaSH9dLpr2CkzGwELI.jpg'),
(112320, 7999, 'Wolf [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/krq6ZbPnhh3id4ir9UwWIZMYcB7.jpg'),
(112321, 7999, 'Wolf [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wbb3Cv9G20s235UNPfECmwph1f3.jpg'),
(112322, 8000, 'Zumbiverso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jsZXLNJxLkVNL5RL59vBbiG83fn.jpg'),
(112323, 8000, 'Zumbiverso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gcCtVpy5xhCxT6R8KNfnUhArm6i.jpg'),
(112324, 8000, 'Zumbiverso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dtqk0rHMtcqBK5x3Z3fVTK4ukgE.jpg'),
(112325, 8000, 'Zumbiverso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jksjPiU4ifwJ7wBR6v961mFguDp.jpg'),
(112326, 8000, 'Zumbiverso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zNlqyPqdSkkrNNwY0Zhjk1LRb7C.jpg'),
(112327, 8000, 'Zumbiverso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wSJp469uR5nKuhDfMJgFWS58ATn.jpg'),
(112328, 8000, 'Zumbiverso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/224785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wSJp469uR5nKuhDfMJgFWS58ATn.jpg'),
(112329, 8000, 'Zumbiverso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/224786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wSJp469uR5nKuhDfMJgFWS58ATn.jpg'),
(112330, 8001, 'Zumbiverso S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/509162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wSJp469uR5nKuhDfMJgFWS58ATn.jpg'),
(112331, 8001, 'Zumbiverso S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/509163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wSJp469uR5nKuhDfMJgFWS58ATn.jpg'),
(112332, 8001, 'Zumbiverso S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/509164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wSJp469uR5nKuhDfMJgFWS58ATn.jpg'),
(112333, 8001, 'Zumbiverso S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/509165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wSJp469uR5nKuhDfMJgFWS58ATn.jpg'),
(112334, 8001, 'Zumbiverso S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/509166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wSJp469uR5nKuhDfMJgFWS58ATn.jpg'),
(112335, 8001, 'Zumbiverso S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/509167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wSJp469uR5nKuhDfMJgFWS58ATn.jpg'),
(112336, 8001, 'Zumbiverso S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/509168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wSJp469uR5nKuhDfMJgFWS58ATn.jpg'),
(112337, 8002, 'Segurança em Jogo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/224423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tO0r3q3PAvfDmOPvcw7c6F1qvnk.jpg'),
(112338, 8002, 'Segurança em Jogo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/224424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/79PIafK8W8Iy6o8hFS3vVvMO5hk.jpg'),
(112339, 8002, 'Segurança em Jogo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/224425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7EG10kCXecTRZsyvs19KNj9lun5.jpg'),
(112340, 8002, 'Segurança em Jogo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/224426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/704wqEAXHqZRh13Fy6nHH6YsGRE.jpg'),
(112341, 8002, 'Segurança em Jogo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/224427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eIUWlgc0GsyKlR3gMJsIKueqcN8.jpg'),
(112342, 8002, 'Segurança em Jogo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/224428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r3sWab87KlEGQYUub7lYeOieB3o.jpg'),
(112343, 8003, 'Addicted: Vidas em Recuperação S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v67zbnPT3ldmAwMnLwgFm1clgvH.jpg'),
(112344, 8003, 'Addicted: Vidas em Recuperação S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/388kKcdCTGofnkG8KfSkCUlTc8U.jpg'),
(112345, 8003, 'Addicted: Vidas em Recuperação S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rZtozI3zyJdDP3qS9tKzfo8o3b.jpg'),
(112346, 8003, 'Addicted: Vidas em Recuperação S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vxc3D5UhlXzVOD83jq5DkN5C0bx.jpg'),
(112347, 8003, 'Addicted: Vidas em Recuperação S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r6QERBgdXb1PRTYOjFq2pBswXOP.jpg'),
(112348, 8003, 'Addicted: Vidas em Recuperação S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yfaEgGan8aoxYVhTYUPpcMRbaYm.jpg'),
(112349, 8003, 'Addicted: Vidas em Recuperação S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ZI8H10roIGD1QrqCCqZem4CFgC.jpg'),
(112350, 8003, 'Addicted: Vidas em Recuperação S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j5xv8XL0phIj8OsFsn5K4WJRlrt.jpg'),
(112351, 8004, 'Addicted: Vidas em Recuperação S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xu4HKgKcQiiwADUPloVGwNtjb8o.jpg'),
(112352, 8004, 'Addicted: Vidas em Recuperação S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zaYweOVELRnki1Qs5mCgdj3PLMG.jpg'),
(112353, 8004, 'Addicted: Vidas em Recuperação S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aVbW4d3TbHT16via8kgp7FXy7PO.jpg'),
(112354, 8004, 'Addicted: Vidas em Recuperação S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzdkXBysPburxDDzeyTAlagSfRP.jpg'),
(112355, 8004, 'Addicted: Vidas em Recuperação S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qm1NLBEbr8HACdKjDDGkJHAYDQT.jpg'),
(112356, 8004, 'Addicted: Vidas em Recuperação S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c5q1JkIAoZbvX37Vl5las5YS9ll.jpg'),
(112357, 8004, 'Addicted: Vidas em Recuperação S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v1bfxN73tgixqlC2uawyjnBu6dY.jpg'),
(112358, 8004, 'Addicted: Vidas em Recuperação S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A7jw2lxOtKhAdsCJ882d96XfNUW.jpg'),
(112359, 8005, 'Addicted: Vidas em Recuperação S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/avsfx0nfaFxa9GHIaHaAXqQWDdv.jpg'),
(112360, 8005, 'Addicted: Vidas em Recuperação S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyq1yCTa3ShPOdWXko7q0JhFRwS.jpg'),
(112361, 8005, 'Addicted: Vidas em Recuperação S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ydYieF8sPey8YU1GhPpvXVOL6zU.jpg'),
(112362, 8005, 'Addicted: Vidas em Recuperação S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ydYieF8sPey8YU1GhPpvXVOL6zU.jpg'),
(112363, 8005, 'Addicted: Vidas em Recuperação S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ydYieF8sPey8YU1GhPpvXVOL6zU.jpg'),
(112364, 8005, 'Addicted: Vidas em Recuperação S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ydYieF8sPey8YU1GhPpvXVOL6zU.jpg'),
(112365, 8005, 'Addicted: Vidas em Recuperação S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ydYieF8sPey8YU1GhPpvXVOL6zU.jpg'),
(112366, 8005, 'Addicted: Vidas em Recuperação S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ydYieF8sPey8YU1GhPpvXVOL6zU.jpg'),
(112367, 8006, 'As Aventuras de Sunny Bunnies S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lx68BxKIKFW2RSAT67TKZ8J4Dqg.jpg'),
(112368, 8006, 'As Aventuras de Sunny Bunnies S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBK0L0n4wZ3kiBVblq9cSGWZ1vx.jpg'),
(112369, 8006, 'As Aventuras de Sunny Bunnies S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/TL62SDynlySuPMVgXRr2lzuy8K.jpg'),
(112370, 8006, 'As Aventuras de Sunny Bunnies S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sWyWUhPQp2JnjjchKxrSUzSMIix.jpg'),
(112371, 8006, 'As Aventuras de Sunny Bunnies S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112372, 8006, 'As Aventuras de Sunny Bunnies S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sVWCTAuufCUOzdezqEFC6RyHisY.jpg'),
(112373, 8006, 'As Aventuras de Sunny Bunnies S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112374, 8006, 'As Aventuras de Sunny Bunnies S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112375, 8006, 'As Aventuras de Sunny Bunnies S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112376, 8006, 'As Aventuras de Sunny Bunnies S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112377, 8006, 'As Aventuras de Sunny Bunnies S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/231011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112378, 8006, 'As Aventuras de Sunny Bunnies S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/231012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112379, 8006, 'As Aventuras de Sunny Bunnies S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/231013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112380, 8006, 'As Aventuras de Sunny Bunnies S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/231014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112381, 8006, 'As Aventuras de Sunny Bunnies S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/231015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112382, 8006, 'As Aventuras de Sunny Bunnies S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/231016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112383, 8006, 'As Aventuras de Sunny Bunnies S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/231017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ukyveaMwh93oGvIoaGqcAmoV8AA.jpg'),
(112384, 8006, 'As Aventuras de Sunny Bunnies S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/231018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112385, 8006, 'As Aventuras de Sunny Bunnies S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/231019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112386, 8006, 'As Aventuras de Sunny Bunnies S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/231020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112387, 8006, 'As Aventuras de Sunny Bunnies S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/231021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112388, 8006, 'As Aventuras de Sunny Bunnies S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/231022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112389, 8006, 'As Aventuras de Sunny Bunnies S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/231023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112390, 8006, 'As Aventuras de Sunny Bunnies S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/231024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112391, 8006, 'As Aventuras de Sunny Bunnies S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/231025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112392, 8006, 'As Aventuras de Sunny Bunnies S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/231026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112393, 8007, 'As Aventuras de Sunny Bunnies S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112394, 8007, 'As Aventuras de Sunny Bunnies S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112395, 8007, 'As Aventuras de Sunny Bunnies S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112396, 8007, 'As Aventuras de Sunny Bunnies S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112397, 8007, 'As Aventuras de Sunny Bunnies S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112398, 8007, 'As Aventuras de Sunny Bunnies S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112399, 8007, 'As Aventuras de Sunny Bunnies S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112400, 8007, 'As Aventuras de Sunny Bunnies S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112401, 8007, 'As Aventuras de Sunny Bunnies S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112402, 8007, 'As Aventuras de Sunny Bunnies S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112403, 8007, 'As Aventuras de Sunny Bunnies S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/231037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112404, 8007, 'As Aventuras de Sunny Bunnies S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/231038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112405, 8007, 'As Aventuras de Sunny Bunnies S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/231039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112406, 8007, 'As Aventuras de Sunny Bunnies S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/231040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112407, 8007, 'As Aventuras de Sunny Bunnies S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/231041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112408, 8007, 'As Aventuras de Sunny Bunnies S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/231042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112409, 8007, 'As Aventuras de Sunny Bunnies S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/231043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112410, 8007, 'As Aventuras de Sunny Bunnies S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/231044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112411, 8007, 'As Aventuras de Sunny Bunnies S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/231045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112412, 8007, 'As Aventuras de Sunny Bunnies S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/231046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112413, 8007, 'As Aventuras de Sunny Bunnies S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/231047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112414, 8007, 'As Aventuras de Sunny Bunnies S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/231048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112415, 8007, 'As Aventuras de Sunny Bunnies S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/231049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112416, 8007, 'As Aventuras de Sunny Bunnies S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/231050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112417, 8007, 'As Aventuras de Sunny Bunnies S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/231051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112418, 8007, 'As Aventuras de Sunny Bunnies S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/231052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jPwQyT5XX8OcwDEC7ODEpMg6jkq.jpg'),
(112419, 8008, 'Ilha dos Desafios S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uVrDRVrubZUMRLXX9kUt1Ouw6kn.jpg'),
(112420, 8008, 'Ilha dos Desafios S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pLFKYnf3VgFajyFSIl2kyxOH1Pa.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(112421, 8008, 'Ilha dos Desafios S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Rvv9DtreLw6AJTvbWr0fbycTo3.jpg'),
(112422, 8008, 'Ilha dos Desafios S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rSpt2n3kF0xanXMQCpO1yVhwvx4.jpg'),
(112423, 8008, 'Ilha dos Desafios S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJVzLtfrlv3svMNSnJgPjdnW3H8.jpg'),
(112424, 8008, 'Ilha dos Desafios S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uxxjRAK3dJDOoA7GjpPqnEYSJUX.jpg'),
(112425, 8008, 'Ilha dos Desafios S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yU6GBbAfaTGmRvfTTxiCpDL4FFM.jpg'),
(112426, 8008, 'Ilha dos Desafios S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3DWRUaCfF8LH4VBqCWgkRUFZeSJ.jpg'),
(112427, 8008, 'Ilha dos Desafios S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDVQPLi674hIT2SNlfLaKRRMZVB.jpg'),
(112428, 8008, 'Ilha dos Desafios S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t1vuTLi6qtvfGFgqy979d4jGblv.jpg'),
(112429, 8008, 'Ilha dos Desafios S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zwg2t3XTMeLbjhUOgkBS8cKMkr6.jpg'),
(112430, 8008, 'Ilha dos Desafios S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gaxaSKAAleEVj1B4Pipk80QrlAg.jpg'),
(112431, 8008, 'Ilha dos Desafios S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/231000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dsLm35YQ5Jq0srEh9guBsW4gch.jpg'),
(112432, 8009, 'Jack Frost [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m5E9diQFPTZB8MXqXxVkq35f2dN.jpg'),
(112433, 8009, 'Jack Frost [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cYbYUiW24Bc2OSKt01Pz4yN78lw.jpg'),
(112434, 8009, 'Jack Frost [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2964fEIr1AYfwoPLNZh1TtHhKPA.jpg'),
(112435, 8009, 'Jack Frost [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w91q6l5MNReovWnsBXPass9oaLT.jpg'),
(112436, 8009, 'Jack Frost [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bqSAIVPjrhNPOUO6hLEChgiUk2f.jpg'),
(112437, 8009, 'Jack Frost [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kojRk2WhXavPJL6GXfL8MyI0WUB.jpg'),
(112438, 8010, 'O Fim do Mundo Com Você [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8RT4Zdesg8v5EhpkYfKUwP93dSn.jpg'),
(112439, 8010, 'O Fim do Mundo Com Você [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDod2RNazvyarTlrofLHqUHzwvW.jpg'),
(112440, 8010, 'O Fim do Mundo Com Você [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3gHoHveM6tzu3YxkNVJ3BzNyBQ8.jpg'),
(112441, 8010, 'O Fim do Mundo Com Você [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3mhyTr6UX5LLVTLZmepsrJK4B3F.jpg'),
(112442, 8010, 'O Fim do Mundo Com Você [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2CErXQJwXLt1q19plMBje90Cteq.jpg'),
(112443, 8010, 'O Fim do Mundo Com Você [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5NySBCjQKRtZo7Rq2SpvspgqFLM.jpg'),
(112444, 8010, 'O Fim do Mundo Com Você [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/avcIA4H8j4NRP5x5KTbo5g1H0ew.jpg'),
(112445, 8010, 'O Fim do Mundo Com Você [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/emQoy0wM6HbedNfv6hSvdI5b0uP.jpg'),
(112446, 8011, 'Our Dating Sim [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u5tvTB7PvibFqSB5BjtrEzKVV10.jpg'),
(112447, 8011, 'Our Dating Sim [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5hKrFYfbhgpOeVzL3O0fNCIXTy8.jpg'),
(112448, 8011, 'Our Dating Sim [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6sclo2ewivF4SAymVwL1lZhxI1p.jpg'),
(112449, 8011, 'Our Dating Sim [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sWO88qhELMojSwk7qTxJXu5XZPE.jpg'),
(112450, 8011, 'Our Dating Sim [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYEGrnsZnpmaGyzeUiynQMt3Vwz.jpg'),
(112451, 8011, 'Our Dating Sim [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4yOZ7ni33Pvx6lfX7UpCnH1bt6q.jpg'),
(112452, 8011, 'Our Dating Sim [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7cK5EkcNogVA5fOvitcRMCqfQP1.jpg'),
(112453, 8011, 'Our Dating Sim [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5VgdnGTFe7lTjLWTfXJKWj0qNPj.jpg'),
(112454, 8012, 'Planeta Estranho S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hodox0jbs6AxNT9kcNYv7p73eUc.jpg'),
(112455, 8012, 'Planeta Estranho S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mGiIQgLgAko01ssHAs04qeGVbld.jpg'),
(112456, 8012, 'Planeta Estranho S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gkBzOgFxVIr4hs8yUisXvP0HFJ6.jpg'),
(112457, 8012, 'Planeta Estranho S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234798.mp4', 'http://image.tmdb.org/t/p/w1280/wjB9BTw0oE03ENqQ46kPFahIwsD.jpg'),
(112458, 8012, 'Planeta Estranho S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234799.mp4', 'http://image.tmdb.org/t/p/w1280/urY0OnvTDUFoWR6NCiRhjvZlSVQ.jpg'),
(112459, 8012, 'Planeta Estranho S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234800.mp4', 'http://image.tmdb.org/t/p/w1280/pcbh5AYIHQKLO1u3G0h7DnlegSk.jpg'),
(112460, 8012, 'Planeta Estranho S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/blfTNwA1QSX85FjxJyiRiYQrELR.jpg'),
(112461, 8012, 'Planeta Estranho S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/blfTNwA1QSX85FjxJyiRiYQrELR.jpg'),
(112462, 8012, 'Planeta Estranho S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/blfTNwA1QSX85FjxJyiRiYQrELR.jpg'),
(112463, 8012, 'Planeta Estranho S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/blfTNwA1QSX85FjxJyiRiYQrELR.jpg'),
(112464, 8013, 'Primeiro as Damas: Mulheres no Hip-Hop S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dSZtuRvKrlKoJTQVSrNXDYiBcWT.jpg'),
(112465, 8013, 'Primeiro as Damas: Mulheres no Hip-Hop S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h4VwcCoLotxP0WYLXwWokwEpKyE.jpg'),
(112466, 8013, 'Primeiro as Damas: Mulheres no Hip-Hop S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fhkhBz43asRYCDuOaEowSU6Xe26.jpg'),
(112467, 8013, 'Primeiro as Damas: Mulheres no Hip-Hop S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5lJs5HlNwMt4zZxKvziG75QpO1Q.jpg'),
(112468, 8014, 'Regra do 80/20 do Amor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112469, 8014, 'Regra do 80/20 do Amor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112470, 8014, 'Regra do 80/20 do Amor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112471, 8014, 'Regra do 80/20 do Amor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112472, 8014, 'Regra do 80/20 do Amor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112473, 8014, 'Regra do 80/20 do Amor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112474, 8014, 'Regra do 80/20 do Amor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112475, 8014, 'Regra do 80/20 do Amor [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112476, 8014, 'Regra do 80/20 do Amor [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112477, 8014, 'Regra do 80/20 do Amor [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112478, 8014, 'Regra do 80/20 do Amor [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112479, 8014, 'Regra do 80/20 do Amor [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112480, 8014, 'Regra do 80/20 do Amor [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112481, 8014, 'Regra do 80/20 do Amor [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/230860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112482, 8014, 'Regra do 80/20 do Amor [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/230861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112483, 8014, 'Regra do 80/20 do Amor [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/230862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112484, 8014, 'Regra do 80/20 do Amor [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/230863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112485, 8014, 'Regra do 80/20 do Amor [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/230864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112486, 8014, 'Regra do 80/20 do Amor [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/230865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112487, 8014, 'Regra do 80/20 do Amor [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/230866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112488, 8014, 'Regra do 80/20 do Amor [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/230867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112489, 8014, 'Regra do 80/20 do Amor [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/230868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112490, 8014, 'Regra do 80/20 do Amor [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/230869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112491, 8014, 'Regra do 80/20 do Amor [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/230870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112492, 8014, 'Regra do 80/20 do Amor [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/230871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112493, 8014, 'Regra do 80/20 do Amor [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/230872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112494, 8014, 'Regra do 80/20 do Amor [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/230873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112495, 8014, 'Regra do 80/20 do Amor [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/230874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112496, 8014, 'Regra do 80/20 do Amor [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/230875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112497, 8014, 'Regra do 80/20 do Amor [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/230876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112498, 8014, 'Regra do 80/20 do Amor [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/230877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112499, 8014, 'Regra do 80/20 do Amor [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/230878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112500, 8014, 'Regra do 80/20 do Amor [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/230879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112501, 8014, 'Regra do 80/20 do Amor [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/230880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112502, 8014, 'Regra do 80/20 do Amor [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/230881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112503, 8014, 'Regra do 80/20 do Amor [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/230882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112504, 8014, 'Regra do 80/20 do Amor [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/230883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112505, 8014, 'Regra do 80/20 do Amor [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/230884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112506, 8014, 'Regra do 80/20 do Amor [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/230885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112507, 8014, 'Regra do 80/20 do Amor [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/230886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sO3JXsf28koD6sdK3uAvkCC5RiI.jpg'),
(112508, 8015, 'Survivor\'s Remorse S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z6IAw9rZd5l1T5aEAK8SiNgqsF.jpg'),
(112509, 8015, 'Survivor\'s Remorse S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7mQrJTYcozBjs3ZD9IShlL24R2M.jpg'),
(112510, 8015, 'Survivor\'s Remorse S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rWwJulNaLfkQ4VbnIQSBmYUxAtn.jpg'),
(112511, 8015, 'Survivor\'s Remorse S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n3zfumLlqgyBiiXiOoUTfUNS9bU.jpg'),
(112512, 8015, 'Survivor\'s Remorse S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/af6U8FsoBFY7oHuMpcKfguZTCDg.jpg'),
(112513, 8015, 'Survivor\'s Remorse S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lmnOJFcGe434HiFOlQTRQs0KRJe.jpg'),
(112514, 8016, 'Survivor\'s Remorse S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aKGQL59nhxa89LRUhAhukYQgFgE.jpg'),
(112515, 8016, 'Survivor\'s Remorse S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jNWIxdbqXt3RWiZUiE3TsEeIike.jpg'),
(112516, 8016, 'Survivor\'s Remorse S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7mtv6KgqIImr4X7exunlGwIMqF2.jpg'),
(112517, 8016, 'Survivor\'s Remorse S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yOB3P5mF3AIgPUJnDnY7EPx3IXB.jpg'),
(112518, 8016, 'Survivor\'s Remorse S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dfoTaFcIb7M1lCbFgjhbFb14GF.jpg'),
(112519, 8016, 'Survivor\'s Remorse S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lsqoSNHgDPPkFbNq3QsUWU92BBm.jpg'),
(112520, 8016, 'Survivor\'s Remorse S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jwb3FDQuF3BzN6vBXqISZaZuTRm.jpg'),
(112521, 8016, 'Survivor\'s Remorse S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6fN2Y9QJtTCZcksUPEH7S5BUyw5.jpg'),
(112522, 8016, 'Survivor\'s Remorse S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zYtdcZZw1sXZbJJzyuHVdVEwGuu.jpg'),
(112523, 8016, 'Survivor\'s Remorse S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mdCsWfPcJVf8PGKLXAMnbD05rxL.jpg'),
(112524, 8017, 'Survivor\'s Remorse S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8eLgMh6wQ1WgFIDWvHKYIn0UaKc.jpg'),
(112525, 8017, 'Survivor\'s Remorse S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bwPeZ4lomIDS4ynCBaGCDACksuF.jpg'),
(112526, 8017, 'Survivor\'s Remorse S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wQUN9VWa5NYURVrqBCcvvZoClUu.jpg'),
(112527, 8017, 'Survivor\'s Remorse S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lRcp8AMKJdKQlEH9fWEDRuSXBYw.jpg'),
(112528, 8017, 'Survivor\'s Remorse S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hTPTwepSYVXRyS7jEAEXv3Ulrzu.jpg'),
(112529, 8017, 'Survivor\'s Remorse S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSy6GE7VLNhKXNdmcp1t5OKA0NB.jpg'),
(112530, 8017, 'Survivor\'s Remorse S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sxLYYZFRmuD9vijnm9QQABeZG2D.jpg'),
(112531, 8017, 'Survivor\'s Remorse S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rnypP6gEWaYXlUPWOzHNpm1qFlD.jpg'),
(112532, 8017, 'Survivor\'s Remorse S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bRytQ4iqg37xwoCoDZFJTBpzFuY.jpg'),
(112533, 8017, 'Survivor\'s Remorse S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/soRVfl6UjySjr59G879AkIfX2sK.jpg'),
(112534, 8018, 'Survivor\'s Remorse S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wrrdaBWAWaiiwPwJNbGg5xE3IEh.jpg'),
(112535, 8018, 'Survivor\'s Remorse S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kMjOkHYdmV8yQREFXYASTBScxnz.jpg'),
(112536, 8018, 'Survivor\'s Remorse S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oayGFU9ODi1f61NYuBMUMjxBa8F.jpg'),
(112537, 8018, 'Survivor\'s Remorse S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzGgPYRQxBcXVPYwKvDkciu806e.jpg'),
(112538, 8018, 'Survivor\'s Remorse S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fEnQOLvFJQxXjkyMWubum7pvted.jpg'),
(112539, 8018, 'Survivor\'s Remorse S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aw2pJtvAlassJ9vghMYoARYZh4g.jpg'),
(112540, 8018, 'Survivor\'s Remorse S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/820hpyTIqHhixfBWvwmWgzVPk0r.jpg'),
(112541, 8018, 'Survivor\'s Remorse S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ouC3cq1oSzuALB7B4K03Ce6UCBH.jpg'),
(112542, 8018, 'Survivor\'s Remorse S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oBcBXHYrHACjJHrUVadTmAQQQjh.jpg'),
(112543, 8018, 'Survivor\'s Remorse S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dQe6GiyuG6ieq0TWLSnCwWGeFWo.jpg'),
(112544, 8019, 'O Oitavo Sentido [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xEbvLTnI9stNUJEtGTzUsRrkRie.jpg'),
(112545, 8019, 'O Oitavo Sentido [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x2dmAxfrFymMLcb3HfdnPoEWzNI.jpg'),
(112546, 8019, 'O Oitavo Sentido [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x2dmAxfrFymMLcb3HfdnPoEWzNI.jpg'),
(112547, 8019, 'O Oitavo Sentido [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x2dmAxfrFymMLcb3HfdnPoEWzNI.jpg'),
(112548, 8019, 'O Oitavo Sentido [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x2dmAxfrFymMLcb3HfdnPoEWzNI.jpg'),
(112549, 8019, 'O Oitavo Sentido [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x2dmAxfrFymMLcb3HfdnPoEWzNI.jpg'),
(112550, 8019, 'O Oitavo Sentido [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x2dmAxfrFymMLcb3HfdnPoEWzNI.jpg'),
(112551, 8019, 'O Oitavo Sentido [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x2dmAxfrFymMLcb3HfdnPoEWzNI.jpg'),
(112552, 8019, 'O Oitavo Sentido [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x2dmAxfrFymMLcb3HfdnPoEWzNI.jpg'),
(112553, 8019, 'O Oitavo Sentido [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x2dmAxfrFymMLcb3HfdnPoEWzNI.jpg'),
(112554, 8020, 'The Ferragnez: La Serie [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pGVVMFfc17SwMazWT5G6Ix3zhY4.jpg'),
(112555, 8020, 'The Ferragnez: La Serie [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Sh5geLQVDtWYTozfE3Om87Ueax.jpg'),
(112556, 8020, 'The Ferragnez: La Serie [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7BJuewp91lC4rAqNiBrVJCjJhb.jpg'),
(112557, 8020, 'The Ferragnez: La Serie [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wk6aANQ5uQCFaSc1vzAPLKqoOGR.jpg'),
(112558, 8020, 'The Ferragnez: La Serie [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4BnZKDTbDCAX1TIOLNQJVEl40BR.jpg'),
(112559, 8020, 'The Ferragnez: La Serie [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3WMrU42symSz6shkpvn0fOmXH2T.jpg'),
(112560, 8020, 'The Ferragnez: La Serie [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7BVpPDv9jZHpMnOplmIvPiTagDk.jpg'),
(112561, 8020, 'The Ferragnez: La Serie [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x1XNheB4Pt6MHLrvgjihsUbssj9.jpg'),
(112562, 8021, 'The Ferragnez: La Serie [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i9T3Zlxy51Iojcy5pj8aGSv6yVR.jpg'),
(112563, 8021, 'The Ferragnez: La Serie [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iF5BPPuqRyhODafMC2I1uKhzBhf.jpg'),
(112564, 8021, 'The Ferragnez: La Serie [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tZtlP2GkF5ZC7pvV9wFGfsUPr9X.jpg'),
(112565, 8021, 'The Ferragnez: La Serie [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8H7Q8yIHdKcHGar24RTVaD1NzFs.jpg'),
(112566, 8022, 'The Fox\'s Summer [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zsnLAmGETwcE3BC2R2G0lX5NuL1.jpg'),
(112567, 8022, 'The Fox\'s Summer [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ke9RVXMmPDjx7L7mzbGsnZb1pIr.jpg'),
(112568, 8022, 'The Fox\'s Summer [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yKINC6ZDEfOtPzTYwSNVgBdaHck.jpg'),
(112569, 8022, 'The Fox\'s Summer [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5QOvH4Rd61EQAQtmSGgLEMbnrIw.jpg'),
(112570, 8022, 'The Fox\'s Summer [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ruc7Jq6b7pXxoIakJlz8KTZ8jdE.jpg'),
(112571, 8022, 'The Fox\'s Summer [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oBSDsiFjbeZ49Y6NnDmb4aawFyO.jpg'),
(112572, 8022, 'The Fox\'s Summer [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dXxfGJKU9VguSyTKoUsQPcihCd1.jpg'),
(112573, 8022, 'The Fox\'s Summer [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ggzwZWUPFEcPS5KcseyKIS6GS71.jpg'),
(112574, 8022, 'The Fox\'s Summer [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJxZuCwduSCs96hnmZbgqlXB19I.jpg'),
(112575, 8022, 'The Fox\'s Summer [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/juM8Pmbxf8fvUMgG49FVoL9gl77.jpg'),
(112576, 8022, 'The Fox\'s Summer [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mnASETIelYghwHRFXf13DQXj22d.jpg'),
(112577, 8022, 'The Fox\'s Summer [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/itoargUmMWr1JhkKBLbJtBq0Jqb.jpg'),
(112578, 8022, 'The Fox\'s Summer [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c2UxTbZZH4YRXcxiNJpCeX3jfQF.jpg'),
(112579, 8022, 'The Fox\'s Summer [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/230758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wi8fvEmIQuV5Q4aLfTdwbqeeUIk.jpg'),
(112580, 8022, 'The Fox\'s Summer [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/230759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zOVdhelThYjo4Dmvi281NruiNyR.jpg'),
(112581, 8022, 'The Fox\'s Summer [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/230760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pMhqQljbDtJPtyvjstp4K7HLKf8.jpg'),
(112582, 8022, 'The Fox\'s Summer [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/230761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/imrCKulroBU5uhg1HDHlRHoI8sW.jpg'),
(112583, 8022, 'The Fox\'s Summer [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/230762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pHSgYJMTZH9vEdI5xDw5RSvO4Fc.jpg'),
(112584, 8022, 'The Fox\'s Summer [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/230763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5FMtwcrRZBtJHAfMDsdJQplSZli.jpg'),
(112585, 8022, 'The Fox\'s Summer [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/230764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oWfwytF5efXEgNdRG9OvF3yxSmv.jpg'),
(112586, 8022, 'The Fox\'s Summer [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/230765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v6ZLqUikiLwgUUWLuluaKvjE4jP.jpg'),
(112587, 8023, 'The Fox\'s Summer [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/imVP5ga0mO4NiME3sR9InqOuAwZ.jpg'),
(112588, 8023, 'The Fox\'s Summer [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1uGbNMqDSzuRF6XedkaAmZ3j4r2.jpg'),
(112589, 8023, 'The Fox\'s Summer [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8en7Kx7iVpbGg2Vcab1Up1wZ2m.jpg'),
(112590, 8023, 'The Fox\'s Summer [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l2oW1rutcLU1zYzZnmnofCNsGY1.jpg'),
(112591, 8023, 'The Fox\'s Summer [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j2szrVniveswipTqc77VJd9fMt6.jpg'),
(112592, 8023, 'The Fox\'s Summer [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ovCOlSU00mkUieGhzYdGrXULoYt.jpg'),
(112593, 8023, 'The Fox\'s Summer [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/XjEtclEYbZjVskaH3mpdzQXSMO.jpg'),
(112594, 8023, 'The Fox\'s Summer [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qYNeDPp8B8NEWoDHsGJ7Z93s1hG.jpg'),
(112595, 8023, 'The Fox\'s Summer [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/spp1gP3exBOPIFRWjbFUqnV0Wuh.jpg'),
(112596, 8023, 'The Fox\'s Summer [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uiukZerqmN8mwdtpYRaWIkeRsu3.jpg'),
(112597, 8023, 'The Fox\'s Summer [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AihA23ZXzyESFn31nkDlF1fRgaZ.jpg'),
(112598, 8023, 'The Fox\'s Summer [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FBnfN1B4CavFBFRUhS0bvbbtZN.jpg'),
(112599, 8023, 'The Fox\'s Summer [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ixNB3aD1ix6cvRtbSFl05JzQR2.jpg'),
(112600, 8023, 'The Fox\'s Summer [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/230779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vfrWC8szth5R2yr7KCF8sTDAr5m.jpg'),
(112601, 8023, 'The Fox\'s Summer [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/230780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aYruax6SBJ0GhfgyGG4ut8rjGPI.jpg'),
(112602, 8023, 'The Fox\'s Summer [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/230781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A6hJi4I8nPeOZUhG51VXUi8LYTP.jpg'),
(112603, 8023, 'The Fox\'s Summer [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/230782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/SLjsbKcLjNPSQS0gNKnw7oIxbx.jpg'),
(112604, 8023, 'The Fox\'s Summer [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/230783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9MTNJSzlqBpDDIrnjeigx3rJruQ.jpg'),
(112605, 8023, 'The Fox\'s Summer [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/230784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkcHhHgsYhKTKcaUkbqXmGm8gaX.jpg'),
(112606, 8023, 'The Fox\'s Summer [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/230785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AjjfwSOGOOLhhIbXSj36FrkHozb.jpg'),
(112607, 8023, 'The Fox\'s Summer [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/230786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hvblWyqXRBCICzVI9s2dr4MmZy1.jpg'),
(112608, 8023, 'The Fox\'s Summer [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/230787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6IclprVSZJgN1ShcfJSsYPio8ok.jpg'),
(112609, 8023, 'The Fox\'s Summer [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/230788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63f3UCumQqscrtUk3d0asBCa76k.jpg'),
(112610, 8024, 'The Hunt for Veerappan [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qeKU7aiBqKCUCC2JVr2phorhyJR.jpg'),
(112611, 8024, 'The Hunt for Veerappan [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tN3s9xuhBDCfQ4xi2MbJKKHhZSv.jpg'),
(112612, 8024, 'The Hunt for Veerappan [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wrE0zdxnonIqI367diIyNHVQZLJ.jpg'),
(112613, 8024, 'The Hunt for Veerappan [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ozfQOn3fByl8Vz2I82unij3lxVi.jpg'),
(112614, 8025, 'Hotéis Incríveis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112615, 8025, 'Hotéis Incríveis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112616, 8025, 'Hotéis Incríveis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112617, 8025, 'Hotéis Incríveis S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112618, 8025, 'Hotéis Incríveis S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112619, 8025, 'Hotéis Incríveis S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112620, 8025, 'Hotéis Incríveis S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112621, 8025, 'Hotéis Incríveis S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112622, 8025, 'Hotéis Incríveis S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112623, 8025, 'Hotéis Incríveis S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112624, 8025, 'Hotéis Incríveis S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112625, 8025, 'Hotéis Incríveis S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112626, 8025, 'Hotéis Incríveis S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112627, 8026, 'Hotéis Incríveis S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112628, 8026, 'Hotéis Incríveis S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112629, 8026, 'Hotéis Incríveis S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112630, 8026, 'Hotéis Incríveis S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112631, 8026, 'Hotéis Incríveis S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112632, 8026, 'Hotéis Incríveis S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112633, 8026, 'Hotéis Incríveis S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112634, 8026, 'Hotéis Incríveis S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112635, 8026, 'Hotéis Incríveis S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112636, 8026, 'Hotéis Incríveis S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112637, 8026, 'Hotéis Incríveis S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112638, 8026, 'Hotéis Incríveis S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112639, 8026, 'Hotéis Incríveis S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112640, 8027, 'Hotéis Incríveis S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112641, 8027, 'Hotéis Incríveis S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112642, 8027, 'Hotéis Incríveis S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112643, 8027, 'Hotéis Incríveis S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112644, 8027, 'Hotéis Incríveis S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112645, 8027, 'Hotéis Incríveis S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112646, 8027, 'Hotéis Incríveis S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112647, 8027, 'Hotéis Incríveis S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112648, 8027, 'Hotéis Incríveis S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112649, 8027, 'Hotéis Incríveis S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112650, 8027, 'Hotéis Incríveis S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112651, 8027, 'Hotéis Incríveis S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112652, 8027, 'Hotéis Incríveis S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112653, 8028, 'Hotéis Incríveis S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112654, 8028, 'Hotéis Incríveis S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112655, 8028, 'Hotéis Incríveis S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112656, 8028, 'Hotéis Incríveis S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112657, 8028, 'Hotéis Incríveis S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112658, 8028, 'Hotéis Incríveis S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112659, 8028, 'Hotéis Incríveis S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112660, 8028, 'Hotéis Incríveis S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112661, 8028, 'Hotéis Incríveis S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112662, 8028, 'Hotéis Incríveis S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112663, 8028, 'Hotéis Incríveis S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112664, 8028, 'Hotéis Incríveis S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112665, 8028, 'Hotéis Incríveis S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112666, 8029, 'Hotéis Incríveis S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112667, 8029, 'Hotéis Incríveis S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112668, 8029, 'Hotéis Incríveis S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112669, 8029, 'Hotéis Incríveis S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112670, 8029, 'Hotéis Incríveis S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112671, 8029, 'Hotéis Incríveis S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112672, 8029, 'Hotéis Incríveis S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112673, 8029, 'Hotéis Incríveis S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112674, 8029, 'Hotéis Incríveis S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112675, 8029, 'Hotéis Incríveis S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112676, 8030, 'Hotéis Incríveis S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112677, 8030, 'Hotéis Incríveis S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(112678, 8030, 'Hotéis Incríveis S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112679, 8030, 'Hotéis Incríveis S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112680, 8030, 'Hotéis Incríveis S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112681, 8030, 'Hotéis Incríveis S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112682, 8030, 'Hotéis Incríveis S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112683, 8030, 'Hotéis Incríveis S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112684, 8030, 'Hotéis Incríveis S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112685, 8030, 'Hotéis Incríveis S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112686, 8030, 'Hotéis Incríveis S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112687, 8030, 'Hotéis Incríveis S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112688, 8030, 'Hotéis Incríveis S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xU6qDklvfPFo0X5DUb9Qd6f3t.jpg'),
(112689, 8031, 'Em Movimento [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzmsts2DLrQSeWZS3HA9DFyYVML.jpg'),
(112690, 8031, 'Em Movimento [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e4ilufN512VeAvozhkVmafnL8YI.jpg'),
(112691, 8031, 'Em Movimento [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rUz3yxUpJUmjJlRIy6bZjMelFjB.jpg'),
(112692, 8031, 'Em Movimento [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vc2ydZmrEEWZc79U6KoI1vDhmkg.jpg'),
(112693, 8031, 'Em Movimento [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8EZov2D9DClbDu78feZZIT3iJdH.jpg'),
(112694, 8031, 'Em Movimento [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cXZ1zIpno8XPAgkBUGSX3hqi8T.jpg'),
(112695, 8031, 'Em Movimento [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fWfIG4n3Bgfaovfm1whBThuwLUa.jpg'),
(112696, 8031, 'Em Movimento [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236471.mp4', 'http://image.tmdb.org/t/p/w1280/eICfp1hJNiZqCTUzelnyRWozaJ2.jpg'),
(112697, 8031, 'Em Movimento [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236472.mp4', 'http://image.tmdb.org/t/p/w1280/to9IVB8gTD1XXBovN0W0tyNufWF.jpg'),
(112698, 8031, 'Em Movimento [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236473.mp4', 'http://image.tmdb.org/t/p/w1280/uBXfPgFKmTQOVir5pcddoasjAw5.jpg'),
(112699, 8031, 'Em Movimento [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236474.mp4', 'http://image.tmdb.org/t/p/w1280/fxpv1CNnfN72rjOm9cpbh2vFJCZ.jpg'),
(112700, 8031, 'Em Movimento [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236475.mp4', 'http://image.tmdb.org/t/p/w1280/kaHcyUhawF1R3bC063GmLG0nCod.jpg'),
(112701, 8031, 'Em Movimento [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236476.mp4', 'http://image.tmdb.org/t/p/w1280/6XQuFG42gdJA8LXHUAmD1aeywfg.jpg'),
(112702, 8031, 'Em Movimento [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236477.mp4', 'http://image.tmdb.org/t/p/w1280/vJtRzxiC0JKyD4tV0YtNRjWIrpY.jpg'),
(112703, 8031, 'Em Movimento [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236478.mp4', 'http://image.tmdb.org/t/p/w1280/31rJUgq5H3tm6in5BOHu8icRneM.jpg'),
(112704, 8031, 'Em Movimento [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0TNzLe84uFXF0fqwbPbCYOB2Fk.jpg'),
(112705, 8031, 'Em Movimento [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0TNzLe84uFXF0fqwbPbCYOB2Fk.jpg'),
(112706, 8031, 'Em Movimento [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0TNzLe84uFXF0fqwbPbCYOB2Fk.jpg'),
(112707, 8031, 'Em Movimento [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/236482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0TNzLe84uFXF0fqwbPbCYOB2Fk.jpg'),
(112708, 8031, 'Em Movimento [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/236483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0TNzLe84uFXF0fqwbPbCYOB2Fk.jpg'),
(112709, 8032, 'Império da Dor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xiSm3vG43T7NxlcCxkBYHJ9G7KE.jpg'),
(112710, 8032, 'Império da Dor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sffbWfWC2p4mezxDFBhkS16c79T.jpg'),
(112711, 8032, 'Império da Dor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A7Wx8jCEzRdnpsbM9DC7FMMicRD.jpg'),
(112712, 8032, 'Império da Dor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/HSHwcRinQHHaHm3ee7eLj3xC3p.jpg'),
(112713, 8032, 'Império da Dor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q8M5kk83VYqLFTBi5Xztpul0Xzk.jpg'),
(112714, 8032, 'Império da Dor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xM5KVAUKXaVECKf0hNSS69tEGLb.jpg'),
(112715, 8033, 'Louvada Seja Petey [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tc4SsHADvySs7dOcdiudx45yEPn.jpg'),
(112716, 8033, 'Louvada Seja Petey [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ntBDHlg94pgBObfeE2bAVaJvXjw.jpg'),
(112717, 8033, 'Louvada Seja Petey [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231892.mp4', 'http://image.tmdb.org/t/p/w1280/9pnJjxDeN4mHlc42Ou79D62RRcx.jpg'),
(112718, 8033, 'Louvada Seja Petey [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231893.mp4', 'http://image.tmdb.org/t/p/w1280/kZDZjjJ0PK9z8rbiXI3HM8VJYEM.jpg'),
(112719, 8033, 'Louvada Seja Petey [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qPsOk0BhyX4XDufBSbmLnZFMJo9.jpg'),
(112720, 8033, 'Louvada Seja Petey [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ps6rszXfvWe31ChyZoWXQZ1BVLY.jpg'),
(112721, 8033, 'Louvada Seja Petey [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mhbQukxUCpoqFDkvOTNnNrAnJe4.jpg'),
(112722, 8033, 'Louvada Seja Petey [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mq9crnynEUsPaKOVF044I9ilX39.jpg'),
(112723, 8033, 'Louvada Seja Petey [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8PQCgunLQH2k4gJcPdifEI7ngX4.jpg'),
(112724, 8033, 'Louvada Seja Petey [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pF3SBeEuazJScPsZQqx41NJqlM2.jpg'),
(112725, 8034, 'Minha Crush Esqueceu os Óculos [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wcn78sZuFsQ5CpqMhh6znqsdIlm.jpg'),
(112726, 8034, 'Minha Crush Esqueceu os Óculos [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aOrtRHmSjsyJPdXDm8ZZJ4l8gck.jpg'),
(112727, 8034, 'Minha Crush Esqueceu os Óculos [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7hi0q2L1rG0YiIQrj6whK2rMyS.jpg'),
(112728, 8034, 'Minha Crush Esqueceu os Óculos [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jcRZO2DszO2PNxVQCERa5QCTh5p.jpg'),
(112729, 8034, 'Minha Crush Esqueceu os Óculos [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/csGlvyN3QtlaoNPy3nTzCanBafv.jpg'),
(112730, 8034, 'Minha Crush Esqueceu os Óculos [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h3lDgFj2llpBxqUsAthcLZS7ldo.jpg'),
(112731, 8034, 'Minha Crush Esqueceu os Óculos [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/76mprLhXILnPtnBr8VBoFxIpx5i.jpg'),
(112732, 8034, 'Minha Crush Esqueceu os Óculos [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/76mprLhXILnPtnBr8VBoFxIpx5i.jpg'),
(112733, 8034, 'Minha Crush Esqueceu os Óculos [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/76mprLhXILnPtnBr8VBoFxIpx5i.jpg'),
(112734, 8034, 'Minha Crush Esqueceu os Óculos [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/76mprLhXILnPtnBr8VBoFxIpx5i.jpg'),
(112735, 8034, 'Minha Crush Esqueceu os Óculos [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/76mprLhXILnPtnBr8VBoFxIpx5i.jpg'),
(112736, 8034, 'Minha Crush Esqueceu os Óculos [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/76mprLhXILnPtnBr8VBoFxIpx5i.jpg'),
(112737, 8034, 'Minha Crush Esqueceu os Óculos [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/76mprLhXILnPtnBr8VBoFxIpx5i.jpg'),
(112738, 8035, 'Os Cadetes Mech S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gajhxRliZwOfqucq57V5sVQacGR.jpg'),
(112739, 8035, 'Os Cadetes Mech S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gajhxRliZwOfqucq57V5sVQacGR.jpg'),
(112740, 8035, 'Os Cadetes Mech S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gajhxRliZwOfqucq57V5sVQacGR.jpg'),
(112741, 8035, 'Os Cadetes Mech S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gajhxRliZwOfqucq57V5sVQacGR.jpg'),
(112742, 8035, 'Os Cadetes Mech S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gajhxRliZwOfqucq57V5sVQacGR.jpg'),
(112743, 8035, 'Os Cadetes Mech S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gajhxRliZwOfqucq57V5sVQacGR.jpg'),
(112744, 8035, 'Os Cadetes Mech S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gajhxRliZwOfqucq57V5sVQacGR.jpg'),
(112745, 8035, 'Os Cadetes Mech S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gajhxRliZwOfqucq57V5sVQacGR.jpg'),
(112746, 8035, 'Os Cadetes Mech S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gajhxRliZwOfqucq57V5sVQacGR.jpg'),
(112747, 8035, 'Os Cadetes Mech S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gajhxRliZwOfqucq57V5sVQacGR.jpg'),
(112748, 8036, 'Behind Your Touch S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/waltpS1I6KMnCsN0nWzQr7cOuCS.jpg'),
(112749, 8036, 'Behind Your Touch S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vB7livIVXJFWoQMd49d3gCIYe8r.jpg'),
(112750, 8036, 'Behind Your Touch S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238431.mp4', 'http://image.tmdb.org/t/p/w1280/bnVY9F4jyRSfuzidQD9rQ71m98t.jpg'),
(112751, 8036, 'Behind Your Touch S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238432.mp4', 'http://image.tmdb.org/t/p/w1280/8VJCjLUa3foJlGgVDYku4qjWN06.jpg'),
(112752, 8036, 'Behind Your Touch S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AizUiSXFJ5Rop7VGJBu22TOQJ8K.jpg'),
(112753, 8036, 'Behind Your Touch S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xzngaglTqMVVICyJnvSn4PDaZOz.jpg'),
(112754, 8036, 'Behind Your Touch S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238435.mp4', 'http://image.tmdb.org/t/p/w1280/uIMmuSjIFslvLmqKYFAfvvrptrq.jpg'),
(112755, 8036, 'Behind Your Touch S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238436.mp4', 'http://image.tmdb.org/t/p/w1280/QjfLDPAWTBWxmJcz5CSy7f6rnP.jpg'),
(112756, 8036, 'Behind Your Touch S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h04dFQwpXXDLfFRK6ZONjtR4HDT.jpg'),
(112757, 8036, 'Behind Your Touch S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h04dFQwpXXDLfFRK6ZONjtR4HDT.jpg'),
(112758, 8036, 'Behind Your Touch S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/238439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h04dFQwpXXDLfFRK6ZONjtR4HDT.jpg'),
(112759, 8036, 'Behind Your Touch S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/238440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h04dFQwpXXDLfFRK6ZONjtR4HDT.jpg'),
(112760, 8036, 'Behind Your Touch S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/238441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h04dFQwpXXDLfFRK6ZONjtR4HDT.jpg'),
(112761, 8036, 'Behind Your Touch S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/238442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h04dFQwpXXDLfFRK6ZONjtR4HDT.jpg'),
(112762, 8036, 'Behind Your Touch S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/238443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h04dFQwpXXDLfFRK6ZONjtR4HDT.jpg'),
(112763, 8036, 'Behind Your Touch S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/238444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h04dFQwpXXDLfFRK6ZONjtR4HDT.jpg'),
(112764, 8037, 'Horimiya: Piece S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jjZAGXlR4oyXf8wYMCqIFNCfwrW.jpg'),
(112765, 8037, 'Horimiya: Piece S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ixTgSlaowwgxG9lJWMfUHqDoMn.jpg'),
(112766, 8037, 'Horimiya: Piece S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gAyNhyn48IrXzzhp2BLZznd430a.jpg'),
(112767, 8037, 'Horimiya: Piece S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnGb4NYOyRfCl5DKYPIK9A0Cgww.jpg'),
(112768, 8037, 'Horimiya: Piece S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnGb4NYOyRfCl5DKYPIK9A0Cgww.jpg'),
(112769, 8037, 'Horimiya: Piece S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnGb4NYOyRfCl5DKYPIK9A0Cgww.jpg'),
(112770, 8037, 'Horimiya: Piece S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnGb4NYOyRfCl5DKYPIK9A0Cgww.jpg'),
(112771, 8037, 'Horimiya: Piece S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnGb4NYOyRfCl5DKYPIK9A0Cgww.jpg'),
(112772, 8037, 'Horimiya: Piece S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnGb4NYOyRfCl5DKYPIK9A0Cgww.jpg'),
(112773, 8037, 'Horimiya: Piece S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnGb4NYOyRfCl5DKYPIK9A0Cgww.jpg'),
(112774, 8037, 'Horimiya: Piece S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnGb4NYOyRfCl5DKYPIK9A0Cgww.jpg'),
(112775, 8037, 'Horimiya: Piece S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnGb4NYOyRfCl5DKYPIK9A0Cgww.jpg'),
(112776, 8037, 'Horimiya: Piece S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnGb4NYOyRfCl5DKYPIK9A0Cgww.jpg'),
(112777, 8038, 'Louca Compulsão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/olk8f8fieRLM0nhpMsj7QG7VLC4.jpg'),
(112778, 8038, 'Louca Compulsão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sWkqSDt3tQBVVRTWH3UvNT6AESe.jpg'),
(112779, 8038, 'Louca Compulsão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112780, 8038, 'Louca Compulsão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zP2jmgwIuumweEY3S2AeGTeOLtF.jpg'),
(112781, 8038, 'Louca Compulsão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112782, 8038, 'Louca Compulsão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112783, 8038, 'Louca Compulsão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h4GXO1i7zdWeFpLdAmwiCdpXq0i.jpg'),
(112784, 8038, 'Louca Compulsão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5qbyr8Hz9J7G3mdLceKGjcfrSy9.jpg'),
(112785, 8038, 'Louca Compulsão S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/heTyAF824kRPZfAHOUllVxYAhnr.jpg'),
(112786, 8038, 'Louca Compulsão S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hoD0Rs4G9npGkQR2LiSOnhZyGgB.jpg'),
(112787, 8038, 'Louca Compulsão S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dsir3DsLbpPCXyZIdOy0RSqU22a.jpg'),
(112788, 8038, 'Louca Compulsão S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/39osBoEYzMjiGqnkG1fBW4qp5VI.jpg'),
(112789, 8039, 'Louca Compulsão S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rXk9laIemiSDSjoy8KsAaBjtBJn.jpg'),
(112790, 8039, 'Louca Compulsão S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kD3lFi6e5OUOBKWdjUowhOeocDm.jpg'),
(112791, 8039, 'Louca Compulsão S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9wHnowZfNquNIKh6OWaOJoRewgs.jpg'),
(112792, 8039, 'Louca Compulsão S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6WjFcM5EbOJrKEQ8tz9VLvvsPZo.jpg'),
(112793, 8039, 'Louca Compulsão S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nl0pxzPKurQkV0Nn7KKYdrF6QYs.jpg'),
(112794, 8039, 'Louca Compulsão S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5FavMjzbyvab5kVahyk563fUhQ.jpg'),
(112795, 8039, 'Louca Compulsão S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yymEOrYchRrTfATf1SSY8FPQyYP.jpg'),
(112796, 8039, 'Louca Compulsão S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mLMQ59VZyag06KkL3TcUT0bRHht.jpg'),
(112797, 8040, 'Louca Compulsão S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Anjhqv095b9GaPltce7FPz7zO3r.jpg'),
(112798, 8040, 'Louca Compulsão S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1IIxYPWV2dYvlw01U1YHvAOUkK4.jpg'),
(112799, 8040, 'Louca Compulsão S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a7nnudysnxhRn8MOoaB7IM5NdTP.jpg'),
(112800, 8040, 'Louca Compulsão S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6tyTDsdmryTfOmRcVlht6H6xkeI.jpg'),
(112801, 8040, 'Louca Compulsão S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xPJQkcwchxBcFyQkRIoIdDuan7t.jpg'),
(112802, 8040, 'Louca Compulsão S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/se1aUublpk9wW4OehrLL0rz1ngL.jpg'),
(112803, 8040, 'Louca Compulsão S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uIEe4iLmtmX4VXGoVABLpqopDK2.jpg'),
(112804, 8040, 'Louca Compulsão S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6v7kts4bkFFatVmBmZ0JJ5dLHzJ.jpg'),
(112805, 8041, 'Louca Compulsão S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112806, 8041, 'Louca Compulsão S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112807, 8041, 'Louca Compulsão S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112808, 8041, 'Louca Compulsão S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112809, 8041, 'Louca Compulsão S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112810, 8041, 'Louca Compulsão S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112811, 8041, 'Louca Compulsão S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112812, 8041, 'Louca Compulsão S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112813, 8042, 'Louca Compulsão S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112814, 8042, 'Louca Compulsão S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112815, 8042, 'Louca Compulsão S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112816, 8042, 'Louca Compulsão S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112817, 8042, 'Louca Compulsão S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112818, 8042, 'Louca Compulsão S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112819, 8043, 'Louca Compulsão S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112820, 8043, 'Louca Compulsão S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112821, 8043, 'Louca Compulsão S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112822, 8043, 'Louca Compulsão S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112823, 8043, 'Louca Compulsão S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/znKnFFSk0bcXqijgfYfVY687Cjl.jpg'),
(112824, 8044, 'Maldito Rap S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tCqTncgBZxOB3CHsHubz2ZP12It.jpg'),
(112825, 8044, 'Maldito Rap S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8y7thWix4khAgQig1F2jj2oe6ys.jpg'),
(112826, 8044, 'Maldito Rap S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8PgsY1Psc5lopJB6ITuK0UnUwHZ.jpg'),
(112827, 8044, 'Maldito Rap S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6qj8IF90rx8eOdHLJFetvEixmc9.jpg'),
(112828, 8044, 'Maldito Rap S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2PRGVMpGXnDm2u5DD29Est0yN9.jpg'),
(112829, 8044, 'Maldito Rap S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/noB1U8W83Vfc23XhKdb5TOt1kwT.jpg'),
(112830, 8044, 'Maldito Rap S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gbdQbSdeQtWfRaeYuigJoqn7LyV.jpg'),
(112831, 8044, 'Maldito Rap S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZndXmkdjD4GgLio3L1Zgja7EeI.jpg'),
(112832, 8045, 'Maldito Rap S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rcxf3kiTv7IAQMElJJag8fCT2Wm.jpg'),
(112833, 8045, 'Maldito Rap S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rcxf3kiTv7IAQMElJJag8fCT2Wm.jpg'),
(112834, 8045, 'Maldito Rap S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rcxf3kiTv7IAQMElJJag8fCT2Wm.jpg'),
(112835, 8045, 'Maldito Rap S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rcxf3kiTv7IAQMElJJag8fCT2Wm.jpg'),
(112836, 8045, 'Maldito Rap S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rcxf3kiTv7IAQMElJJag8fCT2Wm.jpg'),
(112837, 8045, 'Maldito Rap S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rcxf3kiTv7IAQMElJJag8fCT2Wm.jpg'),
(112838, 8045, 'Maldito Rap S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rcxf3kiTv7IAQMElJJag8fCT2Wm.jpg'),
(112839, 8045, 'Maldito Rap S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rcxf3kiTv7IAQMElJJag8fCT2Wm.jpg'),
(112840, 8046, 'Mascotes Extraordinários S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Opi2sXEBMpxUyKnxOcPTYzKLOI.jpg'),
(112841, 8046, 'Mascotes Extraordinários S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sYBDAOsXw6BLk0XYF5nYJXEgwBF.jpg'),
(112842, 8046, 'Mascotes Extraordinários S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jqvtZNUITjtM8URVnteDqV0Hbs4.jpg'),
(112843, 8046, 'Mascotes Extraordinários S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jqvtZNUITjtM8URVnteDqV0Hbs4.jpg'),
(112844, 8046, 'Mascotes Extraordinários S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jqvtZNUITjtM8URVnteDqV0Hbs4.jpg'),
(112845, 8046, 'Mascotes Extraordinários S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jqvtZNUITjtM8URVnteDqV0Hbs4.jpg'),
(112846, 8047, 'Minha Estranha Obsessão S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s8nu0CAReNgGFickU8scVu1AjRn.jpg'),
(112847, 8047, 'Minha Estranha Obsessão S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s8nu0CAReNgGFickU8scVu1AjRn.jpg'),
(112848, 8047, 'Minha Estranha Obsessão S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s8nu0CAReNgGFickU8scVu1AjRn.jpg'),
(112849, 8047, 'Minha Estranha Obsessão S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s8nu0CAReNgGFickU8scVu1AjRn.jpg'),
(112850, 8047, 'Minha Estranha Obsessão S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s8nu0CAReNgGFickU8scVu1AjRn.jpg'),
(112851, 8047, 'Minha Estranha Obsessão S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s8nu0CAReNgGFickU8scVu1AjRn.jpg'),
(112852, 8047, 'Minha Estranha Obsessão S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s8nu0CAReNgGFickU8scVu1AjRn.jpg'),
(112853, 8047, 'Minha Estranha Obsessão S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s8nu0CAReNgGFickU8scVu1AjRn.jpg'),
(112854, 8048, 'Minha Estranha Obsessão S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s8nu0CAReNgGFickU8scVu1AjRn.jpg'),
(112855, 8048, 'Minha Estranha Obsessão S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s8nu0CAReNgGFickU8scVu1AjRn.jpg'),
(112856, 8048, 'Minha Estranha Obsessão S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s8nu0CAReNgGFickU8scVu1AjRn.jpg'),
(112857, 8048, 'Minha Estranha Obsessão S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s8nu0CAReNgGFickU8scVu1AjRn.jpg'),
(112858, 8048, 'Minha Estranha Obsessão S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s8nu0CAReNgGFickU8scVu1AjRn.jpg'),
(112859, 8048, 'Minha Estranha Obsessão S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s8nu0CAReNgGFickU8scVu1AjRn.jpg'),
(112860, 8048, 'Minha Estranha Obsessão S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s8nu0CAReNgGFickU8scVu1AjRn.jpg'),
(112861, 8048, 'Minha Estranha Obsessão S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s8nu0CAReNgGFickU8scVu1AjRn.jpg'),
(112862, 8049, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/230012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eERkVzAtvvHjWhZD8Yp2YKwNcpX.jpg'),
(112863, 8049, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/230013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qQOtOYt2yLqDIF1cF2xybmPR6Qb.jpg'),
(112864, 8049, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/230014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/scyKo97Sa64SVSFLXL0S8Ng12g7.jpg'),
(112865, 8049, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rZDUjIHAjgDiMVX0CHTCkMt6SPp.jpg'),
(112866, 8049, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/quFRg4wME1YOhgxZzr6dyCGj2pR.jpg'),
(112867, 8049, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h3ZSgns0CybDwjSNKBrGYrbPE59.jpg'),
(112868, 8049, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Y9Nl74mqrDAuChmptS6zwVF7zs.jpg'),
(112869, 8049, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gKRjzTvkJAppJuB50XfVeYixQ0N.jpg'),
(112870, 8049, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8bFjpmMoWN7yezGLKVFJEDYXmgB.jpg'),
(112871, 8049, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uRghGd1gtKJe35flR5YAzffA1BJ.jpg'),
(112872, 8049, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3CjE4kw5L7MXRo2dfsXEyvBOrd.jpg'),
(112873, 8050, 'Perception: Truques da Mente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ypupx8VtlDCEICmRvHGC8HLdxPB.jpg'),
(112874, 8050, 'Perception: Truques da Mente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMmNBq89TVKB3KqXMrXRjX1x0t8.jpg'),
(112875, 8050, 'Perception: Truques da Mente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zrpLh6t2iXRVTazvi3GTqMlSGf6.jpg'),
(112876, 8050, 'Perception: Truques da Mente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yF6fB6bxEgqrVoltZUCMbqISZHH.jpg'),
(112877, 8050, 'Perception: Truques da Mente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2F3iI4dpMWefCWqqWURGGiXJ7oE.jpg'),
(112878, 8050, 'Perception: Truques da Mente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oXcwxjcgdepr3fNp5s55lC1H4Pz.jpg'),
(112879, 8050, 'Perception: Truques da Mente S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cHp9hCP8EtNMn50dPrnKtJdKWvZ.jpg'),
(112880, 8050, 'Perception: Truques da Mente S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e8lVID4B4zSRyNMyaWgLVHDAiOS.jpg'),
(112881, 8050, 'Perception: Truques da Mente S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mTijruGBmqodUmWHFbTJbmC4GRZ.jpg'),
(112882, 8050, 'Perception: Truques da Mente S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1x319536m47icMbdcJTG6iXkrpL.jpg'),
(112883, 8051, 'Perception: Truques da Mente S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v2ExemtxoNE1mrEI2qfrnysgplU.jpg'),
(112884, 8051, 'Perception: Truques da Mente S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QIvb4nnoeDqCPQOAdGwVMPzymO.jpg'),
(112885, 8051, 'Perception: Truques da Mente S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zgwaFbk6OPDzhAhvHtGoZj7x0zG.jpg'),
(112886, 8051, 'Perception: Truques da Mente S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gTWE6VrxKcPhESMZfmFr3hD5hn0.jpg'),
(112887, 8051, 'Perception: Truques da Mente S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uTygiEj4WHAAzLpNE20AUeiV7bs.jpg'),
(112888, 8051, 'Perception: Truques da Mente S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wKVwMYtyv1ndiQxSttZHEVqgFSD.jpg'),
(112889, 8051, 'Perception: Truques da Mente S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tNVRpjV4whSAqvS82U7RygB6g2Z.jpg'),
(112890, 8051, 'Perception: Truques da Mente S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qVTSj5WtIpwaMvgapl2vbhGVqTq.jpg'),
(112891, 8051, 'Perception: Truques da Mente S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tESagaK8VAw3ZGztdpdcCJL2eIq.jpg'),
(112892, 8051, 'Perception: Truques da Mente S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n4pQE6dsgVepJEFvCM2QAiEVj6u.jpg'),
(112893, 8051, 'Perception: Truques da Mente S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/229993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9s3WeJFX8KEHHJ99ZwZx1q96yaQ.jpg'),
(112894, 8051, 'Perception: Truques da Mente S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/229994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5mW3PEyMiOFIs96EeqTjjeshtJC.jpg'),
(112895, 8051, 'Perception: Truques da Mente S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/229995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tIbZ4HP40rFI1NxhzflDlJZABxV.jpg'),
(112896, 8051, 'Perception: Truques da Mente S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/229996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/83lmhQ516aoAeg4S5DLoe9ibFyg.jpg'),
(112897, 8052, 'Perception: Truques da Mente S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6vFJzZYRwiISCzJI8Uu10SzjdY8.jpg'),
(112898, 8052, 'Perception: Truques da Mente S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a35uUKqUk9Tdeho5ae48xbbWq4n.jpg'),
(112899, 8052, 'Perception: Truques da Mente S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3prQ5O2J9qAgZ3rT5UCUSwxhU8k.jpg'),
(112900, 8052, 'Perception: Truques da Mente S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/230000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/re75Ay5fJ5eKFi11r4zZzPgISfN.jpg'),
(112901, 8052, 'Perception: Truques da Mente S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/230001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/558Y59jNkSIkABaRtecbYAoD4iI.jpg'),
(112902, 8052, 'Perception: Truques da Mente S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/230002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mmLeOwMR6yORg8ell7Dtn3bVkVM.jpg'),
(112903, 8052, 'Perception: Truques da Mente S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/230003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r44WpbliHt1PWIG5Y10Rcf4xkL4.jpg'),
(112904, 8052, 'Perception: Truques da Mente S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/230004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBrTRUxp227D5EFpFU0btiH6eCG.jpg'),
(112905, 8052, 'Perception: Truques da Mente S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/230005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ztVlr0qfxdyD5MRV7UxyjQkNQ36.jpg'),
(112906, 8052, 'Perception: Truques da Mente S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/230006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cloaEzIHN3a0Bbb2aHhja19PxwT.jpg'),
(112907, 8052, 'Perception: Truques da Mente S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/230007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/obbcz9nh1ip2Mp7qcJq8k0gkhe5.jpg'),
(112908, 8052, 'Perception: Truques da Mente S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/230008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8zO25pJ70UqQrrAoD6oP0joBp2I.jpg'),
(112909, 8052, 'Perception: Truques da Mente S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/230009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fp6kIg4zBnj1cT8QowOewdPBP7c.jpg'),
(112910, 8052, 'Perception: Truques da Mente S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/230010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/duNSkDCir91OWmnoFGpiTRijEjb.jpg'),
(112911, 8052, 'Perception: Truques da Mente S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/230011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tqr9XhOkrlAGQR6H6KJrcuyoWkk.jpg'),
(112912, 8053, 'Rent-a-Girlfriend S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240353.mp4', 'http://timg.bdta.pro/images/050ee345ae62f135dea4dc92f3f5c21d.jpg'),
(112913, 8053, 'Rent-a-Girlfriend S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240354.mp4', 'http://timg.bdta.pro/images/e5150e50a061ac6aedfc7ab1ce2dab8e.jpg'),
(112914, 8053, 'Rent-a-Girlfriend S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240355.mp4', 'http://timg.bdta.pro/images/7b07a342da83a1c8d4c5a16f29bd15bc.jpg'),
(112915, 8053, 'Rent-a-Girlfriend S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240356.mp4', 'http://timg.bdta.pro/images/7eebe8178c7a25a97ede5fbf57d7e618.jpg'),
(112916, 8053, 'Rent-a-Girlfriend S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240357.mp4', 'http://timg.bdta.pro/images/7efc3d22c94908e8bd04e0b3e4f18819.jpg'),
(112917, 8053, 'Rent-a-Girlfriend S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240358.mp4', 'http://timg.bdta.pro/images/c264fb248b63f6b26b78855ae2512e00.jpg'),
(112918, 8053, 'Rent-a-Girlfriend S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240359.mp4', 'http://timg.bdta.pro/images/126d6425bdd89d2610b08f80e859bae4.jpg'),
(112919, 8053, 'Rent-a-Girlfriend S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240360.mp4', 'http://timg.bdta.pro/images/ff62fca7eb4599ab4dd01813e610a1f3.jpg'),
(112920, 8053, 'Rent-a-Girlfriend S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240361.mp4', 'http://timg.bdta.pro/images/f60a4e4b84c66e7d93b429a858f31cd5.jpg'),
(112921, 8053, 'Rent-a-Girlfriend S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240362.mp4', 'http://timg.bdta.pro/images/05330f8522fa426e26fc4fb0ba803c9b.jpg'),
(112922, 8053, 'Rent-a-Girlfriend S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240363.mp4', 'http://timg.bdta.pro/images/e69557476fff9ff6e33149940a0122e8.jpg'),
(112923, 8053, 'Rent-a-Girlfriend S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240364.mp4', 'http://timg.bdta.pro/images/355a45eb5db1d4f962bc86bbaaaa2ef5.jpg'),
(112924, 8054, 'Rent-a-Girlfriend S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112925, 8054, 'Rent-a-Girlfriend S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112926, 8054, 'Rent-a-Girlfriend S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112927, 8054, 'Rent-a-Girlfriend S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112928, 8054, 'Rent-a-Girlfriend S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112929, 8054, 'Rent-a-Girlfriend S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112930, 8054, 'Rent-a-Girlfriend S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112931, 8054, 'Rent-a-Girlfriend S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112932, 8054, 'Rent-a-Girlfriend S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112933, 8054, 'Rent-a-Girlfriend S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112934, 8054, 'Rent-a-Girlfriend S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(112935, 8054, 'Rent-a-Girlfriend S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112936, 8055, 'Rent-a-Girlfriend S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112937, 8055, 'Rent-a-Girlfriend S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112938, 8055, 'Rent-a-Girlfriend S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112939, 8055, 'Rent-a-Girlfriend S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112940, 8055, 'Rent-a-Girlfriend S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112941, 8055, 'Rent-a-Girlfriend S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112942, 8055, 'Rent-a-Girlfriend S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112943, 8055, 'Rent-a-Girlfriend S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112944, 8055, 'Rent-a-Girlfriend S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112945, 8055, 'Rent-a-Girlfriend S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112946, 8055, 'Rent-a-Girlfriend S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112947, 8055, 'Rent-a-Girlfriend S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112948, 8056, 'Rent-a-Girlfriend S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/878092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112949, 8056, 'Rent-a-Girlfriend S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/878837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112950, 8056, 'Rent-a-Girlfriend S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/879946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112951, 8056, 'Rent-a-Girlfriend S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/880344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112952, 8056, 'Rent-a-Girlfriend S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/881161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112953, 8056, 'Rent-a-Girlfriend S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/881286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112954, 8056, 'Rent-a-Girlfriend S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/883024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112955, 8056, 'Rent-a-Girlfriend S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/883781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112956, 8056, 'Rent-a-Girlfriend S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/885308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112957, 8056, 'Rent-a-Girlfriend S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/886060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112958, 8056, 'Rent-a-Girlfriend S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/887553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112959, 8056, 'Rent-a-Girlfriend S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/888143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(112960, 8057, 'Rurouni Kenshin S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hGH5Bier7a0p4JIW7J3wHfvmj5J.jpg'),
(112961, 8057, 'Rurouni Kenshin S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rEXyswu58tvwDte1mMSfee7Dy99.jpg'),
(112962, 8057, 'Rurouni Kenshin S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOOaOaKe2kc2UOF6UZLQp9ZukYd.jpg'),
(112963, 8057, 'Rurouni Kenshin S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yU0aq74N5L9lws6haxEkiWsx7X8.jpg'),
(112964, 8057, 'Rurouni Kenshin S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ojzTV2SxMWatJ5GMHwoKbGLNje3.jpg'),
(112965, 8057, 'Rurouni Kenshin S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8PI8QXv7OsFKhBSoCtwxEmGuMKN.jpg'),
(112966, 8057, 'Rurouni Kenshin S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112967, 8057, 'Rurouni Kenshin S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112968, 8057, 'Rurouni Kenshin S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112969, 8057, 'Rurouni Kenshin S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112970, 8057, 'Rurouni Kenshin S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112971, 8057, 'Rurouni Kenshin S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112972, 8057, 'Rurouni Kenshin S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112973, 8057, 'Rurouni Kenshin S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112974, 8057, 'Rurouni Kenshin S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112975, 8057, 'Rurouni Kenshin S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112976, 8057, 'Rurouni Kenshin S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112977, 8057, 'Rurouni Kenshin S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112978, 8057, 'Rurouni Kenshin S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112979, 8057, 'Rurouni Kenshin S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112980, 8057, 'Rurouni Kenshin S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112981, 8057, 'Rurouni Kenshin S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112982, 8057, 'Rurouni Kenshin S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/260353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112983, 8057, 'Rurouni Kenshin S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/260354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112984, 8058, 'Rurouni Kenshin S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/633427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112985, 8058, 'Rurouni Kenshin S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/633428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112986, 8058, 'Rurouni Kenshin S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/633429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112987, 8058, 'Rurouni Kenshin S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/633430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112988, 8058, 'Rurouni Kenshin S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/633431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112989, 8058, 'Rurouni Kenshin S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/633432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112990, 8058, 'Rurouni Kenshin S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/517232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112991, 8058, 'Rurouni Kenshin S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112992, 8058, 'Rurouni Kenshin S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/639028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112993, 8058, 'Rurouni Kenshin S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/657668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112994, 8058, 'Rurouni Kenshin S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/657669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112995, 8058, 'Rurouni Kenshin S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/661486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112996, 8058, 'Rurouni Kenshin S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/678333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112997, 8058, 'Rurouni Kenshin S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/697468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112998, 8058, 'Rurouni Kenshin S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/697469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(112999, 8058, 'Rurouni Kenshin S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/704238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113000, 8058, 'Rurouni Kenshin S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/713238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113001, 8058, 'Rurouni Kenshin S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/716927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113002, 8058, 'Rurouni Kenshin S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/723739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113003, 8058, 'Rurouni Kenshin S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/730258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113004, 8058, 'Rurouni Kenshin S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/758275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113005, 8058, 'Rurouni Kenshin S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/758276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113006, 8058, 'Rurouni Kenshin S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/763667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113007, 8059, 'Sala de Aula dos Heróis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fYEduAYozdD5tAE2uSEnAqSE4QX.jpg'),
(113008, 8059, 'Sala de Aula dos Heróis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ZNatu9Se5fQWaVIpxroHF0dXP0.jpg'),
(113009, 8059, 'Sala de Aula dos Heróis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241571.mp4', 'http://image.tmdb.org/t/p/w1280/nREb41mdpjM5DmDdNlKSogq16F7.jpg'),
(113010, 8059, 'Sala de Aula dos Heróis S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v6g67rHGQZ8HeCpYAaIRQ3VGp8j.jpg'),
(113011, 8059, 'Sala de Aula dos Heróis S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v6g67rHGQZ8HeCpYAaIRQ3VGp8j.jpg'),
(113012, 8059, 'Sala de Aula dos Heróis S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v6g67rHGQZ8HeCpYAaIRQ3VGp8j.jpg'),
(113013, 8059, 'Sala de Aula dos Heróis S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v6g67rHGQZ8HeCpYAaIRQ3VGp8j.jpg'),
(113014, 8059, 'Sala de Aula dos Heróis S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v6g67rHGQZ8HeCpYAaIRQ3VGp8j.jpg'),
(113015, 8059, 'Sala de Aula dos Heróis S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v6g67rHGQZ8HeCpYAaIRQ3VGp8j.jpg'),
(113016, 8059, 'Sala de Aula dos Heróis S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v6g67rHGQZ8HeCpYAaIRQ3VGp8j.jpg'),
(113017, 8059, 'Sala de Aula dos Heróis S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v6g67rHGQZ8HeCpYAaIRQ3VGp8j.jpg'),
(113018, 8059, 'Sala de Aula dos Heróis S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v6g67rHGQZ8HeCpYAaIRQ3VGp8j.jpg'),
(113019, 8060, 'Tribunal Noturno S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9J1itO4KCysRVAXxuyq61mDJEOT.jpg'),
(113020, 8060, 'Tribunal Noturno S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5iqFDcFh8w4A8oSUAmEmhml7Rvs.jpg'),
(113021, 8060, 'Tribunal Noturno S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MJYZgJAJIfcij9mlixo16rzcb5.jpg'),
(113022, 8060, 'Tribunal Noturno S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJFLoLi0TrUO1ZMnHOKNIvd1WJH.jpg'),
(113023, 8060, 'Tribunal Noturno S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5UJQaecsvDyqimP0F6vnmQ2ryia.jpg'),
(113024, 8060, 'Tribunal Noturno S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hYbThMUyqvVnGkiu1SUSxizgKRV.jpg'),
(113025, 8060, 'Tribunal Noturno S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ehrQ2CKjGhKGDHTa3hHKW8MtmS.jpg'),
(113026, 8060, 'Tribunal Noturno S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zMsyL0NiAC1wZ4tv1k5G2bQWZQS.jpg'),
(113027, 8060, 'Tribunal Noturno S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2p73JNnx43abcTM2KksgF45CcOH.jpg'),
(113028, 8060, 'Tribunal Noturno S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nWBovD2nwOoNzJMqymljPn52kyy.jpg'),
(113029, 8060, 'Tribunal Noturno S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/229967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lotkR0dxHRCLraMjmq8D0YpplsJ.jpg'),
(113030, 8060, 'Tribunal Noturno S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/229968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2DnWzjufeXqv22nRkrdxf8iqlqb.jpg'),
(113031, 8060, 'Tribunal Noturno S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/229969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2JQgfej9yQRlLLVdmVm6J4EA1Mh.jpg'),
(113032, 8060, 'Tribunal Noturno S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/229970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5T2cfpiyM1xDwXdIfhx6d2pdnSo.jpg'),
(113033, 8060, 'Tribunal Noturno S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/229971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fHB2h9PfkJ4rWH7yi1BemaXhBy8.jpg'),
(113034, 8060, 'Tribunal Noturno S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/229972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1uXDAt5MCQPcnhtDLo8M8fzZMaH.jpg'),
(113035, 8061, 'Tribunal Noturno S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/607185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113036, 8061, 'Tribunal Noturno S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/607186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113037, 8061, 'Tribunal Noturno S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/607187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113038, 8061, 'Tribunal Noturno S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/607188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113039, 8061, 'Tribunal Noturno S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/607189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113040, 8061, 'Tribunal Noturno S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/607190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113041, 8061, 'Tribunal Noturno S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/607191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113042, 8061, 'Tribunal Noturno S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/607192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113043, 8061, 'Tribunal Noturno S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/607193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113044, 8061, 'Tribunal Noturno S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/607194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113045, 8061, 'Tribunal Noturno S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/607195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113046, 8061, 'Tribunal Noturno S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/607196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113047, 8061, 'Tribunal Noturno S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/607197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113048, 8062, 'Tribunal Noturno S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/820186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113049, 8062, 'Tribunal Noturno S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/820187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113050, 8062, 'Tribunal Noturno S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/820188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113051, 8062, 'Tribunal Noturno S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/820189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113052, 8062, 'Tribunal Noturno S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/820190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113053, 8062, 'Tribunal Noturno S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/820191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113054, 8062, 'Tribunal Noturno S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/820192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113055, 8062, 'Tribunal Noturno S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/820193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113056, 8062, 'Tribunal Noturno S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/820194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113057, 8062, 'Tribunal Noturno S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/820195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113058, 8062, 'Tribunal Noturno S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/820196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113059, 8062, 'Tribunal Noturno S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/820197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113060, 8062, 'Tribunal Noturno S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/820198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113061, 8062, 'Tribunal Noturno S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/820199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113062, 8062, 'Tribunal Noturno S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/820200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113063, 8062, 'Tribunal Noturno S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/820201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113064, 8062, 'Tribunal Noturno S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/820202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113065, 8062, 'Tribunal Noturno S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/820203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVs82vU1OOMTsZMPnls1rULuLP.jpg'),
(113066, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUSd5MZGQ82IQrcaR8Totc38U7C.jpg'),
(113067, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ci53x9OjV9CPZxnJlbep9B0OCdk.jpg'),
(113068, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4MtP45iBiC4Atao7EcE5unpquM.jpg'),
(113069, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1okSTrJOkSbjOvEGGBC85QJQJf.jpg'),
(113070, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lrHJZBakKP5iH6NIcxw6MlnkYzW.jpg'),
(113071, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vw470TI7gV0qjYgznWPgwkyRjyd.jpg'),
(113072, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8pqNN9ujqDO4CFjkdBmyYNvpIs.jpg'),
(113073, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zcHY8gX7at7PLUPvPDTlx7CZ7hN.jpg'),
(113074, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MblvpAJiax0qMkZpnCwlAK3rHE.jpg'),
(113075, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zi8X8iguIOaTLrTICLMQdWwB7bH.jpg'),
(113076, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/229641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Oe0XV9MhY5t2RKRdp4yIejoFaQ.jpg'),
(113077, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/229642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iw4ivT1tcr60BUiDa3JZfVZ8XuL.jpg'),
(113078, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/229643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oUiYzSBbB6dbiq1bb0uqIcNUZ60.jpg'),
(113079, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/229644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yI0YfR7onv8x9VttxbxRZyUvRI3.jpg'),
(113080, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/229645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hcKYOzAkxXDFmrsT99YcIl12f9p.jpg'),
(113081, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/229646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eQ9o1FgaOHc5V8KE1RrXQvCmeAw.jpg'),
(113082, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/229647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gpOA4rNfWug9WvkI5Y9N1j9vrbH.jpg'),
(113083, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/229648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dy1uXdANOz9KFTdiXQtURPjfIaL.jpg'),
(113084, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/229649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZxwChmo5rrKxEgyWAv5SpX2Ihd.jpg'),
(113085, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/229650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iZ8XNosV0HN5jtoCxzFFY6DbVF5.jpg'),
(113086, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/229651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/siWiVfed4uNqLTbxu0oemWkf3SH.jpg'),
(113087, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/229652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bsdcjnN9K7maiZXandOSult9pBq.jpg'),
(113088, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/229653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bsdcjnN9K7maiZXandOSult9pBq.jpg'),
(113089, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/229654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bsdcjnN9K7maiZXandOSult9pBq.jpg'),
(113090, 8063, 'Zack e Cody: Gêmeos a Bordo S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/229655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bsdcjnN9K7maiZXandOSult9pBq.jpg'),
(113091, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Si0IFusfp7uY99YoeS6M71gIg8.jpg'),
(113092, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wfyChaABl3JbIR9cmvj1DLiNmCA.jpg'),
(113093, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6HNre7OwMWxX4cL8mtEvdWPrW7.jpg'),
(113094, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tYpwGbiyItBNpZsBSA7CSCq5Huh.jpg'),
(113095, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ncq2seU5E0flqbt2PsPNvMg3zXU.jpg'),
(113096, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLwPiDOoMXcKa3EKna48Btbw9Is.jpg'),
(113097, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k2UHoDqexVOflKmBW3ECtZAQPGT.jpg'),
(113098, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/azLVUJLAFW3QEREXMvufYq7kWqr.jpg'),
(113099, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhV8scuGZO58tNBbj6QIn0dV1XI.jpg'),
(113100, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ohBbjOeSfGZlq18RcgOQNvk7QcN.jpg'),
(113101, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/229666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cSt19cHBcQiwREcdWsD6362bjZW.jpg'),
(113102, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/229667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hUdT02mBZ5N2tezTvDYjoVBlo4c.jpg'),
(113103, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/229668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/em1Nr3uvy1SSGdX138G1uG6YH83.jpg'),
(113104, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/229669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dktEML356Qh1fVhcopf3wzwOn3x.jpg'),
(113105, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/229670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5QAz6W3wFCVf3gJnXK273cwb2hd.jpg'),
(113106, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/229671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lxORCB08dAszOPkVTxOvz4MZF60.jpg'),
(113107, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/229672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4EFTboDHt7Q2NZ79aQDYlRmOVNk.jpg'),
(113108, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/229673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/852kl0sisEc51ihiUPqxxF2S6dr.jpg'),
(113109, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/229674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xEWJbqyvRu2jl9vd741aLzXetTu.jpg'),
(113110, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/229675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oN4tqIyrD2lcUdSIHTDQj939pOm.jpg'),
(113111, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/229676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yAJYhCZLmCAPyfUspI1bsRvUoO7.jpg'),
(113112, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/229677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wE2xa2JmI4WReiATbPqbwgND8vj.jpg'),
(113113, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/229678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mdwmhxePSXhu7tpBTEF1yopu8DK.jpg'),
(113114, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/229679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q6sw1X2Jt1YtICqaOCMZAjh6KnG.jpg'),
(113115, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/229680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wcLFOkegdTXg4VgCjSFuXvfTNgz.jpg'),
(113116, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/229681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/26f0Br12v2TabtAXCgqikQg0MXl.jpg'),
(113117, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/229682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gqzGnQmEFECLaSUGjCkssR0FOUI.jpg'),
(113118, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/229683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t4Yqz5MgvzrEpyfprqIEAxaor4F.jpg'),
(113119, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/229684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j2cN6pXGj3CXpAahHtuJ65nAkFR.jpg'),
(113120, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/229685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ooJjePHEDpcu5j0LZtk58CkF7uU.jpg'),
(113121, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/229686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bsdcjnN9K7maiZXandOSult9pBq.jpg'),
(113122, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/229687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bsdcjnN9K7maiZXandOSult9pBq.jpg'),
(113123, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/229688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bsdcjnN9K7maiZXandOSult9pBq.jpg'),
(113124, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/229689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bsdcjnN9K7maiZXandOSult9pBq.jpg'),
(113125, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/229690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bsdcjnN9K7maiZXandOSult9pBq.jpg'),
(113126, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/229691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bsdcjnN9K7maiZXandOSult9pBq.jpg'),
(113127, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/229692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bsdcjnN9K7maiZXandOSult9pBq.jpg'),
(113128, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/229693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bsdcjnN9K7maiZXandOSult9pBq.jpg'),
(113129, 8064, 'Zack e Cody: Gêmeos a Bordo S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/229694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bsdcjnN9K7maiZXandOSult9pBq.jpg'),
(113130, 8065, 'Zack e Cody: Gêmeos a Bordo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZTPAzaUK70jMAod5uBjUZffAwi.jpg'),
(113131, 8065, 'Zack e Cody: Gêmeos a Bordo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mGotaPX65nLOm8mEnrIJJ52lNfp.jpg'),
(113132, 8065, 'Zack e Cody: Gêmeos a Bordo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ik6fIM2TKANPMI3Npt3WVveSpFT.jpg'),
(113133, 8065, 'Zack e Cody: Gêmeos a Bordo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5YdJ2szySzsdXMTe62GUTuHHJsD.jpg'),
(113134, 8065, 'Zack e Cody: Gêmeos a Bordo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4hbXwV4thjinu6DqdKq9bycngQd.jpg'),
(113135, 8065, 'Zack e Cody: Gêmeos a Bordo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDRfZpYUM0IPDRHptpnG5DlXE8t.jpg'),
(113136, 8065, 'Zack e Cody: Gêmeos a Bordo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mheyOGYMLnBDxFj8H1XozGY6BT5.jpg'),
(113137, 8065, 'Zack e Cody: Gêmeos a Bordo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9PsebP8UH5BgBqhWIfLjKXXATop.jpg'),
(113138, 8065, 'Zack e Cody: Gêmeos a Bordo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f53TQyxEKSaaV6oSTCwApw8Y3LR.jpg'),
(113139, 8065, 'Zack e Cody: Gêmeos a Bordo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sgF7fkbo6GjDlYD1jXqSin3EtSl.jpg'),
(113140, 8065, 'Zack e Cody: Gêmeos a Bordo S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/229705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pj94E7A8jOLwKrnWLqi1qetuWxw.jpg'),
(113141, 8065, 'Zack e Cody: Gêmeos a Bordo S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/229706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kdnEyoYZQ8pc1WuNlKdhAZ6d2NH.jpg'),
(113142, 8065, 'Zack e Cody: Gêmeos a Bordo S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/229707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r4DIIJFfQlOPTOqsn8smCEY5JcI.jpg'),
(113143, 8065, 'Zack e Cody: Gêmeos a Bordo S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/229708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uFlPQgVcbER7eUxu3CFMs15Ft7W.jpg'),
(113144, 8065, 'Zack e Cody: Gêmeos a Bordo S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/229709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bYUdASDWscXcR1gImlfs4fmUQce.jpg'),
(113145, 8065, 'Zack e Cody: Gêmeos a Bordo S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/229710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u5Xg8vDp95Mf24WjEZaHj9WlA2Z.jpg'),
(113146, 8065, 'Zack e Cody: Gêmeos a Bordo S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/229711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6dTzEyrFEVcFbDimMrqSZ9eu1kv.jpg'),
(113147, 8065, 'Zack e Cody: Gêmeos a Bordo S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/229712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mPfXd67D7BubT95IT0tln3LyZsM.jpg'),
(113148, 8065, 'Zack e Cody: Gêmeos a Bordo S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/229713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cHd7AaPbGZdKVfWngHsz6SSJiMp.jpg'),
(113149, 8065, 'Zack e Cody: Gêmeos a Bordo S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/229714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gx9wedubxjJOnzEcJh3X2ht3zZw.jpg'),
(113150, 8065, 'Zack e Cody: Gêmeos a Bordo S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/229715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gpX6me8glOnUtZBgqBo1zmqoBZh.jpg'),
(113151, 8066, 'Mr. Bean: A Série S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lh2K2eyftjjmP1tJcywDbw6zWqh.jpg'),
(113152, 8066, 'Mr. Bean: A Série S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dqKsEGlO39aAfB4S6QV7rmYeQso.jpg'),
(113153, 8066, 'Mr. Bean: A Série S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5z1LD8AxIznlj7cgy6EL1dogCYf.jpg'),
(113154, 8066, 'Mr. Bean: A Série S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wD56LG2Wevp5Bw6hWMEckyGcQr3.jpg'),
(113155, 8066, 'Mr. Bean: A Série S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2EQBRq1lmMVQ5MJNPIoNpHP8TKF.jpg'),
(113156, 8066, 'Mr. Bean: A Série S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AhnynPfy9T85HxfAfgKK2VlwvuF.jpg'),
(113157, 8066, 'Mr. Bean: A Série S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d5E7zYfKrdUJBs3gtHuFVto42Ma.jpg'),
(113158, 8066, 'Mr. Bean: A Série S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9FOgRmHFwukMAPr7d4iYudObQzv.jpg'),
(113159, 8066, 'Mr. Bean: A Série S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0lNpmcCM7uHMtzt2oacwqBHkLj.jpg'),
(113160, 8066, 'Mr. Bean: A Série S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hezs9eNpNjJ1dSKwyppmIK7Bz6k.jpg'),
(113161, 8066, 'Mr. Bean: A Série S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/229539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0uODCbxTB3s7uNAcexKBJkFvXf.jpg'),
(113162, 8066, 'Mr. Bean: A Série S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/229540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tP9ALNHyVu5istSZAWqcekd7lC7.jpg'),
(113163, 8066, 'Mr. Bean: A Série S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/229541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gGLgGxSSk65649y1yQmIjbWjWxr.jpg'),
(113164, 8066, 'Mr. Bean: A Série S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/229542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ZzYy2Kef3lgZK5fAmY9TliaYnZ.jpg'),
(113165, 8067, 'Mr. Pickles S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gnFMAYhLSBtpnUfVmWkYTXp1FiM.jpg'),
(113166, 8067, 'Mr. Pickles S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uVQZ7srECWNv94ssw5DYgub0WYK.jpg'),
(113167, 8067, 'Mr. Pickles S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j5FirnlZLMt8xa3SRiROLnc7jLX.jpg'),
(113168, 8067, 'Mr. Pickles S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t5hJTaJ6NndhHYtjioreiLMKIQS.jpg'),
(113169, 8067, 'Mr. Pickles S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3J97IMUJDHSL4kDVKoauT4qlxGX.jpg'),
(113170, 8067, 'Mr. Pickles S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vOZc5pm2tPQAeMHQVLQLBDQ4AQ4.jpg'),
(113171, 8067, 'Mr. Pickles S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s3YpvrjzwZhw3aMrM07geyKoFQp.jpg'),
(113172, 8067, 'Mr. Pickles S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fjVhC4MdWcEhrp5nYb5pi6WUORF.jpg'),
(113173, 8067, 'Mr. Pickles S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lIe0s9f1CZKOw57dwBBvDVzZFMP.jpg'),
(113174, 8067, 'Mr. Pickles S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kRMnNqFjyF8eXFQPGu4BjJyetp3.jpg'),
(113175, 8068, 'Mr. Pickles S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8UkzxNwMh6ZrEL8gZMITwn8Wp52.jpg'),
(113176, 8068, 'Mr. Pickles S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nCVHy2l8fFO9HBGC9almWL33SFY.jpg'),
(113177, 8068, 'Mr. Pickles S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3yTapuuu277xRr4KYQj7B8U5d00.jpg'),
(113178, 8068, 'Mr. Pickles S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1hni7GTiedk8XauJZKzGkUuc3qd.jpg'),
(113179, 8068, 'Mr. Pickles S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ZRH7Wqa6VeshgAhLH80svkfrZr.jpg'),
(113180, 8068, 'Mr. Pickles S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/LF1pM0n33pZeShnqxAOuCUrLLp.jpg'),
(113181, 8068, 'Mr. Pickles S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zHSDPPnFRkUkKNetSwgrcYTDtsQ.jpg'),
(113182, 8068, 'Mr. Pickles S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rDFvkFiv9wyq3fIa10ipA1NTYUs.jpg'),
(113183, 8068, 'Mr. Pickles S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8J50HOddQKbK4fIJa35aQW2hCHV.jpg'),
(113184, 8068, 'Mr. Pickles S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iqh6lv98YkAaFN3qBxHm5BjpBAK.jpg'),
(113185, 8069, 'Mr. Pickles S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sHnRulH6poLCIQVdRQALrlxldAa.jpg'),
(113186, 8069, 'Mr. Pickles S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dbN8fuwmYVyvSI4KyIZy9NS7QH7.jpg'),
(113187, 8069, 'Mr. Pickles S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ZtUsawtRgsIn3EKNLmImaus848.jpg'),
(113188, 8069, 'Mr. Pickles S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eSIGAp6EvjXK4yY0BKv6unkADlb.jpg'),
(113189, 8069, 'Mr. Pickles S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/T8UgM63U5IMeVjNBq0Dvg8ga2S.jpg'),
(113190, 8069, 'Mr. Pickles S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/T8UgM63U5IMeVjNBq0Dvg8ga2S.jpg'),
(113191, 8069, 'Mr. Pickles S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/T8UgM63U5IMeVjNBq0Dvg8ga2S.jpg'),
(113192, 8069, 'Mr. Pickles S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/T8UgM63U5IMeVjNBq0Dvg8ga2S.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(113193, 8069, 'Mr. Pickles S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/T8UgM63U5IMeVjNBq0Dvg8ga2S.jpg'),
(113194, 8069, 'Mr. Pickles S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/T8UgM63U5IMeVjNBq0Dvg8ga2S.jpg'),
(113195, 8070, 'Mr. Pickles S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/T8UgM63U5IMeVjNBq0Dvg8ga2S.jpg'),
(113196, 8071, '100 Coisas para Fazer Antes de Virar Zumbi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zME0h04UnDR2Gea5n3iK1dxaNeS.jpg'),
(113197, 8071, '100 Coisas para Fazer Antes de Virar Zumbi S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266930.mp4', 'http://image.tmdb.org/t/p/w1280/nmiK481iHBfOpPqITzEExn6SO6u.jpg'),
(113198, 8071, '100 Coisas para Fazer Antes de Virar Zumbi S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266931.mp4', 'http://image.tmdb.org/t/p/w1280/cr3CuapvM8bm1TJbK1OrjALJTv7.jpg'),
(113199, 8071, '100 Coisas para Fazer Antes de Virar Zumbi S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266932.mp4', 'http://image.tmdb.org/t/p/w1280/n1LkQyrG2NNqOzIJ8sAwBqaEI7L.jpg'),
(113200, 8071, '100 Coisas para Fazer Antes de Virar Zumbi S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wUgE1ceORQzsZnGrASVKjEaGkzO.jpg'),
(113201, 8071, '100 Coisas para Fazer Antes de Virar Zumbi S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wUgE1ceORQzsZnGrASVKjEaGkzO.jpg'),
(113202, 8071, '100 Coisas para Fazer Antes de Virar Zumbi S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wUgE1ceORQzsZnGrASVKjEaGkzO.jpg'),
(113203, 8071, '100 Coisas para Fazer Antes de Virar Zumbi S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wUgE1ceORQzsZnGrASVKjEaGkzO.jpg'),
(113204, 8071, '100 Coisas para Fazer Antes de Virar Zumbi S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wUgE1ceORQzsZnGrASVKjEaGkzO.jpg'),
(113205, 8071, '100 Coisas para Fazer Antes de Virar Zumbi S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wUgE1ceORQzsZnGrASVKjEaGkzO.jpg'),
(113206, 8071, '100 Coisas para Fazer Antes de Virar Zumbi S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wUgE1ceORQzsZnGrASVKjEaGkzO.jpg'),
(113207, 8071, '100 Coisas para Fazer Antes de Virar Zumbi S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wUgE1ceORQzsZnGrASVKjEaGkzO.jpg'),
(113208, 8072, 'A Veterana Pitica da Firma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n1wPYLWH09XJt3nqzKaxhIN8eSA.jpg'),
(113209, 8072, 'A Veterana Pitica da Firma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8lvwj9ky6ajUq8muXRQSS6J69cd.jpg'),
(113210, 8073, 'Em Casa com Tyson Fury S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kORkYbc1l5DoNJu7fSprtTwwqFi.jpg'),
(113211, 8073, 'Em Casa com Tyson Fury S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/V1QaSNditoqoJrUZYWExlfFudH.jpg'),
(113212, 8073, 'Em Casa com Tyson Fury S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/90X6vfOOzaJMFdXQ5oVQnGn1EOt.jpg'),
(113213, 8073, 'Em Casa com Tyson Fury S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5AIfuhtOFg2JPX5dUUb88vnSvrP.jpg'),
(113214, 8073, 'Em Casa com Tyson Fury S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cJugqktvQLbhT90PVQEvwm9vqCE.jpg'),
(113215, 8073, 'Em Casa com Tyson Fury S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jsSumsU3AeomBWMk0pOKJHWImLO.jpg'),
(113216, 8073, 'Em Casa com Tyson Fury S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hx0WajvAdkkGRw3UWdhIVLCznFx.jpg'),
(113217, 8073, 'Em Casa com Tyson Fury S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c7F8C4Zf2OT6V1bmaH3wptAzhLB.jpg'),
(113218, 8073, 'Em Casa com Tyson Fury S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gy52FXab5lJOQECcA798hhCcdRT.jpg'),
(113219, 8074, 'Johnny Depp x Amber Heard S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jnkn8NCrUidQmRScnWW1maUyBfo.jpg'),
(113220, 8074, 'Johnny Depp x Amber Heard S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1iuG6nGo9HUCJD1tTGQZbc6dRHy.jpg'),
(113221, 8074, 'Johnny Depp x Amber Heard S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gwihdG6qE75q9TCR9wrT8B4VLxh.jpg'),
(113222, 8075, 'Link Click S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/icUfSdcAqVPZq2Tmh4kg5z6CXYt.jpg'),
(113223, 8075, 'Link Click S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Z6zB98wuoWlp7ravt86LoKYZO2.jpg'),
(113224, 8075, 'Link Click S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q010fF2hxZ1CDq26cYfBNXS66C6.jpg'),
(113225, 8075, 'Link Click S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5tsBmkQawTch8yFLFAegQ2qKVUI.jpg'),
(113226, 8075, 'Link Click S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmJtccseY6GU5ozR0nt6Mp5j0y6.jpg'),
(113227, 8075, 'Link Click S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bpahkhKvkfDFNuglHjX5LIsYBi0.jpg'),
(113228, 8075, 'Link Click S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7HyEa5AJyxxbKUPrY9Ey8pkHWgY.jpg'),
(113229, 8075, 'Link Click S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8bwB55PbKq8A8MInwrtHIrpljXN.jpg'),
(113230, 8075, 'Link Click S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jLntnHS1996YZNGIwmxVFwO7ANd.jpg'),
(113231, 8075, 'Link Click S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5WIoYAfp8sMRTmKovORRsYLilk9.jpg'),
(113232, 8075, 'Link Click S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/229154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iW4c0cYeVqorCOML4vkjqIoV4cM.jpg'),
(113233, 8076, 'Link Click S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/679332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113234, 8076, 'Link Click S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/679333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113235, 8076, 'Link Click S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/679334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113236, 8076, 'Link Click S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/679335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113237, 8076, 'Link Click S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/679336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113238, 8076, 'Link Click S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/679337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113239, 8076, 'Link Click S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/679338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113240, 8076, 'Link Click S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/679339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113241, 8076, 'Link Click S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/679340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113242, 8076, 'Link Click S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/679341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113243, 8076, 'Link Click S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/679342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113244, 8076, 'Link Click S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/679343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113245, 8077, 'Link Click S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/697901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113246, 8077, 'Link Click S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/697902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113247, 8077, 'Link Click S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/697903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113248, 8077, 'Link Click S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/705148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113249, 8077, 'Link Click S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/712765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113250, 8077, 'Link Click S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/718010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113251, 8078, 'Minha Habilidade Única Me Deixa Invencível no Nível 1 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tbBWEZdLhgVIEz6nD8aHFclbkYn.jpg'),
(113252, 8078, 'Minha Habilidade Única Me Deixa Invencível no Nível 1 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lokZIhEogVHkjckmid79QPDIls.jpg'),
(113253, 8078, 'Minha Habilidade Única Me Deixa Invencível no Nível 1 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yJMJ10WmldU5g3dvJULXZ8l02Af.jpg'),
(113254, 8078, 'Minha Habilidade Única Me Deixa Invencível no Nível 1 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4tRiRXc0w3QMQJbxFJEQahDmPCa.jpg'),
(113255, 8078, 'Minha Habilidade Única Me Deixa Invencível no Nível 1 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mNMCeuBmpUyKKFDv5ygpbUImfw8.jpg'),
(113256, 8078, 'Minha Habilidade Única Me Deixa Invencível no Nível 1 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fNp20OA61QWLIYcVeJ5lPbldRLU.jpg'),
(113257, 8078, 'Minha Habilidade Única Me Deixa Invencível no Nível 1 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rUzd55GHiOogGiFAgTlW4aWsC2O.jpg'),
(113258, 8078, 'Minha Habilidade Única Me Deixa Invencível no Nível 1 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rUzd55GHiOogGiFAgTlW4aWsC2O.jpg'),
(113259, 8078, 'Minha Habilidade Única Me Deixa Invencível no Nível 1 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rUzd55GHiOogGiFAgTlW4aWsC2O.jpg'),
(113260, 8078, 'Minha Habilidade Única Me Deixa Invencível no Nível 1 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rUzd55GHiOogGiFAgTlW4aWsC2O.jpg'),
(113261, 8078, 'Minha Habilidade Única Me Deixa Invencível no Nível 1 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rUzd55GHiOogGiFAgTlW4aWsC2O.jpg'),
(113262, 8078, 'Minha Habilidade Única Me Deixa Invencível no Nível 1 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rUzd55GHiOogGiFAgTlW4aWsC2O.jpg'),
(113263, 8079, 'Não Sou um Robô S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tz0A3HiTkrH98REsac3FTvFfcIk.jpg'),
(113264, 8079, 'Não Sou um Robô S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tz0A3HiTkrH98REsac3FTvFfcIk.jpg'),
(113265, 8079, 'Não Sou um Robô S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tz0A3HiTkrH98REsac3FTvFfcIk.jpg'),
(113266, 8079, 'Não Sou um Robô S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tz0A3HiTkrH98REsac3FTvFfcIk.jpg'),
(113267, 8079, 'Não Sou um Robô S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tz0A3HiTkrH98REsac3FTvFfcIk.jpg'),
(113268, 8079, 'Não Sou um Robô S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tz0A3HiTkrH98REsac3FTvFfcIk.jpg'),
(113269, 8079, 'Não Sou um Robô S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tz0A3HiTkrH98REsac3FTvFfcIk.jpg'),
(113270, 8079, 'Não Sou um Robô S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tz0A3HiTkrH98REsac3FTvFfcIk.jpg'),
(113271, 8079, 'Não Sou um Robô S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tz0A3HiTkrH98REsac3FTvFfcIk.jpg'),
(113272, 8079, 'Não Sou um Robô S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tz0A3HiTkrH98REsac3FTvFfcIk.jpg'),
(113273, 8079, 'Não Sou um Robô S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/229072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tz0A3HiTkrH98REsac3FTvFfcIk.jpg'),
(113274, 8079, 'Não Sou um Robô S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/229073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tz0A3HiTkrH98REsac3FTvFfcIk.jpg'),
(113275, 8079, 'Não Sou um Robô S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/229074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tz0A3HiTkrH98REsac3FTvFfcIk.jpg'),
(113276, 8079, 'Não Sou um Robô S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/229075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tz0A3HiTkrH98REsac3FTvFfcIk.jpg'),
(113277, 8079, 'Não Sou um Robô S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/229076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tz0A3HiTkrH98REsac3FTvFfcIk.jpg'),
(113278, 8079, 'Não Sou um Robô S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/229077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tz0A3HiTkrH98REsac3FTvFfcIk.jpg'),
(113279, 8080, 'NooBees S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113280, 8080, 'NooBees S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113281, 8080, 'NooBees S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113282, 8080, 'NooBees S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113283, 8080, 'NooBees S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113284, 8080, 'NooBees S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113285, 8080, 'NooBees S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113286, 8080, 'NooBees S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113287, 8080, 'NooBees S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113288, 8080, 'NooBees S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113289, 8080, 'NooBees S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/229088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113290, 8080, 'NooBees S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/229089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113291, 8080, 'NooBees S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/229090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113292, 8080, 'NooBees S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/229091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113293, 8080, 'NooBees S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/229092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113294, 8080, 'NooBees S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/229093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113295, 8080, 'NooBees S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/229094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113296, 8080, 'NooBees S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/229095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113297, 8080, 'NooBees S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/229096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113298, 8080, 'NooBees S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/229097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113299, 8080, 'NooBees S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/229098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113300, 8080, 'NooBees S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/229099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113301, 8080, 'NooBees S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/229100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113302, 8080, 'NooBees S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/229101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113303, 8080, 'NooBees S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/229102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113304, 8080, 'NooBees S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/229103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113305, 8080, 'NooBees S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/229104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113306, 8080, 'NooBees S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/229105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113307, 8080, 'NooBees S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/229106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113308, 8080, 'NooBees S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/229107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113309, 8080, 'NooBees S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/229108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113310, 8080, 'NooBees S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/229109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113311, 8080, 'NooBees S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/229110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113312, 8080, 'NooBees S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/229111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113313, 8080, 'NooBees S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/229112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113314, 8080, 'NooBees S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/229113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113315, 8080, 'NooBees S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/229114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113316, 8080, 'NooBees S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/229115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113317, 8080, 'NooBees S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/229116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113318, 8080, 'NooBees S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/229117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113319, 8080, 'NooBees S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/229118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113320, 8080, 'NooBees S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/229119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113321, 8080, 'NooBees S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/229120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113322, 8080, 'NooBees S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/229121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113323, 8080, 'NooBees S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/229122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113324, 8080, 'NooBees S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/229123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113325, 8080, 'NooBees S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/229124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113326, 8080, 'NooBees S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/229125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113327, 8080, 'NooBees S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/229126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113328, 8080, 'NooBees S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/229127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113329, 8080, 'NooBees S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/229128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113330, 8080, 'NooBees S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/229129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113331, 8080, 'NooBees S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/229130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113332, 8080, 'NooBees S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/229131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113333, 8080, 'NooBees S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/229132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113334, 8080, 'NooBees S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/229133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113335, 8080, 'NooBees S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/229134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113336, 8080, 'NooBees S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/229135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113337, 8080, 'NooBees S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/229136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113338, 8080, 'NooBees S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/229137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9jKi659AGladvLjPiwNfEoiuR.jpg'),
(113339, 8081, 'O Eleito S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/12FkVFT9PTLuT0OA6y5hEnNSTAw.jpg'),
(113340, 8081, 'O Eleito S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/arrVFLkf2t3ZYvBD4FBwBXXA9J6.jpg'),
(113341, 8081, 'O Eleito S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yfbuuvHR9Bq5LdePw4aAT9yVrhD.jpg'),
(113342, 8081, 'O Eleito S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xnezfRnX9hHlwBNpfs7PcPApmfz.jpg'),
(113343, 8081, 'O Eleito S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/20Igy17mIwZgwKIwcGtQM1D5xJf.jpg'),
(113344, 8081, 'O Eleito S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dTbFeiRbtDHKpLduD45BcnTNpZ4.jpg'),
(113345, 8082, 'Te Amar Dói S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5my80feE4NwMWLsk4Wd6iOANrX9.jpg'),
(113346, 8082, 'Te Amar Dói S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5my80feE4NwMWLsk4Wd6iOANrX9.jpg'),
(113347, 8082, 'Te Amar Dói S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5my80feE4NwMWLsk4Wd6iOANrX9.jpg'),
(113348, 8082, 'Te Amar Dói S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dTDSAvXqmNmyH48VlZvqj5KbchQ.jpg'),
(113349, 8082, 'Te Amar Dói S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1r9WYWZajbiGl1J7VJotwauUT9r.jpg'),
(113350, 8082, 'Te Amar Dói S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zSfiKPl8aUAi0CF8glcWPYY596q.jpg'),
(113351, 8082, 'Te Amar Dói S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5my80feE4NwMWLsk4Wd6iOANrX9.jpg'),
(113352, 8082, 'Te Amar Dói S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5my80feE4NwMWLsk4Wd6iOANrX9.jpg'),
(113353, 8082, 'Te Amar Dói S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5my80feE4NwMWLsk4Wd6iOANrX9.jpg'),
(113354, 8082, 'Te Amar Dói S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5my80feE4NwMWLsk4Wd6iOANrX9.jpg'),
(113355, 8082, 'Te Amar Dói S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/231859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5my80feE4NwMWLsk4Wd6iOANrX9.jpg'),
(113356, 8082, 'Te Amar Dói S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/231860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5my80feE4NwMWLsk4Wd6iOANrX9.jpg'),
(113357, 8082, 'Te Amar Dói S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/231861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5my80feE4NwMWLsk4Wd6iOANrX9.jpg'),
(113358, 8083, '100 Coisas para Fazer Antes de Virar Zumbi [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zME0h04UnDR2Gea5n3iK1dxaNeS.jpg'),
(113359, 8083, '100 Coisas para Fazer Antes de Virar Zumbi [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/otuPRIdx8C4Ex1Y20dpdYzmdv42.jpg'),
(113360, 8083, '100 Coisas para Fazer Antes de Virar Zumbi [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mBbmqYq4fHmNhdeMJOA8K569Qr7.jpg'),
(113361, 8083, '100 Coisas para Fazer Antes de Virar Zumbi [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1iH3IFZINIiXwW3xsQmBbLlpFH2.jpg'),
(113362, 8083, '100 Coisas para Fazer Antes de Virar Zumbi [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rjmoCYLIwnx1ajWx9m9g8v7w3pY.jpg'),
(113363, 8083, '100 Coisas para Fazer Antes de Virar Zumbi [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257353.mp4', 'http://image.tmdb.org/t/p/w1280/qViGNP8J4xubUtyKtZ8nrMh97Vs.jpg'),
(113364, 8083, '100 Coisas para Fazer Antes de Virar Zumbi [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257354.mp4', 'http://image.tmdb.org/t/p/w1280/h2SyhU89h1RaBafKRbeeR23Eyf4.jpg'),
(113365, 8083, '100 Coisas para Fazer Antes de Virar Zumbi [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wUgE1ceORQzsZnGrASVKjEaGkzO.jpg'),
(113366, 8083, '100 Coisas para Fazer Antes de Virar Zumbi [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wUgE1ceORQzsZnGrASVKjEaGkzO.jpg'),
(113367, 8083, '100 Coisas para Fazer Antes de Virar Zumbi [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wUgE1ceORQzsZnGrASVKjEaGkzO.jpg'),
(113368, 8083, '100 Coisas para Fazer Antes de Virar Zumbi [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wUgE1ceORQzsZnGrASVKjEaGkzO.jpg'),
(113369, 8083, '100 Coisas para Fazer Antes de Virar Zumbi [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wUgE1ceORQzsZnGrASVKjEaGkzO.jpg'),
(113370, 8072, 'A Veterana Pitica da Firma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n1wPYLWH09XJt3nqzKaxhIN8eSA.jpg'),
(113371, 8072, 'A Veterana Pitica da Firma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8lvwj9ky6ajUq8muXRQSS6J69cd.jpg'),
(113372, 8072, 'A Veterana Pitica da Firma S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/580866.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5v4nOgKolmJYVBlKqGNtRyjJnXa.jpg'),
(113373, 8072, 'A Veterana Pitica da Firma S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/580868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vJ2zxsBQVMDkhtyMbNAZzBvJvSI.jpg'),
(113374, 8072, 'A Veterana Pitica da Firma S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/580870.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j4YsdjOHcFpi1j8ZPhCE8J8be4J.jpg'),
(113375, 8072, 'A Veterana Pitica da Firma S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/580872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vJ2zxsBQVMDkhtyMbNAZzBvJvSI.jpg'),
(113376, 8072, 'A Veterana Pitica da Firma S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/580874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vJ2zxsBQVMDkhtyMbNAZzBvJvSI.jpg'),
(113377, 8072, 'A Veterana Pitica da Firma S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vJ2zxsBQVMDkhtyMbNAZzBvJvSI.jpg'),
(113378, 8072, 'A Veterana Pitica da Firma S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vJ2zxsBQVMDkhtyMbNAZzBvJvSI.jpg'),
(113379, 8072, 'A Veterana Pitica da Firma S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vJ2zxsBQVMDkhtyMbNAZzBvJvSI.jpg'),
(113380, 8072, 'A Veterana Pitica da Firma S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vJ2zxsBQVMDkhtyMbNAZzBvJvSI.jpg'),
(113381, 8072, 'A Veterana Pitica da Firma S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vJ2zxsBQVMDkhtyMbNAZzBvJvSI.jpg'),
(113382, 8084, 'Atelier Ryza: Ever Darkness & the Secret Hideout The Animation [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6nGpxpvgfdMOJT2jUFCoJKlEaCx.jpg'),
(113383, 8084, 'Atelier Ryza: Ever Darkness & the Secret Hideout The Animation [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTb6OYJrqpJPiHTydaThfOXvgTX.jpg'),
(113384, 8084, 'Atelier Ryza: Ever Darkness & the Secret Hideout The Animation [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bp1C4t0Ml4MSOrwKRZdQTLmMLNN.jpg'),
(113385, 8084, 'Atelier Ryza: Ever Darkness & the Secret Hideout The Animation [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o1Y6yrMYYPEi6EqAqffSwLODBt3.jpg'),
(113386, 8084, 'Atelier Ryza: Ever Darkness & the Secret Hideout The Animation [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6mZQBZfumc3KqBQSwzk5atxO4zt.jpg'),
(113387, 8084, 'Atelier Ryza: Ever Darkness & the Secret Hideout The Animation [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyGjerik4YKiMPlIg4yOI9Quf11.jpg'),
(113388, 8084, 'Atelier Ryza: Ever Darkness & the Secret Hideout The Animation [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9E0NyNecG0LV9JSkwRAUD8ndNqa.jpg'),
(113389, 8084, 'Atelier Ryza: Ever Darkness & the Secret Hideout The Animation [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jKPfjNCJycFys8iasWXZJbpRFp.jpg'),
(113390, 8084, 'Atelier Ryza: Ever Darkness & the Secret Hideout The Animation [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jKPfjNCJycFys8iasWXZJbpRFp.jpg'),
(113391, 8084, 'Atelier Ryza: Ever Darkness & the Secret Hideout The Animation [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jKPfjNCJycFys8iasWXZJbpRFp.jpg'),
(113392, 8084, 'Atelier Ryza: Ever Darkness & the Secret Hideout The Animation [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jKPfjNCJycFys8iasWXZJbpRFp.jpg'),
(113393, 8084, 'Atelier Ryza: Ever Darkness & the Secret Hideout The Animation [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jKPfjNCJycFys8iasWXZJbpRFp.jpg'),
(113394, 8085, 'AYAKA [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mnpVHG5xl3U7YBsVufkaAw8p0xz.jpg'),
(113395, 8085, 'AYAKA [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f88W6ihKH32ch33pveX4CEOilgj.jpg'),
(113396, 8085, 'AYAKA [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pdvxHN8jMXamh8FnguDs36mVLu3.jpg'),
(113397, 8085, 'AYAKA [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rtSOE683WptW70HDkUq1PslCGzq.jpg'),
(113398, 8085, 'AYAKA [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ApLG86cGdYpBczmS134BcAsHav6.jpg'),
(113399, 8085, 'AYAKA [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3TDAhKf5EKPtIoWYdWYPtJX7ZNt.jpg'),
(113400, 8085, 'AYAKA [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zmvCcvQl15JGMWMv51AxxjSi8Vg.jpg'),
(113401, 8085, 'AYAKA [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8v6p3nkSVW5p1UIpoaTIGHCz6hO.jpg'),
(113402, 8085, 'AYAKA [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8v6p3nkSVW5p1UIpoaTIGHCz6hO.jpg'),
(113403, 8085, 'AYAKA [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8v6p3nkSVW5p1UIpoaTIGHCz6hO.jpg'),
(113404, 8085, 'AYAKA [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8v6p3nkSVW5p1UIpoaTIGHCz6hO.jpg'),
(113405, 8085, 'AYAKA [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8v6p3nkSVW5p1UIpoaTIGHCz6hO.jpg'),
(113406, 8086, 'BanG Dream! It\'s MyGO!!!!! [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aa9vGFIvQF2T3CDJisjz7h6cQG0.jpg'),
(113407, 8086, 'BanG Dream! It\'s MyGO!!!!! [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/visMF7rUidWlzX75ZiYdgz80Drr.jpg'),
(113408, 8086, 'BanG Dream! It\'s MyGO!!!!! [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vIbRu6XY9GBXZITKoG34pXZ7A70.jpg'),
(113409, 8086, 'BanG Dream! It\'s MyGO!!!!! [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kKraNPdfdVBhLOQ9Y5wKhlgMNrc.jpg'),
(113410, 8086, 'BanG Dream! It\'s MyGO!!!!! [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pMhDfgBCPGVQtRUMwhwzOQjuTh5.jpg'),
(113411, 8086, 'BanG Dream! It\'s MyGO!!!!! [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yF6Pdlu71KRxBNPJB1hHXK2DxQJ.jpg'),
(113412, 8086, 'BanG Dream! It\'s MyGO!!!!! [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dw5DcRwcOtDNPBvVeSAqj9nak7s.jpg'),
(113413, 8086, 'BanG Dream! It\'s MyGO!!!!! [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/opkg13L98XBlaY1F7F5567gj206.jpg'),
(113414, 8086, 'BanG Dream! It\'s MyGO!!!!! [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vvc1TbcuWMb8xmoYqYuQcu78F9.jpg'),
(113415, 8086, 'BanG Dream! It\'s MyGO!!!!! [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vvc1TbcuWMb8xmoYqYuQcu78F9.jpg'),
(113416, 8086, 'BanG Dream! It\'s MyGO!!!!! [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/242351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vvc1TbcuWMb8xmoYqYuQcu78F9.jpg'),
(113417, 8086, 'BanG Dream! It\'s MyGO!!!!! [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/242352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vvc1TbcuWMb8xmoYqYuQcu78F9.jpg'),
(113418, 8086, 'BanG Dream! It\'s MyGO!!!!! [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/242353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vvc1TbcuWMb8xmoYqYuQcu78F9.jpg'),
(113419, 8087, 'É Sério Que Eu Sou o Mais Forte? [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6eOEBIKkG4Axp8rRraQDOODafHq.jpg'),
(113420, 8087, 'É Sério Que Eu Sou o Mais Forte? [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eiPLt9EdEmjA7PkA5D8S6gBqr2x.jpg'),
(113421, 8087, 'É Sério Que Eu Sou o Mais Forte? [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vSnHCdtbJVkyfajr6z1S1ZWpTyL.jpg'),
(113422, 8087, 'É Sério Que Eu Sou o Mais Forte? [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rngRmUJIDBz5Wae3jxseudKpFAa.jpg'),
(113423, 8087, 'É Sério Que Eu Sou o Mais Forte? [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y2waAcub7h4fHkYU4GwqkevlD1D.jpg'),
(113424, 8087, 'É Sério Que Eu Sou o Mais Forte? [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238422.mp4', 'http://image.tmdb.org/t/p/w1280/xvyq6Yxb7maZsqCtyHNyIKEcdmm.jpg'),
(113425, 8087, 'É Sério Que Eu Sou o Mais Forte? [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bGXYvnEJwsk2BuwMMUP1LqjZnSl.jpg'),
(113426, 8087, 'É Sério Que Eu Sou o Mais Forte? [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bGXYvnEJwsk2BuwMMUP1LqjZnSl.jpg'),
(113427, 8087, 'É Sério Que Eu Sou o Mais Forte? [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bGXYvnEJwsk2BuwMMUP1LqjZnSl.jpg'),
(113428, 8087, 'É Sério Que Eu Sou o Mais Forte? [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bGXYvnEJwsk2BuwMMUP1LqjZnSl.jpg'),
(113429, 8087, 'É Sério Que Eu Sou o Mais Forte? [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/238427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bGXYvnEJwsk2BuwMMUP1LqjZnSl.jpg'),
(113430, 8087, 'É Sério Que Eu Sou o Mais Forte? [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/238428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bGXYvnEJwsk2BuwMMUP1LqjZnSl.jpg'),
(113431, 8088, 'Hataraku Maou-sama! [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bM0ApZxAfSLlcHg93jeDlaBWp2C.jpg'),
(113432, 8088, 'Hataraku Maou-sama! [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/deVDhZv0pEFbhS38tCBI5O3YpP0.jpg'),
(113433, 8088, 'Hataraku Maou-sama! [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5I16tFuQPc53vy5rDQ9yC6eZaWV.jpg'),
(113434, 8088, 'Hataraku Maou-sama! [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8mGjWPlwROVBe21NutxZOgz45Cx.jpg'),
(113435, 8088, 'Hataraku Maou-sama! [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ReEifytyZchTqh8Dc9eAai4EGQ.jpg'),
(113436, 8088, 'Hataraku Maou-sama! [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j1l4XiZhRUoZeRSw8FPTLyeq2xI.jpg'),
(113437, 8088, 'Hataraku Maou-sama! [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b7vUzzwWm9fT9EltsrFU58dOvhD.jpg'),
(113438, 8088, 'Hataraku Maou-sama! [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Pu6NucK2o6ofhbnoTwLFGradXt.jpg'),
(113439, 8088, 'Hataraku Maou-sama! [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5aqHRiH286YbgTyB6I7Aq1PEwqI.jpg'),
(113440, 8088, 'Hataraku Maou-sama! [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p60RYPHsAuFlocdtA2y3AeCmGJL.jpg'),
(113441, 8088, 'Hataraku Maou-sama! [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/229059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nXDNkjg6ybEZQgwFoMnefA3HlDO.jpg'),
(113442, 8088, 'Hataraku Maou-sama! [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/229060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sYfW8txJKVYwHyJPPa6Xb4yidPi.jpg'),
(113443, 8088, 'Hataraku Maou-sama! [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/229061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/feY0MMI5VzniNH7TYVVbqR6cFtr.jpg'),
(113444, 8089, 'Horimiya: Piece [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jjZAGXlR4oyXf8wYMCqIFNCfwrW.jpg'),
(113445, 8089, 'Horimiya: Piece [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ixTgSlaowwgxG9lJWMfUHqDoMn.jpg'),
(113446, 8089, 'Horimiya: Piece [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gAyNhyn48IrXzzhp2BLZznd430a.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(113447, 8089, 'Horimiya: Piece [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uERna80hUO3ut1on8goBRXSyzEv.jpg'),
(113448, 8089, 'Horimiya: Piece [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hIW7vZcHrTme0BsxMhQjHYvgPhv.jpg'),
(113449, 8089, 'Horimiya: Piece [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oDH6F0vDy38ihvm2xLhbuFRAlO5.jpg'),
(113450, 8089, 'Horimiya: Piece [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vtpjyWCRsYd4kxLJxYNhjvfBL97.jpg'),
(113451, 8089, 'Horimiya: Piece [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnGb4NYOyRfCl5DKYPIK9A0Cgww.jpg'),
(113452, 8089, 'Horimiya: Piece [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnGb4NYOyRfCl5DKYPIK9A0Cgww.jpg'),
(113453, 8089, 'Horimiya: Piece [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnGb4NYOyRfCl5DKYPIK9A0Cgww.jpg'),
(113454, 8089, 'Horimiya: Piece [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnGb4NYOyRfCl5DKYPIK9A0Cgww.jpg'),
(113455, 8089, 'Horimiya: Piece [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnGb4NYOyRfCl5DKYPIK9A0Cgww.jpg'),
(113456, 8089, 'Horimiya: Piece [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnGb4NYOyRfCl5DKYPIK9A0Cgww.jpg'),
(113457, 8090, 'How To with John Wilson [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/drPbN2QKIzZ9DKywORNUGQIsWuA.jpg'),
(113458, 8090, 'How To with John Wilson [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5SjsUdXumSgPoEiQv1IR3MnF6um.jpg'),
(113459, 8090, 'How To with John Wilson [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9dXlO50d6ljYJ4iBnd5wqYOtjOQ.jpg'),
(113460, 8090, 'How To with John Wilson [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/opeyJDGB2Y3cUqNa6H17ZYizvrN.jpg'),
(113461, 8090, 'How To with John Wilson [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5VHEpw648MLBxra07l772xu7eDf.jpg'),
(113462, 8090, 'How To with John Wilson [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tHZMW0tMOkd86sGDS9OPJ9iNGTg.jpg'),
(113463, 8091, 'How To with John Wilson [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBxSJOUK70ofAuIpBwYLqPikrSm.jpg'),
(113464, 8091, 'How To with John Wilson [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bWu6zpSA35lwGIys5at2W26Zmjr.jpg'),
(113465, 8091, 'How To with John Wilson [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2C8pdxQxv43UFpt1u7uqOn8QP5l.jpg'),
(113466, 8091, 'How To with John Wilson [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/itKEbX3PJC0c40UsMRaosVP3KD9.jpg'),
(113467, 8091, 'How To with John Wilson [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rILQTTC1LBO5aBj03xNYLUOhD0p.jpg'),
(113468, 8091, 'How To with John Wilson [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xGdu2CObbjLEey0jiilRYFLrRoH.jpg'),
(113469, 8092, 'How To with John Wilson [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z4wpEksJ0eeQghWBTTKpBDfMTW.jpg'),
(113470, 8092, 'How To with John Wilson [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uvoUxhhp3iGDFCFPu7F1ExemsTK.jpg'),
(113471, 8092, 'How To with John Wilson [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tEZ368zMho2crkTmn07R4lLwSQa.jpg'),
(113472, 8092, 'How To with John Wilson [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hBMb4ZWTIkHXPdqZU0lUxOnPHfE.jpg'),
(113473, 8092, 'How To with John Wilson [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6DtCGSX8VSBpDUoqNxRvZ2GnSVW.jpg'),
(113474, 8092, 'How To with John Wilson [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tmT4hA5DZdtQBdygd0EDMH4ssEi.jpg'),
(113475, 8093, 'Jujutsu Kaisen [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/veG3J8KaBudM8omuGi58fYOMDTz.jpg'),
(113476, 8093, 'Jujutsu Kaisen [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7IBoZgraHqJHqEW5een8lEeq0CU.jpg'),
(113477, 8093, 'Jujutsu Kaisen [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/foMCHRzZVfCTvrmfWWeWViBzvZH.jpg'),
(113478, 8093, 'Jujutsu Kaisen [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cndCnExIUNflwBrcr3EsXcrUCeL.jpg'),
(113479, 8093, 'Jujutsu Kaisen [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wVNJS9YdpMirs2Xz7leKhOGs44I.jpg'),
(113480, 8093, 'Jujutsu Kaisen [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p7iB7X4BBr1vxeIjfeIelKZWaeS.jpg'),
(113481, 8093, 'Jujutsu Kaisen [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ggoWW4AChFzqNkVNr941EhRqTiX.jpg'),
(113482, 8093, 'Jujutsu Kaisen [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6RmiWPTEzDIOLmGI3zYo2GqVeOW.jpg'),
(113483, 8093, 'Jujutsu Kaisen [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4veQBFVrtqhHTU90BCfHqA2Ai8a.jpg'),
(113484, 8093, 'Jujutsu Kaisen [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rYa2K1q24GNb3dgAvgZm6K6OTzj.jpg'),
(113485, 8093, 'Jujutsu Kaisen [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dVRE3XvFfgm8BRww4AqxokPMds1.jpg'),
(113486, 8093, 'Jujutsu Kaisen [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/17EU0yGpKt7Vxa1uXhLkZ5MSsAy.jpg'),
(113487, 8093, 'Jujutsu Kaisen [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ritCXU7BUcNodAVMMiTOAkrSigF.jpg'),
(113488, 8093, 'Jujutsu Kaisen [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Mo7BjJpr1ZepKKLrcLlm4ZgPG2.jpg'),
(113489, 8093, 'Jujutsu Kaisen [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glnKK8Vrq5ggYKqSHfIcDmi0noV.jpg'),
(113490, 8093, 'Jujutsu Kaisen [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/42EWqeWMDuc8ByQ7BlNl6C5Z5nr.jpg'),
(113491, 8093, 'Jujutsu Kaisen [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ikepTZxM3z2rs4DNXiNCACIn87j.jpg'),
(113492, 8093, 'Jujutsu Kaisen [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4JY8sEpqWkDNCiqBI2ecAiyKPUQ.jpg'),
(113493, 8093, 'Jujutsu Kaisen [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qpDxYXnn0ZkoLPz0lB6iQZVIkHM.jpg'),
(113494, 8093, 'Jujutsu Kaisen [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f15D3bnszZigSKbc85wL8ItwLKn.jpg'),
(113495, 8093, 'Jujutsu Kaisen [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/255501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cPFSFfnZzHq5PpsTkWXxBextwzX.jpg'),
(113496, 8093, 'Jujutsu Kaisen [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/255502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/OdE55RF3yQLzFkW9g1Bhja8f93.jpg'),
(113497, 8093, 'Jujutsu Kaisen [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/255503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7iHBhkwEUyrDsdOUc35CRtY45Dn.jpg'),
(113498, 8093, 'Jujutsu Kaisen [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/255504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zIG6nADGUqJYDBXEsDaYyzYjHgH.jpg'),
(113499, 8094, 'Jujutsu Kaisen [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113500, 8094, 'Jujutsu Kaisen [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113501, 8094, 'Jujutsu Kaisen [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113502, 8094, 'Jujutsu Kaisen [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113503, 8094, 'Jujutsu Kaisen [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113504, 8094, 'Jujutsu Kaisen [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113505, 8094, 'Jujutsu Kaisen [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113506, 8094, 'Jujutsu Kaisen [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113507, 8094, 'Jujutsu Kaisen [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113508, 8094, 'Jujutsu Kaisen [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113509, 8094, 'Jujutsu Kaisen [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113510, 8094, 'Jujutsu Kaisen [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113511, 8094, 'Jujutsu Kaisen [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113512, 8094, 'Jujutsu Kaisen [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113513, 8094, 'Jujutsu Kaisen [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113514, 8094, 'Jujutsu Kaisen [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113515, 8094, 'Jujutsu Kaisen [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113516, 8094, 'Jujutsu Kaisen [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113517, 8094, 'Jujutsu Kaisen [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113518, 8094, 'Jujutsu Kaisen [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113519, 8094, 'Jujutsu Kaisen [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/255525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113520, 8094, 'Jujutsu Kaisen [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/255526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113521, 8094, 'Jujutsu Kaisen [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/255527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3cKEEthevZvKRelF4Ko6cUnUdu.jpg'),
(113522, 8095, 'Liar [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vP8fLo1RYsw4YT9EeFli4ZOeZMf.jpg'),
(113523, 8095, 'Liar [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fWSG5Kw4j3zDBJMyCmiXDA2aNZN.jpg'),
(113524, 8095, 'Liar [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g89OtXv6QYzyM4ivCVuFWOCL2IE.jpg'),
(113525, 8095, 'Liar [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uap8KXxjEBry5m92C1rfXWMAXEp.jpg'),
(113526, 8095, 'Liar [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mclf7h9dg7r6vZCQUPFSpKXDWYT.jpg'),
(113527, 8095, 'Liar [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j7WRAWnNlh8Iad8LSdWeHIoiEZq.jpg'),
(113528, 8095, 'Liar [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0bEBSdrB0wqUq81X277AyTfsn6.jpg'),
(113529, 8096, 'Link Click [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/icUfSdcAqVPZq2Tmh4kg5z6CXYt.jpg'),
(113530, 8096, 'Link Click [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Z6zB98wuoWlp7ravt86LoKYZO2.jpg'),
(113531, 8096, 'Link Click [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q010fF2hxZ1CDq26cYfBNXS66C6.jpg'),
(113532, 8096, 'Link Click [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5tsBmkQawTch8yFLFAegQ2qKVUI.jpg'),
(113533, 8096, 'Link Click [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmJtccseY6GU5ozR0nt6Mp5j0y6.jpg'),
(113534, 8096, 'Link Click [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bpahkhKvkfDFNuglHjX5LIsYBi0.jpg'),
(113535, 8096, 'Link Click [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7HyEa5AJyxxbKUPrY9Ey8pkHWgY.jpg'),
(113536, 8096, 'Link Click [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8bwB55PbKq8A8MInwrtHIrpljXN.jpg'),
(113537, 8096, 'Link Click [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jLntnHS1996YZNGIwmxVFwO7ANd.jpg'),
(113538, 8096, 'Link Click [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5WIoYAfp8sMRTmKovORRsYLilk9.jpg'),
(113539, 8096, 'Link Click [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iW4c0cYeVqorCOML4vkjqIoV4cM.jpg'),
(113540, 8097, 'Link Click [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113541, 8097, 'Link Click [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113542, 8097, 'Link Click [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113543, 8097, 'Link Click [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113544, 8097, 'Link Click [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113545, 8097, 'Link Click [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113546, 8098, 'Link Click [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/659113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113547, 8098, 'Link Click [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/659114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113548, 8098, 'Link Click [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/662225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113549, 8098, 'Link Click [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/668671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113550, 8098, 'Link Click [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/675568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113551, 8098, 'Link Click [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/679366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A9z3veK4kJhaPog9laE4eHNeI8D.jpg'),
(113552, 8099, 'Malevolent Spirits: Mononogatari [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6SkYSTd6Mb0vj3abHkOV2jedrDC.jpg'),
(113553, 8099, 'Malevolent Spirits: Mononogatari [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tF7pRN1tB68SNLU1Y0gdad6SQCe.jpg'),
(113554, 8099, 'Malevolent Spirits: Mononogatari [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zDgcCAZ2GPoNvU0mpKqynt4cSej.jpg'),
(113555, 8099, 'Malevolent Spirits: Mononogatari [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzPuyJyrqo3xVbQ07UWBgZViQOA.jpg'),
(113556, 8099, 'Malevolent Spirits: Mononogatari [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hcajSk3V0ePsFYupSo0xk78sE1n.jpg'),
(113557, 8099, 'Malevolent Spirits: Mononogatari [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k7c4IJQmlpOb7U8ABbl9evI86Xg.jpg'),
(113558, 8099, 'Malevolent Spirits: Mononogatari [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9IsQfPSS5bUhLfUGWKWYsbofQom.jpg'),
(113559, 8099, 'Malevolent Spirits: Mononogatari [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/elZkDJB0VcubRsWR7EB1TTVx3J9.jpg'),
(113560, 8099, 'Malevolent Spirits: Mononogatari [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hX4gHI5uKt9N3l98OQaesGD17Oo.jpg'),
(113561, 8099, 'Malevolent Spirits: Mononogatari [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/joyQVcHKLECj58UOPLmY7ef81wY.jpg'),
(113562, 8099, 'Malevolent Spirits: Mononogatari [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/242305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xXoZJxegYmyiXCBKApNcYxzemjd.jpg'),
(113563, 8099, 'Malevolent Spirits: Mononogatari [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/242306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7dLVbhgdnoXzUFVUwVlkQs91Olr.jpg'),
(113564, 8100, 'Malevolent Spirits: Mononogatari [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2i9wiEuw0xNiMahwJJYPTZc3QNC.jpg'),
(113565, 8100, 'Malevolent Spirits: Mononogatari [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2i9wiEuw0xNiMahwJJYPTZc3QNC.jpg'),
(113566, 8100, 'Malevolent Spirits: Mononogatari [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2i9wiEuw0xNiMahwJJYPTZc3QNC.jpg'),
(113567, 8100, 'Malevolent Spirits: Mononogatari [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2i9wiEuw0xNiMahwJJYPTZc3QNC.jpg'),
(113568, 8101, 'My Dear Donavan [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2XgCA5a3M9dg4MszbMkCiou4VY9.jpg'),
(113569, 8101, 'My Dear Donavan [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2XgCA5a3M9dg4MszbMkCiou4VY9.jpg'),
(113570, 8101, 'My Dear Donavan [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2XgCA5a3M9dg4MszbMkCiou4VY9.jpg'),
(113571, 8101, 'My Dear Donavan [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2XgCA5a3M9dg4MszbMkCiou4VY9.jpg'),
(113572, 8101, 'My Dear Donavan [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2XgCA5a3M9dg4MszbMkCiou4VY9.jpg'),
(113573, 8101, 'My Dear Donavan [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2XgCA5a3M9dg4MszbMkCiou4VY9.jpg'),
(113574, 8101, 'My Dear Donavan [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2XgCA5a3M9dg4MszbMkCiou4VY9.jpg'),
(113575, 8101, 'My Dear Donavan [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2XgCA5a3M9dg4MszbMkCiou4VY9.jpg'),
(113576, 8101, 'My Dear Donavan [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2XgCA5a3M9dg4MszbMkCiou4VY9.jpg'),
(113577, 8101, 'My Dear Donavan [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2XgCA5a3M9dg4MszbMkCiou4VY9.jpg'),
(113578, 8101, 'My Dear Donavan [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/229036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2XgCA5a3M9dg4MszbMkCiou4VY9.jpg'),
(113579, 8101, 'My Dear Donavan [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/229037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2XgCA5a3M9dg4MszbMkCiou4VY9.jpg'),
(113580, 8101, 'My Dear Donavan [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/229038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2XgCA5a3M9dg4MszbMkCiou4VY9.jpg'),
(113581, 8101, 'My Dear Donavan [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/229039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2XgCA5a3M9dg4MszbMkCiou4VY9.jpg'),
(113582, 8101, 'My Dear Donavan [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/229040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2XgCA5a3M9dg4MszbMkCiou4VY9.jpg'),
(113583, 8101, 'My Dear Donavan [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/229041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2XgCA5a3M9dg4MszbMkCiou4VY9.jpg'),
(113584, 8102, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eERkVzAtvvHjWhZD8Yp2YKwNcpX.jpg'),
(113585, 8102, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qQOtOYt2yLqDIF1cF2xybmPR6Qb.jpg'),
(113586, 8102, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/scyKo97Sa64SVSFLXL0S8Ng12g7.jpg'),
(113587, 8102, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rZDUjIHAjgDiMVX0CHTCkMt6SPp.jpg'),
(113588, 8102, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/quFRg4wME1YOhgxZzr6dyCGj2pR.jpg'),
(113589, 8102, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h3ZSgns0CybDwjSNKBrGYrbPE59.jpg'),
(113590, 8102, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Y9Nl74mqrDAuChmptS6zwVF7zs.jpg'),
(113591, 8102, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gKRjzTvkJAppJuB50XfVeYixQ0N.jpg'),
(113592, 8102, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8bFjpmMoWN7yezGLKVFJEDYXmgB.jpg'),
(113593, 8102, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uRghGd1gtKJe35flR5YAzffA1BJ.jpg'),
(113594, 8102, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/229024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3CjE4kw5L7MXRo2dfsXEyvBOrd.jpg'),
(113595, 8102, 'Ningen Fushin: Adventurers Who Don\'t Believe in Humanity Will Save the World [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/229025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mc7VmEzYWnXcRRPJuLAXtrXUfI9.jpg'),
(113596, 8103, 'O Gato Prendado está Deprimido Hoje de Novo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tkMLz9jg7QiXVM9vWOyzqEuzSGJ.jpg'),
(113597, 8103, 'O Gato Prendado está Deprimido Hoje de Novo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/99OcXXDuAZTjEiGByabAi6PGU5Z.jpg'),
(113598, 8103, 'O Gato Prendado está Deprimido Hoje de Novo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i6T9LwczWYUdNCegK4tgdJDy92k.jpg'),
(113599, 8103, 'O Gato Prendado está Deprimido Hoje de Novo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oj0fEBnhPwyiOivmsFErY98noIL.jpg'),
(113600, 8103, 'O Gato Prendado está Deprimido Hoje de Novo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nSQDd7V18NbVBqrqLof9kJU0qun.jpg'),
(113601, 8103, 'O Gato Prendado está Deprimido Hoje de Novo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gKxxoFVwfSv5wDpabI2TqkawlOp.jpg'),
(113602, 8103, 'O Gato Prendado está Deprimido Hoje de Novo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7J32cHY4oXmvtizpipXPlO29Dhx.jpg'),
(113603, 8103, 'O Gato Prendado está Deprimido Hoje de Novo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7J32cHY4oXmvtizpipXPlO29Dhx.jpg'),
(113604, 8103, 'O Gato Prendado está Deprimido Hoje de Novo [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7J32cHY4oXmvtizpipXPlO29Dhx.jpg'),
(113605, 8103, 'O Gato Prendado está Deprimido Hoje de Novo [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7J32cHY4oXmvtizpipXPlO29Dhx.jpg'),
(113606, 8103, 'O Gato Prendado está Deprimido Hoje de Novo [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7J32cHY4oXmvtizpipXPlO29Dhx.jpg'),
(113607, 8103, 'O Gato Prendado está Deprimido Hoje de Novo [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7J32cHY4oXmvtizpipXPlO29Dhx.jpg'),
(113608, 8103, 'O Gato Prendado está Deprimido Hoje de Novo [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7J32cHY4oXmvtizpipXPlO29Dhx.jpg'),
(113609, 8104, 'O Homem na Arena: Tom Brady [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/229004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dLOZ1rTi8cekPxWY1xsZevfXgq8.jpg'),
(113610, 8104, 'O Homem na Arena: Tom Brady [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/229005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ZYEc5dnGrnvhFD1bFSjkuwGZE5.jpg'),
(113611, 8104, 'O Homem na Arena: Tom Brady [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/229006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/82tYxW7JTTXRJVYoVQLbpmKYM9e.jpg'),
(113612, 8104, 'O Homem na Arena: Tom Brady [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/229007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWB9u0ROvJB4z7WEZggC70iYwSL.jpg'),
(113613, 8104, 'O Homem na Arena: Tom Brady [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/229008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5pTeIb4oOeWYi49BXkv440Im8UZ.jpg'),
(113614, 8104, 'O Homem na Arena: Tom Brady [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/229009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tZeL07jpi52lqCKiFquhpLrN2dJ.jpg'),
(113615, 8104, 'O Homem na Arena: Tom Brady [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/229010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vZkGl6mSY4eF1zSDazy9crCujJH.jpg'),
(113616, 8104, 'O Homem na Arena: Tom Brady [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/229011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l3xqTrvKux1VPRbrVCDg5CQl2Fb.jpg'),
(113617, 8104, 'O Homem na Arena: Tom Brady [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/229012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5IyVsi8I15yiCbra99OSJOwv86q.jpg'),
(113618, 8104, 'O Homem na Arena: Tom Brady [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/229013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o7eLCdEff17ZgmhtZMy4zkeDZOx.jpg'),
(113619, 8105, 'O Reino das Sete Magilâminas [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uTTKIA2FMguWPdHrUEm5do8NPUP.jpg'),
(113620, 8105, 'O Reino das Sete Magilâminas [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dLSssuOw0nDXn3ccdCgg62YQFdK.jpg'),
(113621, 8105, 'O Reino das Sete Magilâminas [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5TjLJMZNzVCZIiFHpB78r9iW6mY.jpg'),
(113622, 8105, 'O Reino das Sete Magilâminas [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oYSzyJFSQ7YnnlKP0CoWw3S6TQc.jpg'),
(113623, 8105, 'O Reino das Sete Magilâminas [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/72qTINFt89Bw9vyDUVHAVmQu6eL.jpg'),
(113624, 8105, 'O Reino das Sete Magilâminas [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3yXj4rbERjeyQ913ab2cZRuXOjx.jpg'),
(113625, 8105, 'O Reino das Sete Magilâminas [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zQ0NKS691LTwc6kBDdhmECsmBHl.jpg'),
(113626, 8105, 'O Reino das Sete Magilâminas [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zQ0NKS691LTwc6kBDdhmECsmBHl.jpg'),
(113627, 8105, 'O Reino das Sete Magilâminas [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zQ0NKS691LTwc6kBDdhmECsmBHl.jpg'),
(113628, 8105, 'O Reino das Sete Magilâminas [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zQ0NKS691LTwc6kBDdhmECsmBHl.jpg'),
(113629, 8105, 'O Reino das Sete Magilâminas [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zQ0NKS691LTwc6kBDdhmECsmBHl.jpg'),
(113630, 8105, 'O Reino das Sete Magilâminas [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zQ0NKS691LTwc6kBDdhmECsmBHl.jpg'),
(113631, 8105, 'O Reino das Sete Magilâminas [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zQ0NKS691LTwc6kBDdhmECsmBHl.jpg'),
(113632, 8105, 'O Reino das Sete Magilâminas [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zQ0NKS691LTwc6kBDdhmECsmBHl.jpg'),
(113633, 8105, 'O Reino das Sete Magilâminas [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zQ0NKS691LTwc6kBDdhmECsmBHl.jpg'),
(113634, 8106, 'Pokemon Horizontes A Serie [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qA7nU7QMlGMOuuVtCCLCixYbOuv.jpg'),
(113635, 8106, 'Pokemon Horizontes A Serie [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5YcOiSb3E34um8FugYuL4Kl3YBC.jpg'),
(113636, 8106, 'Pokemon Horizontes A Serie [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zRcbyBDoyVjklDyxkBWGi9fB6or.jpg'),
(113637, 8106, 'Pokemon Horizontes A Serie [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3XVY7yioW0uCpx1sVxo83V604fa.jpg'),
(113638, 8106, 'Pokemon Horizontes A Serie [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLYaUjI8tYBVeKniyOajTJvzpJv.jpg'),
(113639, 8106, 'Pokemon Horizontes A Serie [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dPBFnhCTsBCt5SM72H6dHiHZtEB.jpg'),
(113640, 8106, 'Pokemon Horizontes A Serie [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vH369Xd1mLuvjP9L0kPJGZRy6Ei.jpg'),
(113641, 8106, 'Pokemon Horizontes A Serie [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/beO7wzNExoqcrEx8nWgHJFL2NXu.jpg'),
(113642, 8106, 'Pokemon Horizontes A Serie [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzMfx63z9aLhDvEMNoJVEO5h0Tg.jpg'),
(113643, 8106, 'Pokemon Horizontes A Serie [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vgWOgOO1sK2HPqNIngtOiFXaDh8.jpg'),
(113644, 8106, 'Pokemon Horizontes A Serie [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2oBDgA3QbDkFiNiMvxwP8Bwj19Y.jpg'),
(113645, 8106, 'Pokemon Horizontes A Serie [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQ2ZkoYDh08BCZ5lzBdVBtjPM2P.jpg'),
(113646, 8106, 'Pokemon Horizontes A Serie [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5uOb9sjwhQQ5jXpbjIP8K2zmTE.jpg'),
(113647, 8106, 'Pokemon Horizontes A Serie [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dQxkQ8nHHvfIwekAWLEoIl5e3h4.jpg'),
(113648, 8106, 'Pokemon Horizontes A Serie [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/268992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udz9jTWdH2S7fv9TyxzORbsdFvh.jpg'),
(113649, 8106, 'Pokemon Horizontes A Serie [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/268993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ud9o2WY1qZU5Dne85Dii8qtICAo.jpg'),
(113650, 8106, 'Pokemon Horizontes A Serie [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/268994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbwNHNdQOBtaPfvocQOAvstNuxP.jpg'),
(113651, 8106, 'Pokemon Horizontes A Serie [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/268995.mp4', 'http://image.tmdb.org/t/p/w1280/bK6nhaoHxuuqvp0TryDzyqswEVw.jpg'),
(113652, 8106, 'Pokemon Horizontes A Serie [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/268996.mp4', 'http://image.tmdb.org/t/p/w1280/izUs8jREeUt1gidGWg1VcoElqoL.jpg'),
(113653, 8106, 'Pokemon Horizontes A Serie [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/268997.mp4', 'http://image.tmdb.org/t/p/w1280/hBkAcNxEXgekLB1bXYyXB1XJEVq.jpg'),
(113654, 8106, 'Pokemon Horizontes A Serie [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/268998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113655, 8106, 'Pokemon Horizontes A Serie [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/268999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113656, 8106, 'Pokemon Horizontes A Serie [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/269000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113657, 8106, 'Pokemon Horizontes A Serie [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/269001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113658, 8106, 'Pokemon Horizontes A Serie [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/269002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113659, 8106, 'Pokemon Horizontes A Serie [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/269003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113660, 8106, 'Pokemon Horizontes A Serie [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/269004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113661, 8106, 'Pokemon Horizontes A Serie [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/269005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113662, 8106, 'Pokemon Horizontes A Serie [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/269006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113663, 8106, 'Pokemon Horizontes A Serie [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/269007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113664, 8106, 'Pokemon Horizontes A Serie [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/269008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113665, 8106, 'Pokemon Horizontes A Serie [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/269009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113666, 8106, 'Pokemon Horizontes A Serie [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/269010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113667, 8106, 'Pokemon Horizontes A Serie [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/269011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113668, 8106, 'Pokemon Horizontes A Serie [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/269012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113669, 8106, 'Pokemon Horizontes A Serie [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/269013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113670, 8106, 'Pokemon Horizontes A Serie [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/269014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113671, 8106, 'Pokemon Horizontes A Serie [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/269015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113672, 8106, 'Pokemon Horizontes A Serie [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/272688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113673, 8106, 'Pokemon Horizontes A Serie [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/275154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113674, 8106, 'Pokemon Horizontes A Serie [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/290747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113675, 8106, 'Pokemon Horizontes A Serie [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/295349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113676, 8106, 'Pokemon Horizontes A Serie [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/301326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113677, 8106, 'Pokemon Horizontes A Serie [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/307378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113678, 8106, 'Pokemon Horizontes A Serie [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/313718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113679, 8106, 'Pokemon Horizontes A Serie [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/326758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113680, 8106, 'Pokemon Horizontes A Serie [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/329392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113681, 8106, 'Pokemon Horizontes A Serie [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/343800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113682, 8106, 'Pokemon Horizontes A Serie [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/354957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113683, 8106, 'Pokemon Horizontes A Serie [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/354958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113684, 8106, 'Pokemon Horizontes A Serie [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/361457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113685, 8106, 'Pokemon Horizontes A Serie [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/365391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113686, 8106, 'Pokemon Horizontes A Serie [L] S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/376570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113687, 8106, 'Pokemon Horizontes A Serie [L] S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/386492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113688, 8106, 'Pokemon Horizontes A Serie [L] S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/391167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113689, 8106, 'Pokemon Horizontes A Serie [L] S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/394608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113690, 8106, 'Pokemon Horizontes A Serie [L] S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/401665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113691, 8106, 'Pokemon Horizontes A Serie [L] S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/407264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113692, 8106, 'Pokemon Horizontes A Serie [L] S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/417055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113693, 8106, 'Pokemon Horizontes A Serie [L] S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/430917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(113694, 8106, 'Pokemon Horizontes A Serie [L] S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/433217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113695, 8106, 'Pokemon Horizontes A Serie [L] S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/439281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113696, 8106, 'Pokemon Horizontes A Serie [L] S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/443268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113697, 8106, 'Pokemon Horizontes A Serie [L] S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/451340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113698, 8106, 'Pokemon Horizontes A Serie [L] S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/454685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113699, 8106, 'Pokemon Horizontes A Serie [L] S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/459406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113700, 8106, 'Pokemon Horizontes A Serie [L] S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/466994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113701, 8106, 'Pokemon Horizontes A Serie [L] S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/511282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113702, 8106, 'Pokemon Horizontes A Serie [L] S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/511283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113703, 8106, 'Pokemon Horizontes A Serie [L] S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/511284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113704, 8106, 'Pokemon Horizontes A Serie [L] S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/511285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113705, 8106, 'Pokemon Horizontes A Serie [L] S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/511286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113706, 8106, 'Pokemon Horizontes A Serie [L] S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/511287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113707, 8106, 'Pokemon Horizontes A Serie [L] S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/511288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113708, 8106, 'Pokemon Horizontes A Serie [L] S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/514120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113709, 8107, 'Pokemon Horizontes A Serie [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/517550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113710, 8107, 'Pokemon Horizontes A Serie [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/517551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113711, 8107, 'Pokemon Horizontes A Serie [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/517552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113712, 8107, 'Pokemon Horizontes A Serie [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/517553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113713, 8107, 'Pokemon Horizontes A Serie [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/517554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113714, 8107, 'Pokemon Horizontes A Serie [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/517555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113715, 8107, 'Pokemon Horizontes A Serie [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/517556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113716, 8107, 'Pokemon Horizontes A Serie [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/517557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113717, 8107, 'Pokemon Horizontes A Serie [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/517558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113718, 8107, 'Pokemon Horizontes A Serie [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/517559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113719, 8107, 'Pokemon Horizontes A Serie [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/517560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113720, 8107, 'Pokemon Horizontes A Serie [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/517561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113721, 8107, 'Pokemon Horizontes A Serie [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/517562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113722, 8107, 'Pokemon Horizontes A Serie [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/517563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113723, 8107, 'Pokemon Horizontes A Serie [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/517564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113724, 8107, 'Pokemon Horizontes A Serie [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/517565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113725, 8107, 'Pokemon Horizontes A Serie [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/517566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113726, 8107, 'Pokemon Horizontes A Serie [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/517567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113727, 8107, 'Pokemon Horizontes A Serie [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/517568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113728, 8107, 'Pokemon Horizontes A Serie [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/517569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113729, 8107, 'Pokemon Horizontes A Serie [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/517570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113730, 8107, 'Pokemon Horizontes A Serie [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/517571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113731, 8107, 'Pokemon Horizontes A Serie [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/517572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113732, 8107, 'Pokemon Horizontes A Serie [L] S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/517573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113733, 8107, 'Pokemon Horizontes A Serie [L] S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/517574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113734, 8107, 'Pokemon Horizontes A Serie [L] S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/517575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113735, 8107, 'Pokemon Horizontes A Serie [L] S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/517576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113736, 8107, 'Pokemon Horizontes A Serie [L] S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/517577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113737, 8107, 'Pokemon Horizontes A Serie [L] S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/517578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113738, 8107, 'Pokemon Horizontes A Serie [L] S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/517579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113739, 8107, 'Pokemon Horizontes A Serie [L] S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/517580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113740, 8107, 'Pokemon Horizontes A Serie [L] S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/525028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113741, 8107, 'Pokemon Horizontes A Serie [L] S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/638021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113742, 8107, 'Pokemon Horizontes A Serie [L] S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/671313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113743, 8107, 'Pokemon Horizontes A Serie [L] S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/671314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113744, 8107, 'Pokemon Horizontes A Serie [L] S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/685110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113745, 8107, 'Pokemon Horizontes A Serie [L] S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/688441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113746, 8107, 'Pokemon Horizontes A Serie [L] S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/699568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113747, 8107, 'Pokemon Horizontes A Serie [L] S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/708900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113748, 8107, 'Pokemon Horizontes A Serie [L] S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/717660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113749, 8107, 'Pokemon Horizontes A Serie [L] S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/721078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113750, 8107, 'Pokemon Horizontes A Serie [L] S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/730411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113751, 8107, 'Pokemon Horizontes A Serie [L] S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/739849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113752, 8108, 'Pokemon Horizontes A Serie [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/772787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113753, 8108, 'Pokemon Horizontes A Serie [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/772788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113754, 8108, 'Pokemon Horizontes A Serie [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/782025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113755, 8108, 'Pokemon Horizontes A Serie [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/788463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113756, 8108, 'Pokemon Horizontes A Serie [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/799510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113757, 8108, 'Pokemon Horizontes A Serie [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/810933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113758, 8108, 'Pokemon Horizontes A Serie [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/826561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113759, 8108, 'Pokemon Horizontes A Serie [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/834337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113760, 8108, 'Pokemon Horizontes A Serie [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/844748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113761, 8108, 'Pokemon Horizontes A Serie [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/860519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113762, 8108, 'Pokemon Horizontes A Serie [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/860520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vCtYhWxiWsEtXkiunpKhTxZfc5R.jpg'),
(113763, 8109, 'Rent-a-Girlfriend [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238534.mp4', 'http://timg.bdta.pro/images/050ee345ae62f135dea4dc92f3f5c21d.jpg'),
(113764, 8109, 'Rent-a-Girlfriend [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238535.mp4', 'http://timg.bdta.pro/images/e5150e50a061ac6aedfc7ab1ce2dab8e.jpg'),
(113765, 8109, 'Rent-a-Girlfriend [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238536.mp4', 'http://timg.bdta.pro/images/7b07a342da83a1c8d4c5a16f29bd15bc.jpg'),
(113766, 8109, 'Rent-a-Girlfriend [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238537.mp4', 'http://timg.bdta.pro/images/7eebe8178c7a25a97ede5fbf57d7e618.jpg'),
(113767, 8109, 'Rent-a-Girlfriend [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238538.mp4', 'http://timg.bdta.pro/images/7efc3d22c94908e8bd04e0b3e4f18819.jpg'),
(113768, 8109, 'Rent-a-Girlfriend [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238539.mp4', 'http://timg.bdta.pro/images/c264fb248b63f6b26b78855ae2512e00.jpg'),
(113769, 8109, 'Rent-a-Girlfriend [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238540.mp4', 'http://timg.bdta.pro/images/126d6425bdd89d2610b08f80e859bae4.jpg'),
(113770, 8109, 'Rent-a-Girlfriend [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238541.mp4', 'http://timg.bdta.pro/images/ff62fca7eb4599ab4dd01813e610a1f3.jpg'),
(113771, 8109, 'Rent-a-Girlfriend [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238542.mp4', 'http://timg.bdta.pro/images/f60a4e4b84c66e7d93b429a858f31cd5.jpg'),
(113772, 8109, 'Rent-a-Girlfriend [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238543.mp4', 'http://timg.bdta.pro/images/05330f8522fa426e26fc4fb0ba803c9b.jpg'),
(113773, 8109, 'Rent-a-Girlfriend [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/238544.mp4', 'http://timg.bdta.pro/images/e69557476fff9ff6e33149940a0122e8.jpg'),
(113774, 8109, 'Rent-a-Girlfriend [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/238545.mp4', 'http://timg.bdta.pro/images/355a45eb5db1d4f962bc86bbaaaa2ef5.jpg'),
(113775, 8110, 'Rent-a-Girlfriend [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113776, 8110, 'Rent-a-Girlfriend [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113777, 8110, 'Rent-a-Girlfriend [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113778, 8110, 'Rent-a-Girlfriend [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113779, 8110, 'Rent-a-Girlfriend [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113780, 8110, 'Rent-a-Girlfriend [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113781, 8110, 'Rent-a-Girlfriend [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113782, 8110, 'Rent-a-Girlfriend [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113783, 8110, 'Rent-a-Girlfriend [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113784, 8110, 'Rent-a-Girlfriend [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113785, 8110, 'Rent-a-Girlfriend [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/238556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113786, 8110, 'Rent-a-Girlfriend [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/238557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113787, 8111, 'Rent-a-Girlfriend [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113788, 8111, 'Rent-a-Girlfriend [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113789, 8111, 'Rent-a-Girlfriend [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113790, 8111, 'Rent-a-Girlfriend [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113791, 8111, 'Rent-a-Girlfriend [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113792, 8111, 'Rent-a-Girlfriend [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113793, 8111, 'Rent-a-Girlfriend [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113794, 8111, 'Rent-a-Girlfriend [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113795, 8111, 'Rent-a-Girlfriend [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113796, 8111, 'Rent-a-Girlfriend [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113797, 8111, 'Rent-a-Girlfriend [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/238568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113798, 8111, 'Rent-a-Girlfriend [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/238569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113799, 8112, 'Rent-a-Girlfriend [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/856593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113800, 8112, 'Rent-a-Girlfriend [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/863469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113801, 8112, 'Rent-a-Girlfriend [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/869366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113802, 8112, 'Rent-a-Girlfriend [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/873217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113803, 8112, 'Rent-a-Girlfriend [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/878829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113804, 8112, 'Rent-a-Girlfriend [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/879933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113805, 8112, 'Rent-a-Girlfriend [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/880332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113806, 8112, 'Rent-a-Girlfriend [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/881142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113807, 8112, 'Rent-a-Girlfriend [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/882054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113808, 8112, 'Rent-a-Girlfriend [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/883014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113809, 8112, 'Rent-a-Girlfriend [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/883733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113810, 8112, 'Rent-a-Girlfriend [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/885273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uwDDmfNQGzbAGtOgzdGO7UteNU.jpg'),
(113811, 8113, 'Rooftop Prince [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yJgxAkRWIRThUC7n4MTlIk6BweR.jpg'),
(113812, 8113, 'Rooftop Prince [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uBrXjX4dPaVNkKm1InCULAQCcmf.jpg'),
(113813, 8113, 'Rooftop Prince [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/exQ5qahWJr4dn0uLnCNiMRxFJ7B.jpg'),
(113814, 8113, 'Rooftop Prince [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/53VwRnA9rmvCmuRolgerdrTfWbc.jpg'),
(113815, 8113, 'Rooftop Prince [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iuum0R1agnLrPzocyB178yiAUxb.jpg'),
(113816, 8113, 'Rooftop Prince [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kspm4QAxTaLnD7nC85qAnvk0tfl.jpg'),
(113817, 8113, 'Rooftop Prince [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5tZ3YbKG3zNXqnv1xpxwfzEOdHu.jpg'),
(113818, 8113, 'Rooftop Prince [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kcmueuPF9JbcysMkkFf5L0FZKwu.jpg'),
(113819, 8113, 'Rooftop Prince [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3vIB8yTkxF3tEFuyRjHRQKXKVF9.jpg'),
(113820, 8113, 'Rooftop Prince [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1HtxR9Rg0WSV7GWRsRH4oMgyrue.jpg'),
(113821, 8113, 'Rooftop Prince [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jb4SWHyUEs2YUBrhya8ulDf7ED5.jpg'),
(113822, 8113, 'Rooftop Prince [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mTnC80lDs3D3qftDwg7YEEn160w.jpg'),
(113823, 8113, 'Rooftop Prince [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qfxFKzhEdnndeR0zCaboVWqtW5p.jpg'),
(113824, 8113, 'Rooftop Prince [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6WCE5UMcYjXVLRFr8TLH0E6EsxY.jpg'),
(113825, 8113, 'Rooftop Prince [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1JHdonEqftL3u8MNd1ijIlfhOnY.jpg'),
(113826, 8113, 'Rooftop Prince [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/228999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bFeJjImi6z05WcsGwG5sJ8oOX8Z.jpg'),
(113827, 8113, 'Rooftop Prince [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/229000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lJIbriNd1MjZvpi1Lfo6hIIRmDi.jpg'),
(113828, 8113, 'Rooftop Prince [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/229001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hkQ3E0PbhH0ZyDeRlBLxJavpH71.jpg'),
(113829, 8113, 'Rooftop Prince [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/229002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gRLJ8a19wtYlMx1Gm5jg3CB6LF8.jpg'),
(113830, 8113, 'Rooftop Prince [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/229003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4CtOouIYct2JDZx1xbPPzZaZPrY.jpg'),
(113831, 8114, 'Rurouni Kenshin [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hGH5Bier7a0p4JIW7J3wHfvmj5J.jpg'),
(113832, 8114, 'Rurouni Kenshin [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rEXyswu58tvwDte1mMSfee7Dy99.jpg'),
(113833, 8114, 'Rurouni Kenshin [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOOaOaKe2kc2UOF6UZLQp9ZukYd.jpg'),
(113834, 8114, 'Rurouni Kenshin [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tRazXrgRJB00tw9DUdW9F2BAX7H.jpg'),
(113835, 8114, 'Rurouni Kenshin [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ojzTV2SxMWatJ5GMHwoKbGLNje3.jpg'),
(113836, 8114, 'Rurouni Kenshin [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8PI8QXv7OsFKhBSoCtwxEmGuMKN.jpg'),
(113837, 8114, 'Rurouni Kenshin [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253550.mp4', 'http://image.tmdb.org/t/p/w1280/s8Pb4bjh64auZbUqAAm4csUHzgo.jpg'),
(113838, 8114, 'Rurouni Kenshin [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253551.mp4', 'http://image.tmdb.org/t/p/w1280/tODZiUYRms7CrgYVu0OGAvQNSCa.jpg'),
(113839, 8114, 'Rurouni Kenshin [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253552.mp4', 'http://image.tmdb.org/t/p/w1280/4e4UChZirhSI7Ysda8oV1qepi5H.jpg'),
(113840, 8114, 'Rurouni Kenshin [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113841, 8114, 'Rurouni Kenshin [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113842, 8114, 'Rurouni Kenshin [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113843, 8114, 'Rurouni Kenshin [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/253556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113844, 8114, 'Rurouni Kenshin [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/253557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113845, 8114, 'Rurouni Kenshin [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/253558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113846, 8114, 'Rurouni Kenshin [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/253559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113847, 8114, 'Rurouni Kenshin [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/253560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113848, 8114, 'Rurouni Kenshin [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/253561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113849, 8114, 'Rurouni Kenshin [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/253562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113850, 8114, 'Rurouni Kenshin [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/253563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113851, 8114, 'Rurouni Kenshin [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/253564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113852, 8114, 'Rurouni Kenshin [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/253565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113853, 8114, 'Rurouni Kenshin [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/253566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113854, 8114, 'Rurouni Kenshin [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/253567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113855, 8115, 'Rurouni Kenshin [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/634951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113856, 8115, 'Rurouni Kenshin [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/634952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113857, 8115, 'Rurouni Kenshin [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/634953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113858, 8115, 'Rurouni Kenshin [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/634954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113859, 8115, 'Rurouni Kenshin [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/634955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113860, 8115, 'Rurouni Kenshin [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/634956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113861, 8115, 'Rurouni Kenshin [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/634957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113862, 8115, 'Rurouni Kenshin [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/634958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113863, 8115, 'Rurouni Kenshin [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/515141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113864, 8115, 'Rurouni Kenshin [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/517266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113865, 8115, 'Rurouni Kenshin [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/521967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113866, 8115, 'Rurouni Kenshin [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/639064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113867, 8115, 'Rurouni Kenshin [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/661523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113868, 8115, 'Rurouni Kenshin [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/667477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113869, 8115, 'Rurouni Kenshin [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/677875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113870, 8115, 'Rurouni Kenshin [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/678373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113871, 8115, 'Rurouni Kenshin [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/687149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113872, 8115, 'Rurouni Kenshin [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/697511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113873, 8115, 'Rurouni Kenshin [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/704281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113874, 8115, 'Rurouni Kenshin [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/713282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113875, 8115, 'Rurouni Kenshin [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/716972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113876, 8115, 'Rurouni Kenshin [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/723785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113877, 8115, 'Rurouni Kenshin [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/730305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCafSOuO3PqgoxaweNCo45KpctE.jpg'),
(113878, 8116, 'Sala de Aula dos Heróis [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fYEduAYozdD5tAE2uSEnAqSE4QX.jpg'),
(113879, 8116, 'Sala de Aula dos Heróis [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ZNatu9Se5fQWaVIpxroHF0dXP0.jpg'),
(113880, 8116, 'Sala de Aula dos Heróis [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nREb41mdpjM5DmDdNlKSogq16F7.jpg'),
(113881, 8116, 'Sala de Aula dos Heróis [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w00DBnNVNXGh3FUDOHqfmhBOMWC.jpg'),
(113882, 8116, 'Sala de Aula dos Heróis [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lmHiun0445jj73iX0xu3K53ZhWn.jpg'),
(113883, 8116, 'Sala de Aula dos Heróis [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Xh98RBlMpTgonCNi9Gqg394PXW.jpg'),
(113884, 8116, 'Sala de Aula dos Heróis [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241856.mp4', 'http://image.tmdb.org/t/p/w1280/mN9RsqedzJVlmawEfk6oYQLDXQg.jpg'),
(113885, 8116, 'Sala de Aula dos Heróis [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v6g67rHGQZ8HeCpYAaIRQ3VGp8j.jpg'),
(113886, 8117, 'Silence [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7xAXsrY6HaR0Ag3vAhQMdcbJye.jpg'),
(113887, 8117, 'Silence [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wQ2gGGLjHOH0UcF70TlpB1PMiMg.jpg'),
(113888, 8117, 'Silence [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lyGx2Lc0wvXLqmUT4UMriaN9TgM.jpg'),
(113889, 8117, 'Silence [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3WBlVgiwtZjiQVGTh5OMne1ELLI.jpg'),
(113890, 8117, 'Silence [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c3s7LnAuH4n4xVY9TkZNlAxNSPC.jpg'),
(113891, 8117, 'Silence [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/psa2biPg8TiblFv8lqeykUFakC8.jpg'),
(113892, 8118, 'Sugar Apple Fairy Tale [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/epUSwKCRniT4p2yFiWnoho2jhob.jpg'),
(113893, 8118, 'Sugar Apple Fairy Tale [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w2PcLkqWTbfZAiaFXHOPpMj3AN9.jpg'),
(113894, 8118, 'Sugar Apple Fairy Tale [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ojTdcTcCn3ulW3p3yb0GCOkHNic.jpg'),
(113895, 8118, 'Sugar Apple Fairy Tale [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mvCd0QdYZuHeTREYGx2cs6iS1N0.jpg'),
(113896, 8118, 'Sugar Apple Fairy Tale [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4933uaPrPdQVsSX1WpGuEpUxrur.jpg'),
(113897, 8118, 'Sugar Apple Fairy Tale [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1GAnjXM7yPIDKBBj9XstZPweQCQ.jpg'),
(113898, 8118, 'Sugar Apple Fairy Tale [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zNxItvFX3DMPPIe2zmEiohlsMZO.jpg'),
(113899, 8118, 'Sugar Apple Fairy Tale [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6dinwxdVkQtdNzj49BGajK9s8vY.jpg'),
(113900, 8118, 'Sugar Apple Fairy Tale [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uj2s7HzK0t4fODnJlT1YVsencdI.jpg'),
(113901, 8118, 'Sugar Apple Fairy Tale [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mlcZBcG3VP9BA1ASbGQWPfmlkfn.jpg'),
(113902, 8118, 'Sugar Apple Fairy Tale [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iuBCq3mYHiLQy3YvikQgikD5nF8.jpg'),
(113903, 8118, 'Sugar Apple Fairy Tale [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nfKn4aKS48UQvl7eAeFTFM5s7kW.jpg'),
(113904, 8119, 'Sugar Apple Fairy Tale [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rcUFHv5S7eY0nArCYfZlmGXih4J.jpg'),
(113905, 8119, 'Sugar Apple Fairy Tale [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rcUFHv5S7eY0nArCYfZlmGXih4J.jpg'),
(113906, 8119, 'Sugar Apple Fairy Tale [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rcUFHv5S7eY0nArCYfZlmGXih4J.jpg'),
(113907, 8119, 'Sugar Apple Fairy Tale [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rcUFHv5S7eY0nArCYfZlmGXih4J.jpg'),
(113908, 8119, 'Sugar Apple Fairy Tale [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rcUFHv5S7eY0nArCYfZlmGXih4J.jpg'),
(113909, 8119, 'Sugar Apple Fairy Tale [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rcUFHv5S7eY0nArCYfZlmGXih4J.jpg'),
(113910, 8120, 'Synduality: Noir [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqVw0cxPs6GuLLGtNChpBi8HniZ.jpg'),
(113911, 8120, 'Synduality: Noir [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZ5XcsYhrI7oNu361kJKnBK1s4d.jpg'),
(113912, 8120, 'Synduality: Noir [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hHM61GZAjdwzV3ZQn0bX98Ljpgu.jpg'),
(113913, 8120, 'Synduality: Noir [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9xR2reovRWtCRjIe2Xxwm4gz5ox.jpg'),
(113914, 8120, 'Synduality: Noir [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5OiU4T7KrMv7JX3niC4I190V5lm.jpg'),
(113915, 8120, 'Synduality: Noir [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9lAMYGYbbAqOKFrB69vIjutPW6F.jpg'),
(113916, 8120, 'Synduality: Noir [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266464.mp4', 'http://image.tmdb.org/t/p/w1280/A9qFJHnuFmNvg5UOmDCku7WDsph.jpg'),
(113917, 8120, 'Synduality: Noir [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266465.mp4', 'http://image.tmdb.org/t/p/w1280/o9D72jNEEImERDCpl0kXxaM3k3p.jpg'),
(113918, 8120, 'Synduality: Noir [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hLSjzucVFbrbJN9kJ3f44J6Dttp.jpg'),
(113919, 8120, 'Synduality: Noir [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hLSjzucVFbrbJN9kJ3f44J6Dttp.jpg'),
(113920, 8120, 'Synduality: Noir [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hLSjzucVFbrbJN9kJ3f44J6Dttp.jpg'),
(113921, 8120, 'Synduality: Noir [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hLSjzucVFbrbJN9kJ3f44J6Dttp.jpg'),
(113922, 8120, 'Synduality: Noir [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hLSjzucVFbrbJN9kJ3f44J6Dttp.jpg'),
(113923, 8120, 'Synduality: Noir [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hLSjzucVFbrbJN9kJ3f44J6Dttp.jpg'),
(113924, 8120, 'Synduality: Noir [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/266472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hLSjzucVFbrbJN9kJ3f44J6Dttp.jpg'),
(113925, 8120, 'Synduality: Noir [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/266473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hLSjzucVFbrbJN9kJ3f44J6Dttp.jpg'),
(113926, 8120, 'Synduality: Noir [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/272563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hLSjzucVFbrbJN9kJ3f44J6Dttp.jpg'),
(113927, 8120, 'Synduality: Noir [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/272564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hLSjzucVFbrbJN9kJ3f44J6Dttp.jpg'),
(113928, 8120, 'Synduality: Noir [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/274329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hLSjzucVFbrbJN9kJ3f44J6Dttp.jpg'),
(113929, 8120, 'Synduality: Noir [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/288542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hLSjzucVFbrbJN9kJ3f44J6Dttp.jpg'),
(113930, 8120, 'Synduality: Noir [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/289900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hLSjzucVFbrbJN9kJ3f44J6Dttp.jpg'),
(113931, 8120, 'Synduality: Noir [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/297095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hLSjzucVFbrbJN9kJ3f44J6Dttp.jpg'),
(113932, 8120, 'Synduality: Noir [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/303952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hLSjzucVFbrbJN9kJ3f44J6Dttp.jpg'),
(113933, 8120, 'Synduality: Noir [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/309649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hLSjzucVFbrbJN9kJ3f44J6Dttp.jpg'),
(113934, 8121, 'TenPuru [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sxxot7IVDzXN6hToH6jLSOGtLJr.jpg'),
(113935, 8121, 'TenPuru [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xgKTsCkBwYQdaKLzEaVeqBxgd1m.jpg'),
(113936, 8121, 'TenPuru [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gL8jTxzBYZl8TW7x8jDTIjnTRTZ.jpg'),
(113937, 8121, 'TenPuru [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tkX4eTrGKqVT8Ha2lRVFpSsYVrM.jpg'),
(113938, 8121, 'TenPuru [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/siunolMmXbQHhJSNCxsySPXVO8M.jpg'),
(113939, 8121, 'TenPuru [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qPvDtVJT2qZgmqEoIx5l4s5Tq8h.jpg'),
(113940, 8121, 'TenPuru [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5edyBIMjpBdOK50964UCezIO2Ie.jpg'),
(113941, 8121, 'TenPuru [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5edyBIMjpBdOK50964UCezIO2Ie.jpg'),
(113942, 8121, 'TenPuru [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5edyBIMjpBdOK50964UCezIO2Ie.jpg'),
(113943, 8121, 'TenPuru [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5edyBIMjpBdOK50964UCezIO2Ie.jpg'),
(113944, 8121, 'TenPuru [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5edyBIMjpBdOK50964UCezIO2Ie.jpg'),
(113945, 8121, 'TenPuru [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5edyBIMjpBdOK50964UCezIO2Ie.jpg'),
(113946, 8121, 'TenPuru [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5edyBIMjpBdOK50964UCezIO2Ie.jpg'),
(113947, 8121, 'TenPuru [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/254228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5edyBIMjpBdOK50964UCezIO2Ie.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(113948, 8122, 'The Duke of Death and His Maid [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tBiA85MyyqkzE4tc0EQC1XsnR2g.jpg'),
(113949, 8122, 'The Duke of Death and His Maid [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yxre86PZyJAv1Z9FrNwLkHh7MJA.jpg'),
(113950, 8122, 'The Duke of Death and His Maid [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/akVn9TFlwaLcmfTb7jmNOgfD9T4.jpg'),
(113951, 8122, 'The Duke of Death and His Maid [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ylpjETqLOLv4VvcylWnRSonBmJK.jpg'),
(113952, 8122, 'The Duke of Death and His Maid [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vY32YTu7NhUmFUYbgKpM2FV8FRD.jpg'),
(113953, 8122, 'The Duke of Death and His Maid [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1mMPfzgqswBoLpoXE6s6h2QrmTw.jpg'),
(113954, 8122, 'The Duke of Death and His Maid [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtDpeUkAITLzRFGxmC9sBuhKpsl.jpg'),
(113955, 8122, 'The Duke of Death and His Maid [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4H7QK0AsbBVBX7w5ChuvK8aznK4.jpg'),
(113956, 8122, 'The Duke of Death and His Maid [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b7FQ1UQajAuARwDFuw1fdrKJnI5.jpg'),
(113957, 8122, 'The Duke of Death and His Maid [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rYMdxeHs6AOQ18WQZAVhsYkGB6O.jpg'),
(113958, 8122, 'The Duke of Death and His Maid [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qWryssJHYHQefquWG3D5REgMlZ2.jpg'),
(113959, 8122, 'The Duke of Death and His Maid [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iUraugIKx7j3tiR2mzxcCpPKK4W.jpg'),
(113960, 8123, 'The Duke of Death and His Maid [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(113961, 8123, 'The Duke of Death and His Maid [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(113962, 8123, 'The Duke of Death and His Maid [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(113963, 8123, 'The Duke of Death and His Maid [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(113964, 8123, 'The Duke of Death and His Maid [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(113965, 8123, 'The Duke of Death and His Maid [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(113966, 8124, 'The Duke of Death and His Maid [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/321127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(113967, 8124, 'The Duke of Death and His Maid [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(113968, 8124, 'The Duke of Death and His Maid [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/339902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(113969, 8124, 'The Duke of Death and His Maid [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/339903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(113970, 8124, 'The Duke of Death and His Maid [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/604817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(113971, 8124, 'The Duke of Death and His Maid [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/360499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(113972, 8124, 'The Duke of Death and His Maid [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/360500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(113973, 8124, 'The Duke of Death and His Maid [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/360501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(113974, 8124, 'The Duke of Death and His Maid [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/372856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(113975, 8124, 'The Duke of Death and His Maid [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/604823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(113976, 8124, 'The Duke of Death and His Maid [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/388388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(113977, 8124, 'The Duke of Death and His Maid [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(113978, 8125, 'The Gene of AI [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3FnKGbjKsPHzTq6b4kuK4fs7oa7.jpg'),
(113979, 8125, 'The Gene of AI [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4rNqTn8CqwMiCbjnJecV2KOpUeP.jpg'),
(113980, 8125, 'The Gene of AI [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rinJvDG32OItzQSi7p2U2nzoAkv.jpg'),
(113981, 8125, 'The Gene of AI [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZmL2Tzl0TqlOdU2kcJTQZKbVH7.jpg'),
(113982, 8125, 'The Gene of AI [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJEuRxEjlCPp0N57IvWVPRuxYwH.jpg'),
(113983, 8125, 'The Gene of AI [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hVN2DcZhV4AluLBIdRS8BGyWXlP.jpg'),
(113984, 8125, 'The Gene of AI [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wSAD5RS0LRvx7rqvCKEJlXbDOv1.jpg'),
(113985, 8125, 'The Gene of AI [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wSAD5RS0LRvx7rqvCKEJlXbDOv1.jpg'),
(113986, 8125, 'The Gene of AI [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wSAD5RS0LRvx7rqvCKEJlXbDOv1.jpg'),
(113987, 8125, 'The Gene of AI [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wSAD5RS0LRvx7rqvCKEJlXbDOv1.jpg'),
(113988, 8125, 'The Gene of AI [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wSAD5RS0LRvx7rqvCKEJlXbDOv1.jpg'),
(113989, 8125, 'The Gene of AI [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wSAD5RS0LRvx7rqvCKEJlXbDOv1.jpg'),
(113990, 8126, 'Uma Vizinha de Outro Mundo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSEtViXIaFbbwpJjXx9aTxlcJrM.jpg'),
(113991, 8126, 'Uma Vizinha de Outro Mundo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJr0vytrlBcgdrIU3jl5VYa6eQr.jpg'),
(113992, 8126, 'Uma Vizinha de Outro Mundo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x4I5Ss7g7wEIi3lVUTAoDdoGnhG.jpg'),
(113993, 8126, 'Uma Vizinha de Outro Mundo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZhECnrmI5i4gWTEFdogKPKDxfD.jpg'),
(113994, 8126, 'Uma Vizinha de Outro Mundo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fCmJArpyNvj4OmWG5F4kpBCDw6q.jpg'),
(113995, 8126, 'Uma Vizinha de Outro Mundo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/95SpmT6Ti3wVtIyKELKfHDkmA64.jpg'),
(113996, 8126, 'Uma Vizinha de Outro Mundo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bhcWtUq3SuQ8jbOfvYsO3iKX5H1.jpg'),
(113997, 8126, 'Uma Vizinha de Outro Mundo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/55X00rRZuU8X2mxwXsNtqqGXjyS.jpg'),
(113998, 8126, 'Uma Vizinha de Outro Mundo [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1yeeWJACQ96vDFRgN7L8vv6sUcz.jpg'),
(113999, 8126, 'Uma Vizinha de Outro Mundo [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ua6ICaL3g3KklcctBX1ghEpNmc.jpg'),
(114000, 8126, 'Uma Vizinha de Outro Mundo [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y7nMHYbbpTXVHWEWGoxq6Sk1R4q.jpg'),
(114001, 8126, 'Uma Vizinha de Outro Mundo [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kgZWxqRj7euxnNE3QEF15K3sh45.jpg'),
(114002, 8127, 'A Torre [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4YKMh0yRd9zVVFzkqhxH2dDolOI.jpg'),
(114003, 8127, 'A Torre [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Zr0NJRbHwpwHh5ZORJRW0mL9hI.jpg'),
(114004, 8127, 'A Torre [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lRgCsnyLR0Jof3pynIJLZjnDqS8.jpg'),
(114005, 8128, 'A Torre [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7JnEjHVc9eveupA2cKh5jTAMZwi.jpg'),
(114006, 8128, 'A Torre [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231428.mp4', 'http://image.tmdb.org/t/p/w1280/33BcDsUU5TYT4q3G9CsCuIFUKWC.jpg'),
(114007, 8128, 'A Torre [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gMFxFR19eAlDLvaTyD9a4zNALaF.jpg'),
(114008, 8128, 'A Torre [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gMFxFR19eAlDLvaTyD9a4zNALaF.jpg'),
(114009, 8129, 'A Torre [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/464835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gMFxFR19eAlDLvaTyD9a4zNALaF.jpg'),
(114010, 8129, 'A Torre [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/475372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gMFxFR19eAlDLvaTyD9a4zNALaF.jpg'),
(114011, 8129, 'A Torre [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gMFxFR19eAlDLvaTyD9a4zNALaF.jpg'),
(114012, 8129, 'A Torre [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gMFxFR19eAlDLvaTyD9a4zNALaF.jpg'),
(114013, 8130, 'Armas e Amores S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/llUUewrFJQdNSp6ElYfVuRmxmvf.jpg'),
(114014, 8130, 'Armas e Amores S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9l4VqkuHn7OOORdhuHovH4F2Zez.jpg'),
(114015, 8130, 'Armas e Amores S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gvFuo33ZNfVkefJYxENMamzohFt.jpg'),
(114016, 8130, 'Armas e Amores S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3FqpMDT7GoiidPsJw39rwI5Vl4J.jpg'),
(114017, 8130, 'Armas e Amores S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3N9JxfcjUFkORcVxtgsLIFHMqDc.jpg'),
(114018, 8130, 'Armas e Amores S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bymyyEzg92qbuI19QFqc50Pf08P.jpg'),
(114019, 8130, 'Armas e Amores S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/327DFuyUCmFhSCXFOLrJADY7UCf.jpg'),
(114020, 8131, 'As Aventuras de José e Durval S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bGeXTTz0BFlK2FYyiCNyEGsrZcZ.jpg'),
(114021, 8131, 'As Aventuras de José e Durval S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bGeXTTz0BFlK2FYyiCNyEGsrZcZ.jpg'),
(114022, 8131, 'As Aventuras de José e Durval S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bGeXTTz0BFlK2FYyiCNyEGsrZcZ.jpg'),
(114023, 8131, 'As Aventuras de José e Durval S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236238.mp4', 'http://image.tmdb.org/t/p/w1280/uR0EuDjMuQwf19MyJ9hbbhFyiTl.jpg'),
(114024, 8131, 'As Aventuras de José e Durval S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bGeXTTz0BFlK2FYyiCNyEGsrZcZ.jpg'),
(114025, 8131, 'As Aventuras de José e Durval S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bGeXTTz0BFlK2FYyiCNyEGsrZcZ.jpg'),
(114026, 8131, 'As Aventuras de José e Durval S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bGeXTTz0BFlK2FYyiCNyEGsrZcZ.jpg'),
(114027, 8131, 'As Aventuras de José e Durval S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bGeXTTz0BFlK2FYyiCNyEGsrZcZ.jpg'),
(114028, 8132, 'Cangaço Novo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o03nNIvGisbEHy7s68LflnO3LxF.jpg'),
(114029, 8132, 'Cangaço Novo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dxFNNALEAPWOKKNPiZCAFFn58Lb.jpg'),
(114030, 8132, 'Cangaço Novo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sAU76ehTjXNpRqxkv0Q0TMhI9lP.jpg'),
(114031, 8132, 'Cangaço Novo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jIoICvi1Aqf3ERMMjWYyac5S82z.jpg'),
(114032, 8132, 'Cangaço Novo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lf5wbug3TWGzafq3lHW7zMJvZoT.jpg'),
(114033, 8132, 'Cangaço Novo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkJhQ74qm0tLg3QAd9GbhKn9NRw.jpg'),
(114034, 8132, 'Cangaço Novo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dD6ULcyWuTaKODOdJjivYsbYfdQ.jpg'),
(114035, 8132, 'Cangaço Novo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rs0GtPEP2qFjKS0xejcwRlsSaoz.jpg'),
(114036, 8133, 'Má Fortuna S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tuA0rHwN3OEzapXSjsSoYt42dJ6.jpg'),
(114037, 8133, 'Má Fortuna S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tuA0rHwN3OEzapXSjsSoYt42dJ6.jpg'),
(114038, 8133, 'Má Fortuna S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tuA0rHwN3OEzapXSjsSoYt42dJ6.jpg'),
(114039, 8133, 'Má Fortuna S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tuA0rHwN3OEzapXSjsSoYt42dJ6.jpg'),
(114040, 8133, 'Má Fortuna S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tuA0rHwN3OEzapXSjsSoYt42dJ6.jpg'),
(114041, 8133, 'Má Fortuna S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tuA0rHwN3OEzapXSjsSoYt42dJ6.jpg'),
(114042, 8133, 'Má Fortuna S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tuA0rHwN3OEzapXSjsSoYt42dJ6.jpg'),
(114043, 8133, 'Má Fortuna S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tuA0rHwN3OEzapXSjsSoYt42dJ6.jpg'),
(114044, 8134, 'Mask Girl S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ykn8vX7sPOKywExfDrBgFr3Hul.jpg'),
(114045, 8134, 'Mask Girl S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t0peHehauuVdVu1IfYP5PEzT6NT.jpg'),
(114046, 8134, 'Mask Girl S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7Dz048xl5eXx2s96mffE7m2BU0.jpg'),
(114047, 8134, 'Mask Girl S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/crCdEFCl2xf0o1fP921FrX1Lhql.jpg'),
(114048, 8134, 'Mask Girl S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2D0M4ZYG6JOrOP8bSwK20x9s4H.jpg'),
(114049, 8134, 'Mask Girl S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUyZNGtMkOcBBDZtmR4cDheS1QP.jpg'),
(114050, 8134, 'Mask Girl S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uBZUceQctbk3bBWYP9fUppaUfDj.jpg'),
(114051, 8135, 'O Que Fazemos nas Sombras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWypXq9IFxs7DIUAG5h9ppiDO0X.jpg'),
(114052, 8135, 'O Que Fazemos nas Sombras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mXz90qsbNehzh3g1m2UasUeORIm.jpg'),
(114053, 8135, 'O Que Fazemos nas Sombras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6HLC1CM3Xj1sW7y085DIpn0BwrL.jpg'),
(114054, 8135, 'O Que Fazemos nas Sombras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vS496mwI85SBqV6Y3ICBOrq6Zz2.jpg'),
(114055, 8135, 'O Que Fazemos nas Sombras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sKB2QffyoJnkYLHDK7wIUoMVtl1.jpg'),
(114056, 8135, 'O Que Fazemos nas Sombras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6i2sKUOUUYQOiu8T3fcaLc9Z2kd.jpg'),
(114057, 8135, 'O Que Fazemos nas Sombras S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOiYygcvwxha46oecjDkimKF5qr.jpg'),
(114058, 8135, 'O Que Fazemos nas Sombras S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gOOVxRjXFr3pbtpKPrLpPZKO61b.jpg'),
(114059, 8135, 'O Que Fazemos nas Sombras S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oahn4Abn427VvgCowp5ApdfMByz.jpg'),
(114060, 8135, 'O Que Fazemos nas Sombras S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9PpuLmt4dZBWxFVMbWnZSIRpuvy.jpg'),
(114061, 8136, 'O Que Fazemos nas Sombras S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5G09BmGOGWa44zmMM34qhQkTXyj.jpg'),
(114062, 8136, 'O Que Fazemos nas Sombras S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nRmEEdHxaJPcSRw3o5B0wkmI07v.jpg'),
(114063, 8136, 'O Que Fazemos nas Sombras S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dexnh3HWWFbPFsfu4esFNa0Fw86.jpg'),
(114064, 8136, 'O Que Fazemos nas Sombras S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/68LoYE73198Xa9nXNNfNbow6EE3.jpg'),
(114065, 8136, 'O Que Fazemos nas Sombras S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9mLJ3rhxvGUDDOW1ekSiYPyGAMO.jpg'),
(114066, 8136, 'O Que Fazemos nas Sombras S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yzY1KdyTIUArD1NuVuIACqwDww9.jpg'),
(114067, 8136, 'O Que Fazemos nas Sombras S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gGJevOJqqH4WAgZHn66bRb73rWY.jpg'),
(114068, 8136, 'O Que Fazemos nas Sombras S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bsDWofrze6W99NJZpaCSAaNVzL4.jpg'),
(114069, 8136, 'O Que Fazemos nas Sombras S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fkS06ptsNsfnVRwBgUGi6NNIG9W.jpg'),
(114070, 8136, 'O Que Fazemos nas Sombras S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9FUnQZBMXq7P3zxWBybKElKVQaG.jpg'),
(114071, 8137, 'O Que Fazemos nas Sombras S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9MlFY79QRbRVPFpPtYq5vXCpzCt.jpg'),
(114072, 8137, 'O Que Fazemos nas Sombras S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1iQP8GYAtQNlcSZaKRhwuUr5R5O.jpg'),
(114073, 8137, 'O Que Fazemos nas Sombras S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hU1nzzHre9a56GaklsnQfiuJ9fs.jpg'),
(114074, 8137, 'O Que Fazemos nas Sombras S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ixyE6jyj6PUWDJ51RTNVBi0lmPT.jpg'),
(114075, 8137, 'O Que Fazemos nas Sombras S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uw7zsLoPcQynPDhrw8TM7nLIjIZ.jpg'),
(114076, 8137, 'O Que Fazemos nas Sombras S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nNQiFjrhh5gsGZRRdW7wntAkI2y.jpg'),
(114077, 8137, 'O Que Fazemos nas Sombras S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7iPQ37XLU3DCRxjhXLhklz1xyL.jpg'),
(114078, 8137, 'O Que Fazemos nas Sombras S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JTO6lcXVOJlyzg0e83GKFtdZJt.jpg'),
(114079, 8137, 'O Que Fazemos nas Sombras S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dpaH9LtZ9GiAGK1D0qz5EvNorcJ.jpg'),
(114080, 8137, 'O Que Fazemos nas Sombras S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1KDw6asac05ct1SONRPjybQcske.jpg'),
(114081, 8138, 'O Que Fazemos nas Sombras S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6dCvtzLkR01KKzxvmIpHeIQ7h0G.jpg'),
(114082, 8138, 'O Que Fazemos nas Sombras S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AkJxOPMUJJ7GESAgVKz59xXTIdT.jpg'),
(114083, 8138, 'O Que Fazemos nas Sombras S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7X9ZiONiodX3VC2Gh7NuMuo9PtZ.jpg'),
(114084, 8138, 'O Que Fazemos nas Sombras S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wV8ODmpYwMOG1yhwsmXEcp9w9tF.jpg'),
(114085, 8138, 'O Que Fazemos nas Sombras S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/92aycEyAM77LATkdWAfIW8YHXRb.jpg'),
(114086, 8138, 'O Que Fazemos nas Sombras S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/88TxhGxkXPBdPxiIhuFDIzNe5n8.jpg'),
(114087, 8138, 'O Que Fazemos nas Sombras S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aMObsxiDWDZ9pTSFKnqkDkolisC.jpg'),
(114088, 8138, 'O Que Fazemos nas Sombras S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qGyWXDtAFMLPkVOLdyicIxdH0BB.jpg'),
(114089, 8138, 'O Que Fazemos nas Sombras S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i3KTPO8CpuLyQuvl69jCl5spAn6.jpg'),
(114090, 8138, 'O Que Fazemos nas Sombras S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yz2eUTRrnp9MG9hzmSBqIBTiXvF.jpg'),
(114091, 8139, 'O Que Fazemos nas Sombras S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5eBRvsjGKh2pMQtXHabTHzqsClm.jpg'),
(114092, 8139, 'O Que Fazemos nas Sombras S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pFTY2ljzdF6Mj2YycvsZzPFNmIM.jpg'),
(114093, 8139, 'O Que Fazemos nas Sombras S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242263.mp4', 'http://image.tmdb.org/t/p/w1280/fHRmrdsFvF2Ktz2VD3ASfNS8uA8.jpg'),
(114094, 8139, 'O Que Fazemos nas Sombras S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242264.mp4', 'http://image.tmdb.org/t/p/w1280/vviMajyGlWy7cMwwI4AxbC5MC9B.jpg'),
(114095, 8139, 'O Que Fazemos nas Sombras S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chckIPxBbvyFCcCFz8VPHgWCIHL.jpg'),
(114096, 8139, 'O Que Fazemos nas Sombras S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chckIPxBbvyFCcCFz8VPHgWCIHL.jpg'),
(114097, 8139, 'O Que Fazemos nas Sombras S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chckIPxBbvyFCcCFz8VPHgWCIHL.jpg'),
(114098, 8139, 'O Que Fazemos nas Sombras S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chckIPxBbvyFCcCFz8VPHgWCIHL.jpg'),
(114099, 8139, 'O Que Fazemos nas Sombras S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chckIPxBbvyFCcCFz8VPHgWCIHL.jpg'),
(114100, 8139, 'O Que Fazemos nas Sombras S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chckIPxBbvyFCcCFz8VPHgWCIHL.jpg'),
(114101, 8140, 'O Que Fazemos nas Sombras S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/525210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chckIPxBbvyFCcCFz8VPHgWCIHL.jpg'),
(114102, 8140, 'O Que Fazemos nas Sombras S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/525211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chckIPxBbvyFCcCFz8VPHgWCIHL.jpg'),
(114103, 8140, 'O Que Fazemos nas Sombras S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/525212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chckIPxBbvyFCcCFz8VPHgWCIHL.jpg'),
(114104, 8140, 'O Que Fazemos nas Sombras S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/525213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chckIPxBbvyFCcCFz8VPHgWCIHL.jpg'),
(114105, 8140, 'O Que Fazemos nas Sombras S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/525214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chckIPxBbvyFCcCFz8VPHgWCIHL.jpg'),
(114106, 8140, 'O Que Fazemos nas Sombras S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/658927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chckIPxBbvyFCcCFz8VPHgWCIHL.jpg'),
(114107, 8140, 'O Que Fazemos nas Sombras S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/525216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chckIPxBbvyFCcCFz8VPHgWCIHL.jpg'),
(114108, 8140, 'O Que Fazemos nas Sombras S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/525217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chckIPxBbvyFCcCFz8VPHgWCIHL.jpg'),
(114109, 8140, 'O Que Fazemos nas Sombras S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/640845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chckIPxBbvyFCcCFz8VPHgWCIHL.jpg'),
(114110, 8140, 'O Que Fazemos nas Sombras S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/658931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chckIPxBbvyFCcCFz8VPHgWCIHL.jpg'),
(114111, 8140, 'O Que Fazemos nas Sombras S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/658932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chckIPxBbvyFCcCFz8VPHgWCIHL.jpg'),
(114112, 8141, 'Refúgio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4QAhacJ9Lg3W5isPMH1HE6zldDd.jpg'),
(114113, 8141, 'Refúgio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xwt03UqpgnLi261Z67P5bVXcHd5.jpg'),
(114114, 8141, 'Refúgio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eOWfK5KbtO0XsiIKC5FOidDxTuY.jpg'),
(114115, 8141, 'Refúgio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236230.mp4', 'http://image.tmdb.org/t/p/w1280/27Ebt6ploVGgOJLjQx8xGu60bLP.jpg'),
(114116, 8141, 'Refúgio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236231.mp4', 'http://image.tmdb.org/t/p/w1280/bhKvSeuTrqDDIf8ZKS0Zy38jUKF.jpg'),
(114117, 8141, 'Refúgio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGXGEP6T5dnSlSlm7gnUISo4AID.jpg'),
(114118, 8141, 'Refúgio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGXGEP6T5dnSlSlm7gnUISo4AID.jpg'),
(114119, 8141, 'Refúgio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGXGEP6T5dnSlSlm7gnUISo4AID.jpg'),
(114120, 8142, 'Doce Reencarnação [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AsfCidD6cjPTZg1Q4Ua6EBsHXeC.jpg'),
(114121, 8142, 'Doce Reencarnação [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7uH6AyFpTJp6swzp6AbtUtRTc55.jpg'),
(114122, 8142, 'Doce Reencarnação [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cZ0pL4AfP36xm0GkmeNKhI45Iml.jpg'),
(114123, 8142, 'Doce Reencarnação [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jQF30eQfB3QLGmEX8qf22cjIQhd.jpg'),
(114124, 8142, 'Doce Reencarnação [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3gPZy5ni3kNlwr30qGYxoWmmuwn.jpg'),
(114125, 8142, 'Doce Reencarnação [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yKDqUneMtDNXx5CCvZuuiWXn44n.jpg'),
(114126, 8142, 'Doce Reencarnação [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4TaIgTfMTZRFdFSLSipBQuQogjr.jpg'),
(114127, 8142, 'Doce Reencarnação [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gbaKEfCq0KmAgRdZzBLbbGshvOE.jpg'),
(114128, 8142, 'Doce Reencarnação [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPmbLLoCgvdxsG0kpm8mF9aY4fK.jpg'),
(114129, 8142, 'Doce Reencarnação [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPmbLLoCgvdxsG0kpm8mF9aY4fK.jpg'),
(114130, 8142, 'Doce Reencarnação [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPmbLLoCgvdxsG0kpm8mF9aY4fK.jpg'),
(114131, 8142, 'Doce Reencarnação [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dPmbLLoCgvdxsG0kpm8mF9aY4fK.jpg'),
(114132, 8143, 'Tomo-chan Is a Girl! [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kw8OqUhlcxD4MCAVtyH7jCjzbNy.jpg'),
(114133, 8143, 'Tomo-chan Is a Girl! [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5aInmTEDAB86fRKbU3m1LfuGcvk.jpg'),
(114134, 8143, 'Tomo-chan Is a Girl! [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yZyIZTuHunS3i2Tcsqsa6OoM7Ia.jpg'),
(114135, 8143, 'Tomo-chan Is a Girl! [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nID36AQDQFH2JNBO32PVYZWFcyc.jpg'),
(114136, 8143, 'Tomo-chan Is a Girl! [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jplnsTQzXCNFoZL12qxsSU6gxwM.jpg'),
(114137, 8143, 'Tomo-chan Is a Girl! [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/49jvmhx55ppy890QfOeI5QX561m.jpg'),
(114138, 8143, 'Tomo-chan Is a Girl! [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5O3b2HEQuCMcmAACghgrG8go2p.jpg'),
(114139, 8143, 'Tomo-chan Is a Girl! [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfO61lJS2uqZTCPYtgC7hwPz73L.jpg'),
(114140, 8143, 'Tomo-chan Is a Girl! [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tFGNP8tSYdsH1OgdRK3TDtSdoL.jpg'),
(114141, 8143, 'Tomo-chan Is a Girl! [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ifpS2NWw5WDpHLiaI1cZG9bGeAt.jpg'),
(114142, 8143, 'Tomo-chan Is a Girl! [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Y1wLshEIYwRvzecFsqxcpmv6t6.jpg'),
(114143, 8143, 'Tomo-chan Is a Girl! [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8o5qYI1KQMG50i190rz3dM4uaOQ.jpg'),
(114144, 8143, 'Tomo-chan Is a Girl! [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1NJR63PmaPQNfblkjYwn5ONOiWQ.jpg'),
(114145, 8144, 'When Sharks Attack... and Why S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cUFml3HYeH6QOMne4iyA62ZRwjH.jpg'),
(114146, 8144, 'When Sharks Attack... and Why S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cUFml3HYeH6QOMne4iyA62ZRwjH.jpg'),
(114147, 8144, 'When Sharks Attack... and Why S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cUFml3HYeH6QOMne4iyA62ZRwjH.jpg'),
(114148, 8144, 'When Sharks Attack... and Why S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cUFml3HYeH6QOMne4iyA62ZRwjH.jpg'),
(114149, 8144, 'When Sharks Attack... and Why S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cUFml3HYeH6QOMne4iyA62ZRwjH.jpg'),
(114150, 8144, 'When Sharks Attack... and Why S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cUFml3HYeH6QOMne4iyA62ZRwjH.jpg'),
(114151, 8144, 'When Sharks Attack... and Why S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cUFml3HYeH6QOMne4iyA62ZRwjH.jpg'),
(114152, 8144, 'When Sharks Attack... and Why S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cUFml3HYeH6QOMne4iyA62ZRwjH.jpg'),
(114153, 8145, 'YOHANE THE PARHELION SUNSHINE in the MIRROR [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDd6QUKO0029OXY4Wl1op56Gjqz.jpg'),
(114154, 8145, 'YOHANE THE PARHELION SUNSHINE in the MIRROR [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c4ZLPfXWYLkrOBvFNrQKwvnVev0.jpg'),
(114155, 8145, 'YOHANE THE PARHELION SUNSHINE in the MIRROR [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tkgVyHcK1K3IdAVn7Px4RCxEW6b.jpg'),
(114156, 8145, 'YOHANE THE PARHELION SUNSHINE in the MIRROR [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jU7qJ2Xq7Cytr7vX3csWQayqTeB.jpg'),
(114157, 8145, 'YOHANE THE PARHELION SUNSHINE in the MIRROR [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mChfWsG7bgmnswhOcWX2YlTY0qo.jpg'),
(114158, 8145, 'YOHANE THE PARHELION SUNSHINE in the MIRROR [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/reIAYoUFNIEwNGU69VTCJmI7jBh.jpg'),
(114159, 8145, 'YOHANE THE PARHELION SUNSHINE in the MIRROR [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7oQkRSOBhSfBYHPy8dmIDTvOs.jpg'),
(114160, 8145, 'YOHANE THE PARHELION SUNSHINE in the MIRROR [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5NdDlRa22zqI5jnYUREt0z6MVvu.jpg'),
(114161, 8145, 'YOHANE THE PARHELION SUNSHINE in the MIRROR [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veG1PzAYKR5aGbXfmF5ioT3wIk3.jpg'),
(114162, 8145, 'YOHANE THE PARHELION SUNSHINE in the MIRROR [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veG1PzAYKR5aGbXfmF5ioT3wIk3.jpg'),
(114163, 8145, 'YOHANE THE PARHELION SUNSHINE in the MIRROR [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veG1PzAYKR5aGbXfmF5ioT3wIk3.jpg'),
(114164, 8145, 'YOHANE THE PARHELION SUNSHINE in the MIRROR [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veG1PzAYKR5aGbXfmF5ioT3wIk3.jpg'),
(114165, 8145, 'YOHANE THE PARHELION SUNSHINE in the MIRROR [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veG1PzAYKR5aGbXfmF5ioT3wIk3.jpg'),
(114166, 8146, 'A Familia Hathaway S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114167, 8146, 'A Familia Hathaway S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114168, 8146, 'A Familia Hathaway S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114169, 8146, 'A Familia Hathaway S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114170, 8146, 'A Familia Hathaway S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114171, 8146, 'A Familia Hathaway S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114172, 8146, 'A Familia Hathaway S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114173, 8146, 'A Familia Hathaway S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114174, 8146, 'A Familia Hathaway S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114175, 8146, 'A Familia Hathaway S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114176, 8146, 'A Familia Hathaway S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114177, 8146, 'A Familia Hathaway S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114178, 8146, 'A Familia Hathaway S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114179, 8146, 'A Familia Hathaway S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114180, 8146, 'A Familia Hathaway S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114181, 8146, 'A Familia Hathaway S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/228326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114182, 8146, 'A Familia Hathaway S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/228327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114183, 8146, 'A Familia Hathaway S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/228328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114184, 8146, 'A Familia Hathaway S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/228329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114185, 8146, 'A Familia Hathaway S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/228330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114186, 8146, 'A Familia Hathaway S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/228331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114187, 8146, 'A Familia Hathaway S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/228332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114188, 8146, 'A Familia Hathaway S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/228333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114189, 8146, 'A Familia Hathaway S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/228334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114190, 8146, 'A Familia Hathaway S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/228335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114191, 8146, 'A Familia Hathaway S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/228336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114192, 8147, 'A Familia Hathaway S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114193, 8147, 'A Familia Hathaway S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114194, 8147, 'A Familia Hathaway S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114195, 8147, 'A Familia Hathaway S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114196, 8147, 'A Familia Hathaway S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114197, 8147, 'A Familia Hathaway S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114198, 8147, 'A Familia Hathaway S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114199, 8147, 'A Familia Hathaway S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114200, 8147, 'A Familia Hathaway S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tAxJQA3113LReFMNu4o7Gi54k4r.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(114201, 8147, 'A Familia Hathaway S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114202, 8147, 'A Familia Hathaway S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114203, 8147, 'A Familia Hathaway S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114204, 8147, 'A Familia Hathaway S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114205, 8147, 'A Familia Hathaway S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114206, 8147, 'A Familia Hathaway S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114207, 8147, 'A Familia Hathaway S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/228352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114208, 8147, 'A Familia Hathaway S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/228353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114209, 8147, 'A Familia Hathaway S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/228354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114210, 8147, 'A Familia Hathaway S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/228355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114211, 8147, 'A Familia Hathaway S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/228356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114212, 8147, 'A Familia Hathaway S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/228357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114213, 8147, 'A Familia Hathaway S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/228358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q4to2WY4SUx0HhIyNxh2ykZGEh2.jpg'),
(114214, 8148, 'Ahsoka S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i29R3K7YgLQvBFtTkMAI7zQ9bHi.jpg'),
(114215, 8148, 'Ahsoka S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sNpqRcwDFwDSWlkW6L3ZqQHZLIK.jpg'),
(114216, 8148, 'Ahsoka S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8dcwHjqqE09a90vPCoBO7y4Qgfh.jpg'),
(114217, 8148, 'Ahsoka S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237753.mp4', 'http://image.tmdb.org/t/p/w1280/3wHTKAmxGASishRbSg3U7K84Tjy.jpg'),
(114218, 8148, 'Ahsoka S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/laCJxobHoPVaLQTKxc14Y2zV64J.jpg'),
(114219, 8148, 'Ahsoka S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/laCJxobHoPVaLQTKxc14Y2zV64J.jpg'),
(114220, 8148, 'Ahsoka S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/laCJxobHoPVaLQTKxc14Y2zV64J.jpg'),
(114221, 8148, 'Ahsoka S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/laCJxobHoPVaLQTKxc14Y2zV64J.jpg'),
(114222, 8149, 'Amarras do Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wP73IbRnfbhfMtko67Io9yZBecJ.jpg'),
(114223, 8149, 'Amarras do Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vZYz6nDSWG1Nq8G3Zd8nJAiHk59.jpg'),
(114224, 8149, 'Amarras do Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vslBu1jWM9MIsqEaLBvO9yV9qyE.jpg'),
(114225, 8149, 'Amarras do Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fZLddHAfajr7lxxokjdWwJdiZrM.jpg'),
(114226, 8149, 'Amarras do Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hsjyebM113PdI23GSXeZ7GWqqE9.jpg'),
(114227, 8149, 'Amarras do Amor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xsHrVPakucf3cIW0W2AJVVUmFGH.jpg'),
(114228, 8149, 'Amarras do Amor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oUQ29Tks7wUgkU48KXcJkKsnA0F.jpg'),
(114229, 8149, 'Amarras do Amor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBiSGxChUARK0eg2YOzt010n2e3.jpg'),
(114230, 8149, 'Amarras do Amor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/33AcOXF069yDSZue7f6Q09TWALc.jpg'),
(114231, 8149, 'Amarras do Amor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/acjZqpiZGMvVNu6iQvZnV4hcPuF.jpg'),
(114232, 8149, 'Amarras do Amor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2gKJhlZ27JYx8sFdkgrw8dlU2jh.jpg'),
(114233, 8149, 'Amarras do Amor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ryPFtgPM3axMt36NUASJEuSUwgN.jpg'),
(114234, 8149, 'Amarras do Amor S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5OkAZBsMdtUmnMxGXCS2OcKIHKv.jpg'),
(114235, 8149, 'Amarras do Amor S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sUFJ94VhJ9MZk3Eh7BbyLKRJXgr.jpg'),
(114236, 8149, 'Amarras do Amor S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c25o6rPUOV4lFRYBWGVkNCsOikH.jpg'),
(114237, 8149, 'Amarras do Amor S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/228278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/50ZbI3VMVEQDxrjeFS4diq8qZyK.jpg'),
(114238, 8149, 'Amarras do Amor S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/228279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gx2Yue6eIXhBJ6vlvhkdsMHileD.jpg'),
(114239, 8149, 'Amarras do Amor S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/228280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4NU78MgbYBivLwyCfShgylIHc4W.jpg'),
(114240, 8149, 'Amarras do Amor S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/228281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/al93LCltTqBKUaLvv7amLnDs4rr.jpg'),
(114241, 8149, 'Amarras do Amor S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/228282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m0Z4GLHfL0yQ53klo5Y8vy2FGTy.jpg'),
(114242, 8149, 'Amarras do Amor S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/228283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vHdSsiHEMacBLfUPJnG1twhl021.jpg'),
(114243, 8149, 'Amarras do Amor S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/228284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sBQOxm2ofCS2ywz83eb1chBcO6w.jpg'),
(114244, 8149, 'Amarras do Amor S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/228285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m1o5CA3jRcnfVbCsDcHlw82gubU.jpg'),
(114245, 8149, 'Amarras do Amor S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/228286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lpXDwTGqMxO9AqaMlKFYgIFMfYp.jpg'),
(114246, 8150, 'Amarras do Amor S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nNYQHLDZ5lrDWQJ7JAwCwQpECqw.jpg'),
(114247, 8150, 'Amarras do Amor S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2C7TEFbdDofNDoclSBX6fbqd9NS.jpg'),
(114248, 8150, 'Amarras do Amor S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hXeNhbwUNE7KBbOyZZ7qH2i9vGO.jpg'),
(114249, 8150, 'Amarras do Amor S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bTquxOY34OmHkgrmBf2rH6C6Rct.jpg'),
(114250, 8150, 'Amarras do Amor S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wUxkuTtI4Eml9HVBYZV8aiDL5RZ.jpg'),
(114251, 8150, 'Amarras do Amor S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iyVWjbvvorl5jZHdwVhUiOprDkO.jpg'),
(114252, 8150, 'Amarras do Amor S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jiTnPsGPIfPcRa98moV44KVHcea.jpg'),
(114253, 8150, 'Amarras do Amor S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tmSyjhcxhXJFInUTvbZt1c1fl7J.jpg'),
(114254, 8150, 'Amarras do Amor S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ymLP6a01Z5aV4XVCZJyOaQmQ6yF.jpg'),
(114255, 8150, 'Amarras do Amor S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oW4vbZONeFNbMi5i4EzyXxniBYq.jpg'),
(114256, 8150, 'Amarras do Amor S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xmu5ks7Q6LttFeRnqNRGCMX0Yhk.jpg'),
(114257, 8150, 'Amarras do Amor S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/teGgI662NMh5NxZHmkLfXaGtP6Z.jpg'),
(114258, 8150, 'Amarras do Amor S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eV0QVjVJnrGFjrgyGZJ0HlqDN3e.jpg'),
(114259, 8150, 'Amarras do Amor S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/30m2K1O0BjmMR2yIaAJ8e5gdnDR.jpg'),
(114260, 8150, 'Amarras do Amor S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d7nynpYpksqKXgMCWSdWP0lgytz.jpg'),
(114261, 8150, 'Amarras do Amor S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/228302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uFYQ0tb4DML6zWnKS58CPQ7LAjp.jpg'),
(114262, 8150, 'Amarras do Amor S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/228303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZY07FxiPB7erARGhiUVl3QIxZ7.jpg'),
(114263, 8150, 'Amarras do Amor S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/228304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vsRZ89KtBCQE45U5I2Y9JIokfkj.jpg'),
(114264, 8150, 'Amarras do Amor S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/228305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tAnMGEZpFInHPTm9KmzWUYOSB0v.jpg'),
(114265, 8150, 'Amarras do Amor S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/228306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYg3yUx0tSSwIizS9qSI6VWdfcG.jpg'),
(114266, 8150, 'Amarras do Amor S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/228307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fhHaNb3ni7VzTo7XWQE5nq2D4Rz.jpg'),
(114267, 8150, 'Amarras do Amor S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/228308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eEa4WdUMCzYJ2byneBhq91Fo74N.jpg'),
(114268, 8150, 'Amarras do Amor S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/228309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lHeu4zn7VYydg4Z0hUR1X5mmwDP.jpg'),
(114269, 8150, 'Amarras do Amor S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/228310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3K9gTI9E288A4kiqLKX6dWjrq3Y.jpg'),
(114270, 8151, 'Bar do Gogó S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6d9P9lFFkc0qSfQnHA05AhYUdxR.jpg'),
(114271, 8151, 'Bar do Gogó S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7utcoKUoS6OxMxYVzQYpuev8jor.jpg'),
(114272, 8151, 'Bar do Gogó S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/56ZbWYbytr7Ub2ktkG0oVClicqA.jpg'),
(114273, 8151, 'Bar do Gogó S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2owN1bwKBJmg3w0HIlTre6q4xbW.jpg'),
(114274, 8151, 'Bar do Gogó S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231413.mp4', 'http://image.tmdb.org/t/p/w1280/42HzHLHVlWhPxVx30J3zmQIx3E0.jpg'),
(114275, 8151, 'Bar do Gogó S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231414.mp4', 'http://image.tmdb.org/t/p/w1280/1YK7eXz6KAXFEtDw5O7VHbVFrnR.jpg'),
(114276, 8151, 'Bar do Gogó S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231415.mp4', 'http://image.tmdb.org/t/p/w1280/puyzKS6waakLEhIcBZ5uDOfUnJ9.jpg'),
(114277, 8151, 'Bar do Gogó S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231416.mp4', 'http://image.tmdb.org/t/p/w1280/uFmME6n3zzf54ECkmNfbsCyiPnz.jpg'),
(114278, 8151, 'Bar do Gogó S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231417.mp4', 'http://image.tmdb.org/t/p/w1280/yEYGVKDupI9Cuu3IgFkdSuq2uLT.jpg'),
(114279, 8151, 'Bar do Gogó S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231418.mp4', 'http://image.tmdb.org/t/p/w1280/7FGR8Uycqg1slnhE03aIZkiu1zp.jpg'),
(114280, 8151, 'Bar do Gogó S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/231419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9miHVmUwKF6A0e02qewP8XYnb7r.jpg'),
(114281, 8151, 'Bar do Gogó S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/231420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wPtT9H7YarkUxL4uwmDMsFeCkgS.jpg'),
(114282, 8151, 'Bar do Gogó S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/231421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uk8T2T7vt2reeIVBDUijlNiTGQb.jpg'),
(114283, 8151, 'Bar do Gogó S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/231422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3vMtvK25ASKmtycqa4qXgbXQ6Bk.jpg'),
(114284, 8151, 'Bar do Gogó S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/231423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rFgElzlIA0pzg7g2czvFAXVXyQy.jpg'),
(114285, 8152, 'Bar do Gogó S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/385060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rFgElzlIA0pzg7g2czvFAXVXyQy.jpg'),
(114286, 8152, 'Bar do Gogó S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/385061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rFgElzlIA0pzg7g2czvFAXVXyQy.jpg'),
(114287, 8152, 'Bar do Gogó S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/385062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rFgElzlIA0pzg7g2czvFAXVXyQy.jpg'),
(114288, 8152, 'Bar do Gogó S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/392926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rFgElzlIA0pzg7g2czvFAXVXyQy.jpg'),
(114289, 8152, 'Bar do Gogó S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/392927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rFgElzlIA0pzg7g2czvFAXVXyQy.jpg'),
(114290, 8152, 'Bar do Gogó S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/398041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rFgElzlIA0pzg7g2czvFAXVXyQy.jpg'),
(114291, 8152, 'Bar do Gogó S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/398042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rFgElzlIA0pzg7g2czvFAXVXyQy.jpg'),
(114292, 8152, 'Bar do Gogó S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/398822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rFgElzlIA0pzg7g2czvFAXVXyQy.jpg'),
(114293, 8152, 'Bar do Gogó S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/398823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rFgElzlIA0pzg7g2czvFAXVXyQy.jpg'),
(114294, 8152, 'Bar do Gogó S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/398824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rFgElzlIA0pzg7g2czvFAXVXyQy.jpg'),
(114295, 8152, 'Bar do Gogó S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/401256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rFgElzlIA0pzg7g2czvFAXVXyQy.jpg'),
(114296, 8152, 'Bar do Gogó S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/403692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rFgElzlIA0pzg7g2czvFAXVXyQy.jpg'),
(114297, 8152, 'Bar do Gogó S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/403693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rFgElzlIA0pzg7g2czvFAXVXyQy.jpg'),
(114298, 8152, 'Bar do Gogó S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/403694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rFgElzlIA0pzg7g2czvFAXVXyQy.jpg'),
(114299, 8152, 'Bar do Gogó S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/403695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rFgElzlIA0pzg7g2czvFAXVXyQy.jpg'),
(114300, 8153, 'Humor Negro: A Série S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ewC72nykDv4wBmTJvwXChKw0ds2.jpg'),
(114301, 8153, 'Humor Negro: A Série S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBjmdu5Qo7DY2VyvRjBedl4oWw9.jpg'),
(114302, 8153, 'Humor Negro: A Série S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fcjqIQSZPk7zbb9KwjPqL4XH20e.jpg'),
(114303, 8153, 'Humor Negro: A Série S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fN8HV80Iq5M2O4jIGYf8jKOJ0ED.jpg'),
(114304, 8153, 'Humor Negro: A Série S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iyoyHMoVQPsJpQOoip1856SvAdY.jpg'),
(114305, 8153, 'Humor Negro: A Série S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mKmXBuJTSSvyf1ENeytCSxiXxA5.jpg'),
(114306, 8153, 'Humor Negro: A Série S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1kYhflvmJCa3tg6IjiP3hjZ9VXp.jpg'),
(114307, 8153, 'Humor Negro: A Série S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3MUCHzaPwYTT4wQdEbofOqt8zN.jpg'),
(114308, 8153, 'Humor Negro: A Série S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7G3KbyUj7oGynkiQqinbS2FvCUz.jpg'),
(114309, 8153, 'Humor Negro: A Série S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5nNRFjBof8AVfgavFXU7RnOTvUY.jpg'),
(114310, 8154, 'O Negociador S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i4aR3J6iyYWivIl8EiKgQDtzkPd.jpg'),
(114311, 8154, 'O Negociador S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i4aR3J6iyYWivIl8EiKgQDtzkPd.jpg'),
(114312, 8154, 'O Negociador S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i4aR3J6iyYWivIl8EiKgQDtzkPd.jpg'),
(114313, 8154, 'O Negociador S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i4aR3J6iyYWivIl8EiKgQDtzkPd.jpg'),
(114314, 8154, 'O Negociador S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i4aR3J6iyYWivIl8EiKgQDtzkPd.jpg'),
(114315, 8154, 'O Negociador S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i4aR3J6iyYWivIl8EiKgQDtzkPd.jpg'),
(114316, 8154, 'O Negociador S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i4aR3J6iyYWivIl8EiKgQDtzkPd.jpg'),
(114317, 8154, 'O Negociador S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i4aR3J6iyYWivIl8EiKgQDtzkPd.jpg'),
(114318, 8155, 'Untold: Entre o Campo e o Crime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i6ibHnkZvH2HiQdA19Tf8dVQhCr.jpg'),
(114319, 8155, 'Untold: Entre o Campo e o Crime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZk2L0k2GC0hl5U2riuHOvR4IWX.jpg'),
(114320, 8155, 'Untold: Entre o Campo e o Crime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b2jffyHgowi0Ui0kFuWwhoVzvIo.jpg'),
(114321, 8155, 'Untold: Entre o Campo e o Crime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v5tmJioz84AfEc2eA0VCvImCucP.jpg'),
(114322, 8156, 'Nosso Destino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pqbw6FCn2yIDbd5kp9VzOMg8pFY.jpg'),
(114323, 8156, 'Nosso Destino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2tkXtj2JasbScnrvUfYnxfVP4yb.jpg'),
(114324, 8156, 'Nosso Destino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241864.mp4', 'http://image.tmdb.org/t/p/w1280/dyGJIo5YvhqCVJzw07yKZqYT8g4.jpg'),
(114325, 8156, 'Nosso Destino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5L4GaXs0WYGmMGWeOynjN9hqBXP.jpg'),
(114326, 8156, 'Nosso Destino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241866.mp4', 'http://image.tmdb.org/t/p/w1280/6ltOdyQgxyNznmAhHTqQFvcO0i0.jpg'),
(114327, 8156, 'Nosso Destino S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241867.mp4', 'http://image.tmdb.org/t/p/w1280/hcKbGuCV4HPOywmREMn5neYrWhU.jpg'),
(114328, 8156, 'Nosso Destino S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5L4GaXs0WYGmMGWeOynjN9hqBXP.jpg'),
(114329, 8156, 'Nosso Destino S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5L4GaXs0WYGmMGWeOynjN9hqBXP.jpg'),
(114330, 8156, 'Nosso Destino S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5L4GaXs0WYGmMGWeOynjN9hqBXP.jpg'),
(114331, 8156, 'Nosso Destino S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5L4GaXs0WYGmMGWeOynjN9hqBXP.jpg'),
(114332, 8156, 'Nosso Destino S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5L4GaXs0WYGmMGWeOynjN9hqBXP.jpg'),
(114333, 8156, 'Nosso Destino S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5L4GaXs0WYGmMGWeOynjN9hqBXP.jpg'),
(114334, 8156, 'Nosso Destino S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5L4GaXs0WYGmMGWeOynjN9hqBXP.jpg'),
(114335, 8156, 'Nosso Destino S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5L4GaXs0WYGmMGWeOynjN9hqBXP.jpg'),
(114336, 8156, 'Nosso Destino S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5L4GaXs0WYGmMGWeOynjN9hqBXP.jpg'),
(114337, 8156, 'Nosso Destino S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/241877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5L4GaXs0WYGmMGWeOynjN9hqBXP.jpg'),
(114338, 8157, 'Quem é Erin Carter? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2GRg3GzVLusgTT33OfR1FPYQJ92.jpg'),
(114339, 8157, 'Quem é Erin Carter? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8GAoChAtAUx5h2qFfTO0v7mzePK.jpg'),
(114340, 8157, 'Quem é Erin Carter? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nfB8aOWUP5En8fg3vNVZbWYzqJl.jpg'),
(114341, 8157, 'Quem é Erin Carter? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yewV6lMGnzmroj8hhg3onIB6yS3.jpg'),
(114342, 8157, 'Quem é Erin Carter? S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sA3Ed1OXJUEnpAj3oPiR99TPC0R.jpg'),
(114343, 8157, 'Quem é Erin Carter? S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yIBykxp6mAbqvrwds7HKSLxYUnz.jpg'),
(114344, 8157, 'Quem é Erin Carter? S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tadCYU83YiGt9T8wKmc3wU3eVxw.jpg'),
(114345, 8158, 'Sobre Nós Dois S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20jITgCIx43x1Jm6i2Il2VnQ5DB.jpg'),
(114346, 8158, 'Sobre Nós Dois S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20jITgCIx43x1Jm6i2Il2VnQ5DB.jpg'),
(114347, 8158, 'Sobre Nós Dois S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20jITgCIx43x1Jm6i2Il2VnQ5DB.jpg'),
(114348, 8158, 'Sobre Nós Dois S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20jITgCIx43x1Jm6i2Il2VnQ5DB.jpg'),
(114349, 8158, 'Sobre Nós Dois S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20jITgCIx43x1Jm6i2Il2VnQ5DB.jpg'),
(114350, 8158, 'Sobre Nós Dois S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20jITgCIx43x1Jm6i2Il2VnQ5DB.jpg'),
(114351, 8158, 'Sobre Nós Dois S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20jITgCIx43x1Jm6i2Il2VnQ5DB.jpg'),
(114352, 8158, 'Sobre Nós Dois S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20jITgCIx43x1Jm6i2Il2VnQ5DB.jpg'),
(114353, 8158, 'Sobre Nós Dois S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20jITgCIx43x1Jm6i2Il2VnQ5DB.jpg'),
(114354, 8158, 'Sobre Nós Dois S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20jITgCIx43x1Jm6i2Il2VnQ5DB.jpg'),
(114355, 8159, 'Sobre Nós Dois S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/428650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20jITgCIx43x1Jm6i2Il2VnQ5DB.jpg'),
(114356, 8159, 'Sobre Nós Dois S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20jITgCIx43x1Jm6i2Il2VnQ5DB.jpg'),
(114357, 8159, 'Sobre Nós Dois S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20jITgCIx43x1Jm6i2Il2VnQ5DB.jpg'),
(114358, 8159, 'Sobre Nós Dois S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20jITgCIx43x1Jm6i2Il2VnQ5DB.jpg'),
(114359, 8159, 'Sobre Nós Dois S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/451938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20jITgCIx43x1Jm6i2Il2VnQ5DB.jpg'),
(114360, 8159, 'Sobre Nós Dois S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/458968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20jITgCIx43x1Jm6i2Il2VnQ5DB.jpg'),
(114361, 8159, 'Sobre Nós Dois S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/463671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20jITgCIx43x1Jm6i2Il2VnQ5DB.jpg'),
(114362, 8159, 'Sobre Nós Dois S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/469164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20jITgCIx43x1Jm6i2Il2VnQ5DB.jpg'),
(114363, 8159, 'Sobre Nós Dois S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/481016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20jITgCIx43x1Jm6i2Il2VnQ5DB.jpg'),
(114364, 8159, 'Sobre Nós Dois S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/481017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20jITgCIx43x1Jm6i2Il2VnQ5DB.jpg'),
(114365, 8160, 'A Coleção [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3vrfWpLnh8HxgMXlr7Kh11kIgLf.jpg'),
(114366, 8160, 'A Coleção [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Pn6kTclhIp5Fw8AIq2Cz3aXiHb.jpg'),
(114367, 8160, 'A Coleção [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5TQnslYiCJdJf8PhC62ZnyjlMgo.jpg'),
(114368, 8160, 'A Coleção [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4xSGZEPtvtfBhMWvUQ9fYyov799.jpg'),
(114369, 8160, 'A Coleção [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iX8Bw0QJJMyK9eDEaKx1t5s0opi.jpg'),
(114370, 8160, 'A Coleção [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mz1dvsoqr23i3jUPIeNviqyxqZy.jpg'),
(114371, 8160, 'A Coleção [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zkSdZ63nyymeC61dYFMN9yn4ZXc.jpg'),
(114372, 8160, 'A Coleção [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/66sKs8JL9f1Qd8NxeamJaxVZ5gu.jpg'),
(114373, 8161, 'Burning Bush [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zlxItduZM8i4ZrgEfAqhLBAwPUa.jpg'),
(114374, 8161, 'Burning Bush [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ggVPbolQzuEjywiaRRF4DpYqOFf.jpg'),
(114375, 8161, 'Burning Bush [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dSI7rWcuNWzlI7ywMrW6rnFdEu4.jpg'),
(114376, 8162, 'Efeito Carbonaro [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oWDymBSW0i8q94o76lqqARwTtok.jpg'),
(114377, 8162, 'Efeito Carbonaro [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w7JcPtFWeZhQgHZMTCRytjk30Ti.jpg'),
(114378, 8162, 'Efeito Carbonaro [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ax2f0Y6orKwmRnAG0NN0PEB735i.jpg'),
(114379, 8162, 'Efeito Carbonaro [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9yF6EaepBJ3x6OyTf8v3XW3YqAZ.jpg'),
(114380, 8162, 'Efeito Carbonaro [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uzwqAeCEiWo4AfBi8YTiNWnBTcw.jpg'),
(114381, 8162, 'Efeito Carbonaro [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lx7puj2CMcwUbYVD1Mosdk83ZwM.jpg'),
(114382, 8162, 'Efeito Carbonaro [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i5JQ2MBXBfGOTtXy77Xfd5j8miH.jpg'),
(114383, 8162, 'Efeito Carbonaro [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vrapOpIUlljc6cyxjyFXGCx3bWz.jpg'),
(114384, 8162, 'Efeito Carbonaro [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mWjYg55tLUJmFPxzIYCo8qAoMHM.jpg'),
(114385, 8162, 'Efeito Carbonaro [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgzFrCiNksLBSra8bZoKzAmaAcA.jpg'),
(114386, 8162, 'Efeito Carbonaro [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Af8aBqhMrYvbdSYqA8gRxDNECfk.jpg'),
(114387, 8162, 'Efeito Carbonaro [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iOnje1YbLIL9ldv45wcacukced8.jpg'),
(114388, 8162, 'Efeito Carbonaro [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mAAINZUWfsAF6Btzea0Rkj1XJY3.jpg'),
(114389, 8162, 'Efeito Carbonaro [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lYsryJYzfjbY9TBm3Dx9ngJvN6j.jpg'),
(114390, 8162, 'Efeito Carbonaro [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Rz0Jl8UXIi8w1b1Vi0Hp24NxCV.jpg'),
(114391, 8162, 'Efeito Carbonaro [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/228140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mBftwobPSHIUHVPJbdCx1VJ6T2r.jpg'),
(114392, 8162, 'Efeito Carbonaro [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/228141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOaQhFj0MNL27AXAHp1ERwZTJy.jpg'),
(114393, 8162, 'Efeito Carbonaro [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/228142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3KGlNKpFYcLku279k16ZmIVgQ5.jpg'),
(114394, 8162, 'Efeito Carbonaro [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/228143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wiVU3wUdhP5gHY5Ge49nrPm1wOL.jpg'),
(114395, 8162, 'Efeito Carbonaro [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/228144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zRf801WSjvZmFdz8txA0rKgBvpo.jpg'),
(114396, 8162, 'Efeito Carbonaro [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/228145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZJA54iE4bzKO3zkHzFv08sQszb.jpg'),
(114397, 8162, 'Efeito Carbonaro [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/228146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1GU7uVcETh1CNryT6e4BjltgMxT.jpg'),
(114398, 8162, 'Efeito Carbonaro [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/228147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s0j9z073W6OcWCMMJFy1C802ECz.jpg'),
(114399, 8162, 'Efeito Carbonaro [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/228148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/stAdOR3n2xllBnCCMicBFTwnpp8.jpg'),
(114400, 8162, 'Efeito Carbonaro [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/228149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a83XDCiCWflrWEnkjTYuBUiyyJh.jpg'),
(114401, 8162, 'Efeito Carbonaro [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/228150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114402, 8162, 'Efeito Carbonaro [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/228151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114403, 8162, 'Efeito Carbonaro [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/228152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114404, 8163, 'Efeito Carbonaro [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kJV5Ri9D28EcqEumR3rOooTLoYQ.jpg'),
(114405, 8163, 'Efeito Carbonaro [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Agzh67jcn14XQaskad2CKdVWDW8.jpg'),
(114406, 8163, 'Efeito Carbonaro [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iCj4gNAWRoLMirqlBdIEQ4V9oDL.jpg'),
(114407, 8163, 'Efeito Carbonaro [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/moHmwX5cpZKtzqfWS2lW9n35JZ7.jpg'),
(114408, 8163, 'Efeito Carbonaro [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kgk2xwlO19UiW6kvl05XPgtjiQJ.jpg'),
(114409, 8163, 'Efeito Carbonaro [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aNuMdFDn50kwMD0LchFLWoTTsEE.jpg'),
(114410, 8163, 'Efeito Carbonaro [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aLpRxtJJN8yuTVmGUPQdyr9nwpW.jpg'),
(114411, 8163, 'Efeito Carbonaro [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hAxFiQTPqjzWZre0bqFY5f7iWYF.jpg'),
(114412, 8163, 'Efeito Carbonaro [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rDyKJNtL8hHxK4bzB3BCDvtLDL6.jpg'),
(114413, 8163, 'Efeito Carbonaro [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/meqtmidS2w7CvlNgWbGflaBL2fl.jpg'),
(114414, 8163, 'Efeito Carbonaro [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3t02XpAVAz2fF6aZEtDEzWyMbVv.jpg'),
(114415, 8163, 'Efeito Carbonaro [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uONhHM6viZoIaoSoQZaTXDBtdnL.jpg'),
(114416, 8163, 'Efeito Carbonaro [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c518pRrGCq97552OIltExtiHoAy.jpg'),
(114417, 8163, 'Efeito Carbonaro [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6bQ1KITm4tCxgwMZ4jgJbrKXWFQ.jpg'),
(114418, 8163, 'Efeito Carbonaro [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p8BaAZlCsh2SfFqSgVzTOb8g0jt.jpg'),
(114419, 8163, 'Efeito Carbonaro [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/228168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/90r1fuiP0OrzeK1O2sRcVC14xej.jpg'),
(114420, 8163, 'Efeito Carbonaro [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/228169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oCQRsrjNx8DiW1OY2ekEkTXeVV5.jpg'),
(114421, 8163, 'Efeito Carbonaro [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/228170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lNCU1ELD0SsEHoGqDlOhFvPDZIh.jpg'),
(114422, 8163, 'Efeito Carbonaro [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/228171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/VpCdhpLOu4WwfPiwPIZau8AK7.jpg'),
(114423, 8163, 'Efeito Carbonaro [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/228172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eLe1UQSPxjN0FfxRYWUGbYp5Zkx.jpg'),
(114424, 8163, 'Efeito Carbonaro [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/228173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1gJtgtmG0jSRKNoMGQX9djpoG9k.jpg'),
(114425, 8163, 'Efeito Carbonaro [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/228174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kptJF6th7fUjdWps2dSezwrgZTF.jpg'),
(114426, 8163, 'Efeito Carbonaro [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/228175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pX6wlTfgNsKmE3LPMvb1RxGDXUo.jpg'),
(114427, 8163, 'Efeito Carbonaro [L] S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/228176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ddYTA1o1JLZcvF3oAnK4SnoStbH.jpg'),
(114428, 8163, 'Efeito Carbonaro [L] S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/228177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2oQqAL9N7aUKxarhK9s4rea3XY7.jpg'),
(114429, 8163, 'Efeito Carbonaro [L] S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/228178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1k5IMM3jj58wkeB2fCEYpFT48Q9.jpg'),
(114430, 8163, 'Efeito Carbonaro [L] S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/228179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114431, 8163, 'Efeito Carbonaro [L] S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/228180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114432, 8163, 'Efeito Carbonaro [L] S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/228181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114433, 8163, 'Efeito Carbonaro [L] S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/228182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114434, 8164, 'Efeito Carbonaro [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kZogZjfGKPXT8wDBQkwJd3EyW9H.jpg'),
(114435, 8164, 'Efeito Carbonaro [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gPS2FBXivAYEpCT14diiKTDvO2x.jpg'),
(114436, 8164, 'Efeito Carbonaro [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Ne30RlSZ4tZKlevzbzkSUFnAPK.jpg'),
(114437, 8164, 'Efeito Carbonaro [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/95n1rFjeDa1uDT9BJ5JUFJrhXJW.jpg'),
(114438, 8164, 'Efeito Carbonaro [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rFZYwfGFhFsm0YIml1uFv1aWCZr.jpg'),
(114439, 8164, 'Efeito Carbonaro [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y43TPyqvCvPCQvYMHAeHCa6aM9n.jpg'),
(114440, 8164, 'Efeito Carbonaro [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ArqnbaKWts73k6d815MXLHS7SjV.jpg'),
(114441, 8164, 'Efeito Carbonaro [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v5OwPWpLP9iJ5z6WZ7PTGjlDdsG.jpg'),
(114442, 8164, 'Efeito Carbonaro [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4PSa9NLGBE2zN44nQ1bISU4MmCj.jpg'),
(114443, 8164, 'Efeito Carbonaro [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/MKaaLNVCISOsU4VZ4VYemfEIiL.jpg'),
(114444, 8164, 'Efeito Carbonaro [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9eSScl9y465nW8UK1qPnHi9TDut.jpg'),
(114445, 8164, 'Efeito Carbonaro [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3HNxUsEDEJSAqXAGVB52h1IWuTN.jpg'),
(114446, 8164, 'Efeito Carbonaro [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kYbBKadrq8swtJUY08FU489AnVm.jpg'),
(114447, 8164, 'Efeito Carbonaro [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oTbplftqTIyMk3cre7QT6lM4iC0.jpg'),
(114448, 8164, 'Efeito Carbonaro [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ciiX8iLwuqzUpLsLDF7moIAVtVj.jpg'),
(114449, 8164, 'Efeito Carbonaro [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/228198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzuVTnSTo4cl8NP9yexwZUB98Na.jpg'),
(114450, 8164, 'Efeito Carbonaro [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/228199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n4HGrys24u7vQ1CsTzCWFE3wtuW.jpg'),
(114451, 8164, 'Efeito Carbonaro [L] S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/228200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114452, 8164, 'Efeito Carbonaro [L] S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/228201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114453, 8164, 'Efeito Carbonaro [L] S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/228202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114454, 8164, 'Efeito Carbonaro [L] S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/228203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114455, 8164, 'Efeito Carbonaro [L] S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/228204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114456, 8164, 'Efeito Carbonaro [L] S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/228205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114457, 8165, 'Efeito Carbonaro [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lIesazewvv4KFj8Nap9fX8YtdHT.jpg'),
(114458, 8165, 'Efeito Carbonaro [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wItdxwxCcMat2cMGNcUdJGdkJYN.jpg'),
(114459, 8165, 'Efeito Carbonaro [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pQHVNOJcnVTPU9r0w0edA6eAcvn.jpg'),
(114460, 8165, 'Efeito Carbonaro [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vBqPBuexLlFUjOg9006Vmb4AxLl.jpg'),
(114461, 8165, 'Efeito Carbonaro [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fiMT7z3HSNCdcKRqJk0vQ7dGmR8.jpg'),
(114462, 8165, 'Efeito Carbonaro [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kMfJbBSM1dWbiI0ck38shHbMQxG.jpg'),
(114463, 8165, 'Efeito Carbonaro [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5AltFzgBPtNqsqgHds1LoTcRGvZ.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(114464, 8165, 'Efeito Carbonaro [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/akk399C7lIZM1yKFSUMnl4d6b4U.jpg'),
(114465, 8165, 'Efeito Carbonaro [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7VKnAv5krqPpSZU73yjPeMbEmwS.jpg'),
(114466, 8165, 'Efeito Carbonaro [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lI9xorDIiJPgMFu48DHGEzq6Rua.jpg'),
(114467, 8165, 'Efeito Carbonaro [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xexfJFUnxTfTPcJSHmEdzCEeGku.jpg'),
(114468, 8165, 'Efeito Carbonaro [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7uBYlTpO7z2fVozEGKmivHAaN95.jpg'),
(114469, 8165, 'Efeito Carbonaro [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pnk3BoRouJBvBcFEanPKpjsvR9h.jpg'),
(114470, 8165, 'Efeito Carbonaro [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fiuNWv0pMSjnKcpHBJICJyYNwix.jpg'),
(114471, 8165, 'Efeito Carbonaro [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hgcQtUDekCEaBa1G7KpaSFhKs3t.jpg'),
(114472, 8165, 'Efeito Carbonaro [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/228221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A6hteRUo3x1ARqjETV8xxnx9Tat.jpg'),
(114473, 8165, 'Efeito Carbonaro [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/228222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114474, 8166, 'Efeito Carbonaro [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/crPCwFkcjnfCSeVP4nT0aXMJGhG.jpg'),
(114475, 8166, 'Efeito Carbonaro [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6bawDMmPwSfLG99nIhiZh1EL57.jpg'),
(114476, 8166, 'Efeito Carbonaro [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Ln919H8b2MN50riWzKAxWRyMXI.jpg'),
(114477, 8166, 'Efeito Carbonaro [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p4RZ7W8p27OdaMAXHhTMtvtFPr6.jpg'),
(114478, 8166, 'Efeito Carbonaro [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3EHQhzCeSC7cowqOjCnsfqZtuOA.jpg'),
(114479, 8166, 'Efeito Carbonaro [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ajVLaTTW1XSVKKyYF76beAgcW1o.jpg'),
(114480, 8166, 'Efeito Carbonaro [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8X2NYkpWxA85iWUJJOYEafKmG2Z.jpg'),
(114481, 8166, 'Efeito Carbonaro [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/feq1YEGBlzsOLjPg2XnBlWQn6un.jpg'),
(114482, 8166, 'Efeito Carbonaro [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114483, 8166, 'Efeito Carbonaro [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114484, 8166, 'Efeito Carbonaro [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114485, 8166, 'Efeito Carbonaro [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114486, 8166, 'Efeito Carbonaro [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114487, 8166, 'Efeito Carbonaro [L] S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114488, 8166, 'Efeito Carbonaro [L] S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114489, 8166, 'Efeito Carbonaro [L] S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/228238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114490, 8166, 'Efeito Carbonaro [L] S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/228239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/am9aBRY0ZuUi2wEEUUySNp7ewjT.jpg'),
(114491, 8167, 'Imóveis de Luxo em Família [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mbIMQAbnb2dWW1A0XW8QrX824I.jpg'),
(114492, 8167, 'Imóveis de Luxo em Família [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mbIMQAbnb2dWW1A0XW8QrX824I.jpg'),
(114493, 8167, 'Imóveis de Luxo em Família [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mbIMQAbnb2dWW1A0XW8QrX824I.jpg'),
(114494, 8167, 'Imóveis de Luxo em Família [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mbIMQAbnb2dWW1A0XW8QrX824I.jpg'),
(114495, 8167, 'Imóveis de Luxo em Família [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mbIMQAbnb2dWW1A0XW8QrX824I.jpg'),
(114496, 8168, 'Imóveis de Luxo em Família [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mbIMQAbnb2dWW1A0XW8QrX824I.jpg'),
(114497, 8168, 'Imóveis de Luxo em Família [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mbIMQAbnb2dWW1A0XW8QrX824I.jpg'),
(114498, 8168, 'Imóveis de Luxo em Família [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mbIMQAbnb2dWW1A0XW8QrX824I.jpg'),
(114499, 8168, 'Imóveis de Luxo em Família [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mbIMQAbnb2dWW1A0XW8QrX824I.jpg'),
(114500, 8168, 'Imóveis de Luxo em Família [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mbIMQAbnb2dWW1A0XW8QrX824I.jpg'),
(114501, 8168, 'Imóveis de Luxo em Família [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mbIMQAbnb2dWW1A0XW8QrX824I.jpg'),
(114502, 8169, 'Imóveis de Luxo em Família [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mbIMQAbnb2dWW1A0XW8QrX824I.jpg'),
(114503, 8169, 'Imóveis de Luxo em Família [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mbIMQAbnb2dWW1A0XW8QrX824I.jpg'),
(114504, 8169, 'Imóveis de Luxo em Família [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mbIMQAbnb2dWW1A0XW8QrX824I.jpg'),
(114505, 8169, 'Imóveis de Luxo em Família [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mbIMQAbnb2dWW1A0XW8QrX824I.jpg'),
(114506, 8169, 'Imóveis de Luxo em Família [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mbIMQAbnb2dWW1A0XW8QrX824I.jpg'),
(114507, 8169, 'Imóveis de Luxo em Família [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mbIMQAbnb2dWW1A0XW8QrX824I.jpg'),
(114508, 8169, 'Imóveis de Luxo em Família [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mbIMQAbnb2dWW1A0XW8QrX824I.jpg'),
(114509, 8169, 'Imóveis de Luxo em Família [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mbIMQAbnb2dWW1A0XW8QrX824I.jpg'),
(114510, 8170, 'Kage no Jitsuryokusha ni Naritakute! [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8pvDj5Z7pcZIk3KczQVhPYCsBbY.jpg'),
(114511, 8170, 'Kage no Jitsuryokusha ni Naritakute! [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b4jf83UsgDglZaWTOo9vQbd7eaE.jpg'),
(114512, 8170, 'Kage no Jitsuryokusha ni Naritakute! [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ysArSHE1FIzqAYIiuXBzEv3qx5w.jpg'),
(114513, 8170, 'Kage no Jitsuryokusha ni Naritakute! [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eVkqQDMCmuC4bEdyfNkKYH2xXWu.jpg'),
(114514, 8170, 'Kage no Jitsuryokusha ni Naritakute! [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rWLaaAsbol1oxlXu5k7zs1adeLz.jpg'),
(114515, 8170, 'Kage no Jitsuryokusha ni Naritakute! [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/op8r4shHpzzBrbLk6Rt5pFp7phd.jpg'),
(114516, 8170, 'Kage no Jitsuryokusha ni Naritakute! [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZRbGR50WPICFbPugMHM5Wk15hH.jpg'),
(114517, 8170, 'Kage no Jitsuryokusha ni Naritakute! [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bZnKpqD9xpa7EQ2gYvDGviWp6Fa.jpg'),
(114518, 8170, 'Kage no Jitsuryokusha ni Naritakute! [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mP0CChoVHqYuious4MLL6dHIuRi.jpg'),
(114519, 8170, 'Kage no Jitsuryokusha ni Naritakute! [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ieog04twIx3llt3s4n0oXrJ69aT.jpg'),
(114520, 8170, 'Kage no Jitsuryokusha ni Naritakute! [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g8qRNYyYYWHUQ9xkJt6UftCneeO.jpg'),
(114521, 8170, 'Kage no Jitsuryokusha ni Naritakute! [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6NpbpLi2mAcEN4cyLicIxicUoXr.jpg'),
(114522, 8170, 'Kage no Jitsuryokusha ni Naritakute! [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/91ngOa9nh4rRXmIuBRYox5MER0S.jpg'),
(114523, 8170, 'Kage no Jitsuryokusha ni Naritakute! [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rLJk63wrpN2TyodCVtQSAjWfGWw.jpg'),
(114524, 8170, 'Kage no Jitsuryokusha ni Naritakute! [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/52VKQLGGI7BIqmq9W4hIdSPdrCw.jpg'),
(114525, 8170, 'Kage no Jitsuryokusha ni Naritakute! [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/251405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gmRkrX9i1ISka705wfJDrb32GGp.jpg'),
(114526, 8170, 'Kage no Jitsuryokusha ni Naritakute! [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/251406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j8eYUYpWVucJjDV4bajmCmrcMBp.jpg'),
(114527, 8170, 'Kage no Jitsuryokusha ni Naritakute! [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/251407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hOMciHCdCGDW5GMKrT2MvFCeKyD.jpg'),
(114528, 8170, 'Kage no Jitsuryokusha ni Naritakute! [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/251408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jcOd47NoCPkCDCGr2wzdMuUqJw5.jpg'),
(114529, 8170, 'Kage no Jitsuryokusha ni Naritakute! [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/251409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wdYOmpLaHeRHVsNFXHYztBymtMY.jpg'),
(114530, 8171, 'Kage no Jitsuryokusha ni Naritakute! [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r3IHw82QFkLmggTG9QpBFpYArVM.jpg'),
(114531, 8171, 'Kage no Jitsuryokusha ni Naritakute! [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r3IHw82QFkLmggTG9QpBFpYArVM.jpg'),
(114532, 8171, 'Kage no Jitsuryokusha ni Naritakute! [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r3IHw82QFkLmggTG9QpBFpYArVM.jpg'),
(114533, 8171, 'Kage no Jitsuryokusha ni Naritakute! [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r3IHw82QFkLmggTG9QpBFpYArVM.jpg'),
(114534, 8171, 'Kage no Jitsuryokusha ni Naritakute! [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r3IHw82QFkLmggTG9QpBFpYArVM.jpg'),
(114535, 8171, 'Kage no Jitsuryokusha ni Naritakute! [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r3IHw82QFkLmggTG9QpBFpYArVM.jpg'),
(114536, 8171, 'Kage no Jitsuryokusha ni Naritakute! [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r3IHw82QFkLmggTG9QpBFpYArVM.jpg'),
(114537, 8171, 'Kage no Jitsuryokusha ni Naritakute! [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r3IHw82QFkLmggTG9QpBFpYArVM.jpg'),
(114538, 8171, 'Kage no Jitsuryokusha ni Naritakute! [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r3IHw82QFkLmggTG9QpBFpYArVM.jpg'),
(114539, 8171, 'Kage no Jitsuryokusha ni Naritakute! [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r3IHw82QFkLmggTG9QpBFpYArVM.jpg'),
(114540, 8171, 'Kage no Jitsuryokusha ni Naritakute! [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r3IHw82QFkLmggTG9QpBFpYArVM.jpg'),
(114541, 8171, 'Kage no Jitsuryokusha ni Naritakute! [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r3IHw82QFkLmggTG9QpBFpYArVM.jpg'),
(114542, 8172, 'Meu Anjo de Vizinha Me Mima Demais [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qbZyY7imWoTvmfOEyMAmS6HrJI1.jpg'),
(114543, 8172, 'Meu Anjo de Vizinha Me Mima Demais [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cvLjM7cHvY2ERiw0wczvGGPOxkK.jpg'),
(114544, 8172, 'Meu Anjo de Vizinha Me Mima Demais [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tsL0Q6JSwDSsXfUU6fdIrGmn3vX.jpg'),
(114545, 8172, 'Meu Anjo de Vizinha Me Mima Demais [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7K4lEGA94UojtNykTCxykcCgyhP.jpg'),
(114546, 8172, 'Meu Anjo de Vizinha Me Mima Demais [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/um6uPM6FYVOWVKZtYccJV5mGA4N.jpg'),
(114547, 8172, 'Meu Anjo de Vizinha Me Mima Demais [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7fo3WgwDzvLyAfkV2omkuQugkPY.jpg'),
(114548, 8172, 'Meu Anjo de Vizinha Me Mima Demais [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/57A9W5uWGE0FdNDhhKhcSRxoE65.jpg'),
(114549, 8172, 'Meu Anjo de Vizinha Me Mima Demais [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/86G9gQOEHroxbQrGOy862gbZW6b.jpg'),
(114550, 8172, 'Meu Anjo de Vizinha Me Mima Demais [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVz00MTRhh4KT7JX0nm01OD8vQr.jpg'),
(114551, 8172, 'Meu Anjo de Vizinha Me Mima Demais [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gAuLS31P9YshyuqFyyGw9nCr13R.jpg'),
(114552, 8172, 'Meu Anjo de Vizinha Me Mima Demais [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hCz3fPUeyCF3zRXTw0ZZWu23H2I.jpg'),
(114553, 8172, 'Meu Anjo de Vizinha Me Mima Demais [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4XZ6rYvY9jOUpeGl7wyjvDG6f6A.jpg'),
(114554, 8173, 'Minha Habilidade Única Me Deixa Invencível no Nível 1 [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tbBWEZdLhgVIEz6nD8aHFclbkYn.jpg'),
(114555, 8173, 'Minha Habilidade Única Me Deixa Invencível no Nível 1 [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lokZIhEogVHkjckmid79QPDIls.jpg'),
(114556, 8173, 'Minha Habilidade Única Me Deixa Invencível no Nível 1 [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yJMJ10WmldU5g3dvJULXZ8l02Af.jpg'),
(114557, 8173, 'Minha Habilidade Única Me Deixa Invencível no Nível 1 [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4tRiRXc0w3QMQJbxFJEQahDmPCa.jpg'),
(114558, 8173, 'Minha Habilidade Única Me Deixa Invencível no Nível 1 [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mNMCeuBmpUyKKFDv5ygpbUImfw8.jpg'),
(114559, 8173, 'Minha Habilidade Única Me Deixa Invencível no Nível 1 [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fNp20OA61QWLIYcVeJ5lPbldRLU.jpg'),
(114560, 8173, 'Minha Habilidade Única Me Deixa Invencível no Nível 1 [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2YCSEX4bZ7wUZvlVUqWNm3Z1OLg.jpg'),
(114561, 8174, 'Na Mira do Júri [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aneYfJfC4lk0VmwUHiKGgC8cgJy.jpg'),
(114562, 8174, 'Na Mira do Júri [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/25bDPI3rCYawqY0meBYnVS2xxEw.jpg'),
(114563, 8174, 'Na Mira do Júri [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2xQWR6RXvkH7KjBaYHKvb5EMeQP.jpg'),
(114564, 8174, 'Na Mira do Júri [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lFu5Y9h5Yz0GDybjJ9FQaRWNO6f.jpg'),
(114565, 8174, 'Na Mira do Júri [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b7iPxbZ7EXM0BXJ1jbc7DpSXac3.jpg'),
(114566, 8174, 'Na Mira do Júri [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/idGIMONHi08aFKJL79LEfqfQ7ux.jpg'),
(114567, 8174, 'Na Mira do Júri [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3fWllDqeolin2jBzfolSZd03zax.jpg'),
(114568, 8174, 'Na Mira do Júri [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wTQzv1l7Wpz6BIkhs9dNQI28paB.jpg'),
(114569, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cCxskb1iLKfrqtRYLaIJhx5SqaH.jpg'),
(114570, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Hx7ZR8a3uBFup8grQdJOVZG37T.jpg'),
(114571, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zc742i2E1Qy9Ck5Mymyox5P3UlD.jpg'),
(114572, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dBQZJUIWytuoBAm6kCKdxgMgAfu.jpg'),
(114573, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6CUwPV9lzses0Mp50hYQ0LMB3S8.jpg'),
(114574, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/seh22Xj7GyYN8BWvLHsH7uKd6z4.jpg'),
(114575, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/isLePQvRummlgZLmjgeIET8UJg.jpg'),
(114576, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kKHOv755BckVykKp4NilYXyFOL.jpg'),
(114577, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oeazeVTxY2MVgRuf6sHBdP7oc3R.jpg'),
(114578, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s8MvQzk20ILsDUO4XdPXWsTIiPX.jpg'),
(114579, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/98XRcTNOLIhymG0Ow2wHc6ed92z.jpg'),
(114580, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t4tXs5yhZ4Vv6V6zwY2Z6WTVfHX.jpg'),
(114581, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MMUno6cmAye1VHvK60g7U5qW0E.jpg'),
(114582, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/228066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jV6BL62QcRa5eOgWAjims4ciqem.jpg'),
(114583, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/228067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2CpL55JVBHarEU4uCO2tWIwZvGj.jpg'),
(114584, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/228068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v32L7il4Fv364B1JLKi4DlmpOvZ.jpg'),
(114585, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/228069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/89kWNXGOFwfZeeNcRfjbR93MWhe.jpg'),
(114586, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/228070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gFwA8mVFOCyFre6PMNSJr5KyGp2.jpg'),
(114587, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/228071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cNJHvaZs3pnDZ8isXGnmrU7JMTC.jpg'),
(114588, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/228072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qlPOFbgmPAI9Uni09FFyuOmgm5N.jpg'),
(114589, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/228073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mGilq2hlwAPTytkOXV60aQrKEHg.jpg'),
(114590, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/228074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5GOGFJaxd0871QbeERaDpayygW.jpg'),
(114591, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/228075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/C7NtfDfSPZS4nuyBSiZwmyCGPX.jpg'),
(114592, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/228076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3zwpyKHs8I24xy5dgZmoJENIc4H.jpg'),
(114593, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/228077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgcSrgyJFaP8DQsFJOtcNKn3PU4.jpg'),
(114594, 8175, 'Rainbow: Nisha Rokubou No Shichinin [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/228078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5rUjX7sliZNvJ8vxUzg3ppb45j6.jpg'),
(114595, 8176, 'RWBY: Ice Queendom [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lsyiPix6Z482vXRSBbmtqt3SWcE.jpg'),
(114596, 8176, 'RWBY: Ice Queendom [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tGRIWsZ6Hw0I2l6Sn3tBG7BWMGg.jpg'),
(114597, 8176, 'RWBY: Ice Queendom [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mUswWgjveI3HXSKQY39r3b5Uent.jpg'),
(114598, 8176, 'RWBY: Ice Queendom [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nosaWk69KQcFaYsHh6ImuXexhEy.jpg'),
(114599, 8176, 'RWBY: Ice Queendom [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qd3VcB5CwvV66usPEtNMDDFJNjx.jpg'),
(114600, 8176, 'RWBY: Ice Queendom [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tNK0PluwGHlKMwK1Q3eEsFR3JrC.jpg'),
(114601, 8176, 'RWBY: Ice Queendom [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ebrN0FNNqz0PUvPbUmWfQPuF6n2.jpg'),
(114602, 8176, 'RWBY: Ice Queendom [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/me7VNuQCUDu4pZBY6gqIwmK8LdJ.jpg'),
(114603, 8176, 'RWBY: Ice Queendom [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8xOpBGrH8St0gMkrkYmf1dGAsEs.jpg'),
(114604, 8176, 'RWBY: Ice Queendom [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4ZudRZVAxHPd8Dg0DUQvUfMiUc.jpg'),
(114605, 8176, 'RWBY: Ice Queendom [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uEc3JN5ewTCRqEYI2RSg0wCDops.jpg'),
(114606, 8176, 'RWBY: Ice Queendom [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2yMadzuGfaZdj0QQBM9gATrVSSL.jpg'),
(114607, 8177, 'Saikyou Onmyouji no Isekai Tenseiki [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8rkFLZCRxb8ejruRlq4JAqIWxgE.jpg'),
(114608, 8177, 'Saikyou Onmyouji no Isekai Tenseiki [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uMObKMfYT4Bjq5TbXJ5o0Uax9HM.jpg'),
(114609, 8177, 'Saikyou Onmyouji no Isekai Tenseiki [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6LnRYfVdbEjWFS3lfeOH5xF4SvS.jpg'),
(114610, 8177, 'Saikyou Onmyouji no Isekai Tenseiki [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aE8eTfkLKe3KUCSOVGJOphOMAOw.jpg'),
(114611, 8177, 'Saikyou Onmyouji no Isekai Tenseiki [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c1Mz3MzWKntK8rvzVJE1zmGsBQu.jpg'),
(114612, 8177, 'Saikyou Onmyouji no Isekai Tenseiki [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/OYsVXFe1heBhIKlLZ4m5sHjqzy.jpg'),
(114613, 8177, 'Saikyou Onmyouji no Isekai Tenseiki [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kbzDHFvy8ASwUdkA3U17Ma2nHlq.jpg'),
(114614, 8177, 'Saikyou Onmyouji no Isekai Tenseiki [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uKzzJ8s8OF7zviwayfTWrtfepHv.jpg'),
(114615, 8177, 'Saikyou Onmyouji no Isekai Tenseiki [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4RocfgPQVAHv6DA5ke6SYeR6OSa.jpg'),
(114616, 8177, 'Saikyou Onmyouji no Isekai Tenseiki [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tw1H3p4dvV7QL69wvsMS32sG5Wi.jpg'),
(114617, 8177, 'Saikyou Onmyouji no Isekai Tenseiki [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oQocKhKoLU9BkykRKhW2N9W1k8O.jpg'),
(114618, 8177, 'Saikyou Onmyouji no Isekai Tenseiki [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5GtV2g1ceEA4aR437iQawqgT9bS.jpg'),
(114619, 8177, 'Saikyou Onmyouji no Isekai Tenseiki [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/228040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l7UiMEqvFpy6EkyDFiiuW6a9jC8.jpg'),
(114620, 8178, 'Tomodachi Game [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/228016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sszG61Yxq2CAeYlRqPexRojMOVQ.jpg'),
(114621, 8178, 'Tomodachi Game [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/228017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hce3tOxQlOL9iTOEZ3EgcwM50VP.jpg'),
(114622, 8178, 'Tomodachi Game [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/228018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wok7huBS55WdV635gCUmuj5EksH.jpg'),
(114623, 8178, 'Tomodachi Game [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/228019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbLBELYhMbD4cL4GSoPdMfEGRW6.jpg'),
(114624, 8178, 'Tomodachi Game [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/228020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zEUeoJBcQVHnIGAhSaS5t1nfhvH.jpg'),
(114625, 8178, 'Tomodachi Game [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/228021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qYfrXcCWSdcDuNgPujldesONhZV.jpg'),
(114626, 8178, 'Tomodachi Game [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/228022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oQcCc48XAT8NJwtM8FQIPavUwlD.jpg'),
(114627, 8178, 'Tomodachi Game [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/228023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8LfESAMHHMvwAsiHFM9rLIeYIkI.jpg'),
(114628, 8178, 'Tomodachi Game [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/228024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dpv7nSPKSbbEqHB6SooB71NxuB.jpg'),
(114629, 8178, 'Tomodachi Game [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/228025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2pZz5yV1hABjRkYhwoTVLZXNUsJ.jpg'),
(114630, 8178, 'Tomodachi Game [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/228026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Gp0cbHv4K4TlDzMOk12qoAj2P8.jpg'),
(114631, 8178, 'Tomodachi Game [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/228027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jikuPpJLjyJzl3y3oh1yTaKW7aY.jpg'),
(114632, 8179, 'Iludida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iDPJv8R46SR4M6svVr8mFQaZIbJ.jpg'),
(114633, 8179, 'Iludida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/irx4QFscZqQFioelD19tFAj4f8I.jpg'),
(114634, 8179, 'Iludida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uhSxvi5Z1XzPcqof8ZGA9ua4YkP.jpg'),
(114635, 8179, 'Iludida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v7mlOdiyeRhNp7m6y52sqsYYIaQ.jpg'),
(114636, 8179, 'Iludida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vTrpVg0zhLh5s4c2nXAMQBboV1x.jpg'),
(114637, 8179, 'Iludida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f695DkJsHFJaZayLima4u7gMVZS.jpg'),
(114638, 8179, 'Iludida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yUO5IaKetiFLjHoGI5Husjo1pIc.jpg'),
(114639, 8179, 'Iludida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/esSHr5LLLnr3agzEsP1T28JQO9j.jpg'),
(114640, 8179, 'Iludida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyH9CnCJHmTIe8NXPqcbyJXmQJa.jpg'),
(114641, 8179, 'Iludida S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s6KbHir9Bf028nGuLwgsfu8O7De.jpg'),
(114642, 8179, 'Iludida S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iDMXTGuttsrT1Vx8Lbs9Ps4b63B.jpg'),
(114643, 8179, 'Iludida S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zOBc8GxhFEszvZlqqAoj1SkiKJe.jpg'),
(114644, 8179, 'Iludida S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/233813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTTYPFtYFy8ex6cBNBOYAzGJzWR.jpg'),
(114645, 8179, 'Iludida S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/233814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q6OIGaokUiytqZwFC6itIvQwOJY.jpg'),
(114646, 8179, 'Iludida S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/233815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bwjpbKmolQofcoJhEd5lupJ1Dbs.jpg'),
(114647, 8179, 'Iludida S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/233816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hDarFOR51JdQqkbv665NFhOltIH.jpg'),
(114648, 8179, 'Iludida S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/233817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8t5296yThaUvVG4N4M74fPgGvPJ.jpg'),
(114649, 8179, 'Iludida S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/233818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ALheRVLnxFFu8Ouu5K1TyuK04C.jpg'),
(114650, 8179, 'Iludida S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/233819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5sTLNMhcILfu2w3ndERZZf5xA0e.jpg'),
(114651, 8179, 'Iludida S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/233820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qG1KTkYYnilHTImdOB4umQ0epZM.jpg'),
(114652, 8179, 'Iludida S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/233821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/edz8EYS14SmeGFnYeouwwQOf5zv.jpg'),
(114653, 8179, 'Iludida S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/233822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/laVwp4GdNPywyudBJMjykghMo67.jpg'),
(114654, 8179, 'Iludida S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/233823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1TW87SDEuh9E05pigZ7nmYU2sza.jpg'),
(114655, 8179, 'Iludida S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/233824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ywhlKd4UuAVZKb0zMjCxy3XjtGx.jpg'),
(114656, 8179, 'Iludida S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/233825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vOi4oN3ExzMUnGNixip8IMhibRO.jpg'),
(114657, 8179, 'Iludida S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/233826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ymTjJ2xoscqVFq1UEaZR1WZ4ar.jpg'),
(114658, 8179, 'Iludida S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/233827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hop8NovqYpCSSnG6JhQp0Rz7I6B.jpg'),
(114659, 8179, 'Iludida S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/233828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ApePBA1JEFprzfKwXMIt1vrNaUP.jpg'),
(114660, 8179, 'Iludida S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/233829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bI17JMUJSqI5Au2C11t3ektAzuR.jpg'),
(114661, 8179, 'Iludida S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/233830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Qv6TCPbWi7TAI6EpVuc51VCm4m.jpg'),
(114662, 8179, 'Iludida S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/233831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHmb5FWrlPDx16uM0PlYnfriS9B.jpg'),
(114663, 8179, 'Iludida S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/233832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114664, 8179, 'Iludida S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/233833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114665, 8179, 'Iludida S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/233834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114666, 8179, 'Iludida S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/233835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114667, 8179, 'Iludida S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/233836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114668, 8179, 'Iludida S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/233837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114669, 8179, 'Iludida S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/233838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114670, 8179, 'Iludida S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/233839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114671, 8179, 'Iludida S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/233840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114672, 8179, 'Iludida S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/233841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114673, 8179, 'Iludida S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/233842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114674, 8179, 'Iludida S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/233843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114675, 8179, 'Iludida S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/233844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114676, 8179, 'Iludida S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/233845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114677, 8179, 'Iludida S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/233846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114678, 8179, 'Iludida S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/233847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114679, 8179, 'Iludida S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/233848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114680, 8179, 'Iludida S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/233849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114681, 8179, 'Iludida S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/233850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114682, 8179, 'Iludida S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/233851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114683, 8179, 'Iludida S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/233852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114684, 8179, 'Iludida S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/233853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114685, 8179, 'Iludida S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/233854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114686, 8179, 'Iludida S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/233855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114687, 8179, 'Iludida S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/233856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114688, 8179, 'Iludida S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/233857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114689, 8179, 'Iludida S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/233858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114690, 8179, 'Iludida S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/233859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114691, 8179, 'Iludida S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/233860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114692, 8179, 'Iludida S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/233861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114693, 8179, 'Iludida S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/233862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114694, 8179, 'Iludida S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/233863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114695, 8179, 'Iludida S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/233864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114696, 8179, 'Iludida S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/233865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114697, 8179, 'Iludida S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/233866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114698, 8179, 'Iludida S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/233867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114699, 8179, 'Iludida S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/233868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114700, 8179, 'Iludida S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/233869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114701, 8179, 'Iludida S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/233870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114702, 8179, 'Iludida S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/233871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114703, 8179, 'Iludida S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/233872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114704, 8179, 'Iludida S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/233873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114705, 8179, 'Iludida S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/233874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114706, 8179, 'Iludida S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/233875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114707, 8179, 'Iludida S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/233876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114708, 8179, 'Iludida S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/233877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114709, 8179, 'Iludida S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/233878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114710, 8180, 'Iludida S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k5RgLiLMnnydUBkbf1msBSlAv10.jpg'),
(114711, 8180, 'Iludida S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rq8V5olExtpenSace0lD9NdI1vD.jpg'),
(114712, 8180, 'Iludida S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9TOxTRPxibGKvxGiN4MQGAAxGle.jpg'),
(114713, 8180, 'Iludida S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l3mpBuha596bK3N6LkOf7ekbaJv.jpg'),
(114714, 8180, 'Iludida S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iXNEX7LE68d2SrkgyicshKy3cDn.jpg'),
(114715, 8180, 'Iludida S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lKzCVtR7wk0jb3RVzprHA5c7NFL.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(114716, 8180, 'Iludida S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/csTFfumP7x1RwFbuPlgxNgnPnro.jpg'),
(114717, 8180, 'Iludida S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/unMTLLzLbrbnUbH6yBaNj2MvGw8.jpg'),
(114718, 8180, 'Iludida S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kurGeEH26Inni9VJY9QJwqfDnDT.jpg'),
(114719, 8180, 'Iludida S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zNgMLdnsQIbKA3ZWmbnWYVUBItX.jpg'),
(114720, 8180, 'Iludida S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5mYROAzKQsRTaP7or2plJuGr54.jpg'),
(114721, 8180, 'Iludida S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r0GSHuRlnGj6PZ4S8HL5eQ1QOYp.jpg'),
(114722, 8180, 'Iludida S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/233891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y7lvhcQOsNZs7n7MUy9VRZOhkzU.jpg'),
(114723, 8180, 'Iludida S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/233892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lfsi1l67xJy0abEjvCCCkoU1Mt.jpg'),
(114724, 8180, 'Iludida S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/233893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fERbayOuB5Ml7oLG7Akz33FMyw8.jpg'),
(114725, 8180, 'Iludida S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/233894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sHc8K2GNeP0vd0KVIf1VyUcu3rW.jpg'),
(114726, 8180, 'Iludida S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/233895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdvBqUzrdCt4TSZzbHzFlADzcwY.jpg'),
(114727, 8180, 'Iludida S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/233896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lI5Uhu3vx1g7Hpt1gtnmYdj9Qch.jpg'),
(114728, 8180, 'Iludida S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/233897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jUeyApXvjTHzBmx1ND9z3PQ1myk.jpg'),
(114729, 8180, 'Iludida S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/233898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oPDOnDo4y3GvnszWaCcftNhkHgP.jpg'),
(114730, 8180, 'Iludida S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/233899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114731, 8180, 'Iludida S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/233900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114732, 8180, 'Iludida S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/233901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114733, 8180, 'Iludida S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/233902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114734, 8180, 'Iludida S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/233903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114735, 8180, 'Iludida S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/233904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114736, 8180, 'Iludida S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/233905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114737, 8180, 'Iludida S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/233906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gMqA3YYhR9BU1KjNZs7gSmzRqiR.jpg'),
(114738, 8180, 'Iludida S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/233907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114739, 8180, 'Iludida S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/233908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114740, 8180, 'Iludida S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/233909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114741, 8180, 'Iludida S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/233910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114742, 8180, 'Iludida S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/233911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114743, 8180, 'Iludida S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/233912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114744, 8180, 'Iludida S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/233913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114745, 8180, 'Iludida S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/233914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114746, 8180, 'Iludida S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/233915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114747, 8180, 'Iludida S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/233916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114748, 8180, 'Iludida S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/233917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114749, 8180, 'Iludida S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/233918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114750, 8180, 'Iludida S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/233919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114751, 8180, 'Iludida S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/233920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114752, 8180, 'Iludida S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/233921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114753, 8180, 'Iludida S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/233922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114754, 8180, 'Iludida S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/233923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114755, 8180, 'Iludida S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/233924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114756, 8180, 'Iludida S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/233925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114757, 8180, 'Iludida S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/233926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114758, 8180, 'Iludida S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/233927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114759, 8180, 'Iludida S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/233928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114760, 8180, 'Iludida S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/233929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114761, 8180, 'Iludida S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/233930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114762, 8180, 'Iludida S02 E53', 'http://sinalprivado.info:80/series/1533784/1533784/233931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114763, 8180, 'Iludida S02 E54', 'http://sinalprivado.info:80/series/1533784/1533784/233932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114764, 8180, 'Iludida S02 E55', 'http://sinalprivado.info:80/series/1533784/1533784/233933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114765, 8180, 'Iludida S02 E56', 'http://sinalprivado.info:80/series/1533784/1533784/233934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114766, 8180, 'Iludida S02 E57', 'http://sinalprivado.info:80/series/1533784/1533784/233935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114767, 8180, 'Iludida S02 E58', 'http://sinalprivado.info:80/series/1533784/1533784/233936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114768, 8180, 'Iludida S02 E59', 'http://sinalprivado.info:80/series/1533784/1533784/233937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114769, 8180, 'Iludida S02 E60', 'http://sinalprivado.info:80/series/1533784/1533784/233938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114770, 8180, 'Iludida S02 E61', 'http://sinalprivado.info:80/series/1533784/1533784/233939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114771, 8180, 'Iludida S02 E62', 'http://sinalprivado.info:80/series/1533784/1533784/233940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114772, 8180, 'Iludida S02 E63', 'http://sinalprivado.info:80/series/1533784/1533784/233941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114773, 8180, 'Iludida S02 E64', 'http://sinalprivado.info:80/series/1533784/1533784/233942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114774, 8180, 'Iludida S02 E65', 'http://sinalprivado.info:80/series/1533784/1533784/233943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114775, 8180, 'Iludida S02 E66', 'http://sinalprivado.info:80/series/1533784/1533784/233944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114776, 8180, 'Iludida S02 E67', 'http://sinalprivado.info:80/series/1533784/1533784/233945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114777, 8180, 'Iludida S02 E68', 'http://sinalprivado.info:80/series/1533784/1533784/233946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114778, 8180, 'Iludida S02 E69', 'http://sinalprivado.info:80/series/1533784/1533784/233947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114779, 8180, 'Iludida S02 E70', 'http://sinalprivado.info:80/series/1533784/1533784/233948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114780, 8180, 'Iludida S02 E71', 'http://sinalprivado.info:80/series/1533784/1533784/233949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xC9vUFVIrxnhZiEYLeMDVqxj7og.jpg'),
(114781, 8181, 'Olhos da Lei S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114782, 8181, 'Olhos da Lei S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114783, 8181, 'Olhos da Lei S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114784, 8181, 'Olhos da Lei S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114785, 8181, 'Olhos da Lei S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114786, 8181, 'Olhos da Lei S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114787, 8181, 'Olhos da Lei S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114788, 8181, 'Olhos da Lei S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114789, 8181, 'Olhos da Lei S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114790, 8181, 'Olhos da Lei S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114791, 8181, 'Olhos da Lei S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114792, 8181, 'Olhos da Lei S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114793, 8181, 'Olhos da Lei S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114794, 8181, 'Olhos da Lei S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/248662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114795, 8181, 'Olhos da Lei S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/248663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114796, 8181, 'Olhos da Lei S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/248664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114797, 8182, 'Olhos da Lei S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/812352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114798, 8182, 'Olhos da Lei S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/812353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114799, 8182, 'Olhos da Lei S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/816308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114800, 8182, 'Olhos da Lei S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/816309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114801, 8182, 'Olhos da Lei S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/824572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114802, 8182, 'Olhos da Lei S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/824573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114803, 8182, 'Olhos da Lei S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/836515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114804, 8182, 'Olhos da Lei S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/836516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114805, 8182, 'Olhos da Lei S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/886075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114806, 8182, 'Olhos da Lei S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/886076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114807, 8182, 'Olhos da Lei S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/887558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114808, 8182, 'Olhos da Lei S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/887559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114809, 8182, 'Olhos da Lei S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/888159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114810, 8182, 'Olhos da Lei S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/888160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114811, 8182, 'Olhos da Lei S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/889619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114812, 8182, 'Olhos da Lei S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/889620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8o65sMDiXgjmSAKOKHGnVpBqsTP.jpg'),
(114813, 8183, 'Beyblade: Metal Fusion S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114814, 8183, 'Beyblade: Metal Fusion S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114815, 8183, 'Beyblade: Metal Fusion S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114816, 8183, 'Beyblade: Metal Fusion S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114817, 8183, 'Beyblade: Metal Fusion S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114818, 8183, 'Beyblade: Metal Fusion S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114819, 8183, 'Beyblade: Metal Fusion S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114820, 8183, 'Beyblade: Metal Fusion S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114821, 8183, 'Beyblade: Metal Fusion S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114822, 8183, 'Beyblade: Metal Fusion S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114823, 8183, 'Beyblade: Metal Fusion S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114824, 8183, 'Beyblade: Metal Fusion S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114825, 8183, 'Beyblade: Metal Fusion S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/233762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114826, 8183, 'Beyblade: Metal Fusion S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/233763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114827, 8183, 'Beyblade: Metal Fusion S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/233764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114828, 8183, 'Beyblade: Metal Fusion S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/233765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114829, 8183, 'Beyblade: Metal Fusion S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/233766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114830, 8183, 'Beyblade: Metal Fusion S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/233767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114831, 8183, 'Beyblade: Metal Fusion S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/233768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114832, 8183, 'Beyblade: Metal Fusion S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/233769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114833, 8183, 'Beyblade: Metal Fusion S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/233770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114834, 8183, 'Beyblade: Metal Fusion S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/233771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114835, 8183, 'Beyblade: Metal Fusion S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/233772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114836, 8183, 'Beyblade: Metal Fusion S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/233773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114837, 8183, 'Beyblade: Metal Fusion S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/233774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114838, 8183, 'Beyblade: Metal Fusion S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/233775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114839, 8183, 'Beyblade: Metal Fusion S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/233776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114840, 8183, 'Beyblade: Metal Fusion S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/233777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114841, 8183, 'Beyblade: Metal Fusion S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/233778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114842, 8183, 'Beyblade: Metal Fusion S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/233779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114843, 8183, 'Beyblade: Metal Fusion S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/233780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114844, 8183, 'Beyblade: Metal Fusion S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/233781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114845, 8183, 'Beyblade: Metal Fusion S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/233782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114846, 8183, 'Beyblade: Metal Fusion S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/233783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114847, 8183, 'Beyblade: Metal Fusion S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/233784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114848, 8183, 'Beyblade: Metal Fusion S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/233785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114849, 8183, 'Beyblade: Metal Fusion S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/233786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114850, 8183, 'Beyblade: Metal Fusion S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/233787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114851, 8183, 'Beyblade: Metal Fusion S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/233788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114852, 8183, 'Beyblade: Metal Fusion S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/233789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114853, 8183, 'Beyblade: Metal Fusion S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/233790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114854, 8183, 'Beyblade: Metal Fusion S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/233791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114855, 8183, 'Beyblade: Metal Fusion S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/233792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114856, 8183, 'Beyblade: Metal Fusion S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/233793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114857, 8183, 'Beyblade: Metal Fusion S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/233794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114858, 8183, 'Beyblade: Metal Fusion S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/233795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114859, 8183, 'Beyblade: Metal Fusion S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/233796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114860, 8183, 'Beyblade: Metal Fusion S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/233797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114861, 8183, 'Beyblade: Metal Fusion S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/233798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114862, 8183, 'Beyblade: Metal Fusion S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/233799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114863, 8183, 'Beyblade: Metal Fusion S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/233800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pboJ6DOZk92DFcY2yXJ75pMUCwW.jpg'),
(114864, 8184, 'Como Viver até os 100: Os Segredos das Zonas Azuis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9a8ZScIBnyiRBEqqKC7jVr3piNK.jpg'),
(114865, 8184, 'Como Viver até os 100: Os Segredos das Zonas Azuis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hs4ZSqpIqWjRWNuDCQWNJhTn3W1.jpg'),
(114866, 8184, 'Como Viver até os 100: Os Segredos das Zonas Azuis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p0RcNrSYDRQRM9XggDanIVlahmR.jpg'),
(114867, 8184, 'Como Viver até os 100: Os Segredos das Zonas Azuis S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g0w9yVvbdo6RpCUBHUN4B8U8i3z.jpg'),
(114868, 8185, 'Die Hart [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jXYnzg9Tc4nsAEPeDe4VasVFN9m.jpg'),
(114869, 8185, 'Die Hart [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mXgANXD2ElxhajdRIMOYEx4JVbZ.jpg'),
(114870, 8185, 'Die Hart [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fu2IsLj1fGjHU7cUNRyI5zXJFi1.jpg'),
(114871, 8185, 'Die Hart [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d7WOW0AbocoQ2MZ0RgVGWWuUqhI.jpg'),
(114872, 8185, 'Die Hart [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3CX3Baair9qgo6ySWqL0oigxrr4.jpg'),
(114873, 8185, 'Die Hart [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3YPDNXBan6J0lv1jq1OQjey6Tmy.jpg'),
(114874, 8185, 'Die Hart [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/65AVmZ6mULVhpOky4PI8XuEom1q.jpg'),
(114875, 8185, 'Die Hart [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u2WmQS2HSKIonjaPToMPadVh7Pu.jpg'),
(114876, 8185, 'Die Hart [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gPRYZgLPXeoncn6fCHVQ6eQTWvm.jpg'),
(114877, 8185, 'Die Hart [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xAkJr3Mf80XX3T6hTlFdgjlm2zI.jpg'),
(114878, 8186, 'Jogos Invictus: Veteranos no Topo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5kmNhrZ7mwc0J4Cqyp3oARub1zT.jpg'),
(114879, 8186, 'Jogos Invictus: Veteranos no Topo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5kmNhrZ7mwc0J4Cqyp3oARub1zT.jpg'),
(114880, 8186, 'Jogos Invictus: Veteranos no Topo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5kmNhrZ7mwc0J4Cqyp3oARub1zT.jpg'),
(114881, 8186, 'Jogos Invictus: Veteranos no Topo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5kmNhrZ7mwc0J4Cqyp3oARub1zT.jpg'),
(114882, 8186, 'Jogos Invictus: Veteranos no Topo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5kmNhrZ7mwc0J4Cqyp3oARub1zT.jpg'),
(114883, 8187, 'Justificado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/amUzFh3acoWgotjL0z3NeElfPNW.jpg'),
(114884, 8187, 'Justificado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uXOnmLpQAiBV0rRsRCrfUpmfwa6.jpg'),
(114885, 8187, 'Justificado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5sIdOZkKrVCk23Fr0mTtGkNGZHX.jpg'),
(114886, 8187, 'Justificado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zlhXCNtZEbuIjXASSg8Ny1LhTp4.jpg'),
(114887, 8187, 'Justificado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pmqgqFlpuK78wlUmzld71y3jd0N.jpg'),
(114888, 8187, 'Justificado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LCIaDflKC2MCkmmgxWUxQCm4eA.jpg'),
(114889, 8187, 'Justificado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pNgjRW7X3TTKE664acUfMyNas5V.jpg'),
(114890, 8187, 'Justificado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hnNreicesX5Pm3ALAmt7r111gLr.jpg'),
(114891, 8187, 'Justificado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i10BhhY7ojkClmXX09sDLyj5DX7.jpg'),
(114892, 8187, 'Justificado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6zzCWyN4MZyDQpNIHMlY8SuRkVu.jpg'),
(114893, 8187, 'Justificado S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8HNDo2W2JHmHeqvpcBDg7yKBG0.jpg'),
(114894, 8187, 'Justificado S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qj8dAnJuYgc6DxaCHNwGY0laNq7.jpg'),
(114895, 8187, 'Justificado S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/233665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mopwTPrbC1vQaYZ7WGhoWgutdYa.jpg'),
(114896, 8188, 'Justificado S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6wozvjlBdfzl6GF5PlnpzAeBtDz.jpg'),
(114897, 8188, 'Justificado S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/knht83khTxnTkEqqZBs9ID3l0YN.jpg'),
(114898, 8188, 'Justificado S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJ5JE3YLKd8go8z2kiDI8Zp0w1w.jpg'),
(114899, 8188, 'Justificado S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/veKszxArPVx5HHGnm20evyI3RDt.jpg'),
(114900, 8188, 'Justificado S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6HrMyw3zvwg2CtzaustyjoXkgeX.jpg'),
(114901, 8188, 'Justificado S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pxKKWlJN6T27HS1UD5ZGlPdWbft.jpg'),
(114902, 8188, 'Justificado S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9KW8DbRtkaZNKIvFrw9rzE0VeE.jpg'),
(114903, 8188, 'Justificado S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdYCWpaxQJNhiRLCziBpGxGnfEQ.jpg'),
(114904, 8188, 'Justificado S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3KvMfG1pCiSYCe0wPQhhpkXUCuu.jpg'),
(114905, 8188, 'Justificado S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sITYuOkTNqdojJXw4IOGUjXDUcH.jpg'),
(114906, 8188, 'Justificado S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/df1eNBHZAPwy6OTK7lXOm2p6kOV.jpg'),
(114907, 8188, 'Justificado S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a1n1ON30HCUKPHIp8mufBONyG4b.jpg'),
(114908, 8188, 'Justificado S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/233678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uV3X3uS2ywHjfxouFlgwtPclAcB.jpg'),
(114909, 8189, 'Justificado S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oXEFeHuY71ONoegG6efvuR83ULE.jpg'),
(114910, 8189, 'Justificado S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ztSrjgXRR0p8kHJCeV5zbHaS4y5.jpg'),
(114911, 8189, 'Justificado S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nOwAPkPSpNuq63HvsszYaidefOq.jpg'),
(114912, 8189, 'Justificado S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n24Mu2TS0j9ZbkTdL5ohr7azLNa.jpg'),
(114913, 8189, 'Justificado S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7LKa2uEbmsNEq4hWUIpUxLn8BCs.jpg'),
(114914, 8189, 'Justificado S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1e0w0m8KRo0bFw9I6DNdf0OCb2.jpg'),
(114915, 8189, 'Justificado S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o7FNVvjrANOQR5KZb1tqxQxS87S.jpg'),
(114916, 8189, 'Justificado S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oyiKtcgDWJrMgFmKGtUuP3cjWz4.jpg'),
(114917, 8189, 'Justificado S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7NbsPjz3W53p5b5hwIbsPhXE6Xe.jpg'),
(114918, 8189, 'Justificado S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdi7nP6HJ2Xt7ssKGzmWyGtt4On.jpg'),
(114919, 8189, 'Justificado S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dRUds2RhISYuYKFy998BJp3vnkO.jpg'),
(114920, 8189, 'Justificado S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oUElCM1Po1J3kUXVCiuCFD8e2cl.jpg'),
(114921, 8189, 'Justificado S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/233691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y7Ig6tAGSqTgRKjuf2OwH9LkQfb.jpg'),
(114922, 8190, 'Justificado S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zJTt8QgC9pK2mzqtuQuOWIh8nOh.jpg'),
(114923, 8190, 'Justificado S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qpZnx1SihNQGx3TP5XfhFRgaLjz.jpg'),
(114924, 8190, 'Justificado S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/irZ5UkQyZl9UVm5ykhyomIw9LK2.jpg'),
(114925, 8190, 'Justificado S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLBnRcwu3pqXEe21TJJphGC7RDC.jpg'),
(114926, 8190, 'Justificado S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/51vO6GYrOcqFSyswje0h3NjEmBA.jpg'),
(114927, 8190, 'Justificado S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oZgqiFl2l6QeGuwYHJ8eMZVMRor.jpg'),
(114928, 8190, 'Justificado S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4fLv5YXBVq3CJgmOnSYyhg09KIZ.jpg'),
(114929, 8190, 'Justificado S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jGRy00FlDvMlxAyhpdEG9Ed40Ru.jpg'),
(114930, 8190, 'Justificado S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rclQOJcEKAUE6OqS3vqSdwcx6y5.jpg'),
(114931, 8190, 'Justificado S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/amvwAEzwat3pGqdB3qE9y6ZsWJK.jpg'),
(114932, 8190, 'Justificado S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTAQC2V2f3iCiZCxvYIpLu6OuNI.jpg'),
(114933, 8190, 'Justificado S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lK0eOyxAffQHn87po0qMvcWUy8s.jpg'),
(114934, 8190, 'Justificado S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/233704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6qhyvEfO1hvgdTJCdUwIbCaTGw.jpg'),
(114935, 8191, 'Justificado S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vGmiIqEnttCilIGYqsKCophZNwP.jpg'),
(114936, 8191, 'Justificado S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iZVqd7enPMuzuNDh3JiWirJQ8ck.jpg'),
(114937, 8191, 'Justificado S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h119NeIACPnVsslYeNaow89qqkI.jpg'),
(114938, 8191, 'Justificado S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6mhK3G5r9SLtvTytMEtbD5rVyWO.jpg'),
(114939, 8191, 'Justificado S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/auHV1FOsiDeXigxJRgS6NszV6pz.jpg'),
(114940, 8191, 'Justificado S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwYLuZ9r0Fj55B7wwN6L7iql5o6.jpg'),
(114941, 8191, 'Justificado S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/crXwhcZGNe4pHcASWSAO8nCqTt8.jpg'),
(114942, 8191, 'Justificado S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5yoISiHVzxDc0FwEWFAmDDDcRwZ.jpg'),
(114943, 8191, 'Justificado S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vInK4Hu6L8LohwnIRfg1PH2otYD.jpg'),
(114944, 8191, 'Justificado S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qA75jx4bTq7OPjKHq3EsG5d6AxF.jpg'),
(114945, 8191, 'Justificado S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w7dnIDm2A4J8VKY0nqKeUVGk4I2.jpg'),
(114946, 8191, 'Justificado S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bsF2QnN70EO0zoPsR3SA5yKorwF.jpg'),
(114947, 8191, 'Justificado S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/233717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5iNMfmh4dptpj981r141lgfjDoU.jpg'),
(114948, 8192, 'Justificado S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mFfO9Yz2FwJ5IXpjuCaLaLKfeE2.jpg'),
(114949, 8192, 'Justificado S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m3okLM7xM1GsknpuXux3uUeEqIM.jpg'),
(114950, 8192, 'Justificado S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fpVV4zKCWd6ovAHSsfASs13sg01.jpg'),
(114951, 8192, 'Justificado S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eHxvyWUd4bv4oFn0i7pl1SNbqC7.jpg'),
(114952, 8192, 'Justificado S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4v1JlwQnRbA1A7pVeDIa9k86Bny.jpg'),
(114953, 8192, 'Justificado S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9eI39Y5G3N5o96fUQm1F2Q2egc.jpg'),
(114954, 8192, 'Justificado S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wKoe1P6e6DLF6lvv6HS1RT8OpP7.jpg'),
(114955, 8192, 'Justificado S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nfmR7mzht2iiduVmRsB8VUYCGB7.jpg'),
(114956, 8192, 'Justificado S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7V3GjbKcJX0MniS9cGN6amDSrHM.jpg'),
(114957, 8192, 'Justificado S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nwzC5TGEuOmu4Bn95qrwCNQ4zcx.jpg'),
(114958, 8192, 'Justificado S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yhVLc5FII450BMUWic2XuDpwVjs.jpg'),
(114959, 8192, 'Justificado S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3v4wUsB59wi2LFtNlaWjs8tUGI1.jpg'),
(114960, 8192, 'Justificado S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/233730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHlWonydIO0FX8XIp7qJDk1gDfq.jpg'),
(114961, 8193, 'Justificado [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/amUzFh3acoWgotjL0z3NeElfPNW.jpg'),
(114962, 8193, 'Justificado [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uXOnmLpQAiBV0rRsRCrfUpmfwa6.jpg'),
(114963, 8193, 'Justificado [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5sIdOZkKrVCk23Fr0mTtGkNGZHX.jpg'),
(114964, 8193, 'Justificado [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zlhXCNtZEbuIjXASSg8Ny1LhTp4.jpg'),
(114965, 8193, 'Justificado [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pmqgqFlpuK78wlUmzld71y3jd0N.jpg'),
(114966, 8193, 'Justificado [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LCIaDflKC2MCkmmgxWUxQCm4eA.jpg'),
(114967, 8193, 'Justificado [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pNgjRW7X3TTKE664acUfMyNas5V.jpg'),
(114968, 8193, 'Justificado [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hnNreicesX5Pm3ALAmt7r111gLr.jpg'),
(114969, 8193, 'Justificado [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i10BhhY7ojkClmXX09sDLyj5DX7.jpg'),
(114970, 8193, 'Justificado [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6zzCWyN4MZyDQpNIHMlY8SuRkVu.jpg'),
(114971, 8193, 'Justificado [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8HNDo2W2JHmHeqvpcBDg7yKBG0.jpg'),
(114972, 8193, 'Justificado [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qj8dAnJuYgc6DxaCHNwGY0laNq7.jpg'),
(114973, 8193, 'Justificado [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/233587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mopwTPrbC1vQaYZ7WGhoWgutdYa.jpg'),
(114974, 8194, 'Justificado [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6wozvjlBdfzl6GF5PlnpzAeBtDz.jpg'),
(114975, 8194, 'Justificado [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/knht83khTxnTkEqqZBs9ID3l0YN.jpg'),
(114976, 8194, 'Justificado [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJ5JE3YLKd8go8z2kiDI8Zp0w1w.jpg'),
(114977, 8194, 'Justificado [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/veKszxArPVx5HHGnm20evyI3RDt.jpg'),
(114978, 8194, 'Justificado [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6HrMyw3zvwg2CtzaustyjoXkgeX.jpg'),
(114979, 8194, 'Justificado [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pxKKWlJN6T27HS1UD5ZGlPdWbft.jpg'),
(114980, 8194, 'Justificado [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9KW8DbRtkaZNKIvFrw9rzE0VeE.jpg'),
(114981, 8194, 'Justificado [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdYCWpaxQJNhiRLCziBpGxGnfEQ.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(114982, 8194, 'Justificado [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3KvMfG1pCiSYCe0wPQhhpkXUCuu.jpg'),
(114983, 8194, 'Justificado [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sITYuOkTNqdojJXw4IOGUjXDUcH.jpg'),
(114984, 8194, 'Justificado [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/df1eNBHZAPwy6OTK7lXOm2p6kOV.jpg'),
(114985, 8194, 'Justificado [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a1n1ON30HCUKPHIp8mufBONyG4b.jpg'),
(114986, 8194, 'Justificado [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/233600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uV3X3uS2ywHjfxouFlgwtPclAcB.jpg'),
(114987, 8195, 'Justificado [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oXEFeHuY71ONoegG6efvuR83ULE.jpg'),
(114988, 8195, 'Justificado [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ztSrjgXRR0p8kHJCeV5zbHaS4y5.jpg'),
(114989, 8195, 'Justificado [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nOwAPkPSpNuq63HvsszYaidefOq.jpg'),
(114990, 8195, 'Justificado [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n24Mu2TS0j9ZbkTdL5ohr7azLNa.jpg'),
(114991, 8195, 'Justificado [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7LKa2uEbmsNEq4hWUIpUxLn8BCs.jpg'),
(114992, 8195, 'Justificado [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1e0w0m8KRo0bFw9I6DNdf0OCb2.jpg'),
(114993, 8195, 'Justificado [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o7FNVvjrANOQR5KZb1tqxQxS87S.jpg'),
(114994, 8195, 'Justificado [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oyiKtcgDWJrMgFmKGtUuP3cjWz4.jpg'),
(114995, 8195, 'Justificado [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7NbsPjz3W53p5b5hwIbsPhXE6Xe.jpg'),
(114996, 8195, 'Justificado [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdi7nP6HJ2Xt7ssKGzmWyGtt4On.jpg'),
(114997, 8195, 'Justificado [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dRUds2RhISYuYKFy998BJp3vnkO.jpg'),
(114998, 8195, 'Justificado [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oUElCM1Po1J3kUXVCiuCFD8e2cl.jpg'),
(114999, 8195, 'Justificado [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/233613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y7Ig6tAGSqTgRKjuf2OwH9LkQfb.jpg'),
(115000, 8196, 'Justificado [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zJTt8QgC9pK2mzqtuQuOWIh8nOh.jpg'),
(115001, 8196, 'Justificado [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qpZnx1SihNQGx3TP5XfhFRgaLjz.jpg'),
(115002, 8196, 'Justificado [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/irZ5UkQyZl9UVm5ykhyomIw9LK2.jpg'),
(115003, 8196, 'Justificado [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLBnRcwu3pqXEe21TJJphGC7RDC.jpg'),
(115004, 8196, 'Justificado [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/51vO6GYrOcqFSyswje0h3NjEmBA.jpg'),
(115005, 8196, 'Justificado [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oZgqiFl2l6QeGuwYHJ8eMZVMRor.jpg'),
(115006, 8196, 'Justificado [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4fLv5YXBVq3CJgmOnSYyhg09KIZ.jpg'),
(115007, 8196, 'Justificado [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jGRy00FlDvMlxAyhpdEG9Ed40Ru.jpg'),
(115008, 8196, 'Justificado [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rclQOJcEKAUE6OqS3vqSdwcx6y5.jpg'),
(115009, 8196, 'Justificado [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/amvwAEzwat3pGqdB3qE9y6ZsWJK.jpg'),
(115010, 8196, 'Justificado [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTAQC2V2f3iCiZCxvYIpLu6OuNI.jpg'),
(115011, 8196, 'Justificado [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lK0eOyxAffQHn87po0qMvcWUy8s.jpg'),
(115012, 8196, 'Justificado [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/233626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6qhyvEfO1hvgdTJCdUwIbCaTGw.jpg'),
(115013, 8197, 'Justificado [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vGmiIqEnttCilIGYqsKCophZNwP.jpg'),
(115014, 8197, 'Justificado [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iZVqd7enPMuzuNDh3JiWirJQ8ck.jpg'),
(115015, 8197, 'Justificado [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h119NeIACPnVsslYeNaow89qqkI.jpg'),
(115016, 8197, 'Justificado [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6mhK3G5r9SLtvTytMEtbD5rVyWO.jpg'),
(115017, 8197, 'Justificado [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/auHV1FOsiDeXigxJRgS6NszV6pz.jpg'),
(115018, 8197, 'Justificado [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwYLuZ9r0Fj55B7wwN6L7iql5o6.jpg'),
(115019, 8197, 'Justificado [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/crXwhcZGNe4pHcASWSAO8nCqTt8.jpg'),
(115020, 8197, 'Justificado [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5yoISiHVzxDc0FwEWFAmDDDcRwZ.jpg'),
(115021, 8197, 'Justificado [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vInK4Hu6L8LohwnIRfg1PH2otYD.jpg'),
(115022, 8197, 'Justificado [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qA75jx4bTq7OPjKHq3EsG5d6AxF.jpg'),
(115023, 8197, 'Justificado [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w7dnIDm2A4J8VKY0nqKeUVGk4I2.jpg'),
(115024, 8197, 'Justificado [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bsF2QnN70EO0zoPsR3SA5yKorwF.jpg'),
(115025, 8197, 'Justificado [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/233639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5iNMfmh4dptpj981r141lgfjDoU.jpg'),
(115026, 8198, 'Justificado [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mFfO9Yz2FwJ5IXpjuCaLaLKfeE2.jpg'),
(115027, 8198, 'Justificado [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m3okLM7xM1GsknpuXux3uUeEqIM.jpg'),
(115028, 8198, 'Justificado [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fpVV4zKCWd6ovAHSsfASs13sg01.jpg'),
(115029, 8198, 'Justificado [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eHxvyWUd4bv4oFn0i7pl1SNbqC7.jpg'),
(115030, 8198, 'Justificado [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4v1JlwQnRbA1A7pVeDIa9k86Bny.jpg'),
(115031, 8198, 'Justificado [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9eI39Y5G3N5o96fUQm1F2Q2egc.jpg'),
(115032, 8198, 'Justificado [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wKoe1P6e6DLF6lvv6HS1RT8OpP7.jpg'),
(115033, 8198, 'Justificado [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nfmR7mzht2iiduVmRsB8VUYCGB7.jpg'),
(115034, 8198, 'Justificado [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7V3GjbKcJX0MniS9cGN6amDSrHM.jpg'),
(115035, 8198, 'Justificado [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nwzC5TGEuOmu4Bn95qrwCNQ4zcx.jpg'),
(115036, 8198, 'Justificado [L] S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yhVLc5FII450BMUWic2XuDpwVjs.jpg'),
(115037, 8198, 'Justificado [L] S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3v4wUsB59wi2LFtNlaWjs8tUGI1.jpg'),
(115038, 8198, 'Justificado [L] S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/233652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHlWonydIO0FX8XIp7qJDk1gDfq.jpg'),
(115039, 8199, 'Tacoma FD [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4JA0eAwje4ITqNYqWn0zTaNlsrH.jpg'),
(115040, 8199, 'Tacoma FD [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5AOKx6WoGqqw1Imi7I422AblbIi.jpg'),
(115041, 8199, 'Tacoma FD [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vMvTXA9DkCyGDf1mLxj3rRAd56q.jpg'),
(115042, 8199, 'Tacoma FD [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5rItx94E38I99BUpn12lOjNQ7F7.jpg'),
(115043, 8199, 'Tacoma FD [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qd6v8m14VA2cnjT1dWMrGPoOUXg.jpg'),
(115044, 8199, 'Tacoma FD [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/urkLVVAWpDnnII0UNykPNnwM0s3.jpg'),
(115045, 8199, 'Tacoma FD [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lDPtYsjJm7FWUdYTxF1OCyGj8ol.jpg'),
(115046, 8199, 'Tacoma FD [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHoEfTvFaPboMIYYQuWDpx8Qpic.jpg'),
(115047, 8199, 'Tacoma FD [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2l3VOFXbUmiKMSSbH2112yBIFON.jpg'),
(115048, 8199, 'Tacoma FD [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mWwaxaqs8yaY93vAucvqz5nLQgK.jpg'),
(115049, 8200, 'Tacoma FD [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iaitbzHC1VpGEJ5PMt3RRDlsWt3.jpg'),
(115050, 8200, 'Tacoma FD [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7htluqn17JmaFNm2zcNqp9fZHJz.jpg'),
(115051, 8200, 'Tacoma FD [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/elVcPhXVPSZZqMEVDIcuVzB72XB.jpg'),
(115052, 8200, 'Tacoma FD [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/87x5D1HhFtcWol960geBWm8B6aU.jpg'),
(115053, 8200, 'Tacoma FD [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ZDuwtVJrnBd67cxBKCpfVUFBSb.jpg'),
(115054, 8200, 'Tacoma FD [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gguA4jwKnL1rZR9640DyNJ23HoH.jpg'),
(115055, 8200, 'Tacoma FD [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5BG8yYtZdBrzH0yAyT02TFk7yuW.jpg'),
(115056, 8200, 'Tacoma FD [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8CgyoVwnvBBQFAcOLCU6RyKbFOj.jpg'),
(115057, 8200, 'Tacoma FD [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vljd3FIoaSum6erwpg4I0qHkvdO.jpg'),
(115058, 8200, 'Tacoma FD [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/guvDTxIMvAR3LoNw4H3AsIydda8.jpg'),
(115059, 8200, 'Tacoma FD [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/86Ff4AXClwfy2PKu1JRHkIYREWm.jpg'),
(115060, 8200, 'Tacoma FD [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/54GbQVS582bhhhJ91KwhbQZfP0z.jpg'),
(115061, 8200, 'Tacoma FD [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/233569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ev7nXQgB6tUypUSiejpKUN5Z4Y.jpg'),
(115062, 8201, 'Tacoma FD [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fq6TNGaWPupeEXnH55HkE2QlTX8.jpg'),
(115063, 8201, 'Tacoma FD [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4l7FF6PSoW8DAVgbbMV24gwnaCg.jpg'),
(115064, 8201, 'Tacoma FD [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/U3lAXQoEsWy2rHCP6ouQzWwIKZ.jpg'),
(115065, 8201, 'Tacoma FD [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5grWvlvDXHoMxr03Mshzksznne.jpg'),
(115066, 8201, 'Tacoma FD [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZ8i46EzSVVTf63Bm5p81p0R8cn.jpg'),
(115067, 8202, 'As Células de Yumi [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vn1KeuRrIO2D84RJF822iwtejX1.jpg'),
(115068, 8202, 'As Células de Yumi [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkct6YjHViBVurFSKrV5uutTs6.jpg'),
(115069, 8202, 'As Células de Yumi [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1lFFVl2Sn8ymROYkXgw7U864q9T.jpg'),
(115070, 8202, 'As Células de Yumi [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fC6ZzroIq0OdtzUeZVJyQAO9dRD.jpg'),
(115071, 8202, 'As Células de Yumi [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xWFc2xUPbHe0rbjECy3MsVvX88W.jpg'),
(115072, 8202, 'As Células de Yumi [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4SBSRSQ5vFIAd5WNBZ4XtbqOCDe.jpg'),
(115073, 8202, 'As Células de Yumi [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yiBVfuED1noXsnnplyCPhfVoFij.jpg'),
(115074, 8202, 'As Células de Yumi [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e2PgQfO8UEaK8SGF51UjKqUalhj.jpg'),
(115075, 8202, 'As Células de Yumi [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3phWgHKkncDUSqYMQg98DQHw4OO.jpg'),
(115076, 8202, 'As Células de Yumi [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nLR7WasTIr8RDVweHq3kDjEGAX5.jpg'),
(115077, 8202, 'As Células de Yumi [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNP8hrwVFIDyuihweD9ENkdphjx.jpg'),
(115078, 8202, 'As Células de Yumi [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gfbG6GXGMXv6tVoq0HtrpYpjAyj.jpg'),
(115079, 8202, 'As Células de Yumi [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/233531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nRE6V4HOSU8em0r5p3eIHX8f6WY.jpg'),
(115080, 8202, 'As Células de Yumi [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/233532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8BFLxGhQ6DsaCM2IZpy0xBNi5Vp.jpg'),
(115081, 8203, 'As Células de Yumi [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bZO50C895eNxTLu638TonpQlAr7.jpg'),
(115082, 8203, 'As Células de Yumi [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yv4ruT1eEuGxT40AykricCNkkYv.jpg'),
(115083, 8203, 'As Células de Yumi [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nIiGBI9HN4YZd2bfBzk97GBZpJ9.jpg'),
(115084, 8203, 'As Células de Yumi [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lMGkm6cRjmSE0bZ1d07ldqtXDaI.jpg'),
(115085, 8203, 'As Células de Yumi [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dKQNK2TQkowR3FLCHt1osejuDBc.jpg'),
(115086, 8203, 'As Células de Yumi [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1YPwa1BT676hIfs5UqUc4weRY2.jpg'),
(115087, 8203, 'As Células de Yumi [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/teqxKsES30wnIOAqE7OVqwOdJ5c.jpg'),
(115088, 8203, 'As Células de Yumi [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSIHXVp7aFhNhKGBeEMWWpP6DsU.jpg'),
(115089, 8203, 'As Células de Yumi [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lfFvJ2b79X3ew5ro5XQimFmDz93.jpg'),
(115090, 8203, 'As Células de Yumi [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lYhjXtOo7NdnKkwrphOgg4rwFFV.jpg'),
(115091, 8203, 'As Células de Yumi [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dNDfPuxyHgtUaPqXa4LaXNa5aAA.jpg'),
(115092, 8203, 'As Células de Yumi [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jkJK64yHAHOh1Ede33Gw2nLtxJP.jpg'),
(115093, 8203, 'As Células de Yumi [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/233545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jyATxl2IWr06MLwaV6zKlytIS5u.jpg'),
(115094, 8203, 'As Células de Yumi [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/233546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o6SDUbATj7AgFYzIcvDCzUHFgIg.jpg'),
(115095, 8204, '3Hz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9R1paAYG8HpzPs6JS7hxmKgO8t.jpg'),
(115096, 8204, '3Hz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9R1paAYG8HpzPs6JS7hxmKgO8t.jpg'),
(115097, 8204, '3Hz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9R1paAYG8HpzPs6JS7hxmKgO8t.jpg'),
(115098, 8204, '3Hz S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9R1paAYG8HpzPs6JS7hxmKgO8t.jpg'),
(115099, 8204, '3Hz S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9R1paAYG8HpzPs6JS7hxmKgO8t.jpg'),
(115100, 8204, '3Hz S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9R1paAYG8HpzPs6JS7hxmKgO8t.jpg'),
(115101, 8204, '3Hz S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9R1paAYG8HpzPs6JS7hxmKgO8t.jpg'),
(115102, 8204, '3Hz S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9R1paAYG8HpzPs6JS7hxmKgO8t.jpg'),
(115103, 8204, '3Hz S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/233396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9R1paAYG8HpzPs6JS7hxmKgO8t.jpg'),
(115104, 8204, '3Hz S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/233397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9R1paAYG8HpzPs6JS7hxmKgO8t.jpg'),
(115105, 8204, '3Hz S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/233398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9R1paAYG8HpzPs6JS7hxmKgO8t.jpg'),
(115106, 8204, '3Hz S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/233399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9R1paAYG8HpzPs6JS7hxmKgO8t.jpg'),
(115107, 8204, '3Hz S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/233400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9R1paAYG8HpzPs6JS7hxmKgO8t.jpg'),
(115108, 8205, 'A Baía S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aF67VMZ5DtsnB2zp0DgPnvJkulF.jpg'),
(115109, 8205, 'A Baía S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ua8foz6fHbRPUjxd5xvsFD7efI.jpg'),
(115110, 8205, 'A Baía S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ArzbW8Avoo89fIyXs0NM9JonCNk.jpg'),
(115111, 8205, 'A Baía S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3WNJPKZy6y8IYp6h3TKKgxxek0f.jpg'),
(115112, 8205, 'A Baía S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ivwToYxQHGMu4qLpsZ7ZOgViyKI.jpg'),
(115113, 8205, 'A Baía S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2bLjnLYTcGjpytl27w5Se7E7ieR.jpg'),
(115114, 8206, 'A Baía S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmCxh4ltwDxO5i8xnEX5dyIKGEv.jpg'),
(115115, 8206, 'A Baía S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g0d0fPYpQIPvdAN7ubod165prwI.jpg'),
(115116, 8206, 'A Baía S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9SjquZJmDeeOvp52UHZpVCxAHh1.jpg'),
(115117, 8206, 'A Baía S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Um4TSR1fAZyvXiHlekQuRsfvS.jpg'),
(115118, 8206, 'A Baía S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ad1JlVE3wtyJgtW5mZMbI0pAyYY.jpg'),
(115119, 8206, 'A Baía S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nxXlOlKvDUZu9HlruF7rqL38sVC.jpg'),
(115120, 8207, 'A Baía S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zFl7fziSLzk6zhnZb03axmVZ4jM.jpg'),
(115121, 8207, 'A Baía S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97JOM4P48TaiBtQtXfHlXcARjqC.jpg'),
(115122, 8207, 'A Baía S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eSaNz0A2L2oYGOAEuZySldWq6z.jpg'),
(115123, 8207, 'A Baía S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3C5068CQMevi615zPKnT4xxPezw.jpg'),
(115124, 8207, 'A Baía S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fh3GJt0MKWWvcCH0HuM6TF9t7YU.jpg'),
(115125, 8207, 'A Baía S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/exAfZpPe2kXtOjvU3vmBURqtcZ9.jpg'),
(115126, 8208, 'A Baía S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/456835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jDXt6xzGrE7uw8aC2rK33RzJ4Jy.jpg'),
(115127, 8208, 'A Baía S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/456836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jDXt6xzGrE7uw8aC2rK33RzJ4Jy.jpg'),
(115128, 8208, 'A Baía S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/456837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jDXt6xzGrE7uw8aC2rK33RzJ4Jy.jpg'),
(115129, 8208, 'A Baía S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/456838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jDXt6xzGrE7uw8aC2rK33RzJ4Jy.jpg'),
(115130, 8208, 'A Baía S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/456839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jDXt6xzGrE7uw8aC2rK33RzJ4Jy.jpg'),
(115131, 8208, 'A Baía S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/456840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jDXt6xzGrE7uw8aC2rK33RzJ4Jy.jpg'),
(115132, 8209, 'Christina Boyer: No Corredor da Morte [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tU6LkDROuHCSU3WeumJ4yGoOS7G.jpg'),
(115133, 8209, 'Christina Boyer: No Corredor da Morte [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mI8efJ1zSUVEi7CisDaxaExdRkJ.jpg'),
(115134, 8209, 'Christina Boyer: No Corredor da Morte [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9goXHm8llNotSCrLVCK0rdX7YyE.jpg'),
(115135, 8210, 'Deslizando para o Amor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8iUSZoLamsMnWQ1DoMp2txvydfG.jpg'),
(115136, 8210, 'Deslizando para o Amor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqyWrE1KaPtfuUBkyzOhuzqxPPu.jpg'),
(115137, 8210, 'Deslizando para o Amor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6g4lTfyhXFnnVg5Vdlug6en97Ma.jpg'),
(115138, 8210, 'Deslizando para o Amor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oir6Pf8AMfuBqOEMGNUnnIkCsMs.jpg'),
(115139, 8210, 'Deslizando para o Amor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZWs5MxoO2OzpZbRMxmuk1RbzOx.jpg'),
(115140, 8210, 'Deslizando para o Amor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1vPhhaVjbYOugvPmWoG3ftXnnsR.jpg'),
(115141, 8210, 'Deslizando para o Amor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o7aAUY0N7dQnNDwITPV0w0bYuif.jpg'),
(115142, 8210, 'Deslizando para o Amor [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kl02WmrFouOUKIehuQ0wIyWnHBw.jpg'),
(115143, 8211, 'Heróis da Selva S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WZ0ebGqb5j4EhNe3IX7t7Ctg1g.jpg'),
(115144, 8211, 'Heróis da Selva S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WZ0ebGqb5j4EhNe3IX7t7Ctg1g.jpg'),
(115145, 8211, 'Heróis da Selva S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WZ0ebGqb5j4EhNe3IX7t7Ctg1g.jpg'),
(115146, 8211, 'Heróis da Selva S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WZ0ebGqb5j4EhNe3IX7t7Ctg1g.jpg'),
(115147, 8211, 'Heróis da Selva S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WZ0ebGqb5j4EhNe3IX7t7Ctg1g.jpg'),
(115148, 8211, 'Heróis da Selva S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WZ0ebGqb5j4EhNe3IX7t7Ctg1g.jpg'),
(115149, 8212, 'Hora de Aventura com Fionna e Cake S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fqe4KymCOf3kouVj1GjqrYcec9X.jpg'),
(115150, 8212, 'Hora de Aventura com Fionna e Cake S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vrjbAfwZCEGhzYGzUAnPNr5OsLz.jpg'),
(115151, 8212, 'Hora de Aventura com Fionna e Cake S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242333.mp4', 'http://image.tmdb.org/t/p/w1280/vu6UEAVaNGz97v2EZ951oXyeIzg.jpg'),
(115152, 8212, 'Hora de Aventura com Fionna e Cake S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242334.mp4', 'http://image.tmdb.org/t/p/w1280/j8jvCvYI7h39mGezBXojKF8ZjfS.jpg'),
(115153, 8212, 'Hora de Aventura com Fionna e Cake S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64SpFbPGKkoJ6sqXcIbnm4CXWBB.jpg'),
(115154, 8212, 'Hora de Aventura com Fionna e Cake S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64SpFbPGKkoJ6sqXcIbnm4CXWBB.jpg'),
(115155, 8212, 'Hora de Aventura com Fionna e Cake S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64SpFbPGKkoJ6sqXcIbnm4CXWBB.jpg'),
(115156, 8212, 'Hora de Aventura com Fionna e Cake S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64SpFbPGKkoJ6sqXcIbnm4CXWBB.jpg'),
(115157, 8212, 'Hora de Aventura com Fionna e Cake S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64SpFbPGKkoJ6sqXcIbnm4CXWBB.jpg'),
(115158, 8212, 'Hora de Aventura com Fionna e Cake S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64SpFbPGKkoJ6sqXcIbnm4CXWBB.jpg'),
(115159, 8213, 'Hora de Aventura com Fionna e Cake S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/890688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64SpFbPGKkoJ6sqXcIbnm4CXWBB.jpg'),
(115160, 8213, 'Hora de Aventura com Fionna e Cake S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/890689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64SpFbPGKkoJ6sqXcIbnm4CXWBB.jpg'),
(115161, 8213, 'Hora de Aventura com Fionna e Cake S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/892002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64SpFbPGKkoJ6sqXcIbnm4CXWBB.jpg'),
(115162, 8213, 'Hora de Aventura com Fionna e Cake S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/892444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64SpFbPGKkoJ6sqXcIbnm4CXWBB.jpg'),
(115163, 8213, 'Hora de Aventura com Fionna e Cake S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/893131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64SpFbPGKkoJ6sqXcIbnm4CXWBB.jpg'),
(115164, 8213, 'Hora de Aventura com Fionna e Cake S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/893586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64SpFbPGKkoJ6sqXcIbnm4CXWBB.jpg'),
(115165, 8213, 'Hora de Aventura com Fionna e Cake S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/894218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64SpFbPGKkoJ6sqXcIbnm4CXWBB.jpg'),
(115166, 8213, 'Hora de Aventura com Fionna e Cake S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/895882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64SpFbPGKkoJ6sqXcIbnm4CXWBB.jpg'),
(115167, 8213, 'Hora de Aventura com Fionna e Cake S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/896485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64SpFbPGKkoJ6sqXcIbnm4CXWBB.jpg'),
(115168, 8213, 'Hora de Aventura com Fionna e Cake S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/897446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64SpFbPGKkoJ6sqXcIbnm4CXWBB.jpg'),
(115169, 8214, 'ONE PIECE: A Série S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g89bbPLUEBohUuuSxyKLlGpSZX7.jpg'),
(115170, 8214, 'ONE PIECE: A Série S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUYSyYPYCTB7bGuiqrwFQqt5xja.jpg'),
(115171, 8214, 'ONE PIECE: A Série S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/71U4bl7z63ZGF5n2stJ7paELeNQ.jpg'),
(115172, 8214, 'ONE PIECE: A Série S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/94TQgW3NgeaEXsugrlcwbpGiIb3.jpg'),
(115173, 8214, 'ONE PIECE: A Série S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6nJBXGTN1ig4whalJvaWA2vyAgr.jpg'),
(115174, 8214, 'ONE PIECE: A Série S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lZgNsaPEIrvXi2InAlilH51EGZA.jpg'),
(115175, 8214, 'ONE PIECE: A Série S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/828JBjk9zrKbMQgdp6oHrRog0WY.jpg'),
(115176, 8214, 'ONE PIECE: A Série S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nMiFAm30mAkNQS7YGrMEdMCT4NJ.jpg'),
(115177, 8215, 'Reservation Dogs [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hq7KksUYLs4OyeJXOj1ILgqsw2G.jpg'),
(115178, 8215, 'Reservation Dogs [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2T0xFdy4RHfWaIf2GwN5bbVGQhY.jpg'),
(115179, 8215, 'Reservation Dogs [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uXamMrHyJ4UTgMqZXLBdopkWOfC.jpg'),
(115180, 8215, 'Reservation Dogs [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/72dsnJDYsBPhrT3SpSKdstIgCku.jpg'),
(115181, 8215, 'Reservation Dogs [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x2RIvsU2oKN9NCuKEIj3GjPvacc.jpg'),
(115182, 8215, 'Reservation Dogs [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/76tKWLjOKWo556mVndVbCwDM2bg.jpg'),
(115183, 8215, 'Reservation Dogs [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1aGJBq5A4qGq2BXJtS6zdEknvLZ.jpg'),
(115184, 8215, 'Reservation Dogs [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8qcWhiKVToAb2IWgNm1R1g9F364.jpg'),
(115185, 8216, 'Reservation Dogs [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/unHL6054a1lztZDFRjhYzKTLwFr.jpg'),
(115186, 8216, 'Reservation Dogs [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Out15lbVMyvkWzEPqo0ivwQtVz.jpg'),
(115187, 8216, 'Reservation Dogs [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6RxD9U4V5JjeXtmTeUu3WQF74O3.jpg'),
(115188, 8216, 'Reservation Dogs [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3VEK6cmT0zOENTXeEnCZkz0ZzP.jpg'),
(115189, 8216, 'Reservation Dogs [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nhSJOuF7EOAJUQxPvFKBtFlFiNI.jpg'),
(115190, 8216, 'Reservation Dogs [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2AQw5ab4EbEggpyJtl6xRCcsISs.jpg'),
(115191, 8216, 'Reservation Dogs [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/njFjGrT47Cl5AFF9qyAqAb0FwRw.jpg'),
(115192, 8216, 'Reservation Dogs [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qKrmlKmN8qxEUhmBgs0zGxGhzyM.jpg'),
(115193, 8216, 'Reservation Dogs [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhjq0goLyqvQVhqXfx3gLlPwofa.jpg'),
(115194, 8216, 'Reservation Dogs [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fj78g8amS9KIreQ8ALjbYn4JMdd.jpg'),
(115195, 8217, 'Reservation Dogs [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bQ8bJGcIs6qa16wNcvYyOWGOdeC.jpg'),
(115196, 8217, 'Reservation Dogs [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/icvV90ewejBJrXWdXv4a06bGp3v.jpg'),
(115197, 8217, 'Reservation Dogs [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t6hqwD5oQRGgNrZKN71BQYxteC1.jpg'),
(115198, 8217, 'Reservation Dogs [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t6hqwD5oQRGgNrZKN71BQYxteC1.jpg'),
(115199, 8217, 'Reservation Dogs [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t6hqwD5oQRGgNrZKN71BQYxteC1.jpg'),
(115200, 8217, 'Reservation Dogs [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t6hqwD5oQRGgNrZKN71BQYxteC1.jpg'),
(115201, 8217, 'Reservation Dogs [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t6hqwD5oQRGgNrZKN71BQYxteC1.jpg'),
(115202, 8217, 'Reservation Dogs [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t6hqwD5oQRGgNrZKN71BQYxteC1.jpg'),
(115203, 8217, 'Reservation Dogs [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t6hqwD5oQRGgNrZKN71BQYxteC1.jpg'),
(115204, 8217, 'Reservation Dogs [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t6hqwD5oQRGgNrZKN71BQYxteC1.jpg'),
(115205, 8218, 'Sobre Juventude [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A5HK9DTTruGDaPxtbvGJKQroaYz.jpg'),
(115206, 8218, 'Sobre Juventude [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1fcAM0eIKujRIO7BcaqiB8gcxXf.jpg'),
(115207, 8218, 'Sobre Juventude [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hbDQqARzHoWWCG9ScpgqI6H7BT1.jpg'),
(115208, 8218, 'Sobre Juventude [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/233340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jVPNyM0Sa5ip4MoW9tRV5y3BUyn.jpg'),
(115209, 8218, 'Sobre Juventude [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/233341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tQp2hJuMmIyYf3SJ8PE7fEJp78M.jpg'),
(115210, 8218, 'Sobre Juventude [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/233342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r91wzDhaFFDGim0BLO4jT25Hupj.jpg'),
(115211, 8218, 'Sobre Juventude [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/233343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lfaOdzHaTWWbLhcPuF4FKy9GeOv.jpg'),
(115212, 8218, 'Sobre Juventude [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/233344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lfaOdzHaTWWbLhcPuF4FKy9GeOv.jpg'),
(115213, 8219, 'The Woman in the Wall [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hv1GFxc6gFItFbmWrsJB7BCoat7.jpg'),
(115214, 8219, 'The Woman in the Wall [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jow7c1aylTs3OtGiiRJVrgBv6g5.jpg'),
(115215, 8219, 'The Woman in the Wall [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f54pcD2UuOLOV6SwW790Q1awidw.jpg'),
(115216, 8219, 'The Woman in the Wall [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f54pcD2UuOLOV6SwW790Q1awidw.jpg'),
(115217, 8219, 'The Woman in the Wall [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f54pcD2UuOLOV6SwW790Q1awidw.jpg'),
(115218, 8219, 'The Woman in the Wall [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f54pcD2UuOLOV6SwW790Q1awidw.jpg'),
(115219, 8220, 'Wayne Shorter: Zero Gravity [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/233334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5NzsfklSXi8JsicMFun2yxtNpSt.jpg'),
(115220, 8220, 'Wayne Shorter: Zero Gravity [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/233335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/75BwBOBeywd2OcsxEVVn4b39nxH.jpg'),
(115221, 8220, 'Wayne Shorter: Zero Gravity [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/233336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/akPzIciYWlZAc1NNb3JnCgSi8TY.jpg'),
(115222, 8221, 'Drag Race Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/noRX1y0aTTPRPzHhP3baolpkJUg.jpg'),
(115223, 8221, 'Drag Race Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246704.mp4', 'http://image.tmdb.org/t/p/w1280/k026ZHtTIJKbIFul6Bkoqivb71T.jpg'),
(115224, 8221, 'Drag Race Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/noRX1y0aTTPRPzHhP3baolpkJUg.jpg'),
(115225, 8221, 'Drag Race Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/noRX1y0aTTPRPzHhP3baolpkJUg.jpg'),
(115226, 8221, 'Drag Race Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/noRX1y0aTTPRPzHhP3baolpkJUg.jpg'),
(115227, 8221, 'Drag Race Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/noRX1y0aTTPRPzHhP3baolpkJUg.jpg'),
(115228, 8221, 'Drag Race Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/noRX1y0aTTPRPzHhP3baolpkJUg.jpg'),
(115229, 8221, 'Drag Race Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/noRX1y0aTTPRPzHhP3baolpkJUg.jpg'),
(115230, 8221, 'Drag Race Brasil S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/noRX1y0aTTPRPzHhP3baolpkJUg.jpg'),
(115231, 8221, 'Drag Race Brasil S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/noRX1y0aTTPRPzHhP3baolpkJUg.jpg'),
(115232, 8221, 'Drag Race Brasil S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/noRX1y0aTTPRPzHhP3baolpkJUg.jpg'),
(115233, 8221, 'Drag Race Brasil S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/noRX1y0aTTPRPzHhP3baolpkJUg.jpg'),
(115234, 8222, 'Quem é a Loba? S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yH7KsOP4qSFJG8CoBKQUsBloKni.jpg'),
(115235, 8222, 'Quem é a Loba? S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yH7KsOP4qSFJG8CoBKQUsBloKni.jpg'),
(115236, 8222, 'Quem é a Loba? S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yH7KsOP4qSFJG8CoBKQUsBloKni.jpg'),
(115237, 8222, 'Quem é a Loba? S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yH7KsOP4qSFJG8CoBKQUsBloKni.jpg'),
(115238, 8222, 'Quem é a Loba? S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yH7KsOP4qSFJG8CoBKQUsBloKni.jpg'),
(115239, 8222, 'Quem é a Loba? S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yH7KsOP4qSFJG8CoBKQUsBloKni.jpg'),
(115240, 8222, 'Quem é a Loba? S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yH7KsOP4qSFJG8CoBKQUsBloKni.jpg'),
(115241, 8222, 'Quem é a Loba? S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yH7KsOP4qSFJG8CoBKQUsBloKni.jpg'),
(115242, 8222, 'Quem é a Loba? S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yH7KsOP4qSFJG8CoBKQUsBloKni.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(115243, 8222, 'Quem é a Loba? S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yH7KsOP4qSFJG8CoBKQUsBloKni.jpg'),
(115244, 8222, 'Quem é a Loba? S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yH7KsOP4qSFJG8CoBKQUsBloKni.jpg'),
(115245, 8222, 'Quem é a Loba? S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yH7KsOP4qSFJG8CoBKQUsBloKni.jpg'),
(115246, 8223, 'Pandemia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d5ScdO9GUeEOhP305ofo9zQ04dW.jpg'),
(115247, 8223, 'Pandemia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kbushZDzOcExPclhuSw06LIffmF.jpg'),
(115248, 8223, 'Pandemia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sdmY2wI8ZvxeckZ89UVzOMbb6lv.jpg'),
(115249, 8223, 'Pandemia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dpzhsivX9AQezOEAXsQ3Kl1PE60.jpg'),
(115250, 8223, 'Pandemia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7GQ7xDKCTK5J26oGmxQhX4LwIKZ.jpg'),
(115251, 8223, 'Pandemia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gmfHwOdol0f4bXrb4LEpxf8gXwx.jpg'),
(115252, 8224, 'All That We Loved [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z0p2BGKNTuT2FLtTv8c0kbluia.jpg'),
(115253, 8224, 'All That We Loved [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2V38008vup41l0h1608vrtHGE1V.jpg'),
(115254, 8224, 'All That We Loved [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzI6mj1euBBFH7bFcXclqlF44vk.jpg'),
(115255, 8224, 'All That We Loved [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7T60d5u3dsy1DtzEuvSRMIWSAtg.jpg'),
(115256, 8224, 'All That We Loved [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/phpg7ElPlvBA2t7uNH4ZV0TsXGH.jpg'),
(115257, 8224, 'All That We Loved [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4YeJMigkm1fKGpWb9fkhrvbHFw0.jpg'),
(115258, 8224, 'All That We Loved [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zXvUw4WFt6K41faPWgv9kucMIKB.jpg'),
(115259, 8224, 'All That We Loved [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tSMYlRXN6PDagUAzVS9FMwZKQAC.jpg'),
(115260, 8225, 'Apartamento 6/9 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3EjpvUB1bC9DAYO45nktkUKFAUs.jpg'),
(115261, 8225, 'Apartamento 6/9 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/79pMPXYV59XpE54Pt5WKuqZW7Tq.jpg'),
(115262, 8225, 'Apartamento 6/9 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dFmjVb0xNBvecY2uUyiKGUrD6Ky.jpg'),
(115263, 8225, 'Apartamento 6/9 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8RJeQ8hTWZWMCSfZGEYPiCMvduu.jpg'),
(115264, 8225, 'Apartamento 6/9 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3wIB0nLsUQFVU9KB3pKaARDeev6.jpg'),
(115265, 8225, 'Apartamento 6/9 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/co0kx390mLnUCRojDf6G7OkCHgN.jpg'),
(115266, 8226, 'B.O. S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/GAwNfeB1EOaK1q8W3QOIcignes.jpg'),
(115267, 8226, 'B.O. S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/axJQSk8P7Gr81Z7EhN3BUNXwx4W.jpg'),
(115268, 8226, 'B.O. S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rnIYZ8hLoRplLylHgvvMk0cCYOP.jpg'),
(115269, 8226, 'B.O. S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/826toPIf2pdWNiUqkVFZCFqqIlr.jpg'),
(115270, 8226, 'B.O. S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dCUOVXEYSTRDuXtgcnu9c76opGi.jpg'),
(115271, 8226, 'B.O. S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzWSAxcwPrptt0dSU9veg9VuGwB.jpg'),
(115272, 8226, 'B.O. S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mI0YKOnMw5wVgQbvmHc1wYOAKo0.jpg'),
(115273, 8226, 'B.O. S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/46QgRTU9hjrzv3R2Oz5pfKQHasu.jpg'),
(115274, 8227, 'Big Boys [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ZQ0RSnZKpjx7LZ72Gq2VTico6d.jpg'),
(115275, 8227, 'Big Boys [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5xxWaKwSVhK8BLkBMsKVABxDoNa.jpg'),
(115276, 8227, 'Big Boys [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jX11SICkRbTGlnQE40WR0yCuvvx.jpg'),
(115277, 8227, 'Big Boys [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sokLti2nfacUDAxJVHpTLr2iFH7.jpg'),
(115278, 8227, 'Big Boys [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ZAnKD112I8uBxa8QfMVH3mI1gC.jpg'),
(115279, 8227, 'Big Boys [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pXYGgSBPLm0gUA6HBKfLtNqP9ee.jpg'),
(115280, 8228, 'Bluey S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4vrYTRSUjQ6i9BuyBwAyFHBWfO6.jpg'),
(115281, 8228, 'Bluey S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8YoNM0dgSw6gqUtOoijsw1VyQi8.jpg'),
(115282, 8228, 'Bluey S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rju1CL5ae40DmHSawZAr7GvVHKs.jpg'),
(115283, 8228, 'Bluey S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/NytBQymaDFBK1NYFHeW7iThJ9w.jpg'),
(115284, 8228, 'Bluey S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJhXDWIufAgpx5I7mzZ38dY3hQU.jpg'),
(115285, 8228, 'Bluey S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFCjrfxQLeWaoN3XcUYGnnml3pA.jpg'),
(115286, 8228, 'Bluey S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yIiT5Js01PYXIKpJv00KuMx2paG.jpg'),
(115287, 8228, 'Bluey S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jK63ogwEHXrts80FmOEABqWE3BW.jpg'),
(115288, 8228, 'Bluey S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhFYMpKCXV1wTCfqZDEUJJHn0QJ.jpg'),
(115289, 8228, 'Bluey S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mFyLt6qBB0dafVFZQlTdGGExM2h.jpg'),
(115290, 8228, 'Bluey S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aOPQxhssWj8H7YFbQVDlZqKVhfx.jpg'),
(115291, 8228, 'Bluey S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wsxhWcHZIjqGjpWrkonTaRXe7tj.jpg'),
(115292, 8228, 'Bluey S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/232398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4qlxb1AsumuyvHbNbFLR2Onuvl.jpg'),
(115293, 8228, 'Bluey S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/232399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wafyBQrONgZPjYdALYbXHJZ5pPI.jpg'),
(115294, 8228, 'Bluey S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/232400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7pMrJZyiPOM4KbwXgd25yXEysVN.jpg'),
(115295, 8228, 'Bluey S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/232401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kLg2kMqsAaHOzq7J9BBcTUb7B5M.jpg'),
(115296, 8228, 'Bluey S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/232402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yg7uuNk1gK691GVsoLAoJUslMZN.jpg'),
(115297, 8228, 'Bluey S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/232403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eAsVhkNZFod4j2SEoXkDA4QZQoF.jpg'),
(115298, 8228, 'Bluey S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/232404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vDmrxFxIuAfXBq6bLizpIA1aWC6.jpg'),
(115299, 8228, 'Bluey S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/232405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l9uYp4PFr12T4RBcNLq2bK4IpKi.jpg'),
(115300, 8228, 'Bluey S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/232406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3uzpV4RXF38lbTrZ2SMhheSamsa.jpg'),
(115301, 8228, 'Bluey S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/232407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jG1A6M3iIBso6YqVDaXvvvMFGq9.jpg'),
(115302, 8228, 'Bluey S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/232408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hXcovq3Cu4hlc8UCvhIZDKkaYaG.jpg'),
(115303, 8228, 'Bluey S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/232409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9kvwBygFGtRiCugSjZa5U6hmJcO.jpg'),
(115304, 8228, 'Bluey S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/232410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lMfAZViQaxM9UD3ObU56X04wi0S.jpg'),
(115305, 8228, 'Bluey S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/232411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lRaV9XdB8bZlkWAVvE7KycwTtCW.jpg'),
(115306, 8228, 'Bluey S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/232412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1CVOBYCLNtxUHQzLaTKtFwoVVYq.jpg'),
(115307, 8228, 'Bluey S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/232413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1cc2RR89DKq62adX4wHq0GggRf.jpg'),
(115308, 8228, 'Bluey S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/232414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9TJ9R6yHokHi9vyOqS5JluJYAvn.jpg'),
(115309, 8228, 'Bluey S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/232415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ur2u40xuVPM8JcKxiFHHMQFnxmk.jpg'),
(115310, 8228, 'Bluey S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/232416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fEfNl9WNx0yYqlXQySir7bHrOFU.jpg'),
(115311, 8228, 'Bluey S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/232417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hDbLiheC6Pk1Ms6aqbxjFPwuBVT.jpg'),
(115312, 8228, 'Bluey S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/232418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wgSRgjuS90r2lihm2YgrvVoBfix.jpg'),
(115313, 8228, 'Bluey S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/232419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fzCuVY77jrvWLzummwcTdFqdDoE.jpg'),
(115314, 8228, 'Bluey S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/232420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/inRr9Te55NSBL8m8G3mG2F8OB4h.jpg'),
(115315, 8228, 'Bluey S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/232421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dmbPaTbyud4z0AMbAZc1gPZgLCj.jpg'),
(115316, 8228, 'Bluey S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/232422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rwnos52lEMJRHscrtwgqgIlmT0m.jpg'),
(115317, 8228, 'Bluey S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/232423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kwsAfCN0HheRLnPwRriBwqgnqjw.jpg'),
(115318, 8228, 'Bluey S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/232424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8lcNQoRB6NNyciddhHyYH4E7mW6.jpg'),
(115319, 8228, 'Bluey S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/232425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AdTLNOUs3UJMlNFf6Suk911m467.jpg'),
(115320, 8228, 'Bluey S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/232426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fND9vJgw0LcxaiX135j3WlJdSCx.jpg'),
(115321, 8228, 'Bluey S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/232427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5bF4qHS9itVNECu9zQt3XgWLbme.jpg'),
(115322, 8228, 'Bluey S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/232428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iBCtT1JPG8CGpdJVNzDcskIBKNn.jpg'),
(115323, 8228, 'Bluey S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/232429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eB3JRB2NzUUY5w5a710OcimR006.jpg'),
(115324, 8228, 'Bluey S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/232430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zDM04knovkL51ZtvlDaPJkedrjc.jpg'),
(115325, 8228, 'Bluey S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/232431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lhjphYTx3xu8bDUZtMKs2fykee7.jpg'),
(115326, 8228, 'Bluey S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/232432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/255Jskg9R3MRQASUB4zAulrDZKg.jpg'),
(115327, 8228, 'Bluey S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/232433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Q4Xa6mw6ppqmkH5Fc9VxWEOQfm.jpg'),
(115328, 8228, 'Bluey S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/232434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3YfsDHp13MyCjO9wQCZXIGd0EYl.jpg'),
(115329, 8228, 'Bluey S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/232435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/adZXKciVTu6oH96TZmPw9329Phr.jpg'),
(115330, 8228, 'Bluey S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/232436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/40QNX8ZGKhABEIVYTlYEhSYkzxL.jpg'),
(115331, 8229, 'Bluey S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yobiCpcOyolRxpVJJ0y9PYUIqZf.jpg'),
(115332, 8229, 'Bluey S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lIN7vBaTzPzv9Usl9OqQCZmGc9g.jpg'),
(115333, 8229, 'Bluey S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZOBCTytqy7YDYUz4TJ8qcMxXIi.jpg'),
(115334, 8229, 'Bluey S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jq6hAhN36GMU9s6O0uHO8G3I3vf.jpg'),
(115335, 8229, 'Bluey S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eTVRpM1PtX7LIG6kbkvCHnGKYy8.jpg'),
(115336, 8229, 'Bluey S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nTfZngqPl6nyFtZD0xbbWquTJkX.jpg'),
(115337, 8229, 'Bluey S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jv9q9OnkzATUc9nTUSXHAmm8eM9.jpg'),
(115338, 8229, 'Bluey S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hyJtqtcdCcToISNaIuAUqDcKHqO.jpg'),
(115339, 8229, 'Bluey S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ddURgaQmmHRDw0JBnubWY0GZLZ.jpg'),
(115340, 8229, 'Bluey S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wHEwbJCrQYlxiYg1ugT7RCms8yf.jpg'),
(115341, 8229, 'Bluey S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mNBDckENRn45e3ooKVBexfpKUJ6.jpg'),
(115342, 8229, 'Bluey S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0LIfTKVy0Nt9Z2xR6NywtRadN7.jpg'),
(115343, 8229, 'Bluey S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/232449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7f3UCRo8eLxVmsPQMw6vTTkGgSx.jpg'),
(115344, 8229, 'Bluey S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/232450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2ha6ddJfZaYyhAw0P6TV0jPuFs.jpg'),
(115345, 8229, 'Bluey S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/232451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7hdcFlSERQT8o2e8SEbuj6VHPfI.jpg'),
(115346, 8229, 'Bluey S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/232452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bWTMKLnIoFBMTXvbT7Wnt40JKNm.jpg'),
(115347, 8229, 'Bluey S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/232453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zNVFqKAc5WlwNGfxAAcTAT3aBfm.jpg'),
(115348, 8229, 'Bluey S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/232454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rIs8xthKwklY3WpdCt0caO5ujZc.jpg'),
(115349, 8229, 'Bluey S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/232455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nRPpF0i5jMcbYSNgZxw3CeNoCWb.jpg'),
(115350, 8229, 'Bluey S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/232456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hswxRS56uU3hs4SkzCeloY6tlJg.jpg'),
(115351, 8229, 'Bluey S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/232457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uxszuXxNxKz0WH70JZ7dvbDwcTC.jpg'),
(115352, 8229, 'Bluey S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/232458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3HffG0X3GUg9QVJdn9Xiy22yRjn.jpg'),
(115353, 8229, 'Bluey S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/232459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/X9ktOXvkJsFj7OyLYQvXyL3kJl.jpg'),
(115354, 8229, 'Bluey S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/232460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkAN8roEFnGUjvi7hO6rYc8ceVs.jpg'),
(115355, 8229, 'Bluey S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/232461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eTwoAi4vL3rxOr5LfJ2JaFqav5P.jpg'),
(115356, 8229, 'Bluey S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/232462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2892eHHJ9Tav4JA8MExApa4gZiV.jpg'),
(115357, 8229, 'Bluey S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/232463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nue5cqVOONDiX8q5eEVVwkdSt5o.jpg'),
(115358, 8229, 'Bluey S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/232464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hV8OMQWb1FvAdIoY1vJxlNls0jR.jpg'),
(115359, 8229, 'Bluey S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/232465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFVhnckUgLhJRSOpWM2O9vOeRjw.jpg'),
(115360, 8229, 'Bluey S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/232466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/awkZTdIMCHPRAzl7lGyThofp5XH.jpg'),
(115361, 8229, 'Bluey S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/232467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ZPYRPIYpRcfVcDYCl4BOZSx2gb.jpg'),
(115362, 8229, 'Bluey S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/232468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qqNxrPwS7qIgafPA86oCXYZCXLl.jpg'),
(115363, 8229, 'Bluey S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/232469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yXtCgOicMTFx7ChnyiLCJlnkc7s.jpg'),
(115364, 8229, 'Bluey S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/232470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zS7GR9L7isTaQy0NKxYJeo3O0KS.jpg'),
(115365, 8229, 'Bluey S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/232471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iOLlDI2OWoRhSv2Rm38iTQjLV1m.jpg'),
(115366, 8229, 'Bluey S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/232472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sxz3z3FNlY6oHnIA73Hp8lm41Ej.jpg'),
(115367, 8229, 'Bluey S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/232473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m3ucz85WzhQlvNl2YWMbQNqxlqM.jpg'),
(115368, 8229, 'Bluey S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/232474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/78wXNdx2I6B1AbqraGsHU3V5U4W.jpg'),
(115369, 8229, 'Bluey S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/232475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3l6AIdK0uLKw4zKOsZ97YWjXAKF.jpg'),
(115370, 8229, 'Bluey S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/232476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kZXEVaIiVandvjUnEjVLEQA4WG1.jpg'),
(115371, 8229, 'Bluey S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/232477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ygpwh2EIYQHkqOGZSFZ8EkuBWCJ.jpg'),
(115372, 8229, 'Bluey S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/232478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9z1CZhWUfcDvMmTlOPrmYfajPZ.jpg'),
(115373, 8229, 'Bluey S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/232479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fax8Pj4G495WGOILxdZW9bFPQxa.jpg'),
(115374, 8229, 'Bluey S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/232480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zufBnRBvgQ1aLsecfPOaqA0Dc2z.jpg'),
(115375, 8229, 'Bluey S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/232481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w9WwaurvnVnsNELGFzSNvXOs1bL.jpg'),
(115376, 8229, 'Bluey S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/232482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/smpe17I0K6IiwghRnPYPZ1HyJqK.jpg'),
(115377, 8229, 'Bluey S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/232483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3mA8pzNzrhZpKFxk2RZR5Ghpebn.jpg'),
(115378, 8229, 'Bluey S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/232484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tLgptlPvDShy2kPcGKowwLZy6Ii.jpg'),
(115379, 8229, 'Bluey S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/232485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Pmd8705VW0GJK64Sc9czh88fgP.jpg'),
(115380, 8229, 'Bluey S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/232486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cBzUkj9zgE2XE4Iw1QNuM0D7wSF.jpg'),
(115381, 8229, 'Bluey S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/232487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pZXnsut1BVWC2KHFvBdiTxhWZ68.jpg'),
(115382, 8230, 'Bluey S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b9X8YYaMz2X5SkPBWFyWvFin34X.jpg'),
(115383, 8230, 'Bluey S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2onzCMfZVJ8a7CW8KpYSmz8iaa.jpg'),
(115384, 8230, 'Bluey S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zEc2CD0bu9Kwm66akDgNQeyFleF.jpg'),
(115385, 8230, 'Bluey S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uwgsPkWU43I7UeX0SvX6do1smcF.jpg'),
(115386, 8230, 'Bluey S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hFOdB7NghGAKMcQwhwDomrlkvFC.jpg'),
(115387, 8230, 'Bluey S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ki5UjXzZUDJ578KA41y6J1GGy4g.jpg'),
(115388, 8230, 'Bluey S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hHlV3O7NsllqZlB06ANNP62fcsl.jpg'),
(115389, 8230, 'Bluey S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uiBaZCL1NTDn1hKKUiiBPvb4Fri.jpg'),
(115390, 8230, 'Bluey S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pLBYZuaNNQL3CNTmjUrQcFEpvA0.jpg'),
(115391, 8230, 'Bluey S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d7A6JUZ8stC0ROzEwcPkH7vSzJU.jpg'),
(115392, 8230, 'Bluey S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lYCRZmh9zv0fjLHDdZahIx6g5S6.jpg'),
(115393, 8230, 'Bluey S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2dSf8aGyAzHgCYtZeAxOlgABFSc.jpg'),
(115394, 8230, 'Bluey S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/232500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lLru77tl2gxGXMY5OlDLodfX1s9.jpg'),
(115395, 8230, 'Bluey S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/232501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fFXQIMNvRqiRyFl9YRXG2YNkKMq.jpg'),
(115396, 8230, 'Bluey S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/232502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8DNrhHZYTo7d4HQicSFdZtEtrKB.jpg'),
(115397, 8230, 'Bluey S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/232503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QJQMntDJyK9cD5DPnAq17btiWO.jpg'),
(115398, 8230, 'Bluey S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/232504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vk6or8Mx34Sw1vuBwyLXxATNF9q.jpg'),
(115399, 8230, 'Bluey S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/232505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hPynSYRKC4aQP1WtiNfFkYUUnWI.jpg'),
(115400, 8230, 'Bluey S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/232506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6hccFN4DfDD4ANhEjjyc27hWH3m.jpg'),
(115401, 8230, 'Bluey S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/232507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zewn4S5ukzfWj9QioSrXAtMKs4C.jpg'),
(115402, 8230, 'Bluey S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/232508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9AiFPFaUMlVdGzXqWNyU3B6GYGm.jpg'),
(115403, 8230, 'Bluey S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/232509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g6LzJuFMUn60JrTMJ9lwRVMox3J.jpg'),
(115404, 8230, 'Bluey S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/232510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nNIMYZ5asUjZF1Q8n6jMlhCcaNU.jpg'),
(115405, 8230, 'Bluey S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/232511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5LCe5Y5i3rM9TLBrlX7ENZywBPi.jpg'),
(115406, 8230, 'Bluey S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/232512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rWUNXgQ1zHB5U8mJF0RvhP290ft.jpg'),
(115407, 8230, 'Bluey S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/232513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/krZWXEotzy0eJ8lbx84tf3ODg1d.jpg'),
(115408, 8230, 'Bluey S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/232514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Foy6zf6JItA8obSw0aiz2etEit.jpg'),
(115409, 8230, 'Bluey S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/232515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5GSGKHMO8umpNCwK5B0VDU1Jvy7.jpg'),
(115410, 8230, 'Bluey S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/232516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/955HlHqaoAumheswVyNswjFHfVU.jpg'),
(115411, 8230, 'Bluey S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/232517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZ45QAFwd7neUJbCaRyktIYawXq.jpg'),
(115412, 8230, 'Bluey S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/232518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jjkrzPm1LkaUVG523cWB7e2MvpL.jpg'),
(115413, 8230, 'Bluey S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/232519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vwysPwNUnS9ZqxEn8AGFzqlJwOS.jpg'),
(115414, 8230, 'Bluey S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/232520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/txe8CY65fa7sbE4orBSh16g7EUB.jpg'),
(115415, 8230, 'Bluey S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/232521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4DjVJhgap6pEg5Z1fZgmvfAFNsH.jpg'),
(115416, 8230, 'Bluey S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/232522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6lD9HRggpG9xUQlIB5fatsLW3HE.jpg'),
(115417, 8230, 'Bluey S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/232523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lp2pGDoDVbvgImE0osnLfShhqea.jpg'),
(115418, 8230, 'Bluey S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/232524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/19n9Zf1Ajus5POq9cAP1zUBYX1O.jpg'),
(115419, 8230, 'Bluey S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/887625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9mY0X5T20ZM073hoa5n0dgmbfN.jpg'),
(115420, 8230, 'Bluey S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/887626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9mY0X5T20ZM073hoa5n0dgmbfN.jpg'),
(115421, 8230, 'Bluey S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/887627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9mY0X5T20ZM073hoa5n0dgmbfN.jpg'),
(115422, 8230, 'Bluey S03 E41', 'http://sinalprivado.info:80/series/1533784/1533784/887628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9mY0X5T20ZM073hoa5n0dgmbfN.jpg'),
(115423, 8230, 'Bluey S03 E42', 'http://sinalprivado.info:80/series/1533784/1533784/887629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9mY0X5T20ZM073hoa5n0dgmbfN.jpg'),
(115424, 8230, 'Bluey S03 E43', 'http://sinalprivado.info:80/series/1533784/1533784/887630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9mY0X5T20ZM073hoa5n0dgmbfN.jpg'),
(115425, 8230, 'Bluey S03 E44', 'http://sinalprivado.info:80/series/1533784/1533784/887631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9mY0X5T20ZM073hoa5n0dgmbfN.jpg'),
(115426, 8230, 'Bluey S03 E45', 'http://sinalprivado.info:80/series/1533784/1533784/887632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9mY0X5T20ZM073hoa5n0dgmbfN.jpg'),
(115427, 8230, 'Bluey S03 E46', 'http://sinalprivado.info:80/series/1533784/1533784/887633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9mY0X5T20ZM073hoa5n0dgmbfN.jpg'),
(115428, 8230, 'Bluey S03 E47', 'http://sinalprivado.info:80/series/1533784/1533784/887634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9mY0X5T20ZM073hoa5n0dgmbfN.jpg'),
(115429, 8230, 'Bluey S03 E48', 'http://sinalprivado.info:80/series/1533784/1533784/887635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9mY0X5T20ZM073hoa5n0dgmbfN.jpg'),
(115430, 8230, 'Bluey S03 E49', 'http://sinalprivado.info:80/series/1533784/1533784/887636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9mY0X5T20ZM073hoa5n0dgmbfN.jpg'),
(115431, 8230, 'Bluey S03 E50', 'http://sinalprivado.info:80/series/1533784/1533784/887637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b9mY0X5T20ZM073hoa5n0dgmbfN.jpg'),
(115432, 8231, 'Chico Xavier: A Série S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uBbGdca9RZvksJ6yVQtrBQLkCf8.jpg'),
(115433, 8231, 'Chico Xavier: A Série S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uBbGdca9RZvksJ6yVQtrBQLkCf8.jpg'),
(115434, 8231, 'Chico Xavier: A Série S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uBbGdca9RZvksJ6yVQtrBQLkCf8.jpg'),
(115435, 8231, 'Chico Xavier: A Série S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uBbGdca9RZvksJ6yVQtrBQLkCf8.jpg'),
(115436, 8231, 'Chico Xavier: A Série S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uBbGdca9RZvksJ6yVQtrBQLkCf8.jpg'),
(115437, 8231, 'Chico Xavier: A Série S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uBbGdca9RZvksJ6yVQtrBQLkCf8.jpg'),
(115438, 8232, 'Corpo em Chamas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k3IiXp4GyZAZHh4moCPPHPNO4fC.jpg'),
(115439, 8232, 'Corpo em Chamas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3LylD96g0AnjsHPkt5An1xdnuYd.jpg'),
(115440, 8232, 'Corpo em Chamas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjvCzLKo5C59PFp1tKVJSBcTVJ.jpg'),
(115441, 8232, 'Corpo em Chamas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5IOHoFvnAJrcv3DSPNh61jHkaY.jpg'),
(115442, 8232, 'Corpo em Chamas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJ6ZV2DJlt8AhqSNgw2WXTbSv7x.jpg'),
(115443, 8232, 'Corpo em Chamas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gfst13EJIGlbJ09fFNtxoQlQdOM.jpg'),
(115444, 8232, 'Corpo em Chamas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aP6xIjhg4Y60kbGcg6bZJys7jRN.jpg'),
(115445, 8232, 'Corpo em Chamas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/paMh9WMgWpvRit7A3a83pyeA4E2.jpg'),
(115446, 8233, 'Depois da Cabana S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Apt9ILMPTTFFsGC8Jgpnegmg7Ok.jpg'),
(115447, 8233, 'Depois da Cabana S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sYDvQr7ADx8BdctIGejydc2h3z5.jpg'),
(115448, 8233, 'Depois da Cabana S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lDqEIOzbnNcRmIQIMcnR8ekBzlh.jpg'),
(115449, 8233, 'Depois da Cabana S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2MuKZLfJ3JKMvORit1doP0y7MCZ.jpg'),
(115450, 8233, 'Depois da Cabana S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tgDmEhKGXJHeOAYhDRXwSqkhrFK.jpg'),
(115451, 8233, 'Depois da Cabana S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a63ZhLjDqBYVSmERXb3R9fKKhOW.jpg'),
(115452, 8234, 'Gamera: O Renascimento S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t5cNst6bWKoBcGgLy15okWQBf6Z.jpg'),
(115453, 8234, 'Gamera: O Renascimento S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3H1693Y94pwTAjukTKssdpeaH3h.jpg'),
(115454, 8234, 'Gamera: O Renascimento S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rxCyVZ3MENn6g1DTHdC0y65dZ4D.jpg'),
(115455, 8234, 'Gamera: O Renascimento S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4zC8923x4doMYkUOJdOjoSBXNeb.jpg'),
(115456, 8234, 'Gamera: O Renascimento S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/95UmPY2InnjiJNkKmPYjguCreYP.jpg'),
(115457, 8234, 'Gamera: O Renascimento S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/enk4jb55quvvc7ovw98TC9rdqQk.jpg'),
(115458, 8235, 'Gangues de Oslo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eCHXtsWHFQeQxR8VXuLuLpkhWhE.jpg'),
(115459, 8235, 'Gangues de Oslo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cy8WLlK3P05RJFN0TIAcdL4wvn7.jpg'),
(115460, 8235, 'Gangues de Oslo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lsC4dfuFt1fR0oFac7gl16fDk4l.jpg'),
(115461, 8235, 'Gangues de Oslo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yEbpPJKtzqZhExRzh048UBoiWI0.jpg'),
(115462, 8235, 'Gangues de Oslo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7J2U4mrB5T5X924gnCUbTMXOoIN.jpg'),
(115463, 8235, 'Gangues de Oslo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cumHkiKuZrc1YtOBo9fNgdfmMOI.jpg'),
(115464, 8236, 'Grandes Roubos da História com Pierce Brosnan S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dDFwE612WjKoVxeitenr0myC16P.jpg'),
(115465, 8236, 'Grandes Roubos da História com Pierce Brosnan S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBRm8syqizlF4psndRqP3WQY6A2.jpg'),
(115466, 8236, 'Grandes Roubos da História com Pierce Brosnan S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9xG23PIJ0MGyriAeBfHyEiaLSTo.jpg'),
(115467, 8236, 'Grandes Roubos da História com Pierce Brosnan S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uulpGSZiSKF9YRuwKTpf4h64kyk.jpg'),
(115468, 8236, 'Grandes Roubos da História com Pierce Brosnan S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8W8yJv03SKjMehxLTwljQkA4zeo.jpg'),
(115469, 8236, 'Grandes Roubos da História com Pierce Brosnan S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8NJGpBPcwTpfvF1elBdnTVANWE6.jpg'),
(115470, 8236, 'Grandes Roubos da História com Pierce Brosnan S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jbtyz7UDfOKyrWpcfHu1YmukaR6.jpg'),
(115471, 8236, 'Grandes Roubos da História com Pierce Brosnan S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j6DOaidgiL0siRj3YbDBm5Uyz31.jpg'),
(115472, 8237, 'Infâmia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g24Kx3px36SJZjyri7TqRo1Plvc.jpg'),
(115473, 8237, 'Infâmia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/27qnGQsUER1Pk3QeCfuFLnxpB2i.jpg'),
(115474, 8237, 'Infâmia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/53x08YOkGyBDPMTUWv8tIBRx0dx.jpg'),
(115475, 8237, 'Infâmia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4xPNskteacm6iHyufkNZvCwtRr8.jpg'),
(115476, 8237, 'Infâmia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1j6vFziWfggrR6VBxaQ9crUowQK.jpg'),
(115477, 8237, 'Infâmia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oONrAfXj9CNqZi6y5ITak6UPSrC.jpg'),
(115478, 8237, 'Infâmia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/45vdMt1JHsM3HkQVZPCUyk4Jkj4.jpg'),
(115479, 8237, 'Infâmia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xU6RAFobsme0EL2Exrp5K2UHTqs.jpg'),
(115480, 8238, 'Jun e Jun [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3VATathuVXdyj2LJoGw7nns7Kx3.jpg'),
(115481, 8238, 'Jun e Jun [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m0JMgAVIOwdIOZwBN3PyLiEwA5y.jpg'),
(115482, 8238, 'Jun e Jun [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w1BnqCtwxar5IuB9KrGr2CpI1on.jpg'),
(115483, 8238, 'Jun e Jun [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6VQJtb43oQ79wmQtNr2NpUVXWsW.jpg'),
(115484, 8238, 'Jun e Jun [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/menZjzOD5jMYjUppQUzm2YmynPo.jpg'),
(115485, 8238, 'Jun e Jun [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2L3eLlSnuB2mIJUpsN4YqiiYP9W.jpg'),
(115486, 8238, 'Jun e Jun [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mcfSpHDYaZ6k6xczLrdAcOqjFox.jpg'),
(115487, 8238, 'Jun e Jun [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r25Dj5v2fLrPP66p0jQSN3OqheC.jpg'),
(115488, 8239, 'Kamen Rider Gotchard [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115489, 8239, 'Kamen Rider Gotchard [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115490, 8239, 'Kamen Rider Gotchard [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115491, 8239, 'Kamen Rider Gotchard [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115492, 8239, 'Kamen Rider Gotchard [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115493, 8239, 'Kamen Rider Gotchard [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115494, 8239, 'Kamen Rider Gotchard [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115495, 8239, 'Kamen Rider Gotchard [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115496, 8239, 'Kamen Rider Gotchard [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/262617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115497, 8239, 'Kamen Rider Gotchard [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/262618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115498, 8239, 'Kamen Rider Gotchard [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/262619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115499, 8239, 'Kamen Rider Gotchard [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/262620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115500, 8239, 'Kamen Rider Gotchard [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/262621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115501, 8239, 'Kamen Rider Gotchard [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/262622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115502, 8239, 'Kamen Rider Gotchard [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/262623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115503, 8239, 'Kamen Rider Gotchard [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/262624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115504, 8239, 'Kamen Rider Gotchard [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/262625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115505, 8239, 'Kamen Rider Gotchard [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/262626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115506, 8239, 'Kamen Rider Gotchard [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/262627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115507, 8239, 'Kamen Rider Gotchard [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/262628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115508, 8239, 'Kamen Rider Gotchard [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/272828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115509, 8239, 'Kamen Rider Gotchard [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/272829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115510, 8239, 'Kamen Rider Gotchard [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/274441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115511, 8239, 'Kamen Rider Gotchard [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/282916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115512, 8239, 'Kamen Rider Gotchard [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/294117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115513, 8239, 'Kamen Rider Gotchard [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/297711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(115514, 8239, 'Kamen Rider Gotchard [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/304538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115515, 8239, 'Kamen Rider Gotchard [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/310047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115516, 8239, 'Kamen Rider Gotchard [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/317603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115517, 8239, 'Kamen Rider Gotchard [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/323894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115518, 8239, 'Kamen Rider Gotchard [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/327740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115519, 8239, 'Kamen Rider Gotchard [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/332566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115520, 8239, 'Kamen Rider Gotchard [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/340891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115521, 8239, 'Kamen Rider Gotchard [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/345288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115522, 8239, 'Kamen Rider Gotchard [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/352133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115523, 8239, 'Kamen Rider Gotchard [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/359548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115524, 8239, 'Kamen Rider Gotchard [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/368325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115525, 8239, 'Kamen Rider Gotchard [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/368326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115526, 8239, 'Kamen Rider Gotchard [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/382584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115527, 8239, 'Kamen Rider Gotchard [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/389622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115528, 8239, 'Kamen Rider Gotchard [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/396719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115529, 8239, 'Kamen Rider Gotchard [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/403031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115530, 8239, 'Kamen Rider Gotchard [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/405141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115531, 8239, 'Kamen Rider Gotchard [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/412224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115532, 8239, 'Kamen Rider Gotchard [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/414966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115533, 8239, 'Kamen Rider Gotchard [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/421605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115534, 8239, 'Kamen Rider Gotchard [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/427630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115535, 8239, 'Kamen Rider Gotchard [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/436573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115536, 8239, 'Kamen Rider Gotchard [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/436574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115537, 8239, 'Kamen Rider Gotchard [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/442300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x1QKfnoteeqbcOeUpBXZlafiOQ8.jpg'),
(115538, 8240, 'Lara com Z S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f4ZxPMbvZ65l7uiVb4dI587oYKQ.jpg'),
(115539, 8240, 'Lara com Z S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f4ZxPMbvZ65l7uiVb4dI587oYKQ.jpg'),
(115540, 8240, 'Lara com Z S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f4ZxPMbvZ65l7uiVb4dI587oYKQ.jpg'),
(115541, 8240, 'Lara com Z S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f4ZxPMbvZ65l7uiVb4dI587oYKQ.jpg'),
(115542, 8240, 'Lara com Z S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f4ZxPMbvZ65l7uiVb4dI587oYKQ.jpg'),
(115543, 8240, 'Lara com Z S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f4ZxPMbvZ65l7uiVb4dI587oYKQ.jpg'),
(115544, 8240, 'Lara com Z S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f4ZxPMbvZ65l7uiVb4dI587oYKQ.jpg'),
(115545, 8240, 'Lara com Z S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f4ZxPMbvZ65l7uiVb4dI587oYKQ.jpg'),
(115546, 8240, 'Lara com Z S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f4ZxPMbvZ65l7uiVb4dI587oYKQ.jpg'),
(115547, 8240, 'Lara com Z S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f4ZxPMbvZ65l7uiVb4dI587oYKQ.jpg'),
(115548, 8240, 'Lara com Z S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f4ZxPMbvZ65l7uiVb4dI587oYKQ.jpg'),
(115549, 8240, 'Lara com Z S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f4ZxPMbvZ65l7uiVb4dI587oYKQ.jpg'),
(115550, 8240, 'Lara com Z S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/232328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f4ZxPMbvZ65l7uiVb4dI587oYKQ.jpg'),
(115551, 8240, 'Lara com Z S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/232329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f4ZxPMbvZ65l7uiVb4dI587oYKQ.jpg'),
(115552, 8241, 'Linda de Morrer [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9geyXEiFjBiwHrcrczgc8JezAfN.jpg'),
(115553, 8241, 'Linda de Morrer [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/81mg3wvKS8rrQNQ5kPku4rKnZu.jpg'),
(115554, 8241, 'Linda de Morrer [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sU3KnrsBo2LlVwOTAfgBhorponk.jpg'),
(115555, 8241, 'Linda de Morrer [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uvYkmmniwVfAwedyZgyg7Hof7R7.jpg'),
(115556, 8241, 'Linda de Morrer [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xRmsWNdcycMZEAcRd1HJ9SEMdgb.jpg'),
(115557, 8241, 'Linda de Morrer [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/41eV5ksMsYnsaMN0mRFKV4FQrnO.jpg'),
(115558, 8241, 'Linda de Morrer [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kiNYJUbc9WA2uteIXYEGh4JWbcq.jpg'),
(115559, 8241, 'Linda de Morrer [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dbXkVS8JS9B1xjJqb9g2StWVbOD.jpg'),
(115560, 8242, 'Macho Man S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/577002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGxUzzevKHXVmToQWBGWb8c9ow2.jpg'),
(115561, 8242, 'Macho Man S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/577004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGxUzzevKHXVmToQWBGWb8c9ow2.jpg'),
(115562, 8242, 'Macho Man S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/577006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGxUzzevKHXVmToQWBGWb8c9ow2.jpg'),
(115563, 8242, 'Macho Man S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/577008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGxUzzevKHXVmToQWBGWb8c9ow2.jpg'),
(115564, 8242, 'Macho Man S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/577010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGxUzzevKHXVmToQWBGWb8c9ow2.jpg'),
(115565, 8242, 'Macho Man S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/577012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGxUzzevKHXVmToQWBGWb8c9ow2.jpg'),
(115566, 8242, 'Macho Man S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/577014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGxUzzevKHXVmToQWBGWb8c9ow2.jpg'),
(115567, 8242, 'Macho Man S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGxUzzevKHXVmToQWBGWb8c9ow2.jpg'),
(115568, 8242, 'Macho Man S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGxUzzevKHXVmToQWBGWb8c9ow2.jpg'),
(115569, 8242, 'Macho Man S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGxUzzevKHXVmToQWBGWb8c9ow2.jpg'),
(115570, 8242, 'Macho Man S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGxUzzevKHXVmToQWBGWb8c9ow2.jpg'),
(115571, 8242, 'Macho Man S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGxUzzevKHXVmToQWBGWb8c9ow2.jpg'),
(115572, 8242, 'Macho Man S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/232306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGxUzzevKHXVmToQWBGWb8c9ow2.jpg'),
(115573, 8242, 'Macho Man S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/232307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGxUzzevKHXVmToQWBGWb8c9ow2.jpg'),
(115574, 8243, 'My Lovely Boxer [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/daYYQbliXfwP8TY6yPRUE5QVEh1.jpg'),
(115575, 8243, 'My Lovely Boxer [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w9K6TLdlXweEs6454PRSrE0A7Yd.jpg'),
(115576, 8243, 'My Lovely Boxer [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYJWFH4DnItlY0VHY29Rf2znSwZ.jpg'),
(115577, 8243, 'My Lovely Boxer [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tIbmvjq4Hll09I921zGcTGBF2cl.jpg'),
(115578, 8243, 'My Lovely Boxer [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/27FX5h5y7XUCWXgc9p3woGtxLbO.jpg'),
(115579, 8243, 'My Lovely Boxer [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7grqZHh5uURi8ZENZwS5O6xezPS.jpg'),
(115580, 8243, 'My Lovely Boxer [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7grqZHh5uURi8ZENZwS5O6xezPS.jpg'),
(115581, 8243, 'My Lovely Boxer [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7grqZHh5uURi8ZENZwS5O6xezPS.jpg'),
(115582, 8243, 'My Lovely Boxer [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7grqZHh5uURi8ZENZwS5O6xezPS.jpg'),
(115583, 8243, 'My Lovely Boxer [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7grqZHh5uURi8ZENZwS5O6xezPS.jpg'),
(115584, 8243, 'My Lovely Boxer [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7grqZHh5uURi8ZENZwS5O6xezPS.jpg'),
(115585, 8243, 'My Lovely Boxer [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7grqZHh5uURi8ZENZwS5O6xezPS.jpg'),
(115586, 8244, 'O Ônibus Mágico Decola Novamente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1u4BD8Qe6kFVsCVYLAC7cL24zwc.jpg'),
(115587, 8244, 'O Ônibus Mágico Decola Novamente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24Y0yYIqGbtxCsLj5ejzqIrMDEX.jpg'),
(115588, 8244, 'O Ônibus Mágico Decola Novamente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOMmsPtOVrr6UZLWN6qb6tcd7rs.jpg'),
(115589, 8244, 'O Ônibus Mágico Decola Novamente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jt2dOQYxGa5NbXcDPSY7VLyvSkb.jpg'),
(115590, 8244, 'O Ônibus Mágico Decola Novamente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b7kuxskeL5VLFvtx1uJmu6Oeaq9.jpg'),
(115591, 8244, 'O Ônibus Mágico Decola Novamente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/51d5NIftQZ7XXHbhgJCrwNs4dvS.jpg'),
(115592, 8244, 'O Ônibus Mágico Decola Novamente S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ayuCZzmmrYs7BlgpnqKulJiUtwK.jpg'),
(115593, 8244, 'O Ônibus Mágico Decola Novamente S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qhmMLrDjYsijF8eujYO6D83E8Mt.jpg'),
(115594, 8244, 'O Ônibus Mágico Decola Novamente S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vBwVjHxg9PfNo1SkRr1m4ZZz3qB.jpg'),
(115595, 8244, 'O Ônibus Mágico Decola Novamente S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1vfg80t8soVKHhqDtYzQZS50scq.jpg'),
(115596, 8244, 'O Ônibus Mágico Decola Novamente S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9cfsLUffDZfYey9SON6luUUSDb8.jpg'),
(115597, 8244, 'O Ônibus Mágico Decola Novamente S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vo52Jb48jRmsWROW49bq7MKe6I8.jpg'),
(115598, 8244, 'O Ônibus Mágico Decola Novamente S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/232273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vok4Q0DkW0n8WhzSOFn6BodUZxh.jpg'),
(115599, 8245, 'O Ônibus Mágico Decola Novamente S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSe58F4tSoxCc8dU4zrNXWjvv8g.jpg'),
(115600, 8245, 'O Ônibus Mágico Decola Novamente S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pBZXxJZa2TIbglm9i4pcHnrzp69.jpg'),
(115601, 8245, 'O Ônibus Mágico Decola Novamente S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jL3dDP3gEccl4y6d5vhpNyMi273.jpg'),
(115602, 8245, 'O Ônibus Mágico Decola Novamente S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kz9QAhPfFgRqR3jAgFIDEE8O3mJ.jpg'),
(115603, 8245, 'O Ônibus Mágico Decola Novamente S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/95wyRPr87KvBuwexZYA3W8KCkMl.jpg'),
(115604, 8245, 'O Ônibus Mágico Decola Novamente S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bQfXC6jVvHBulJ8A8HhDEVPz2FP.jpg'),
(115605, 8245, 'O Ônibus Mágico Decola Novamente S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o9v2nX0DEwWaEvodf9y7alU9023.jpg'),
(115606, 8245, 'O Ônibus Mágico Decola Novamente S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vocgyEZYoZBLGDYabNEy0Otlml8.jpg'),
(115607, 8245, 'O Ônibus Mágico Decola Novamente S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vB8wBk1FF07cldKJtOIL6CmCYNy.jpg'),
(115608, 8245, 'O Ônibus Mágico Decola Novamente S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/um649zgtMWrJtlu5yIyoYnUmrSZ.jpg'),
(115609, 8245, 'O Ônibus Mágico Decola Novamente S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZiNG6cokmjX7bWb92fMuq5x3kA.jpg'),
(115610, 8245, 'O Ônibus Mágico Decola Novamente S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zNR7bU3KeA3Lc6HcEuypa9p1hZG.jpg'),
(115611, 8245, 'O Ônibus Mágico Decola Novamente S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/232286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6JSBWKSkKDxjvQIDSrl2rdYKzMJ.jpg'),
(115612, 8246, 'O Tempo Traz Você pra Mim S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vZxmOhjd4rcsTYHJIb1RdB5FW8z.jpg'),
(115613, 8246, 'O Tempo Traz Você pra Mim S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/agyMzWmd4yTJkDliUizC0GryDqc.jpg'),
(115614, 8246, 'O Tempo Traz Você pra Mim S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wVuI8F8FCsUcq6eg1K5bBsln249.jpg'),
(115615, 8246, 'O Tempo Traz Você pra Mim S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uTWtDrkMXgfkDGzjDSh5mpknoay.jpg'),
(115616, 8246, 'O Tempo Traz Você pra Mim S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ikG1ti2vRoDYPNCTcJJnEeFvbnW.jpg'),
(115617, 8246, 'O Tempo Traz Você pra Mim S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v2k4O4Vm3bbGed7LPylPaMZlFJp.jpg'),
(115618, 8246, 'O Tempo Traz Você pra Mim S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bwnYf4n7Mz2fZUXtr2R8YplXjH.jpg'),
(115619, 8246, 'O Tempo Traz Você pra Mim S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3YeD00qVvezdxDkFwZ9hKnG7FOt.jpg'),
(115620, 8246, 'O Tempo Traz Você pra Mim S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ao4YSMTRZDb411ELvYDyLRaRfGV.jpg'),
(115621, 8246, 'O Tempo Traz Você pra Mim S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wcEyYdHPo9r2kzsC9gO9Bze4vW1.jpg'),
(115622, 8246, 'O Tempo Traz Você pra Mim S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kAvm45KLiqt0Cv5i7rIVS2QiYJw.jpg'),
(115623, 8246, 'O Tempo Traz Você pra Mim S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u08ahgJ9WWIUi4nzGrfwsuIeTFx.jpg'),
(115624, 8247, 'Please Like Me [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pQxK1KckyaIc9ZJYMer4lhNpyFc.jpg'),
(115625, 8247, 'Please Like Me [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bfbxl2PZp3pVM0WPgtx7zijMHfX.jpg'),
(115626, 8247, 'Please Like Me [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9mlDmfkFXaO9u1mqTTmQFhQWPF.jpg'),
(115627, 8247, 'Please Like Me [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/prDpExuiV6He4zEq6k3grbgtIkM.jpg'),
(115628, 8247, 'Please Like Me [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7kVRD9EzboHFXmmP1y4jMHA7eYq.jpg'),
(115629, 8247, 'Please Like Me [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZ88TvzjNRA1o78SUkvEkCUo9Bu.jpg'),
(115630, 8248, 'Please Like Me [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qtHtfmXPbawEWWe8kNChiidKIs3.jpg'),
(115631, 8248, 'Please Like Me [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yGyE48mpf4pGj8TuEbAnCYTYmRF.jpg'),
(115632, 8248, 'Please Like Me [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dxIkWZoQ5A1rmMANP5Axw7eKeUM.jpg'),
(115633, 8248, 'Please Like Me [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/17MNqWayhPgbLk7SHqoZXO8lOv.jpg'),
(115634, 8248, 'Please Like Me [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mJD4aGGLtXnpA3E184BcpnUNHtO.jpg'),
(115635, 8248, 'Please Like Me [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wO9gPRQiiH7LioGK6oH1iUylstZ.jpg'),
(115636, 8248, 'Please Like Me [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/flD4tBsLChbGFldiUsoZh6IojeZ.jpg'),
(115637, 8248, 'Please Like Me [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fxK2Esna28TaTgU6Fej1wSeOIbk.jpg'),
(115638, 8248, 'Please Like Me [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lQJSpydkDJ7PfGgGB84CYEilPOu.jpg'),
(115639, 8249, 'Please Like Me [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7qX8CMGhGx2sN4T0lWU5Qzvd1L9.jpg'),
(115640, 8249, 'Please Like Me [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4sKQ3RDKlWmI8iCZHkafDUAx3SD.jpg'),
(115641, 8249, 'Please Like Me [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lRmFXrtKSi0vkVWYzDpNGI9AAjx.jpg'),
(115642, 8249, 'Please Like Me [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ihc3HKu487ZergTioFFD37sNFS.jpg'),
(115643, 8249, 'Please Like Me [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pXtzSdTspLTuIjv3J6YWIzUtqkj.jpg'),
(115644, 8249, 'Please Like Me [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zRoAAsUOAcExhPUPqPK41YU44eB.jpg'),
(115645, 8249, 'Please Like Me [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gLlHrON8wD4fz1CBuLd6s5OVxWj.jpg'),
(115646, 8249, 'Please Like Me [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xdf9mt8qtvwMn5eD1jrNJkVu2Sb.jpg'),
(115647, 8249, 'Please Like Me [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5TiDtGMPHwZb1wjOKwcoC9fPBi9.jpg'),
(115648, 8249, 'Please Like Me [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7xU2RqctfSFHV83cmrdzcelnSSE.jpg'),
(115649, 8250, 'Please Like Me [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y4DEvL5Cm7RG90dsEKmObRqPb7x.jpg'),
(115650, 8250, 'Please Like Me [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fVB62HgapbapNLT889w4egKX8Tf.jpg'),
(115651, 8250, 'Please Like Me [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zN6DBl7Z0dSXh69FgFYM6XRQdEk.jpg'),
(115652, 8250, 'Please Like Me [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gSLvFuEQ98SvKDhKtwHv2Yk4xGb.jpg'),
(115653, 8250, 'Please Like Me [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cXZIIgPv8WgjBIcqvfqkfG6uEKh.jpg'),
(115654, 8250, 'Please Like Me [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xzODpuQgov14b9MzLvK95qLQKby.jpg'),
(115655, 8251, 'Predadores do Mundo Animal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ayMA4Bl9V3yF82k4nA3oawjSpQS.jpg'),
(115656, 8251, 'Predadores do Mundo Animal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wKbxS7V5NQoVsOmtId9lRp3z0MP.jpg'),
(115657, 8251, 'Predadores do Mundo Animal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k06t8ElPBJuHtocH48n7mMSkshb.jpg'),
(115658, 8251, 'Predadores do Mundo Animal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mEKdE19X850e61f2zHKL82kjNGC.jpg'),
(115659, 8251, 'Predadores do Mundo Animal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5mSHwPwN9Yf0b5TdggnHmJ6XtqG.jpg'),
(115660, 8252, 'Redescobrindo o Amor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mgKCFeBNEM9J9PkPrSUo6j7Omm8.jpg'),
(115661, 8252, 'Redescobrindo o Amor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uRg4No6wlOGr6XxHkUcJekYiBL.jpg'),
(115662, 8252, 'Redescobrindo o Amor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7eAHXA4wjF5uxs3IHLxkNEOw2j.jpg'),
(115663, 8252, 'Redescobrindo o Amor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ekccuawCzZKJ60pml8wTGO1aSyE.jpg'),
(115664, 8252, 'Redescobrindo o Amor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aRc4lHU9LebX0V58NcsCbO0mys5.jpg'),
(115665, 8252, 'Redescobrindo o Amor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hZU6F07tFc1HzZAlMyLEF1dZpII.jpg'),
(115666, 8252, 'Redescobrindo o Amor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tkW9LZHUyjMTgG4vRFKklf01FhY.jpg'),
(115667, 8252, 'Redescobrindo o Amor [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hTxz88I3MknTu0THEVxcDeNv0OI.jpg'),
(115668, 8252, 'Redescobrindo o Amor [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8gFnq4lttgVnLwfzlmmHI1eeP5g.jpg'),
(115669, 8252, 'Redescobrindo o Amor [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5c0sKpxFHS7U2qMZFW0ohfanQjW.jpg'),
(115670, 8252, 'Redescobrindo o Amor [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1WKSnXTOkNlP3a1xhFp2t8vWrbt.jpg'),
(115671, 8252, 'Redescobrindo o Amor [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jHqvImzxb6n39ZPhYrKEN6t4C5D.jpg'),
(115672, 8253, 'Renai Flops [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nvfatOKTPNjK56tR8N5qjyAT6XZ.jpg'),
(115673, 8253, 'Renai Flops [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sriUbQuOQdo7lY5RFCSCW8MJaLk.jpg'),
(115674, 8253, 'Renai Flops [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/baAgumu7qutpZcDHGkIA0mocN21.jpg'),
(115675, 8253, 'Renai Flops [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2qQzTWJr2l3ePOIpqx9GSPE2xy.jpg'),
(115676, 8253, 'Renai Flops [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4rTp5WP0umsX99o9wZDlPyagnNj.jpg'),
(115677, 8253, 'Renai Flops [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/evaAAXJIK5FrKdPsoB2x0tWVvHx.jpg'),
(115678, 8253, 'Renai Flops [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5UoiOqKj4fcO6J65DhKjaVotwsi.jpg'),
(115679, 8253, 'Renai Flops [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCHgWHthH8M65spJvd4QL4UYOjB.jpg'),
(115680, 8253, 'Renai Flops [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c4YUVQZaTLlXtKWgyy40YmIEn8h.jpg'),
(115681, 8253, 'Renai Flops [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qqQiFXrP3FETPrKfOUkiiVXpHs0.jpg'),
(115682, 8253, 'Renai Flops [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mEkrxzO8x8lYp2H2pCM2wkx9onC.jpg'),
(115683, 8253, 'Renai Flops [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bsBKaEjenvUfXVFJ1e358gaxsXO.jpg'),
(115684, 8254, 'Rougo ni Sonaete Isekai de 8-manmai no Kinka wo Tamemasu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzmemUguCZAHJzSbxQpVts6watX.jpg'),
(115685, 8254, 'Rougo ni Sonaete Isekai de 8-manmai no Kinka wo Tamemasu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A91DlrV6dy5BJISnV676LP3y4hQ.jpg'),
(115686, 8254, 'Rougo ni Sonaete Isekai de 8-manmai no Kinka wo Tamemasu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTndFoYbb3S8AMCHWqNBwr0kLXv.jpg'),
(115687, 8254, 'Rougo ni Sonaete Isekai de 8-manmai no Kinka wo Tamemasu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1noebUA6zBxpfgnKmDIdyx1lFHe.jpg'),
(115688, 8254, 'Rougo ni Sonaete Isekai de 8-manmai no Kinka wo Tamemasu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9X8GMvqulDbOOS2MVwRAGkMQIaN.jpg'),
(115689, 8254, 'Rougo ni Sonaete Isekai de 8-manmai no Kinka wo Tamemasu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fQqYwnmWBex4wPb1QlQhiaqDrxW.jpg'),
(115690, 8254, 'Rougo ni Sonaete Isekai de 8-manmai no Kinka wo Tamemasu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hjOOYOs8WU4iW4IFgdmTkjIgsAa.jpg'),
(115691, 8254, 'Rougo ni Sonaete Isekai de 8-manmai no Kinka wo Tamemasu S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ni16DgLCE6HCrZj4N7GffHzeWVF.jpg'),
(115692, 8254, 'Rougo ni Sonaete Isekai de 8-manmai no Kinka wo Tamemasu S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/26e1dk6Pyv7tEaV50NZCndZBsi6.jpg'),
(115693, 8254, 'Rougo ni Sonaete Isekai de 8-manmai no Kinka wo Tamemasu S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJgJkJzLhcE70NkyyPqMLvCLLmw.jpg'),
(115694, 8254, 'Rougo ni Sonaete Isekai de 8-manmai no Kinka wo Tamemasu S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jxdLtUYRJuBm5KF2Lk9mUbGn5Le.jpg'),
(115695, 8254, 'Rougo ni Sonaete Isekai de 8-manmai no Kinka wo Tamemasu S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eYgcZuxw4GR3NQYwT1JF1WByvLt.jpg'),
(115696, 8255, 'The Changeling - Sombras de Nova York S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vTmSnogiEW8SjFUKOQPyIF2RtTl.jpg'),
(115697, 8255, 'The Changeling - Sombras de Nova York S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tib1A7DO5YGcO1RbaAKrabkTK7Q.jpg'),
(115698, 8255, 'The Changeling - Sombras de Nova York S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vwixjGSzTp2nmpY93LKNL6mYWX.jpg'),
(115699, 8255, 'The Changeling - Sombras de Nova York S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pIqxGcVj0B0WzOQvcpknKAwMTbx.jpg'),
(115700, 8255, 'The Changeling - Sombras de Nova York S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pIqxGcVj0B0WzOQvcpknKAwMTbx.jpg'),
(115701, 8255, 'The Changeling - Sombras de Nova York S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pIqxGcVj0B0WzOQvcpknKAwMTbx.jpg'),
(115702, 8255, 'The Changeling - Sombras de Nova York S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pIqxGcVj0B0WzOQvcpknKAwMTbx.jpg'),
(115703, 8255, 'The Changeling - Sombras de Nova York S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pIqxGcVj0B0WzOQvcpknKAwMTbx.jpg'),
(115704, 8256, 'The Great Pottery Throw Down S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Gnic4ySPg4DTnIKRy3cLF7vDBm.jpg'),
(115705, 8256, 'The Great Pottery Throw Down S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8gx30ApVJbSxXobRrj3ygvsY9oF.jpg'),
(115706, 8256, 'The Great Pottery Throw Down S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/prqvdvA0J4Di61hUoccZFRug3SQ.jpg'),
(115707, 8256, 'The Great Pottery Throw Down S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yr6KQUv3ecQk4j1P4QdlF78NImA.jpg'),
(115708, 8256, 'The Great Pottery Throw Down S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AbsTHVfjVx4aPoirihvPjirLkvI.jpg'),
(115709, 8256, 'The Great Pottery Throw Down S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rcwk66wQxJSL2F1bsgEZS3Dwmfk.jpg'),
(115710, 8256, 'The Great Pottery Throw Down S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCMO9WZ7qITqKkysf9Rr1vrucsq.jpg'),
(115711, 8256, 'The Great Pottery Throw Down S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9NNUcTOGUUklg6B4GNKjvGBqnOs.jpg'),
(115712, 8256, 'The Great Pottery Throw Down S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ChUkMrAHBzFCZ7WFG7XBm3gmzv.jpg'),
(115713, 8256, 'The Great Pottery Throw Down S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8qUJyQzSRHF0OtS9TaccwH86jC4.jpg'),
(115714, 8257, 'The Legend of Anle [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uTUOWqG0jUzCyPXLI49Xy238pui.jpg'),
(115715, 8257, 'The Legend of Anle [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2zUKeChGTg9ourlkhnpgOwW2CnS.jpg'),
(115716, 8257, 'The Legend of Anle [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bI7Ok9FuB7oydpGrTWbpwN2hSTs.jpg'),
(115717, 8257, 'The Legend of Anle [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hgRWidzfhFJR1q0cRTTUs7d3n1d.jpg'),
(115718, 8257, 'The Legend of Anle [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/edmp545djuaghmeC10g2CRzWoxQ.jpg'),
(115719, 8257, 'The Legend of Anle [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zcSH5qYcmf62wUHOqzrVLjmymXq.jpg'),
(115720, 8257, 'The Legend of Anle [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3ajAspyV5bIwdQxKRTuvgUH7Gb.jpg'),
(115721, 8257, 'The Legend of Anle [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QPi3n3IeSMn2rqmyc3LL5BdbF6.jpg'),
(115722, 8257, 'The Legend of Anle [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rj8br5bAP63aJ9EdaIzr3jATxET.jpg'),
(115723, 8257, 'The Legend of Anle [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gawZKl4KdNDJ6qkUeA4nXe19VqA.jpg'),
(115724, 8257, 'The Legend of Anle [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ezzgMftAwQwAPcdxJiYDDPFFxT4.jpg'),
(115725, 8257, 'The Legend of Anle [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bZlG9IlUW0ldeBRkV3tq77txkN3.jpg'),
(115726, 8257, 'The Legend of Anle [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/232140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zdhTcS5thlVirRBpyZQWPnYLoiQ.jpg'),
(115727, 8257, 'The Legend of Anle [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/232141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oGL4SI6kLWrLm5yMCEX7CAPCMkf.jpg'),
(115728, 8257, 'The Legend of Anle [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/232142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eS3rZfwdboZkPZAsDiCePUNyIZ9.jpg'),
(115729, 8257, 'The Legend of Anle [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/232143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c6osWY1aBaivwWBIcXH76CDtOPj.jpg'),
(115730, 8257, 'The Legend of Anle [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/232144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/beP4XQQ5SVRisGNGRVG1iJ1TV5s.jpg'),
(115731, 8257, 'The Legend of Anle [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/232145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5alrTRVcvqeS9BqILXUaonlF6zc.jpg'),
(115732, 8257, 'The Legend of Anle [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/232146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d8wJVCJQCdkcm1vd43q1FEEzYLC.jpg'),
(115733, 8257, 'The Legend of Anle [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/232147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJKmoBKj2OzUItLb4J41sg79udh.jpg'),
(115734, 8257, 'The Legend of Anle [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/232148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hNi9q28x79FrCe1BZb7VTIDtqoX.jpg'),
(115735, 8257, 'The Legend of Anle [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/232149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c6K8i0aMmN6fQLOvIYXoCJOq4sO.jpg'),
(115736, 8257, 'The Legend of Anle [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/232150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wYaqgqF1jvGKTr1wR4Knl0CEstz.jpg'),
(115737, 8257, 'The Legend of Anle [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/232151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1PAmlLIOAcw1wlULuxrVPu3PhRX.jpg'),
(115738, 8257, 'The Legend of Anle [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/232152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wxiuiAJTxar81EZ0xAK5vCBAwiO.jpg'),
(115739, 8257, 'The Legend of Anle [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/232153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmzh0ec76m57bTYK1kXwtlh7zi3.jpg'),
(115740, 8257, 'The Legend of Anle [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/232154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hs70pj5PRrf8hQa4Lo3NTkdSlx9.jpg'),
(115741, 8257, 'The Legend of Anle [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/232155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zb9hiaGzUoYFeQN4oMPqzvoIKQ3.jpg'),
(115742, 8257, 'The Legend of Anle [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/232156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lg76W11yMVXiDIAvaj2wCun9UVX.jpg'),
(115743, 8257, 'The Legend of Anle [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/232157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tmOJckzN7iUPzyP23OGIOBdHK1W.jpg'),
(115744, 8257, 'The Legend of Anle [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/232158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8UuHAg7AtOp3rmZ83DCrgHXFfSC.jpg'),
(115745, 8257, 'The Legend of Anle [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/232159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zG4BH29LrQM2sttCtmAsJbITdZx.jpg'),
(115746, 8257, 'The Legend of Anle [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/232160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8PWxGr7NsftviFj9m1VEgNaQrKd.jpg'),
(115747, 8257, 'The Legend of Anle [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/232161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5EEM9LhOZ3foILEtEUIs4P4DxM0.jpg'),
(115748, 8257, 'The Legend of Anle [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/232162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bVXjUc8SCv84ukNN4vlTk5DwVTS.jpg'),
(115749, 8257, 'The Legend of Anle [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/232163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l0wKaympmNRfV6LFkyswKpgU4Ec.jpg'),
(115750, 8257, 'The Legend of Anle [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/232164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4IUewMNm1jCEvtmxLrBMPVaTaIc.jpg'),
(115751, 8257, 'The Legend of Anle [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/232165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aYyOkMgiLpgNp07W1dh93RdZj9e.jpg'),
(115752, 8257, 'The Legend of Anle [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/232166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nFi12jDlT6vi4BkpFpcWiDqO1FA.jpg'),
(115753, 8258, 'The Winter King [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSnAg64f5gkt4avoLmLJuA2MI2i.jpg'),
(115754, 8258, 'The Winter King [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fYx5q9hPAmbDrWzsYUDhxZJnigC.jpg'),
(115755, 8258, 'The Winter King [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fYx5q9hPAmbDrWzsYUDhxZJnigC.jpg'),
(115756, 8258, 'The Winter King [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fYx5q9hPAmbDrWzsYUDhxZJnigC.jpg'),
(115757, 8258, 'The Winter King [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fYx5q9hPAmbDrWzsYUDhxZJnigC.jpg'),
(115758, 8258, 'The Winter King [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fYx5q9hPAmbDrWzsYUDhxZJnigC.jpg'),
(115759, 8258, 'The Winter King [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fYx5q9hPAmbDrWzsYUDhxZJnigC.jpg'),
(115760, 8258, 'The Winter King [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fYx5q9hPAmbDrWzsYUDhxZJnigC.jpg'),
(115761, 8258, 'The Winter King [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fYx5q9hPAmbDrWzsYUDhxZJnigC.jpg'),
(115762, 8258, 'The Winter King [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fYx5q9hPAmbDrWzsYUDhxZJnigC.jpg'),
(115763, 8259, 'Weak Hero Class 1 [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dsQAYb7pwroV4qi5k18Dr4VWEWA.jpg'),
(115764, 8259, 'Weak Hero Class 1 [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cctMDZ93Zkzw3WSEvA6WggLO2u3.jpg'),
(115765, 8259, 'Weak Hero Class 1 [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5jZ0XQpMwiMsQivDdjRBv8HwkcV.jpg'),
(115766, 8259, 'Weak Hero Class 1 [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b2re9wWf1QgY8tyPQJoKYUJH44K.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(115767, 8259, 'Weak Hero Class 1 [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o0rA1YDtr3DD25rvJg3BGlYXJTm.jpg'),
(115768, 8259, 'Weak Hero Class 1 [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2UdpZTY018CdYLcw7mVMnlkDDeh.jpg'),
(115769, 8259, 'Weak Hero Class 1 [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vWeAOwYMJ2BblvQ5iS3EKrpJMfr.jpg'),
(115770, 8259, 'Weak Hero Class 1 [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1BoOWh8ruTUL2rYbpUOQr6erU1V.jpg'),
(115771, 8260, 'Why R U? [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/232103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jGmE5cP63o6mEifuW0jyY0SZgIN.jpg'),
(115772, 8260, 'Why R U? [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/232104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t0CASO9dCml4gUOY3gao76TPDge.jpg'),
(115773, 8260, 'Why R U? [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/232105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7RGSBcWWR6tnUtQnO2U4g0wkm6A.jpg'),
(115774, 8260, 'Why R U? [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/232106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mzdgyfLImpgj2609MjgS9tAUDKO.jpg'),
(115775, 8260, 'Why R U? [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/232107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKNYBpHdqjdSV2u4Ov3Y04gZ84M.jpg'),
(115776, 8260, 'Why R U? [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/232108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6mtARGVrsFh4xjzwPv5RA0KHpEj.jpg'),
(115777, 8260, 'Why R U? [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/232109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uFaw9RUKanwY67kExMzXdjrWd5i.jpg'),
(115778, 8260, 'Why R U? [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/232110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wQDl1h1vYtpOeVeWSoJeyelt2p5.jpg'),
(115779, 8260, 'Why R U? [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/232111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2b20Ghjdi36QngoHhNT5jQDldPN.jpg'),
(115780, 8260, 'Why R U? [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/232112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iK2ccCSA45H0yeMP9YoWfA4iDHT.jpg'),
(115781, 8260, 'Why R U? [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/232113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nD4zndLMpkJU9E2EQJLjEMzZPnd.jpg'),
(115782, 8260, 'Why R U? [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/232114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mN9z64Ug52Q9OSGij23rcKRHB1b.jpg'),
(115783, 8260, 'Why R U? [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/232115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oNH3vRFDv7iNiS6c7nRiBVCR0Js.jpg'),
(115784, 8260, 'Why R U? [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/232116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sKS1XwEaareXoH6kuuKC1p0op2A.jpg'),
(115785, 8260, 'Why R U? [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/232117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sKS1XwEaareXoH6kuuKC1p0op2A.jpg'),
(115786, 8260, 'Why R U? [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/232118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sKS1XwEaareXoH6kuuKC1p0op2A.jpg'),
(115787, 8260, 'Why R U? [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/232119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sKS1XwEaareXoH6kuuKC1p0op2A.jpg'),
(115788, 8261, 'As Mil Vidas de Bernard Tapie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jqP43GHOt39b2YOr8yVlU6kuaep.jpg'),
(115789, 8261, 'As Mil Vidas de Bernard Tapie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jqP43GHOt39b2YOr8yVlU6kuaep.jpg'),
(115790, 8261, 'As Mil Vidas de Bernard Tapie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jqP43GHOt39b2YOr8yVlU6kuaep.jpg'),
(115791, 8261, 'As Mil Vidas de Bernard Tapie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jqP43GHOt39b2YOr8yVlU6kuaep.jpg'),
(115792, 8261, 'As Mil Vidas de Bernard Tapie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jqP43GHOt39b2YOr8yVlU6kuaep.jpg'),
(115793, 8261, 'As Mil Vidas de Bernard Tapie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jqP43GHOt39b2YOr8yVlU6kuaep.jpg'),
(115794, 8261, 'As Mil Vidas de Bernard Tapie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jqP43GHOt39b2YOr8yVlU6kuaep.jpg'),
(115795, 8262, 'Lutadores S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srsEAAt95Vqgcc2M9us4VMlr6cS.jpg'),
(115796, 8262, 'Lutadores S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srsEAAt95Vqgcc2M9us4VMlr6cS.jpg'),
(115797, 8262, 'Lutadores S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srsEAAt95Vqgcc2M9us4VMlr6cS.jpg'),
(115798, 8262, 'Lutadores S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srsEAAt95Vqgcc2M9us4VMlr6cS.jpg'),
(115799, 8262, 'Lutadores S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srsEAAt95Vqgcc2M9us4VMlr6cS.jpg'),
(115800, 8262, 'Lutadores S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srsEAAt95Vqgcc2M9us4VMlr6cS.jpg'),
(115801, 8262, 'Lutadores S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/srsEAAt95Vqgcc2M9us4VMlr6cS.jpg'),
(115802, 8263, 'Molly McGee e o Fantasma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/270266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115803, 8263, 'Molly McGee e o Fantasma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/270267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115804, 8263, 'Molly McGee e o Fantasma S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/270268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115805, 8263, 'Molly McGee e o Fantasma S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/270269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115806, 8263, 'Molly McGee e o Fantasma S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/270270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115807, 8263, 'Molly McGee e o Fantasma S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/270271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115808, 8263, 'Molly McGee e o Fantasma S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/270272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115809, 8263, 'Molly McGee e o Fantasma S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/270273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115810, 8263, 'Molly McGee e o Fantasma S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/270274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115811, 8263, 'Molly McGee e o Fantasma S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/270275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115812, 8263, 'Molly McGee e o Fantasma S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/270276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115813, 8263, 'Molly McGee e o Fantasma S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/270277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115814, 8263, 'Molly McGee e o Fantasma S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/270278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115815, 8263, 'Molly McGee e o Fantasma S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/270279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115816, 8263, 'Molly McGee e o Fantasma S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/270280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115817, 8263, 'Molly McGee e o Fantasma S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/270281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115818, 8263, 'Molly McGee e o Fantasma S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/270282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115819, 8263, 'Molly McGee e o Fantasma S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/270283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115820, 8263, 'Molly McGee e o Fantasma S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/270284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115821, 8263, 'Molly McGee e o Fantasma S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/270285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115822, 8264, 'Molly McGee e o Fantasma S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/270286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115823, 8264, 'Molly McGee e o Fantasma S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/270287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115824, 8264, 'Molly McGee e o Fantasma S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/270288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115825, 8264, 'Molly McGee e o Fantasma S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/270289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115826, 8264, 'Molly McGee e o Fantasma S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/270290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115827, 8264, 'Molly McGee e o Fantasma S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/270291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115828, 8264, 'Molly McGee e o Fantasma S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/270292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115829, 8264, 'Molly McGee e o Fantasma S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/270293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115830, 8264, 'Molly McGee e o Fantasma S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/270294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115831, 8264, 'Molly McGee e o Fantasma S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/270295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115832, 8264, 'Molly McGee e o Fantasma S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/270296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115833, 8264, 'Molly McGee e o Fantasma S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/270297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115834, 8264, 'Molly McGee e o Fantasma S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/270298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115835, 8264, 'Molly McGee e o Fantasma S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/270299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115836, 8264, 'Molly McGee e o Fantasma S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/270300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115837, 8264, 'Molly McGee e o Fantasma S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/270301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115838, 8264, 'Molly McGee e o Fantasma S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/270302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115839, 8264, 'Molly McGee e o Fantasma S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/270303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115840, 8264, 'Molly McGee e o Fantasma S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/270304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115841, 8264, 'Molly McGee e o Fantasma S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/331365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dzPOenKwe7dcCsCXGWWtYXBPKbO.jpg'),
(115842, 8265, 'Não Conte a Ninguém S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5a2gg35KSiesqcJwu3H8HZVpD16.jpg'),
(115843, 8265, 'Não Conte a Ninguém S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5a2gg35KSiesqcJwu3H8HZVpD16.jpg'),
(115844, 8265, 'Não Conte a Ninguém S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5a2gg35KSiesqcJwu3H8HZVpD16.jpg'),
(115845, 8265, 'Não Conte a Ninguém S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5a2gg35KSiesqcJwu3H8HZVpD16.jpg'),
(115846, 8265, 'Não Conte a Ninguém S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5a2gg35KSiesqcJwu3H8HZVpD16.jpg'),
(115847, 8266, 'O Mundo da Espionagem [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5iehCajknOIaSOjoJexwnVf2bV.jpg'),
(115848, 8266, 'O Mundo da Espionagem [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5iehCajknOIaSOjoJexwnVf2bV.jpg'),
(115849, 8266, 'O Mundo da Espionagem [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5iehCajknOIaSOjoJexwnVf2bV.jpg'),
(115850, 8266, 'O Mundo da Espionagem [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5iehCajknOIaSOjoJexwnVf2bV.jpg'),
(115851, 8266, 'O Mundo da Espionagem [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5iehCajknOIaSOjoJexwnVf2bV.jpg'),
(115852, 8266, 'O Mundo da Espionagem [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5iehCajknOIaSOjoJexwnVf2bV.jpg'),
(115853, 8266, 'O Mundo da Espionagem [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5iehCajknOIaSOjoJexwnVf2bV.jpg'),
(115854, 8266, 'O Mundo da Espionagem [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5iehCajknOIaSOjoJexwnVf2bV.jpg'),
(115855, 8267, 'The Walking Dead: Daryl Dixon [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdM24KINoAVK9wjCtDJCkdffEpc.jpg'),
(115856, 8267, 'The Walking Dead: Daryl Dixon [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdM24KINoAVK9wjCtDJCkdffEpc.jpg'),
(115857, 8267, 'The Walking Dead: Daryl Dixon [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdM24KINoAVK9wjCtDJCkdffEpc.jpg'),
(115858, 8267, 'The Walking Dead: Daryl Dixon [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdM24KINoAVK9wjCtDJCkdffEpc.jpg'),
(115859, 8267, 'The Walking Dead: Daryl Dixon [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdM24KINoAVK9wjCtDJCkdffEpc.jpg'),
(115860, 8267, 'The Walking Dead: Daryl Dixon [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdM24KINoAVK9wjCtDJCkdffEpc.jpg'),
(115861, 8268, 'The Walking Dead: Daryl Dixon [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdM24KINoAVK9wjCtDJCkdffEpc.jpg'),
(115862, 8268, 'The Walking Dead: Daryl Dixon [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdM24KINoAVK9wjCtDJCkdffEpc.jpg'),
(115863, 8268, 'The Walking Dead: Daryl Dixon [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdM24KINoAVK9wjCtDJCkdffEpc.jpg'),
(115864, 8268, 'The Walking Dead: Daryl Dixon [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/489925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdM24KINoAVK9wjCtDJCkdffEpc.jpg'),
(115865, 8268, 'The Walking Dead: Daryl Dixon [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/497707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdM24KINoAVK9wjCtDJCkdffEpc.jpg'),
(115866, 8268, 'The Walking Dead: Daryl Dixon [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/504510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdM24KINoAVK9wjCtDJCkdffEpc.jpg'),
(115867, 8269, 'The Walking Dead: Daryl Dixon [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/889650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdM24KINoAVK9wjCtDJCkdffEpc.jpg'),
(115868, 8269, 'The Walking Dead: Daryl Dixon [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/889651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdM24KINoAVK9wjCtDJCkdffEpc.jpg'),
(115869, 8269, 'The Walking Dead: Daryl Dixon [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/889652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdM24KINoAVK9wjCtDJCkdffEpc.jpg'),
(115870, 8269, 'The Walking Dead: Daryl Dixon [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/889653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdM24KINoAVK9wjCtDJCkdffEpc.jpg'),
(115871, 8269, 'The Walking Dead: Daryl Dixon [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/889654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdM24KINoAVK9wjCtDJCkdffEpc.jpg'),
(115872, 8270, 'Treadstone S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/231355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1qgtga389R88dR3dfxk2KAuAdJi.jpg'),
(115873, 8270, 'Treadstone S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/231356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vjE68xIS0aZtkHTNFITev3Z3i6o.jpg'),
(115874, 8270, 'Treadstone S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/231357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dTqPH81SjcW4JsnBbuHz5rlgxX6.jpg'),
(115875, 8270, 'Treadstone S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/231358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j2bXJhU9OaXBzJYFv7YwWrmmHXc.jpg'),
(115876, 8270, 'Treadstone S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/231359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wMDNKhmrGfz1y9JEXrIHBtNmn3U.jpg'),
(115877, 8270, 'Treadstone S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/231360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tnN8qZPqTxRWX6xDd0mZvJVNyTn.jpg'),
(115878, 8270, 'Treadstone S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/231361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ncQ6ghRD97wegJeHxSv3rnkbBeP.jpg'),
(115879, 8270, 'Treadstone S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/231362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ebDAl5p0v9sJliipsgByUpeHFo.jpg'),
(115880, 8270, 'Treadstone S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/231363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c96rDk5ja6qRjGm8oEhESV1Scyv.jpg'),
(115881, 8270, 'Treadstone S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/231364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvF1zVrgihvHFjM606JlwOcJcov.jpg'),
(115882, 8271, 'As Viúvas das Quintas-Feiras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ydD0j0dKALkODUwCUAl3xEfmWXT.jpg'),
(115883, 8271, 'As Viúvas das Quintas-Feiras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ydD0j0dKALkODUwCUAl3xEfmWXT.jpg'),
(115884, 8271, 'As Viúvas das Quintas-Feiras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ydD0j0dKALkODUwCUAl3xEfmWXT.jpg'),
(115885, 8271, 'As Viúvas das Quintas-Feiras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ydD0j0dKALkODUwCUAl3xEfmWXT.jpg'),
(115886, 8271, 'As Viúvas das Quintas-Feiras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ydD0j0dKALkODUwCUAl3xEfmWXT.jpg'),
(115887, 8271, 'As Viúvas das Quintas-Feiras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ydD0j0dKALkODUwCUAl3xEfmWXT.jpg'),
(115888, 8272, 'Crime Cruel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115889, 8272, 'Crime Cruel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115890, 8272, 'Crime Cruel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115891, 8272, 'Crime Cruel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115892, 8272, 'Crime Cruel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115893, 8272, 'Crime Cruel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115894, 8273, 'Crime Cruel S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115895, 8273, 'Crime Cruel S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115896, 8273, 'Crime Cruel S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115897, 8273, 'Crime Cruel S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115898, 8273, 'Crime Cruel S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115899, 8273, 'Crime Cruel S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115900, 8273, 'Crime Cruel S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115901, 8273, 'Crime Cruel S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115902, 8273, 'Crime Cruel S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115903, 8273, 'Crime Cruel S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115904, 8274, 'Crime Cruel S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115905, 8274, 'Crime Cruel S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115906, 8274, 'Crime Cruel S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115907, 8274, 'Crime Cruel S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115908, 8274, 'Crime Cruel S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115909, 8274, 'Crime Cruel S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115910, 8274, 'Crime Cruel S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115911, 8274, 'Crime Cruel S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115912, 8274, 'Crime Cruel S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115913, 8274, 'Crime Cruel S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115914, 8274, 'Crime Cruel S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115915, 8274, 'Crime Cruel S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115916, 8274, 'Crime Cruel S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115917, 8275, 'Crime Cruel S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115918, 8275, 'Crime Cruel S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115919, 8275, 'Crime Cruel S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115920, 8275, 'Crime Cruel S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115921, 8275, 'Crime Cruel S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115922, 8275, 'Crime Cruel S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115923, 8276, 'Crime Cruel S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115924, 8276, 'Crime Cruel S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115925, 8276, 'Crime Cruel S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115926, 8276, 'Crime Cruel S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115927, 8276, 'Crime Cruel S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115928, 8276, 'Crime Cruel S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115929, 8277, 'Crime Cruel S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115930, 8277, 'Crime Cruel S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115931, 8277, 'Crime Cruel S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115932, 8277, 'Crime Cruel S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115933, 8277, 'Crime Cruel S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115934, 8277, 'Crime Cruel S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115935, 8278, 'Crime Cruel S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115936, 8278, 'Crime Cruel S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115937, 8278, 'Crime Cruel S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115938, 8278, 'Crime Cruel S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115939, 8278, 'Crime Cruel S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115940, 8278, 'Crime Cruel S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115941, 8279, 'Crime Cruel S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/422370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115942, 8279, 'Crime Cruel S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/432518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115943, 8279, 'Crime Cruel S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/437079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115944, 8279, 'Crime Cruel S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/437080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115945, 8279, 'Crime Cruel S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/448214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115946, 8279, 'Crime Cruel S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/448215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115947, 8279, 'Crime Cruel S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/461623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115948, 8280, 'Crime Cruel S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/728353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115949, 8280, 'Crime Cruel S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/728354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115950, 8280, 'Crime Cruel S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/728355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115951, 8280, 'Crime Cruel S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/728356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115952, 8280, 'Crime Cruel S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/728357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115953, 8280, 'Crime Cruel S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/728358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115954, 8280, 'Crime Cruel S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/728359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115955, 8280, 'Crime Cruel S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/728360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115956, 8280, 'Crime Cruel S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/728361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys7l6zoWCiCqPSCSjlV1Sxs77jS.jpg'),
(115957, 8281, 'Do Caos ao Sonho com a Família Holmes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6u5dWC6xzOEBX1E9hdJBBOGyRgO.jpg'),
(115958, 8281, 'Do Caos ao Sonho com a Família Holmes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6u5dWC6xzOEBX1E9hdJBBOGyRgO.jpg'),
(115959, 8281, 'Do Caos ao Sonho com a Família Holmes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6u5dWC6xzOEBX1E9hdJBBOGyRgO.jpg'),
(115960, 8281, 'Do Caos ao Sonho com a Família Holmes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6u5dWC6xzOEBX1E9hdJBBOGyRgO.jpg'),
(115961, 8281, 'Do Caos ao Sonho com a Família Holmes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6u5dWC6xzOEBX1E9hdJBBOGyRgO.jpg'),
(115962, 8281, 'Do Caos ao Sonho com a Família Holmes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6u5dWC6xzOEBX1E9hdJBBOGyRgO.jpg'),
(115963, 8281, 'Do Caos ao Sonho com a Família Holmes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6u5dWC6xzOEBX1E9hdJBBOGyRgO.jpg'),
(115964, 8281, 'Do Caos ao Sonho com a Família Holmes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6u5dWC6xzOEBX1E9hdJBBOGyRgO.jpg'),
(115965, 8281, 'Do Caos ao Sonho com a Família Holmes S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6u5dWC6xzOEBX1E9hdJBBOGyRgO.jpg'),
(115966, 8281, 'Do Caos ao Sonho com a Família Holmes S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6u5dWC6xzOEBX1E9hdJBBOGyRgO.jpg'),
(115967, 8281, 'Do Caos ao Sonho com a Família Holmes S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/276660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6u5dWC6xzOEBX1E9hdJBBOGyRgO.jpg'),
(115968, 8281, 'Do Caos ao Sonho com a Família Holmes S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/276661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6u5dWC6xzOEBX1E9hdJBBOGyRgO.jpg'),
(115969, 8282, 'Do Caos ao Sonho com a Família Holmes S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/276662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6u5dWC6xzOEBX1E9hdJBBOGyRgO.jpg'),
(115970, 8282, 'Do Caos ao Sonho com a Família Holmes S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/276663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6u5dWC6xzOEBX1E9hdJBBOGyRgO.jpg'),
(115971, 8282, 'Do Caos ao Sonho com a Família Holmes S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/276664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6u5dWC6xzOEBX1E9hdJBBOGyRgO.jpg'),
(115972, 8282, 'Do Caos ao Sonho com a Família Holmes S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/281410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6u5dWC6xzOEBX1E9hdJBBOGyRgO.jpg'),
(115973, 8282, 'Do Caos ao Sonho com a Família Holmes S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/287717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6u5dWC6xzOEBX1E9hdJBBOGyRgO.jpg'),
(115974, 8282, 'Do Caos ao Sonho com a Família Holmes S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/295776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6u5dWC6xzOEBX1E9hdJBBOGyRgO.jpg'),
(115975, 8282, 'Do Caos ao Sonho com a Família Holmes S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/300587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6u5dWC6xzOEBX1E9hdJBBOGyRgO.jpg'),
(115976, 8282, 'Do Caos ao Sonho com a Família Holmes S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/312518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6u5dWC6xzOEBX1E9hdJBBOGyRgO.jpg'),
(115977, 8282, 'Do Caos ao Sonho com a Família Holmes S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/322915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6u5dWC6xzOEBX1E9hdJBBOGyRgO.jpg'),
(115978, 8283, 'Em Busca de um Chefe S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hrQGn6MyMYLEderEGs6TVtwH6Mk.jpg'),
(115979, 8283, 'Em Busca de um Chefe S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hrQGn6MyMYLEderEGs6TVtwH6Mk.jpg'),
(115980, 8283, 'Em Busca de um Chefe S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hrQGn6MyMYLEderEGs6TVtwH6Mk.jpg'),
(115981, 8283, 'Em Busca de um Chefe S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hrQGn6MyMYLEderEGs6TVtwH6Mk.jpg'),
(115982, 8283, 'Em Busca de um Chefe S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hrQGn6MyMYLEderEGs6TVtwH6Mk.jpg'),
(115983, 8283, 'Em Busca de um Chefe S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hrQGn6MyMYLEderEGs6TVtwH6Mk.jpg'),
(115984, 8283, 'Em Busca de um Chefe S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hrQGn6MyMYLEderEGs6TVtwH6Mk.jpg'),
(115985, 8283, 'Em Busca de um Chefe S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hrQGn6MyMYLEderEGs6TVtwH6Mk.jpg'),
(115986, 8283, 'Em Busca de um Chefe S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hrQGn6MyMYLEderEGs6TVtwH6Mk.jpg'),
(115987, 8283, 'Em Busca de um Chefe S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hrQGn6MyMYLEderEGs6TVtwH6Mk.jpg'),
(115988, 8283, 'Em Busca de um Chefe S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hrQGn6MyMYLEderEGs6TVtwH6Mk.jpg'),
(115989, 8283, 'Em Busca de um Chefe S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hrQGn6MyMYLEderEGs6TVtwH6Mk.jpg'),
(115990, 8284, 'O Ouro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8HNLXxJsdyu4Rg1TnF8pW4ZtN1W.jpg'),
(115991, 8284, 'O Ouro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8HNLXxJsdyu4Rg1TnF8pW4ZtN1W.jpg'),
(115992, 8284, 'O Ouro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8HNLXxJsdyu4Rg1TnF8pW4ZtN1W.jpg'),
(115993, 8284, 'O Ouro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8HNLXxJsdyu4Rg1TnF8pW4ZtN1W.jpg'),
(115994, 8284, 'O Ouro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8HNLXxJsdyu4Rg1TnF8pW4ZtN1W.jpg'),
(115995, 8284, 'O Ouro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8HNLXxJsdyu4Rg1TnF8pW4ZtN1W.jpg'),
(115996, 8285, 'Os Experientes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8fxX7f0AmaCB3zimdghO05Khp8Q.jpg'),
(115997, 8285, 'Os Experientes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8fxX7f0AmaCB3zimdghO05Khp8Q.jpg'),
(115998, 8285, 'Os Experientes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8fxX7f0AmaCB3zimdghO05Khp8Q.jpg'),
(115999, 8285, 'Os Experientes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8fxX7f0AmaCB3zimdghO05Khp8Q.jpg'),
(116000, 8285, 'Os Experientes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8fxX7f0AmaCB3zimdghO05Khp8Q.jpg'),
(116001, 8285, 'Os Experientes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8fxX7f0AmaCB3zimdghO05Khp8Q.jpg'),
(116002, 8285, 'Os Experientes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8fxX7f0AmaCB3zimdghO05Khp8Q.jpg'),
(116003, 8286, 'The Rising: Buscando Meu Assassino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2RtjnbW13RhT9X93QuhxViTaTzx.jpg'),
(116004, 8286, 'The Rising: Buscando Meu Assassino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2RtjnbW13RhT9X93QuhxViTaTzx.jpg'),
(116005, 8286, 'The Rising: Buscando Meu Assassino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2RtjnbW13RhT9X93QuhxViTaTzx.jpg'),
(116006, 8286, 'The Rising: Buscando Meu Assassino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2RtjnbW13RhT9X93QuhxViTaTzx.jpg'),
(116007, 8286, 'The Rising: Buscando Meu Assassino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2RtjnbW13RhT9X93QuhxViTaTzx.jpg'),
(116008, 8286, 'The Rising: Buscando Meu Assassino S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2RtjnbW13RhT9X93QuhxViTaTzx.jpg'),
(116009, 8286, 'The Rising: Buscando Meu Assassino S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2RtjnbW13RhT9X93QuhxViTaTzx.jpg'),
(116010, 8286, 'The Rising: Buscando Meu Assassino S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2RtjnbW13RhT9X93QuhxViTaTzx.jpg'),
(116011, 8287, 'Um Dia de Chef S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116012, 8287, 'Um Dia de Chef S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116013, 8287, 'Um Dia de Chef S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116014, 8287, 'Um Dia de Chef S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116015, 8287, 'Um Dia de Chef S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116016, 8287, 'Um Dia de Chef S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116017, 8287, 'Um Dia de Chef S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116018, 8287, 'Um Dia de Chef S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116019, 8287, 'Um Dia de Chef S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116020, 8287, 'Um Dia de Chef S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116021, 8287, 'Um Dia de Chef S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116022, 8287, 'Um Dia de Chef S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(116023, 8287, 'Um Dia de Chef S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116024, 8288, 'Um Dia de Chef S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116025, 8288, 'Um Dia de Chef S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116026, 8288, 'Um Dia de Chef S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116027, 8288, 'Um Dia de Chef S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116028, 8288, 'Um Dia de Chef S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116029, 8288, 'Um Dia de Chef S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116030, 8288, 'Um Dia de Chef S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116031, 8288, 'Um Dia de Chef S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116032, 8288, 'Um Dia de Chef S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116033, 8288, 'Um Dia de Chef S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116034, 8288, 'Um Dia de Chef S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116035, 8288, 'Um Dia de Chef S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116036, 8288, 'Um Dia de Chef S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116037, 8289, 'Um Dia de Chef S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116038, 8289, 'Um Dia de Chef S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116039, 8289, 'Um Dia de Chef S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116040, 8289, 'Um Dia de Chef S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116041, 8289, 'Um Dia de Chef S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116042, 8289, 'Um Dia de Chef S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116043, 8289, 'Um Dia de Chef S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116044, 8289, 'Um Dia de Chef S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116045, 8289, 'Um Dia de Chef S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116046, 8289, 'Um Dia de Chef S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116047, 8289, 'Um Dia de Chef S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116048, 8289, 'Um Dia de Chef S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116049, 8289, 'Um Dia de Chef S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116050, 8290, 'Um Dia de Chef S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116051, 8290, 'Um Dia de Chef S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116052, 8290, 'Um Dia de Chef S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116053, 8290, 'Um Dia de Chef S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116054, 8290, 'Um Dia de Chef S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116055, 8290, 'Um Dia de Chef S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116056, 8290, 'Um Dia de Chef S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116057, 8290, 'Um Dia de Chef S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116058, 8290, 'Um Dia de Chef S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116059, 8290, 'Um Dia de Chef S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116060, 8290, 'Um Dia de Chef S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116061, 8290, 'Um Dia de Chef S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116062, 8290, 'Um Dia de Chef S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/35uNIdtJfO6cBqkD0qfdTaFoJB9.jpg'),
(116063, 8291, 'Animais de Perto com Bertie Gregory [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fRFaLFHuaQFGQWKOn31J5QilmJs.jpg'),
(116064, 8291, 'Animais de Perto com Bertie Gregory [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fRFaLFHuaQFGQWKOn31J5QilmJs.jpg'),
(116065, 8291, 'Animais de Perto com Bertie Gregory [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fRFaLFHuaQFGQWKOn31J5QilmJs.jpg'),
(116066, 8291, 'Animais de Perto com Bertie Gregory [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fRFaLFHuaQFGQWKOn31J5QilmJs.jpg'),
(116067, 8291, 'Animais de Perto com Bertie Gregory [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fRFaLFHuaQFGQWKOn31J5QilmJs.jpg'),
(116068, 8291, 'Animais de Perto com Bertie Gregory [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fRFaLFHuaQFGQWKOn31J5QilmJs.jpg'),
(116069, 8292, 'Blood [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17qv1NhAcz9ti9CPsqRbLkgGewL.jpg'),
(116070, 8292, 'Blood [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17qv1NhAcz9ti9CPsqRbLkgGewL.jpg'),
(116071, 8292, 'Blood [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17qv1NhAcz9ti9CPsqRbLkgGewL.jpg'),
(116072, 8292, 'Blood [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17qv1NhAcz9ti9CPsqRbLkgGewL.jpg'),
(116073, 8292, 'Blood [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17qv1NhAcz9ti9CPsqRbLkgGewL.jpg'),
(116074, 8292, 'Blood [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17qv1NhAcz9ti9CPsqRbLkgGewL.jpg'),
(116075, 8292, 'Blood [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17qv1NhAcz9ti9CPsqRbLkgGewL.jpg'),
(116076, 8292, 'Blood [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17qv1NhAcz9ti9CPsqRbLkgGewL.jpg'),
(116077, 8292, 'Blood [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17qv1NhAcz9ti9CPsqRbLkgGewL.jpg'),
(116078, 8292, 'Blood [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17qv1NhAcz9ti9CPsqRbLkgGewL.jpg'),
(116079, 8292, 'Blood [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17qv1NhAcz9ti9CPsqRbLkgGewL.jpg'),
(116080, 8292, 'Blood [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17qv1NhAcz9ti9CPsqRbLkgGewL.jpg'),
(116081, 8292, 'Blood [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17qv1NhAcz9ti9CPsqRbLkgGewL.jpg'),
(116082, 8292, 'Blood [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17qv1NhAcz9ti9CPsqRbLkgGewL.jpg'),
(116083, 8292, 'Blood [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17qv1NhAcz9ti9CPsqRbLkgGewL.jpg'),
(116084, 8292, 'Blood [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/237228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17qv1NhAcz9ti9CPsqRbLkgGewL.jpg'),
(116085, 8292, 'Blood [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/237229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17qv1NhAcz9ti9CPsqRbLkgGewL.jpg'),
(116086, 8292, 'Blood [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/237230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17qv1NhAcz9ti9CPsqRbLkgGewL.jpg'),
(116087, 8292, 'Blood [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/237231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17qv1NhAcz9ti9CPsqRbLkgGewL.jpg'),
(116088, 8292, 'Blood [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/237232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17qv1NhAcz9ti9CPsqRbLkgGewL.jpg'),
(116089, 8293, 'I Can Hear Your Voice [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqPxjad5RDqz9JGcLSUYfqcKQjx.jpg'),
(116090, 8293, 'I Can Hear Your Voice [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqPxjad5RDqz9JGcLSUYfqcKQjx.jpg'),
(116091, 8293, 'I Can Hear Your Voice [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqPxjad5RDqz9JGcLSUYfqcKQjx.jpg'),
(116092, 8293, 'I Can Hear Your Voice [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqPxjad5RDqz9JGcLSUYfqcKQjx.jpg'),
(116093, 8293, 'I Can Hear Your Voice [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqPxjad5RDqz9JGcLSUYfqcKQjx.jpg'),
(116094, 8293, 'I Can Hear Your Voice [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqPxjad5RDqz9JGcLSUYfqcKQjx.jpg'),
(116095, 8293, 'I Can Hear Your Voice [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqPxjad5RDqz9JGcLSUYfqcKQjx.jpg'),
(116096, 8293, 'I Can Hear Your Voice [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqPxjad5RDqz9JGcLSUYfqcKQjx.jpg'),
(116097, 8293, 'I Can Hear Your Voice [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqPxjad5RDqz9JGcLSUYfqcKQjx.jpg'),
(116098, 8293, 'I Can Hear Your Voice [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqPxjad5RDqz9JGcLSUYfqcKQjx.jpg'),
(116099, 8293, 'I Can Hear Your Voice [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqPxjad5RDqz9JGcLSUYfqcKQjx.jpg'),
(116100, 8293, 'I Can Hear Your Voice [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqPxjad5RDqz9JGcLSUYfqcKQjx.jpg'),
(116101, 8293, 'I Can Hear Your Voice [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqPxjad5RDqz9JGcLSUYfqcKQjx.jpg'),
(116102, 8293, 'I Can Hear Your Voice [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqPxjad5RDqz9JGcLSUYfqcKQjx.jpg'),
(116103, 8293, 'I Can Hear Your Voice [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqPxjad5RDqz9JGcLSUYfqcKQjx.jpg'),
(116104, 8293, 'I Can Hear Your Voice [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/237168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqPxjad5RDqz9JGcLSUYfqcKQjx.jpg'),
(116105, 8293, 'I Can Hear Your Voice [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/237169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqPxjad5RDqz9JGcLSUYfqcKQjx.jpg'),
(116106, 8293, 'I Can Hear Your Voice [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/237170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fqPxjad5RDqz9JGcLSUYfqcKQjx.jpg'),
(116107, 8294, 'Mad Dog [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CSKC6UCRt7G1l9Y0aYgKBM6W0M.jpg'),
(116108, 8294, 'Mad Dog [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CSKC6UCRt7G1l9Y0aYgKBM6W0M.jpg'),
(116109, 8294, 'Mad Dog [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CSKC6UCRt7G1l9Y0aYgKBM6W0M.jpg'),
(116110, 8294, 'Mad Dog [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CSKC6UCRt7G1l9Y0aYgKBM6W0M.jpg'),
(116111, 8294, 'Mad Dog [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CSKC6UCRt7G1l9Y0aYgKBM6W0M.jpg'),
(116112, 8294, 'Mad Dog [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CSKC6UCRt7G1l9Y0aYgKBM6W0M.jpg'),
(116113, 8294, 'Mad Dog [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CSKC6UCRt7G1l9Y0aYgKBM6W0M.jpg'),
(116114, 8294, 'Mad Dog [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CSKC6UCRt7G1l9Y0aYgKBM6W0M.jpg'),
(116115, 8294, 'Mad Dog [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CSKC6UCRt7G1l9Y0aYgKBM6W0M.jpg'),
(116116, 8294, 'Mad Dog [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CSKC6UCRt7G1l9Y0aYgKBM6W0M.jpg'),
(116117, 8294, 'Mad Dog [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CSKC6UCRt7G1l9Y0aYgKBM6W0M.jpg'),
(116118, 8294, 'Mad Dog [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CSKC6UCRt7G1l9Y0aYgKBM6W0M.jpg'),
(116119, 8294, 'Mad Dog [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CSKC6UCRt7G1l9Y0aYgKBM6W0M.jpg'),
(116120, 8294, 'Mad Dog [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CSKC6UCRt7G1l9Y0aYgKBM6W0M.jpg'),
(116121, 8294, 'Mad Dog [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CSKC6UCRt7G1l9Y0aYgKBM6W0M.jpg'),
(116122, 8294, 'Mad Dog [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/237152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8CSKC6UCRt7G1l9Y0aYgKBM6W0M.jpg'),
(116123, 8295, 'My Name is Kim Sam Soon [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pcCmzOSn2vfbo6gmGc4n5X4KMTj.jpg'),
(116124, 8295, 'My Name is Kim Sam Soon [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pcCmzOSn2vfbo6gmGc4n5X4KMTj.jpg'),
(116125, 8295, 'My Name is Kim Sam Soon [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pcCmzOSn2vfbo6gmGc4n5X4KMTj.jpg'),
(116126, 8295, 'My Name is Kim Sam Soon [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pcCmzOSn2vfbo6gmGc4n5X4KMTj.jpg'),
(116127, 8295, 'My Name is Kim Sam Soon [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pcCmzOSn2vfbo6gmGc4n5X4KMTj.jpg'),
(116128, 8295, 'My Name is Kim Sam Soon [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pcCmzOSn2vfbo6gmGc4n5X4KMTj.jpg'),
(116129, 8295, 'My Name is Kim Sam Soon [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pcCmzOSn2vfbo6gmGc4n5X4KMTj.jpg'),
(116130, 8295, 'My Name is Kim Sam Soon [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pcCmzOSn2vfbo6gmGc4n5X4KMTj.jpg'),
(116131, 8295, 'My Name is Kim Sam Soon [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pcCmzOSn2vfbo6gmGc4n5X4KMTj.jpg'),
(116132, 8295, 'My Name is Kim Sam Soon [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pcCmzOSn2vfbo6gmGc4n5X4KMTj.jpg'),
(116133, 8295, 'My Name is Kim Sam Soon [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pcCmzOSn2vfbo6gmGc4n5X4KMTj.jpg'),
(116134, 8295, 'My Name is Kim Sam Soon [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pcCmzOSn2vfbo6gmGc4n5X4KMTj.jpg'),
(116135, 8295, 'My Name is Kim Sam Soon [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pcCmzOSn2vfbo6gmGc4n5X4KMTj.jpg'),
(116136, 8295, 'My Name is Kim Sam Soon [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pcCmzOSn2vfbo6gmGc4n5X4KMTj.jpg'),
(116137, 8295, 'My Name is Kim Sam Soon [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pcCmzOSn2vfbo6gmGc4n5X4KMTj.jpg'),
(116138, 8295, 'My Name is Kim Sam Soon [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/237136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pcCmzOSn2vfbo6gmGc4n5X4KMTj.jpg'),
(116139, 8296, 'One More Happy Ending [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2oqc4u0O8BqNLNS2EtBiPUUFq7.jpg'),
(116140, 8296, 'One More Happy Ending [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2oqc4u0O8BqNLNS2EtBiPUUFq7.jpg'),
(116141, 8296, 'One More Happy Ending [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2oqc4u0O8BqNLNS2EtBiPUUFq7.jpg'),
(116142, 8296, 'One More Happy Ending [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2oqc4u0O8BqNLNS2EtBiPUUFq7.jpg'),
(116143, 8296, 'One More Happy Ending [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2oqc4u0O8BqNLNS2EtBiPUUFq7.jpg'),
(116144, 8296, 'One More Happy Ending [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2oqc4u0O8BqNLNS2EtBiPUUFq7.jpg'),
(116145, 8296, 'One More Happy Ending [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2oqc4u0O8BqNLNS2EtBiPUUFq7.jpg'),
(116146, 8296, 'One More Happy Ending [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2oqc4u0O8BqNLNS2EtBiPUUFq7.jpg'),
(116147, 8296, 'One More Happy Ending [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2oqc4u0O8BqNLNS2EtBiPUUFq7.jpg'),
(116148, 8296, 'One More Happy Ending [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2oqc4u0O8BqNLNS2EtBiPUUFq7.jpg'),
(116149, 8296, 'One More Happy Ending [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2oqc4u0O8BqNLNS2EtBiPUUFq7.jpg'),
(116150, 8296, 'One More Happy Ending [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2oqc4u0O8BqNLNS2EtBiPUUFq7.jpg'),
(116151, 8296, 'One More Happy Ending [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2oqc4u0O8BqNLNS2EtBiPUUFq7.jpg'),
(116152, 8296, 'One More Happy Ending [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2oqc4u0O8BqNLNS2EtBiPUUFq7.jpg'),
(116153, 8296, 'One More Happy Ending [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2oqc4u0O8BqNLNS2EtBiPUUFq7.jpg'),
(116154, 8296, 'One More Happy Ending [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/237114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2oqc4u0O8BqNLNS2EtBiPUUFq7.jpg'),
(116155, 8297, 'Patrulha do Rio Han [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMzeqFvhaqZMCwuVuDSMI6wwOcG.jpg'),
(116156, 8297, 'Patrulha do Rio Han [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMzeqFvhaqZMCwuVuDSMI6wwOcG.jpg'),
(116157, 8297, 'Patrulha do Rio Han [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMzeqFvhaqZMCwuVuDSMI6wwOcG.jpg'),
(116158, 8297, 'Patrulha do Rio Han [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMzeqFvhaqZMCwuVuDSMI6wwOcG.jpg'),
(116159, 8297, 'Patrulha do Rio Han [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMzeqFvhaqZMCwuVuDSMI6wwOcG.jpg'),
(116160, 8297, 'Patrulha do Rio Han [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMzeqFvhaqZMCwuVuDSMI6wwOcG.jpg'),
(116161, 8298, 'Pinóquio [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qqB4ftImSYUVAhreLeO8TY0FkDX.jpg'),
(116162, 8298, 'Pinóquio [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qqB4ftImSYUVAhreLeO8TY0FkDX.jpg'),
(116163, 8298, 'Pinóquio [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qqB4ftImSYUVAhreLeO8TY0FkDX.jpg'),
(116164, 8298, 'Pinóquio [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qqB4ftImSYUVAhreLeO8TY0FkDX.jpg'),
(116165, 8298, 'Pinóquio [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qqB4ftImSYUVAhreLeO8TY0FkDX.jpg'),
(116166, 8298, 'Pinóquio [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qqB4ftImSYUVAhreLeO8TY0FkDX.jpg'),
(116167, 8298, 'Pinóquio [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qqB4ftImSYUVAhreLeO8TY0FkDX.jpg'),
(116168, 8298, 'Pinóquio [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qqB4ftImSYUVAhreLeO8TY0FkDX.jpg'),
(116169, 8298, 'Pinóquio [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qqB4ftImSYUVAhreLeO8TY0FkDX.jpg'),
(116170, 8298, 'Pinóquio [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qqB4ftImSYUVAhreLeO8TY0FkDX.jpg'),
(116171, 8298, 'Pinóquio [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qqB4ftImSYUVAhreLeO8TY0FkDX.jpg'),
(116172, 8298, 'Pinóquio [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qqB4ftImSYUVAhreLeO8TY0FkDX.jpg'),
(116173, 8298, 'Pinóquio [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qqB4ftImSYUVAhreLeO8TY0FkDX.jpg'),
(116174, 8298, 'Pinóquio [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qqB4ftImSYUVAhreLeO8TY0FkDX.jpg'),
(116175, 8298, 'Pinóquio [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qqB4ftImSYUVAhreLeO8TY0FkDX.jpg'),
(116176, 8298, 'Pinóquio [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qqB4ftImSYUVAhreLeO8TY0FkDX.jpg'),
(116177, 8298, 'Pinóquio [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qqB4ftImSYUVAhreLeO8TY0FkDX.jpg'),
(116178, 8298, 'Pinóquio [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qqB4ftImSYUVAhreLeO8TY0FkDX.jpg'),
(116179, 8298, 'Pinóquio [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/236462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qqB4ftImSYUVAhreLeO8TY0FkDX.jpg'),
(116180, 8298, 'Pinóquio [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/236463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qqB4ftImSYUVAhreLeO8TY0FkDX.jpg'),
(116181, 8299, 'Traição: O Marido Perfeito [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u0lKzeEFZgePWK3KVpNhOF8q3zp.jpg'),
(116182, 8299, 'Traição: O Marido Perfeito [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u0lKzeEFZgePWK3KVpNhOF8q3zp.jpg'),
(116183, 8299, 'Traição: O Marido Perfeito [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u0lKzeEFZgePWK3KVpNhOF8q3zp.jpg'),
(116184, 8300, 'Vigarista Profissional [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1kdHRTOdTeN9BJvpBRToJXa8CA.jpg'),
(116185, 8300, 'Vigarista Profissional [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1kdHRTOdTeN9BJvpBRToJXa8CA.jpg'),
(116186, 8300, 'Vigarista Profissional [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1kdHRTOdTeN9BJvpBRToJXa8CA.jpg'),
(116187, 8300, 'Vigarista Profissional [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1kdHRTOdTeN9BJvpBRToJXa8CA.jpg'),
(116188, 8300, 'Vigarista Profissional [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1kdHRTOdTeN9BJvpBRToJXa8CA.jpg'),
(116189, 8300, 'Vigarista Profissional [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1kdHRTOdTeN9BJvpBRToJXa8CA.jpg'),
(116190, 8300, 'Vigarista Profissional [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1kdHRTOdTeN9BJvpBRToJXa8CA.jpg'),
(116191, 8300, 'Vigarista Profissional [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1kdHRTOdTeN9BJvpBRToJXa8CA.jpg'),
(116192, 8301, 'Turismo Selvagem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yz8WdZMBwQ0g8bqsXbxXWbsktHn.jpg'),
(116193, 8301, 'Turismo Selvagem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0hTgVrjtHZkIPF45EGILmPXxWz.jpg'),
(116194, 8301, 'Turismo Selvagem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h0Zs7BssDEMbGzdIA7hJTXDJa7t.jpg'),
(116195, 8301, 'Turismo Selvagem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJgnLpjJHk6CvhULD2Hbrk12FJR.jpg'),
(116196, 8301, 'Turismo Selvagem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/teuQmH1OGBCMLpzpwIvWjVYsReV.jpg'),
(116197, 8301, 'Turismo Selvagem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9RCJL9mQ0LTZtuKCBWelWvaAUB3.jpg'),
(116198, 8302, 'Caçadores de Demônios S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7aTEpb6CR4w1GyhwuaBKO9ZIwS3.jpg'),
(116199, 8302, 'Caçadores de Demônios S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cFP4rtuhIa1T39toYIDwoTP405h.jpg'),
(116200, 8302, 'Caçadores de Demônios S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v2jQYm3YGy8J6wBs8bLDDqIPSnB.jpg'),
(116201, 8302, 'Caçadores de Demônios S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qCbz0EWatMu3JRztZEhnPh8PWCR.jpg'),
(116202, 8302, 'Caçadores de Demônios S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4tMQmnmOnVcMj6ugLPq7CGlbzn7.jpg'),
(116203, 8302, 'Caçadores de Demônios S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOQ2t8MJOuLsiXc3fOYAhglwkoz.jpg'),
(116204, 8302, 'Caçadores de Demônios S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/42jS2VAOxzOj1XmXDInGiwLeOCN.jpg'),
(116205, 8302, 'Caçadores de Demônios S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2DVYOqareyqHaTd3oDZzFP1G2Ga.jpg'),
(116206, 8302, 'Caçadores de Demônios S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eI9qCZsbprmtdnQlT7LgCZEtVO2.jpg'),
(116207, 8302, 'Caçadores de Demônios S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qfrWQRrVg9XQOJSyqKKnTFbhQi8.jpg'),
(116208, 8302, 'Caçadores de Demônios S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kS2wrX3B9U7lbI02wqhjbki0E8s.jpg'),
(116209, 8302, 'Caçadores de Demônios S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfOwBAXUgGGFVv2sJNS1B86OdlC.jpg'),
(116210, 8302, 'Caçadores de Demônios S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/253973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AefZgDuPQMApKwUCCZlkN10e9J5.jpg'),
(116211, 8302, 'Caçadores de Demônios S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/253974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oWaWnHTMI4TdCiTYF50st5zVUTo.jpg'),
(116212, 8302, 'Caçadores de Demônios S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/253975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pmrKEyoxgGIB0WFuLF0gho0FxRm.jpg'),
(116213, 8302, 'Caçadores de Demônios S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/253976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bc4S9kPszX3AylwaAL2OANqlr6D.jpg'),
(116214, 8303, 'Caçadores de Demônios S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0PThW9zC8QTASAQvHn4pKzABey.jpg'),
(116215, 8303, 'Caçadores de Demônios S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Y9WZyHPtBWZKmYcazr4np0EVhn.jpg'),
(116216, 8303, 'Caçadores de Demônios S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p9FGjrpNNJRWLAHxqhSNgTAeeqQ.jpg'),
(116217, 8303, 'Caçadores de Demônios S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vT4fBZfl9GRKQsC8hdee8LQYYnJ.jpg'),
(116218, 8303, 'Caçadores de Demônios S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBsY8wjU2MWxMJPxdi3ynkD2wuN.jpg'),
(116219, 8303, 'Caçadores de Demônios S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3KQ1PQNLuUI1VBNAtYqpi6duUU.jpg'),
(116220, 8303, 'Caçadores de Demônios S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3mtxPqhz1aVgVadmajnApQoMnXW.jpg'),
(116221, 8303, 'Caçadores de Demônios S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q2Qsta8VOHRHhggSQmKJaRynoJM.jpg'),
(116222, 8303, 'Caçadores de Demônios S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qyf8Wws56fXbtrDYH9PqQhjo0qQ.jpg'),
(116223, 8303, 'Caçadores de Demônios S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fW2tFliDiWVq19TCrquf3fLywlN.jpg'),
(116224, 8303, 'Caçadores de Demônios S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tHCGJtxiciVRvxSqKErTH5cjoO7.jpg'),
(116225, 8303, 'Caçadores de Demônios S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8RQNWqu9YkXEyN5whV4rz3AlqYe.jpg'),
(116226, 8304, 'Fora da Bolha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hfLwkbbiPqwmQDPkCNrOy37JAoC.jpg'),
(116227, 8304, 'Fora da Bolha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6tRLic2V5FbBujpxLRlc4msoZ9m.jpg'),
(116228, 8304, 'Fora da Bolha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mk5a15QrHEESIoiqWl76iSCpgw6.jpg'),
(116229, 8304, 'Fora da Bolha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ebbpn6xvz2f0YrOJKvSqAyqejBr.jpg'),
(116230, 8304, 'Fora da Bolha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/isE57Dt2OguK8joL2uFA9ofG0ET.jpg'),
(116231, 8304, 'Fora da Bolha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iIhtXE5dJrhcEKXqEY3yFQ58Mtz.jpg'),
(116232, 8305, 'Match nas Estrelas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eLlF5Vqd5o35baPWrWXXh0z04Vz.jpg'),
(116233, 8305, 'Match nas Estrelas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eLlF5Vqd5o35baPWrWXXh0z04Vz.jpg'),
(116234, 8305, 'Match nas Estrelas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eLlF5Vqd5o35baPWrWXXh0z04Vz.jpg'),
(116235, 8305, 'Match nas Estrelas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eLlF5Vqd5o35baPWrWXXh0z04Vz.jpg'),
(116236, 8305, 'Match nas Estrelas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eLlF5Vqd5o35baPWrWXXh0z04Vz.jpg'),
(116237, 8305, 'Match nas Estrelas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eLlF5Vqd5o35baPWrWXXh0z04Vz.jpg'),
(116238, 8305, 'Match nas Estrelas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eLlF5Vqd5o35baPWrWXXh0z04Vz.jpg'),
(116239, 8305, 'Match nas Estrelas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eLlF5Vqd5o35baPWrWXXh0z04Vz.jpg'),
(116240, 8305, 'Match nas Estrelas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eLlF5Vqd5o35baPWrWXXh0z04Vz.jpg'),
(116241, 8305, 'Match nas Estrelas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eLlF5Vqd5o35baPWrWXXh0z04Vz.jpg'),
(116242, 8305, 'Match nas Estrelas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eLlF5Vqd5o35baPWrWXXh0z04Vz.jpg'),
(116243, 8305, 'Match nas Estrelas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eLlF5Vqd5o35baPWrWXXh0z04Vz.jpg'),
(116244, 8306, 'Tudo Por Um Like S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u8pB6TzhWi7sKvbTBu9Vrvfv56o.jpg'),
(116245, 8306, 'Tudo Por Um Like S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zjVpOsBJ29k12ZdTcMzMXf3Xk6K.jpg'),
(116246, 8306, 'Tudo Por Um Like S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lJWCyzHPzuB9gMEENXnEJriFrV9.jpg'),
(116247, 8306, 'Tudo Por Um Like S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ikpkp37Kr3UuZLQG3MRrOQ0Avg.jpg'),
(116248, 8306, 'Tudo Por Um Like S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pwaBqRoLk6QoRIrlYxdfhjATiyr.jpg'),
(116249, 8306, 'Tudo Por Um Like S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ifzuPsDqmx2loqVtMQhjvUoToPq.jpg'),
(116250, 8306, 'Tudo Por Um Like S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/koCVPkAYwaTWecopQRMxF6DeQAU.jpg'),
(116251, 8306, 'Tudo Por Um Like S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qt0U3z1HXPJ1KAipTYYHubfM5oD.jpg'),
(116252, 8307, 'Pipoca da Ivete S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116253, 8307, 'Pipoca da Ivete S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116254, 8307, 'Pipoca da Ivete S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116255, 8307, 'Pipoca da Ivete S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116256, 8307, 'Pipoca da Ivete S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116257, 8307, 'Pipoca da Ivete S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116258, 8307, 'Pipoca da Ivete S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116259, 8307, 'Pipoca da Ivete S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116260, 8307, 'Pipoca da Ivete S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116261, 8307, 'Pipoca da Ivete S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116262, 8307, 'Pipoca da Ivete S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116263, 8308, 'Pipoca da Ivete S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116264, 8308, 'Pipoca da Ivete S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116265, 8308, 'Pipoca da Ivete S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116266, 8308, 'Pipoca da Ivete S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116267, 8308, 'Pipoca da Ivete S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116268, 8308, 'Pipoca da Ivete S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116269, 8308, 'Pipoca da Ivete S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116270, 8308, 'Pipoca da Ivete S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116271, 8308, 'Pipoca da Ivete S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116272, 8308, 'Pipoca da Ivete S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116273, 8308, 'Pipoca da Ivete S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116274, 8308, 'Pipoca da Ivete S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116275, 8308, 'Pipoca da Ivete S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116276, 8308, 'Pipoca da Ivete S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/252273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHfn2bzopl0DgscmlXtzdvg7Gx.jpg'),
(116277, 8309, 'O Jardim dos Esquecidos: A Origem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/szqP5UkQhis7g31WelxI5QRi1Cz.jpg'),
(116278, 8309, 'O Jardim dos Esquecidos: A Origem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yOE3ZSewK79KhOXIeSIvtcYgmx7.jpg'),
(116279, 8309, 'O Jardim dos Esquecidos: A Origem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8VHixJZMPsgzK5Wmh11Wt7vf35R.jpg'),
(116280, 8309, 'O Jardim dos Esquecidos: A Origem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/47uoAfVOuFGzI3clUl7gnw4qe8r.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(116281, 8310, 'Fire Country S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/peUwLXgtG8DDDTBm3eFYGKqKXCi.jpg'),
(116282, 8310, 'Fire Country S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116283, 8310, 'Fire Country S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116284, 8310, 'Fire Country S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116285, 8310, 'Fire Country S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116286, 8310, 'Fire Country S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116287, 8310, 'Fire Country S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116288, 8310, 'Fire Country S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116289, 8310, 'Fire Country S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116290, 8310, 'Fire Country S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116291, 8310, 'Fire Country S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116292, 8310, 'Fire Country S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116293, 8310, 'Fire Country S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116294, 8310, 'Fire Country S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116295, 8310, 'Fire Country S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116296, 8310, 'Fire Country S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116297, 8310, 'Fire Country S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116298, 8310, 'Fire Country S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116299, 8310, 'Fire Country S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116300, 8310, 'Fire Country S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116301, 8310, 'Fire Country S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/255062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116302, 8310, 'Fire Country S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/255063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116303, 8311, 'Fire Country S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n71te4oKoTw3YJIjHal9jzNLhM2.jpg'),
(116304, 8311, 'Fire Country S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/288726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116305, 8311, 'Fire Country S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116306, 8311, 'Fire Country S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116307, 8311, 'Fire Country S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116308, 8311, 'Fire Country S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/327895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116309, 8311, 'Fire Country S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/341082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116310, 8311, 'Fire Country S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fkWvcWh84xZHCG9g7WNaSWdTW27.jpg'),
(116311, 8311, 'Fire Country S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/452628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116312, 8311, 'Fire Country S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/766856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jMCBW1Z9Ha1Mx0gh7qxrFzhx75U.jpg'),
(116313, 8312, 'Tem que Suar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116314, 8312, 'Tem que Suar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116315, 8312, 'Tem que Suar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116316, 8312, 'Tem que Suar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116317, 8312, 'Tem que Suar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116318, 8312, 'Tem que Suar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116319, 8312, 'Tem que Suar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116320, 8312, 'Tem que Suar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116321, 8312, 'Tem que Suar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116322, 8312, 'Tem que Suar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116323, 8312, 'Tem que Suar S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116324, 8312, 'Tem que Suar S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116325, 8312, 'Tem que Suar S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116326, 8312, 'Tem que Suar S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116327, 8312, 'Tem que Suar S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116328, 8312, 'Tem que Suar S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/241845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116329, 8312, 'Tem que Suar S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/241846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116330, 8312, 'Tem que Suar S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/241847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116331, 8312, 'Tem que Suar S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/241848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116332, 8312, 'Tem que Suar S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/241849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116333, 8313, 'Tem que Suar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/420598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116334, 8313, 'Tem que Suar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/420599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116335, 8313, 'Tem que Suar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/423016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116336, 8313, 'Tem que Suar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/423017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116337, 8313, 'Tem que Suar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/426368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116338, 8313, 'Tem que Suar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/426369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116339, 8313, 'Tem que Suar S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/426370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116340, 8313, 'Tem que Suar S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/426371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116341, 8313, 'Tem que Suar S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/426372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116342, 8313, 'Tem que Suar S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/428610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116343, 8313, 'Tem que Suar S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/428611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116344, 8313, 'Tem que Suar S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/428612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116345, 8313, 'Tem que Suar S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/428613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116346, 8313, 'Tem que Suar S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/432939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116347, 8313, 'Tem que Suar S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/432940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/podEPB0Yp9j30RaKkmOQf78ykS9.jpg'),
(116348, 8314, '4 Cut Hero [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q2oL9ZvuWbdSYRqUmdMHzyGoeaV.jpg'),
(116349, 8314, '4 Cut Hero [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJlMNex0MMJFjDbe3uVHJbbHDZo.jpg'),
(116350, 8314, '4 Cut Hero [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qdec5znAJdXaZxWLtEo3l0D8qMV.jpg'),
(116351, 8314, '4 Cut Hero [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u88cP20qpldI5XkdjzDtUKxcGLj.jpg'),
(116352, 8314, '4 Cut Hero [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Af7vr6BWRLkqoXsO2exLD8TKFbB.jpg'),
(116353, 8314, '4 Cut Hero [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fcL5uMum8FrIK2GMsjVquKp3EvW.jpg'),
(116354, 8314, '4 Cut Hero [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tIBoRXDpwmgO0EKCkw0EiFtvd5t.jpg'),
(116355, 8314, '4 Cut Hero [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Nwt7cJBnPgZiiNJMkhAN0kqPNJ.jpg'),
(116356, 8314, '4 Cut Hero [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nSjyayQx3xsSGpUceTsc2qSM1Cm.jpg'),
(116357, 8314, '4 Cut Hero [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8dgZGaSbERp8C9tpW5KOJmLKyls.jpg'),
(116358, 8315, 'A Outra Garota Negra [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ZxC5KaAd1kmjWkYl69y5R2vhWs.jpg'),
(116359, 8315, 'A Outra Garota Negra [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vRyGpqOuMraAUjNHshy1XqFEmoW.jpg'),
(116360, 8315, 'A Outra Garota Negra [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lFwga4QL9ph5ny4TgnKIVF2V4W3.jpg'),
(116361, 8315, 'A Outra Garota Negra [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cX0zP5EJs03Ok5w0j1O6AUIk2z7.jpg'),
(116362, 8315, 'A Outra Garota Negra [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/95rvcYyi0SUmHGZxnQwGVaFqM2f.jpg'),
(116363, 8315, 'A Outra Garota Negra [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dvtbYN1sY3nq5HAFcpFWiVGyBG5.jpg'),
(116364, 8315, 'A Outra Garota Negra [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/goHDKj42RtBa2kWWtrk7hQ8tGTU.jpg'),
(116365, 8315, 'A Outra Garota Negra [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zbRWFejSD97mCUMCnMCud0LUMQ2.jpg'),
(116366, 8315, 'A Outra Garota Negra [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/64yVnbZxjib9uYLGK4dgpXDmWLF.jpg'),
(116367, 8315, 'A Outra Garota Negra [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sJwiYd9oviHaPlwbvcY1ACZqPTA.jpg'),
(116368, 8316, 'Caçadores de Demônios [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7aTEpb6CR4w1GyhwuaBKO9ZIwS3.jpg'),
(116369, 8316, 'Caçadores de Demônios [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cFP4rtuhIa1T39toYIDwoTP405h.jpg'),
(116370, 8316, 'Caçadores de Demônios [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v2jQYm3YGy8J6wBs8bLDDqIPSnB.jpg'),
(116371, 8316, 'Caçadores de Demônios [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qCbz0EWatMu3JRztZEhnPh8PWCR.jpg'),
(116372, 8316, 'Caçadores de Demônios [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4tMQmnmOnVcMj6ugLPq7CGlbzn7.jpg'),
(116373, 8316, 'Caçadores de Demônios [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOQ2t8MJOuLsiXc3fOYAhglwkoz.jpg'),
(116374, 8316, 'Caçadores de Demônios [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/42jS2VAOxzOj1XmXDInGiwLeOCN.jpg'),
(116375, 8316, 'Caçadores de Demônios [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2DVYOqareyqHaTd3oDZzFP1G2Ga.jpg'),
(116376, 8316, 'Caçadores de Demônios [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eI9qCZsbprmtdnQlT7LgCZEtVO2.jpg'),
(116377, 8316, 'Caçadores de Demônios [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qfrWQRrVg9XQOJSyqKKnTFbhQi8.jpg'),
(116378, 8316, 'Caçadores de Demônios [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kS2wrX3B9U7lbI02wqhjbki0E8s.jpg'),
(116379, 8316, 'Caçadores de Demônios [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfOwBAXUgGGFVv2sJNS1B86OdlC.jpg'),
(116380, 8316, 'Caçadores de Demônios [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AefZgDuPQMApKwUCCZlkN10e9J5.jpg'),
(116381, 8316, 'Caçadores de Demônios [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oWaWnHTMI4TdCiTYF50st5zVUTo.jpg'),
(116382, 8316, 'Caçadores de Demônios [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pmrKEyoxgGIB0WFuLF0gho0FxRm.jpg'),
(116383, 8316, 'Caçadores de Demônios [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bc4S9kPszX3AylwaAL2OANqlr6D.jpg'),
(116384, 8317, 'Mau Comportamento S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4tMGTrn1CNaNc21QIfrDM3D8iZM.jpg'),
(116385, 8317, 'Mau Comportamento S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0qIeSOkfjPqICQyYfkHLjlL1qp.jpg'),
(116386, 8317, 'Mau Comportamento S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tsEJEROTQN7sAnsRVWoY4yjoEN5.jpg'),
(116387, 8317, 'Mau Comportamento S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/IaEJnxlooRm3eJ3S7Jhy0ab8bE.jpg'),
(116388, 8318, 'The Chelsea Detective [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/42erO9DlPirdkuT3OPMV4IdiJAA.jpg'),
(116389, 8318, 'The Chelsea Detective [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kZJdSQP74mezP0xOQWAr1BKXVuT.jpg'),
(116390, 8318, 'The Chelsea Detective [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2FGbzLKERaLXXcYtBNoPRHeFsb2.jpg'),
(116391, 8318, 'The Chelsea Detective [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1K5uaCL0NxfWNGHjkZ0whWSzKzq.jpg'),
(116392, 8319, 'The Chelsea Detective [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vWWf7eAipYitLE2lJ7plWL1aO6f.jpg'),
(116393, 8319, 'The Chelsea Detective [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vWWf7eAipYitLE2lJ7plWL1aO6f.jpg'),
(116394, 8320, 'The Killing Kind [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8AebuN7ASvZYm1BgwtlfcNQNU1l.jpg'),
(116395, 8320, 'The Killing Kind [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oOE4MX0SrkmgiBpmZwkWIo21Iay.jpg'),
(116396, 8320, 'The Killing Kind [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AmJMGLtVEbCTf85PsY4C8ftZnuR.jpg'),
(116397, 8320, 'The Killing Kind [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oQE4RRNf1VGODihlWvvolzRWtoG.jpg'),
(116398, 8320, 'The Killing Kind [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k5fMpRm7EghsT4hTM4EGwuqsGQ5.jpg'),
(116399, 8320, 'The Killing Kind [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k5fMpRm7EghsT4hTM4EGwuqsGQ5.jpg'),
(116400, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qQoCxiWqarOYtmYIrp7G9GXGoF8.jpg'),
(116401, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9E44MqSmoV4xWIQh60rd6okNU98.jpg'),
(116402, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r5vStSmEUfdBWGX5ABJIH07KRR1.jpg'),
(116403, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVGwaUVmTTTGaNfXHqIrxmbateZ.jpg'),
(116404, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJVOssyoMegLOZC7rjvigpZoGvo.jpg'),
(116405, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fgbgVEjjyZQzfVTIMldx2dQCtIU.jpg'),
(116406, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q6v020GGp8dAB8VKgF4I1soLFJF.jpg'),
(116407, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j5cNIaQwtV9ofyIUeHHE5l7dTl6.jpg'),
(116408, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1VmyiQzE3j0Kpnmc8CCCR8EZ1P6.jpg'),
(116409, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bl0G9SMu71cT9i0ocFDKm2hg8gf.jpg'),
(116410, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/33KTn4MYnFQKRRfewQnNQ6IbfT0.jpg'),
(116411, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4gdVBZecAmjpPhTbvq7vpx0UlFo.jpg'),
(116412, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1QGMG4gZgYtOa7dtsu8sM0AP9Ov.jpg'),
(116413, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n8TSE3R1Iy2jepiYoJaV5vJrJ7I.jpg'),
(116414, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hfBo9HQtNd5klEF9nfgZ7aFctVo.jpg'),
(116415, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pAWaUv6k2LYJDi1IwoSriFzNJQi.jpg'),
(116416, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pH75pZXRrriyKQlgOzVOb4Gxzj8.jpg'),
(116417, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gGQDDMu6bOTF2TjyukGAAYgsurs.jpg'),
(116418, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/236508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jAkgwbpKSh14swMU0jeuTOVaY9h.jpg'),
(116419, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/236509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kXbsxLZKeoDqH18xDbjMZONj9uB.jpg'),
(116420, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/236510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m5Vh4FCTDJy4dUpfqikPFYsPPVb.jpg'),
(116421, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/236511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/arMVkMwxQUq8bPeZ8blVZH11QSx.jpg'),
(116422, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/236512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mzpk3t42wnb33T0x2sEl2QfSg6l.jpg'),
(116423, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/236513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u1tH3Lobyjj8zUS5ORvBImgmTC5.jpg'),
(116424, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/236514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eINX0Eg9vkWVnphEN1jbZ5Bq4un.jpg'),
(116425, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/236515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wC9Auric3K4lgy7vxzfOLGtVG3t.jpg'),
(116426, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/236516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uHhVpgU4lyZakvgVZVeGSvUv28E.jpg'),
(116427, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/236517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6SLPfUAcO7Aup0vh8CbFYcORhyS.jpg'),
(116428, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/236518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iBLH78CqIflK4HwViV1SKr4tqQ2.jpg'),
(116429, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/236519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7CkzMbEtkJ38PpZtLuuJMS8fkSz.jpg'),
(116430, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/236520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzopJa9cLPX2FXyzOPDb89cVsUG.jpg'),
(116431, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/236521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2OWw32Px3xX58qDaFl06DyjMpg9.jpg'),
(116432, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/236522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5oEYFdNPCjK8mITWYMhmMO71zCc.jpg'),
(116433, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/236523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sERaT6lwK4xIb5JcxlOkSxkRe6t.jpg'),
(116434, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/236524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9vaWag4ea9AO9cFC4zA1qjeG1sw.jpg'),
(116435, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/236525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t8HjaXb6jcR3ZEhODNSafJx8a1X.jpg'),
(116436, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/236526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/enpBVkL1SdYqIoA0nv5alRbzq3P.jpg'),
(116437, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/236527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nSYKjeMqRlGbXcElfws0l8LkwZu.jpg'),
(116438, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/236528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1oE875YRrUISQoqEWwwTFZxdhGd.jpg'),
(116439, 8321, 'Fogos de Artifício do Meu Coração [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/236529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/98Pj624klzbEibcAQp2gPe5OCHy.jpg'),
(116440, 8322, 'Monstros Invisíveis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pD98HqisRAUj3DT7hVnqNwWPLtC.jpg'),
(116441, 8322, 'Monstros Invisíveis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pD98HqisRAUj3DT7hVnqNwWPLtC.jpg'),
(116442, 8322, 'Monstros Invisíveis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pD98HqisRAUj3DT7hVnqNwWPLtC.jpg'),
(116443, 8322, 'Monstros Invisíveis S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pD98HqisRAUj3DT7hVnqNwWPLtC.jpg'),
(116444, 8322, 'Monstros Invisíveis S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pD98HqisRAUj3DT7hVnqNwWPLtC.jpg'),
(116445, 8322, 'Monstros Invisíveis S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pD98HqisRAUj3DT7hVnqNwWPLtC.jpg'),
(116446, 8323, 'Coreia O Pais do Kimchi [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/762331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wpkaxXdAfVHe0Kh1tXVasb14PKK.jpg'),
(116447, 8323, 'Coreia O Pais do Kimchi [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/762332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wpkaxXdAfVHe0Kh1tXVasb14PKK.jpg'),
(116448, 8323, 'Coreia O Pais do Kimchi [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/762333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wpkaxXdAfVHe0Kh1tXVasb14PKK.jpg'),
(116449, 8324, 'My Lovely Liar [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vP8fLo1RYsw4YT9EeFli4ZOeZMf.jpg'),
(116450, 8324, 'My Lovely Liar [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fWSG5Kw4j3zDBJMyCmiXDA2aNZN.jpg'),
(116451, 8324, 'My Lovely Liar [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g89OtXv6QYzyM4ivCVuFWOCL2IE.jpg'),
(116452, 8324, 'My Lovely Liar [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uap8KXxjEBry5m92C1rfXWMAXEp.jpg'),
(116453, 8324, 'My Lovely Liar [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mclf7h9dg7r6vZCQUPFSpKXDWYT.jpg'),
(116454, 8324, 'My Lovely Liar [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j7WRAWnNlh8Iad8LSdWeHIoiEZq.jpg'),
(116455, 8324, 'My Lovely Liar [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4tVGy54nbuSIADS7to91ZYegxCV.jpg'),
(116456, 8324, 'My Lovely Liar [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8bYM3H86ylBSCt2cG1jugr2PTEc.jpg'),
(116457, 8324, 'My Lovely Liar [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lJZjzJoeixAPmpxV6CHWmTzi3sF.jpg'),
(116458, 8324, 'My Lovely Liar [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7rVH6nZZP1BI5oyHcUY29SN7Hw8.jpg'),
(116459, 8324, 'My Lovely Liar [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6YJlUnQYiK4ZHwUNgmLXkEOJ6L0.jpg'),
(116460, 8324, 'My Lovely Liar [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/78hXGHMzgfonr2uDiy0iBNxQ1d5.jpg'),
(116461, 8324, 'My Lovely Liar [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aw44eFEGAkPIkWvXilSWliAmO4h.jpg'),
(116462, 8324, 'My Lovely Liar [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ZfSCcTT9QxpJ909BPS4nk5z6u7.jpg'),
(116463, 8324, 'My Lovely Liar [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5YyCoWfXrWxNqKoH2DpyOvbx0l.jpg'),
(116464, 8324, 'My Lovely Liar [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w1kwBWncwjipPDDp8ZE8qCcaxP9.jpg'),
(116465, 8325, 'Acusado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3wIwJDnn5ATsL2JCI8YSioB2XNe.jpg'),
(116466, 8325, 'Acusado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g6ZeGQKlzrpGBmkkuKHzOMljlfL.jpg'),
(116467, 8325, 'Acusado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zESQHojnK7OqXTRoB4KqoCtkWvA.jpg'),
(116468, 8325, 'Acusado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ve4EtIbcx4rCGk9ZJYBpnwdpHhB.jpg'),
(116469, 8325, 'Acusado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8lD6DQ5oFSVOHiyu4Hlv3YRmCe0.jpg'),
(116470, 8325, 'Acusado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vKmfQhBwFuls1x7gug4DBhnJQd.jpg'),
(116471, 8325, 'Acusado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tu1GTiNQMngHX1tehm8e45j0Qmq.jpg'),
(116472, 8325, 'Acusado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aFfKa5tND1X5MleOBAA9oQWJ4IK.jpg'),
(116473, 8325, 'Acusado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o4EC48c2dNqq8bknRVkB1qyC31i.jpg'),
(116474, 8325, 'Acusado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9yyllrBj0nxZ0knzfeGZJBEB9a.jpg'),
(116475, 8325, 'Acusado S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2fWK64zywCvgtIjMdEM94SbHq6d.jpg'),
(116476, 8325, 'Acusado S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ohSz4DA4Bcq8ItkskmngAat4Tg.jpg'),
(116477, 8325, 'Acusado S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Hozpu3W2UFCxDEsrYiSY4YfmYj.jpg'),
(116478, 8325, 'Acusado S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8gHW8ywnrmpPqhOFcAW3PWktA0F.jpg'),
(116479, 8325, 'Acusado S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AjY6SFGUuEBVSSLN4ofvTDabpuv.jpg'),
(116480, 8326, 'Acusado S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/880294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1xC2oCWaCTt1MOzG9D9T96m1LLD.jpg'),
(116481, 8326, 'Acusado S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/880295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4m0y4ebJibu2dKeui3R9zfqUKZA.jpg'),
(116482, 8326, 'Acusado S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/880296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xDRSg2rR0my4nVKzEDKQWF2zwQb.jpg'),
(116483, 8326, 'Acusado S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/880297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kaSZOnH0FgMVUCSby8iPaCaCqrU.jpg'),
(116484, 8326, 'Acusado S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/880298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKHuCBQ2kKTM7qSJ6PlHJbpkHzm.jpg'),
(116485, 8326, 'Acusado S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/880299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hrvDoZPs2vzvMGY9wDGK5oIXgpG.jpg'),
(116486, 8326, 'Acusado S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/880300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFinVgPD9NlMRy7QvTBsHsEz55x.jpg'),
(116487, 8326, 'Acusado S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/880301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rRWQ3a9iNSRq0O5HciFYX5JrnXF.jpg'),
(116488, 8327, 'Bombaim Cidade Sem Lei S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8SEjpRRM02xsPVsnnE0k16jb4zu.jpg'),
(116489, 8327, 'Bombaim Cidade Sem Lei S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9YmljvDeWaOchb4BOi8xcQUy5A.jpg'),
(116490, 8327, 'Bombaim Cidade Sem Lei S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yUWUPqLj1diNCTsRDpOvXyAAn8s.jpg'),
(116491, 8327, 'Bombaim Cidade Sem Lei S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xHfZBc7whC9Qc4vngb4zgPtFLVJ.jpg'),
(116492, 8327, 'Bombaim Cidade Sem Lei S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m9PtPQy2OlnBIH1xwCtsn7cNp0v.jpg'),
(116493, 8327, 'Bombaim Cidade Sem Lei S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6IJjsJboBPtTbR6iMMYtJxzXrKp.jpg'),
(116494, 8327, 'Bombaim Cidade Sem Lei S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fvyZGoIRWaVHMackxiJ2AOZiH02.jpg'),
(116495, 8327, 'Bombaim Cidade Sem Lei S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/olENi9zlsvKUskWhduUQ5zpbwfO.jpg'),
(116496, 8327, 'Bombaim Cidade Sem Lei S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTS8QXi0W2y7Ze1eIJIzhnIUAsy.jpg'),
(116497, 8327, 'Bombaim Cidade Sem Lei S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9BlPHs7ZqTHJux15geNycnGJaq1.jpg'),
(116498, 8328, 'Carruagem Errada Noivo Certo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PaUPyib4sesBSTRgHD3hAaiYx2.jpg'),
(116499, 8328, 'Carruagem Errada Noivo Certo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r0eSFRs3FN55sKOkc34UR2loea3.jpg'),
(116500, 8328, 'Carruagem Errada Noivo Certo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sWSvmjIi6UFE6G92LQmaZgPDb2S.jpg'),
(116501, 8328, 'Carruagem Errada Noivo Certo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pA2ymuRALM8ZX4pmC07Y3epHQxF.jpg'),
(116502, 8328, 'Carruagem Errada Noivo Certo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AlpQjqwloorTsrmg3QX0RDXZgPs.jpg'),
(116503, 8328, 'Carruagem Errada Noivo Certo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFaKWReB9seE5pbA3ApU8kKAG4I.jpg'),
(116504, 8328, 'Carruagem Errada Noivo Certo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1QDgTikITb84VNpRw8BLMDiRi8C.jpg'),
(116505, 8328, 'Carruagem Errada Noivo Certo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wAsmRaHjnkC4huYUdh3LpKSTCPh.jpg'),
(116506, 8328, 'Carruagem Errada Noivo Certo [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Fv26qBXYiRKvRp92FVkj7Gv2sl.jpg'),
(116507, 8328, 'Carruagem Errada Noivo Certo [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rubXgYv3N9JxpmuW06AD1Bio4nB.jpg'),
(116508, 8328, 'Carruagem Errada Noivo Certo [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bfC8q2wUtcMFxce01BAjBZRYmhu.jpg'),
(116509, 8328, 'Carruagem Errada Noivo Certo [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3P7I7VC11dVPJBSIecqdWcmuxor.jpg'),
(116510, 8328, 'Carruagem Errada Noivo Certo [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6dQ2T7v6b9hdGj0w8Whi7yNrsnx.jpg'),
(116511, 8328, 'Carruagem Errada Noivo Certo [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/emOjUnTvRRp3g41guRUrMGQ98tT.jpg'),
(116512, 8328, 'Carruagem Errada Noivo Certo [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lkCWTGCtsWqjan44J1QuMSTPcE2.jpg'),
(116513, 8328, 'Carruagem Errada Noivo Certo [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i15Aickivl4MeQuyBHHPOyCTSlq.jpg'),
(116514, 8328, 'Carruagem Errada Noivo Certo [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v4tIb7q9znERe68Jl3hCQSPkjgY.jpg'),
(116515, 8328, 'Carruagem Errada Noivo Certo [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uTcpE9IVitpahCE6J7XUs5oXLnB.jpg'),
(116516, 8328, 'Carruagem Errada Noivo Certo [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/236365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5zsr2NqIkdDfW8x9EeAKv49zzC8.jpg'),
(116517, 8328, 'Carruagem Errada Noivo Certo [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/236366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n5t6r1FkY8PpAjNeLHbHE9SYLUT.jpg'),
(116518, 8328, 'Carruagem Errada Noivo Certo [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/236367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e8czGgrxiNAEAgxE98R2oAKuasT.jpg'),
(116519, 8328, 'Carruagem Errada Noivo Certo [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/236368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oSOBG7ckIChxOvMdnLielcACkGO.jpg'),
(116520, 8328, 'Carruagem Errada Noivo Certo [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/236369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2wCBZL6HCZPTYntDrE35C9KwGV.jpg'),
(116521, 8329, 'Young Love S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3hlgCKtrQYOZacrvgeIWjRmb89Y.jpg'),
(116522, 8329, 'Young Love S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6jPf5boarSTh8GLaMFZnHNRsLIc.jpg'),
(116523, 8329, 'Young Love S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qXf0V3ydNyJckkuTFNkwfH8ll5R.jpg'),
(116524, 8329, 'Young Love S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wsDJl1osCi8LKOVXvKwubGaqcCi.jpg'),
(116525, 8329, 'Young Love S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gC3oBr8es4hFr6zwvXIMMBFi5c2.jpg'),
(116526, 8329, 'Young Love S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gC3oBr8es4hFr6zwvXIMMBFi5c2.jpg'),
(116527, 8329, 'Young Love S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gC3oBr8es4hFr6zwvXIMMBFi5c2.jpg'),
(116528, 8329, 'Young Love S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gC3oBr8es4hFr6zwvXIMMBFi5c2.jpg'),
(116529, 8329, 'Young Love S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gC3oBr8es4hFr6zwvXIMMBFi5c2.jpg'),
(116530, 8329, 'Young Love S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gC3oBr8es4hFr6zwvXIMMBFi5c2.jpg'),
(116531, 8329, 'Young Love S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/242388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gC3oBr8es4hFr6zwvXIMMBFi5c2.jpg'),
(116532, 8329, 'Young Love S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/242389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gC3oBr8es4hFr6zwvXIMMBFi5c2.jpg'),
(116533, 8330, 'As Trapalhadas de Flapjack S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3AdPE6o2z2Cre2PG9Fk39HOSLBh.jpg'),
(116534, 8330, 'As Trapalhadas de Flapjack S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1PKHE0IqKf86frfFRdDrGjReNn6.jpg'),
(116535, 8330, 'As Trapalhadas de Flapjack S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3K44u9K4dLQezP4pwLqE4U86R6Z.jpg'),
(116536, 8330, 'As Trapalhadas de Flapjack S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c5KqDIGmm7fbEQKm7ScSaY5VKPp.jpg'),
(116537, 8330, 'As Trapalhadas de Flapjack S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fBhSmvMZbG1OEvEl8ygZycc9jcs.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(116538, 8330, 'As Trapalhadas de Flapjack S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2o28jWIhaKoCN5ZvyTp8BpiK9II.jpg'),
(116539, 8330, 'As Trapalhadas de Flapjack S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qxlLuj0eixtZ0ZlIWtQ5KpiJndV.jpg'),
(116540, 8330, 'As Trapalhadas de Flapjack S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8RtXIOQvR1n1ovuCNjnBafMHemF.jpg'),
(116541, 8330, 'As Trapalhadas de Flapjack S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dBsdJqy8D2UuiRUP85LELdCOJEl.jpg'),
(116542, 8330, 'As Trapalhadas de Flapjack S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFQVux9jOypjm0rUKV5BD8MjsbM.jpg'),
(116543, 8330, 'As Trapalhadas de Flapjack S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5xKr1ksTlA4xD9xPVxfrnOhC4P9.jpg'),
(116544, 8330, 'As Trapalhadas de Flapjack S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f3Fs11tAAlhIOlxnOeEKFYfPU8w.jpg'),
(116545, 8330, 'As Trapalhadas de Flapjack S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Tl4p1nMAq41PAImuicKeri8LmW.jpg'),
(116546, 8330, 'As Trapalhadas de Flapjack S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7mxZFdK2FQjLwS5ylXwB6wWMCx.jpg'),
(116547, 8330, 'As Trapalhadas de Flapjack S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fnDbYRODLMLMjO0J9ETXWmGXNJO.jpg'),
(116548, 8330, 'As Trapalhadas de Flapjack S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j1AnmG4W5SXej7ByjMaPUGTlBlb.jpg'),
(116549, 8330, 'As Trapalhadas de Flapjack S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qdwNVHiXd2XhBJpVNCdUL1sb9eh.jpg'),
(116550, 8330, 'As Trapalhadas de Flapjack S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iDFYL9cstjBoxL3J88aH1IIEErp.jpg'),
(116551, 8330, 'As Trapalhadas de Flapjack S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/236275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4JyjqRH9u6AyS1X3DeWnNAQTEdQ.jpg'),
(116552, 8330, 'As Trapalhadas de Flapjack S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/236276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u0QCsfpPh55C8CH7XHK2yj0yUBD.jpg'),
(116553, 8330, 'As Trapalhadas de Flapjack S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/236277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2RfG3rCtCQtiQjCBUC773INhi12.jpg'),
(116554, 8330, 'As Trapalhadas de Flapjack S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/236278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rVuUpi7qHRg8jtLs28Yj4915z8g.jpg'),
(116555, 8330, 'As Trapalhadas de Flapjack S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/236279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAiXzmBkXAKtUlgeSy14GmkCJV6.jpg'),
(116556, 8330, 'As Trapalhadas de Flapjack S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/236280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nQfE9QbBWSfOLgrpvL63tXSw6Le.jpg'),
(116557, 8330, 'As Trapalhadas de Flapjack S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/236281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4zQ0Hz40evbOEdsslzWml02QNEg.jpg'),
(116558, 8330, 'As Trapalhadas de Flapjack S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/236282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bfFspsj3b3K61ujkEAq3Il2wkDX.jpg'),
(116559, 8330, 'As Trapalhadas de Flapjack S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/236283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7XJtPmEZ2gxaioDWM61nrDZeroM.jpg'),
(116560, 8330, 'As Trapalhadas de Flapjack S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/236284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hU43qBj2IFbrHMENhHxpupIIEht.jpg'),
(116561, 8330, 'As Trapalhadas de Flapjack S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/236285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jivCv0Sf8t8Z3JJ3No8o6MjZz5M.jpg'),
(116562, 8330, 'As Trapalhadas de Flapjack S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/236286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rf2wBQxvPQfyqC8PFaVCsWaFPoR.jpg'),
(116563, 8330, 'As Trapalhadas de Flapjack S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/236287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4vBVADNL7zraFfzNyy1TJxmmuUB.jpg'),
(116564, 8330, 'As Trapalhadas de Flapjack S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/236288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tchjSqdsMWyd1RuaGU44Zi8bAEK.jpg'),
(116565, 8330, 'As Trapalhadas de Flapjack S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/236289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l2y4TKWOSJ7QN1szkkhKUOvNk1j.jpg'),
(116566, 8330, 'As Trapalhadas de Flapjack S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/236290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hkx6Kp8ET14f0tHZodcZ5b3ufrm.jpg'),
(116567, 8330, 'As Trapalhadas de Flapjack S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/236291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jRBfVmW0av9uNy3CUAOhY7JcuwT.jpg'),
(116568, 8330, 'As Trapalhadas de Flapjack S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/236292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yfsnviT5KmZrKPwaAOevEM5N6nh.jpg'),
(116569, 8330, 'As Trapalhadas de Flapjack S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/236293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qupQi1yQFS4YylAIu3r4p3GIpAX.jpg'),
(116570, 8330, 'As Trapalhadas de Flapjack S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/236294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ivHql37q6hGQyPhdFfeRMVFEFRo.jpg'),
(116571, 8330, 'As Trapalhadas de Flapjack S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/236295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lDAxpBtp37paeIGFq8TyN9WmTdd.jpg'),
(116572, 8330, 'As Trapalhadas de Flapjack S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/236296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kLXiIpex2JN8EDKAbATj5rrTkv4.jpg'),
(116573, 8331, 'As Trapalhadas de Flapjack S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/T84CZBbnBREENGUKOdLFnDae0H.jpg'),
(116574, 8331, 'As Trapalhadas de Flapjack S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n84i1D0GqqClCLalvpv6fgCap9Q.jpg'),
(116575, 8331, 'As Trapalhadas de Flapjack S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lMTfl7bXZgWdQz7AdYjhCPCg2Td.jpg'),
(116576, 8331, 'As Trapalhadas de Flapjack S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZkZrMUkCvYmHXCElsSRClf9lCv.jpg'),
(116577, 8331, 'As Trapalhadas de Flapjack S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hIEOzTZDYnNI0UemYCjFrKdYKbg.jpg'),
(116578, 8331, 'As Trapalhadas de Flapjack S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1718YBWKtx5PCYgzRuIx00bm3JU.jpg'),
(116579, 8331, 'As Trapalhadas de Flapjack S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kByaZ0ICCdsggd6nuQiPb6Z1lL4.jpg'),
(116580, 8331, 'As Trapalhadas de Flapjack S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tnTBanIUTv7WTTJgSFzMSQofXk4.jpg'),
(116581, 8331, 'As Trapalhadas de Flapjack S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y3AFn9zPOrZWiQyfJreV0s94CA4.jpg'),
(116582, 8331, 'As Trapalhadas de Flapjack S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5wUtynC9Rq3EhkNOtyU0d4FHyL1.jpg'),
(116583, 8331, 'As Trapalhadas de Flapjack S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wsLEgERgct9Vg0Us9b85dEw1hyl.jpg'),
(116584, 8331, 'As Trapalhadas de Flapjack S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i0CPvA70x5PDOVBWK7BiXbZymP3.jpg'),
(116585, 8331, 'As Trapalhadas de Flapjack S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/236309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/seVCCy853hCOUi7UwvByrt863V9.jpg'),
(116586, 8331, 'As Trapalhadas de Flapjack S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/236310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mLUZgW6YR7iP6ncHOJwYLT7aE1I.jpg'),
(116587, 8331, 'As Trapalhadas de Flapjack S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/236311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jfNLMEop3j6Yr97fQzWapujAURe.jpg'),
(116588, 8331, 'As Trapalhadas de Flapjack S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/236312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJ1Vqhfgay3u4A0IFdymZWNQKgq.jpg'),
(116589, 8331, 'As Trapalhadas de Flapjack S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/236313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/56dycdmR2pNy075QKw0RqjdRBXj.jpg'),
(116590, 8331, 'As Trapalhadas de Flapjack S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/236314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3iOWo8o90VJsY5yjBgzljKp3k6n.jpg'),
(116591, 8331, 'As Trapalhadas de Flapjack S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/236315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4MCqZdv6Cuc0ce0qFp9eRURZYPQ.jpg'),
(116592, 8331, 'As Trapalhadas de Flapjack S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/236316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/weq5qxDX4ne6i7vl3uorIOLGnS2.jpg'),
(116593, 8331, 'As Trapalhadas de Flapjack S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/236317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zM2Qxf5Ata0TdoR0CC7MG8Oqbfq.jpg'),
(116594, 8331, 'As Trapalhadas de Flapjack S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/236318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uOh8aRSC4YIv0gnMEBNOjpwieRy.jpg'),
(116595, 8331, 'As Trapalhadas de Flapjack S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/236319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5YWbV3q7OnHii8V84Pe6D4xQ9rE.jpg'),
(116596, 8331, 'As Trapalhadas de Flapjack S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/236320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dTQzrQVyGOo9XjzUlrAAcMKqn6y.jpg'),
(116597, 8331, 'As Trapalhadas de Flapjack S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/236321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bw4xCqGqRMU4ToLCZCGZOOza1no.jpg'),
(116598, 8331, 'As Trapalhadas de Flapjack S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/236322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5LR11bdvoiW6AAiMHPgT5R4sVgE.jpg'),
(116599, 8331, 'As Trapalhadas de Flapjack S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/236323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lw54SmBvdJXjamhPXx4IBT8S5tQ.jpg'),
(116600, 8331, 'As Trapalhadas de Flapjack S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/236324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9MT4QDf18AhlHZM8IuKOYoIM88z.jpg'),
(116601, 8331, 'As Trapalhadas de Flapjack S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/236325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ac5ctLHNBnma8znodwwMfvz3foy.jpg'),
(116602, 8331, 'As Trapalhadas de Flapjack S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/236326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4zfaoA3KnfOrwIm0oOlxq1nfERU.jpg'),
(116603, 8331, 'As Trapalhadas de Flapjack S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/236327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tmqLCbIxB6AViAdPq5xVATTxtiL.jpg'),
(116604, 8331, 'As Trapalhadas de Flapjack S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/236328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fa8kjg0ei2D8xAPkIA8sKHqIZqO.jpg'),
(116605, 8331, 'As Trapalhadas de Flapjack S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/236329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aKCFp641kTnl19syTMep1X0sHNY.jpg'),
(116606, 8331, 'As Trapalhadas de Flapjack S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/236330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ydVOqcnxs3SBtdMdYYWHFbW8twt.jpg'),
(116607, 8331, 'As Trapalhadas de Flapjack S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/236331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8pSeWrWQLt52qgn1ORKRoY97yMa.jpg'),
(116608, 8331, 'As Trapalhadas de Flapjack S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/236332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aIg2lcw5fOui74WMU5x5jPcJiUQ.jpg'),
(116609, 8331, 'As Trapalhadas de Flapjack S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/236333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rE4BJJDdz3mgMPQKgafPO6xQvMV.jpg'),
(116610, 8331, 'As Trapalhadas de Flapjack S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/236334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJBD50KqNZBgEUrEkp9W4liowDJ.jpg'),
(116611, 8332, 'As Trapalhadas de Flapjack S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sKCY4dbQRRsRiFCGc3AJul73GGn.jpg'),
(116612, 8332, 'As Trapalhadas de Flapjack S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1X20h3nqYSDpdmNr47dY9BzdzVC.jpg'),
(116613, 8332, 'As Trapalhadas de Flapjack S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lygU45iOekbA2yWrPIN6SbgLvxd.jpg'),
(116614, 8332, 'As Trapalhadas de Flapjack S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fKY3Mg2fjhxbzmbdKyPhCxysvB6.jpg'),
(116615, 8332, 'As Trapalhadas de Flapjack S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uw52rHxjHgMen9QIqF6rPNTmmhu.jpg'),
(116616, 8332, 'As Trapalhadas de Flapjack S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6YdOOt01x3wA5DjmarxvS4O3rQK.jpg'),
(116617, 8332, 'As Trapalhadas de Flapjack S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kdMTogDIK9Ealq50bEpuUKelDR4.jpg'),
(116618, 8332, 'As Trapalhadas de Flapjack S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1IUjTwls4m9gxWOAv3yhOL0lxE3.jpg'),
(116619, 8332, 'As Trapalhadas de Flapjack S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/snBW5NO7phVS4mXfYsF4q9lFb3j.jpg'),
(116620, 8332, 'As Trapalhadas de Flapjack S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/236344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bzTbfGrTgtd9yDOgleMwe42WtYk.jpg'),
(116621, 8332, 'As Trapalhadas de Flapjack S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/236345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uamn61sUqtSQzSCBV8gJYH7Z3a7.jpg'),
(116622, 8332, 'As Trapalhadas de Flapjack S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/236346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lENDz3IhaRABC9zYTnjekuCa7rY.jpg'),
(116623, 8333, 'Ainda Acordados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/poLsVlqFA31OC7H0adNavK9ED16.jpg'),
(116624, 8333, 'Ainda Acordados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8TTzaENeHRaefF8GM0ArRxXJ7vP.jpg'),
(116625, 8333, 'Ainda Acordados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ykCUNOUW1C2VavhqxjPtYIwNgpo.jpg'),
(116626, 8333, 'Ainda Acordados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ZTdkSD7YKVMHojqgs0Ix89cgS.jpg'),
(116627, 8333, 'Ainda Acordados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ZTdkSD7YKVMHojqgs0Ix89cgS.jpg'),
(116628, 8333, 'Ainda Acordados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ZTdkSD7YKVMHojqgs0Ix89cgS.jpg'),
(116629, 8333, 'Ainda Acordados S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ZTdkSD7YKVMHojqgs0Ix89cgS.jpg'),
(116630, 8333, 'Ainda Acordados S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ZTdkSD7YKVMHojqgs0Ix89cgS.jpg'),
(116631, 8334, 'Compro Likes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7SDrJIDehmyfLjSKkArgW9fYZe.jpg'),
(116632, 8334, 'Compro Likes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1JEg0byAAlpSjpTL3zK2rzhm0G8.jpg'),
(116633, 8334, 'Compro Likes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vGrV8KZEWPEkde2gK0ASdyNYK1J.jpg'),
(116634, 8334, 'Compro Likes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rl149P0mkDXxZIdpVjHmCDm6Efz.jpg'),
(116635, 8334, 'Compro Likes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gjZTgD1g96Cie8uHxuOHZVGB13m.jpg'),
(116636, 8335, 'Song of the Bandits S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/236243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gBwRSywED04vCkZgnhHPHqBcBL2.jpg'),
(116637, 8335, 'Song of the Bandits S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/236244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBLP4SUmQY2BAwhGlejm9jdq3PH.jpg'),
(116638, 8335, 'Song of the Bandits S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/236245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5m007aAEhyXpQUzXxuDmhhHfkII.jpg'),
(116639, 8335, 'Song of the Bandits S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/236246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5DKehEwHal6cm9HiaBsaq0dBGrG.jpg'),
(116640, 8335, 'Song of the Bandits S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/236247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ufbRHSElitlAQYhcRvOXwG2EW3f.jpg'),
(116641, 8335, 'Song of the Bandits S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/236248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bWPc9h4wh7GveCD2KN4I1bFWNKV.jpg'),
(116642, 8335, 'Song of the Bandits S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/236249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eHv43PuCQbir4ZVcfiMgyikpqSN.jpg'),
(116643, 8335, 'Song of the Bandits S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/236250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5skifdKOInFgcJ2zxSDyu8BQDte.jpg'),
(116644, 8335, 'Song of the Bandits S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/236251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4tlQYEvbIRnydCBKUc9D3UoaBb0.jpg'),
(116645, 8336, 'O Continental Do Mundo de John Wick S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fuXsh7wnAyyysr6qfORx1BXZPgb.jpg'),
(116646, 8336, 'O Continental Do Mundo de John Wick S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uRcrRc74ztb1TV5uojRtXqvNQ5y.jpg'),
(116647, 8336, 'O Continental Do Mundo de John Wick S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uRcrRc74ztb1TV5uojRtXqvNQ5y.jpg'),
(116648, 8337, 'Fantasmas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gfTKbRs5DcVQKcohbvO6xvArzxb.jpg'),
(116649, 8337, 'Fantasmas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yaEjlZKvl9pk1MNdx2TOWu18Onn.jpg'),
(116650, 8337, 'Fantasmas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9wbhWS1fkdkqkWUVn3ZsDmu2tsb.jpg'),
(116651, 8337, 'Fantasmas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1YJc171aGLUgc2sS1fq1sPQbsPY.jpg'),
(116652, 8337, 'Fantasmas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A9CRGxeLjiQI6siajdWGsQinNd7.jpg'),
(116653, 8337, 'Fantasmas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zwF5MWLxyDTaiROELnDVDNPhcCC.jpg'),
(116654, 8337, 'Fantasmas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ija5kouIih1ug7BhIVCpfvoto6G.jpg'),
(116655, 8337, 'Fantasmas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6dkC1Gbtg0tnnFN6m6KS8Ytcbjp.jpg'),
(116656, 8337, 'Fantasmas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5XgUUqEEQyjdnra8wOipTHJUmhy.jpg'),
(116657, 8337, 'Fantasmas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9aRpEQmBD7YBkb0UTFQLZp2WAbR.jpg'),
(116658, 8337, 'Fantasmas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rnkC0hfphSuwswWDJavWXrLug28.jpg'),
(116659, 8337, 'Fantasmas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6W4s9DfqVNDP69LPNGLRWYX7YUs.jpg'),
(116660, 8337, 'Fantasmas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmDzugj2MbfQ3ikyaaU7g7lFCWT.jpg'),
(116661, 8337, 'Fantasmas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/235924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9RF5chCsJjg3glBVNXGpq3pGTY2.jpg'),
(116662, 8337, 'Fantasmas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/235925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aV0TL2jGJkkWVdqtr0qqEjeXc7y.jpg'),
(116663, 8337, 'Fantasmas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/235926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kDly9tmmVrGkxjJfpKrsmFshVJ.jpg'),
(116664, 8337, 'Fantasmas S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/235927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLynZUQxjvdZb8PYG6JEM4l10T3.jpg'),
(116665, 8337, 'Fantasmas S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/235928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aOM118eCGTr16352KiBicBYSYlX.jpg'),
(116666, 8338, 'Fantasmas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tQ9JWOZJ7cJSKukqMJc947RSqzR.jpg'),
(116667, 8338, 'Fantasmas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5xjUEmp1Nn6DAqou87CZTWKVwqQ.jpg'),
(116668, 8338, 'Fantasmas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6IIE66YsSVDUs5JzgkduRPiq9U3.jpg'),
(116669, 8338, 'Fantasmas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tYnR3qajOfNV0fAT80ITJMjN272.jpg'),
(116670, 8338, 'Fantasmas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Nw5OGXuDlxLAg8kFVpudp1wd6e.jpg'),
(116671, 8338, 'Fantasmas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l5lTQ7hFxCgT9h0w6SyJmIymCzw.jpg'),
(116672, 8338, 'Fantasmas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6pQlTc3kjdcA3vytxem5RBoGW57.jpg'),
(116673, 8338, 'Fantasmas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8P2mxjNI8dYSu125KmvQcWzT2J.jpg'),
(116674, 8338, 'Fantasmas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k08Jvsg279IReHP9yUgDnNyMl0w.jpg'),
(116675, 8338, 'Fantasmas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kg08WAVHmDjkzbSpZYBxenqyynF.jpg'),
(116676, 8338, 'Fantasmas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hB3lngkK0rkosYQ0nMpPLfMk6vI.jpg'),
(116677, 8338, 'Fantasmas S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qHug8GaHRtSkut1uCDza61caYbl.jpg'),
(116678, 8338, 'Fantasmas S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1pFSxSskN5NaFVvzV03dZ84Etqu.jpg'),
(116679, 8338, 'Fantasmas S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/235942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hA90t1maallfVG5sUp6T6eFUgGw.jpg'),
(116680, 8338, 'Fantasmas S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/235943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/guurMxupi4LhMtlqdPQzmB8begE.jpg'),
(116681, 8338, 'Fantasmas S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/235944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rvNFJdi5jCSkdAOzzKZYl5jdXRn.jpg'),
(116682, 8338, 'Fantasmas S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/235945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qpU7VXdbjHQlIxKvLi1t91VRF6R.jpg'),
(116683, 8338, 'Fantasmas S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/235946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dQYDkDmIH5Ajl5FjuKVNy2FfrQ5.jpg'),
(116684, 8338, 'Fantasmas S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/235947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6waoCLqabssSFKxJFRqo78imlT7.jpg'),
(116685, 8338, 'Fantasmas S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/235948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A0696PyuvZEVoxW5Xh6kSvZRxqR.jpg'),
(116686, 8338, 'Fantasmas S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/235949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eoEtVuHcoMkRYXZXkoB88CMEQD2.jpg'),
(116687, 8338, 'Fantasmas S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/235950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hhOpqbsxpPzOj0ejVouJ1gsykWB.jpg'),
(116688, 8339, 'Fantasmas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/442564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/plHXxDancifffCR249yhkfoqteZ.jpg'),
(116689, 8339, 'Fantasmas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/442565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/plHXxDancifffCR249yhkfoqteZ.jpg'),
(116690, 8339, 'Fantasmas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/442566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/plHXxDancifffCR249yhkfoqteZ.jpg'),
(116691, 8339, 'Fantasmas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/442567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/plHXxDancifffCR249yhkfoqteZ.jpg'),
(116692, 8339, 'Fantasmas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/442568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/plHXxDancifffCR249yhkfoqteZ.jpg'),
(116693, 8339, 'Fantasmas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/442569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/plHXxDancifffCR249yhkfoqteZ.jpg'),
(116694, 8339, 'Fantasmas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/442570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/plHXxDancifffCR249yhkfoqteZ.jpg'),
(116695, 8339, 'Fantasmas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/442571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/plHXxDancifffCR249yhkfoqteZ.jpg'),
(116696, 8339, 'Fantasmas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/442572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/plHXxDancifffCR249yhkfoqteZ.jpg'),
(116697, 8339, 'Fantasmas S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/442573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/plHXxDancifffCR249yhkfoqteZ.jpg'),
(116698, 8340, 'Fantasmas S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/887874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nBgLSnqcyHb9Hpk222Ky1MyB9nW.jpg'),
(116699, 8340, 'Fantasmas S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/887875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4EnfR2LdmPcdOPavZYtxtILIKbj.jpg'),
(116700, 8340, 'Fantasmas S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/887876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yYr0IKlvE3mdibY6uRK90UupS8V.jpg'),
(116701, 8340, 'Fantasmas S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/887877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/88x2F9yThFnfrWWJZyLALwPJLxM.jpg'),
(116702, 8340, 'Fantasmas S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/887878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nmBbOB54CYArxxMUWSguLmt4Whj.jpg'),
(116703, 8340, 'Fantasmas S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/887879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pNgmCvf1iNhPmulqujsz4IaayNO.jpg'),
(116704, 8340, 'Fantasmas S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/887880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cgnZzE3wry6PWQDGsYih9yRNHmJ.jpg'),
(116705, 8340, 'Fantasmas S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/887881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uALb7MuuQChnGJ67agHHLlfZKaI.jpg'),
(116706, 8340, 'Fantasmas S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/887882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ea3yCXhJbrllC2DfdIlgtHBYA4.jpg'),
(116707, 8340, 'Fantasmas S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/887883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a8UytvKMR6vFNOgltySyxLPyRiY.jpg'),
(116708, 8340, 'Fantasmas S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/887884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/te4BWLJ49jJwxuLCXkGHL7odpp2.jpg'),
(116709, 8340, 'Fantasmas S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/887885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5t3RRy0oygtQobkTI7j5yioxURx.jpg'),
(116710, 8340, 'Fantasmas S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/887886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ypdNE1s07WjQ8IL0slE2ucsm3xZ.jpg'),
(116711, 8340, 'Fantasmas S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/887887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bCIL6r3QkSE1eL4WzqU1dA9e0tz.jpg'),
(116712, 8340, 'Fantasmas S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/887888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jhgU6xTqm6EFzCXTzQdwgyPTqTm.jpg'),
(116713, 8340, 'Fantasmas S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/887889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tylsQ2pDrU1XNqHwdNJaX0iR6Gl.jpg'),
(116714, 8340, 'Fantasmas S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/887890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7IExs72S6awNBPGrciCIevxxghP.jpg'),
(116715, 8340, 'Fantasmas S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/887891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jSeepqTprM4HgFaaegVelX3Glbs.jpg'),
(116716, 8340, 'Fantasmas S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/887892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k77TsZauQQWTS2GVjpuaREO6IbF.jpg'),
(116717, 8340, 'Fantasmas S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/887893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTXcIKiJFkLdFK4eLofWldWaG4s.jpg'),
(116718, 8340, 'Fantasmas S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/887894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aSs5D7sNQ5siLwheoa9bYMfMVCd.jpg'),
(116719, 8340, 'Fantasmas S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/887895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2OBbycXCe7GXljVBdmAWFAZIcyg.jpg'),
(116720, 8341, 'Ate Que O Restaurante Nos Separe S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCpwHHWvz3YB1UKTsgwbKkTnZdG.jpg'),
(116721, 8341, 'Ate Que O Restaurante Nos Separe S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yICueoud16JyyzQlDSxOm3vkGvl.jpg'),
(116722, 8341, 'Ate Que O Restaurante Nos Separe S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7VPeqcPPmg6QeTUKOAFvfSOxyYG.jpg'),
(116723, 8341, 'Ate Que O Restaurante Nos Separe S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gWd2JzTd09ZTzwOqSblHFmwjwyU.jpg'),
(116724, 8341, 'Ate Que O Restaurante Nos Separe S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vtsBELx0G7q8ei7AoQDKboMsXmu.jpg'),
(116725, 8341, 'Ate Que O Restaurante Nos Separe S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/peNEXbtLQYCwtdInhjLnZy5opbC.jpg'),
(116726, 8342, 'Global Citizen Festival S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235507.mp4', 'https://i.bj-share.info/576193d206770807d877e3be8cf8a8a4.png'),
(116727, 8342, 'Global Citizen Festival S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235508.mp4', 'https://i.bj-share.info/576193d206770807d877e3be8cf8a8a4.png'),
(116728, 8342, 'Global Citizen Festival S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235509.mp4', 'https://i.bj-share.info/576193d206770807d877e3be8cf8a8a4.png'),
(116729, 8342, 'Global Citizen Festival S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235510.mp4', 'https://i.bj-share.info/576193d206770807d877e3be8cf8a8a4.png'),
(116730, 8342, 'Global Citizen Festival S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235511.mp4', 'https://i.bj-share.info/576193d206770807d877e3be8cf8a8a4.png'),
(116731, 8342, 'Global Citizen Festival S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235512.mp4', 'https://i.bj-share.info/576193d206770807d877e3be8cf8a8a4.png'),
(116732, 8342, 'Global Citizen Festival S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235513.mp4', 'https://i.bj-share.info/576193d206770807d877e3be8cf8a8a4.png'),
(116733, 8342, 'Global Citizen Festival S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235514.mp4', 'https://i.bj-share.info/576193d206770807d877e3be8cf8a8a4.png'),
(116734, 8343, 'O Assassinato de Jill Dando S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ptCEA5qJD4UB9OEXdLwP0f5PlM.jpg'),
(116735, 8343, 'O Assassinato de Jill Dando S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lpM1gcWohpGrLY96HQ8xBtgSYNC.jpg'),
(116736, 8343, 'O Assassinato de Jill Dando S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3imCqegqLcsbIWtyeLx1GSI69kn.jpg'),
(116737, 8344, 'O Jogo do Diabo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wWLnMzA2IVfC5e9Q5hJs12T23Ne.jpg'),
(116738, 8344, 'O Jogo do Diabo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uDEFNF3oC3SudPQ7pmyzh6svuuf.jpg'),
(116739, 8344, 'O Jogo do Diabo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6HNOeSwXJMHzWGWziYH9YYJfuDq.jpg'),
(116740, 8344, 'O Jogo do Diabo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/80hFM4pnNVDcIlojmHZZVRPytyr.jpg'),
(116741, 8344, 'O Jogo do Diabo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shhkdVOSqhkdECc8qFmxZf6u2Dk.jpg'),
(116742, 8344, 'O Jogo do Diabo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wgFJgATsLG514XLnSSr9Ge2BAvm.jpg'),
(116743, 8344, 'O Jogo do Diabo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fbtQGPSNm8HUPxAxsWfrPfoMUXJ.jpg'),
(116744, 8344, 'O Jogo do Diabo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/52pTzAhPVWnzUzF6350NSykntt.jpg'),
(116745, 8344, 'O Jogo do Diabo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pXy9pCurENmIh7qe32H6F9vQUAX.jpg'),
(116746, 8344, 'O Jogo do Diabo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2yzpXEHtQWhny8D2K3YXwm0w1ep.jpg'),
(116747, 8344, 'O Jogo do Diabo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QVBYnaWTFCHiQc2YbYbzUiekTW.jpg'),
(116748, 8344, 'O Jogo do Diabo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/243247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5FYh8NabRopx9UJTLqYVYBK1ETF.jpg'),
(116749, 8345, 'O Jogo do Diabo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/789527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8ED7O2RM5pXCafMQuBKragWqPz.jpg'),
(116750, 8345, 'O Jogo do Diabo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/789528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8ED7O2RM5pXCafMQuBKragWqPz.jpg'),
(116751, 8345, 'O Jogo do Diabo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/789529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8ED7O2RM5pXCafMQuBKragWqPz.jpg'),
(116752, 8345, 'O Jogo do Diabo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/789530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8ED7O2RM5pXCafMQuBKragWqPz.jpg'),
(116753, 8345, 'O Jogo do Diabo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/801989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8ED7O2RM5pXCafMQuBKragWqPz.jpg'),
(116754, 8345, 'O Jogo do Diabo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/801990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8ED7O2RM5pXCafMQuBKragWqPz.jpg'),
(116755, 8345, 'O Jogo do Diabo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/801991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8ED7O2RM5pXCafMQuBKragWqPz.jpg'),
(116756, 8345, 'O Jogo do Diabo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/801992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8ED7O2RM5pXCafMQuBKragWqPz.jpg'),
(116757, 8345, 'O Jogo do Diabo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/801993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8ED7O2RM5pXCafMQuBKragWqPz.jpg'),
(116758, 8345, 'O Jogo do Diabo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/812375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8ED7O2RM5pXCafMQuBKragWqPz.jpg'),
(116759, 8345, 'O Jogo do Diabo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/812376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8ED7O2RM5pXCafMQuBKragWqPz.jpg'),
(116760, 8345, 'O Jogo do Diabo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/812377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8ED7O2RM5pXCafMQuBKragWqPz.jpg'),
(116761, 8346, 'Segredos Aereos da Segunda Guerra Mundial S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8HZW5HBvrIJfCu9H09gGiufJ5FC.jpg'),
(116762, 8346, 'Segredos Aereos da Segunda Guerra Mundial S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yzNeM2pN0YTtx2sOggW2TWREVCP.jpg'),
(116763, 8346, 'Segredos Aereos da Segunda Guerra Mundial S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gvBWnlKxVIDJUpVkofT4Q32X05d.jpg'),
(116764, 8346, 'Segredos Aereos da Segunda Guerra Mundial S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eY8oI7UJ0frhMKV14zU6gdI2ZUT.jpg'),
(116765, 8346, 'Segredos Aereos da Segunda Guerra Mundial S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ecWVBdnsvABjOwaKPHzLkGAbOkl.jpg'),
(116766, 8346, 'Segredos Aereos da Segunda Guerra Mundial S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nlvOAbqKUYr4cYyEUWadchBPH5U.jpg'),
(116767, 8347, 'Buddy Thunderstruck S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dH20QrHcnretLqtW34QtCFxKKTd.jpg'),
(116768, 8347, 'Buddy Thunderstruck S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jEtXiQqeNHR0RB4EowR2U3ADi3L.jpg'),
(116769, 8347, 'Buddy Thunderstruck S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kseCPmxonG0B6BKBLzbHWWQOxo4.jpg'),
(116770, 8347, 'Buddy Thunderstruck S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/teypXIOery3xmrJxptxi0rPV29.jpg'),
(116771, 8347, 'Buddy Thunderstruck S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q3A4jHrV63V71QOLpBEsyhwjjDc.jpg'),
(116772, 8347, 'Buddy Thunderstruck S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p8RH8HD5qWgsd9Sr39XMFzuBI5Y.jpg'),
(116773, 8347, 'Buddy Thunderstruck S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kr4HYm4EZ9zTvyC2CABJ2wjI01Z.jpg'),
(116774, 8347, 'Buddy Thunderstruck S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Kp0BddJFESnmIGFp6Et5IVqcEE.jpg'),
(116775, 8347, 'Buddy Thunderstruck S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d6tcyVBxyb3mSmHu0zBfIDID8gK.jpg'),
(116776, 8347, 'Buddy Thunderstruck S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/708280SgFeYZGRvYI2tqL1Qscav.jpg'),
(116777, 8347, 'Buddy Thunderstruck S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z1pCFDC2RK9nRDg41OF7fu88VNC.jpg'),
(116778, 8347, 'Buddy Thunderstruck S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zQgNoEaCUfVi1j7Z6nGS4xl4dXp.jpg'),
(116779, 8348, 'Castlevania Noturno S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n3nXWtH47MpxKLhae6uZTtEMbfn.jpg'),
(116780, 8348, 'Castlevania Noturno S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mvqJY2RmIw5hk0qOn1oG3gRfCgk.jpg'),
(116781, 8348, 'Castlevania Noturno S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aY7azwun9mWxFdk8QC3t2rAzcSd.jpg'),
(116782, 8348, 'Castlevania Noturno S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k2HwlIh6txqesGGFe28ecO465xp.jpg'),
(116783, 8348, 'Castlevania Noturno S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eQiYkplCwqCzjhnNiAZCVPKXoWo.jpg'),
(116784, 8348, 'Castlevania Noturno S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wLSenC11V8f5cKi9D8rE9IjaGFG.jpg'),
(116785, 8348, 'Castlevania Noturno S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dUBBX9T3nkwEcvF3REH2AKvBsOc.jpg'),
(116786, 8348, 'Castlevania Noturno S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pRPTloU49kbrrMMbfrisBmCCuFo.jpg'),
(116787, 8349, 'Castlevania Noturno S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/665399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tcc85fepTZLkfKx7ZscSjRlF17V.jpg'),
(116788, 8349, 'Castlevania Noturno S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/665400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tcc85fepTZLkfKx7ZscSjRlF17V.jpg'),
(116789, 8349, 'Castlevania Noturno S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/665401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tcc85fepTZLkfKx7ZscSjRlF17V.jpg'),
(116790, 8349, 'Castlevania Noturno S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/665402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tcc85fepTZLkfKx7ZscSjRlF17V.jpg'),
(116791, 8349, 'Castlevania Noturno S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/665403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tcc85fepTZLkfKx7ZscSjRlF17V.jpg'),
(116792, 8349, 'Castlevania Noturno S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/665404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tcc85fepTZLkfKx7ZscSjRlF17V.jpg'),
(116793, 8349, 'Castlevania Noturno S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/665405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tcc85fepTZLkfKx7ZscSjRlF17V.jpg'),
(116794, 8349, 'Castlevania Noturno S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/665406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tcc85fepTZLkfKx7ZscSjRlF17V.jpg'),
(116795, 8350, 'Drag Race Mexico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p08hWkYyA3kQQ1hfH2bqWSVogAt.jpg'),
(116796, 8350, 'Drag Race Mexico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3eVf1nuyochSmPCSNJUd7ezFYjs.jpg'),
(116797, 8350, 'Drag Race Mexico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/quLod66VF0ipkuPCRCRbSc6zCg9.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(116798, 8350, 'Drag Race Mexico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eQpW90vsU7otQm3qISXLp86DX4Z.jpg'),
(116799, 8350, 'Drag Race Mexico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o1cGCsBpDJhb7Lts1CS0s4EQ9uD.jpg'),
(116800, 8350, 'Drag Race Mexico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9x4AmRjLAquVdpMWJaj0pp3WZhY.jpg'),
(116801, 8350, 'Drag Race Mexico S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aPdxuTTyqt7vxZ2ymEbokMm4J0S.jpg'),
(116802, 8350, 'Drag Race Mexico S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jaBtDpet7sPRDGjR86KseqnKHCp.jpg'),
(116803, 8350, 'Drag Race Mexico S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xh3AaMFFKlbnZoqEnu9iHxaSns0.jpg'),
(116804, 8350, 'Drag Race Mexico S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4kwQsq94fQuHCEAu4CFskLdAKT9.jpg'),
(116805, 8350, 'Drag Race Mexico S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2n7NnOltE7A8m5yQ3vX83qy950.jpg'),
(116806, 8350, 'Drag Race Mexico S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nxSXgVHWZIFWHgPhUeQLqRfk6o4.jpg'),
(116807, 8351, 'Encontros Extraterrestres S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cgvEMp6SmjCp7g5fKQbdQp8WWBp.jpg'),
(116808, 8351, 'Encontros Extraterrestres S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a12Kv1mejZt11fp1E3vgiaHqfFi.jpg'),
(116809, 8351, 'Encontros Extraterrestres S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iZ6WU6sldkrH0Fsk5G4IOlXGGhi.jpg'),
(116810, 8351, 'Encontros Extraterrestres S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bZ7P6qi04ohi9JivRKWkCFyL1M9.jpg'),
(116811, 8352, 'Grandes Chefs Torneio dos Campeoes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116812, 8352, 'Grandes Chefs Torneio dos Campeoes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116813, 8352, 'Grandes Chefs Torneio dos Campeoes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116814, 8352, 'Grandes Chefs Torneio dos Campeoes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116815, 8352, 'Grandes Chefs Torneio dos Campeoes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116816, 8353, 'Grandes Chefs Torneio dos Campeoes S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116817, 8353, 'Grandes Chefs Torneio dos Campeoes S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116818, 8353, 'Grandes Chefs Torneio dos Campeoes S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116819, 8353, 'Grandes Chefs Torneio dos Campeoes S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116820, 8353, 'Grandes Chefs Torneio dos Campeoes S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116821, 8353, 'Grandes Chefs Torneio dos Campeoes S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116822, 8353, 'Grandes Chefs Torneio dos Campeoes S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116823, 8353, 'Grandes Chefs Torneio dos Campeoes S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116824, 8353, 'Grandes Chefs Torneio dos Campeoes S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116825, 8353, 'Grandes Chefs Torneio dos Campeoes S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116826, 8353, 'Grandes Chefs Torneio dos Campeoes S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116827, 8353, 'Grandes Chefs Torneio dos Campeoes S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116828, 8353, 'Grandes Chefs Torneio dos Campeoes S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116829, 8354, 'Grandes Chefs Torneio dos Campeoes S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116830, 8354, 'Grandes Chefs Torneio dos Campeoes S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116831, 8354, 'Grandes Chefs Torneio dos Campeoes S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116832, 8354, 'Grandes Chefs Torneio dos Campeoes S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116833, 8354, 'Grandes Chefs Torneio dos Campeoes S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116834, 8354, 'Grandes Chefs Torneio dos Campeoes S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116835, 8354, 'Grandes Chefs Torneio dos Campeoes S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116836, 8354, 'Grandes Chefs Torneio dos Campeoes S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116837, 8355, 'Grandes Chefs Torneio dos Campeoes S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/611955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116838, 8355, 'Grandes Chefs Torneio dos Campeoes S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/611956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116839, 8355, 'Grandes Chefs Torneio dos Campeoes S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/611957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116840, 8355, 'Grandes Chefs Torneio dos Campeoes S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/611958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116841, 8355, 'Grandes Chefs Torneio dos Campeoes S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/611959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116842, 8355, 'Grandes Chefs Torneio dos Campeoes S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/412739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116843, 8355, 'Grandes Chefs Torneio dos Campeoes S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/412740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116844, 8355, 'Grandes Chefs Torneio dos Campeoes S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/412741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nIXTIiR2iXfou4LA0PITjgw1qUa.jpg'),
(116845, 8356, 'Jericho S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7Ax6uxtrwciElTsaJuYW6n2Fn7.jpg'),
(116846, 8356, 'Jericho S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6mQzBDyCZQ7fZ48cpVM1EELiJoU.jpg'),
(116847, 8356, 'Jericho S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qWFPJXQlUmzAGf50NiqxXvVht1p.jpg'),
(116848, 8356, 'Jericho S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQ0d9JdSZNhACSqQix1S81Usydh.jpg'),
(116849, 8356, 'Jericho S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mp3aUtEbNdPur3lcteEqyPiJOIw.jpg'),
(116850, 8356, 'Jericho S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/96LF25GTB6GaiFNZK3M6kyUqOlY.jpg'),
(116851, 8356, 'Jericho S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9RkFGPK4Z9lGUOVuCJySiWAYNYm.jpg'),
(116852, 8356, 'Jericho S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/249xLNnmjjgFEZCUcMV5oKJX2Q9.jpg'),
(116853, 8356, 'Jericho S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/myCYOyLjXtQEffnlda8uUyg5hDY.jpg'),
(116854, 8356, 'Jericho S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i9sZeodItBp2Q41BVfGhtchNl2Y.jpg'),
(116855, 8356, 'Jericho S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gPSRoa2hhqhTpAYMQ8QgRM3hmDn.jpg'),
(116856, 8356, 'Jericho S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1pnnpJVhUiXsG9SNjCBpfVwusuZ.jpg'),
(116857, 8356, 'Jericho S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odo8Jisdf7B1HNTmibIApfOfT9E.jpg'),
(116858, 8356, 'Jericho S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/235133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6CvvSPYdCTGIzgKtlWNTexEAMTp.jpg'),
(116859, 8356, 'Jericho S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/235134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvR8ppIKOyExdXL7zu3d78ns4Zc.jpg'),
(116860, 8356, 'Jericho S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/235135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2dkYqsitqmqfKcIhENPGiEXCtS.jpg'),
(116861, 8356, 'Jericho S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/235136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7q1IKSehrDuzt95yPG2nI3S9f8b.jpg'),
(116862, 8356, 'Jericho S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/235137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3nD8J13Fb2DxekmgBtsVFwGdO1t.jpg'),
(116863, 8356, 'Jericho S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/235138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1vZ4VWdGb0XY8RX9HFhLCvakop6.jpg'),
(116864, 8356, 'Jericho S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/235139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3DplLZbWFw0l5m2zUibXEypH2zq.jpg'),
(116865, 8356, 'Jericho S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/235140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j6rwxtwm1xZ3qoF3gfXO332qFMS.jpg'),
(116866, 8356, 'Jericho S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/235141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aMWbScHw32bJ1v4ZEJOuR3oONUA.jpg'),
(116867, 8356, 'Jericho S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/235142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a57H9UsS388Av2LSLKO9inNmY7j.jpg'),
(116868, 8357, 'Jericho S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tdVusaYDtmh7KKqDyre4N3HT9l0.jpg'),
(116869, 8357, 'Jericho S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ltjNqyXMxiLAkaAEbtRSmC1aCTL.jpg'),
(116870, 8357, 'Jericho S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i6vvf6nFGFCtCEqwCeSvT7txFNR.jpg'),
(116871, 8357, 'Jericho S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dDBz34n8e5j7smk2hSOOYZDnN52.jpg'),
(116872, 8357, 'Jericho S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fekxNCPR2WnSOooSwBuNRkoNQWT.jpg'),
(116873, 8357, 'Jericho S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fECWlZH3u5r6T2GGqoFwwnF9f6B.jpg'),
(116874, 8357, 'Jericho S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l8SjGbV1KzgbOfCzv0gTTvxwC0o.jpg'),
(116875, 8358, 'L Pop S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jSDkFWppfQf4INHD2JmzLb4dQtz.jpg'),
(116876, 8358, 'L Pop S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qvatnPaQx5nwm2DMBY0yoXZKsYz.jpg'),
(116877, 8358, 'L Pop S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9yUMC3OQw5ufk1eyWJTV2SkyB4B.jpg'),
(116878, 8358, 'L Pop S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6eHFpcR5TToGdSDGyc0JJlWxcSS.jpg'),
(116879, 8358, 'L Pop S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fQlpUS03tn0Xw803ysWy3hoHaMf.jpg'),
(116880, 8358, 'L Pop S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j914WsHzelGulRNmLRFhu6eg1iA.jpg'),
(116881, 8359, 'Magnolia Table Receitas com Joanna Gaines S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfj36wEwfmbWj8nUCUMQVlPgVkf.jpg'),
(116882, 8359, 'Magnolia Table Receitas com Joanna Gaines S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tWDlhGNZDsk9psYoxxDaPDKPy3u.jpg'),
(116883, 8359, 'Magnolia Table Receitas com Joanna Gaines S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7XWTMhalA7pBn2HF0Q0n2ZBNd5i.jpg'),
(116884, 8359, 'Magnolia Table Receitas com Joanna Gaines S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sLnTCAwaidHSf02XZUSXtdmUt0Z.jpg'),
(116885, 8359, 'Magnolia Table Receitas com Joanna Gaines S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2tXKHTyiEFq3f1qQ441fnopMAe.jpg'),
(116886, 8359, 'Magnolia Table Receitas com Joanna Gaines S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6tzhy7d7fkZHj2J4lvrN6Fxo5vX.jpg'),
(116887, 8360, 'Magnolia Table Receitas com Joanna Gaines S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f3VMIeoFuJ7eisQGP9NfkZF04ov.jpg'),
(116888, 8360, 'Magnolia Table Receitas com Joanna Gaines S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rey68UH3sB5WrpLLULgUgYNQRtw.jpg'),
(116889, 8360, 'Magnolia Table Receitas com Joanna Gaines S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ABcYSimouoYb9fRsvf41ZWfX90.jpg'),
(116890, 8360, 'Magnolia Table Receitas com Joanna Gaines S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1zkv6r0uTx4X4DJjwaoJNwoYJrj.jpg'),
(116891, 8360, 'Magnolia Table Receitas com Joanna Gaines S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2o0OByUOaexN5V8EW8WNlZs7bd4.jpg'),
(116892, 8360, 'Magnolia Table Receitas com Joanna Gaines S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iVzSJbRNowwGItZAYqjdAWYNYL3.jpg'),
(116893, 8361, 'Magnolia Table Receitas com Joanna Gaines S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7COJ1dyZ7d6B3IXSCLSQZt5uJte.jpg'),
(116894, 8361, 'Magnolia Table Receitas com Joanna Gaines S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sGrc9e9Pt0ik76YkxHhEYlj0Koi.jpg'),
(116895, 8361, 'Magnolia Table Receitas com Joanna Gaines S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/265uhe5xYGSZE4vsxuvGvLuPDYV.jpg'),
(116896, 8361, 'Magnolia Table Receitas com Joanna Gaines S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tXSYsrELcUmiZtdL53YIcH1Rwx6.jpg'),
(116897, 8361, 'Magnolia Table Receitas com Joanna Gaines S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hjD6CPzH4Pc13pBIqCDUyNI19F4.jpg'),
(116898, 8361, 'Magnolia Table Receitas com Joanna Gaines S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9FH3nKd6trW2okKa6lZ8Nw22R3U.jpg'),
(116899, 8361, 'Magnolia Table Receitas com Joanna Gaines S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9SQkja0cFDlhAMaz6w98H6PAtNn.jpg'),
(116900, 8362, 'Magnolia Table Receitas com Joanna Gaines S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tHPNJ542wwoxLhddRIXi5PUjeTi.jpg'),
(116901, 8362, 'Magnolia Table Receitas com Joanna Gaines S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4NKfd1tGtzXYFZoRw2htp1gQ3pU.jpg'),
(116902, 8362, 'Magnolia Table Receitas com Joanna Gaines S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oPMNRMv77I7F1wDXbApRx35TVqB.jpg'),
(116903, 8362, 'Magnolia Table Receitas com Joanna Gaines S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dKrlJHHsFg683fYW8H1BDJkYfRj.jpg'),
(116904, 8362, 'Magnolia Table Receitas com Joanna Gaines S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dKrlJHHsFg683fYW8H1BDJkYfRj.jpg'),
(116905, 8362, 'Magnolia Table Receitas com Joanna Gaines S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dKrlJHHsFg683fYW8H1BDJkYfRj.jpg'),
(116906, 8363, 'Magnolia Table Receitas com Joanna Gaines S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5l1pGF9ljN7hwSlUrPgnoCAJrtk.jpg'),
(116907, 8363, 'Magnolia Table Receitas com Joanna Gaines S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xFwikjFSI2HybL2Zfv1lSAUZSBw.jpg'),
(116908, 8363, 'Magnolia Table Receitas com Joanna Gaines S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/33jdEhrYV9GuefEbL46JSjv4TcC.jpg'),
(116909, 8363, 'Magnolia Table Receitas com Joanna Gaines S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bNpK02dqOvtChN40PUZNUIqQFCL.jpg'),
(116910, 8363, 'Magnolia Table Receitas com Joanna Gaines S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eweVPsOxMpaQHNmxG5CPQQUWn8F.jpg'),
(116911, 8363, 'Magnolia Table Receitas com Joanna Gaines S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iUzojwl7V3jphvrAdzTgftaOKsf.jpg'),
(116912, 8364, 'Magnolia Table Receitas com Joanna Gaines S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5baCfyG6tSXmi2MIuX4K1L1OwTB.jpg'),
(116913, 8364, 'Magnolia Table Receitas com Joanna Gaines S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mC0uthnYlAhq0s0CYAmkLYS5XlD.jpg'),
(116914, 8364, 'Magnolia Table Receitas com Joanna Gaines S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ceB8hNJsKnjvyXf8LJINaIiu0Ej.jpg'),
(116915, 8364, 'Magnolia Table Receitas com Joanna Gaines S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6XN1y6cfXxbgP6FrZkpQeJH7k3k.jpg'),
(116916, 8364, 'Magnolia Table Receitas com Joanna Gaines S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pSCoSi27xvkxLlsQ5TrmRl3pPVR.jpg'),
(116917, 8364, 'Magnolia Table Receitas com Joanna Gaines S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5f84jZfKcW6ZDuQIxO0myyYfbBd.jpg'),
(116918, 8365, 'Magnolia Table Receitas com Joanna Gaines S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fZmK45Tpvg3vCsxEbIrGFY5CdsR.jpg'),
(116919, 8365, 'Magnolia Table Receitas com Joanna Gaines S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lo4iinGNu069Bou5lePCpVuDDqE.jpg'),
(116920, 8365, 'Magnolia Table Receitas com Joanna Gaines S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/flUNvQnI1bSjqjoSj4saZk9bcNE.jpg'),
(116921, 8365, 'Magnolia Table Receitas com Joanna Gaines S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qslwSELp9CIuafDTQX9uvP9BNDV.jpg'),
(116922, 8365, 'Magnolia Table Receitas com Joanna Gaines S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lJXa1nQXWNeKfDMuJVSmb6FlMop.jpg'),
(116923, 8365, 'Magnolia Table Receitas com Joanna Gaines S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v7mdMZZHLYDhN63webCzzDvMOVH.jpg'),
(116924, 8366, 'My Love From The Star S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSv4ClZhdZrCyvXOIHxBQT1FzYq.jpg'),
(116925, 8366, 'My Love From The Star S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSv4ClZhdZrCyvXOIHxBQT1FzYq.jpg'),
(116926, 8366, 'My Love From The Star S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSv4ClZhdZrCyvXOIHxBQT1FzYq.jpg'),
(116927, 8366, 'My Love From The Star S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSv4ClZhdZrCyvXOIHxBQT1FzYq.jpg'),
(116928, 8366, 'My Love From The Star S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSv4ClZhdZrCyvXOIHxBQT1FzYq.jpg'),
(116929, 8366, 'My Love From The Star S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSv4ClZhdZrCyvXOIHxBQT1FzYq.jpg'),
(116930, 8366, 'My Love From The Star S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSv4ClZhdZrCyvXOIHxBQT1FzYq.jpg'),
(116931, 8366, 'My Love From The Star S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSv4ClZhdZrCyvXOIHxBQT1FzYq.jpg'),
(116932, 8366, 'My Love From The Star S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSv4ClZhdZrCyvXOIHxBQT1FzYq.jpg'),
(116933, 8366, 'My Love From The Star S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSv4ClZhdZrCyvXOIHxBQT1FzYq.jpg'),
(116934, 8366, 'My Love From The Star S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSv4ClZhdZrCyvXOIHxBQT1FzYq.jpg'),
(116935, 8366, 'My Love From The Star S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSv4ClZhdZrCyvXOIHxBQT1FzYq.jpg'),
(116936, 8366, 'My Love From The Star S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSv4ClZhdZrCyvXOIHxBQT1FzYq.jpg'),
(116937, 8366, 'My Love From The Star S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/235063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSv4ClZhdZrCyvXOIHxBQT1FzYq.jpg'),
(116938, 8366, 'My Love From The Star S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/235064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSv4ClZhdZrCyvXOIHxBQT1FzYq.jpg'),
(116939, 8366, 'My Love From The Star S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/235065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSv4ClZhdZrCyvXOIHxBQT1FzYq.jpg'),
(116940, 8366, 'My Love From The Star S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/235066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSv4ClZhdZrCyvXOIHxBQT1FzYq.jpg'),
(116941, 8366, 'My Love From The Star S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/235067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSv4ClZhdZrCyvXOIHxBQT1FzYq.jpg'),
(116942, 8366, 'My Love From The Star S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/235068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSv4ClZhdZrCyvXOIHxBQT1FzYq.jpg'),
(116943, 8366, 'My Love From The Star S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/235069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSv4ClZhdZrCyvXOIHxBQT1FzYq.jpg'),
(116944, 8366, 'My Love From The Star S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/235070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSv4ClZhdZrCyvXOIHxBQT1FzYq.jpg'),
(116945, 8367, 'NCIS Nova Orleans S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iCyfyycuC66DKxzB5Y85MM74oFK.jpg'),
(116946, 8367, 'NCIS Nova Orleans S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3jBkKUys7UKKwxQ5eEAkT6XuhJw.jpg'),
(116947, 8367, 'NCIS Nova Orleans S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zuJiRJU0ROmIgqWka0EG0MhqDy.jpg'),
(116948, 8367, 'NCIS Nova Orleans S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aepp8DJs5xOLI6OYzrE7aB2F3e.jpg'),
(116949, 8367, 'NCIS Nova Orleans S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uYEyUdhdO4mtH3TE4hWW4HOmy7k.jpg'),
(116950, 8367, 'NCIS Nova Orleans S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Xc4zg71Q4VcZzxyK9YPSgLotJ4.jpg'),
(116951, 8367, 'NCIS Nova Orleans S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3mD0U2La9jdHazv4vFosJFXYzjX.jpg'),
(116952, 8367, 'NCIS Nova Orleans S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nT0SIyfdbAED2Yhs4YMivmdYMJ2.jpg'),
(116953, 8367, 'NCIS Nova Orleans S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qk8wMslVceOAehktR9Jm5CAAsBM.jpg'),
(116954, 8367, 'NCIS Nova Orleans S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iNF9glNFt1NVt049qwFAN7k3y0m.jpg'),
(116955, 8367, 'NCIS Nova Orleans S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ioEclJ1HpLommVN3Jz3skqWfZQp.jpg'),
(116956, 8367, 'NCIS Nova Orleans S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1JpvWkb3YbshugTpE9lZc3eg53F.jpg'),
(116957, 8367, 'NCIS Nova Orleans S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xKBoUphLvwPBwCh8Gj4BJqZJnVj.jpg'),
(116958, 8367, 'NCIS Nova Orleans S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/235016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t2aVHCyy085PAHizumx7DQYIJ5D.jpg'),
(116959, 8367, 'NCIS Nova Orleans S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/235017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mOvSnnmO40tpUnLizdfMrCGSGsS.jpg'),
(116960, 8367, 'NCIS Nova Orleans S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/235018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/81GBz5VqItYFn6pmNiOAQnoWsFk.jpg'),
(116961, 8367, 'NCIS Nova Orleans S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/235019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6LKtqzt5rUanLIg0bWa6PJ0iSFk.jpg'),
(116962, 8367, 'NCIS Nova Orleans S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/235020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eI5zFndXi16tga6ToXUlWShy25Q.jpg'),
(116963, 8367, 'NCIS Nova Orleans S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/235021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n1uUPsCVaBnX4jBex0AHRgnwHhN.jpg'),
(116964, 8367, 'NCIS Nova Orleans S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/235022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yUf8sE7ExxaLl9HNRx231y3aSBS.jpg'),
(116965, 8367, 'NCIS Nova Orleans S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/235023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMLZymvQ8z9B4cudek2rQdhnCPU.jpg'),
(116966, 8367, 'NCIS Nova Orleans S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/235024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dXRoEU9N4AgbJryD0M3UCbT65zv.jpg'),
(116967, 8367, 'NCIS Nova Orleans S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/235025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hTBzjnKwamBdU13ChDcGE847EHq.jpg'),
(116968, 8368, 'NCIS Nova Orleans S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/235026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/56MIS62e76O4vGHwY1MFNwJqPU3.jpg'),
(116969, 8368, 'NCIS Nova Orleans S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8iVzmKbGElhLrYqR39vAm4FCGHz.jpg'),
(116970, 8368, 'NCIS Nova Orleans S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/baH1B33xRnRSKDiWHRRnEmoRXuq.jpg'),
(116971, 8368, 'NCIS Nova Orleans S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9wsWvbPwmEgNIlqwK654TCJIOBb.jpg'),
(116972, 8368, 'NCIS Nova Orleans S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/235030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/erKxa38j0VBh0QLJsJ9KFQRHZOF.jpg'),
(116973, 8368, 'NCIS Nova Orleans S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/235031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVwxC6elYJfGZiGuPagbKqlacrP.jpg'),
(116974, 8368, 'NCIS Nova Orleans S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/235032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2022om2LkHTmisIl30oe20Xuc5.jpg'),
(116975, 8368, 'NCIS Nova Orleans S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/235033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAkytWhg3t0g3qiHkuogkbUDHcl.jpg'),
(116976, 8368, 'NCIS Nova Orleans S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/235034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5IvYw3qBNU54spcmg8vrZSVzScQ.jpg'),
(116977, 8368, 'NCIS Nova Orleans S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/235035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/14AJh124ITLPatomgQ2oMJsP4tB.jpg'),
(116978, 8368, 'NCIS Nova Orleans S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/235036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oztNsEe9Y8Q2c8qnvLI4W7hG37j.jpg'),
(116979, 8368, 'NCIS Nova Orleans S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/235037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Hig6w6EWnkLuxihraCKShrBwf2.jpg'),
(116980, 8368, 'NCIS Nova Orleans S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/235038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tSlsdcXSvmoo2MEovDBUd0Lltt5.jpg'),
(116981, 8368, 'NCIS Nova Orleans S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/235039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m8YaXXEPSqMQk8IlGZGBNP4BKDN.jpg'),
(116982, 8368, 'NCIS Nova Orleans S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/235040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u1Qvg7EIpD5KQfK8IIr3z5G3R1w.jpg'),
(116983, 8368, 'NCIS Nova Orleans S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/235041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z6IgkuNv9E24DV6SI9dvDVBo2gV.jpg'),
(116984, 8368, 'NCIS Nova Orleans S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/235042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gFSnSiTag1Wdg13UfYyrm45665X.jpg'),
(116985, 8368, 'NCIS Nova Orleans S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/235043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iFJfEDY1KIOXt0R6J12heAQ0gpY.jpg'),
(116986, 8368, 'NCIS Nova Orleans S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/235044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lUtLsycqVPlzB3hHMTyfYDEBmFd.jpg'),
(116987, 8368, 'NCIS Nova Orleans S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/235045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9LdorvUghwo9Fx2RJfTEY4zZxkw.jpg'),
(116988, 8368, 'NCIS Nova Orleans S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/235046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jdtrrb03mNVxLZ9RTyNlpuw9dHb.jpg'),
(116989, 8368, 'NCIS Nova Orleans S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/235047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a0DSWJfAl7eJb9tVZo84LVSHFkE.jpg'),
(116990, 8368, 'NCIS Nova Orleans S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/235048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bax8iCmAno2PoBrFK0UAYJlgCQU.jpg'),
(116991, 8368, 'NCIS Nova Orleans S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/235049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uddiJfEjqVFulyZz41kLJM7Pvq7.jpg'),
(116992, 8369, 'NCIS Nova Orleans S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/359436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(116993, 8369, 'NCIS Nova Orleans S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/359437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(116994, 8369, 'NCIS Nova Orleans S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/359438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(116995, 8369, 'NCIS Nova Orleans S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/359439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(116996, 8369, 'NCIS Nova Orleans S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/359440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(116997, 8369, 'NCIS Nova Orleans S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/359441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(116998, 8369, 'NCIS Nova Orleans S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/359442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(116999, 8369, 'NCIS Nova Orleans S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/359443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117000, 8369, 'NCIS Nova Orleans S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/359444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117001, 8369, 'NCIS Nova Orleans S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/359445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117002, 8369, 'NCIS Nova Orleans S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/359446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117003, 8369, 'NCIS Nova Orleans S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/359447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117004, 8369, 'NCIS Nova Orleans S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/359448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117005, 8369, 'NCIS Nova Orleans S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/359449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117006, 8369, 'NCIS Nova Orleans S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/359450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117007, 8369, 'NCIS Nova Orleans S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/359451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117008, 8369, 'NCIS Nova Orleans S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/359452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117009, 8369, 'NCIS Nova Orleans S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/359453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117010, 8369, 'NCIS Nova Orleans S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/359454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117011, 8369, 'NCIS Nova Orleans S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/359455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117012, 8369, 'NCIS Nova Orleans S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/359456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117013, 8369, 'NCIS Nova Orleans S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/359457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117014, 8369, 'NCIS Nova Orleans S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/359458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117015, 8369, 'NCIS Nova Orleans S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/359459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117016, 8370, 'NCIS Nova Orleans S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/359460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117017, 8370, 'NCIS Nova Orleans S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/359461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117018, 8370, 'NCIS Nova Orleans S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/359462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117019, 8370, 'NCIS Nova Orleans S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/359463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117020, 8370, 'NCIS Nova Orleans S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/359464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117021, 8370, 'NCIS Nova Orleans S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/359465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117022, 8370, 'NCIS Nova Orleans S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/359466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117023, 8370, 'NCIS Nova Orleans S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/359467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117024, 8370, 'NCIS Nova Orleans S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/359468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117025, 8370, 'NCIS Nova Orleans S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/359469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117026, 8370, 'NCIS Nova Orleans S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/359470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117027, 8370, 'NCIS Nova Orleans S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/359471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117028, 8370, 'NCIS Nova Orleans S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/359472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117029, 8370, 'NCIS Nova Orleans S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/359473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117030, 8370, 'NCIS Nova Orleans S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/359474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117031, 8370, 'NCIS Nova Orleans S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/359475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117032, 8370, 'NCIS Nova Orleans S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/359476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117033, 8370, 'NCIS Nova Orleans S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/359477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117034, 8370, 'NCIS Nova Orleans S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/359478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117035, 8370, 'NCIS Nova Orleans S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/359479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117036, 8370, 'NCIS Nova Orleans S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/359480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117037, 8370, 'NCIS Nova Orleans S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/359481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117038, 8370, 'NCIS Nova Orleans S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/359482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117039, 8370, 'NCIS Nova Orleans S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/359483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WJJUUZODmRTcFydLDBUtiztL6x.jpg'),
(117040, 8371, 'NCIS Nova Orleans S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/453956.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bkla6h5HrVZOt8jFWPxtbCPMR4S.jpg'),
(117041, 8371, 'NCIS Nova Orleans S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/453957.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gGIGlcdAqzcXoIf0fqcYGLQZD60.jpg'),
(117042, 8371, 'NCIS Nova Orleans S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/453958.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hcjcUw7Z73FkA4SnQH5hMq2224n.jpg'),
(117043, 8371, 'NCIS Nova Orleans S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/453959.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cm4Jq8AZwtDESn4HM9vVtduvbqA.jpg'),
(117044, 8371, 'NCIS Nova Orleans S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/453960.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h4SZQ0CNRGhuboPTRP5XTsPF9SV.jpg'),
(117045, 8371, 'NCIS Nova Orleans S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/453961.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kwPH6ffldpXTHI3IzvAB0h3Wj12.jpg'),
(117046, 8371, 'NCIS Nova Orleans S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/453962.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z04TucaUlkvyvun8G2NC3UJJMDA.jpg'),
(117047, 8371, 'NCIS Nova Orleans S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/453963.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yOlOSJyNby6WcTdiClGl0iRHp64.jpg'),
(117048, 8371, 'NCIS Nova Orleans S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/453964.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qO0NsKM3PQ5p0prlWxOkYnSPDdl.jpg'),
(117049, 8371, 'NCIS Nova Orleans S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/453965.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lEET7yjJwrSUCeBx2ygQdriqMVl.jpg'),
(117050, 8371, 'NCIS Nova Orleans S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/453966.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c7BgyqvxjlG92dZnU9Yh9sCf1DY.jpg'),
(117051, 8371, 'NCIS Nova Orleans S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/453967.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uvlZ6Pzwz65k7bL9ZXcsK9jSnbH.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(117052, 8371, 'NCIS Nova Orleans S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/453968.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/43MfpjQ1JUusrL8ptzoKlKckBBp.jpg'),
(117053, 8371, 'NCIS Nova Orleans S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/453969.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5eiavIX82biofb3Vc4vQ7f5pidu.jpg'),
(117054, 8371, 'NCIS Nova Orleans S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/453970.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gIyGaX7IDQ8dhgMhCUfbBhulZ9c.jpg'),
(117055, 8371, 'NCIS Nova Orleans S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/453971.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n17tkqrp8y4WVuuw1ZkcQTiKhPi.jpg'),
(117056, 8371, 'NCIS Nova Orleans S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/453972.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hyYkashflFqhOple3QDG4r8dvhL.jpg'),
(117057, 8371, 'NCIS Nova Orleans S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/453973.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uEwAPeq4jjug20S7OlpfhrZjfAd.jpg'),
(117058, 8371, 'NCIS Nova Orleans S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/453974.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2xUGc5BxSEbRlIeDGCWyTaHyyV0.jpg'),
(117059, 8371, 'NCIS Nova Orleans S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/453975.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yUHTNJtWofDGOPkRry5C1AqVqa1.jpg'),
(117060, 8371, 'NCIS Nova Orleans S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/453976.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mrsCGam71w53GJUZOeHsyi3GKth.jpg'),
(117061, 8371, 'NCIS Nova Orleans S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/453977.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nESDMGBgSV16sVoKRpI6N3X1brq.jpg'),
(117062, 8371, 'NCIS Nova Orleans S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/453978.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hzuyxM7xLQmqLvV8UUYd9xeV1n4.jpg'),
(117063, 8371, 'NCIS Nova Orleans S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/453979.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3LFg1TzvDQdmSAiF1mFtJRYBYbI.jpg'),
(117064, 8372, 'Palmeiras 13 finais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k0JZyYwCrGWOE6kd0Wb9bGfuplY.jpg'),
(117065, 8372, 'Palmeiras 13 finais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/235000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k0JZyYwCrGWOE6kd0Wb9bGfuplY.jpg'),
(117066, 8372, 'Palmeiras 13 finais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/235001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k0JZyYwCrGWOE6kd0Wb9bGfuplY.jpg'),
(117067, 8372, 'Palmeiras 13 finais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/235002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k0JZyYwCrGWOE6kd0Wb9bGfuplY.jpg'),
(117068, 8373, 'Sabores da Fazenda com Molly S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117069, 8373, 'Sabores da Fazenda com Molly S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6TanUrt2tfM9ikfJycuNXHDSlt.jpg'),
(117070, 8373, 'Sabores da Fazenda com Molly S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117071, 8373, 'Sabores da Fazenda com Molly S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xWTFaebpCxqTOe0ky9k0GD8f9g2.jpg'),
(117072, 8373, 'Sabores da Fazenda com Molly S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e8lXGq1Ys0AVihduI6zeAoQBxm1.jpg'),
(117073, 8373, 'Sabores da Fazenda com Molly S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eEMWnb7bmCYfNeWFaO02kz1D1lI.jpg'),
(117074, 8373, 'Sabores da Fazenda com Molly S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gvLka1cWbmxKyUfJbd2cyQrCjfI.jpg'),
(117075, 8374, 'Sabores da Fazenda com Molly S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117076, 8374, 'Sabores da Fazenda com Molly S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2C5NqVqOUlgNy9TJJbae2BaESfK.jpg'),
(117077, 8374, 'Sabores da Fazenda com Molly S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117078, 8374, 'Sabores da Fazenda com Molly S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xSunbN26R8UOfiZ5bK6FebmBYMN.jpg'),
(117079, 8374, 'Sabores da Fazenda com Molly S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117080, 8374, 'Sabores da Fazenda com Molly S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/me4m9iRslXoKsO1aXuo6wH6sHWP.jpg'),
(117081, 8374, 'Sabores da Fazenda com Molly S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117082, 8374, 'Sabores da Fazenda com Molly S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117083, 8374, 'Sabores da Fazenda com Molly S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117084, 8374, 'Sabores da Fazenda com Molly S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3lMk34oYaGIX1S8kc05J7cijY2t.jpg'),
(117085, 8374, 'Sabores da Fazenda com Molly S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/alfA3ZJDr2yxdBQil0xGyAzJRRd.jpg'),
(117086, 8374, 'Sabores da Fazenda com Molly S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5qi5Hs9IwJKiPPHgP6YNehLFu94.jpg'),
(117087, 8374, 'Sabores da Fazenda com Molly S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lz4Rj43YeklOJLyepzNyYmqSiru.jpg'),
(117088, 8375, 'Sabores da Fazenda com Molly S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gtkmbchSeKJJqOSXLDBL23LpLIf.jpg'),
(117089, 8375, 'Sabores da Fazenda com Molly S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117090, 8375, 'Sabores da Fazenda com Molly S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vYVxx0hB9soDTvuq15Fwohum9sj.jpg'),
(117091, 8375, 'Sabores da Fazenda com Molly S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rjtOsBfnTXbL3iRGwim5WL7NQ2D.jpg'),
(117092, 8375, 'Sabores da Fazenda com Molly S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/waB9vWMNfW6jMll6ixEbe69MECM.jpg'),
(117093, 8375, 'Sabores da Fazenda com Molly S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gFPQedKvQw5JjPaLz1jGrCA5X6I.jpg'),
(117094, 8376, 'Sabores da Fazenda com Molly S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117095, 8376, 'Sabores da Fazenda com Molly S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A2eynm0x9TJQ3CO8vUXRXRayFI5.jpg'),
(117096, 8376, 'Sabores da Fazenda com Molly S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kGhHZpfwhEKnBiniTaC6tHZ7iY6.jpg'),
(117097, 8376, 'Sabores da Fazenda com Molly S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXy2uTkIPWxhHw0YmLNsSKdLUTF.jpg'),
(117098, 8376, 'Sabores da Fazenda com Molly S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117099, 8376, 'Sabores da Fazenda com Molly S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mP72FbVrGNMcnWggFAkxGiJaLpo.jpg'),
(117100, 8376, 'Sabores da Fazenda com Molly S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117101, 8376, 'Sabores da Fazenda com Molly S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117102, 8376, 'Sabores da Fazenda com Molly S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1LoJxRmGdCGe1g7PnN6zWkXviCj.jpg'),
(117103, 8376, 'Sabores da Fazenda com Molly S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vKhSVcPZx5OYleyuCz0e5Ch376a.jpg'),
(117104, 8376, 'Sabores da Fazenda com Molly S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117105, 8376, 'Sabores da Fazenda com Molly S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117106, 8376, 'Sabores da Fazenda com Molly S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117107, 8377, 'Sabores da Fazenda com Molly S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117108, 8377, 'Sabores da Fazenda com Molly S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mHvypMEmgMXDyJriP535YEfSuMu.jpg'),
(117109, 8377, 'Sabores da Fazenda com Molly S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dTPRIAQSseqOgQl7UecjprKwjEt.jpg'),
(117110, 8377, 'Sabores da Fazenda com Molly S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/avlrfs3PUKA3aDRJPpETOdunMIv.jpg'),
(117111, 8377, 'Sabores da Fazenda com Molly S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tKF76Gx0hpPOVLm74Kh1DZyN4pL.jpg'),
(117112, 8377, 'Sabores da Fazenda com Molly S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vTl3rwOfq7T0xTo3IItXpeQNVj1.jpg'),
(117113, 8377, 'Sabores da Fazenda com Molly S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7W5dDUfOCCVkL5v2UnAwUx51270.jpg'),
(117114, 8377, 'Sabores da Fazenda com Molly S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117115, 8377, 'Sabores da Fazenda com Molly S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3VpMg80p2YNvn0YxUCyjqi84wu8.jpg'),
(117116, 8377, 'Sabores da Fazenda com Molly S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p7N7KkXHEnk1t9bVSgtMsN5ih0o.jpg'),
(117117, 8377, 'Sabores da Fazenda com Molly S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vdnhbQx7m0wJAI2SYewmDBYAmtU.jpg'),
(117118, 8377, 'Sabores da Fazenda com Molly S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2b3tEEp3aCEXQTkwvlt9g88fPP.jpg'),
(117119, 8377, 'Sabores da Fazenda com Molly S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lZiQDKRiuEx3dzYns8iwwbgc4LC.jpg'),
(117120, 8378, 'Sabores da Fazenda com Molly S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/doF5cgDuyQ2FquaW06MhDaK2caY.jpg'),
(117121, 8378, 'Sabores da Fazenda com Molly S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117122, 8378, 'Sabores da Fazenda com Molly S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117123, 8378, 'Sabores da Fazenda com Molly S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117124, 8378, 'Sabores da Fazenda com Molly S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dvSkFkIHIuivyQZfxw0Zk607aJa.jpg'),
(117125, 8378, 'Sabores da Fazenda com Molly S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8rjFr46w9Yq4bDsj8TFrLdAsFCb.jpg'),
(117126, 8378, 'Sabores da Fazenda com Molly S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4cppG7cPuvNAbtnD10BvLv3gzdt.jpg'),
(117127, 8378, 'Sabores da Fazenda com Molly S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117128, 8378, 'Sabores da Fazenda com Molly S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/90eLdlUi5aotY5y0JjZOnspqral.jpg'),
(117129, 8378, 'Sabores da Fazenda com Molly S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117130, 8378, 'Sabores da Fazenda com Molly S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wpyYwJKOttXX9CghN3u6olGgNw1.jpg'),
(117131, 8378, 'Sabores da Fazenda com Molly S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117132, 8378, 'Sabores da Fazenda com Molly S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117133, 8379, 'Sabores da Fazenda com Molly S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117134, 8379, 'Sabores da Fazenda com Molly S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117135, 8379, 'Sabores da Fazenda com Molly S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117136, 8379, 'Sabores da Fazenda com Molly S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117137, 8379, 'Sabores da Fazenda com Molly S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117138, 8379, 'Sabores da Fazenda com Molly S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8Ueb4irHFFb7nzhCPtCXQGC8Vn.jpg'),
(117139, 8379, 'Sabores da Fazenda com Molly S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117140, 8379, 'Sabores da Fazenda com Molly S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117141, 8379, 'Sabores da Fazenda com Molly S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117142, 8379, 'Sabores da Fazenda com Molly S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117143, 8379, 'Sabores da Fazenda com Molly S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117144, 8379, 'Sabores da Fazenda com Molly S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6z4xAt1ApAg0ZflX3h3lAySJ1jk.jpg'),
(117145, 8380, 'Sem Escapatoria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9juPUz3qVPqo4rzYqSIPng1c0Uj.jpg'),
(117146, 8380, 'Sem Escapatoria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6EI4pcLJU3YDO6sMW1U0oVVRnn9.jpg'),
(117147, 8380, 'Sem Escapatoria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y5IZRJxFuKVWvVSKPsqhV4I1BKi.jpg'),
(117148, 8380, 'Sem Escapatoria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6LTCy8EJZIwnvKiwnfEaAsZ9E99.jpg'),
(117149, 8380, 'Sem Escapatoria S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tlOwnB7tnrRmOj0S8zFjvbXFv7N.jpg'),
(117150, 8380, 'Sem Escapatoria S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wsqusGLLoeJVjKnqzhAsnvpgY5x.jpg'),
(117151, 8380, 'Sem Escapatoria S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vvSN5akBTIQU2GkxDu9H38egbA6.jpg'),
(117152, 8381, 'A Chuva [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zyHUrI0hdillSeCXZ58hizXR2jw.jpg'),
(117153, 8381, 'A Chuva [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWJ1ftja4kWBSwihLfC7pkVFG1y.jpg'),
(117154, 8381, 'A Chuva [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5sue5OPHgglXHOzm54ebmE6BD3h.jpg'),
(117155, 8381, 'A Chuva [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ULfQ7U6QCyfRRBQiblxFd7U8Lu.jpg'),
(117156, 8381, 'A Chuva [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aVxOY7qzi8qOFgnAVLn5MpGoLjZ.jpg'),
(117157, 8381, 'A Chuva [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glkobcaqOIegRwAf50GAZa73mVC.jpg'),
(117158, 8381, 'A Chuva [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ddfkQJymmssf8ZoVHifDsvN8av.jpg'),
(117159, 8381, 'A Chuva [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3tuYo0x13OhM37mhtgApFzAQiZk.jpg'),
(117160, 8381, 'A Chuva [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/chGnRbfWkLWULGd3m5zGW3R87Fb.jpg'),
(117161, 8381, 'A Chuva [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2S0ap60GxMcyfXXFFY9LaQgnGbO.jpg'),
(117162, 8381, 'A Chuva [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0OeVnHyWYF2Beg4HsOj2NSGV73.jpg'),
(117163, 8381, 'A Chuva [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rQaH10JTJfkg20KVbI4t38Culnr.jpg'),
(117164, 8382, 'As Supermodelos [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sb9OoboMi51QmgFrrvg20ScdZf9.jpg'),
(117165, 8382, 'As Supermodelos [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nIIk0hoeDJdGAttGcG7fnNWst6j.jpg'),
(117166, 8382, 'As Supermodelos [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1YVIIby4krSO56RWl0CIVEjlHly.jpg'),
(117167, 8382, 'As Supermodelos [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qFQPhHv01F9TtDGupO1Ymj4Ufsi.jpg'),
(117168, 8383, 'Esposa em Tempo Integral [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k3hcU9mwcAzJeIFapSEaSunvC1M.jpg'),
(117169, 8383, 'Esposa em Tempo Integral [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/knlPHoKVokVSOdxXgtu9XD7Qo5e.jpg'),
(117170, 8383, 'Esposa em Tempo Integral [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gyY4mdluy6XkZNQ4U57Lb4RayhS.jpg'),
(117171, 8383, 'Esposa em Tempo Integral [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cPNAYMtgtTBGocgF2qJUkRTBRO0.jpg'),
(117172, 8383, 'Esposa em Tempo Integral [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzotH2iN2JNBJYxBopChsnVEjNV.jpg'),
(117173, 8383, 'Esposa em Tempo Integral [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4zVj4bsdGrBWGRHum1YV80uHl0Q.jpg'),
(117174, 8383, 'Esposa em Tempo Integral [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uHsRHgv4Ly6zVztXGsJMbnCI7t8.jpg'),
(117175, 8383, 'Esposa em Tempo Integral [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Avxqkgy3yGseWstQWm9GJDfjkn.jpg'),
(117176, 8383, 'Esposa em Tempo Integral [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/okZQ6qcw4p0ptiIdUJp8Ib9XpSC.jpg'),
(117177, 8383, 'Esposa em Tempo Integral [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Qhnitn3DUVqa7UsvsmM7v5BgyF.jpg'),
(117178, 8383, 'Esposa em Tempo Integral [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJYTFbT9nRMClqFp9rxs3rzNMc2.jpg'),
(117179, 8384, 'Mocro Maffia [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bUhxqOFQX3tWoL81JCSKUWK4MuT.jpg'),
(117180, 8384, 'Mocro Maffia [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ele4ogkoZdMKVcZIsCICEfL17N.jpg'),
(117181, 8384, 'Mocro Maffia [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dybNmN8KClTTLEfdVWBHM6LegYm.jpg'),
(117182, 8384, 'Mocro Maffia [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqYMk7kMhlBI9FhqFuXz8JzDigi.jpg'),
(117183, 8384, 'Mocro Maffia [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mr2tCEjwdDiIptc6gc6RZ3oJ3zS.jpg'),
(117184, 8384, 'Mocro Maffia [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vdLm1Fj8IDLnw6ugY6z5hquF7gS.jpg'),
(117185, 8384, 'Mocro Maffia [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2AYGFeBne16tRHe7En7NGanTTDK.jpg'),
(117186, 8384, 'Mocro Maffia [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ijS2BX6nm830v0ZgGYmWUwmJed.jpg'),
(117187, 8385, 'O Coletor de Corpos [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s0Ggy3A9sgylMFubDBmBfowZmlS.jpg'),
(117188, 8385, 'O Coletor de Corpos [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/feuU5qZOQbQcpglur3waBNC3DCS.jpg'),
(117189, 8385, 'O Coletor de Corpos [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cAnTgOvQu6GQrvFqgvnu1dRLtks.jpg'),
(117190, 8386, 'Psycho The Lost Tapes of Ed Gein [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/siEuzkCX8B1gEYUaLZEDQicZhLX.jpg'),
(117191, 8386, 'Psycho The Lost Tapes of Ed Gein [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rvqHqkiHO6Uh17K15hnXIzEpWfl.jpg'),
(117192, 8386, 'Psycho The Lost Tapes of Ed Gein [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rvqHqkiHO6Uh17K15hnXIzEpWfl.jpg'),
(117193, 8386, 'Psycho The Lost Tapes of Ed Gein [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rvqHqkiHO6Uh17K15hnXIzEpWfl.jpg'),
(117194, 8387, 'The Daily Life of the Immortal King [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qYqIo1VygQ2EB5RDBI7nJV2ii1s.jpg'),
(117195, 8387, 'The Daily Life of the Immortal King [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qGKOfF9yng2pL9bmnxzxc4y4ezD.jpg'),
(117196, 8387, 'The Daily Life of the Immortal King [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AaEvNNyHBrSKWdMAG0uWqs9eMRy.jpg'),
(117197, 8387, 'The Daily Life of the Immortal King [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yasX35mtDLTvazkKkzggtBcHC1.jpg'),
(117198, 8387, 'The Daily Life of the Immortal King [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Z8OttbnmlwLm4iQ3JknObu0E3M.jpg'),
(117199, 8387, 'The Daily Life of the Immortal King [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qANWBrs5Yv5xQ8DICShU4kQlxPH.jpg'),
(117200, 8387, 'The Daily Life of the Immortal King [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vQkgEMRIQEXuw4t0VemJkSHQB1M.jpg'),
(117201, 8387, 'The Daily Life of the Immortal King [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mCZW8C1NpJCKPrf0Zajreo2OpE8.jpg'),
(117202, 8387, 'The Daily Life of the Immortal King [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z4bHUkLgqq6bpRmmyatrlIJncgP.jpg'),
(117203, 8387, 'The Daily Life of the Immortal King [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vztdxOw6Q6FLZMC4KgvIGHrgexy.jpg'),
(117204, 8387, 'The Daily Life of the Immortal King [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/moTAtNsMSXf4KAKbv8Sw5gZMWBd.jpg'),
(117205, 8387, 'The Daily Life of the Immortal King [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7zVvVp6b4dmhXmh9FAlRjqp3gJW.jpg'),
(117206, 8387, 'The Daily Life of the Immortal King [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/psSe2A8Zq2onW6e5ou7sGgsAUsg.jpg'),
(117207, 8387, 'The Daily Life of the Immortal King [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/FbFIsLoYa0euAgyrzUrFWvrC9o.jpg'),
(117208, 8387, 'The Daily Life of the Immortal King [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wshuswj1JC9aROBSbAE8bjUmTaf.jpg'),
(117209, 8388, 'The Daily Life of the Immortal King [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1krZyvbvnhSfbzAUxg6XnftgHvS.jpg'),
(117210, 8388, 'The Daily Life of the Immortal King [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ezNPb7HfKiGYc21uwoijjHDvlSo.jpg'),
(117211, 8388, 'The Daily Life of the Immortal King [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1rhABWEKgsIvz3ujsc9mrnCHWdW.jpg'),
(117212, 8388, 'The Daily Life of the Immortal King [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/28ebmfgf5ZzdfaZT2oVP0b4jQG6.jpg'),
(117213, 8388, 'The Daily Life of the Immortal King [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rnMQqKRFMg1V5MXbpGLGePi0UOd.jpg'),
(117214, 8388, 'The Daily Life of the Immortal King [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tiQ97QBuKR6SQuaY4onA6YBnVFL.jpg'),
(117215, 8388, 'The Daily Life of the Immortal King [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jh0xpPRCwpwxuChM1OkXC9cD8tk.jpg'),
(117216, 8388, 'The Daily Life of the Immortal King [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Qa2uSijfQZ7ixpBTRj4K1Qkqrs.jpg'),
(117217, 8389, 'The Daily Life of the Immortal King [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qpeSTTNf44GerAPW3gtQAZezO6c.jpg'),
(117218, 8389, 'The Daily Life of the Immortal King [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/107hFIhBneRf1WdvEoYIyDWBwPJ.jpg'),
(117219, 8389, 'The Daily Life of the Immortal King [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/44TEqc3HBMGK770aiZUl4mckJFu.jpg'),
(117220, 8389, 'The Daily Life of the Immortal King [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zdjOnnuSgFQ8SSBdSRHoTfIKWfn.jpg'),
(117221, 8389, 'The Daily Life of the Immortal King [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lAIBWBPTV6kj5L1vENY1eWhEbbR.jpg'),
(117222, 8389, 'The Daily Life of the Immortal King [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5jJeWEagqKWCrQWXQfXIFTzQ5pE.jpg'),
(117223, 8389, 'The Daily Life of the Immortal King [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8pa1duNDZ3ioIdSeCHtcSXWzzWA.jpg'),
(117224, 8389, 'The Daily Life of the Immortal King [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dH3TXjYxcwJOkPnTQakAyUcS4N3.jpg'),
(117225, 8389, 'The Daily Life of the Immortal King [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8zG4atuVBdXhtYfKVGHQMAHhF5.jpg'),
(117226, 8389, 'The Daily Life of the Immortal King [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qN4azyAc8KPkIFDexSjsVoRuTja.jpg'),
(117227, 8389, 'The Daily Life of the Immortal King [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h6eVxvnUzTq1G15TXuLlWxGT8IB.jpg'),
(117228, 8389, 'The Daily Life of the Immortal King [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eFwEOIWjFaFWPwMiDXqdAsBmG7Z.jpg'),
(117229, 8390, 'The Daily Life of the Immortal King [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AiUzqwU9Dom6rH1Kt6jRXXGDD7p.jpg'),
(117230, 8390, 'The Daily Life of the Immortal King [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AiUzqwU9Dom6rH1Kt6jRXXGDD7p.jpg'),
(117231, 8390, 'The Daily Life of the Immortal King [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AiUzqwU9Dom6rH1Kt6jRXXGDD7p.jpg'),
(117232, 8390, 'The Daily Life of the Immortal King [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AiUzqwU9Dom6rH1Kt6jRXXGDD7p.jpg'),
(117233, 8390, 'The Daily Life of the Immortal King [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AiUzqwU9Dom6rH1Kt6jRXXGDD7p.jpg'),
(117234, 8390, 'The Daily Life of the Immortal King [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AiUzqwU9Dom6rH1Kt6jRXXGDD7p.jpg'),
(117235, 8390, 'The Daily Life of the Immortal King [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AiUzqwU9Dom6rH1Kt6jRXXGDD7p.jpg'),
(117236, 8390, 'The Daily Life of the Immortal King [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AiUzqwU9Dom6rH1Kt6jRXXGDD7p.jpg'),
(117237, 8390, 'The Daily Life of the Immortal King [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/313526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AiUzqwU9Dom6rH1Kt6jRXXGDD7p.jpg'),
(117238, 8390, 'The Daily Life of the Immortal King [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/313527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AiUzqwU9Dom6rH1Kt6jRXXGDD7p.jpg'),
(117239, 8390, 'The Daily Life of the Immortal King [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/313528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AiUzqwU9Dom6rH1Kt6jRXXGDD7p.jpg'),
(117240, 8390, 'The Daily Life of the Immortal King [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/313529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AiUzqwU9Dom6rH1Kt6jRXXGDD7p.jpg'),
(117241, 8391, 'The Daily Life of the Immortal King [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/896885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AiUzqwU9Dom6rH1Kt6jRXXGDD7p.jpg'),
(117242, 8391, 'The Daily Life of the Immortal King [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/896886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AiUzqwU9Dom6rH1Kt6jRXXGDD7p.jpg'),
(117243, 8391, 'The Daily Life of the Immortal King [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/896887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AiUzqwU9Dom6rH1Kt6jRXXGDD7p.jpg'),
(117244, 8392, 'The Ex Wife [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4V9GB1a0i2NdQxIawCe4Clyqg1L.jpg'),
(117245, 8392, 'The Ex Wife [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWu3cBDZZRMD62MFc0qv1h6WjLC.jpg'),
(117246, 8392, 'The Ex Wife [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sphDMLwFYjpWHN7qfnxB0INWCof.jpg'),
(117247, 8392, 'The Ex Wife [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Bn9o6nFYMSfXpEiKl5JE4yLYlG.jpg'),
(117248, 8393, 'The Virtues [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oKxrNIZaz2SP9KNGvsg7rpwWnGt.jpg'),
(117249, 8393, 'The Virtues [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/onn7eGJZBLuCke6E0xCGn99oHBj.jpg'),
(117250, 8393, 'The Virtues [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rtCtQO8xLsrxwCcKeoe1XK8gw1x.jpg'),
(117251, 8393, 'The Virtues [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1vyTndfC0qnD4gkWnPV9hEah5C5.jpg'),
(117252, 8394, 'Torn [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3NE3dzfs7NBbQPNdkcB7764O5CW.jpg'),
(117253, 8394, 'Torn [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3NE3dzfs7NBbQPNdkcB7764O5CW.jpg'),
(117254, 8394, 'Torn [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3NE3dzfs7NBbQPNdkcB7764O5CW.jpg'),
(117255, 8394, 'Torn [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3NE3dzfs7NBbQPNdkcB7764O5CW.jpg'),
(117256, 8394, 'Torn [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3NE3dzfs7NBbQPNdkcB7764O5CW.jpg'),
(117257, 8394, 'Torn [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3NE3dzfs7NBbQPNdkcB7764O5CW.jpg'),
(117258, 8395, 'Traicion [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/26EDf6mcI3M46ywF7xQsAiImZJL.jpg'),
(117259, 8395, 'Traicion [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/goa1hQC6z8eYH26p9MBFwTrutHk.jpg'),
(117260, 8395, 'Traicion [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rvMe4E6LJjibjheMhyN08w8PCWY.jpg'),
(117261, 8395, 'Traicion [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sG1mt7JCmrdLLf6dXCP1kSjg85.jpg'),
(117262, 8395, 'Traicion [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rvMe4E6LJjibjheMhyN08w8PCWY.jpg'),
(117263, 8395, 'Traicion [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rvMe4E6LJjibjheMhyN08w8PCWY.jpg'),
(117264, 8395, 'Traicion [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rvMe4E6LJjibjheMhyN08w8PCWY.jpg'),
(117265, 8395, 'Traicion [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rvMe4E6LJjibjheMhyN08w8PCWY.jpg'),
(117266, 8395, 'Traicion [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rvMe4E6LJjibjheMhyN08w8PCWY.jpg'),
(117267, 8396, 'Undead Murder Farce [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nK2p82SzGh7H83dS5ww89U3zpjO.jpg'),
(117268, 8396, 'Undead Murder Farce [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uxJbaklCILLBu7l1icE2rZ1qa4c.jpg'),
(117269, 8396, 'Undead Murder Farce [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/60BTebVo8vr96yv3PW6yaIv0Qv.jpg'),
(117270, 8396, 'Undead Murder Farce [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ANFbaJPYS2tV5ZmJaZbRk5Sd1i.jpg'),
(117271, 8396, 'Undead Murder Farce [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4wqrxUVmkv8H26nEtOCXhN3UK1G.jpg'),
(117272, 8396, 'Undead Murder Farce [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c2hg7web8RKOc1ngI0GGcid0h1g.jpg'),
(117273, 8396, 'Undead Murder Farce [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4e8xlGyZGv5JpoMtNP79wSXuk0q.jpg'),
(117274, 8396, 'Undead Murder Farce [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1tYy4Z7S2CDeCQC5aVF8iiO71bj.jpg'),
(117275, 8396, 'Undead Murder Farce [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e12fPkOFLyTvKdw5SJCIQc82Qtt.jpg'),
(117276, 8396, 'Undead Murder Farce [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ooFKcoXGpqPS8Oak7JJAJQ4zDjD.jpg'),
(117277, 8396, 'Undead Murder Farce [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dQGufamSL1cH9fv2CQOjvPDNXCy.jpg'),
(117278, 8396, 'Undead Murder Farce [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bPnZKrclYVKha5F2jzL1wpu0SOZ.jpg'),
(117279, 8396, 'Undead Murder Farce [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wcErs5C6HNgP0MYeEoo8E7s46zZ.jpg'),
(117280, 8397, 'Gen V S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tzWMqlYUprbPSSdcsg9cea2p4oI.jpg'),
(117281, 8397, 'Gen V S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZI9jDanZtpUVXvMvMhwM2SsTA8.jpg'),
(117282, 8397, 'Gen V S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b6DkuAT76n7kCWFVaEQgBTzOGIT.jpg'),
(117283, 8397, 'Gen V S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGOV8WrYzHKYt9lMrSGzxVAlfqL.jpg'),
(117284, 8397, 'Gen V S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGOV8WrYzHKYt9lMrSGzxVAlfqL.jpg'),
(117285, 8397, 'Gen V S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGOV8WrYzHKYt9lMrSGzxVAlfqL.jpg'),
(117286, 8397, 'Gen V S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGOV8WrYzHKYt9lMrSGzxVAlfqL.jpg'),
(117287, 8397, 'Gen V S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGOV8WrYzHKYt9lMrSGzxVAlfqL.jpg'),
(117288, 8398, 'Gen V S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/885327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGOV8WrYzHKYt9lMrSGzxVAlfqL.jpg'),
(117289, 8398, 'Gen V S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/885328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGOV8WrYzHKYt9lMrSGzxVAlfqL.jpg'),
(117290, 8398, 'Gen V S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/885329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGOV8WrYzHKYt9lMrSGzxVAlfqL.jpg'),
(117291, 8398, 'Gen V S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/886081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGOV8WrYzHKYt9lMrSGzxVAlfqL.jpg'),
(117292, 8398, 'Gen V S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/887591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGOV8WrYzHKYt9lMrSGzxVAlfqL.jpg'),
(117293, 8398, 'Gen V S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/888207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGOV8WrYzHKYt9lMrSGzxVAlfqL.jpg'),
(117294, 8398, 'Gen V S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/889633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGOV8WrYzHKYt9lMrSGzxVAlfqL.jpg'),
(117295, 8398, 'Gen V S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/890113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGOV8WrYzHKYt9lMrSGzxVAlfqL.jpg'),
(117296, 8399, 'Law e Order Crime Organizado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDVqhraEF3PInGokpn4WApkqyko.jpg'),
(117297, 8399, 'Law e Order Crime Organizado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AevkLn3cDytNA5NoA2GLIHJPYwK.jpg'),
(117298, 8399, 'Law e Order Crime Organizado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6CI8kmqTopou6hnRokeXh8GZ15o.jpg'),
(117299, 8399, 'Law e Order Crime Organizado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2V3gSicFibeOELK3wW42ftHZAS.jpg'),
(117300, 8399, 'Law e Order Crime Organizado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hwx3UXPbYz7OXXsmy4MsuM4R3Ap.jpg'),
(117301, 8399, 'Law e Order Crime Organizado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rgINc6nrCR0ZTnuqwI97K7pRPAr.jpg'),
(117302, 8399, 'Law e Order Crime Organizado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fwVAgLOzbxZHbwgFO09aCf3Zeb9.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(117303, 8399, 'Law e Order Crime Organizado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nv7IQzXdb3GVdch69HlfFr15N3q.jpg'),
(117304, 8400, 'Law e Order Crime Organizado S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234568.mp4', 'http://timg.bdta.pro/images/ca4811a484f3ec92a6fac39ca582a083.jpg'),
(117305, 8400, 'Law e Order Crime Organizado S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234569.mp4', 'http://timg.bdta.pro/images/341dff818b05b728f332ac4ee718e1b2.jpg'),
(117306, 8400, 'Law e Order Crime Organizado S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234570.mp4', 'http://timg.bdta.pro/images/e217a81c385cadd8d02b8998169b6bab.jpg'),
(117307, 8400, 'Law e Order Crime Organizado S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234571.mp4', 'http://timg.bdta.pro/images/cf9b4e743c8329054289d5e2ee5dab52.jpg'),
(117308, 8400, 'Law e Order Crime Organizado S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234572.mp4', 'http://timg.bdta.pro/images/af61790a35949facf743517d812fc3bc.jpg'),
(117309, 8400, 'Law e Order Crime Organizado S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234573.mp4', 'http://timg.bdta.pro/images/956f226070205e797f0b6bf7bbf56ee2.jpg'),
(117310, 8400, 'Law e Order Crime Organizado S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234574.mp4', 'http://timg.bdta.pro/images/1566e5fc95ffbc6c0ded4c2da1d6dc76.jpg'),
(117311, 8400, 'Law e Order Crime Organizado S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234575.mp4', 'http://timg.bdta.pro/images/2cae90aada87fd7bc69f1afc387ce112.jpg'),
(117312, 8400, 'Law e Order Crime Organizado S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234576.mp4', 'http://timg.bdta.pro/images/53c268141cf74a458c2a3a00d34b23b9.jpg'),
(117313, 8400, 'Law e Order Crime Organizado S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234577.mp4', 'http://timg.bdta.pro/images/947904e82c32402259fbc16dae336671.jpg'),
(117314, 8400, 'Law e Order Crime Organizado S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234578.mp4', 'http://timg.bdta.pro/images/ed6b5ef31688f3a0f52615b1216a721a.jpg'),
(117315, 8400, 'Law e Order Crime Organizado S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234579.mp4', 'http://timg.bdta.pro/images/0e0748e97b0119f992737ee81d96a348.jpg'),
(117316, 8400, 'Law e Order Crime Organizado S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234580.mp4', 'http://timg.bdta.pro/images/32ec2f148c575ed3f2bf426c17a75a0a.jpg'),
(117317, 8400, 'Law e Order Crime Organizado S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234581.mp4', 'http://timg.bdta.pro/images/6b3a8cd8e2c2e3f9fd5185443eb20a89.jpg'),
(117318, 8400, 'Law e Order Crime Organizado S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234582.mp4', 'http://timg.bdta.pro/images/3c4db71eaaf371fcc6564e53ba756d2e.jpg'),
(117319, 8400, 'Law e Order Crime Organizado S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234583.mp4', 'http://timg.bdta.pro/images/3a28d697fce54bf435cf07d6695000f4.jpg'),
(117320, 8400, 'Law e Order Crime Organizado S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234584.mp4', 'http://timg.bdta.pro/images/bc779d676cbba721efe6d4d631272bac.jpg'),
(117321, 8400, 'Law e Order Crime Organizado S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/234585.mp4', 'http://timg.bdta.pro/images/922ed5358a14bd5cb16f0c32c4e53e09.jpg'),
(117322, 8400, 'Law e Order Crime Organizado S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/234586.mp4', 'http://timg.bdta.pro/images/4c2c9d45ae1ca231211639b6adf68e7b.jpg'),
(117323, 8400, 'Law e Order Crime Organizado S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/234587.mp4', 'http://timg.bdta.pro/images/c3251bb5340d7e7a184d7beb9b942ade.jpg'),
(117324, 8400, 'Law e Order Crime Organizado S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/234588.mp4', 'http://timg.bdta.pro/images/c386d267d6791840415e44735b7da9a8.jpg'),
(117325, 8400, 'Law e Order Crime Organizado S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/234589.mp4', 'http://timg.bdta.pro/images/a7d8516eea17d5e0949a0f801f341110.jpg'),
(117326, 8401, 'Law e Order Crime Organizado S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yjtTyxYv2uaJCsxpMZIsh2Sx0EK.jpg'),
(117327, 8401, 'Law e Order Crime Organizado S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/183DccPHqhAKIQ1dRt5Wsm1ca1c.jpg'),
(117328, 8401, 'Law e Order Crime Organizado S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/67tvzAcslb8pc2u9pVFNehS9YLG.jpg'),
(117329, 8401, 'Law e Order Crime Organizado S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1il8MCBllyq3oZ5e1STKjyfHREM.jpg'),
(117330, 8401, 'Law e Order Crime Organizado S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4srLPpylvaEkwS6FyYp74WugPww.jpg'),
(117331, 8401, 'Law e Order Crime Organizado S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gEA9hRZ70JykSJxPct8utR4yYfJ.jpg'),
(117332, 8401, 'Law e Order Crime Organizado S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uDlKEf3FoM3VSGGS1dcKqMb7Kak.jpg'),
(117333, 8401, 'Law e Order Crime Organizado S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/OllwQhbdk7CpvhUXoLG8i8g4Sx.jpg'),
(117334, 8401, 'Law e Order Crime Organizado S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dUEUf6vo0ASmaQLUkrmslR45Gl3.jpg'),
(117335, 8401, 'Law e Order Crime Organizado S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDqHEmBznbovHqgH0dyqkAkieJR.jpg'),
(117336, 8401, 'Law e Order Crime Organizado S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sG1ivr4Bh6UtZww6dfRS1bgk5a0.jpg'),
(117337, 8401, 'Law e Order Crime Organizado S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aWMoHsvzHSpe1dvaQBfwJiQbuYb.jpg'),
(117338, 8401, 'Law e Order Crime Organizado S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/234602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o0qXLhQ1SF1hFZBZLkdELeQBvFH.jpg'),
(117339, 8401, 'Law e Order Crime Organizado S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/234603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aCxepS2UMqHrMenOBpOWpSXQiGO.jpg'),
(117340, 8401, 'Law e Order Crime Organizado S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/234604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2qJsebk34QUoky7becMT8A9jQsp.jpg'),
(117341, 8401, 'Law e Order Crime Organizado S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/234605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1gDFJEETISjpgPglBNQXgL8sMsD.jpg'),
(117342, 8401, 'Law e Order Crime Organizado S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/234606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vZExXyrBMSUkYcuZtKP7Aj4SZ6F.jpg'),
(117343, 8401, 'Law e Order Crime Organizado S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/234607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uq3CJnNPAZvYMTGWs0W8HP0YC7y.jpg'),
(117344, 8401, 'Law e Order Crime Organizado S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/234608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/huK3Pzv8YcMWBEgk7l0t65nkkxi.jpg'),
(117345, 8401, 'Law e Order Crime Organizado S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/234609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bmwoyzHJInz5KCSYAir9xpiwrPd.jpg'),
(117346, 8401, 'Law e Order Crime Organizado S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/234610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3kxR3RhsJ0QrJr4IPxiUyXrhif3.jpg'),
(117347, 8401, 'Law e Order Crime Organizado S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/234611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/98qh9GTdTddIovp1PTn2siGF8JF.jpg'),
(117348, 8402, 'Law e Order Crime Organizado S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/477883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117349, 8402, 'Law e Order Crime Organizado S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/477884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117350, 8402, 'Law e Order Crime Organizado S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/477885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117351, 8402, 'Law e Order Crime Organizado S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/477886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117352, 8402, 'Law e Order Crime Organizado S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/477887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117353, 8402, 'Law e Order Crime Organizado S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/477888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117354, 8402, 'Law e Order Crime Organizado S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/477889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117355, 8402, 'Law e Order Crime Organizado S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/477890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117356, 8402, 'Law e Order Crime Organizado S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/477891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117357, 8402, 'Law e Order Crime Organizado S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/477892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117358, 8402, 'Law e Order Crime Organizado S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/477893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117359, 8402, 'Law e Order Crime Organizado S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/477894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117360, 8402, 'Law e Order Crime Organizado S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/477895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117361, 8403, 'Law e Order Crime Organizado S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/879979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117362, 8403, 'Law e Order Crime Organizado S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/879980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117363, 8403, 'Law e Order Crime Organizado S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/879981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117364, 8403, 'Law e Order Crime Organizado S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/879982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117365, 8403, 'Law e Order Crime Organizado S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/879983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117366, 8403, 'Law e Order Crime Organizado S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/879984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117367, 8403, 'Law e Order Crime Organizado S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/879985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117368, 8403, 'Law e Order Crime Organizado S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/879986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117369, 8403, 'Law e Order Crime Organizado S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/879987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117370, 8403, 'Law e Order Crime Organizado S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/879988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FXtXGGYqXcppuOovCW4WzcSi7d.jpg'),
(117371, 8404, 'O Falso Sheik [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3QJXxRgmizrs0BDLkJ5MBn0SNQn.jpg'),
(117372, 8404, 'O Falso Sheik [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q9KgXSQc9TdwiUqaqwHb4bouVXg.jpg'),
(117373, 8404, 'O Falso Sheik [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pNnw7lDXycY9TSpyUyxetp0KDwz.jpg'),
(117374, 8405, 'O Pior do Mal [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9NNTMgttqXG2NyDFASSkUpzSjpO.jpg'),
(117375, 8405, 'O Pior do Mal [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zB6dapl4mk6O5O4tXSg6R0pvoPf.jpg'),
(117376, 8405, 'O Pior do Mal [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwXVqGBoBaF1fJQLOJu7PbYCVJn.jpg'),
(117377, 8405, 'O Pior do Mal [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJMZsRLmJXMdInEXk7ol72E639n.jpg'),
(117378, 8405, 'O Pior do Mal [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJMZsRLmJXMdInEXk7ol72E639n.jpg'),
(117379, 8405, 'O Pior do Mal [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJMZsRLmJXMdInEXk7ol72E639n.jpg'),
(117380, 8405, 'O Pior do Mal [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJMZsRLmJXMdInEXk7ol72E639n.jpg'),
(117381, 8405, 'O Pior do Mal [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJMZsRLmJXMdInEXk7ol72E639n.jpg'),
(117382, 8405, 'O Pior do Mal [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJMZsRLmJXMdInEXk7ol72E639n.jpg'),
(117383, 8405, 'O Pior do Mal [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJMZsRLmJXMdInEXk7ol72E639n.jpg'),
(117384, 8405, 'O Pior do Mal [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJMZsRLmJXMdInEXk7ol72E639n.jpg'),
(117385, 8405, 'O Pior do Mal [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/243912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJMZsRLmJXMdInEXk7ol72E639n.jpg'),
(117386, 8406, 'Power Rangers Furia Cosmica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/870eA45xdZS5hrXTey4cmFJDEiT.jpg'),
(117387, 8406, 'Power Rangers Furia Cosmica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pos46Q8tRCsTjMiUd1IEXruGZZ6.jpg'),
(117388, 8406, 'Power Rangers Furia Cosmica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kKo8IqN7zAXuO70vqIUhZ34wRvC.jpg'),
(117389, 8406, 'Power Rangers Furia Cosmica S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vtGEpQ0kazjhrQmUrzyhiC8Ngar.jpg'),
(117390, 8406, 'Power Rangers Furia Cosmica S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k1zpSfW9UzP3zZeQAy7KmAZ7kDF.jpg'),
(117391, 8406, 'Power Rangers Furia Cosmica S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mes6aVKlTOUyJF9wzMgG3th74bC.jpg'),
(117392, 8406, 'Power Rangers Furia Cosmica S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fTiyf9CgMrGOXs8q9wXpMu0fKv2.jpg'),
(117393, 8406, 'Power Rangers Furia Cosmica S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q4tLhwQoYQdUtUIPdUrPmYPHdrV.jpg'),
(117394, 8406, 'Power Rangers Furia Cosmica S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7p9VpdD92NqYTGBwoRdJlqpWyJf.jpg'),
(117395, 8406, 'Power Rangers Furia Cosmica S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pa5W6SrAhsKFhXpQA8pYnMLzZ6n.jpg'),
(117396, 8407, 'Santa Cecilia e Padre Lawrence [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/olCsq3AmcFsBQRwwCQVL6j3IWOR.jpg'),
(117397, 8407, 'Santa Cecilia e Padre Lawrence [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8RkYfuAVRkvkQaHkiu03EeVSHup.jpg'),
(117398, 8407, 'Santa Cecilia e Padre Lawrence [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vZEMgn8aGaKIbsq1TURStqdykhT.jpg'),
(117399, 8407, 'Santa Cecilia e Padre Lawrence [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1BbqoN0S5i0Wz7w2K88uji1RIE.jpg'),
(117400, 8407, 'Santa Cecilia e Padre Lawrence [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aieCqGtcehcJF9A1j4iW40hqk3e.jpg'),
(117401, 8407, 'Santa Cecilia e Padre Lawrence [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rlqoANSrVb8da5NZyB7CUHKLLi4.jpg'),
(117402, 8407, 'Santa Cecilia e Padre Lawrence [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m019pkL0f4meq1wDMKeaylcBV3K.jpg'),
(117403, 8407, 'Santa Cecilia e Padre Lawrence [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lk7xZoZ0E3tbQcB5EuBsUje6lxn.jpg'),
(117404, 8407, 'Santa Cecilia e Padre Lawrence [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tpBaltcaRI81LIkJdcM4k3Xmdy7.jpg'),
(117405, 8407, 'Santa Cecilia e Padre Lawrence [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/234544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vBcgpNVLv0o13DILJh8V3oH2GOS.jpg'),
(117406, 8407, 'Santa Cecilia e Padre Lawrence [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/234545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gxXRt6t11CjiAVB3szx3E5zMmwY.jpg'),
(117407, 8407, 'Santa Cecilia e Padre Lawrence [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/234546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1TMX9OhET7jwKB3lfcv5Q6NdmDm.jpg'),
(117408, 8408, 'The Big Day S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6YutYLWxXtX8A9zcTm3LA7ZKNOq.jpg'),
(117409, 8408, 'The Big Day S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fErPakhdHEn2Hkra8fEUo8Dy2fl.jpg'),
(117410, 8408, 'The Big Day S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eabNZX9BOmXHiICV9XZHDY7Xxgf.jpg'),
(117411, 8409, 'The Big Day S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sBCgYB9kySJakOpkKgQ3u2jDZ4W.jpg'),
(117412, 8409, 'The Big Day S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pBDP36AHhPX1XkhnEAGpFH0lq9P.jpg'),
(117413, 8409, 'The Big Day S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ks2qV55TpOLHjgP88sekDB4Hn1g.jpg'),
(117414, 8410, 'The Irrational [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sHfoaOLJALcZ8S53S1eKGhiVL9J.jpg'),
(117415, 8410, 'The Irrational [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117416, 8410, 'The Irrational [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117417, 8410, 'The Irrational [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117418, 8410, 'The Irrational [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117419, 8410, 'The Irrational [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117420, 8410, 'The Irrational [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117421, 8410, 'The Irrational [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117422, 8410, 'The Irrational [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/274980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117423, 8410, 'The Irrational [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/274981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117424, 8410, 'The Irrational [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/279418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117425, 8411, 'The Irrational [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/480882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117426, 8411, 'The Irrational [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/488068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117427, 8411, 'The Irrational [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/493460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117428, 8411, 'The Irrational [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/496289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117429, 8411, 'The Irrational [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/509194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117430, 8411, 'The Irrational [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/688272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117431, 8411, 'The Irrational [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/667263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117432, 8411, 'The Irrational [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/667264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117433, 8411, 'The Irrational [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/688275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117434, 8411, 'The Irrational [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/697298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117435, 8411, 'The Irrational [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/703881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117436, 8411, 'The Irrational [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/722957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117437, 8411, 'The Irrational [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/725403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117438, 8411, 'The Irrational [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/763269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117439, 8411, 'The Irrational [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/781934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117440, 8411, 'The Irrational [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/791779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jJtOpfgV4iPu9RtxllHwZgn9dqI.jpg'),
(117441, 8412, 'The Prank Panel [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zoCG1LOUPQtzJsjQZPQmekZBdf6.jpg'),
(117442, 8412, 'The Prank Panel [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4YrYfXkstwkbYSwG34jYca4gkiQ.jpg'),
(117443, 8412, 'The Prank Panel [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ftNJHfhjlZ1Z2EP3eZqRNdAIZDc.jpg'),
(117444, 8412, 'The Prank Panel [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gsIy82xFpl4hHXmI2lFBd8xRQxb.jpg'),
(117445, 8412, 'The Prank Panel [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/234524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j0zY8rPC6r0lNXmmi7pr25HagDP.jpg'),
(117446, 8412, 'The Prank Panel [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/234525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mnwH86A3lLa7NpI3gS0WQyK6vR3.jpg'),
(117447, 8412, 'The Prank Panel [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/234526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mnwH86A3lLa7NpI3gS0WQyK6vR3.jpg'),
(117448, 8412, 'The Prank Panel [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/234527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mnwH86A3lLa7NpI3gS0WQyK6vR3.jpg'),
(117449, 8412, 'The Prank Panel [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/234528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mnwH86A3lLa7NpI3gS0WQyK6vR3.jpg'),
(117450, 8413, 'Tinder Apresenta MTV Beija Sapo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1QRrFdec5y6mtfyf4kNluSI38q.jpg'),
(117451, 8413, 'Tinder Apresenta MTV Beija Sapo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1QRrFdec5y6mtfyf4kNluSI38q.jpg'),
(117452, 8413, 'Tinder Apresenta MTV Beija Sapo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1QRrFdec5y6mtfyf4kNluSI38q.jpg'),
(117453, 8413, 'Tinder Apresenta MTV Beija Sapo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1QRrFdec5y6mtfyf4kNluSI38q.jpg'),
(117454, 8413, 'Tinder Apresenta MTV Beija Sapo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1QRrFdec5y6mtfyf4kNluSI38q.jpg'),
(117455, 8413, 'Tinder Apresenta MTV Beija Sapo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1QRrFdec5y6mtfyf4kNluSI38q.jpg'),
(117456, 8413, 'Tinder Apresenta MTV Beija Sapo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1QRrFdec5y6mtfyf4kNluSI38q.jpg'),
(117457, 8413, 'Tinder Apresenta MTV Beija Sapo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1QRrFdec5y6mtfyf4kNluSI38q.jpg'),
(117458, 8413, 'Tinder Apresenta MTV Beija Sapo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1QRrFdec5y6mtfyf4kNluSI38q.jpg'),
(117459, 8413, 'Tinder Apresenta MTV Beija Sapo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1QRrFdec5y6mtfyf4kNluSI38q.jpg'),
(117460, 8414, 'Voltando a Ler Mafalda [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/234516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLo9P48IxR45hTH9l0nnQPT4Kt4.jpg'),
(117461, 8414, 'Voltando a Ler Mafalda [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/234517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/szWdMSIh6PdOhgkXhCAfZUM9eVG.jpg'),
(117462, 8414, 'Voltando a Ler Mafalda [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/234518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8iAva7R5owGDeZJ5bo44SKk38r8.jpg'),
(117463, 8414, 'Voltando a Ler Mafalda [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/234519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ciuVWZ6UYysEm53cWhtiQx3Huj2.jpg'),
(117464, 8415, 'The Taste Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117465, 8415, 'The Taste Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117466, 8415, 'The Taste Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117467, 8415, 'The Taste Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117468, 8415, 'The Taste Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117469, 8415, 'The Taste Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117470, 8415, 'The Taste Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117471, 8415, 'The Taste Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117472, 8415, 'The Taste Brasil S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117473, 8415, 'The Taste Brasil S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117474, 8416, 'The Taste Brasil S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117475, 8416, 'The Taste Brasil S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117476, 8416, 'The Taste Brasil S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117477, 8416, 'The Taste Brasil S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117478, 8416, 'The Taste Brasil S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117479, 8416, 'The Taste Brasil S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117480, 8416, 'The Taste Brasil S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117481, 8416, 'The Taste Brasil S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117482, 8416, 'The Taste Brasil S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117483, 8416, 'The Taste Brasil S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117484, 8417, 'The Taste Brasil S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117485, 8417, 'The Taste Brasil S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117486, 8417, 'The Taste Brasil S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117487, 8417, 'The Taste Brasil S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117488, 8417, 'The Taste Brasil S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117489, 8417, 'The Taste Brasil S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117490, 8417, 'The Taste Brasil S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117491, 8417, 'The Taste Brasil S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117492, 8417, 'The Taste Brasil S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117493, 8417, 'The Taste Brasil S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117494, 8418, 'The Taste Brasil S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117495, 8418, 'The Taste Brasil S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117496, 8418, 'The Taste Brasil S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117497, 8418, 'The Taste Brasil S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117498, 8418, 'The Taste Brasil S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117499, 8418, 'The Taste Brasil S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117500, 8418, 'The Taste Brasil S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117501, 8418, 'The Taste Brasil S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117502, 8418, 'The Taste Brasil S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117503, 8418, 'The Taste Brasil S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117504, 8419, 'The Taste Brasil S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117505, 8419, 'The Taste Brasil S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117506, 8419, 'The Taste Brasil S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117507, 8419, 'The Taste Brasil S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117508, 8419, 'The Taste Brasil S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117509, 8419, 'The Taste Brasil S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117510, 8419, 'The Taste Brasil S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117511, 8419, 'The Taste Brasil S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117512, 8419, 'The Taste Brasil S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117513, 8419, 'The Taste Brasil S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117514, 8420, 'The Taste Brasil S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117515, 8420, 'The Taste Brasil S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117516, 8420, 'The Taste Brasil S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117517, 8420, 'The Taste Brasil S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117518, 8420, 'The Taste Brasil S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117519, 8420, 'The Taste Brasil S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117520, 8420, 'The Taste Brasil S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117521, 8420, 'The Taste Brasil S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117522, 8420, 'The Taste Brasil S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117523, 8420, 'The Taste Brasil S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117524, 8421, 'The Taste Brasil S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/471753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117525, 8421, 'The Taste Brasil S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/484856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117526, 8421, 'The Taste Brasil S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/488041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117527, 8421, 'The Taste Brasil S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/497771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117528, 8421, 'The Taste Brasil S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/498832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117529, 8421, 'The Taste Brasil S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/504576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117530, 8421, 'The Taste Brasil S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/511100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117531, 8421, 'The Taste Brasil S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117532, 8421, 'The Taste Brasil S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117533, 8421, 'The Taste Brasil S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTmAxNkGGJyBddKS15zYaTPAA9A.jpg'),
(117534, 8422, 'Complexo do Salvador [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aAGTuB9HKMnVOY8D56PQt7IWAhm.jpg'),
(117535, 8422, 'Complexo do Salvador [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xBvZPhuRU5e5bmgpKKxs4tpKagC.jpg'),
(117536, 8422, 'Complexo do Salvador [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/roQ0JxZM0jopTsDTcqZ6zjjKZvX.jpg'),
(117537, 8423, 'Line of Duty S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238570.mp4', 'http://timg.bdta.pro/images/668335d7c71a02a6e9c6d40214d607a6.jpg'),
(117538, 8423, 'Line of Duty S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238571.mp4', 'http://timg.bdta.pro/images/16ef98befb3027bd61ddfdd39ad90ca9.jpg'),
(117539, 8423, 'Line of Duty S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238572.mp4', 'http://timg.bdta.pro/images/2d56e88a08be95cc6ebd1ce159a948ca.jpg'),
(117540, 8423, 'Line of Duty S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238573.mp4', 'http://timg.bdta.pro/images/927c89b2e688b5ea20d358f076b26daa.jpg'),
(117541, 8423, 'Line of Duty S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238574.mp4', 'http://timg.bdta.pro/images/d17c65aabc9420ba8942b245b2a52e06.jpg'),
(117542, 8424, 'Line of Duty S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238575.mp4', 'http://timg.bdta.pro/images/abc9980550da2b10ab79319fd30ad5eb.jpg'),
(117543, 8424, 'Line of Duty S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238576.mp4', 'http://timg.bdta.pro/images/a0725e757193e0d5cdc356c42fec3c48.jpg'),
(117544, 8424, 'Line of Duty S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238577.mp4', 'http://timg.bdta.pro/images/4c50acd37d6e92243035114200ea7532.jpg'),
(117545, 8424, 'Line of Duty S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238578.mp4', 'http://timg.bdta.pro/images/2da1acb339d688c556ca4d03d6853deb.jpg'),
(117546, 8424, 'Line of Duty S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238579.mp4', 'http://timg.bdta.pro/images/c794d13b5414b1d1eea0cd1a9584119e.jpg'),
(117547, 8424, 'Line of Duty S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238580.mp4', 'http://timg.bdta.pro/images/d281b958959928809f3c168e7da260de.jpg'),
(117548, 8425, 'Line of Duty S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238581.mp4', 'http://timg.bdta.pro/images/de9ba51de3a8b12431bc4ca586bd6cb2.jpg'),
(117549, 8425, 'Line of Duty S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238582.mp4', 'http://timg.bdta.pro/images/24caa48bfad30b7fa8884d938dad7f44.jpg'),
(117550, 8425, 'Line of Duty S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238583.mp4', 'http://timg.bdta.pro/images/e6f551eaed275665e6426c30e015188e.jpg'),
(117551, 8425, 'Line of Duty S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238584.mp4', 'http://timg.bdta.pro/images/dbba42045819f9dc913df725d681856b.jpg'),
(117552, 8425, 'Line of Duty S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238585.mp4', 'http://timg.bdta.pro/images/97cb91f3ca0b2a9ff11caf01bb69f412.jpg'),
(117553, 8425, 'Line of Duty S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238586.mp4', 'http://timg.bdta.pro/images/554a06f786ca197a2a6bc4dc28e3e73b.jpg'),
(117554, 8426, 'Line of Duty S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238587.mp4', 'http://timg.bdta.pro/images/5f3950171c6a686ef62a83f89183040a.jpg'),
(117555, 8426, 'Line of Duty S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238588.mp4', 'http://timg.bdta.pro/images/58c84268db4f77780f1e09ebbd9d5f59.jpg'),
(117556, 8426, 'Line of Duty S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238589.mp4', 'http://timg.bdta.pro/images/6708471b189e0c7830a4b8329cdb5fb9.jpg'),
(117557, 8426, 'Line of Duty S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238590.mp4', 'http://timg.bdta.pro/images/eaadbdf124e204df0950343e3059c6f3.jpg'),
(117558, 8426, 'Line of Duty S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238591.mp4', 'http://timg.bdta.pro/images/83413e896bac688b21a55c8502cd4ff2.jpg'),
(117559, 8426, 'Line of Duty S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238592.mp4', 'http://timg.bdta.pro/images/b0959b01df62cb5cc3bc992618ab8aec.jpg'),
(117560, 8427, 'Line of Duty S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238593.mp4', 'http://timg.bdta.pro/images/bdef45173a479fe439d04ed2e360d4e2.jpg'),
(117561, 8427, 'Line of Duty S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238594.mp4', 'http://timg.bdta.pro/images/2428a67b810f252f1070bdae24a7d613.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(117562, 8427, 'Line of Duty S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238595.mp4', 'http://timg.bdta.pro/images/405d12a22a8c9e1832c08190e400133d.jpg'),
(117563, 8427, 'Line of Duty S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238596.mp4', 'http://timg.bdta.pro/images/02fbca36ff54cf0f2694d7ebb1babb63.jpg'),
(117564, 8427, 'Line of Duty S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238597.mp4', 'http://timg.bdta.pro/images/a367d57be3ae9168346b41227b23cc1c.jpg'),
(117565, 8427, 'Line of Duty S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238598.mp4', 'http://timg.bdta.pro/images/76425853c04abf2cc945c05e9a52e25f.jpg'),
(117566, 8428, 'Twisted Metal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gX5QnIbzg0N0BDAcJwdUMYISe80.jpg'),
(117567, 8428, 'Twisted Metal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(117568, 8428, 'Twisted Metal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(117569, 8428, 'Twisted Metal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(117570, 8428, 'Twisted Metal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(117571, 8428, 'Twisted Metal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(117572, 8428, 'Twisted Metal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(117573, 8428, 'Twisted Metal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(117574, 8428, 'Twisted Metal S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(117575, 8428, 'Twisted Metal S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(117576, 8429, 'Twisted Metal S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/880340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(117577, 8429, 'Twisted Metal S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/880874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(117578, 8429, 'Twisted Metal S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/881921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(117579, 8429, 'Twisted Metal S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/881922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(117580, 8429, 'Twisted Metal S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/883534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(117581, 8429, 'Twisted Metal S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/884039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(117582, 8429, 'Twisted Metal S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/885682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(117583, 8429, 'Twisted Metal S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/887334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(117584, 8429, 'Twisted Metal S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/887721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(117585, 8429, 'Twisted Metal S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/888133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(117586, 8429, 'Twisted Metal S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/889712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(117587, 8429, 'Twisted Metal S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/890045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Zr9qJXqHQwi9IyPBDwukgg1jcZ.jpg'),
(117588, 8430, 'Black Snow [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/51bUkhRTiisPtfem9fpJPa0EDON.jpg'),
(117589, 8430, 'Black Snow [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xvcYQJkapmG6E2LGiSgApeg3DMN.jpg'),
(117590, 8430, 'Black Snow [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/talkmNWgPkpHffiSMgHVyKh85eG.jpg'),
(117591, 8430, 'Black Snow [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xwkBXUSUPUX0KuUh7h9Mo5TmtEv.jpg'),
(117592, 8430, 'Black Snow [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s9klUTu3zzra2vfcdLlmkxKjGky.jpg'),
(117593, 8430, 'Black Snow [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tnr6kr71R5lo2YQCx6Ba2Ty42Uh.jpg'),
(117594, 8431, 'Black Snow [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/885954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zDYKrQRho4PHUniVPnhKpH7lTPZ.jpg'),
(117595, 8431, 'Black Snow [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/885955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7xmaua48ML7qHE2jVa7WOmUDLFy.jpg'),
(117596, 8431, 'Black Snow [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/885956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhvh9fIxzvyKbyOTeECunqwVZ4F.jpg'),
(117597, 8431, 'Black Snow [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/665769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fXcO9UYbz5kDFyjNyaHHH8EuxDN.jpg'),
(117598, 8431, 'Black Snow [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/675948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fXcO9UYbz5kDFyjNyaHHH8EuxDN.jpg'),
(117599, 8431, 'Black Snow [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/683992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fXcO9UYbz5kDFyjNyaHHH8EuxDN.jpg'),
(117600, 8432, 'Acerto de Contas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAt1CF4B64gfm5JOi9H1PoBwmL6.jpg'),
(117601, 8432, 'Acerto de Contas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAt1CF4B64gfm5JOi9H1PoBwmL6.jpg'),
(117602, 8432, 'Acerto de Contas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAt1CF4B64gfm5JOi9H1PoBwmL6.jpg'),
(117603, 8432, 'Acerto de Contas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAt1CF4B64gfm5JOi9H1PoBwmL6.jpg'),
(117604, 8432, 'Acerto de Contas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAt1CF4B64gfm5JOi9H1PoBwmL6.jpg'),
(117605, 8432, 'Acerto de Contas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAt1CF4B64gfm5JOi9H1PoBwmL6.jpg'),
(117606, 8432, 'Acerto de Contas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAt1CF4B64gfm5JOi9H1PoBwmL6.jpg'),
(117607, 8432, 'Acerto de Contas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAt1CF4B64gfm5JOi9H1PoBwmL6.jpg'),
(117608, 8432, 'Acerto de Contas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAt1CF4B64gfm5JOi9H1PoBwmL6.jpg'),
(117609, 8432, 'Acerto de Contas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAt1CF4B64gfm5JOi9H1PoBwmL6.jpg'),
(117610, 8432, 'Acerto de Contas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/238414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAt1CF4B64gfm5JOi9H1PoBwmL6.jpg'),
(117611, 8432, 'Acerto de Contas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/238415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAt1CF4B64gfm5JOi9H1PoBwmL6.jpg'),
(117612, 8432, 'Acerto de Contas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/238416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAt1CF4B64gfm5JOi9H1PoBwmL6.jpg'),
(117613, 8433, 'My Fellow Citizens [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qlj2zDHPjAgqZ82BBIXLK8MvN17.jpg'),
(117614, 8433, 'My Fellow Citizens [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qruxYEw9zuYRSSRJur1yznnTUIz.jpg'),
(117615, 8433, 'My Fellow Citizens [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j2zQpL2cz1KR8COhefJnKfwIcdz.jpg'),
(117616, 8433, 'My Fellow Citizens [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lWxLZbunAdq0MzLCmv1DSHcicgk.jpg'),
(117617, 8433, 'My Fellow Citizens [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6allk19zaKNloKdS3JxZQBngbA.jpg'),
(117618, 8433, 'My Fellow Citizens [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3AlmWrp4NSG0SOPcfxG7wXVlTL.jpg'),
(117619, 8433, 'My Fellow Citizens [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wWgCO4p6sCslIMMdoa6wm4baSZ2.jpg'),
(117620, 8433, 'My Fellow Citizens [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4FZIM108VrtdAiTcR69t3WnGUpI.jpg'),
(117621, 8433, 'My Fellow Citizens [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117622, 8433, 'My Fellow Citizens [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117623, 8433, 'My Fellow Citizens [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/238378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117624, 8433, 'My Fellow Citizens [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/238379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117625, 8433, 'My Fellow Citizens [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/238380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117626, 8433, 'My Fellow Citizens [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/238381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117627, 8433, 'My Fellow Citizens [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/238382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117628, 8433, 'My Fellow Citizens [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/238383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117629, 8433, 'My Fellow Citizens [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/238384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117630, 8433, 'My Fellow Citizens [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/238385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117631, 8433, 'My Fellow Citizens [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/238386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117632, 8433, 'My Fellow Citizens [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/238387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117633, 8433, 'My Fellow Citizens [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/238388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117634, 8433, 'My Fellow Citizens [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/238389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117635, 8433, 'My Fellow Citizens [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/238390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117636, 8433, 'My Fellow Citizens [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/238391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117637, 8433, 'My Fellow Citizens [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/238392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117638, 8433, 'My Fellow Citizens [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/238393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117639, 8433, 'My Fellow Citizens [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/238394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117640, 8433, 'My Fellow Citizens [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/238395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117641, 8433, 'My Fellow Citizens [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/238396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117642, 8433, 'My Fellow Citizens [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/238397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117643, 8433, 'My Fellow Citizens [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/238398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117644, 8433, 'My Fellow Citizens [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/238399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117645, 8433, 'My Fellow Citizens [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/238400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117646, 8433, 'My Fellow Citizens [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/238401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117647, 8433, 'My Fellow Citizens [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/238402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117648, 8433, 'My Fellow Citizens [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/238403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sndjLMuA00PVjxAqhEVPvE9b6rG.jpg'),
(117649, 8434, 'O Bicho Vai Pegar O Chamado da Natureza S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7nGB2kKESSQD6KpsQeV5uGetmZ7.jpg'),
(117650, 8434, 'O Bicho Vai Pegar O Chamado da Natureza S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7nGB2kKESSQD6KpsQeV5uGetmZ7.jpg'),
(117651, 8434, 'O Bicho Vai Pegar O Chamado da Natureza S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7nGB2kKESSQD6KpsQeV5uGetmZ7.jpg'),
(117652, 8434, 'O Bicho Vai Pegar O Chamado da Natureza S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7nGB2kKESSQD6KpsQeV5uGetmZ7.jpg'),
(117653, 8434, 'O Bicho Vai Pegar O Chamado da Natureza S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7nGB2kKESSQD6KpsQeV5uGetmZ7.jpg'),
(117654, 8434, 'O Bicho Vai Pegar O Chamado da Natureza S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7nGB2kKESSQD6KpsQeV5uGetmZ7.jpg'),
(117655, 8434, 'O Bicho Vai Pegar O Chamado da Natureza S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7nGB2kKESSQD6KpsQeV5uGetmZ7.jpg'),
(117656, 8434, 'O Bicho Vai Pegar O Chamado da Natureza S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7nGB2kKESSQD6KpsQeV5uGetmZ7.jpg'),
(117657, 8435, 'Os Vivos e os Mortos [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uVQkPGTpQyoaZGpLlQMwMV1ZZpm.jpg'),
(117658, 8435, 'Os Vivos e os Mortos [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhsvrU5jvkkuZ3eg9iv99jyqgVR.jpg'),
(117659, 8435, 'Os Vivos e os Mortos [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hIh7r1gx72d8xB5TiXk6J6yg6Z.jpg'),
(117660, 8435, 'Os Vivos e os Mortos [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/il9m7THK3RyIQmy2ULCXbmiEf7p.jpg'),
(117661, 8435, 'Os Vivos e os Mortos [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sIeId0wRBrKLHVkQIUplv2pKgw9.jpg'),
(117662, 8435, 'Os Vivos e os Mortos [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rzqYnsD50edofJCC5C9yvBhBvxH.jpg'),
(117663, 8436, 'Queer for Fear The History of Queer Horror [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7cSmbV0FJpvtOzlavyON3g9B1gQ.jpg'),
(117664, 8436, 'Queer for Fear The History of Queer Horror [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7cSmbV0FJpvtOzlavyON3g9B1gQ.jpg'),
(117665, 8436, 'Queer for Fear The History of Queer Horror [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7cSmbV0FJpvtOzlavyON3g9B1gQ.jpg'),
(117666, 8436, 'Queer for Fear The History of Queer Horror [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7cSmbV0FJpvtOzlavyON3g9B1gQ.jpg'),
(117667, 8437, 'Roubo por Vinganca [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qlj2zDHPjAgqZ82BBIXLK8MvN17.jpg'),
(117668, 8437, 'Roubo por Vinganca [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qruxYEw9zuYRSSRJur1yznnTUIz.jpg'),
(117669, 8437, 'Roubo por Vinganca [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j2zQpL2cz1KR8COhefJnKfwIcdz.jpg'),
(117670, 8437, 'Roubo por Vinganca [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lWxLZbunAdq0MzLCmv1DSHcicgk.jpg'),
(117671, 8437, 'Roubo por Vinganca [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6allk19zaKNloKdS3JxZQBngbA.jpg'),
(117672, 8437, 'Roubo por Vinganca [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3AlmWrp4NSG0SOPcfxG7wXVlTL.jpg'),
(117673, 8437, 'Roubo por Vinganca [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wWgCO4p6sCslIMMdoa6wm4baSZ2.jpg'),
(117674, 8437, 'Roubo por Vinganca [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4FZIM108VrtdAiTcR69t3WnGUpI.jpg'),
(117675, 8438, 'Stay With Me [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hKtZP4UutMoJEc34Ycwomhrxo5f.jpg'),
(117676, 8438, 'Stay With Me [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Ak7oDKzGk7cw2YGITIRuVD95AR.jpg'),
(117677, 8438, 'Stay With Me [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ZTFIEbrcOeWaUg0mNNxPhPrYEg.jpg'),
(117678, 8438, 'Stay With Me [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ypcBhknJ4Wg6dE0XLbkeSFZxZgm.jpg'),
(117679, 8438, 'Stay With Me [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rtgNroWEI6fXUU9ZvX4abBYEIot.jpg'),
(117680, 8438, 'Stay With Me [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ihnZXGP8Jq7BNRUCG22xg7dfaOB.jpg'),
(117681, 8438, 'Stay With Me [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tN80VMKtIMUkR47JpY8b604Tir0.jpg'),
(117682, 8438, 'Stay With Me [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/96m00yHnjbxLTomsa96nnZ7oAhB.jpg'),
(117683, 8438, 'Stay With Me [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rEYHm0vvM5sQpq6vHxP294SAXQa.jpg'),
(117684, 8438, 'Stay With Me [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shbscV9HKbZ8qbZIvoHNivmC2e9.jpg'),
(117685, 8438, 'Stay With Me [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/238328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n8mYb3ToRCTZzJJn7GuBD17mO8q.jpg'),
(117686, 8438, 'Stay With Me [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/238329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cRyOQH9LwJ82OIVAxqoyByKGU8D.jpg'),
(117687, 8438, 'Stay With Me [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/238330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u8CPRxEsyoBU0iFK3eCuwj5RTdn.jpg'),
(117688, 8438, 'Stay With Me [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/238331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dM6r4j1t2of76oevqSB5EfeNdRv.jpg'),
(117689, 8438, 'Stay With Me [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/238332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oCSSrTUwvApyerjMe4Y8Sy2NND8.jpg'),
(117690, 8438, 'Stay With Me [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/238333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3LitVddkk5FLBTBHOgOzIdYA154.jpg'),
(117691, 8438, 'Stay With Me [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/238334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tDAcO4ApibNzRhiitxlRofSyg4I.jpg'),
(117692, 8438, 'Stay With Me [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/238335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lOW62l8WPw9AItXYubDuNKMPt46.jpg'),
(117693, 8438, 'Stay With Me [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/238336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nQPstC3JfNNgdXoYfmyVDQ3f8Ny.jpg'),
(117694, 8438, 'Stay With Me [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/238337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8i9w25AxCkcJ7OY2vaqDimqD1Jg.jpg'),
(117695, 8438, 'Stay With Me [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/238338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7uQ8DFTGNxNx7K0NSValYjHeEFB.jpg'),
(117696, 8438, 'Stay With Me [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/238339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6HUPlX2LzCzopk0OCNiZAyLvbyI.jpg'),
(117697, 8438, 'Stay With Me [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/238340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odeotF5vbZThei2leezGmFXeUYn.jpg'),
(117698, 8438, 'Stay With Me [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/238341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8J8ulbCQD7DKAZH2eTj0Ufr9Q9.jpg'),
(117699, 8439, 'The Newsreader [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243269.mp4', 'http://timg.bdta.pro/images/448ae4596c02a720452c3ce9e45d53fb.jpg'),
(117700, 8439, 'The Newsreader [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A80E9KLvFnn8RVldRY2wsesXW2e.jpg'),
(117701, 8439, 'The Newsreader [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243271.mp4', 'http://timg.bdta.pro/images/f5a915579cd7e06004a5370881242871.jpg'),
(117702, 8439, 'The Newsreader [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243272.mp4', 'http://timg.bdta.pro/images/be07d2ec193ff97b094778539b5084ff.jpg'),
(117703, 8439, 'The Newsreader [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243273.mp4', 'http://timg.bdta.pro/images/6a7a16e4186d4039c992654e4a72ed47.jpg'),
(117704, 8439, 'The Newsreader [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243274.mp4', 'http://timg.bdta.pro/images/0e70d77f0cfa19a18bfe5156c072477d.jpg'),
(117705, 8440, 'The Newsreader [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/atNgLwin6iUs365TUujfsQgftXb.jpg'),
(117706, 8440, 'The Newsreader [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fQxj36yLEXwqHx06kWQsYAG2Tqy.jpg'),
(117707, 8440, 'The Newsreader [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bj64xOo8J4zThDrgLTqBzLidvCi.jpg'),
(117708, 8440, 'The Newsreader [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tW6pFsH04QrinknQKM26wtzLjia.jpg'),
(117709, 8440, 'The Newsreader [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tW6pFsH04QrinknQKM26wtzLjia.jpg'),
(117710, 8440, 'The Newsreader [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tW6pFsH04QrinknQKM26wtzLjia.jpg'),
(117711, 8441, 'Vasco Rossi Toda uma Vida [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/KAYxBIickOKBj205Sn5Sx1azvu.jpg'),
(117712, 8441, 'Vasco Rossi Toda uma Vida [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t1EAOmzHWt6w1iG8lHd8i8id6AV.jpg'),
(117713, 8441, 'Vasco Rossi Toda uma Vida [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ctOtSAtp7WW8lYRCRfvb2GfZzBL.jpg'),
(117714, 8441, 'Vasco Rossi Toda uma Vida [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cSzwQnYuOmiocUWO8NDHBa5JiL6.jpg'),
(117715, 8441, 'Vasco Rossi Toda uma Vida [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ijh4X68o8w9aluM8JNoUVBsHFdg.jpg'),
(117716, 8442, 'You Are Mine [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sTfmK7KPnFXkHO23gXWxJe6juGq.jpg'),
(117717, 8442, 'You Are Mine [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eeq5kKzu4Eq5kIzVK3OPnI9bAWT.jpg'),
(117718, 8442, 'You Are Mine [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Hzh0MvM2DfcIVsgunYfO8OGI3I.jpg'),
(117719, 8442, 'You Are Mine [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mDfZP16RP381UUeVv2um7LhTJIP.jpg'),
(117720, 8442, 'You Are Mine [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1T8fiexY6Sw97WLWD9rZ2xbTcmE.jpg'),
(117721, 8442, 'You Are Mine [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1T8fiexY6Sw97WLWD9rZ2xbTcmE.jpg'),
(117722, 8442, 'You Are Mine [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1T8fiexY6Sw97WLWD9rZ2xbTcmE.jpg'),
(117723, 8442, 'You Are Mine [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1T8fiexY6Sw97WLWD9rZ2xbTcmE.jpg'),
(117724, 8442, 'You Are Mine [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1T8fiexY6Sw97WLWD9rZ2xbTcmE.jpg'),
(117725, 8442, 'You Are Mine [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1T8fiexY6Sw97WLWD9rZ2xbTcmE.jpg'),
(117726, 8443, 'Hunter x Hunter S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ppEotl1YMs1adTscDdMoLhQaQ3.jpg'),
(117727, 8443, 'Hunter x Hunter S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qEX0cNZhtRdvXkqalV3cg1yiJhB.jpg'),
(117728, 8443, 'Hunter x Hunter S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBvtNJypYY0Jm2nb3B9K7IAC5N2.jpg'),
(117729, 8443, 'Hunter x Hunter S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4guXoOOo3DEN4OkSdlC5Cf6EZey.jpg'),
(117730, 8443, 'Hunter x Hunter S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/597gzJBK4A8tbDX4KZKrK9hmJQG.jpg'),
(117731, 8443, 'Hunter x Hunter S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fU4qeE9kQXtVDHnp2vgzxjOycsG.jpg'),
(117732, 8443, 'Hunter x Hunter S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ktmIrxuf7aOrJlivhovCqnrDvOz.jpg'),
(117733, 8443, 'Hunter x Hunter S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sj2RJGWOjtR9t903J3jXesPGEe3.jpg'),
(117734, 8443, 'Hunter x Hunter S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lAqMF73lJBtNPkyoZHOgpEJwL5E.jpg'),
(117735, 8443, 'Hunter x Hunter S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iwZQOYXqojkNzVIa23t6kY3QBoJ.jpg'),
(117736, 8443, 'Hunter x Hunter S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDlwi2JQREzRF7eyqCXQJmLWCvA.jpg'),
(117737, 8443, 'Hunter x Hunter S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9CjSlm1zoWsFcvBNRds8ilZueWF.jpg'),
(117738, 8443, 'Hunter x Hunter S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8gDyN4qfTUXotm5HqdMsrjxvJv8.jpg'),
(117739, 8443, 'Hunter x Hunter S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qCFO7q6Xu0vFGE9XyzDxK7jcPoL.jpg'),
(117740, 8443, 'Hunter x Hunter S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vwQGJWECo9pcMNOiWcNfZZqYUyj.jpg'),
(117741, 8443, 'Hunter x Hunter S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/237925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ipiSa3T8dTKUN2ONfcRRasL1Yj3.jpg'),
(117742, 8443, 'Hunter x Hunter S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/237926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tNsFQC2NKUubt5tXo0RTM7NkA6W.jpg'),
(117743, 8443, 'Hunter x Hunter S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/237927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJZkqcrHpmZHxegZ78LzDfcOmuX.jpg'),
(117744, 8443, 'Hunter x Hunter S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/237928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3dDeKMK7zSvwPmqfJx8QIysbxvP.jpg'),
(117745, 8443, 'Hunter x Hunter S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/237929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gdCm8R66k7J6lxGHEbH2Dwg0jl4.jpg'),
(117746, 8443, 'Hunter x Hunter S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/237930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v3V2wFLlfDJePv8r539fvZc4d4O.jpg'),
(117747, 8443, 'Hunter x Hunter S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/237931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9rEeoWdY3fGhqyEB0aBuZulmJc.jpg'),
(117748, 8443, 'Hunter x Hunter S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/237932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ubAClUC0YLOcXVTAZBe7Ifc7NcS.jpg'),
(117749, 8443, 'Hunter x Hunter S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/237933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b9dLM01DTcBvNKkkzG7VKrBRwQ2.jpg'),
(117750, 8443, 'Hunter x Hunter S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/237934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yk0Mv0GuGVjyPF9dvHOY5feL5bo.jpg'),
(117751, 8443, 'Hunter x Hunter S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/237935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ALbyCGQjoYTTTiPOeAANpkXyI.jpg'),
(117752, 8444, 'Hunter x Hunter S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117753, 8444, 'Hunter x Hunter S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117754, 8444, 'Hunter x Hunter S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117755, 8444, 'Hunter x Hunter S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117756, 8444, 'Hunter x Hunter S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117757, 8444, 'Hunter x Hunter S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117758, 8444, 'Hunter x Hunter S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117759, 8444, 'Hunter x Hunter S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117760, 8444, 'Hunter x Hunter S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117761, 8444, 'Hunter x Hunter S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117762, 8444, 'Hunter x Hunter S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117763, 8444, 'Hunter x Hunter S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117764, 8445, 'Hunter x Hunter S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117765, 8445, 'Hunter x Hunter S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117766, 8445, 'Hunter x Hunter S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117767, 8445, 'Hunter x Hunter S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117768, 8445, 'Hunter x Hunter S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117769, 8445, 'Hunter x Hunter S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117770, 8445, 'Hunter x Hunter S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117771, 8445, 'Hunter x Hunter S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117772, 8445, 'Hunter x Hunter S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117773, 8445, 'Hunter x Hunter S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117774, 8445, 'Hunter x Hunter S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117775, 8445, 'Hunter x Hunter S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117776, 8445, 'Hunter x Hunter S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117777, 8445, 'Hunter x Hunter S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117778, 8445, 'Hunter x Hunter S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117779, 8445, 'Hunter x Hunter S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/237963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117780, 8445, 'Hunter x Hunter S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/237964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117781, 8445, 'Hunter x Hunter S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/237965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117782, 8445, 'Hunter x Hunter S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/237966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117783, 8445, 'Hunter x Hunter S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/237967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117784, 8446, 'Hunter x Hunter S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117785, 8446, 'Hunter x Hunter S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117786, 8446, 'Hunter x Hunter S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117787, 8446, 'Hunter x Hunter S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117788, 8446, 'Hunter x Hunter S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117789, 8446, 'Hunter x Hunter S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117790, 8446, 'Hunter x Hunter S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117791, 8446, 'Hunter x Hunter S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117792, 8446, 'Hunter x Hunter S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117793, 8446, 'Hunter x Hunter S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117794, 8446, 'Hunter x Hunter S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117795, 8446, 'Hunter x Hunter S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117796, 8446, 'Hunter x Hunter S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117797, 8446, 'Hunter x Hunter S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117798, 8446, 'Hunter x Hunter S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117799, 8446, 'Hunter x Hunter S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/237983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117800, 8446, 'Hunter x Hunter S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/237984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117801, 8447, 'Hunter x Hunter S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117802, 8447, 'Hunter x Hunter S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117803, 8447, 'Hunter x Hunter S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117804, 8447, 'Hunter x Hunter S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117805, 8447, 'Hunter x Hunter S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117806, 8447, 'Hunter x Hunter S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117807, 8447, 'Hunter x Hunter S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117808, 8447, 'Hunter x Hunter S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117809, 8447, 'Hunter x Hunter S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117810, 8447, 'Hunter x Hunter S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117811, 8447, 'Hunter x Hunter S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117812, 8447, 'Hunter x Hunter S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117813, 8447, 'Hunter x Hunter S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117814, 8447, 'Hunter x Hunter S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117815, 8447, 'Hunter x Hunter S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117816, 8447, 'Hunter x Hunter S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/238000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117817, 8447, 'Hunter x Hunter S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/238001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117818, 8447, 'Hunter x Hunter S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/238002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117819, 8447, 'Hunter x Hunter S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/238003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117820, 8447, 'Hunter x Hunter S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/238004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117821, 8447, 'Hunter x Hunter S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/238005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(117822, 8447, 'Hunter x Hunter S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/238006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117823, 8447, 'Hunter x Hunter S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/238007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117824, 8447, 'Hunter x Hunter S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/238008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117825, 8447, 'Hunter x Hunter S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/238009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117826, 8447, 'Hunter x Hunter S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/238010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117827, 8447, 'Hunter x Hunter S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/238011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117828, 8447, 'Hunter x Hunter S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/238012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117829, 8447, 'Hunter x Hunter S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/238013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117830, 8447, 'Hunter x Hunter S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/238014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117831, 8447, 'Hunter x Hunter S05 E31', 'http://sinalprivado.info:80/series/1533784/1533784/238015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117832, 8447, 'Hunter x Hunter S05 E32', 'http://sinalprivado.info:80/series/1533784/1533784/238016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117833, 8447, 'Hunter x Hunter S05 E33', 'http://sinalprivado.info:80/series/1533784/1533784/238017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117834, 8447, 'Hunter x Hunter S05 E34', 'http://sinalprivado.info:80/series/1533784/1533784/238018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117835, 8447, 'Hunter x Hunter S05 E35', 'http://sinalprivado.info:80/series/1533784/1533784/238019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117836, 8447, 'Hunter x Hunter S05 E36', 'http://sinalprivado.info:80/series/1533784/1533784/238020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117837, 8447, 'Hunter x Hunter S05 E37', 'http://sinalprivado.info:80/series/1533784/1533784/238021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117838, 8447, 'Hunter x Hunter S05 E38', 'http://sinalprivado.info:80/series/1533784/1533784/238022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117839, 8447, 'Hunter x Hunter S05 E39', 'http://sinalprivado.info:80/series/1533784/1533784/238023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117840, 8447, 'Hunter x Hunter S05 E40', 'http://sinalprivado.info:80/series/1533784/1533784/238024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117841, 8447, 'Hunter x Hunter S05 E41', 'http://sinalprivado.info:80/series/1533784/1533784/238025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117842, 8447, 'Hunter x Hunter S05 E42', 'http://sinalprivado.info:80/series/1533784/1533784/238026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117843, 8447, 'Hunter x Hunter S05 E43', 'http://sinalprivado.info:80/series/1533784/1533784/238027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117844, 8447, 'Hunter x Hunter S05 E44', 'http://sinalprivado.info:80/series/1533784/1533784/238028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117845, 8447, 'Hunter x Hunter S05 E45', 'http://sinalprivado.info:80/series/1533784/1533784/238029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117846, 8447, 'Hunter x Hunter S05 E46', 'http://sinalprivado.info:80/series/1533784/1533784/238030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117847, 8447, 'Hunter x Hunter S05 E47', 'http://sinalprivado.info:80/series/1533784/1533784/238031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117848, 8447, 'Hunter x Hunter S05 E48', 'http://sinalprivado.info:80/series/1533784/1533784/238032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117849, 8447, 'Hunter x Hunter S05 E49', 'http://sinalprivado.info:80/series/1533784/1533784/238033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117850, 8447, 'Hunter x Hunter S05 E50', 'http://sinalprivado.info:80/series/1533784/1533784/238034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117851, 8447, 'Hunter x Hunter S05 E51', 'http://sinalprivado.info:80/series/1533784/1533784/238035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117852, 8447, 'Hunter x Hunter S05 E52', 'http://sinalprivado.info:80/series/1533784/1533784/238036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117853, 8447, 'Hunter x Hunter S05 E53', 'http://sinalprivado.info:80/series/1533784/1533784/238037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117854, 8447, 'Hunter x Hunter S05 E54', 'http://sinalprivado.info:80/series/1533784/1533784/238038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117855, 8447, 'Hunter x Hunter S05 E55', 'http://sinalprivado.info:80/series/1533784/1533784/238039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117856, 8447, 'Hunter x Hunter S05 E56', 'http://sinalprivado.info:80/series/1533784/1533784/238040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117857, 8447, 'Hunter x Hunter S05 E57', 'http://sinalprivado.info:80/series/1533784/1533784/238041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117858, 8447, 'Hunter x Hunter S05 E58', 'http://sinalprivado.info:80/series/1533784/1533784/238042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117859, 8447, 'Hunter x Hunter S05 E59', 'http://sinalprivado.info:80/series/1533784/1533784/238043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117860, 8447, 'Hunter x Hunter S05 E60', 'http://sinalprivado.info:80/series/1533784/1533784/238044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117861, 8447, 'Hunter x Hunter S05 E61', 'http://sinalprivado.info:80/series/1533784/1533784/238045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117862, 8448, 'Hunter x Hunter S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117863, 8448, 'Hunter x Hunter S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117864, 8448, 'Hunter x Hunter S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117865, 8448, 'Hunter x Hunter S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117866, 8448, 'Hunter x Hunter S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117867, 8448, 'Hunter x Hunter S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117868, 8448, 'Hunter x Hunter S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117869, 8448, 'Hunter x Hunter S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117870, 8448, 'Hunter x Hunter S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117871, 8448, 'Hunter x Hunter S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117872, 8448, 'Hunter x Hunter S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/238056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117873, 8448, 'Hunter x Hunter S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/238057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117874, 8449, 'Hunter x Hunter [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ppEotl1YMs1adTscDdMoLhQaQ3.jpg'),
(117875, 8449, 'Hunter x Hunter [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qEX0cNZhtRdvXkqalV3cg1yiJhB.jpg'),
(117876, 8449, 'Hunter x Hunter [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBvtNJypYY0Jm2nb3B9K7IAC5N2.jpg'),
(117877, 8449, 'Hunter x Hunter [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4guXoOOo3DEN4OkSdlC5Cf6EZey.jpg'),
(117878, 8449, 'Hunter x Hunter [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/597gzJBK4A8tbDX4KZKrK9hmJQG.jpg'),
(117879, 8449, 'Hunter x Hunter [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fU4qeE9kQXtVDHnp2vgzxjOycsG.jpg'),
(117880, 8449, 'Hunter x Hunter [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ktmIrxuf7aOrJlivhovCqnrDvOz.jpg'),
(117881, 8449, 'Hunter x Hunter [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sj2RJGWOjtR9t903J3jXesPGEe3.jpg'),
(117882, 8449, 'Hunter x Hunter [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lAqMF73lJBtNPkyoZHOgpEJwL5E.jpg'),
(117883, 8449, 'Hunter x Hunter [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iwZQOYXqojkNzVIa23t6kY3QBoJ.jpg'),
(117884, 8449, 'Hunter x Hunter [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDlwi2JQREzRF7eyqCXQJmLWCvA.jpg'),
(117885, 8449, 'Hunter x Hunter [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9CjSlm1zoWsFcvBNRds8ilZueWF.jpg'),
(117886, 8449, 'Hunter x Hunter [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8gDyN4qfTUXotm5HqdMsrjxvJv8.jpg'),
(117887, 8449, 'Hunter x Hunter [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qCFO7q6Xu0vFGE9XyzDxK7jcPoL.jpg'),
(117888, 8449, 'Hunter x Hunter [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vwQGJWECo9pcMNOiWcNfZZqYUyj.jpg'),
(117889, 8449, 'Hunter x Hunter [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/237777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ipiSa3T8dTKUN2ONfcRRasL1Yj3.jpg'),
(117890, 8449, 'Hunter x Hunter [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/237778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tNsFQC2NKUubt5tXo0RTM7NkA6W.jpg'),
(117891, 8449, 'Hunter x Hunter [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/237779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJZkqcrHpmZHxegZ78LzDfcOmuX.jpg'),
(117892, 8449, 'Hunter x Hunter [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/237780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3dDeKMK7zSvwPmqfJx8QIysbxvP.jpg'),
(117893, 8449, 'Hunter x Hunter [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/237781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gdCm8R66k7J6lxGHEbH2Dwg0jl4.jpg'),
(117894, 8449, 'Hunter x Hunter [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/237782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v3V2wFLlfDJePv8r539fvZc4d4O.jpg'),
(117895, 8449, 'Hunter x Hunter [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/237783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9rEeoWdY3fGhqyEB0aBuZulmJc.jpg'),
(117896, 8449, 'Hunter x Hunter [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/237784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ubAClUC0YLOcXVTAZBe7Ifc7NcS.jpg'),
(117897, 8449, 'Hunter x Hunter [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/237785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b9dLM01DTcBvNKkkzG7VKrBRwQ2.jpg'),
(117898, 8449, 'Hunter x Hunter [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/237786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yk0Mv0GuGVjyPF9dvHOY5feL5bo.jpg'),
(117899, 8449, 'Hunter x Hunter [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/237787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ALbyCGQjoYTTTiPOeAANpkXyI.jpg'),
(117900, 8450, 'Hunter x Hunter [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117901, 8450, 'Hunter x Hunter [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117902, 8450, 'Hunter x Hunter [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117903, 8450, 'Hunter x Hunter [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117904, 8450, 'Hunter x Hunter [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117905, 8450, 'Hunter x Hunter [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117906, 8450, 'Hunter x Hunter [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117907, 8450, 'Hunter x Hunter [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117908, 8450, 'Hunter x Hunter [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117909, 8450, 'Hunter x Hunter [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117910, 8450, 'Hunter x Hunter [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117911, 8450, 'Hunter x Hunter [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117912, 8451, 'Hunter x Hunter [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117913, 8451, 'Hunter x Hunter [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117914, 8451, 'Hunter x Hunter [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117915, 8451, 'Hunter x Hunter [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117916, 8451, 'Hunter x Hunter [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117917, 8451, 'Hunter x Hunter [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117918, 8451, 'Hunter x Hunter [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117919, 8451, 'Hunter x Hunter [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117920, 8451, 'Hunter x Hunter [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117921, 8451, 'Hunter x Hunter [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117922, 8451, 'Hunter x Hunter [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117923, 8451, 'Hunter x Hunter [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117924, 8451, 'Hunter x Hunter [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117925, 8451, 'Hunter x Hunter [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117926, 8451, 'Hunter x Hunter [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117927, 8451, 'Hunter x Hunter [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/237815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117928, 8451, 'Hunter x Hunter [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/237816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117929, 8451, 'Hunter x Hunter [L] S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/237817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117930, 8451, 'Hunter x Hunter [L] S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/237818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117931, 8451, 'Hunter x Hunter [L] S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/237819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117932, 8452, 'Hunter x Hunter [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117933, 8452, 'Hunter x Hunter [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117934, 8452, 'Hunter x Hunter [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117935, 8452, 'Hunter x Hunter [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117936, 8452, 'Hunter x Hunter [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117937, 8452, 'Hunter x Hunter [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117938, 8452, 'Hunter x Hunter [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117939, 8452, 'Hunter x Hunter [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117940, 8452, 'Hunter x Hunter [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117941, 8452, 'Hunter x Hunter [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117942, 8452, 'Hunter x Hunter [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117943, 8452, 'Hunter x Hunter [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117944, 8452, 'Hunter x Hunter [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117945, 8452, 'Hunter x Hunter [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117946, 8452, 'Hunter x Hunter [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117947, 8452, 'Hunter x Hunter [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/237835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117948, 8452, 'Hunter x Hunter [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/237836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117949, 8453, 'Hunter x Hunter [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117950, 8453, 'Hunter x Hunter [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117951, 8453, 'Hunter x Hunter [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117952, 8453, 'Hunter x Hunter [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117953, 8453, 'Hunter x Hunter [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117954, 8453, 'Hunter x Hunter [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117955, 8453, 'Hunter x Hunter [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117956, 8453, 'Hunter x Hunter [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117957, 8453, 'Hunter x Hunter [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117958, 8453, 'Hunter x Hunter [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117959, 8453, 'Hunter x Hunter [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117960, 8453, 'Hunter x Hunter [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117961, 8453, 'Hunter x Hunter [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117962, 8453, 'Hunter x Hunter [L] S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117963, 8453, 'Hunter x Hunter [L] S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117964, 8453, 'Hunter x Hunter [L] S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/237852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117965, 8453, 'Hunter x Hunter [L] S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/237853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117966, 8453, 'Hunter x Hunter [L] S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/237854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117967, 8453, 'Hunter x Hunter [L] S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/237855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117968, 8453, 'Hunter x Hunter [L] S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/237856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117969, 8453, 'Hunter x Hunter [L] S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/237857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117970, 8453, 'Hunter x Hunter [L] S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/237858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117971, 8453, 'Hunter x Hunter [L] S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/237859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117972, 8453, 'Hunter x Hunter [L] S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/237860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117973, 8453, 'Hunter x Hunter [L] S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/237861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117974, 8453, 'Hunter x Hunter [L] S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/237862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117975, 8453, 'Hunter x Hunter [L] S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/237863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117976, 8453, 'Hunter x Hunter [L] S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/237864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117977, 8453, 'Hunter x Hunter [L] S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/237865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117978, 8453, 'Hunter x Hunter [L] S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/237866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117979, 8453, 'Hunter x Hunter [L] S05 E31', 'http://sinalprivado.info:80/series/1533784/1533784/237867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117980, 8453, 'Hunter x Hunter [L] S05 E32', 'http://sinalprivado.info:80/series/1533784/1533784/237868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117981, 8453, 'Hunter x Hunter [L] S05 E33', 'http://sinalprivado.info:80/series/1533784/1533784/237869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117982, 8453, 'Hunter x Hunter [L] S05 E34', 'http://sinalprivado.info:80/series/1533784/1533784/237870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117983, 8453, 'Hunter x Hunter [L] S05 E35', 'http://sinalprivado.info:80/series/1533784/1533784/237871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117984, 8453, 'Hunter x Hunter [L] S05 E36', 'http://sinalprivado.info:80/series/1533784/1533784/237872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117985, 8453, 'Hunter x Hunter [L] S05 E37', 'http://sinalprivado.info:80/series/1533784/1533784/237873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117986, 8453, 'Hunter x Hunter [L] S05 E38', 'http://sinalprivado.info:80/series/1533784/1533784/237874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117987, 8453, 'Hunter x Hunter [L] S05 E39', 'http://sinalprivado.info:80/series/1533784/1533784/237875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117988, 8453, 'Hunter x Hunter [L] S05 E40', 'http://sinalprivado.info:80/series/1533784/1533784/237876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117989, 8453, 'Hunter x Hunter [L] S05 E41', 'http://sinalprivado.info:80/series/1533784/1533784/237877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117990, 8453, 'Hunter x Hunter [L] S05 E42', 'http://sinalprivado.info:80/series/1533784/1533784/237878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117991, 8453, 'Hunter x Hunter [L] S05 E43', 'http://sinalprivado.info:80/series/1533784/1533784/237879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117992, 8453, 'Hunter x Hunter [L] S05 E44', 'http://sinalprivado.info:80/series/1533784/1533784/237880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117993, 8453, 'Hunter x Hunter [L] S05 E45', 'http://sinalprivado.info:80/series/1533784/1533784/237881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117994, 8453, 'Hunter x Hunter [L] S05 E46', 'http://sinalprivado.info:80/series/1533784/1533784/237882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117995, 8453, 'Hunter x Hunter [L] S05 E47', 'http://sinalprivado.info:80/series/1533784/1533784/237883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117996, 8453, 'Hunter x Hunter [L] S05 E48', 'http://sinalprivado.info:80/series/1533784/1533784/237884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117997, 8453, 'Hunter x Hunter [L] S05 E49', 'http://sinalprivado.info:80/series/1533784/1533784/237885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117998, 8453, 'Hunter x Hunter [L] S05 E50', 'http://sinalprivado.info:80/series/1533784/1533784/237886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(117999, 8453, 'Hunter x Hunter [L] S05 E51', 'http://sinalprivado.info:80/series/1533784/1533784/237887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118000, 8453, 'Hunter x Hunter [L] S05 E52', 'http://sinalprivado.info:80/series/1533784/1533784/237888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118001, 8453, 'Hunter x Hunter [L] S05 E53', 'http://sinalprivado.info:80/series/1533784/1533784/237889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118002, 8453, 'Hunter x Hunter [L] S05 E54', 'http://sinalprivado.info:80/series/1533784/1533784/237890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118003, 8453, 'Hunter x Hunter [L] S05 E55', 'http://sinalprivado.info:80/series/1533784/1533784/237891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118004, 8453, 'Hunter x Hunter [L] S05 E56', 'http://sinalprivado.info:80/series/1533784/1533784/237892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118005, 8453, 'Hunter x Hunter [L] S05 E57', 'http://sinalprivado.info:80/series/1533784/1533784/237893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118006, 8453, 'Hunter x Hunter [L] S05 E58', 'http://sinalprivado.info:80/series/1533784/1533784/237894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118007, 8453, 'Hunter x Hunter [L] S05 E59', 'http://sinalprivado.info:80/series/1533784/1533784/237895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118008, 8453, 'Hunter x Hunter [L] S05 E60', 'http://sinalprivado.info:80/series/1533784/1533784/237896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118009, 8453, 'Hunter x Hunter [L] S05 E61', 'http://sinalprivado.info:80/series/1533784/1533784/237897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118010, 8454, 'Hunter x Hunter [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118011, 8454, 'Hunter x Hunter [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118012, 8454, 'Hunter x Hunter [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118013, 8454, 'Hunter x Hunter [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118014, 8454, 'Hunter x Hunter [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118015, 8454, 'Hunter x Hunter [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118016, 8454, 'Hunter x Hunter [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118017, 8454, 'Hunter x Hunter [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118018, 8454, 'Hunter x Hunter [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118019, 8454, 'Hunter x Hunter [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118020, 8454, 'Hunter x Hunter [L] S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118021, 8454, 'Hunter x Hunter [L] S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WxfAQquTun9ATkV6iAeFHMkqxv.jpg'),
(118022, 8455, 'Beckham S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bGNKvbL3VTiSZzIMLXAgdtJbjGw.jpg'),
(118023, 8455, 'Beckham S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bGNKvbL3VTiSZzIMLXAgdtJbjGw.jpg'),
(118024, 8455, 'Beckham S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bGNKvbL3VTiSZzIMLXAgdtJbjGw.jpg'),
(118025, 8455, 'Beckham S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bGNKvbL3VTiSZzIMLXAgdtJbjGw.jpg'),
(118026, 8456, 'Clara e o Chuveiro do Tempo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2tHxfaCsj6B1hj9NJPKMhr6UC1h.jpg'),
(118027, 8456, 'Clara e o Chuveiro do Tempo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2tHxfaCsj6B1hj9NJPKMhr6UC1h.jpg'),
(118028, 8456, 'Clara e o Chuveiro do Tempo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2tHxfaCsj6B1hj9NJPKMhr6UC1h.jpg'),
(118029, 8456, 'Clara e o Chuveiro do Tempo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2tHxfaCsj6B1hj9NJPKMhr6UC1h.jpg'),
(118030, 8457, 'O Relogio da Aventura S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5TO6gj5gLagFk5paFNFrQw49oZD.jpg'),
(118031, 8457, 'O Relogio da Aventura S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5TO6gj5gLagFk5paFNFrQw49oZD.jpg'),
(118032, 8457, 'O Relogio da Aventura S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5TO6gj5gLagFk5paFNFrQw49oZD.jpg'),
(118033, 8457, 'O Relogio da Aventura S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5TO6gj5gLagFk5paFNFrQw49oZD.jpg'),
(118034, 8457, 'O Relogio da Aventura S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5TO6gj5gLagFk5paFNFrQw49oZD.jpg'),
(118035, 8458, 'CSI Vegas [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zbovhZ4L3PD0KW0bm9ZHbrZFPgh.jpg'),
(118036, 8458, 'CSI Vegas [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qqriIpD224gZlTgWp9AxoB8cjel.jpg'),
(118037, 8458, 'CSI Vegas [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2yC5AEjBqD9NNNJGYH1m3JNUH3M.jpg'),
(118038, 8458, 'CSI Vegas [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/srPg6rNRQmT9G4FD2TARF5C5i8T.jpg'),
(118039, 8458, 'CSI Vegas [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nzILwAsl3mao6pNv30IUY0FVPxS.jpg'),
(118040, 8458, 'CSI Vegas [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w1zEEPscsT4nhOxUwBUb2IkNBvH.jpg'),
(118041, 8458, 'CSI Vegas [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xiQYuv5VnN1KZf47g6QsYlF8ocz.jpg'),
(118042, 8458, 'CSI Vegas [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7BNDvGw9gOpnUoxXcKPIT2X84dM.jpg'),
(118043, 8458, 'CSI Vegas [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3UUAQr5gD5JAceawFR7yE9wOquz.jpg'),
(118044, 8458, 'CSI Vegas [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1W1j3SDtKAD5u0QG8hJFYI7mglf.jpg'),
(118045, 8459, 'CSI Vegas [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gsw4PMM4BtfqJYT27WHmJKrQMMp.jpg'),
(118046, 8459, 'CSI Vegas [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhCTljq8OzlWYW3C5paAr2YvOhf.jpg'),
(118047, 8459, 'CSI Vegas [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rYJrYTR0RpBlp0fw0UfNaAZO7nP.jpg'),
(118048, 8459, 'CSI Vegas [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4CSLPkJwJZjZnfv69M7lIrIxTIc.jpg'),
(118049, 8459, 'CSI Vegas [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyzPZRlQAeCgHs1LVg51IEK5eqG.jpg'),
(118050, 8459, 'CSI Vegas [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aC6itufcH31L6E7HLg4oNo1kaD7.jpg'),
(118051, 8459, 'CSI Vegas [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c2eCFJmoQoJ0elmN7IDiAwPd3CN.jpg'),
(118052, 8459, 'CSI Vegas [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ywT1CJ4kzxKBhbJnkekQtdMaqqy.jpg'),
(118053, 8459, 'CSI Vegas [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUlTcgHvgfyUlN40BwdVjcUtSpz.jpg'),
(118054, 8459, 'CSI Vegas [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eVWvsiDk1AkWERrswokkkBc3AzB.jpg'),
(118055, 8459, 'CSI Vegas [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7zET6xdzBXcZsEfSSAyYaXmgYdg.jpg'),
(118056, 8459, 'CSI Vegas [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iAfwzp5gUwI6yeOa1QOcE5jdL4R.jpg'),
(118057, 8459, 'CSI Vegas [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qg0dtx1tn0MyWZ3fhOwkBemlHj5.jpg'),
(118058, 8459, 'CSI Vegas [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bVHOdqAmd2rJBDgLFmYhdG6whF3.jpg'),
(118059, 8459, 'CSI Vegas [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tpDO78DR5NHAv8rUUtNd040mzcN.jpg'),
(118060, 8459, 'CSI Vegas [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/237723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o5tuf4S9IJury7qZixvSlh0egHz.jpg'),
(118061, 8459, 'CSI Vegas [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/237724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ooXok5vvyL9r9pHuWUXsJhsrX5.jpg'),
(118062, 8459, 'CSI Vegas [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/237725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/HfEYpTcoSlO1VapSX8PuK9bVZ4.jpg'),
(118063, 8459, 'CSI Vegas [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/237726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p4GHGmOs260c1yRjcwFBatoymxf.jpg'),
(118064, 8459, 'CSI Vegas [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/237727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iN1O0ytfgJebsPRAKVHGlQ45UT6.jpg'),
(118065, 8459, 'CSI Vegas [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/237728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kkUXAxBjSi42YRXYtwCz4eaRjJ.jpg'),
(118066, 8460, 'CSI Vegas [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435851.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/prsmeerhXk7lWxml8Gtw0ymK6xu.jpg'),
(118067, 8460, 'CSI Vegas [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435852.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1XUoN5QaV34wmDwYuJ41g7q4aL6.jpg'),
(118068, 8460, 'CSI Vegas [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435853.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jNYpZ9bkjGtAkV2IPUB3NNQdD5J.jpg'),
(118069, 8460, 'CSI Vegas [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435854.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n1v3RIfk5yadfC3qNI3SHDKR8A2.jpg'),
(118070, 8460, 'CSI Vegas [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435855.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kjnf6TbgCxMMY08XVjVQTauHyc9.jpg'),
(118071, 8460, 'CSI Vegas [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435856.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/deRpmqltUaLKo1crVENw0ILAy8X.jpg'),
(118072, 8460, 'CSI Vegas [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/435857.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dNs2RBR6QPMZdobsKxTgQDuDm8f.jpg'),
(118073, 8460, 'CSI Vegas [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/435858.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wH984DfX7OquULmzcLYUm2xMVAT.jpg'),
(118074, 8460, 'CSI Vegas [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/435859.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wK4iOf2rSaiRA4aLhUUSWtVaqld.jpg'),
(118075, 8460, 'CSI Vegas [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/435860.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qb6FoCzWH1wRcJWVtl7fmtvFnqW.jpg'),
(118076, 8461, 'Jericho [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7Ax6uxtrwciElTsaJuYW6n2Fn7.jpg'),
(118077, 8461, 'Jericho [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6mQzBDyCZQ7fZ48cpVM1EELiJoU.jpg'),
(118078, 8461, 'Jericho [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qWFPJXQlUmzAGf50NiqxXvVht1p.jpg'),
(118079, 8461, 'Jericho [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQ0d9JdSZNhACSqQix1S81Usydh.jpg'),
(118080, 8461, 'Jericho [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mp3aUtEbNdPur3lcteEqyPiJOIw.jpg'),
(118081, 8461, 'Jericho [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/96LF25GTB6GaiFNZK3M6kyUqOlY.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(118082, 8461, 'Jericho [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9RkFGPK4Z9lGUOVuCJySiWAYNYm.jpg'),
(118083, 8461, 'Jericho [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/249xLNnmjjgFEZCUcMV5oKJX2Q9.jpg'),
(118084, 8461, 'Jericho [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/myCYOyLjXtQEffnlda8uUyg5hDY.jpg'),
(118085, 8461, 'Jericho [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i9sZeodItBp2Q41BVfGhtchNl2Y.jpg'),
(118086, 8461, 'Jericho [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gPSRoa2hhqhTpAYMQ8QgRM3hmDn.jpg'),
(118087, 8461, 'Jericho [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1pnnpJVhUiXsG9SNjCBpfVwusuZ.jpg'),
(118088, 8461, 'Jericho [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odo8Jisdf7B1HNTmibIApfOfT9E.jpg'),
(118089, 8461, 'Jericho [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6CvvSPYdCTGIzgKtlWNTexEAMTp.jpg'),
(118090, 8461, 'Jericho [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvR8ppIKOyExdXL7zu3d78ns4Zc.jpg'),
(118091, 8461, 'Jericho [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/237685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2dkYqsitqmqfKcIhENPGiEXCtS.jpg'),
(118092, 8461, 'Jericho [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/237686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7q1IKSehrDuzt95yPG2nI3S9f8b.jpg'),
(118093, 8461, 'Jericho [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/237687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3nD8J13Fb2DxekmgBtsVFwGdO1t.jpg'),
(118094, 8461, 'Jericho [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/237688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1vZ4VWdGb0XY8RX9HFhLCvakop6.jpg'),
(118095, 8461, 'Jericho [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/237689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3DplLZbWFw0l5m2zUibXEypH2zq.jpg'),
(118096, 8461, 'Jericho [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/237690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j6rwxtwm1xZ3qoF3gfXO332qFMS.jpg'),
(118097, 8461, 'Jericho [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/237691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aMWbScHw32bJ1v4ZEJOuR3oONUA.jpg'),
(118098, 8462, 'Jericho [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tdVusaYDtmh7KKqDyre4N3HT9l0.jpg'),
(118099, 8462, 'Jericho [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ltjNqyXMxiLAkaAEbtRSmC1aCTL.jpg'),
(118100, 8462, 'Jericho [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dDBz34n8e5j7smk2hSOOYZDnN52.jpg'),
(118101, 8462, 'Jericho [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fekxNCPR2WnSOooSwBuNRkoNQWT.jpg'),
(118102, 8462, 'Jericho [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fECWlZH3u5r6T2GGqoFwwnF9f6B.jpg'),
(118103, 8462, 'Jericho [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l8SjGbV1KzgbOfCzv0gTTvxwC0o.jpg'),
(118104, 8463, 'Migi to Dali [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hHkhP5CNkh1ykHde6xvDbvMcuZL.jpg'),
(118105, 8463, 'Migi to Dali [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSfjTea4v1Gf7EwcEcewmXTdg42.jpg'),
(118106, 8463, 'Migi to Dali [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSfjTea4v1Gf7EwcEcewmXTdg42.jpg'),
(118107, 8463, 'Migi to Dali [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSfjTea4v1Gf7EwcEcewmXTdg42.jpg'),
(118108, 8463, 'Migi to Dali [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSfjTea4v1Gf7EwcEcewmXTdg42.jpg'),
(118109, 8463, 'Migi to Dali [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSfjTea4v1Gf7EwcEcewmXTdg42.jpg'),
(118110, 8463, 'Migi to Dali [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSfjTea4v1Gf7EwcEcewmXTdg42.jpg'),
(118111, 8463, 'Migi to Dali [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSfjTea4v1Gf7EwcEcewmXTdg42.jpg'),
(118112, 8463, 'Migi to Dali [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSfjTea4v1Gf7EwcEcewmXTdg42.jpg'),
(118113, 8463, 'Migi to Dali [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSfjTea4v1Gf7EwcEcewmXTdg42.jpg'),
(118114, 8463, 'Migi to Dali [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSfjTea4v1Gf7EwcEcewmXTdg42.jpg'),
(118115, 8463, 'Migi to Dali [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSfjTea4v1Gf7EwcEcewmXTdg42.jpg'),
(118116, 8463, 'Migi to Dali [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSfjTea4v1Gf7EwcEcewmXTdg42.jpg'),
(118117, 8464, 'Nunca o Deixei Partir Investigando um Assassinato [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQIaIffnqnE8hVVfGQroftz2YUu.jpg'),
(118118, 8464, 'Nunca o Deixei Partir Investigando um Assassinato [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iy7tLWKGoPC1sHV6lTygMVIwH57.jpg'),
(118119, 8464, 'Nunca o Deixei Partir Investigando um Assassinato [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iLDZnX0IUMJcvww5ximWjaYFSqW.jpg'),
(118120, 8464, 'Nunca o Deixei Partir Investigando um Assassinato [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7CYzmY6zwWrHw12LrTyGfxRzd4e.jpg'),
(118121, 8465, 'Os Caras do Telemarketing [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bosDtZNFIfHHjVg4NfSgFKOnIAW.jpg'),
(118122, 8465, 'Os Caras do Telemarketing [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/do0QuxTGN7axI2errFpug02s5HQ.jpg'),
(118123, 8465, 'Os Caras do Telemarketing [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/52qPwKEOYGt0lGECVp0ShqSiNaV.jpg'),
(118124, 8466, 'Ragna Crimson [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1pniXDtlnXZWbYaIcnldhealmfd.jpg'),
(118125, 8466, 'Ragna Crimson [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118126, 8466, 'Ragna Crimson [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118127, 8466, 'Ragna Crimson [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118128, 8466, 'Ragna Crimson [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118129, 8466, 'Ragna Crimson [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118130, 8466, 'Ragna Crimson [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118131, 8466, 'Ragna Crimson [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118132, 8466, 'Ragna Crimson [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118133, 8466, 'Ragna Crimson [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118134, 8466, 'Ragna Crimson [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118135, 8466, 'Ragna Crimson [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118136, 8466, 'Ragna Crimson [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118137, 8466, 'Ragna Crimson [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118138, 8466, 'Ragna Crimson [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/268332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118139, 8466, 'Ragna Crimson [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/268333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118140, 8466, 'Ragna Crimson [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/272649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118141, 8466, 'Ragna Crimson [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/275114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118142, 8466, 'Ragna Crimson [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/282598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118143, 8466, 'Ragna Crimson [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/289937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118144, 8466, 'Ragna Crimson [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/297448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118145, 8466, 'Ragna Crimson [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/301128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118146, 8466, 'Ragna Crimson [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/307329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118147, 8466, 'Ragna Crimson [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/313673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvXdwtlfvJfixInKLMDsguxZ0jx.jpg'),
(118148, 8467, 'Ron Kamonohashis Forbidden Deductions [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iwiLQVvzSJL5a5T4M1odbWmJS4C.jpg'),
(118149, 8467, 'Ron Kamonohashis Forbidden Deductions [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vYRN0QQFFqQEJUANsd6VSThQqI.jpg'),
(118150, 8467, 'Ron Kamonohashis Forbidden Deductions [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/488396.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/icZl4ZKDieZVDTmh2ZrSujGoBlL.jpg'),
(118151, 8467, 'Ron Kamonohashis Forbidden Deductions [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/488397.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rvIk6hA0hAcR0lHC3ffr4hBobx0.jpg'),
(118152, 8467, 'Ron Kamonohashis Forbidden Deductions [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vYRN0QQFFqQEJUANsd6VSThQqI.jpg'),
(118153, 8467, 'Ron Kamonohashis Forbidden Deductions [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vYRN0QQFFqQEJUANsd6VSThQqI.jpg'),
(118154, 8467, 'Ron Kamonohashis Forbidden Deductions [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vYRN0QQFFqQEJUANsd6VSThQqI.jpg'),
(118155, 8467, 'Ron Kamonohashis Forbidden Deductions [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vYRN0QQFFqQEJUANsd6VSThQqI.jpg'),
(118156, 8467, 'Ron Kamonohashis Forbidden Deductions [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vYRN0QQFFqQEJUANsd6VSThQqI.jpg'),
(118157, 8467, 'Ron Kamonohashis Forbidden Deductions [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vYRN0QQFFqQEJUANsd6VSThQqI.jpg'),
(118158, 8467, 'Ron Kamonohashis Forbidden Deductions [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vYRN0QQFFqQEJUANsd6VSThQqI.jpg'),
(118159, 8467, 'Ron Kamonohashis Forbidden Deductions [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vYRN0QQFFqQEJUANsd6VSThQqI.jpg'),
(118160, 8467, 'Ron Kamonohashis Forbidden Deductions [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vYRN0QQFFqQEJUANsd6VSThQqI.jpg'),
(118161, 8468, 'Ron Kamonohashis Forbidden Deductions [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/636100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vYRN0QQFFqQEJUANsd6VSThQqI.jpg'),
(118162, 8468, 'Ron Kamonohashis Forbidden Deductions [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/636101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vYRN0QQFFqQEJUANsd6VSThQqI.jpg'),
(118163, 8468, 'Ron Kamonohashis Forbidden Deductions [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/636102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vYRN0QQFFqQEJUANsd6VSThQqI.jpg'),
(118164, 8468, 'Ron Kamonohashis Forbidden Deductions [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/636103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vYRN0QQFFqQEJUANsd6VSThQqI.jpg'),
(118165, 8468, 'Ron Kamonohashis Forbidden Deductions [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/636104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vYRN0QQFFqQEJUANsd6VSThQqI.jpg'),
(118166, 8468, 'Ron Kamonohashis Forbidden Deductions [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/636107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vYRN0QQFFqQEJUANsd6VSThQqI.jpg'),
(118167, 8468, 'Ron Kamonohashis Forbidden Deductions [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/636108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vYRN0QQFFqQEJUANsd6VSThQqI.jpg'),
(118168, 8468, 'Ron Kamonohashis Forbidden Deductions [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/520141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vYRN0QQFFqQEJUANsd6VSThQqI.jpg'),
(118169, 8468, 'Ron Kamonohashis Forbidden Deductions [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/636110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vYRN0QQFFqQEJUANsd6VSThQqI.jpg'),
(118170, 8468, 'Ron Kamonohashis Forbidden Deductions [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/639972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vYRN0QQFFqQEJUANsd6VSThQqI.jpg'),
(118171, 8468, 'Ron Kamonohashis Forbidden Deductions [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/657695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vYRN0QQFFqQEJUANsd6VSThQqI.jpg'),
(118172, 8469, 'SHY [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ruHXBXSb93K1erMaae8ba7F0vsP.jpg'),
(118173, 8469, 'SHY [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118174, 8469, 'SHY [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118175, 8469, 'SHY [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118176, 8469, 'SHY [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118177, 8469, 'SHY [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118178, 8469, 'SHY [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118179, 8469, 'SHY [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118180, 8469, 'SHY [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118181, 8469, 'SHY [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118182, 8469, 'SHY [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118183, 8469, 'SHY [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118184, 8469, 'SHY [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/404160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118185, 8469, 'SHY [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/404161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118186, 8469, 'SHY [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/411355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118187, 8469, 'SHY [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/414405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118188, 8469, 'SHY [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/420760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118189, 8469, 'SHY [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/428686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118190, 8469, 'SHY [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/438803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118191, 8469, 'SHY [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/441156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118192, 8469, 'SHY [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/450496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118193, 8469, 'SHY [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/450497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118194, 8469, 'SHY [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/457198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118195, 8470, 'SHY [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/463717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118196, 8470, 'SHY [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/463718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118197, 8470, 'SHY [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/463719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118198, 8470, 'SHY [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/463720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118199, 8470, 'SHY [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/463721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118200, 8470, 'SHY [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/463722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118201, 8470, 'SHY [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/463723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118202, 8470, 'SHY [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/463724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118203, 8470, 'SHY [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/463725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118204, 8470, 'SHY [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/463726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118205, 8470, 'SHY [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/463727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118206, 8470, 'SHY [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/463728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tbj6Co2lusxYlYZHNNXwhbAkl7U.jpg'),
(118207, 8471, 'A Era dos Humanos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gSw1VhsnZy87AZRxsib0ZjYl5ik.jpg'),
(118208, 8471, 'A Era dos Humanos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ahFGpS7lg7F1sX99OYS9qHLt2tR.jpg'),
(118209, 8471, 'A Era dos Humanos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hWSuwTMvrAo0549BSlORz6tLrKS.jpg'),
(118210, 8471, 'A Era dos Humanos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lIbiILuIIo9AuBMZwgkZ0ZxY5x2.jpg'),
(118211, 8472, 'Barganha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5oohpbdBCSSzSg1vurWEEV6DdfO.jpg'),
(118212, 8472, 'Barganha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2e7aRwiNtzNFaaFxTxCEYhkAmMW.jpg'),
(118213, 8472, 'Barganha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pxzNfAJV28gmwpDKiI9q1pWqMXO.jpg'),
(118214, 8472, 'Barganha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7zlMXIVkWwi3b8dRlC0KbhmNKum.jpg'),
(118215, 8472, 'Barganha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tx0TNXlMy7hzDszpSIFVCFPcLqM.jpg'),
(118216, 8472, 'Barganha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oBk5mqnaU6O5H3G0Kx4KI4qJxYG.jpg'),
(118217, 8473, 'Bob Esponja Calca Quadrada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hpXGDIK2MzQrMUnevsXBipCL64Z.jpg'),
(118218, 8473, 'Bob Esponja Calca Quadrada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4aaGQY4IWOXPiAYMY1YzsOegF21.jpg'),
(118219, 8473, 'Bob Esponja Calca Quadrada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n2zPM0MXF4FL7m9xkmDdNddNJO3.jpg'),
(118220, 8473, 'Bob Esponja Calca Quadrada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n9Z3CGw8FRc37lUUXtwcLST5eOn.jpg'),
(118221, 8473, 'Bob Esponja Calca Quadrada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n9Z3CGw8FRc37lUUXtwcLST5eOn.jpg'),
(118222, 8473, 'Bob Esponja Calca Quadrada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/thsF4DSn2e9tlo67U5Xz8GTUO9S.jpg'),
(118223, 8473, 'Bob Esponja Calca Quadrada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9HGErr2Eoxj2vbgrEkJWq9M2lGb.jpg'),
(118224, 8473, 'Bob Esponja Calca Quadrada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgv1s4j3HDQ8Elf9QRflZffoVeO.jpg'),
(118225, 8473, 'Bob Esponja Calca Quadrada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mfS7PCzCgi9ZE0njxrByg8aXUi.jpg'),
(118226, 8473, 'Bob Esponja Calca Quadrada S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyPrj3tULYebPYNYyn1YBL7Vcih.jpg'),
(118227, 8473, 'Bob Esponja Calca Quadrada S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7INugqVxq4WwH7Mm5dqRMt3SnEX.jpg'),
(118228, 8473, 'Bob Esponja Calca Quadrada S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j7iEyR6hWkk1kJ8kq3VZAZvMBcO.jpg'),
(118229, 8473, 'Bob Esponja Calca Quadrada S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vXvSXk7uRur697gQZCVqGOOXsuO.jpg'),
(118230, 8473, 'Bob Esponja Calca Quadrada S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d5IZPNQrAGiTvIyoeIhc5humU2o.jpg'),
(118231, 8473, 'Bob Esponja Calca Quadrada S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8cvruwFmo9Mk454MDWAtNODuT9m.jpg'),
(118232, 8473, 'Bob Esponja Calca Quadrada S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zRm48Y7snLTwj0zKL9QV0ukYl4Y.jpg'),
(118233, 8473, 'Bob Esponja Calca Quadrada S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/249223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sRrXQ03qJzPccm1o9zOlpM1H61o.jpg'),
(118234, 8473, 'Bob Esponja Calca Quadrada S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/249224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eKb6B7jNWAy0jtDtj5sewgV31cZ.jpg'),
(118235, 8473, 'Bob Esponja Calca Quadrada S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/249225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eKb6B7jNWAy0jtDtj5sewgV31cZ.jpg'),
(118236, 8473, 'Bob Esponja Calca Quadrada S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/249226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/90utvAP3BXOvSTKCLiXpQIvUfo4.jpg'),
(118237, 8474, 'Bob Esponja Calca Quadrada S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3OeNxHD1FuenrH9VN1gZDN55YU9.jpg'),
(118238, 8474, 'Bob Esponja Calca Quadrada S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6APRZJUAdh4rBZpawwX6yKYoonm.jpg'),
(118239, 8474, 'Bob Esponja Calca Quadrada S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Btm4sB5pPRTz6IrKML6lUco8q7.jpg'),
(118240, 8474, 'Bob Esponja Calca Quadrada S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kuL0UbNdNLDq9N4Wmr3aMALqa1t.jpg'),
(118241, 8474, 'Bob Esponja Calca Quadrada S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ex8op7stLh0ce0iaoQNOf6pqbOm.jpg'),
(118242, 8474, 'Bob Esponja Calca Quadrada S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOOVx88fCn0co0wMA8o41bqJ36c.jpg'),
(118243, 8474, 'Bob Esponja Calca Quadrada S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9f6ffOwZLFKYODIrjohToNQJInt.jpg'),
(118244, 8474, 'Bob Esponja Calca Quadrada S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kLtuLG4aOQhwTXab1kfxN746OYC.jpg'),
(118245, 8474, 'Bob Esponja Calca Quadrada S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6bu7BnKpU0O1JS3zWKJB3G38onM.jpg'),
(118246, 8474, 'Bob Esponja Calca Quadrada S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uOgamjgWwWmiXQDC1D1DQgAYkcy.jpg'),
(118247, 8474, 'Bob Esponja Calca Quadrada S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lVCWmHlyf9VR8PMXaWXufphMuW0.jpg'),
(118248, 8474, 'Bob Esponja Calca Quadrada S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0strOI8eHKNkY3cJ6lHk1lzx48.jpg'),
(118249, 8474, 'Bob Esponja Calca Quadrada S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qwAcl8ySmjE7LURkVbsv0DG6G70.jpg'),
(118250, 8474, 'Bob Esponja Calca Quadrada S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mDxtwLkqoRmQzLYSVE8WR7BomSm.jpg'),
(118251, 8474, 'Bob Esponja Calca Quadrada S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1zN4Kd7514i0gCaC5t7oZkxVPpK.jpg'),
(118252, 8474, 'Bob Esponja Calca Quadrada S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pWt2oAA7hx7WOgzEmpa1rtpmbOa.jpg'),
(118253, 8474, 'Bob Esponja Calca Quadrada S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/249243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jr9oCh072YSNgZhHObrxbysnxqU.jpg'),
(118254, 8474, 'Bob Esponja Calca Quadrada S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/249244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d8OaH3Mpt5nOMM7874uA9VOU9QG.jpg'),
(118255, 8475, 'Bob Esponja Calca Quadrada S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s6KnsSh2uTioBG6iuIxqzTgOq3y.jpg'),
(118256, 8475, 'Bob Esponja Calca Quadrada S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vGFjClvoXhQNPgkkLkmLbi79gTF.jpg'),
(118257, 8475, 'Bob Esponja Calca Quadrada S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/RMCXGHD2tfy8HNXW1SpX197LzE.jpg'),
(118258, 8475, 'Bob Esponja Calca Quadrada S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9yqx2VCiJE4BTnJyT1mO0WuPC7H.jpg'),
(118259, 8475, 'Bob Esponja Calca Quadrada S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vS9P4pEWbz7hmY8euVd1zm8Br2c.jpg'),
(118260, 8475, 'Bob Esponja Calca Quadrada S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rFWdt68YzAHRnxQaFnl5J5dwjiC.jpg'),
(118261, 8475, 'Bob Esponja Calca Quadrada S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uQUAlogGDTPugGS9M9XosvVitk6.jpg'),
(118262, 8475, 'Bob Esponja Calca Quadrada S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5x5ti8Y8HFNNJFOTv7SsoqRV2CD.jpg'),
(118263, 8475, 'Bob Esponja Calca Quadrada S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kjZZrT3dbOMGd3gf9rTXQBwFYeP.jpg'),
(118264, 8475, 'Bob Esponja Calca Quadrada S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qFfRq3JxogpjNOIi5zFCa6Y6AnC.jpg'),
(118265, 8475, 'Bob Esponja Calca Quadrada S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/UKn5Xk3TrR13qsbJWjGuXW9RvX.jpg'),
(118266, 8475, 'Bob Esponja Calca Quadrada S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/reSwVsAvI6qvPIzVzD8jTOh892K.jpg'),
(118267, 8475, 'Bob Esponja Calca Quadrada S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AcXp8S8j37JFBMGdohfryJu1PsG.jpg'),
(118268, 8475, 'Bob Esponja Calca Quadrada S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lj08HKMJwPcW8FvfsBNReANCt0r.jpg'),
(118269, 8475, 'Bob Esponja Calca Quadrada S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iyVZjLQuaQiBRulx3hz7SnPzwJD.jpg'),
(118270, 8475, 'Bob Esponja Calca Quadrada S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/22SX7uY43jOYuMel9N1FLtvvvmQ.jpg'),
(118271, 8475, 'Bob Esponja Calca Quadrada S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/249261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dgdYXc0DG8YP705zx556R1o5nrA.jpg'),
(118272, 8475, 'Bob Esponja Calca Quadrada S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/249262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AhEURr88ANCnMZISGJ6ewfQdDzn.jpg'),
(118273, 8475, 'Bob Esponja Calca Quadrada S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/249263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5c6J7UQ17tW5tXzEMee8hyS1MkO.jpg'),
(118274, 8475, 'Bob Esponja Calca Quadrada S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/249264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uGKoPrNWmJJkhIjWXeAO6Wuxal3.jpg'),
(118275, 8476, 'Bob Esponja Calca Quadrada S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qG7DZVqiJHH56voCBnbJti3lOmI.jpg'),
(118276, 8476, 'Bob Esponja Calca Quadrada S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118277, 8476, 'Bob Esponja Calca Quadrada S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8usQNsBGL7YQqt04iKKuBWGAnhJ.jpg'),
(118278, 8476, 'Bob Esponja Calca Quadrada S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vnVvgDdmxOgcMHtQ1khnMOmfVcV.jpg'),
(118279, 8476, 'Bob Esponja Calca Quadrada S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qkDdFBJak6BaOOSFFEG470h13kf.jpg'),
(118280, 8476, 'Bob Esponja Calca Quadrada S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odKZdANujm7rIl6Vvzx1NzSh8Hd.jpg'),
(118281, 8476, 'Bob Esponja Calca Quadrada S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i3uLRNJH5XItkoVjXSxe3rIOMDz.jpg'),
(118282, 8476, 'Bob Esponja Calca Quadrada S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mcwz91I9Ymttnd4c0D72ZBsuahS.jpg'),
(118283, 8476, 'Bob Esponja Calca Quadrada S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9zvVv8vuJP9KBYB8QqSg7vVMmAw.jpg'),
(118284, 8476, 'Bob Esponja Calca Quadrada S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i8CHM7A1qgEyvJvD9Aw7rXQlnYd.jpg'),
(118285, 8476, 'Bob Esponja Calca Quadrada S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uPooJ5BW5MGyjdPhItkoLzWLnUR.jpg'),
(118286, 8476, 'Bob Esponja Calca Quadrada S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uQwchWckhwgTiS6Gc7qdaFdA7Fc.jpg'),
(118287, 8476, 'Bob Esponja Calca Quadrada S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r5i9dFUapLsqipEkGvSGWiCBMc9.jpg'),
(118288, 8476, 'Bob Esponja Calca Quadrada S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pGa2oV7Ni3KhBldS8EexGC0mCWH.jpg'),
(118289, 8476, 'Bob Esponja Calca Quadrada S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ApOpwowWLVW90qHRBSncnTbW3oI.jpg'),
(118290, 8476, 'Bob Esponja Calca Quadrada S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8PMpd5aXiQ7XqZVfCAjpW2juhSm.jpg'),
(118291, 8476, 'Bob Esponja Calca Quadrada S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/249281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tYIiw7KHMNx7blNnGyOmNpA5rCs.jpg'),
(118292, 8476, 'Bob Esponja Calca Quadrada S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/249282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZig4ipnvz34cuIdwlTYSvdQLR4.jpg'),
(118293, 8476, 'Bob Esponja Calca Quadrada S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/249283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4GBHezc2oYQF5EH7t9UNGto9K4w.jpg'),
(118294, 8476, 'Bob Esponja Calca Quadrada S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/249284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hgvPKA2YTd9awamht39avlWmVYi.jpg'),
(118295, 8477, 'Bob Esponja Calca Quadrada S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o8FFLsFjEOMKTLh3KMWUTyjtqwi.jpg'),
(118296, 8477, 'Bob Esponja Calca Quadrada S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9iL9f75oKaPoiKibHF9ISw0JwIA.jpg'),
(118297, 8477, 'Bob Esponja Calca Quadrada S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aYzxMg8IyXlsMK2DRk5gm5ICg8s.jpg'),
(118298, 8477, 'Bob Esponja Calca Quadrada S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7TuJ23Q6ksqyz2RFoBUXR81kMzJ.jpg'),
(118299, 8477, 'Bob Esponja Calca Quadrada S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gEQtTdVF3G5Zu3RLGGkL45ApfMe.jpg'),
(118300, 8477, 'Bob Esponja Calca Quadrada S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lgsmJzUdJGAcifjN1PxhEUJp2J6.jpg'),
(118301, 8477, 'Bob Esponja Calca Quadrada S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w60PPexCNOtvpkJCLQuspDKQayt.jpg'),
(118302, 8477, 'Bob Esponja Calca Quadrada S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o70VjmF3REIhxoXaeufWeUSp3AI.jpg'),
(118303, 8477, 'Bob Esponja Calca Quadrada S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oZjBkPd2SJvoHCma3FEsDKvieGz.jpg'),
(118304, 8477, 'Bob Esponja Calca Quadrada S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3czNyXIP3ZWDR1QuDP2M3BtZRyx.jpg'),
(118305, 8477, 'Bob Esponja Calca Quadrada S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sysdTxiuWQWQaljmleKiqGSeOQ4.jpg'),
(118306, 8477, 'Bob Esponja Calca Quadrada S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3eGRKm2DbVu3YH0Owtz7QwZbaOG.jpg'),
(118307, 8477, 'Bob Esponja Calca Quadrada S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCNpLy9DovxiaymH0fpNpvFfSqJ.jpg'),
(118308, 8477, 'Bob Esponja Calca Quadrada S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j7eD1EQJWfP8B6vXEJuPQpNRkM8.jpg'),
(118309, 8477, 'Bob Esponja Calca Quadrada S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dVkyWOVvDjKMauYmiqfJLhFdWJJ.jpg'),
(118310, 8477, 'Bob Esponja Calca Quadrada S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2tec4eA5GUKuSEtxapWuDULy473.jpg'),
(118311, 8477, 'Bob Esponja Calca Quadrada S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/249301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eyffVymiPd84vj1d4xaHt80HUuv.jpg'),
(118312, 8477, 'Bob Esponja Calca Quadrada S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/249302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c0cEPTr17hTZf2OLj3KUXkKfcv9.jpg'),
(118313, 8477, 'Bob Esponja Calca Quadrada S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/249303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfkHhm9nEi20pJcswnQ4kTaBgNZ.jpg'),
(118314, 8477, 'Bob Esponja Calca Quadrada S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/249304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3emSNeOEnC8yk6ZIIzuiKfhn8bI.jpg'),
(118315, 8478, 'Bob Esponja Calca Quadrada S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qxl9MmcCPT9SrjS59fHOWGZK7Ef.jpg'),
(118316, 8478, 'Bob Esponja Calca Quadrada S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uIPvPpMEwYzykeHai2UXL9CkOQD.jpg'),
(118317, 8478, 'Bob Esponja Calca Quadrada S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1TbzeNVKmSh4xbwDY45GHcBWp4z.jpg'),
(118318, 8478, 'Bob Esponja Calca Quadrada S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzMobfDntGP7DVUxz7eTxSLn3EL.jpg'),
(118319, 8478, 'Bob Esponja Calca Quadrada S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aeSx7hyFqQTZKi4QHeE9SbGBpgS.jpg'),
(118320, 8478, 'Bob Esponja Calca Quadrada S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqiD43VLYiGUG6hXjX0cAhohJJa.jpg'),
(118321, 8478, 'Bob Esponja Calca Quadrada S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ai9b1FbYIRI5A8TFaVCfMRl0Q8B.jpg'),
(118322, 8478, 'Bob Esponja Calca Quadrada S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iGCvBFcLPx4lAh89EanZWFcHsCB.jpg'),
(118323, 8478, 'Bob Esponja Calca Quadrada S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/htDWga5Ypiiegq58loDokZm58oH.jpg'),
(118324, 8478, 'Bob Esponja Calca Quadrada S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x35xSvDSGjQUyc4Fo2jmlG1hxOk.jpg'),
(118325, 8478, 'Bob Esponja Calca Quadrada S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zaD5If8GkJw0JSe2iAunCkWZdZo.jpg'),
(118326, 8478, 'Bob Esponja Calca Quadrada S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h5OGArxJ2gaVS06xJdichTb0UUy.jpg'),
(118327, 8478, 'Bob Esponja Calca Quadrada S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7eYsK165TBLcdRD6VDeVWh5U14e.jpg'),
(118328, 8478, 'Bob Esponja Calca Quadrada S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ByNZftDDtC7TNs7Fisdb0zMEDM.jpg'),
(118329, 8478, 'Bob Esponja Calca Quadrada S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vgsgz27ZWmgnzTmAD9syEHZOgrb.jpg'),
(118330, 8478, 'Bob Esponja Calca Quadrada S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tCxJv7QFeCtFMdSy5DaSYSRz66h.jpg'),
(118331, 8478, 'Bob Esponja Calca Quadrada S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/249321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQbCxAlP3N5qZCcupoLxysFCAnm.jpg'),
(118332, 8478, 'Bob Esponja Calca Quadrada S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/249322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c54suWMeh7Kx6RKMlTPFfJCJNfs.jpg'),
(118333, 8478, 'Bob Esponja Calca Quadrada S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/249323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9AheEhTCUXC5IQ1Fby30r0yxbms.jpg'),
(118334, 8478, 'Bob Esponja Calca Quadrada S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/249324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7XCcfW9QrfflPMYnmaXEz7fcrwo.jpg'),
(118335, 8479, 'Bob Esponja Calca Quadrada S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sw2RXViBER9zp76mUGPmPbnsSlP.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(118336, 8479, 'Bob Esponja Calca Quadrada S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZ8zNsWuLDtwchQg3RKiy7UGkLD.jpg'),
(118337, 8479, 'Bob Esponja Calca Quadrada S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eitqNRDMMj7n2BNCWbKN0pyobU7.jpg'),
(118338, 8479, 'Bob Esponja Calca Quadrada S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/As3i9X5duBCrb2Ihmnhui0sazv9.jpg'),
(118339, 8479, 'Bob Esponja Calca Quadrada S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ilNHTGhW4pSZ4RITtsUj0p0wOHF.jpg'),
(118340, 8479, 'Bob Esponja Calca Quadrada S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eSnIP7FpWmHeXta4b8bCKEyvnSm.jpg'),
(118341, 8479, 'Bob Esponja Calca Quadrada S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sxL6nsJUn583zloOnjNlsC24XeW.jpg'),
(118342, 8479, 'Bob Esponja Calca Quadrada S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3EPI9zFdD80UKvDZjfgwcG15sbW.jpg'),
(118343, 8479, 'Bob Esponja Calca Quadrada S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1JMnZ6WgUsFfOu8JEqgiY3nayKW.jpg'),
(118344, 8479, 'Bob Esponja Calca Quadrada S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Qy5hE8OHaRSbVgKLukP1DwzJGc.jpg'),
(118345, 8479, 'Bob Esponja Calca Quadrada S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3GqRQjyKHh5obHmuWHQDjN3Oe8D.jpg'),
(118346, 8479, 'Bob Esponja Calca Quadrada S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/waQjzduIEUFwtHvjLgeINkeVywP.jpg'),
(118347, 8479, 'Bob Esponja Calca Quadrada S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nstZepyvVXF6zrCOI5ESgSbRa2B.jpg'),
(118348, 8479, 'Bob Esponja Calca Quadrada S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3mykWclG3AK3KK30mvXB3kJrdir.jpg'),
(118349, 8479, 'Bob Esponja Calca Quadrada S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1fvG19zbzSAuzyW0TB3fU0AfcrL.jpg'),
(118350, 8479, 'Bob Esponja Calca Quadrada S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c21S3bH1lEDu2x2dhCwB9cbXlra.jpg'),
(118351, 8479, 'Bob Esponja Calca Quadrada S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/249341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eWZ7LwpIu0gY4mMys2psAlLx7w0.jpg'),
(118352, 8479, 'Bob Esponja Calca Quadrada S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/249342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/viuEuKIeRsSWxjxPexoKF1PV0WS.jpg'),
(118353, 8479, 'Bob Esponja Calca Quadrada S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/249343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hAqr1mlfwSpm6feO5HOnQlFFrvY.jpg'),
(118354, 8479, 'Bob Esponja Calca Quadrada S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/249344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2kf5vlIUTYjTgFFWMQCIjRUYVsv.jpg'),
(118355, 8479, 'Bob Esponja Calca Quadrada S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/249345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lR8WSLDC9iSa5TQoQQDZXyZLEp0.jpg'),
(118356, 8479, 'Bob Esponja Calca Quadrada S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/249346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZtSRhqwFYzEKYpG5OUVUQQdGZE.jpg'),
(118357, 8479, 'Bob Esponja Calca Quadrada S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/249347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4kDS4GpqdTng19PjTaXkgkXwLm3.jpg'),
(118358, 8479, 'Bob Esponja Calca Quadrada S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/249348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4OeUwoIzUWy2aJfiwBOMrNFbhTr.jpg'),
(118359, 8479, 'Bob Esponja Calca Quadrada S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/249349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lDm8xX8fU496dphqMuUz33ylzp1.jpg'),
(118360, 8479, 'Bob Esponja Calca Quadrada S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/249350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p9SOlbTBBDKngMZq70CxvQYiPbs.jpg'),
(118361, 8480, 'Bob Esponja Calca Quadrada S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ghqvMOat8LNYgbZpxQaRnFJ94Mz.jpg'),
(118362, 8480, 'Bob Esponja Calca Quadrada S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pE51gZDaO0KfEgNytjj9aoZ7rDc.jpg'),
(118363, 8480, 'Bob Esponja Calca Quadrada S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rFQBgJx8avTSiF5y9GgGRVVzYkB.jpg'),
(118364, 8480, 'Bob Esponja Calca Quadrada S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rM3lrXd2LN44DhMHhj6UKS5ZhHW.jpg'),
(118365, 8480, 'Bob Esponja Calca Quadrada S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/21IEqrUCTxM8LKXcXjZEWz4sS2u.jpg'),
(118366, 8480, 'Bob Esponja Calca Quadrada S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7R8XsHMYGmBP0oQiyF9IFRMSUyd.jpg'),
(118367, 8480, 'Bob Esponja Calca Quadrada S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u2NYinrmJigIWUo8dnuc04mgEP6.jpg'),
(118368, 8480, 'Bob Esponja Calca Quadrada S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vpaa5lV7igPzNlV9yfhzaTIkE0z.jpg'),
(118369, 8480, 'Bob Esponja Calca Quadrada S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bXXZWmNIvrgjlQIKyR1ZMJXlnNA.jpg'),
(118370, 8480, 'Bob Esponja Calca Quadrada S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4BorH8Y7rKd2QIR6kiJ2FTGAQSU.jpg'),
(118371, 8480, 'Bob Esponja Calca Quadrada S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ppvffkDMdXu24qUkwHDOErAU4qx.jpg'),
(118372, 8480, 'Bob Esponja Calca Quadrada S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nXgDfTTfQfPawAqGIOxs5dVOMc.jpg'),
(118373, 8480, 'Bob Esponja Calca Quadrada S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ujOZG8iAqqvwKfGdv8UEKulOjfZ.jpg'),
(118374, 8480, 'Bob Esponja Calca Quadrada S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rz9zbjgqHYwRbB9eq2pwyDPvnsa.jpg'),
(118375, 8480, 'Bob Esponja Calca Quadrada S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7iJbkxcVldfJRE8j93JIhZ7j9Kp.jpg'),
(118376, 8480, 'Bob Esponja Calca Quadrada S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vnx9pJgBj5dD3gLneZ3OXbDMf71.jpg'),
(118377, 8480, 'Bob Esponja Calca Quadrada S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/249367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOLc4BQvsCDd0pxycM8ShpDPjBh.jpg'),
(118378, 8480, 'Bob Esponja Calca Quadrada S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/249368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ow9v5jhv6p7wSWARGO5p3tDsIa.jpg'),
(118379, 8480, 'Bob Esponja Calca Quadrada S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/249369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7DzzhXfObBgV7EdahwHNff7Px7U.jpg'),
(118380, 8480, 'Bob Esponja Calca Quadrada S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/249370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/usk6zMciKl9e9UV7HYjNadIKSrd.jpg'),
(118381, 8480, 'Bob Esponja Calca Quadrada S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/249371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kuui9ovJsub929jo6JSUzKbnkaJ.jpg'),
(118382, 8480, 'Bob Esponja Calca Quadrada S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/249372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e0bNR7Iaxyde6MJCrmzNI4FOPel.jpg'),
(118383, 8480, 'Bob Esponja Calca Quadrada S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/249373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v426PeejCOBLeOdreBX0lT4t1hC.jpg'),
(118384, 8480, 'Bob Esponja Calca Quadrada S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/249374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q3Z9lEgJAAw4EKf2Dzmu48WFIr1.jpg'),
(118385, 8480, 'Bob Esponja Calca Quadrada S08 E25', 'http://sinalprivado.info:80/series/1533784/1533784/249375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Xh2rCthCoAnQY25SbzCqgfjm1i.jpg'),
(118386, 8481, 'Bob Esponja Calca Quadrada S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6nNPURkDiuc2IQNSSdiaJomP9RR.jpg'),
(118387, 8481, 'Bob Esponja Calca Quadrada S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bAlpPsSHknxakFEwu5xuczYgrIU.jpg'),
(118388, 8481, 'Bob Esponja Calca Quadrada S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ggNH5cRARVGfNbKDeoHBNPGv10Q.jpg'),
(118389, 8481, 'Bob Esponja Calca Quadrada S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/paN8SyZ2OkisoUsbQlVHkvkdrJy.jpg'),
(118390, 8481, 'Bob Esponja Calca Quadrada S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gP9y4HYZvnwZca2nmiecjFcn8Pc.jpg'),
(118391, 8481, 'Bob Esponja Calca Quadrada S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eEZRyC003OICzjRjQ9jBM2leYTM.jpg'),
(118392, 8481, 'Bob Esponja Calca Quadrada S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1usoiURVwjuGbndXm1wUOVfXXjn.jpg'),
(118393, 8481, 'Bob Esponja Calca Quadrada S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3k9E8doAYRQ1DWsE0JeUUpQnaF8.jpg'),
(118394, 8481, 'Bob Esponja Calca Quadrada S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rPalA1JukkbVdlsMvxte2n8YwD3.jpg'),
(118395, 8481, 'Bob Esponja Calca Quadrada S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3NwAYYZCM6XgItSYO9vywFKvSl3.jpg'),
(118396, 8481, 'Bob Esponja Calca Quadrada S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4EOpSffQsqWj5VFziikb5fIFi5U.jpg'),
(118397, 8481, 'Bob Esponja Calca Quadrada S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJ2NEVtEqMkJ74r5t0oG7APWxxf.jpg'),
(118398, 8481, 'Bob Esponja Calca Quadrada S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/afvhDzkk0QlqgGDRBB1VDdCSKy6.jpg'),
(118399, 8481, 'Bob Esponja Calca Quadrada S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQNAe3HyEmciqzH5fQpUPKScg9a.jpg'),
(118400, 8481, 'Bob Esponja Calca Quadrada S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fuCExrtbINhSKdZJEeeOZmuNQ4c.jpg'),
(118401, 8481, 'Bob Esponja Calca Quadrada S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ex6kM1k2en339V2guoGhKLRTZw.jpg'),
(118402, 8481, 'Bob Esponja Calca Quadrada S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/249392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bdLZyA67KtjOxsAIS1FS30WvN1h.jpg'),
(118403, 8481, 'Bob Esponja Calca Quadrada S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/249393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rQ2g4apdVwX3K4sK9cC8uW30MNl.jpg'),
(118404, 8481, 'Bob Esponja Calca Quadrada S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/249394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f8dIRx4ZaY3QDsBI5GU9dhCzvpP.jpg'),
(118405, 8481, 'Bob Esponja Calca Quadrada S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/249395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5lRqLbhFzR92AEcT4geJf0rYzkX.jpg'),
(118406, 8481, 'Bob Esponja Calca Quadrada S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/249396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7cbKc5uIYagtJM3Rc6o7yJ9JpeJ.jpg'),
(118407, 8481, 'Bob Esponja Calca Quadrada S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/249397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iu7aWqb6AoTH52cPVwVFSs4AW6r.jpg'),
(118408, 8481, 'Bob Esponja Calca Quadrada S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/249398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qPANmRaSsPcFHJK5ZmIb46z9f1L.jpg'),
(118409, 8481, 'Bob Esponja Calca Quadrada S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/249399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3pmdlELYiZPoTsNFaQtCigLyaP6.jpg'),
(118410, 8481, 'Bob Esponja Calca Quadrada S09 E25', 'http://sinalprivado.info:80/series/1533784/1533784/249400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/CLsXzBHWCLMCc9lOijuPtCFYZ9.jpg'),
(118411, 8481, 'Bob Esponja Calca Quadrada S09 E26', 'http://sinalprivado.info:80/series/1533784/1533784/249401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dYOPpQSbhZdz2P3la27KQRMIaPz.jpg'),
(118412, 8482, 'Bob Esponja Calca Quadrada S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w4nWDiREervh3aD1LCr94yQk4tQ.jpg'),
(118413, 8482, 'Bob Esponja Calca Quadrada S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fZ886mCjnv9vi9IM0l7iFLDzYd1.jpg'),
(118414, 8482, 'Bob Esponja Calca Quadrada S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6k7MVgCSZvNm8spjSIEI4C6GuYC.jpg'),
(118415, 8482, 'Bob Esponja Calca Quadrada S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/72e3qn1yaBWxsu3Sp7GAuRic2rj.jpg'),
(118416, 8482, 'Bob Esponja Calca Quadrada S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yuOxtIm4xuXOLOejK5Q3JnfRr5l.jpg'),
(118417, 8482, 'Bob Esponja Calca Quadrada S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJkM0PeQ99YgNEF4aYbmGFaehHD.jpg'),
(118418, 8482, 'Bob Esponja Calca Quadrada S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7F1AKZ10Jtl7Xjx51bWiX0tUxRD.jpg'),
(118419, 8482, 'Bob Esponja Calca Quadrada S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4fwhPRr76jlbJOYl7L2nhWirUDN.jpg'),
(118420, 8482, 'Bob Esponja Calca Quadrada S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/miDPagBymh2FOAC5XYa5TCNoYY1.jpg'),
(118421, 8482, 'Bob Esponja Calca Quadrada S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p0ccZm6HZzDGiyFBkQB4GTXG6Ua.jpg'),
(118422, 8482, 'Bob Esponja Calca Quadrada S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AwlqRVk3tlqxk3iY00bkWeJBPnf.jpg'),
(118423, 8483, 'Bob Esponja Calca Quadrada S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iqXlaEUPcpXkEcdaPpcNEcAGEqp.jpg'),
(118424, 8483, 'Bob Esponja Calca Quadrada S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1NiO4o3iJmtoT5RJU1TKVQ6S9Og.jpg'),
(118425, 8483, 'Bob Esponja Calca Quadrada S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jVw8xuw5xeuW2f101Nr2WPnAbRg.jpg'),
(118426, 8483, 'Bob Esponja Calca Quadrada S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ylYjCFeB8OWnV7w8qcg1T8JxFIz.jpg'),
(118427, 8483, 'Bob Esponja Calca Quadrada S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQJOLRHPa1KUFTSsySr1hJPPVAO.jpg'),
(118428, 8483, 'Bob Esponja Calca Quadrada S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ds7IehgAvqRUBbqmJN91GmUQlgp.jpg'),
(118429, 8483, 'Bob Esponja Calca Quadrada S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2sQ1WQQBL14zIKk3WDA83IHsB3F.jpg'),
(118430, 8483, 'Bob Esponja Calca Quadrada S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lESQt0ZbXHkR7AR92ba0nblyJlj.jpg'),
(118431, 8483, 'Bob Esponja Calca Quadrada S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d4kWzguA1OyczBbrUvkPp9U3F2p.jpg'),
(118432, 8483, 'Bob Esponja Calca Quadrada S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7SQgtIET7OFBWtUHVET4b32eul8.jpg'),
(118433, 8483, 'Bob Esponja Calca Quadrada S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xxddMSnsHKusIJZNO27Yv9698vZ.jpg'),
(118434, 8483, 'Bob Esponja Calca Quadrada S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUcgtfZ2dMMTVsXZU9RaXYCtNPC.jpg'),
(118435, 8483, 'Bob Esponja Calca Quadrada S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yjfF4REmRj00i3GYrYKTy4CQ5sF.jpg'),
(118436, 8483, 'Bob Esponja Calca Quadrada S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/itjYFj6EBP55pdaGzv7yJzWfZyU.jpg'),
(118437, 8483, 'Bob Esponja Calca Quadrada S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1VVY7ms3dXc2QliH393FG1oU05J.jpg'),
(118438, 8483, 'Bob Esponja Calca Quadrada S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o1RTqhsuP8QEr8WMVNj20iJ1uhj.jpg'),
(118439, 8483, 'Bob Esponja Calca Quadrada S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/249429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dSsWCPLXAMWRVB1xOdQww9JoulI.jpg'),
(118440, 8483, 'Bob Esponja Calca Quadrada S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/249430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/37wGD7WFV4Pad1ObfAuVzU04u7v.jpg'),
(118441, 8483, 'Bob Esponja Calca Quadrada S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/249431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8BMCsVIOCF6haXft1p6FGWMVir.jpg'),
(118442, 8483, 'Bob Esponja Calca Quadrada S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/249432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qst4qgdXEWR6bFeqYfd5qmFA3Sq.jpg'),
(118443, 8483, 'Bob Esponja Calca Quadrada S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/249433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2lYtCQKIH7g2ABDPy6CUzkhzFKr.jpg'),
(118444, 8483, 'Bob Esponja Calca Quadrada S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/249434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i9x6QV5PbmMyqwLBMCopflDv93.jpg'),
(118445, 8483, 'Bob Esponja Calca Quadrada S11 E23', 'http://sinalprivado.info:80/series/1533784/1533784/249435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mTw0DYzrw0vByj2DKiUsVhl6Qiz.jpg'),
(118446, 8483, 'Bob Esponja Calca Quadrada S11 E24', 'http://sinalprivado.info:80/series/1533784/1533784/249436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FVNEuiewgv6YdRicMcnDCON4br.jpg'),
(118447, 8483, 'Bob Esponja Calca Quadrada S11 E25', 'http://sinalprivado.info:80/series/1533784/1533784/249437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xUpfKhUqV4cJzTAYtAI5qcV8XQg.jpg'),
(118448, 8483, 'Bob Esponja Calca Quadrada S11 E26', 'http://sinalprivado.info:80/series/1533784/1533784/249438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wRKMRK07dUpyWAYtUeZhHWKbH2R.jpg'),
(118449, 8484, 'Bob Esponja Calca Quadrada S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t9eYVqWTou3aFVT7qiWsXzdQ6Nq.jpg'),
(118450, 8484, 'Bob Esponja Calca Quadrada S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nnmVCbWY2wAbbUlXdqpfhNf5wrl.jpg'),
(118451, 8484, 'Bob Esponja Calca Quadrada S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h4WgaDD1fLDFkOqtmkmGCTKpwLX.jpg'),
(118452, 8484, 'Bob Esponja Calca Quadrada S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfmGMBnSeX6LxsWyDPuZFaeWlSm.jpg'),
(118453, 8484, 'Bob Esponja Calca Quadrada S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ur0GjafTqSJWmonKz5jDRBITQD.jpg'),
(118454, 8484, 'Bob Esponja Calca Quadrada S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/56Gag6TiqNVhACGxximM9xkpfin.jpg'),
(118455, 8484, 'Bob Esponja Calca Quadrada S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/88roxXyUJZly3G5DeprIVnnkpRh.jpg'),
(118456, 8484, 'Bob Esponja Calca Quadrada S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hwasg9zSDedDp6I8T4n8YjbOeVL.jpg'),
(118457, 8484, 'Bob Esponja Calca Quadrada S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/38bCqiSSsquJfqfDDbVHkAHZaQ6.jpg'),
(118458, 8484, 'Bob Esponja Calca Quadrada S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bhUAcClXhIWKPwupTyoPCGBWfiS.jpg'),
(118459, 8484, 'Bob Esponja Calca Quadrada S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gceI5pLIH1Jvn9BblERB5aGvQsI.jpg'),
(118460, 8484, 'Bob Esponja Calca Quadrada S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/22m1cA2vkfXNj4OSI4F9z7ml84e.jpg'),
(118461, 8484, 'Bob Esponja Calca Quadrada S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3NL3gJeowFoC67Mk8SPffxr7zRF.jpg'),
(118462, 8484, 'Bob Esponja Calca Quadrada S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glsVRL1uRdthJmeIuowvnCLZxJS.jpg'),
(118463, 8484, 'Bob Esponja Calca Quadrada S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dSnuFkPE7AtiXB4y77LJgyokMut.jpg'),
(118464, 8484, 'Bob Esponja Calca Quadrada S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3GbTZlXG2A725WONMpcmo1ogxmH.jpg'),
(118465, 8484, 'Bob Esponja Calca Quadrada S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/249455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iducoNGnBmaRGs7Upbz99EkAUz1.jpg'),
(118466, 8484, 'Bob Esponja Calca Quadrada S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/249456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fjD3EAJAAvw4PL3gNRC4EdeWGAv.jpg'),
(118467, 8484, 'Bob Esponja Calca Quadrada S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/249457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lE46HSagV7PCSGHBBRGOyT7fTzX.jpg'),
(118468, 8484, 'Bob Esponja Calca Quadrada S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/249458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sbKmsxSPwLsNWcXQpLBDrwaaw0f.jpg'),
(118469, 8484, 'Bob Esponja Calca Quadrada S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/249459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q4tmOLvBBNAapjgvw6dGvWLZWyU.jpg'),
(118470, 8484, 'Bob Esponja Calca Quadrada S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/249460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/di6mQz0G9ZOxltlDUo9duaBbLbC.jpg'),
(118471, 8484, 'Bob Esponja Calca Quadrada S12 E23', 'http://sinalprivado.info:80/series/1533784/1533784/249461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4UqlwA7nTy3uIkEcNLhjNqWZuZE.jpg'),
(118472, 8484, 'Bob Esponja Calca Quadrada S12 E24', 'http://sinalprivado.info:80/series/1533784/1533784/249462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w7YsMlwuDOSF83fVS8s39E2LioS.jpg'),
(118473, 8484, 'Bob Esponja Calca Quadrada S12 E25', 'http://sinalprivado.info:80/series/1533784/1533784/249463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zysCp6YSA6pFqesdqnG9cRrRrxL.jpg'),
(118474, 8484, 'Bob Esponja Calca Quadrada S12 E26', 'http://sinalprivado.info:80/series/1533784/1533784/249464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uOu27hA5HNUbWGq4qFgbr8dSHE7.jpg'),
(118475, 8485, 'Bob Esponja Calca Quadrada S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pCJ92CLIalrkyXd4HaM0kBBlV9l.jpg'),
(118476, 8485, 'Bob Esponja Calca Quadrada S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e2dgNaPOjqlBNjjrhVI3tvi25NM.jpg'),
(118477, 8485, 'Bob Esponja Calca Quadrada S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pXf9vHmfYzCb2xZcuS3vdkhQGto.jpg'),
(118478, 8485, 'Bob Esponja Calca Quadrada S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nQpqz4UZ6WamIKUSt6YurQ79oTK.jpg'),
(118479, 8485, 'Bob Esponja Calca Quadrada S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xnsDNTkPd4y6eXqXr4LN5aN93WH.jpg'),
(118480, 8485, 'Bob Esponja Calca Quadrada S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eEiod7L3Q8GNbzAHkImEn69dxkR.jpg'),
(118481, 8485, 'Bob Esponja Calca Quadrada S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t5fawjaVCewg5419l70cVSb5Xhu.jpg'),
(118482, 8485, 'Bob Esponja Calca Quadrada S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCQEjIlfvcZS6ECKNVjNhxqBwJC.jpg'),
(118483, 8485, 'Bob Esponja Calca Quadrada S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118484, 8485, 'Bob Esponja Calca Quadrada S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118485, 8485, 'Bob Esponja Calca Quadrada S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118486, 8485, 'Bob Esponja Calca Quadrada S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118487, 8485, 'Bob Esponja Calca Quadrada S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118488, 8485, 'Bob Esponja Calca Quadrada S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118489, 8485, 'Bob Esponja Calca Quadrada S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118490, 8485, 'Bob Esponja Calca Quadrada S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118491, 8485, 'Bob Esponja Calca Quadrada S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/249481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118492, 8485, 'Bob Esponja Calca Quadrada S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/249482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118493, 8485, 'Bob Esponja Calca Quadrada S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/249483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118494, 8485, 'Bob Esponja Calca Quadrada S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/249484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118495, 8485, 'Bob Esponja Calca Quadrada S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/249485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118496, 8485, 'Bob Esponja Calca Quadrada S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/249486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118497, 8486, 'Bob Esponja Calca Quadrada S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/806767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118498, 8486, 'Bob Esponja Calca Quadrada S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/806768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118499, 8486, 'Bob Esponja Calca Quadrada S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/806769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118500, 8486, 'Bob Esponja Calca Quadrada S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/806770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118501, 8486, 'Bob Esponja Calca Quadrada S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/806771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118502, 8486, 'Bob Esponja Calca Quadrada S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/806772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118503, 8486, 'Bob Esponja Calca Quadrada S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/806773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118504, 8486, 'Bob Esponja Calca Quadrada S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/806774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118505, 8486, 'Bob Esponja Calca Quadrada S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/806775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118506, 8486, 'Bob Esponja Calca Quadrada S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/806776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118507, 8486, 'Bob Esponja Calca Quadrada S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/806777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118508, 8486, 'Bob Esponja Calca Quadrada S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/806778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118509, 8487, 'Bob Esponja Calca Quadrada S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/806779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118510, 8487, 'Bob Esponja Calca Quadrada S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/806780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118511, 8487, 'Bob Esponja Calca Quadrada S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/806781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118512, 8487, 'Bob Esponja Calca Quadrada S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/806782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118513, 8487, 'Bob Esponja Calca Quadrada S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/806783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118514, 8487, 'Bob Esponja Calca Quadrada S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/806784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118515, 8487, 'Bob Esponja Calca Quadrada S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/806785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118516, 8487, 'Bob Esponja Calca Quadrada S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/880599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118517, 8487, 'Bob Esponja Calca Quadrada S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/880600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118518, 8487, 'Bob Esponja Calca Quadrada S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/880601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118519, 8487, 'Bob Esponja Calca Quadrada S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/880602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jVJY3tD4t5udjYDL9F3qe4mjh5.jpg'),
(118520, 8488, 'O Show do Patrick Estrela S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uIrAG7khqXpcQ4Ggfg14Wvbl07I.jpg'),
(118521, 8488, 'O Show do Patrick Estrela S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9lsK3iw98PSqJKuk2X4nqCFKf6A.jpg'),
(118522, 8488, 'O Show do Patrick Estrela S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xo6pftgTdUkxFWznOeLMAxq7FV0.jpg'),
(118523, 8488, 'O Show do Patrick Estrela S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tnkWipMbAb7Ylj1ojxqvV8YZPjB.jpg'),
(118524, 8488, 'O Show do Patrick Estrela S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u5SjcELuYs3TCuEa6Qzx45NFmo5.jpg'),
(118525, 8488, 'O Show do Patrick Estrela S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zGjFpz4UdbZnLnT9vVFk2qvmEFg.jpg'),
(118526, 8488, 'O Show do Patrick Estrela S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pzemCxb7chE2c1b7sYwpMZDow7L.jpg'),
(118527, 8488, 'O Show do Patrick Estrela S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hkmoXAjHO5VBQnD6OVLouuusqzX.jpg'),
(118528, 8488, 'O Show do Patrick Estrela S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVqY6OKh3dC7B1JntDUcpDgI54I.jpg'),
(118529, 8488, 'O Show do Patrick Estrela S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3uw3MkkPZ8tn8SEn7QCenur8XyF.jpg'),
(118530, 8488, 'O Show do Patrick Estrela S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/238861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zYeyT778dotiNa3DnIQsz9sRBvC.jpg'),
(118531, 8488, 'O Show do Patrick Estrela S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/238862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dyY2RbS4Hrwlz9l271ftvVoEWVH.jpg'),
(118532, 8488, 'O Show do Patrick Estrela S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/238863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u1Em6WchHWMj8yeVZx1v3sdvh2l.jpg'),
(118533, 8488, 'O Show do Patrick Estrela S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/238864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118534, 8488, 'O Show do Patrick Estrela S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/238865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118535, 8488, 'O Show do Patrick Estrela S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/238866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118536, 8488, 'O Show do Patrick Estrela S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/238867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118537, 8488, 'O Show do Patrick Estrela S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/238868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118538, 8488, 'O Show do Patrick Estrela S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/238869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118539, 8488, 'O Show do Patrick Estrela S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/238870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118540, 8488, 'O Show do Patrick Estrela S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/805823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118541, 8488, 'O Show do Patrick Estrela S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/805824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118542, 8488, 'O Show do Patrick Estrela S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/805825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118543, 8488, 'O Show do Patrick Estrela S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/805826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118544, 8488, 'O Show do Patrick Estrela S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/805827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118545, 8488, 'O Show do Patrick Estrela S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/805828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118546, 8489, 'O Show do Patrick Estrela S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/836563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118547, 8489, 'O Show do Patrick Estrela S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/836564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118548, 8489, 'O Show do Patrick Estrela S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/836565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118549, 8489, 'O Show do Patrick Estrela S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/836566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118550, 8489, 'O Show do Patrick Estrela S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/836567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118551, 8489, 'O Show do Patrick Estrela S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/836568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118552, 8489, 'O Show do Patrick Estrela S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/836569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118553, 8489, 'O Show do Patrick Estrela S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/836570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118554, 8489, 'O Show do Patrick Estrela S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/836571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118555, 8489, 'O Show do Patrick Estrela S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/836572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118556, 8489, 'O Show do Patrick Estrela S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/836573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118557, 8489, 'O Show do Patrick Estrela S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/836574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118558, 8489, 'O Show do Patrick Estrela S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/836575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118559, 8490, 'O Show do Patrick Estrela S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/880568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118560, 8490, 'O Show do Patrick Estrela S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/880569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118561, 8490, 'O Show do Patrick Estrela S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/880570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118562, 8490, 'O Show do Patrick Estrela S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/880571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118563, 8490, 'O Show do Patrick Estrela S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/880572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118564, 8490, 'O Show do Patrick Estrela S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/880573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118565, 8490, 'O Show do Patrick Estrela S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/880574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118566, 8490, 'O Show do Patrick Estrela S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/880575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118567, 8490, 'O Show do Patrick Estrela S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/880576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118568, 8490, 'O Show do Patrick Estrela S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/880577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118569, 8490, 'O Show do Patrick Estrela S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/891024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118570, 8491, 'O Show do Patrick Estrela S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/891025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118571, 8491, 'O Show do Patrick Estrela S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/891026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118572, 8491, 'O Show do Patrick Estrela S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/891027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118573, 8491, 'O Show do Patrick Estrela S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/891028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118574, 8491, 'O Show do Patrick Estrela S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/891029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zXwvdw2n3TshH5Yd1lTi2ABGkNp.jpg'),
(118575, 8492, 'Os Pinguins de Madagascar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/axuCCtQOANHQdC4TQWQQnpTCSVn.jpg'),
(118576, 8492, 'Os Pinguins de Madagascar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1YsbPphmcfCugPwddOKWnXQErJW.jpg'),
(118577, 8492, 'Os Pinguins de Madagascar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lxsbACVgghj8EcWIgXIHXnDANJU.jpg'),
(118578, 8492, 'Os Pinguins de Madagascar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/njXnTEO6es6TVcgiw0doJrYFtt6.jpg'),
(118579, 8492, 'Os Pinguins de Madagascar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a25O56My9uF4jIzajs4IGqNu8o8.jpg'),
(118580, 8492, 'Os Pinguins de Madagascar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/68YNSdtmvl8hj2qYjRfbfkqaOLp.jpg'),
(118581, 8492, 'Os Pinguins de Madagascar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Qy5DeEXXEMDSgl20rMnXACdlwv.jpg'),
(118582, 8492, 'Os Pinguins de Madagascar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mhTHeTZDaUpKBVKKIEiVfdMFzkJ.jpg'),
(118583, 8492, 'Os Pinguins de Madagascar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2VPvs0kbpTQLGJ6lk4FKzyv1XWE.jpg'),
(118584, 8492, 'Os Pinguins de Madagascar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ln5F2NmGq0qyZz41NjiJlKNOyDe.jpg'),
(118585, 8492, 'Os Pinguins de Madagascar S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ks4CZHVt026xfUEdbOEKiW9T2QK.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(118586, 8492, 'Os Pinguins de Madagascar S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ak9oEa0kQwAzBDR5zJWqunTttyC.jpg'),
(118587, 8492, 'Os Pinguins de Madagascar S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jhnFDavGKeI1DEc4vzjeZ1iywWZ.jpg'),
(118588, 8492, 'Os Pinguins de Madagascar S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A9kDqscrIETx1tzyI3x9Dk1UKBe.jpg'),
(118589, 8492, 'Os Pinguins de Madagascar S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8eciVi41Ypn4uldqVdEtX6tBmwc.jpg'),
(118590, 8492, 'Os Pinguins de Madagascar S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/237574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tcNtNGoCwzBI94ywnVdUzXXEhxG.jpg'),
(118591, 8492, 'Os Pinguins de Madagascar S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/237575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1PEW7YAJzaH2BPboo5Y3vv6HR2J.jpg'),
(118592, 8492, 'Os Pinguins de Madagascar S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/237576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lcRF1MwHhXC7vvbLPPNe0Z9PpS1.jpg'),
(118593, 8492, 'Os Pinguins de Madagascar S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/237577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hedku7O71AyczYwmKDRDZOXEW3O.jpg'),
(118594, 8492, 'Os Pinguins de Madagascar S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/237578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8dU82XFfQgsR8poM643OmOV5EMG.jpg'),
(118595, 8492, 'Os Pinguins de Madagascar S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/237579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dwJzDbWrwX3Bz6WNOwi6nw9yVrc.jpg'),
(118596, 8492, 'Os Pinguins de Madagascar S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/237580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g6xR3dEPiD6armWTvmPj2ftu0zu.jpg'),
(118597, 8492, 'Os Pinguins de Madagascar S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/237581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2WGd1Ew7cbOXlvvCgAUGoQud6xQ.jpg'),
(118598, 8492, 'Os Pinguins de Madagascar S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/237582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/EHeVcF4pwquU0sk4cG77VA2bUY.jpg'),
(118599, 8492, 'Os Pinguins de Madagascar S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/237583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hRDjkcwAjPQ4Iojg7XVjSKYqiqK.jpg'),
(118600, 8492, 'Os Pinguins de Madagascar S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/237584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6UtgZWjDPQA01YEMSO7UjAUijAI.jpg'),
(118601, 8493, 'Os Pinguins de Madagascar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118602, 8493, 'Os Pinguins de Madagascar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118603, 8493, 'Os Pinguins de Madagascar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118604, 8493, 'Os Pinguins de Madagascar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118605, 8493, 'Os Pinguins de Madagascar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118606, 8493, 'Os Pinguins de Madagascar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118607, 8493, 'Os Pinguins de Madagascar S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118608, 8493, 'Os Pinguins de Madagascar S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118609, 8493, 'Os Pinguins de Madagascar S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118610, 8493, 'Os Pinguins de Madagascar S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118611, 8493, 'Os Pinguins de Madagascar S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118612, 8493, 'Os Pinguins de Madagascar S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118613, 8493, 'Os Pinguins de Madagascar S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118614, 8493, 'Os Pinguins de Madagascar S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118615, 8493, 'Os Pinguins de Madagascar S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118616, 8493, 'Os Pinguins de Madagascar S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/237600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118617, 8493, 'Os Pinguins de Madagascar S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/237601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118618, 8493, 'Os Pinguins de Madagascar S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/237602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118619, 8493, 'Os Pinguins de Madagascar S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/237603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118620, 8493, 'Os Pinguins de Madagascar S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/237604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118621, 8493, 'Os Pinguins de Madagascar S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/237605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118622, 8493, 'Os Pinguins de Madagascar S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/237606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118623, 8493, 'Os Pinguins de Madagascar S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/237607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118624, 8493, 'Os Pinguins de Madagascar S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/237608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118625, 8493, 'Os Pinguins de Madagascar S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/237609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118626, 8493, 'Os Pinguins de Madagascar S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/237610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118627, 8493, 'Os Pinguins de Madagascar S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/237611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118628, 8493, 'Os Pinguins de Madagascar S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/237612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118629, 8493, 'Os Pinguins de Madagascar S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/237613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118630, 8493, 'Os Pinguins de Madagascar S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/237614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118631, 8493, 'Os Pinguins de Madagascar S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/237615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118632, 8493, 'Os Pinguins de Madagascar S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/237616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118633, 8493, 'Os Pinguins de Madagascar S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/237617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118634, 8493, 'Os Pinguins de Madagascar S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/237618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118635, 8493, 'Os Pinguins de Madagascar S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/237619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118636, 8493, 'Os Pinguins de Madagascar S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/237620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118637, 8494, 'Os Pinguins de Madagascar S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118638, 8494, 'Os Pinguins de Madagascar S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118639, 8494, 'Os Pinguins de Madagascar S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118640, 8494, 'Os Pinguins de Madagascar S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118641, 8494, 'Os Pinguins de Madagascar S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118642, 8494, 'Os Pinguins de Madagascar S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118643, 8494, 'Os Pinguins de Madagascar S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118644, 8494, 'Os Pinguins de Madagascar S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118645, 8494, 'Os Pinguins de Madagascar S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118646, 8494, 'Os Pinguins de Madagascar S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118647, 8494, 'Os Pinguins de Madagascar S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118648, 8494, 'Os Pinguins de Madagascar S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118649, 8494, 'Os Pinguins de Madagascar S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118650, 8494, 'Os Pinguins de Madagascar S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118651, 8494, 'Os Pinguins de Madagascar S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A48Shigo8YLltGphCfOBbvgCOti.jpg'),
(118652, 8495, 'Top Boy Summerhouse S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tbuIxhlU1775FyOBQqkkZrxVxyn.jpg'),
(118653, 8495, 'Top Boy Summerhouse S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ynXtGoHxPd50m0zzGtUPNIMGnP8.jpg'),
(118654, 8495, 'Top Boy Summerhouse S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Op6SLYuywuDMajDtDxzkgYIQIR.jpg'),
(118655, 8495, 'Top Boy Summerhouse S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9GzsWRYZo0N6uFFgQL7tHLHbtDn.jpg'),
(118656, 8496, 'Top Boy Summerhouse S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x8L39s3tJYuugVfRz60vx5cPlmX.jpg'),
(118657, 8496, 'Top Boy Summerhouse S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1soy9kfy1pFVbVWoWEZZydO9F1T.jpg'),
(118658, 8496, 'Top Boy Summerhouse S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vYliKExNsbOY2hfBlBD6DHP8ldK.jpg'),
(118659, 8496, 'Top Boy Summerhouse S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9hEbCDVasqmVhlBLHs6bRkzDVgr.jpg'),
(118660, 8497, 'Top Boy Summerhouse S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118661, 8497, 'Top Boy Summerhouse S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118662, 8497, 'Top Boy Summerhouse S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118663, 8497, 'Top Boy Summerhouse S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118664, 8497, 'Top Boy Summerhouse S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118665, 8497, 'Top Boy Summerhouse S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118666, 8497, 'Top Boy Summerhouse S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118667, 8497, 'Top Boy Summerhouse S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118668, 8497, 'Top Boy Summerhouse S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118669, 8497, 'Top Boy Summerhouse S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118670, 8498, 'Top Boy Summerhouse S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118671, 8498, 'Top Boy Summerhouse S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118672, 8498, 'Top Boy Summerhouse S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118673, 8498, 'Top Boy Summerhouse S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118674, 8498, 'Top Boy Summerhouse S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118675, 8498, 'Top Boy Summerhouse S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118676, 8498, 'Top Boy Summerhouse S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118677, 8498, 'Top Boy Summerhouse S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118678, 8499, 'Top Boy Summerhouse S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118679, 8499, 'Top Boy Summerhouse S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118680, 8499, 'Top Boy Summerhouse S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118681, 8499, 'Top Boy Summerhouse S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118682, 8499, 'Top Boy Summerhouse S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118683, 8499, 'Top Boy Summerhouse S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBqgEMnbleoeLqdadlvBGDxVvKb.jpg'),
(118684, 8500, 'Wu-Tang: An American Saga S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dBQyi4314aoEG9tNCWCnf0FlZnz.jpg'),
(118685, 8500, 'Wu-Tang: An American Saga S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ok6y19nrFqTVzt2DXaBiVYc34HW.jpg'),
(118686, 8500, 'Wu-Tang: An American Saga S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ZgyPlOyxxImsZ6pQsIiPRZsnBk.jpg'),
(118687, 8500, 'Wu-Tang: An American Saga S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ie3zRlmBOxl18rznXtNUdXdF8OO.jpg'),
(118688, 8500, 'Wu-Tang: An American Saga S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xKLkFRmTZVeGXeFTnexrX8y9uAw.jpg'),
(118689, 8500, 'Wu-Tang: An American Saga S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mUXvxRrPDgtn4OwO6EIIeJlczbc.jpg'),
(118690, 8500, 'Wu-Tang: An American Saga S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ulG9VfiVchHyqAvCedfYc9adeUu.jpg'),
(118691, 8500, 'Wu-Tang: An American Saga S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1qXlGg6Y2EHafJjSGZaFDl9r9qr.jpg'),
(118692, 8500, 'Wu-Tang: An American Saga S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/olANm7qsoeckI0lvd4wvpynOTJQ.jpg'),
(118693, 8500, 'Wu-Tang: An American Saga S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lhzsr8eASENSWU7eXsx2ac7MGm1.jpg'),
(118694, 8501, 'Wu-Tang: An American Saga S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fSBH0YYyRt6dT0kGu1KcIXfkUGI.jpg'),
(118695, 8501, 'Wu-Tang: An American Saga S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5wbiflNs1YCX6s06MGewBc4Cw0k.jpg'),
(118696, 8501, 'Wu-Tang: An American Saga S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMjEz5tqfds71Pp78omp9iINrsy.jpg'),
(118697, 8501, 'Wu-Tang: An American Saga S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4Wxqe6ox07win6eyWUwa9tfuWc.jpg'),
(118698, 8501, 'Wu-Tang: An American Saga S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ukot9A5qYhWBE9YPmXxkVdrsK9S.jpg'),
(118699, 8501, 'Wu-Tang: An American Saga S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wKNoFHAowPTqf9seONbiywz2wX8.jpg'),
(118700, 8501, 'Wu-Tang: An American Saga S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wAVBUYLHF5ayueCAOtJF9cspc4z.jpg'),
(118701, 8501, 'Wu-Tang: An American Saga S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/51Wt6NUOL1CzR1TXi5v854fWutc.jpg'),
(118702, 8501, 'Wu-Tang: An American Saga S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zvK8uw2LtoJ54PS0HNKExuaJWg4.jpg'),
(118703, 8501, 'Wu-Tang: An American Saga S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bi2IjlGd7PbzLMvLYqEuqh2FPU0.jpg'),
(118704, 8502, 'Wu-Tang: An American Saga S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v3SRAeDmTa7HPegHFQGOrfhYnNs.jpg'),
(118705, 8502, 'Wu-Tang: An American Saga S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tTFCXP7mX8zLynyA9qh2mMkqONC.jpg'),
(118706, 8502, 'Wu-Tang: An American Saga S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cnJkbXwyKUU9ykChRKZiusPKETk.jpg'),
(118707, 8502, 'Wu-Tang: An American Saga S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ljtq4ZQmTiH7FnkC0zzFDLvc5mJ.jpg'),
(118708, 8502, 'Wu-Tang: An American Saga S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xoJlMO7n8W8eLrw0LpFuXdqJgdh.jpg'),
(118709, 8502, 'Wu-Tang: An American Saga S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/llEBNAOvwDbiFj06JhZFP5ToBWj.jpg'),
(118710, 8502, 'Wu-Tang: An American Saga S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nkcePOJVH8g6Tmrd5OHuwbIdh9Q.jpg'),
(118711, 8502, 'Wu-Tang: An American Saga S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSj6oX9TYDGFiFYrL4dmIA3xv8C.jpg'),
(118712, 8502, 'Wu-Tang: An American Saga S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ssco1nyLqSn33pMsVLMxMd2dxZH.jpg'),
(118713, 8502, 'Wu-Tang: An American Saga S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zUVUdOGFwvoUzeXL2NtdeQsqecT.jpg'),
(118714, 8503, 'Breadwinners S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118715, 8503, 'Breadwinners S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118716, 8503, 'Breadwinners S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118717, 8503, 'Breadwinners S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118718, 8503, 'Breadwinners S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118719, 8503, 'Breadwinners S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118720, 8503, 'Breadwinners S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118721, 8503, 'Breadwinners S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118722, 8503, 'Breadwinners S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118723, 8503, 'Breadwinners S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118724, 8503, 'Breadwinners S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118725, 8503, 'Breadwinners S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118726, 8503, 'Breadwinners S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118727, 8503, 'Breadwinners S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118728, 8503, 'Breadwinners S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118729, 8503, 'Breadwinners S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/237305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118730, 8503, 'Breadwinners S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/237306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118731, 8503, 'Breadwinners S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/237307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118732, 8503, 'Breadwinners S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/237308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118733, 8503, 'Breadwinners S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/237309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118734, 8504, 'Breadwinners S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118735, 8504, 'Breadwinners S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118736, 8504, 'Breadwinners S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118737, 8504, 'Breadwinners S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118738, 8504, 'Breadwinners S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118739, 8504, 'Breadwinners S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118740, 8504, 'Breadwinners S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118741, 8504, 'Breadwinners S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118742, 8504, 'Breadwinners S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118743, 8504, 'Breadwinners S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118744, 8504, 'Breadwinners S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118745, 8504, 'Breadwinners S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118746, 8504, 'Breadwinners S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/237322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118747, 8504, 'Breadwinners S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/237323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118748, 8504, 'Breadwinners S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/237324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118749, 8504, 'Breadwinners S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/237325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118750, 8504, 'Breadwinners S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/237326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118751, 8504, 'Breadwinners S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/237327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118752, 8504, 'Breadwinners S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/237328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118753, 8504, 'Breadwinners S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/237329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eOWAf4jeNPQX2JLMdJ3T1ad1kqR.jpg'),
(118754, 8505, 'Diarios de Mumbai [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cvExIF8wp7hT6TB98wmhuZwwDL6.jpg'),
(118755, 8505, 'Diarios de Mumbai [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bjgvObgXcevzsfKXByEzjKYeU0d.jpg'),
(118756, 8505, 'Diarios de Mumbai [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eGKjOz58jFBuClopmaeQ63qmtsU.jpg'),
(118757, 8505, 'Diarios de Mumbai [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8rmpLHgyaMsL7otmcpxF2YMubgb.jpg'),
(118758, 8505, 'Diarios de Mumbai [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4IFaFrXXHSf5jBSaAdHSMRWXQzv.jpg'),
(118759, 8505, 'Diarios de Mumbai [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v8LUqQtY5jMhKokqBNcwvLQx6om.jpg'),
(118760, 8505, 'Diarios de Mumbai [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ge4EAv00PJRYgmt4R6lbZ9Bne0w.jpg'),
(118761, 8505, 'Diarios de Mumbai [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2oLmg43Y35WfnnPpTOwxUqY9Knd.jpg'),
(118762, 8506, 'Diarios de Mumbai [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWV15P7R23Pdt6mlsn2GysSkXlH.jpg'),
(118763, 8506, 'Diarios de Mumbai [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5W69YA4FgVjmR8rkVNKLuoZDbXi.jpg'),
(118764, 8506, 'Diarios de Mumbai [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g6V3KZTDcDLvR8kFuBxPAK7liqL.jpg'),
(118765, 8506, 'Diarios de Mumbai [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/etIOEo4FHK9BGLo5edRsoJv1aaW.jpg'),
(118766, 8506, 'Diarios de Mumbai [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rAdlFmkucDIJnvYEWnboKrVo86e.jpg'),
(118767, 8506, 'Diarios de Mumbai [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qUJWi6nmc64vP3JrpdDOj2DGH6l.jpg'),
(118768, 8506, 'Diarios de Mumbai [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iwK7VLtOuko6tSG34BuHJqssTXO.jpg'),
(118769, 8506, 'Diarios de Mumbai [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h0i2QraJmsILU11pGYTDuKJD88.jpg'),
(118770, 8507, 'Gigolos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCI4xoficgRV0Owj1noL3Gw30H.jpg'),
(118771, 8507, 'Gigolos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCI4xoficgRV0Owj1noL3Gw30H.jpg'),
(118772, 8507, 'Gigolos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCI4xoficgRV0Owj1noL3Gw30H.jpg'),
(118773, 8507, 'Gigolos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCI4xoficgRV0Owj1noL3Gw30H.jpg'),
(118774, 8507, 'Gigolos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCI4xoficgRV0Owj1noL3Gw30H.jpg'),
(118775, 8507, 'Gigolos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCI4xoficgRV0Owj1noL3Gw30H.jpg'),
(118776, 8507, 'Gigolos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCI4xoficgRV0Owj1noL3Gw30H.jpg'),
(118777, 8507, 'Gigolos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCI4xoficgRV0Owj1noL3Gw30H.jpg'),
(118778, 8508, 'Gigolos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCI4xoficgRV0Owj1noL3Gw30H.jpg'),
(118779, 8508, 'Gigolos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCI4xoficgRV0Owj1noL3Gw30H.jpg'),
(118780, 8508, 'Gigolos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCI4xoficgRV0Owj1noL3Gw30H.jpg'),
(118781, 8508, 'Gigolos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCI4xoficgRV0Owj1noL3Gw30H.jpg'),
(118782, 8508, 'Gigolos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCI4xoficgRV0Owj1noL3Gw30H.jpg'),
(118783, 8508, 'Gigolos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCI4xoficgRV0Owj1noL3Gw30H.jpg'),
(118784, 8508, 'Gigolos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCI4xoficgRV0Owj1noL3Gw30H.jpg'),
(118785, 8508, 'Gigolos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCI4xoficgRV0Owj1noL3Gw30H.jpg'),
(118786, 8509, 'Goblin Slayer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oeHEWC0PbFVC0TrU6KgFhUK0CIh.jpg'),
(118787, 8509, 'Goblin Slayer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7jl5POUeCLkJntrIuU07Y7bU220.jpg'),
(118788, 8509, 'Goblin Slayer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lajNvw0xidfkWo8GrDR1H8uFI0T.jpg'),
(118789, 8509, 'Goblin Slayer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dk3jDsMo3bRqfimtQB7IXzHR2P9.jpg'),
(118790, 8509, 'Goblin Slayer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ERxZTGfeQgclOcubMyZQTJSz4T.jpg'),
(118791, 8509, 'Goblin Slayer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qLLQSVYm76muPbQNxZmXa3izZRV.jpg'),
(118792, 8509, 'Goblin Slayer S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lM8ZegTyeOxHw28hRYBivurn6fi.jpg'),
(118793, 8509, 'Goblin Slayer S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9NJdHXc2OAHgWjz1yr1Nw0W8kkK.jpg'),
(118794, 8509, 'Goblin Slayer S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nU5vVMzz8FMIlxLNMjFx1hDv4Ev.jpg'),
(118795, 8509, 'Goblin Slayer S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1VaILduqlSSgwYhoVkEkQorpWw2.jpg'),
(118796, 8509, 'Goblin Slayer S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/258201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rfectYk8veny3CAIZCzk54zYO5o.jpg'),
(118797, 8509, 'Goblin Slayer S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/258202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bS4vx2yILDnROx5hftgCddyxGJj.jpg'),
(118798, 8510, 'Goblin Slayer S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrAS0A39AW0fezW3gFmsKEDzGiU.jpg'),
(118799, 8510, 'Goblin Slayer S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrAS0A39AW0fezW3gFmsKEDzGiU.jpg'),
(118800, 8510, 'Goblin Slayer S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrAS0A39AW0fezW3gFmsKEDzGiU.jpg'),
(118801, 8510, 'Goblin Slayer S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrAS0A39AW0fezW3gFmsKEDzGiU.jpg'),
(118802, 8510, 'Goblin Slayer S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrAS0A39AW0fezW3gFmsKEDzGiU.jpg'),
(118803, 8510, 'Goblin Slayer S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrAS0A39AW0fezW3gFmsKEDzGiU.jpg'),
(118804, 8510, 'Goblin Slayer S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrAS0A39AW0fezW3gFmsKEDzGiU.jpg'),
(118805, 8510, 'Goblin Slayer S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrAS0A39AW0fezW3gFmsKEDzGiU.jpg'),
(118806, 8510, 'Goblin Slayer S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrAS0A39AW0fezW3gFmsKEDzGiU.jpg'),
(118807, 8510, 'Goblin Slayer S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrAS0A39AW0fezW3gFmsKEDzGiU.jpg'),
(118808, 8510, 'Goblin Slayer S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/258213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrAS0A39AW0fezW3gFmsKEDzGiU.jpg'),
(118809, 8510, 'Goblin Slayer S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/258214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrAS0A39AW0fezW3gFmsKEDzGiU.jpg'),
(118810, 8511, 'O Show dos Tubaroes Babies S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/237246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qtf7iNgM9tI1KxhZYUKHFqDoK6P.jpg'),
(118811, 8511, 'O Show dos Tubaroes Babies S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/237247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dVY4QL9JFDdlG4pQFLr8tim6c2w.jpg'),
(118812, 8511, 'O Show dos Tubaroes Babies S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/237248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t538CLexp0THzRQiH7SkpVG1tAl.jpg'),
(118813, 8511, 'O Show dos Tubaroes Babies S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/237249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/krEfuryiN2uOIfkW8PNcMA48zih.jpg'),
(118814, 8511, 'O Show dos Tubaroes Babies S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/237250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dh41lu4wTt5cDAHfBURzC1QWH6W.jpg'),
(118815, 8511, 'O Show dos Tubaroes Babies S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/237251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kmgWFGExRxOZoCgeFHn5VG97sM4.jpg'),
(118816, 8511, 'O Show dos Tubaroes Babies S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/237252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7GhSexPiFCaHaZW2q4i7OmoAOXd.jpg'),
(118817, 8511, 'O Show dos Tubaroes Babies S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/237253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ut21meK8EceML6i05O4xt65enwN.jpg'),
(118818, 8511, 'O Show dos Tubaroes Babies S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/237254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l7nB4N6P6c36c9rw9cn6rreaHmL.jpg'),
(118819, 8511, 'O Show dos Tubaroes Babies S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/237255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUlPgVUVfwcSnlnYrV6rIicWNOo.jpg'),
(118820, 8511, 'O Show dos Tubaroes Babies S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/237256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUlPgVUVfwcSnlnYrV6rIicWNOo.jpg'),
(118821, 8511, 'O Show dos Tubaroes Babies S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/237257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUlPgVUVfwcSnlnYrV6rIicWNOo.jpg'),
(118822, 8512, 'Strong Girl Nam soon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/78QLfOnEQGTlSlsee3Fpi3FZqS2.jpg'),
(118823, 8512, 'Strong Girl Nam soon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nPjkk0Ecu8Df8VTvB7JTyx9P4yw.jpg'),
(118824, 8512, 'Strong Girl Nam soon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktB3epuAUGjVE6te7udTUAHBuv2.jpg'),
(118825, 8512, 'Strong Girl Nam soon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktB3epuAUGjVE6te7udTUAHBuv2.jpg'),
(118826, 8512, 'Strong Girl Nam soon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktB3epuAUGjVE6te7udTUAHBuv2.jpg'),
(118827, 8512, 'Strong Girl Nam soon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktB3epuAUGjVE6te7udTUAHBuv2.jpg'),
(118828, 8512, 'Strong Girl Nam soon S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktB3epuAUGjVE6te7udTUAHBuv2.jpg'),
(118829, 8512, 'Strong Girl Nam soon S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktB3epuAUGjVE6te7udTUAHBuv2.jpg'),
(118830, 8512, 'Strong Girl Nam soon S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktB3epuAUGjVE6te7udTUAHBuv2.jpg'),
(118831, 8512, 'Strong Girl Nam soon S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktB3epuAUGjVE6te7udTUAHBuv2.jpg'),
(118832, 8512, 'Strong Girl Nam soon S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktB3epuAUGjVE6te7udTUAHBuv2.jpg'),
(118833, 8512, 'Strong Girl Nam soon S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktB3epuAUGjVE6te7udTUAHBuv2.jpg'),
(118834, 8512, 'Strong Girl Nam soon S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktB3epuAUGjVE6te7udTUAHBuv2.jpg'),
(118835, 8512, 'Strong Girl Nam soon S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktB3epuAUGjVE6te7udTUAHBuv2.jpg'),
(118836, 8512, 'Strong Girl Nam soon S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktB3epuAUGjVE6te7udTUAHBuv2.jpg'),
(118837, 8512, 'Strong Girl Nam soon S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktB3epuAUGjVE6te7udTUAHBuv2.jpg'),
(118838, 8513, 'The Rising of the Shield Hero [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251253.mp4', 'http://timg.bdta.pro/images/2ae3c54e08482fbafd21cab0598c519e.jpg'),
(118839, 8513, 'The Rising of the Shield Hero [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251254.mp4', 'http://timg.bdta.pro/images/3cfeedb522af611ac1ca08e6aa813b32.jpg'),
(118840, 8513, 'The Rising of the Shield Hero [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251255.mp4', 'http://timg.bdta.pro/images/dc171ac804b294c5d7201daebcd7b30e.jpg'),
(118841, 8513, 'The Rising of the Shield Hero [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251256.mp4', 'http://timg.bdta.pro/images/b9cc0f12dfb37cf4016a650512c1ef10.jpg'),
(118842, 8513, 'The Rising of the Shield Hero [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251257.mp4', 'http://timg.bdta.pro/images/ed9bf9900a680353c1daf96b34ea1cf4.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(118843, 8513, 'The Rising of the Shield Hero [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251258.mp4', 'http://timg.bdta.pro/images/3be1a31c38a640f5aba14cac9700a644.jpg'),
(118844, 8513, 'The Rising of the Shield Hero [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251259.mp4', 'http://timg.bdta.pro/images/144a2e0f1c68285363a305bcc20b4c6b.jpg'),
(118845, 8513, 'The Rising of the Shield Hero [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251260.mp4', 'http://timg.bdta.pro/images/2cf40b115477fdc816dad5b8a9a824d9.jpg'),
(118846, 8513, 'The Rising of the Shield Hero [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251261.mp4', 'http://timg.bdta.pro/images/6d70713d78fe884be195c3c8b0409702.jpg'),
(118847, 8513, 'The Rising of the Shield Hero [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251262.mp4', 'http://timg.bdta.pro/images/c6fb01e915920a7ead1f8614924ed0d8.jpg'),
(118848, 8513, 'The Rising of the Shield Hero [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251263.mp4', 'http://timg.bdta.pro/images/244ab621e85fb79808e9e8b8f7c01e76.jpg'),
(118849, 8513, 'The Rising of the Shield Hero [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251264.mp4', 'http://timg.bdta.pro/images/edf3a6adf8a2cf154f4c54b1cdfec2d8.jpg'),
(118850, 8513, 'The Rising of the Shield Hero [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251265.mp4', 'http://timg.bdta.pro/images/352364a5c51210c87514e186015b6874.jpg'),
(118851, 8513, 'The Rising of the Shield Hero [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251266.mp4', 'http://timg.bdta.pro/images/d33eb7773062669a6bad33bfe6bd60a4.jpg'),
(118852, 8513, 'The Rising of the Shield Hero [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251267.mp4', 'http://timg.bdta.pro/images/927c1c665be01df29a1317f9d279deb5.jpg'),
(118853, 8513, 'The Rising of the Shield Hero [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/251268.mp4', 'http://timg.bdta.pro/images/7cbc0e715b2ccc6043b6f37829f0a71a.jpg'),
(118854, 8513, 'The Rising of the Shield Hero [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/251269.mp4', 'http://timg.bdta.pro/images/b0d72d7a98dd6a37d9426b8c98863a12.jpg'),
(118855, 8513, 'The Rising of the Shield Hero [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/251270.mp4', 'http://timg.bdta.pro/images/5d0a25fd6f278bfcf50c4ea8faf55017.jpg'),
(118856, 8513, 'The Rising of the Shield Hero [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/251271.mp4', 'http://timg.bdta.pro/images/725ad2e63984e00aba00fd0e031a5a71.jpg'),
(118857, 8513, 'The Rising of the Shield Hero [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/251272.mp4', 'http://timg.bdta.pro/images/27e688cb8c1b34a311d4e4c4efeedbe2.jpg'),
(118858, 8513, 'The Rising of the Shield Hero [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/251273.mp4', 'http://timg.bdta.pro/images/3ad25e5572b132bf1eda89c61a841e1d.jpg'),
(118859, 8513, 'The Rising of the Shield Hero [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/251274.mp4', 'http://timg.bdta.pro/images/35a0edfcd858bb00cee08bf270247601.jpg'),
(118860, 8513, 'The Rising of the Shield Hero [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/251275.mp4', 'http://timg.bdta.pro/images/00d27641dbb302d400f19440065a87b2.jpg'),
(118861, 8513, 'The Rising of the Shield Hero [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/251276.mp4', 'http://timg.bdta.pro/images/d6c788ad0a936b5ab8fc94d89e961382.jpg'),
(118862, 8513, 'The Rising of the Shield Hero [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/251277.mp4', 'http://timg.bdta.pro/images/dbe0d4b3116b53de3dddd624822e9eda.jpg'),
(118863, 8514, 'The Rising of the Shield Hero [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tRO0DbjXkA6s7pU0hVJJfrDrPqr.jpg'),
(118864, 8514, 'The Rising of the Shield Hero [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2WqmAKbSS78m2udzIWSZSflVU4h.jpg'),
(118865, 8514, 'The Rising of the Shield Hero [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iDeFalJ462DLsGPowJYEoy6BKmo.jpg'),
(118866, 8514, 'The Rising of the Shield Hero [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sPsdHO0u2XQpwE8RE8SkbUeaSGO.jpg'),
(118867, 8514, 'The Rising of the Shield Hero [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmbhEixShcIkZdABWO6SwyUsmf9.jpg'),
(118868, 8514, 'The Rising of the Shield Hero [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6cRt8dAvxM49nuEkPe1e5COsHyP.jpg'),
(118869, 8514, 'The Rising of the Shield Hero [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n7TO02GB9Y2uPEXBAhusFZfKqZd.jpg'),
(118870, 8514, 'The Rising of the Shield Hero [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dRIf2z69220x4QOxZqicm3AOB2W.jpg'),
(118871, 8514, 'The Rising of the Shield Hero [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vlnMMoBwzO5XrCeI82VWAF4nS95.jpg'),
(118872, 8514, 'The Rising of the Shield Hero [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/46ak0sKyNul9dwfx1wbLmVXlGTO.jpg'),
(118873, 8514, 'The Rising of the Shield Hero [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/arCt8efkNt2FCHZUWrrqXrczhiu.jpg'),
(118874, 8514, 'The Rising of the Shield Hero [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k7NAImYQXSeshdC7FAVdV6tX0eQ.jpg'),
(118875, 8514, 'The Rising of the Shield Hero [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jUPGP1lycBxOJqfibDsWXjMGwge.jpg'),
(118876, 8515, 'The Rising of the Shield Hero [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dBS9trCTsM0TDRqGWROMfxSh69W.jpg'),
(118877, 8515, 'The Rising of the Shield Hero [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118878, 8515, 'The Rising of the Shield Hero [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118879, 8515, 'The Rising of the Shield Hero [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118880, 8515, 'The Rising of the Shield Hero [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118881, 8515, 'The Rising of the Shield Hero [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118882, 8515, 'The Rising of the Shield Hero [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118883, 8515, 'The Rising of the Shield Hero [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118884, 8515, 'The Rising of the Shield Hero [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118885, 8515, 'The Rising of the Shield Hero [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118886, 8515, 'The Rising of the Shield Hero [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118887, 8515, 'The Rising of the Shield Hero [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118888, 8516, 'The Rising of the Shield Hero [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/863397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118889, 8516, 'The Rising of the Shield Hero [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/869313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118890, 8516, 'The Rising of the Shield Hero [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/873127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118891, 8516, 'The Rising of the Shield Hero [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/878828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118892, 8516, 'The Rising of the Shield Hero [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/879909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118893, 8516, 'The Rising of the Shield Hero [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/880505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118894, 8516, 'The Rising of the Shield Hero [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/881140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118895, 8516, 'The Rising of the Shield Hero [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/882046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118896, 8516, 'The Rising of the Shield Hero [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/882112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118897, 8516, 'The Rising of the Shield Hero [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/883726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118898, 8516, 'The Rising of the Shield Hero [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/885263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118899, 8516, 'The Rising of the Shield Hero [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/885972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yazU3CEZa97RPTMlWCc9LO4F4E.jpg'),
(118900, 8517, 'Tudo pra Ontem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6KpxtrJW5oV4IQsnCf7m96neojL.jpg'),
(118901, 8517, 'Tudo pra Ontem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uOXkkzGfkeV2Uyc1UUPWiNLPZ34.jpg'),
(118902, 8517, 'Tudo pra Ontem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2KFTOxfdmenS4EbrmC7dYalwnPU.jpg'),
(118903, 8517, 'Tudo pra Ontem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5373YsJmzskwi5YpYPOtEkGeWon.jpg'),
(118904, 8517, 'Tudo pra Ontem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMke3zCKDSxzqSYiMUQo8i2kYSd.jpg'),
(118905, 8517, 'Tudo pra Ontem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xwIGXzVe7QxblwKR54aze4DXKqn.jpg'),
(118906, 8517, 'Tudo pra Ontem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A73pOtG99pUUmUz0q9pQnmOuf6u.jpg'),
(118907, 8517, 'Tudo pra Ontem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUaw2iGIpGz89hysB38oLlBOAvX.jpg'),
(118908, 8518, 'A Grande Cacada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/caIcciFYIf3oWHdRC31lZDP5gJO.jpg'),
(118909, 8518, 'A Grande Cacada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eRyE5cPb9K7gGOoi8f6LN9hBDkw.jpg'),
(118910, 8518, 'A Grande Cacada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lQM6SCZ0YVnpLg0rvAhSydVurgA.jpg'),
(118911, 8518, 'A Grande Cacada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yLDTAkBwm4nUi5BMJqESJeVvmlD.jpg'),
(118912, 8518, 'A Grande Cacada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yLDTAkBwm4nUi5BMJqESJeVvmlD.jpg'),
(118913, 8518, 'A Grande Cacada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yLDTAkBwm4nUi5BMJqESJeVvmlD.jpg'),
(118914, 8518, 'A Grande Cacada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yLDTAkBwm4nUi5BMJqESJeVvmlD.jpg'),
(118915, 8518, 'A Grande Cacada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yLDTAkBwm4nUi5BMJqESJeVvmlD.jpg'),
(118916, 8519, 'A Queda da Casa de Usher S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPfX3S7SzgrhIo1EiKCGxcL3qID.jpg'),
(118917, 8519, 'A Queda da Casa de Usher S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vwt9wzuLp4SwfP8kZjTO6LP8QXr.jpg'),
(118918, 8519, 'A Queda da Casa de Usher S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hjbAMmjqUJJbpirtQS2v6LCnAbZ.jpg'),
(118919, 8519, 'A Queda da Casa de Usher S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8cyizpc4uaTsvNiLNdhSHLCYzmH.jpg'),
(118920, 8519, 'A Queda da Casa de Usher S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kMcPhOqU19cyWiGZ4MYqhN8IcET.jpg'),
(118921, 8519, 'A Queda da Casa de Usher S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dPF6nLNBpaSebOxSVFvRRdO8XLB.jpg'),
(118922, 8519, 'A Queda da Casa de Usher S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a0rQXECALSE65fz1HDHltPNYQZa.jpg'),
(118923, 8519, 'A Queda da Casa de Usher S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dNn6qkd3gFteYdlGEVERz4aleB6.jpg'),
(118924, 8520, 'Big Vape The Rise and Fall of Juul S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dI0kGcAZ3SLikVYmfxkkdbKa68d.jpg'),
(118925, 8520, 'Big Vape The Rise and Fall of Juul S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dI0kGcAZ3SLikVYmfxkkdbKa68d.jpg'),
(118926, 8520, 'Big Vape The Rise and Fall of Juul S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dI0kGcAZ3SLikVYmfxkkdbKa68d.jpg'),
(118927, 8520, 'Big Vape The Rise and Fall of Juul S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dI0kGcAZ3SLikVYmfxkkdbKa68d.jpg'),
(118928, 8521, 'Boa Noite Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oIbpqPZaRfZbMzlkubTNVGnPLJ2.jpg'),
(118929, 8521, 'Boa Noite Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rweCPWqKiPvR31abhqqAjyVkfEd.jpg'),
(118930, 8521, 'Boa Noite Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/txAtuoh1qOaHMgizD7dfULDbqKE.jpg'),
(118931, 8521, 'Boa Noite Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4sN5BTpOxc3mgUIUpKFMzGeLCH.jpg'),
(118932, 8521, 'Boa Noite Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3SlQuoRgSlHYMNea68JsGTL1KdZ.jpg'),
(118933, 8521, 'Boa Noite Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jucc35t7yV4Z43mWZIz759nMxDs.jpg'),
(118934, 8521, 'Boa Noite Mundo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Kwf4xyH0qv2aHeXuTKhpgRYlJB.jpg'),
(118935, 8521, 'Boa Noite Mundo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lpZrmwGwlEeC0LFM3Oz2ig6TXwM.jpg'),
(118936, 8521, 'Boa Noite Mundo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gGz82jxZA2gBpznb0r8w1DrVQh7.jpg'),
(118937, 8521, 'Boa Noite Mundo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sImOMLnZXmJl4k155aJIK5yQ7Ct.jpg'),
(118938, 8521, 'Boa Noite Mundo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/242364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kIXpK7xZ1g0sVIZeNzuwQ3ikKOs.jpg'),
(118939, 8521, 'Boa Noite Mundo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/242365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yy5ebbVRDRLzRFcJGuRNg1MQThp.jpg'),
(118940, 8522, 'D1AR10S S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zUgZA3ZakY6fAsubVEmNGd0sfeb.jpg'),
(118941, 8522, 'D1AR10S S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgjzt7NRZqTiGSGDtnOZFCG4JWf.jpg'),
(118942, 8522, 'D1AR10S S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fCF6uTM2dT6OzdFlsjFHN4ubjRo.jpg'),
(118943, 8522, 'D1AR10S S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AwG6SzhGitZMjuL4q2VYsvBJ9pM.jpg'),
(118944, 8522, 'D1AR10S S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oADyvM26ZCok5ap3poOrXAkTA3Z.jpg'),
(118945, 8522, 'D1AR10S S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5wJNH8ykAL9ChoJqZtM8lMFA7kM.jpg'),
(118946, 8522, 'D1AR10S S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/roAqvI13EJLlhxfzjsRB0vXdn7T.jpg'),
(118947, 8522, 'D1AR10S S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZhwjbjafRNSo26fCMgLrGtA9Af.jpg'),
(118948, 8522, 'D1AR10S S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5GikxssHStlzKerCtWvjuy1LGu8.jpg'),
(118949, 8522, 'D1AR10S S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l6oaPy4MrcfrL20D5y21xW6M3AL.jpg'),
(118950, 8522, 'D1AR10S S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mYzAUtrvKm7BTx9QaenuE0Ehhhu.jpg'),
(118951, 8522, 'D1AR10S S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zFmSjsGKCFqFy5rK5MOM63dSYCL.jpg'),
(118952, 8522, 'D1AR10S S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7IqKpIrEnIeJMWNANUTIX2YzZC.jpg'),
(118953, 8522, 'D1AR10S S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/259164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/py0lVLp8AEAjwnLOBmrWF7xuuWL.jpg'),
(118954, 8522, 'D1AR10S S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/259165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uVkqpUQvf2Z3zMjd5GuUU2TKcw5.jpg'),
(118955, 8523, 'D1AR10S S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259166.mp4', 'http://gstaticontent.com/images/e8dfe08e2da9660bf827e236961e1458.jpg'),
(118956, 8523, 'D1AR10S S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259167.mp4', 'http://gstaticontent.com/images/e8dfe08e2da9660bf827e236961e1458.jpg'),
(118957, 8523, 'D1AR10S S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259168.mp4', 'http://gstaticontent.com/images/e8dfe08e2da9660bf827e236961e1458.jpg'),
(118958, 8523, 'D1AR10S S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259169.mp4', 'http://gstaticontent.com/images/e8dfe08e2da9660bf827e236961e1458.jpg'),
(118959, 8523, 'D1AR10S S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259170.mp4', 'http://gstaticontent.com/images/e8dfe08e2da9660bf827e236961e1458.jpg'),
(118960, 8523, 'D1AR10S S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259171.mp4', 'http://gstaticontent.com/images/e8dfe08e2da9660bf827e236961e1458.jpg'),
(118961, 8523, 'D1AR10S S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259172.mp4', 'http://gstaticontent.com/images/e8dfe08e2da9660bf827e236961e1458.jpg'),
(118962, 8523, 'D1AR10S S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259173.mp4', 'http://gstaticontent.com/images/e8dfe08e2da9660bf827e236961e1458.jpg'),
(118963, 8523, 'D1AR10S S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259174.mp4', 'http://gstaticontent.com/images/e8dfe08e2da9660bf827e236961e1458.jpg'),
(118964, 8523, 'D1AR10S S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259175.mp4', 'http://gstaticontent.com/images/e8dfe08e2da9660bf827e236961e1458.jpg'),
(118965, 8523, 'D1AR10S S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259176.mp4', 'http://gstaticontent.com/images/e8dfe08e2da9660bf827e236961e1458.jpg'),
(118966, 8523, 'D1AR10S S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259177.mp4', 'http://gstaticontent.com/images/e8dfe08e2da9660bf827e236961e1458.jpg'),
(118967, 8523, 'D1AR10S S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259178.mp4', 'http://gstaticontent.com/images/e8dfe08e2da9660bf827e236961e1458.jpg'),
(118968, 8523, 'D1AR10S S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/259179.mp4', 'http://gstaticontent.com/images/e8dfe08e2da9660bf827e236961e1458.jpg'),
(118969, 8524, 'Dora e Seus Amigos Na Cidade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w4PvSmFhxGEMGI6el3DXwEPK6Hd.jpg'),
(118970, 8524, 'Dora e Seus Amigos Na Cidade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w4PvSmFhxGEMGI6el3DXwEPK6Hd.jpg'),
(118971, 8524, 'Dora e Seus Amigos Na Cidade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w4PvSmFhxGEMGI6el3DXwEPK6Hd.jpg'),
(118972, 8524, 'Dora e Seus Amigos Na Cidade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w4PvSmFhxGEMGI6el3DXwEPK6Hd.jpg'),
(118973, 8524, 'Dora e Seus Amigos Na Cidade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w4PvSmFhxGEMGI6el3DXwEPK6Hd.jpg'),
(118974, 8524, 'Dora e Seus Amigos Na Cidade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w4PvSmFhxGEMGI6el3DXwEPK6Hd.jpg'),
(118975, 8524, 'Dora e Seus Amigos Na Cidade S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w4PvSmFhxGEMGI6el3DXwEPK6Hd.jpg'),
(118976, 8524, 'Dora e Seus Amigos Na Cidade S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w4PvSmFhxGEMGI6el3DXwEPK6Hd.jpg'),
(118977, 8524, 'Dora e Seus Amigos Na Cidade S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w4PvSmFhxGEMGI6el3DXwEPK6Hd.jpg'),
(118978, 8524, 'Dora e Seus Amigos Na Cidade S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w4PvSmFhxGEMGI6el3DXwEPK6Hd.jpg'),
(118979, 8524, 'Dora e Seus Amigos Na Cidade S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/242321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w4PvSmFhxGEMGI6el3DXwEPK6Hd.jpg'),
(118980, 8524, 'Dora e Seus Amigos Na Cidade S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/242322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w4PvSmFhxGEMGI6el3DXwEPK6Hd.jpg'),
(118981, 8524, 'Dora e Seus Amigos Na Cidade S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/242323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w4PvSmFhxGEMGI6el3DXwEPK6Hd.jpg'),
(118982, 8524, 'Dora e Seus Amigos Na Cidade S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/242324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w4PvSmFhxGEMGI6el3DXwEPK6Hd.jpg'),
(118983, 8524, 'Dora e Seus Amigos Na Cidade S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/242325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w4PvSmFhxGEMGI6el3DXwEPK6Hd.jpg'),
(118984, 8524, 'Dora e Seus Amigos Na Cidade S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/242326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w4PvSmFhxGEMGI6el3DXwEPK6Hd.jpg'),
(118985, 8524, 'Dora e Seus Amigos Na Cidade S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/242327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lufDuguwwAJxw12DXxkxctfqhTS.jpg'),
(118986, 8524, 'Dora e Seus Amigos Na Cidade S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/242328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k2hQWVzgTcOiDPfa65dxklqtlHT.jpg'),
(118987, 8524, 'Dora e Seus Amigos Na Cidade S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/242329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o9r5N44a1BNsJ9S4WjNBsIJEi8s.jpg'),
(118988, 8524, 'Dora e Seus Amigos Na Cidade S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/242330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w4PvSmFhxGEMGI6el3DXwEPK6Hd.jpg'),
(118989, 8525, 'Dupla do Barulho S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iQarHTtZmXKpVHhIp3HJKcRe56B.jpg'),
(118990, 8525, 'Dupla do Barulho S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(118991, 8525, 'Dupla do Barulho S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(118992, 8525, 'Dupla do Barulho S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(118993, 8525, 'Dupla do Barulho S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(118994, 8525, 'Dupla do Barulho S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(118995, 8525, 'Dupla do Barulho S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(118996, 8525, 'Dupla do Barulho S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(118997, 8525, 'Dupla do Barulho S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(118998, 8525, 'Dupla do Barulho S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(118999, 8525, 'Dupla do Barulho S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/242041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119000, 8525, 'Dupla do Barulho S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/242042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119001, 8525, 'Dupla do Barulho S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/242043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119002, 8525, 'Dupla do Barulho S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/242044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119003, 8526, 'Dupla do Barulho S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119004, 8526, 'Dupla do Barulho S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119005, 8526, 'Dupla do Barulho S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119006, 8526, 'Dupla do Barulho S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119007, 8526, 'Dupla do Barulho S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119008, 8526, 'Dupla do Barulho S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119009, 8527, 'Dupla do Barulho S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119010, 8527, 'Dupla do Barulho S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119011, 8527, 'Dupla do Barulho S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119012, 8527, 'Dupla do Barulho S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119013, 8527, 'Dupla do Barulho S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119014, 8527, 'Dupla do Barulho S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119015, 8527, 'Dupla do Barulho S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119016, 8527, 'Dupla do Barulho S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119017, 8528, 'Dupla do Barulho S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/waeB5RBIS6SfTar4LsGaZUZP4dD.jpg'),
(119018, 8528, 'Dupla do Barulho S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119019, 8528, 'Dupla do Barulho S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119020, 8528, 'Dupla do Barulho S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119021, 8528, 'Dupla do Barulho S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119022, 8528, 'Dupla do Barulho S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119023, 8528, 'Dupla do Barulho S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119024, 8528, 'Dupla do Barulho S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119025, 8528, 'Dupla do Barulho S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119026, 8528, 'Dupla do Barulho S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119027, 8528, 'Dupla do Barulho S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/242069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119028, 8528, 'Dupla do Barulho S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/242070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119029, 8528, 'Dupla do Barulho S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/242071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qNjpn0j3AjVzmxhjyRkeeFyiHVQ.jpg'),
(119030, 8528, 'Dupla do Barulho S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/242072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119031, 8529, 'Dupla do Barulho S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jfH5WsOoLKTGLeGdm4cg7gUWQAy.jpg'),
(119032, 8529, 'Dupla do Barulho S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tU9qb07sielVKg9SXw1EqYt7o59.jpg'),
(119033, 8529, 'Dupla do Barulho S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7HzxAN9yY5CefTCH5U67Zhyh6YA.jpg'),
(119034, 8529, 'Dupla do Barulho S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dH9bmHA2lM9F7FViYD4tekKwIQL.jpg'),
(119035, 8529, 'Dupla do Barulho S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yxvsIoN1ar6ROu4S5x4e2f1Btm9.jpg'),
(119036, 8529, 'Dupla do Barulho S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d0Z9cDSctEEflrq6T1DuxpZ2Pt7.jpg'),
(119037, 8529, 'Dupla do Barulho S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8j9CK1kMhb85d9QKLonEDmFtCGJ.jpg'),
(119038, 8529, 'Dupla do Barulho S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w6LC8Z7Xr8CVGyujrjWumyM0N7G.jpg'),
(119039, 8529, 'Dupla do Barulho S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119040, 8530, 'Dupla do Barulho S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lSx7S3jEuZIqpHBfkWZNe5pVvta.jpg'),
(119041, 8530, 'Dupla do Barulho S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119042, 8530, 'Dupla do Barulho S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119043, 8530, 'Dupla do Barulho S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119044, 8530, 'Dupla do Barulho S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119045, 8530, 'Dupla do Barulho S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119046, 8530, 'Dupla do Barulho S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119047, 8530, 'Dupla do Barulho S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119048, 8531, 'Dupla do Barulho S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dYdH1XoK6sUM89oL3JgMtXeJQQF.jpg'),
(119049, 8531, 'Dupla do Barulho S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/150IPL4hTL3giI1uiplLVy3760B.jpg'),
(119050, 8531, 'Dupla do Barulho S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3vtGlC5nZVO0okA8Cbc92ungkC.jpg'),
(119051, 8531, 'Dupla do Barulho S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJzreI9sZtCFp9ln0MP5qEYY9T9.jpg'),
(119052, 8531, 'Dupla do Barulho S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3WGhuyszDTitvVEQOakxCH5o4nM.jpg'),
(119053, 8531, 'Dupla do Barulho S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pNj1m7Cbihr4kGUAIHM2w9umdWo.jpg'),
(119054, 8531, 'Dupla do Barulho S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3KfpCZPePlVJTSmugnvrsoEsdD1.jpg'),
(119055, 8531, 'Dupla do Barulho S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8TFH4X7AOrFilu3BKhsmo2Z1RsW.jpg'),
(119056, 8532, 'Dupla do Barulho S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119057, 8532, 'Dupla do Barulho S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119058, 8532, 'Dupla do Barulho S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119059, 8532, 'Dupla do Barulho S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119060, 8532, 'Dupla do Barulho S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119061, 8532, 'Dupla do Barulho S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119062, 8533, 'Dupla do Barulho S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ljQLP6Lrk7eYaUPlBs2VjwQTuKw.jpg'),
(119063, 8533, 'Dupla do Barulho S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u3dFywnck9Fg5vmFgQY7vftLxGq.jpg'),
(119064, 8533, 'Dupla do Barulho S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rYoiF9h7GCwl6mNkAvNxs9srgrq.jpg'),
(119065, 8533, 'Dupla do Barulho S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wv2xA6j52uj6jhzzXH9iZodmoK4.jpg'),
(119066, 8533, 'Dupla do Barulho S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nnET8xjxlJ63ZrECEd5S23SH4jl.jpg'),
(119067, 8533, 'Dupla do Barulho S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119068, 8533, 'Dupla do Barulho S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119069, 8533, 'Dupla do Barulho S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119070, 8534, 'Dupla do Barulho S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119071, 8534, 'Dupla do Barulho S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119072, 8534, 'Dupla do Barulho S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119073, 8534, 'Dupla do Barulho S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119074, 8534, 'Dupla do Barulho S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119075, 8534, 'Dupla do Barulho S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119076, 8534, 'Dupla do Barulho S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119077, 8534, 'Dupla do Barulho S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119078, 8534, 'Dupla do Barulho S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119079, 8535, 'Dupla do Barulho S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119080, 8535, 'Dupla do Barulho S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119081, 8535, 'Dupla do Barulho S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119082, 8535, 'Dupla do Barulho S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119083, 8535, 'Dupla do Barulho S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119084, 8535, 'Dupla do Barulho S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119085, 8535, 'Dupla do Barulho S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119086, 8535, 'Dupla do Barulho S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119087, 8536, 'Dupla do Barulho S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119088, 8536, 'Dupla do Barulho S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119089, 8536, 'Dupla do Barulho S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119090, 8536, 'Dupla do Barulho S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119091, 8536, 'Dupla do Barulho S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119092, 8536, 'Dupla do Barulho S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119093, 8536, 'Dupla do Barulho S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119094, 8536, 'Dupla do Barulho S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119095, 8536, 'Dupla do Barulho S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119096, 8536, 'Dupla do Barulho S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119097, 8536, 'Dupla do Barulho S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/242139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119098, 8536, 'Dupla do Barulho S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/242140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119099, 8537, 'Dupla do Barulho S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oDQpxXLaaWmNdPcbDstfxpddTTP.jpg'),
(119100, 8537, 'Dupla do Barulho S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hN48h1EltaFMr385Qm6yvn3h44K.jpg'),
(119101, 8537, 'Dupla do Barulho S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mFaACus5fuchkE5eFEacTCbbEa7.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(119102, 8537, 'Dupla do Barulho S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119103, 8537, 'Dupla do Barulho S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119104, 8537, 'Dupla do Barulho S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119105, 8538, 'Dupla do Barulho S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119106, 8538, 'Dupla do Barulho S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119107, 8538, 'Dupla do Barulho S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119108, 8538, 'Dupla do Barulho S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119109, 8538, 'Dupla do Barulho S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119110, 8538, 'Dupla do Barulho S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119111, 8538, 'Dupla do Barulho S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119112, 8538, 'Dupla do Barulho S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119113, 8538, 'Dupla do Barulho S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119114, 8538, 'Dupla do Barulho S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119115, 8539, 'Dupla do Barulho S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119116, 8539, 'Dupla do Barulho S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119117, 8539, 'Dupla do Barulho S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119118, 8539, 'Dupla do Barulho S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119119, 8539, 'Dupla do Barulho S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119120, 8539, 'Dupla do Barulho S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119121, 8539, 'Dupla do Barulho S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119122, 8539, 'Dupla do Barulho S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119123, 8539, 'Dupla do Barulho S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119124, 8539, 'Dupla do Barulho S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119125, 8539, 'Dupla do Barulho S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/242167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119126, 8540, 'Dupla do Barulho S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119127, 8540, 'Dupla do Barulho S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119128, 8540, 'Dupla do Barulho S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119129, 8540, 'Dupla do Barulho S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119130, 8540, 'Dupla do Barulho S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119131, 8540, 'Dupla do Barulho S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119132, 8540, 'Dupla do Barulho S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119133, 8540, 'Dupla do Barulho S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119134, 8540, 'Dupla do Barulho S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119135, 8540, 'Dupla do Barulho S16 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119136, 8540, 'Dupla do Barulho S16 E11', 'http://sinalprivado.info:80/series/1533784/1533784/242178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phtsMZlwyL5LFPjJk0T9Ul8dVKr.jpg'),
(119137, 8541, 'Goblin Slayer [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oeHEWC0PbFVC0TrU6KgFhUK0CIh.jpg'),
(119138, 8541, 'Goblin Slayer [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7jl5POUeCLkJntrIuU07Y7bU220.jpg'),
(119139, 8541, 'Goblin Slayer [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lajNvw0xidfkWo8GrDR1H8uFI0T.jpg'),
(119140, 8541, 'Goblin Slayer [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dk3jDsMo3bRqfimtQB7IXzHR2P9.jpg'),
(119141, 8541, 'Goblin Slayer [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ERxZTGfeQgclOcubMyZQTJSz4T.jpg'),
(119142, 8541, 'Goblin Slayer [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qLLQSVYm76muPbQNxZmXa3izZRV.jpg'),
(119143, 8541, 'Goblin Slayer [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lM8ZegTyeOxHw28hRYBivurn6fi.jpg'),
(119144, 8541, 'Goblin Slayer [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9NJdHXc2OAHgWjz1yr1Nw0W8kkK.jpg'),
(119145, 8541, 'Goblin Slayer [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nU5vVMzz8FMIlxLNMjFx1hDv4Ev.jpg'),
(119146, 8541, 'Goblin Slayer [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1VaILduqlSSgwYhoVkEkQorpWw2.jpg'),
(119147, 8541, 'Goblin Slayer [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rfectYk8veny3CAIZCzk54zYO5o.jpg'),
(119148, 8541, 'Goblin Slayer [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bS4vx2yILDnROx5hftgCddyxGJj.jpg'),
(119149, 8542, 'Goblin Slayer [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/neVAFOKTDpzBeZmrdchiy3CKaqJ.jpg'),
(119150, 8542, 'Goblin Slayer [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nUiT0whRDuUJKkk74L1pn8xUE2z.jpg'),
(119151, 8542, 'Goblin Slayer [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nUiT0whRDuUJKkk74L1pn8xUE2z.jpg'),
(119152, 8542, 'Goblin Slayer [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nUiT0whRDuUJKkk74L1pn8xUE2z.jpg'),
(119153, 8542, 'Goblin Slayer [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nUiT0whRDuUJKkk74L1pn8xUE2z.jpg'),
(119154, 8542, 'Goblin Slayer [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nUiT0whRDuUJKkk74L1pn8xUE2z.jpg'),
(119155, 8542, 'Goblin Slayer [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nUiT0whRDuUJKkk74L1pn8xUE2z.jpg'),
(119156, 8542, 'Goblin Slayer [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nUiT0whRDuUJKkk74L1pn8xUE2z.jpg'),
(119157, 8542, 'Goblin Slayer [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nUiT0whRDuUJKkk74L1pn8xUE2z.jpg'),
(119158, 8542, 'Goblin Slayer [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nUiT0whRDuUJKkk74L1pn8xUE2z.jpg'),
(119159, 8542, 'Goblin Slayer [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nUiT0whRDuUJKkk74L1pn8xUE2z.jpg'),
(119160, 8542, 'Goblin Slayer [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nUiT0whRDuUJKkk74L1pn8xUE2z.jpg'),
(119161, 8543, 'Ilhados com a Sogra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ie0Ju9a48wSkyQTEclUm06qrFnZ.jpg'),
(119162, 8543, 'Ilhados com a Sogra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u3RIdVy4PGvgAeTRMLtfT9k77Y3.jpg'),
(119163, 8543, 'Ilhados com a Sogra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hmBtviJUfnWE3xAMHZxLeyMcsQ1.jpg'),
(119164, 8543, 'Ilhados com a Sogra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9AlAE86arul1mcJRWXeUUDYjGQ.jpg'),
(119165, 8543, 'Ilhados com a Sogra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/stfypoxAkG6gXU4fySq20fnbKqJ.jpg'),
(119166, 8543, 'Ilhados com a Sogra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/stfypoxAkG6gXU4fySq20fnbKqJ.jpg'),
(119167, 8543, 'Ilhados com a Sogra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/stfypoxAkG6gXU4fySq20fnbKqJ.jpg'),
(119168, 8543, 'Ilhados com a Sogra S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/stfypoxAkG6gXU4fySq20fnbKqJ.jpg'),
(119169, 8544, 'Ilhados com a Sogra S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/659152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/stfypoxAkG6gXU4fySq20fnbKqJ.jpg'),
(119170, 8544, 'Ilhados com a Sogra S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/659153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/stfypoxAkG6gXU4fySq20fnbKqJ.jpg'),
(119171, 8544, 'Ilhados com a Sogra S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/659154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/stfypoxAkG6gXU4fySq20fnbKqJ.jpg'),
(119172, 8544, 'Ilhados com a Sogra S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/659155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/stfypoxAkG6gXU4fySq20fnbKqJ.jpg'),
(119173, 8544, 'Ilhados com a Sogra S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/662267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/stfypoxAkG6gXU4fySq20fnbKqJ.jpg'),
(119174, 8544, 'Ilhados com a Sogra S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/662268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/stfypoxAkG6gXU4fySq20fnbKqJ.jpg'),
(119175, 8544, 'Ilhados com a Sogra S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/662269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/stfypoxAkG6gXU4fySq20fnbKqJ.jpg'),
(119176, 8544, 'Ilhados com a Sogra S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/662270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/stfypoxAkG6gXU4fySq20fnbKqJ.jpg'),
(119177, 8545, 'Ilhados com a Sogra S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/894902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/stfypoxAkG6gXU4fySq20fnbKqJ.jpg'),
(119178, 8545, 'Ilhados com a Sogra S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/894903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/stfypoxAkG6gXU4fySq20fnbKqJ.jpg'),
(119179, 8545, 'Ilhados com a Sogra S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/894904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/stfypoxAkG6gXU4fySq20fnbKqJ.jpg'),
(119180, 8545, 'Ilhados com a Sogra S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/894905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/stfypoxAkG6gXU4fySq20fnbKqJ.jpg'),
(119181, 8545, 'Ilhados com a Sogra S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/895878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/stfypoxAkG6gXU4fySq20fnbKqJ.jpg'),
(119182, 8545, 'Ilhados com a Sogra S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/895879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/stfypoxAkG6gXU4fySq20fnbKqJ.jpg'),
(119183, 8545, 'Ilhados com a Sogra S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/895880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/stfypoxAkG6gXU4fySq20fnbKqJ.jpg'),
(119184, 8545, 'Ilhados com a Sogra S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/895881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/stfypoxAkG6gXU4fySq20fnbKqJ.jpg'),
(119185, 8546, 'Leandro e Leonardo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCirtTlyqS2Yn3HXmdLjvgkpN1.jpg'),
(119186, 8546, 'Leandro e Leonardo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCirtTlyqS2Yn3HXmdLjvgkpN1.jpg'),
(119187, 8546, 'Leandro e Leonardo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCirtTlyqS2Yn3HXmdLjvgkpN1.jpg'),
(119188, 8546, 'Leandro e Leonardo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCirtTlyqS2Yn3HXmdLjvgkpN1.jpg'),
(119189, 8546, 'Leandro e Leonardo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCirtTlyqS2Yn3HXmdLjvgkpN1.jpg'),
(119190, 8546, 'Leandro e Leonardo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCirtTlyqS2Yn3HXmdLjvgkpN1.jpg'),
(119191, 8546, 'Leandro e Leonardo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCirtTlyqS2Yn3HXmdLjvgkpN1.jpg'),
(119192, 8546, 'Leandro e Leonardo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCirtTlyqS2Yn3HXmdLjvgkpN1.jpg'),
(119193, 8546, 'Leandro e Leonardo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipCirtTlyqS2Yn3HXmdLjvgkpN1.jpg'),
(119194, 8547, 'O Faz Nada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wuvE5mULOLK6psvRf8I1UT0SpTf.jpg'),
(119195, 8547, 'O Faz Nada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4V7H7y7UDGS4ZlDga6yTzUH9SEl.jpg'),
(119196, 8547, 'O Faz Nada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/am1MdURPyo9HTOrtqmF79CNjeYF.jpg'),
(119197, 8547, 'O Faz Nada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a9iZO7eGtNZdlXFeAxeFWZUxILn.jpg'),
(119198, 8547, 'O Faz Nada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bFT73TQH8hg3ioSJgc8kZCcPBIQ.jpg'),
(119199, 8548, 'O Portal do Ollie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Rzi0XieFeuMu7aW6GTcyHFIh1E.jpg'),
(119200, 8548, 'O Portal do Ollie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/906HKkSRKZIb71f8l6g8gzcUPr9.jpg'),
(119201, 8548, 'O Portal do Ollie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y51hPI3hQmSSjTVr2z3Y1WxUhZv.jpg'),
(119202, 8548, 'O Portal do Ollie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4o5CKKFggL1Ba0J7u7pbiPvMO6c.jpg'),
(119203, 8548, 'O Portal do Ollie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vHVIL1zKmB2qY2TqcuaxwUFqdqO.jpg'),
(119204, 8548, 'O Portal do Ollie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sHAYoKL4ftUYZ2rqKaLAUvMeM6f.jpg'),
(119205, 8548, 'O Portal do Ollie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vHVIL1zKmB2qY2TqcuaxwUFqdqO.jpg'),
(119206, 8548, 'O Portal do Ollie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lHBvfJazzcxUX9UndheZvBXFMxk.jpg'),
(119207, 8548, 'O Portal do Ollie S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vHVIL1zKmB2qY2TqcuaxwUFqdqO.jpg'),
(119208, 8548, 'O Portal do Ollie S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vHVIL1zKmB2qY2TqcuaxwUFqdqO.jpg'),
(119209, 8548, 'O Portal do Ollie S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/242010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nF8pBd9Rbefn8UAjpP5LQxHrjw.jpg'),
(119210, 8548, 'O Portal do Ollie S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/242011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJcV8H8L0TCtlBGZtjdW2cFu7q2.jpg'),
(119211, 8548, 'O Portal do Ollie S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/242012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vHVIL1zKmB2qY2TqcuaxwUFqdqO.jpg'),
(119212, 8548, 'O Portal do Ollie S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/242013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5AVTvwndLu5wr49zm4euUPGYeBU.jpg'),
(119213, 8548, 'O Portal do Ollie S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/242014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vHVIL1zKmB2qY2TqcuaxwUFqdqO.jpg'),
(119214, 8548, 'O Portal do Ollie S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/242015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vHVIL1zKmB2qY2TqcuaxwUFqdqO.jpg'),
(119215, 8548, 'O Portal do Ollie S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/242016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/er2gWsONRy4CGi2gbF1LB3wqekQ.jpg'),
(119216, 8548, 'O Portal do Ollie S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/242017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cQk9oMYKpLe3paCS54woeOvejrT.jpg'),
(119217, 8548, 'O Portal do Ollie S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/242018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vHVIL1zKmB2qY2TqcuaxwUFqdqO.jpg'),
(119218, 8548, 'O Portal do Ollie S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/242019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vHVIL1zKmB2qY2TqcuaxwUFqdqO.jpg'),
(119219, 8548, 'O Portal do Ollie S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/242020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xbaLjNglcu0oDlX8OqldlvQyXT2.jpg'),
(119220, 8548, 'O Portal do Ollie S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/242021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6MTQZXRUkHpdD7b2iwXqLWsXl08.jpg'),
(119221, 8548, 'O Portal do Ollie S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/242022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vHVIL1zKmB2qY2TqcuaxwUFqdqO.jpg'),
(119222, 8548, 'O Portal do Ollie S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/242023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u5u4c9R3NSc9nyYE8mUarUjxprh.jpg'),
(119223, 8548, 'O Portal do Ollie S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/242024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vHVIL1zKmB2qY2TqcuaxwUFqdqO.jpg'),
(119224, 8548, 'O Portal do Ollie S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/242025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/34KpYV90G3CGVpDh75Y9dVHJqHu.jpg'),
(119225, 8549, 'Pacto de Silencio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iKlApshlU1F9vgEBQZIXdUVy5p.jpg'),
(119226, 8549, 'Pacto de Silencio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iKlApshlU1F9vgEBQZIXdUVy5p.jpg'),
(119227, 8549, 'Pacto de Silencio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iKlApshlU1F9vgEBQZIXdUVy5p.jpg'),
(119228, 8549, 'Pacto de Silencio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iKlApshlU1F9vgEBQZIXdUVy5p.jpg'),
(119229, 8549, 'Pacto de Silencio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iKlApshlU1F9vgEBQZIXdUVy5p.jpg'),
(119230, 8549, 'Pacto de Silencio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iKlApshlU1F9vgEBQZIXdUVy5p.jpg'),
(119231, 8549, 'Pacto de Silencio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iKlApshlU1F9vgEBQZIXdUVy5p.jpg'),
(119232, 8549, 'Pacto de Silencio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iKlApshlU1F9vgEBQZIXdUVy5p.jpg'),
(119233, 8549, 'Pacto de Silencio S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iKlApshlU1F9vgEBQZIXdUVy5p.jpg'),
(119234, 8549, 'Pacto de Silencio S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iKlApshlU1F9vgEBQZIXdUVy5p.jpg'),
(119235, 8549, 'Pacto de Silencio S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iKlApshlU1F9vgEBQZIXdUVy5p.jpg'),
(119236, 8549, 'Pacto de Silencio S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iKlApshlU1F9vgEBQZIXdUVy5p.jpg'),
(119237, 8549, 'Pacto de Silencio S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iKlApshlU1F9vgEBQZIXdUVy5p.jpg'),
(119238, 8549, 'Pacto de Silencio S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iKlApshlU1F9vgEBQZIXdUVy5p.jpg'),
(119239, 8549, 'Pacto de Silencio S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iKlApshlU1F9vgEBQZIXdUVy5p.jpg'),
(119240, 8549, 'Pacto de Silencio S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/241997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iKlApshlU1F9vgEBQZIXdUVy5p.jpg'),
(119241, 8549, 'Pacto de Silencio S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/241998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iKlApshlU1F9vgEBQZIXdUVy5p.jpg'),
(119242, 8549, 'Pacto de Silencio S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/241999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iKlApshlU1F9vgEBQZIXdUVy5p.jpg'),
(119243, 8550, 'Romina Poderosa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119244, 8550, 'Romina Poderosa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119245, 8550, 'Romina Poderosa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119246, 8550, 'Romina Poderosa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119247, 8550, 'Romina Poderosa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119248, 8550, 'Romina Poderosa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119249, 8550, 'Romina Poderosa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119250, 8550, 'Romina Poderosa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119251, 8550, 'Romina Poderosa S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119252, 8550, 'Romina Poderosa S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119253, 8550, 'Romina Poderosa S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119254, 8550, 'Romina Poderosa S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119255, 8550, 'Romina Poderosa S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119256, 8550, 'Romina Poderosa S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119257, 8550, 'Romina Poderosa S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119258, 8550, 'Romina Poderosa S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/241932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119259, 8550, 'Romina Poderosa S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/241933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119260, 8550, 'Romina Poderosa S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/241934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119261, 8550, 'Romina Poderosa S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/241935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119262, 8550, 'Romina Poderosa S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/241936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119263, 8550, 'Romina Poderosa S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/241937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119264, 8550, 'Romina Poderosa S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/241938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119265, 8550, 'Romina Poderosa S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/241939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119266, 8550, 'Romina Poderosa S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/241940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119267, 8550, 'Romina Poderosa S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/241941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119268, 8550, 'Romina Poderosa S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/241942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119269, 8550, 'Romina Poderosa S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/241943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119270, 8550, 'Romina Poderosa S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/241944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119271, 8550, 'Romina Poderosa S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/241945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119272, 8550, 'Romina Poderosa S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/241946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119273, 8550, 'Romina Poderosa S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/241947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119274, 8550, 'Romina Poderosa S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/241948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119275, 8550, 'Romina Poderosa S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/241949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119276, 8550, 'Romina Poderosa S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/241950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119277, 8550, 'Romina Poderosa S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/241951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119278, 8550, 'Romina Poderosa S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/241952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119279, 8550, 'Romina Poderosa S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/241953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119280, 8550, 'Romina Poderosa S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/241954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119281, 8550, 'Romina Poderosa S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/241955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119282, 8550, 'Romina Poderosa S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/241956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119283, 8550, 'Romina Poderosa S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/241957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119284, 8550, 'Romina Poderosa S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/241958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119285, 8550, 'Romina Poderosa S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/241959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119286, 8550, 'Romina Poderosa S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/241960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119287, 8550, 'Romina Poderosa S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/241961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119288, 8550, 'Romina Poderosa S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/241962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119289, 8550, 'Romina Poderosa S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/241963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119290, 8550, 'Romina Poderosa S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/241964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119291, 8550, 'Romina Poderosa S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/241965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119292, 8550, 'Romina Poderosa S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/241966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119293, 8550, 'Romina Poderosa S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/241967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119294, 8550, 'Romina Poderosa S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/241968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119295, 8550, 'Romina Poderosa S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/241969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119296, 8550, 'Romina Poderosa S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/241970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119297, 8550, 'Romina Poderosa S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/241971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119298, 8550, 'Romina Poderosa S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/241972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119299, 8550, 'Romina Poderosa S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/241973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119300, 8550, 'Romina Poderosa S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/241974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119301, 8550, 'Romina Poderosa S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/241975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119302, 8550, 'Romina Poderosa S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/241976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119303, 8550, 'Romina Poderosa S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/241977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119304, 8550, 'Romina Poderosa S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/241978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119305, 8550, 'Romina Poderosa S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/241979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119306, 8550, 'Romina Poderosa S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/241980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119307, 8550, 'Romina Poderosa S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/241981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1fR7YoXWphEbaQFeZZ34g2BGd.jpg'),
(119308, 8551, 'Stella Models S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f8lTfilkExsq294HCLu5juVCjTl.jpg'),
(119309, 8551, 'Stella Models S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f8lTfilkExsq294HCLu5juVCjTl.jpg'),
(119310, 8551, 'Stella Models S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f8lTfilkExsq294HCLu5juVCjTl.jpg'),
(119311, 8551, 'Stella Models S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f8lTfilkExsq294HCLu5juVCjTl.jpg'),
(119312, 8551, 'Stella Models S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f8lTfilkExsq294HCLu5juVCjTl.jpg'),
(119313, 8551, 'Stella Models S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f8lTfilkExsq294HCLu5juVCjTl.jpg'),
(119314, 8551, 'Stella Models S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f8lTfilkExsq294HCLu5juVCjTl.jpg'),
(119315, 8551, 'Stella Models S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f8lTfilkExsq294HCLu5juVCjTl.jpg'),
(119316, 8551, 'Stella Models S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f8lTfilkExsq294HCLu5juVCjTl.jpg'),
(119317, 8551, 'Stella Models S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f8lTfilkExsq294HCLu5juVCjTl.jpg'),
(119318, 8552, 'The Loud House Uma Verdadeira Familia Barulhenta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kYgn1YmLc4WmdF5L7O18y2BRxvD.jpg'),
(119319, 8552, 'The Loud House Uma Verdadeira Familia Barulhenta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l7kNSrVjxWUtYJ2q2fbasbh2DOL.jpg'),
(119320, 8552, 'The Loud House Uma Verdadeira Familia Barulhenta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5UeSnsNoXTgtBAxKgStVH0S5IWs.jpg'),
(119321, 8552, 'The Loud House Uma Verdadeira Familia Barulhenta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Ks6Q9QQZKuzHWg7Tye7mLOidsu.jpg'),
(119322, 8552, 'The Loud House Uma Verdadeira Familia Barulhenta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kpHv9cK10IzkZaowdyevryQxQ6t.jpg'),
(119323, 8552, 'The Loud House Uma Verdadeira Familia Barulhenta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iFQXXJTnaQY7MwDqZ9i2quNmUHX.jpg'),
(119324, 8552, 'The Loud House Uma Verdadeira Familia Barulhenta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ZIXSNgrJ2svGNuuN6cOp2sk71g.jpg'),
(119325, 8552, 'The Loud House Uma Verdadeira Familia Barulhenta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tTX1KRCFN9JCyoTuTOeJkXwHTZc.jpg'),
(119326, 8552, 'The Loud House Uma Verdadeira Familia Barulhenta S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBVd36owsdvcJVTwW1HYxOA23Dv.jpg'),
(119327, 8552, 'The Loud House Uma Verdadeira Familia Barulhenta S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2Ue8C0ik1gKxAZ9Iu7aEowYEUw.jpg'),
(119328, 8553, 'Travessuras da Menina Ma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ulUgZcDgy8MKl3tM8QJEP6TVPv4.jpg'),
(119329, 8553, 'Travessuras da Menina Ma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jnqLy86mGb5Px7Q2r8Ykr8dAk5D.jpg'),
(119330, 8553, 'Travessuras da Menina Ma S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pRZBIcG0xuk1F6a4VWevIbUWuAu.jpg'),
(119331, 8553, 'Travessuras da Menina Ma S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rilb08K0Zeu1X793r2PtMeuzxY2.jpg'),
(119332, 8553, 'Travessuras da Menina Ma S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Z6ODZxS2wEb4X1lJFp9XlEmOd4.jpg'),
(119333, 8553, 'Travessuras da Menina Ma S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uYXnoKk7tDPHwApbYudCM12loP.jpg'),
(119334, 8553, 'Travessuras da Menina Ma S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uYXnoKk7tDPHwApbYudCM12loP.jpg'),
(119335, 8553, 'Travessuras da Menina Ma S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uYXnoKk7tDPHwApbYudCM12loP.jpg'),
(119336, 8553, 'Travessuras da Menina Ma S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uYXnoKk7tDPHwApbYudCM12loP.jpg'),
(119337, 8553, 'Travessuras da Menina Ma S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uYXnoKk7tDPHwApbYudCM12loP.jpg'),
(119338, 8554, 'Travessuras da Menina Ma S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/771496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uYXnoKk7tDPHwApbYudCM12loP.jpg'),
(119339, 8554, 'Travessuras da Menina Ma S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/771497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uYXnoKk7tDPHwApbYudCM12loP.jpg'),
(119340, 8554, 'Travessuras da Menina Ma S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/771498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uYXnoKk7tDPHwApbYudCM12loP.jpg'),
(119341, 8554, 'Travessuras da Menina Ma S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/771499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uYXnoKk7tDPHwApbYudCM12loP.jpg'),
(119342, 8554, 'Travessuras da Menina Ma S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/771500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uYXnoKk7tDPHwApbYudCM12loP.jpg'),
(119343, 8554, 'Travessuras da Menina Ma S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/771501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uYXnoKk7tDPHwApbYudCM12loP.jpg'),
(119344, 8554, 'Travessuras da Menina Ma S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/771502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uYXnoKk7tDPHwApbYudCM12loP.jpg'),
(119345, 8554, 'Travessuras da Menina Ma S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/771503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uYXnoKk7tDPHwApbYudCM12loP.jpg'),
(119346, 8554, 'Travessuras da Menina Ma S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/771504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uYXnoKk7tDPHwApbYudCM12loP.jpg'),
(119347, 8554, 'Travessuras da Menina Ma S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/771505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4uYXnoKk7tDPHwApbYudCM12loP.jpg'),
(119348, 8555, 'Alphonse S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ipAwrLjSpUArYjDL5BP7Thr5BrY.jpg'),
(119349, 8555, 'Alphonse S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wtOsSjYkcyJGlUAuTPBZ2cJZ3Xv.jpg'),
(119350, 8555, 'Alphonse S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vkU93IANCyWSDEnL8cpTIXEYleO.jpg'),
(119351, 8555, 'Alphonse S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/68jWgFipSRPeJkJxzqO51gZ4KYc.jpg'),
(119352, 8555, 'Alphonse S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/68jWgFipSRPeJkJxzqO51gZ4KYc.jpg'),
(119353, 8555, 'Alphonse S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/68jWgFipSRPeJkJxzqO51gZ4KYc.jpg'),
(119354, 8556, 'Assim Como a Gente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfY44rhTvb69WCCbuMtMtlnAQry.jpg'),
(119355, 8556, 'Assim Como a Gente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfY44rhTvb69WCCbuMtMtlnAQry.jpg'),
(119356, 8556, 'Assim Como a Gente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfY44rhTvb69WCCbuMtMtlnAQry.jpg'),
(119357, 8556, 'Assim Como a Gente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfY44rhTvb69WCCbuMtMtlnAQry.jpg'),
(119358, 8556, 'Assim Como a Gente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfY44rhTvb69WCCbuMtMtlnAQry.jpg'),
(119359, 8556, 'Assim Como a Gente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfY44rhTvb69WCCbuMtMtlnAQry.jpg'),
(119360, 8556, 'Assim Como a Gente S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfY44rhTvb69WCCbuMtMtlnAQry.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(119361, 8556, 'Assim Como a Gente S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfY44rhTvb69WCCbuMtMtlnAQry.jpg'),
(119362, 8556, 'Assim Como a Gente S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfY44rhTvb69WCCbuMtMtlnAQry.jpg'),
(119363, 8556, 'Assim Como a Gente S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfY44rhTvb69WCCbuMtMtlnAQry.jpg'),
(119364, 8557, 'Christina Boyer No Corredor da Morte [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tU6LkDROuHCSU3WeumJ4yGoOS7G.jpg'),
(119365, 8557, 'Christina Boyer No Corredor da Morte [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mI8efJ1zSUVEi7CisDaxaExdRkJ.jpg'),
(119366, 8557, 'Christina Boyer No Corredor da Morte [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9goXHm8llNotSCrLVCK0rdX7YyE.jpg'),
(119367, 8558, 'Farmacia Mundo Paralelo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sOLgXvJ0N2A2oqlT3saDN3XPyvb.jpg'),
(119368, 8558, 'Farmacia Mundo Paralelo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vmSRSt1QCrt2XSyPh03PvzhqJkS.jpg'),
(119369, 8558, 'Farmacia Mundo Paralelo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oSXy2nPHbKIkk9gt1AUcVOruzBJ.jpg'),
(119370, 8558, 'Farmacia Mundo Paralelo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8T6TOEaQL1knDbTOrQcLbobkYuW.jpg'),
(119371, 8558, 'Farmacia Mundo Paralelo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aNaidcZB8yJ2UUgKmTt1daPEFtH.jpg'),
(119372, 8558, 'Farmacia Mundo Paralelo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rKfWZvbeJklPG2q5bBUMBIol7Qy.jpg'),
(119373, 8558, 'Farmacia Mundo Paralelo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q2a39ej9AO6dREkKrpNunOJBigg.jpg'),
(119374, 8558, 'Farmacia Mundo Paralelo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v1WIqaY6tb46HvCLSON1laJaH0.jpg'),
(119375, 8558, 'Farmacia Mundo Paralelo [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wbCymWSzUEf0wDbJ36nPYUGTTxX.jpg'),
(119376, 8558, 'Farmacia Mundo Paralelo [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kTR3Z6Is9nXUOBMGwmvgSzqDtxa.jpg'),
(119377, 8558, 'Farmacia Mundo Paralelo [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbK3hJwmabaB5wM7597dC2UULfU.jpg'),
(119378, 8558, 'Farmacia Mundo Paralelo [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fFGDE3Y0q7Fd7tThHFRXKeoXeap.jpg'),
(119379, 6573, 'Frasier S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQAjtgjgb5VAQXJog1bZgY5cjL2.jpg'),
(119380, 6573, 'Frasier S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQAjtgjgb5VAQXJog1bZgY5cjL2.jpg'),
(119381, 6573, 'Frasier S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQAjtgjgb5VAQXJog1bZgY5cjL2.jpg'),
(119382, 6573, 'Frasier S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQAjtgjgb5VAQXJog1bZgY5cjL2.jpg'),
(119383, 6573, 'Frasier S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQAjtgjgb5VAQXJog1bZgY5cjL2.jpg'),
(119384, 6573, 'Frasier S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQAjtgjgb5VAQXJog1bZgY5cjL2.jpg'),
(119385, 6573, 'Frasier S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQAjtgjgb5VAQXJog1bZgY5cjL2.jpg'),
(119386, 6573, 'Frasier S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQAjtgjgb5VAQXJog1bZgY5cjL2.jpg'),
(119387, 6573, 'Frasier S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQAjtgjgb5VAQXJog1bZgY5cjL2.jpg'),
(119388, 6573, 'Frasier S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQAjtgjgb5VAQXJog1bZgY5cjL2.jpg'),
(119389, 6574, 'Frasier S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQAjtgjgb5VAQXJog1bZgY5cjL2.jpg'),
(119390, 6574, 'Frasier S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/637178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQAjtgjgb5VAQXJog1bZgY5cjL2.jpg'),
(119391, 6574, 'Frasier S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQAjtgjgb5VAQXJog1bZgY5cjL2.jpg'),
(119392, 6574, 'Frasier S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQAjtgjgb5VAQXJog1bZgY5cjL2.jpg'),
(119393, 6574, 'Frasier S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/637181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQAjtgjgb5VAQXJog1bZgY5cjL2.jpg'),
(119394, 6574, 'Frasier S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/637182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQAjtgjgb5VAQXJog1bZgY5cjL2.jpg'),
(119395, 6574, 'Frasier S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQAjtgjgb5VAQXJog1bZgY5cjL2.jpg'),
(119396, 6574, 'Frasier S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQAjtgjgb5VAQXJog1bZgY5cjL2.jpg'),
(119397, 6574, 'Frasier S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/637185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQAjtgjgb5VAQXJog1bZgY5cjL2.jpg'),
(119398, 6574, 'Frasier S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/637186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQAjtgjgb5VAQXJog1bZgY5cjL2.jpg'),
(119399, 8559, 'Goosebumps S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i0JWKJol7A3NKPlat8UAnDx18yS.jpg'),
(119400, 8559, 'Goosebumps S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wsMobRBvugr2mxxRpw2YF3SR3Li.jpg'),
(119401, 8559, 'Goosebumps S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cZ9xMaeYX3c003oohvbvOapLFBt.jpg'),
(119402, 8559, 'Goosebumps S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/khn0loSmNrFiir3NlbM10OqVEhf.jpg'),
(119403, 8559, 'Goosebumps S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/26DJr62b2V17jIFfdaHZsJSgSIC.jpg'),
(119404, 8559, 'Goosebumps S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rg1ryfupSUkecDcSKpdTN4ktnul.jpg'),
(119405, 8559, 'Goosebumps S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rg1ryfupSUkecDcSKpdTN4ktnul.jpg'),
(119406, 8559, 'Goosebumps S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rg1ryfupSUkecDcSKpdTN4ktnul.jpg'),
(119407, 8559, 'Goosebumps S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rg1ryfupSUkecDcSKpdTN4ktnul.jpg'),
(119408, 8559, 'Goosebumps S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rg1ryfupSUkecDcSKpdTN4ktnul.jpg'),
(119409, 8560, 'Goosebumps S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/662721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rg1ryfupSUkecDcSKpdTN4ktnul.jpg'),
(119410, 8560, 'Goosebumps S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/662722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rg1ryfupSUkecDcSKpdTN4ktnul.jpg'),
(119411, 8560, 'Goosebumps S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/662723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rg1ryfupSUkecDcSKpdTN4ktnul.jpg'),
(119412, 8560, 'Goosebumps S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/662724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rg1ryfupSUkecDcSKpdTN4ktnul.jpg'),
(119413, 8560, 'Goosebumps S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/662725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rg1ryfupSUkecDcSKpdTN4ktnul.jpg'),
(119414, 8560, 'Goosebumps S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/662726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rg1ryfupSUkecDcSKpdTN4ktnul.jpg'),
(119415, 8560, 'Goosebumps S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/662727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rg1ryfupSUkecDcSKpdTN4ktnul.jpg'),
(119416, 8560, 'Goosebumps S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/662728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rg1ryfupSUkecDcSKpdTN4ktnul.jpg'),
(119417, 8561, 'O Berserker da Gula [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cUh9q1tOgPqZXTQqYFaFvtmv2eA.jpg'),
(119418, 8561, 'O Berserker da Gula [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQjGf1Oei7s7Il0UigtRZc8njRR.jpg'),
(119419, 8561, 'O Berserker da Gula [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p5rtHwieByHo1NdzOxB3vtVJJnA.jpg'),
(119420, 8561, 'O Berserker da Gula [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p5rtHwieByHo1NdzOxB3vtVJJnA.jpg'),
(119421, 8561, 'O Berserker da Gula [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p5rtHwieByHo1NdzOxB3vtVJJnA.jpg'),
(119422, 8561, 'O Berserker da Gula [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p5rtHwieByHo1NdzOxB3vtVJJnA.jpg'),
(119423, 8561, 'O Berserker da Gula [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p5rtHwieByHo1NdzOxB3vtVJJnA.jpg'),
(119424, 8561, 'O Berserker da Gula [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p5rtHwieByHo1NdzOxB3vtVJJnA.jpg'),
(119425, 8561, 'O Berserker da Gula [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p5rtHwieByHo1NdzOxB3vtVJJnA.jpg'),
(119426, 8561, 'O Berserker da Gula [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p5rtHwieByHo1NdzOxB3vtVJJnA.jpg'),
(119427, 8561, 'O Berserker da Gula [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p5rtHwieByHo1NdzOxB3vtVJJnA.jpg'),
(119428, 8561, 'O Berserker da Gula [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p5rtHwieByHo1NdzOxB3vtVJJnA.jpg'),
(119429, 8562, 'O Grande Clerigo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/GOuWYm2VtyUI22eb8wrOJO96zu.jpg'),
(119430, 8562, 'O Grande Clerigo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ugPXEOXL27GKRvwwn4pFQYsp9EE.jpg'),
(119431, 8562, 'O Grande Clerigo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m1kuOEzJGph6Yy9BKHYGN2OGPo6.jpg'),
(119432, 8562, 'O Grande Clerigo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yhbI9BY54k6ivQojoKyVfbCMcc7.jpg'),
(119433, 8562, 'O Grande Clerigo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2J7wwfoZvV0oaNUlNRz9uBCUt5n.jpg'),
(119434, 8562, 'O Grande Clerigo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ai0XaK3BIykzwl99jfAgyZk6Ea.jpg'),
(119435, 8562, 'O Grande Clerigo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h9fEyyQcMHKilVvyasTvTLEvjq6.jpg'),
(119436, 8562, 'O Grande Clerigo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wPB1yUqhKPBZJ12SLCLVWoLCiKV.jpg'),
(119437, 8562, 'O Grande Clerigo [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tSjTaGp2rk5XlX1WvMKBFuXU1Vx.jpg'),
(119438, 8562, 'O Grande Clerigo [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oiwOXLMXUGt3jZve6Mcsh90YoO5.jpg'),
(119439, 8562, 'O Grande Clerigo [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJt3YuEDbtvZtqX0CNJXWmlLCxz.jpg'),
(119440, 8562, 'O Grande Clerigo [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5rA9DCgOyJcoLdUc1SnFjI0Jew2.jpg'),
(119441, 8563, 'Por que Waldemar Eis a questao do futebol brasileiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5cmv669K3YeQTESHE5HJfcQJnGS.jpg'),
(119442, 8563, 'Por que Waldemar Eis a questao do futebol brasileiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5cmv669K3YeQTESHE5HJfcQJnGS.jpg'),
(119443, 8563, 'Por que Waldemar Eis a questao do futebol brasileiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5cmv669K3YeQTESHE5HJfcQJnGS.jpg'),
(119444, 8564, 'Protocol Rain [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xCo2CTWazqFxcmBHczx5rtkugUN.jpg'),
(119445, 8564, 'Protocol Rain [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9PBJLzscl0LLfSaf1KvkE1lS1W6.jpg'),
(119446, 8564, 'Protocol Rain [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5DFnJmZWCTjuMO65g92iqIKuIxF.jpg'),
(119447, 8564, 'Protocol Rain [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5DFnJmZWCTjuMO65g92iqIKuIxF.jpg'),
(119448, 8564, 'Protocol Rain [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5DFnJmZWCTjuMO65g92iqIKuIxF.jpg'),
(119449, 8564, 'Protocol Rain [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5DFnJmZWCTjuMO65g92iqIKuIxF.jpg'),
(119450, 8564, 'Protocol Rain [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5DFnJmZWCTjuMO65g92iqIKuIxF.jpg'),
(119451, 8564, 'Protocol Rain [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5DFnJmZWCTjuMO65g92iqIKuIxF.jpg'),
(119452, 8564, 'Protocol Rain [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5DFnJmZWCTjuMO65g92iqIKuIxF.jpg'),
(119453, 8564, 'Protocol Rain [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5DFnJmZWCTjuMO65g92iqIKuIxF.jpg'),
(119454, 8564, 'Protocol Rain [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5DFnJmZWCTjuMO65g92iqIKuIxF.jpg'),
(119455, 8564, 'Protocol Rain [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5DFnJmZWCTjuMO65g92iqIKuIxF.jpg'),
(119456, 8565, 'Shadowverse Flame [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xPHisHSsCiiRLqWi3LzNgAC8JRU.jpg'),
(119457, 8565, 'Shadowverse Flame [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3dCqLgRaXj4R2ntRmJClSG1v6AL.jpg'),
(119458, 8565, 'Shadowverse Flame [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/elYe7Qb82fxl6sYWttOLLXqo8la.jpg'),
(119459, 8565, 'Shadowverse Flame [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5w9yUGn62ZKiJHb3jZppAbrroAq.jpg'),
(119460, 8565, 'Shadowverse Flame [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oSC1nopQfJKGttEk7YrxGyZAxVR.jpg'),
(119461, 8565, 'Shadowverse Flame [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wvGaiLvo7P109SonKJIZTNwKhOt.jpg'),
(119462, 8565, 'Shadowverse Flame [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zTk4tN1BGoSu65tKdzZcP8z4lMg.jpg'),
(119463, 8565, 'Shadowverse Flame [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j99qlEn74ivUn9JPGx3eO7kmVOM.jpg'),
(119464, 8565, 'Shadowverse Flame [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQb90ZZI2qOUglOUG1Ax55RZ8cH.jpg'),
(119465, 8565, 'Shadowverse Flame [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/26GgCUla8atbhWJfTiGJCyNDn53.jpg'),
(119466, 8565, 'Shadowverse Flame [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gVK2yOGyQijmXYcI9YxY0UQvLDK.jpg'),
(119467, 8565, 'Shadowverse Flame [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4rYqolfCXe6MflYviQgSQsT6tf2.jpg'),
(119468, 8565, 'Shadowverse Flame [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7wQxYOzUuYVDBlaEBqXQAQ7lIqu.jpg'),
(119469, 8565, 'Shadowverse Flame [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kS2IypSq7irPB0y37AtRJzp4dso.jpg'),
(119470, 8565, 'Shadowverse Flame [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zODlMHwh1HEVXLLHkoRnPO43Bii.jpg'),
(119471, 8565, 'Shadowverse Flame [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/voNmX44fkyh8SPaPwdDepcm0c6L.jpg'),
(119472, 8565, 'Shadowverse Flame [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/256813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hrHB927L4XYEjjXSPtBYMRB3g2M.jpg'),
(119473, 8565, 'Shadowverse Flame [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/256814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzimxcor9pXS7rqogNf1iHsip3S.jpg'),
(119474, 8565, 'Shadowverse Flame [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/256815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6rdBUwzLZ1Xf81mS2r9FynzlCYH.jpg'),
(119475, 8565, 'Shadowverse Flame [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/256816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jeQ3iPt9BM4S8o6fvhju6ogNBd1.jpg'),
(119476, 8565, 'Shadowverse Flame [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/256817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dOl05Ztr8niZV5f6siknlS5QRBx.jpg'),
(119477, 8565, 'Shadowverse Flame [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/256818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bKBgZqKSuyt3DjBnw6SGZmTc5hg.jpg'),
(119478, 8565, 'Shadowverse Flame [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/256819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wYimvsWqtum8rvfeKXVzSJdkERL.jpg'),
(119479, 8565, 'Shadowverse Flame [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/256820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5vuUhDZZMbFz6sqhO3cnYnSgUIg.jpg'),
(119480, 8565, 'Shadowverse Flame [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/256821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5ZtRBdbQfrgjVWJeCi5RRbocrg.jpg'),
(119481, 8565, 'Shadowverse Flame [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/256822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rG8Hiwf4sZU7nfZNOty7uFWc1Rc.jpg'),
(119482, 8565, 'Shadowverse Flame [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/256823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qApMKbCNKcc4tFOUt6fkdAMsJrd.jpg'),
(119483, 8565, 'Shadowverse Flame [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/256824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNqXXvRBDxSoslKAcusWXEH8LC7.jpg'),
(119484, 8565, 'Shadowverse Flame [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/256825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j5yKHQ361RJIXR3j9bwjJrubjQm.jpg'),
(119485, 8565, 'Shadowverse Flame [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/256826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQSYGVZqDJKsHcSaFhruDzrd1iF.jpg'),
(119486, 8565, 'Shadowverse Flame [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/256827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tg813IstVoj7RAy9wLfmDkoaq5V.jpg'),
(119487, 8565, 'Shadowverse Flame [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/256828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oMoYeKg7apYxSfdFIlf0XgD6UhB.jpg'),
(119488, 8565, 'Shadowverse Flame [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/256829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/esTkjqmYJuVESUBhzGG2lnF3Lr7.jpg'),
(119489, 8565, 'Shadowverse Flame [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/256830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ghmbCbByFj9mucuFChoQl9T3ilN.jpg'),
(119490, 8565, 'Shadowverse Flame [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/256831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cd9r22ME09eEMu1TuVWvyveJbV2.jpg'),
(119491, 8565, 'Shadowverse Flame [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/256832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rBQvfNEkJUB55QL28Tcmjv0rtxx.jpg'),
(119492, 8565, 'Shadowverse Flame [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/256833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1yD3DBJyDtA53ErjD6trJ57IBen.jpg'),
(119493, 8565, 'Shadowverse Flame [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/256834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2nPDPEKUbRhDrf9SHZbI1Ii5tZw.jpg'),
(119494, 8565, 'Shadowverse Flame [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/256835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6hN75dT4RK63j3mc1BN0NUaVLMI.jpg'),
(119495, 8565, 'Shadowverse Flame [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/256836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m8aKz0sMeykVDreO4RvvYdtmOGp.jpg'),
(119496, 8565, 'Shadowverse Flame [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/256837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7KtzV5pAlNvQT4jnUauLiEuYYkD.jpg'),
(119497, 8565, 'Shadowverse Flame [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/256838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/647J5ryJyRfEMlUEdVw8XxLK3Mv.jpg'),
(119498, 8565, 'Shadowverse Flame [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/256839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v5YJRlfQUSWbc5s6Gfp4wmoPNm3.jpg'),
(119499, 8565, 'Shadowverse Flame [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/256840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2JzDCZurgZyLKsMXBC89W8Qbmlr.jpg'),
(119500, 8565, 'Shadowverse Flame [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/256841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3eWUt2UtrWeKp6haoINS04U4zuR.jpg'),
(119501, 8565, 'Shadowverse Flame [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/256842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nwoHR9CNxyKE1IFATxPEcKCBbHQ.jpg'),
(119502, 8565, 'Shadowverse Flame [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/256843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dKG83guua63UQV0HjtqEYZGtiij.jpg'),
(119503, 8565, 'Shadowverse Flame [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/256844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yPYTYUdcC8GBy9JCXHnATksBVv7.jpg'),
(119504, 8565, 'Shadowverse Flame [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/256845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3IqEKQivVdKN1UD1AtDYKmzGF6d.jpg'),
(119505, 8565, 'Shadowverse Flame [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/256846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSNwJFbvLBXAXbUvuQSgWRf7tBr.jpg'),
(119506, 8565, 'Shadowverse Flame [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/256847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8wZfjAHo25OiuQIZIiKkB9FcGXV.jpg'),
(119507, 8565, 'Shadowverse Flame [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/256848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ssMlcB2R4PhxqzJ0pRihQWer2p0.jpg'),
(119508, 8565, 'Shadowverse Flame [L] S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/256849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qYqswPY74P9jFQwPuj8P8gTFJeH.jpg'),
(119509, 8565, 'Shadowverse Flame [L] S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/256850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nIseiHpSNJcbkzT7bJ8qaWrhVrg.jpg'),
(119510, 8565, 'Shadowverse Flame [L] S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/256851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hCLaHC2V8FpZvWKH5ZLT4rkah2N.jpg'),
(119511, 8565, 'Shadowverse Flame [L] S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/256852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yaAOfyZmKysPGTymRqT0Sf2urHf.jpg'),
(119512, 8565, 'Shadowverse Flame [L] S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/256853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uLFWzykuJKMReiYYogIzLzwbZmO.jpg'),
(119513, 8565, 'Shadowverse Flame [L] S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/256854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1UX8tVnfFSB4ecqGcfLsUs5fGvj.jpg'),
(119514, 8565, 'Shadowverse Flame [L] S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/256855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qVXu9fwHaRbnxzoGZBMmMUZ8JHg.jpg'),
(119515, 8565, 'Shadowverse Flame [L] S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/256856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqwcxnaaqqsfyGmknELPhMJwHRJ.jpg'),
(119516, 8565, 'Shadowverse Flame [L] S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/256857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mJ5d3COq80BUPjXTxa7GSTR3bxK.jpg'),
(119517, 8565, 'Shadowverse Flame [L] S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/256858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nvkvQQ6Im6QamgYNyUlBidal4Zq.jpg'),
(119518, 8565, 'Shadowverse Flame [L] S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/256859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zy1dUkUe6yZYo3ZwRzkwQwzacVX.jpg'),
(119519, 8565, 'Shadowverse Flame [L] S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/256860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zX5D5oBPauAwPNi45jC4rs5P4me.jpg'),
(119520, 8565, 'Shadowverse Flame [L] S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/256861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzimxcor9pXS7rqogNf1iHsip3S.jpg'),
(119521, 8565, 'Shadowverse Flame [L] S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/256862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzimxcor9pXS7rqogNf1iHsip3S.jpg'),
(119522, 8565, 'Shadowverse Flame [L] S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/256863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzimxcor9pXS7rqogNf1iHsip3S.jpg'),
(119523, 8565, 'Shadowverse Flame [L] S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/256864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzimxcor9pXS7rqogNf1iHsip3S.jpg'),
(119524, 8565, 'Shadowverse Flame [L] S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/256865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzimxcor9pXS7rqogNf1iHsip3S.jpg'),
(119525, 8565, 'Shadowverse Flame [L] S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/256866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzimxcor9pXS7rqogNf1iHsip3S.jpg'),
(119526, 8565, 'Shadowverse Flame [L] S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/256867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzimxcor9pXS7rqogNf1iHsip3S.jpg'),
(119527, 8565, 'Shadowverse Flame [L] S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/256868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzimxcor9pXS7rqogNf1iHsip3S.jpg'),
(119528, 8565, 'Shadowverse Flame [L] S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/256869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzimxcor9pXS7rqogNf1iHsip3S.jpg'),
(119529, 8565, 'Shadowverse Flame [L] S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/256870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzimxcor9pXS7rqogNf1iHsip3S.jpg'),
(119530, 8565, 'Shadowverse Flame [L] S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/256871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzimxcor9pXS7rqogNf1iHsip3S.jpg'),
(119531, 8566, 'Shadowverse Flame [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzimxcor9pXS7rqogNf1iHsip3S.jpg'),
(119532, 8566, 'Shadowverse Flame [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fzimxcor9pXS7rqogNf1iHsip3S.jpg'),
(119533, 8567, 'Shangri La Frontier [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cwOMKeIPzHO8Op8FezrL3oOHaDT.jpg'),
(119534, 8567, 'Shangri La Frontier [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8qU5suic2xgx54CscaQnEGJw0CU.jpg'),
(119535, 8567, 'Shangri La Frontier [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119536, 8567, 'Shangri La Frontier [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119537, 8567, 'Shangri La Frontier [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119538, 8567, 'Shangri La Frontier [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119539, 8567, 'Shangri La Frontier [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119540, 8567, 'Shangri La Frontier [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119541, 8567, 'Shangri La Frontier [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119542, 8567, 'Shangri La Frontier [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119543, 8567, 'Shangri La Frontier [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119544, 8567, 'Shangri La Frontier [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119545, 8567, 'Shangri La Frontier [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119546, 8567, 'Shangri La Frontier [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119547, 8567, 'Shangri La Frontier [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119548, 8567, 'Shangri La Frontier [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119549, 8567, 'Shangri La Frontier [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/272606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119550, 8567, 'Shangri La Frontier [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/272607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119551, 8567, 'Shangri La Frontier [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/275083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119552, 8567, 'Shangri La Frontier [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/282579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119553, 8567, 'Shangri La Frontier [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/290600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119554, 8567, 'Shangri La Frontier [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/297144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119555, 8567, 'Shangri La Frontier [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/301025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119556, 8567, 'Shangri La Frontier [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/307229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119557, 8567, 'Shangri La Frontier [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/313589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119558, 8568, 'Shangri La Frontier [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/633393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119559, 8568, 'Shangri La Frontier [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/633394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119560, 8568, 'Shangri La Frontier [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/633395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119561, 8568, 'Shangri La Frontier [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/633396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119562, 8568, 'Shangri La Frontier [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/633397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119563, 8568, 'Shangri La Frontier [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/633398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119564, 8568, 'Shangri La Frontier [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/633399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119565, 8568, 'Shangri La Frontier [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/633400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119566, 8568, 'Shangri La Frontier [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/517169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119567, 8568, 'Shangri La Frontier [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119568, 8568, 'Shangri La Frontier [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/637935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119569, 8568, 'Shangri La Frontier [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/657485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119570, 8568, 'Shangri La Frontier [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/657486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119571, 8568, 'Shangri La Frontier [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/660195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119572, 8568, 'Shangri La Frontier [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/669221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119573, 8568, 'Shangri La Frontier [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/674757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119574, 8568, 'Shangri La Frontier [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/688359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119575, 8568, 'Shangri La Frontier [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/699485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119576, 8568, 'Shangri La Frontier [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/704049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119577, 8568, 'Shangri La Frontier [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/715974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119578, 8568, 'Shangri La Frontier [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/720949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119579, 8568, 'Shangri La Frontier [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/728517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119580, 8568, 'Shangri La Frontier [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/737282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119581, 8568, 'Shangri La Frontier [L] S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/750271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/beg4GOY71HuaEdJ5yTR2ZXgf3mo.jpg'),
(119582, 8569, 'Todos Amam Diamantes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fWEJioa4u6iH9TjACtXnbGHOHFB.jpg'),
(119583, 8569, 'Todos Amam Diamantes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u4v8zzdUtDjOoflWI6VQ3Y9klgI.jpg'),
(119584, 8569, 'Todos Amam Diamantes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qsaSRitWh2NIeGC11vSL7EOSn03.jpg'),
(119585, 8569, 'Todos Amam Diamantes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ok1o4qTLYhWy0pdeJIMv8DprEqO.jpg'),
(119586, 8569, 'Todos Amam Diamantes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ixHtK45xx0GBL6ViXv87OKcAgWP.jpg'),
(119587, 8569, 'Todos Amam Diamantes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f3PCzk9c7YkBL5TxCw9RltBWesU.jpg'),
(119588, 8569, 'Todos Amam Diamantes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aq1TVqCYUhXxcrWRQjRs1e2p40R.jpg'),
(119589, 8569, 'Todos Amam Diamantes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4SyhA5rjCralizs0td01WPaHztJ.jpg'),
(119590, 8570, 'Uma Questao de Quimica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gEtMdmL6BL98fb21BhhxLIGzy1g.jpg'),
(119591, 8570, 'Uma Questao de Quimica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jztIPHYfJQoaDPN0RImKVzUGmdS.jpg'),
(119592, 8570, 'Uma Questao de Quimica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mt7qYZyzsTKOXXHF4q1dfEB9VHa.jpg'),
(119593, 8570, 'Uma Questao de Quimica S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mt7qYZyzsTKOXXHF4q1dfEB9VHa.jpg'),
(119594, 8570, 'Uma Questao de Quimica S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mt7qYZyzsTKOXXHF4q1dfEB9VHa.jpg'),
(119595, 8570, 'Uma Questao de Quimica S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mt7qYZyzsTKOXXHF4q1dfEB9VHa.jpg'),
(119596, 8570, 'Uma Questao de Quimica S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mt7qYZyzsTKOXXHF4q1dfEB9VHa.jpg'),
(119597, 8570, 'Uma Questao de Quimica S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mt7qYZyzsTKOXXHF4q1dfEB9VHa.jpg'),
(119598, 8571, 'Dali and the Cocky Prince [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mYcuRz9oMKQdvMoaqm3e3nBFbK5.jpg'),
(119599, 8571, 'Dali and the Cocky Prince [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ZYoiudKOF1MUK1S5DNjX20CzcQ.jpg'),
(119600, 8571, 'Dali and the Cocky Prince [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/35L0y6AiIN1pYThYVWmkzBeUwir.jpg'),
(119601, 8571, 'Dali and the Cocky Prince [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jMWU3anERDZpQwAb1yMfGcA57MD.jpg'),
(119602, 8571, 'Dali and the Cocky Prince [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3XnuiRUUxEZeegYrw255DOqyOas.jpg'),
(119603, 8571, 'Dali and the Cocky Prince [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wvHaiRZQLm2rFK24x8j9ileqi2D.jpg'),
(119604, 8571, 'Dali and the Cocky Prince [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2qRVcJrUTnWD5Wr1GU3tK0b05FI.jpg'),
(119605, 8571, 'Dali and the Cocky Prince [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nVjtfgcq9Vl6y2v7DNRfBaj38iV.jpg'),
(119606, 8571, 'Dali and the Cocky Prince [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUXgzb11UgYAkvGa5wr2c1A6qGG.jpg'),
(119607, 8571, 'Dali and the Cocky Prince [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ArMnDs5uUvejKSsHnxCgOxSj67T.jpg'),
(119608, 8571, 'Dali and the Cocky Prince [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fm0bmWYbnzsEuL2jTkVwTkXTY2r.jpg'),
(119609, 8571, 'Dali and the Cocky Prince [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AslDeO5Cp7K0jXJMAFE9HO6mcOV.jpg'),
(119610, 8571, 'Dali and the Cocky Prince [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xpc9EuqrFP5rhiDtBfDqIIkgKFt.jpg'),
(119611, 8571, 'Dali and the Cocky Prince [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fjCi6DxaeShI0raYRpKwO5SlbBS.jpg'),
(119612, 8571, 'Dali and the Cocky Prince [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Ty2jZY9HW1SnxbGkh1oZWj57FA.jpg'),
(119613, 8571, 'Dali and the Cocky Prince [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/241733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2eMjYfHeVEze2BcTSSNLaYFZ9jw.jpg'),
(119614, 8572, 'Joao Sem Deus A Queda de Abadiania S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVYQJMGtojQU6i4iNFsTOAoZ0N3.jpg'),
(119615, 8572, 'Joao Sem Deus A Queda de Abadiania S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ry0jY02K1zDZnd1o1p5r9C0eIcv.jpg'),
(119616, 8572, 'Joao Sem Deus A Queda de Abadiania S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/85IgODXLMVGOOGaNLGzdU5va738.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(119617, 8573, 'My Runway S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tCKwuuTZr5Yx8rTt1FWvQKDrXnw.jpg'),
(119618, 8573, 'My Runway S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tCKwuuTZr5Yx8rTt1FWvQKDrXnw.jpg'),
(119619, 8573, 'My Runway S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tCKwuuTZr5Yx8rTt1FWvQKDrXnw.jpg'),
(119620, 8573, 'My Runway S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tCKwuuTZr5Yx8rTt1FWvQKDrXnw.jpg'),
(119621, 8573, 'My Runway S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tCKwuuTZr5Yx8rTt1FWvQKDrXnw.jpg'),
(119622, 8573, 'My Runway S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tCKwuuTZr5Yx8rTt1FWvQKDrXnw.jpg'),
(119623, 8574, 'Nunca Diga Jamais com Jeff Jenkins S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfTpGPgs0iJcTLvWGayOfsA1aKU.jpg'),
(119624, 8574, 'Nunca Diga Jamais com Jeff Jenkins S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfTpGPgs0iJcTLvWGayOfsA1aKU.jpg'),
(119625, 8574, 'Nunca Diga Jamais com Jeff Jenkins S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfTpGPgs0iJcTLvWGayOfsA1aKU.jpg'),
(119626, 8574, 'Nunca Diga Jamais com Jeff Jenkins S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfTpGPgs0iJcTLvWGayOfsA1aKU.jpg'),
(119627, 8574, 'Nunca Diga Jamais com Jeff Jenkins S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfTpGPgs0iJcTLvWGayOfsA1aKU.jpg'),
(119628, 8574, 'Nunca Diga Jamais com Jeff Jenkins S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfTpGPgs0iJcTLvWGayOfsA1aKU.jpg'),
(119629, 8574, 'Nunca Diga Jamais com Jeff Jenkins S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfTpGPgs0iJcTLvWGayOfsA1aKU.jpg'),
(119630, 8574, 'Nunca Diga Jamais com Jeff Jenkins S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfTpGPgs0iJcTLvWGayOfsA1aKU.jpg'),
(119631, 8575, 'Oh My Baby [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b83as5tF30foMfQ4ujtcYd9z5A8.jpg'),
(119632, 8575, 'Oh My Baby [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQZ31mB7pZs0ehERBcKSLBYmEMp.jpg'),
(119633, 8575, 'Oh My Baby [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wMshUxjz8O85mkn3aMsCo4SECnH.jpg'),
(119634, 8575, 'Oh My Baby [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mzO5MR27ZT6skTJvGy2Dj6AR7SM.jpg'),
(119635, 8575, 'Oh My Baby [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/da4buG0yT7AKu7X6SaP398C1ZTl.jpg'),
(119636, 8575, 'Oh My Baby [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4FRD0qYurDuMKdEDPa3N8eu3hhH.jpg'),
(119637, 8575, 'Oh My Baby [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hASMw9BFrxSKPMF9njYUZoh2rSl.jpg'),
(119638, 8575, 'Oh My Baby [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oBp2xn03sArYzSHwiLfavqhRuXk.jpg'),
(119639, 8575, 'Oh My Baby [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s6brRKMnKwVA6sKKqde99nMxGPM.jpg'),
(119640, 8575, 'Oh My Baby [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fIoZ7DsmXtbl2l7hxzAJAYyUd7h.jpg'),
(119641, 8575, 'Oh My Baby [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iKwLGPSVD9cznTrssuXUtZ8rZk8.jpg'),
(119642, 8575, 'Oh My Baby [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/37483l4SDpcLhgapuyJATKONMg8.jpg'),
(119643, 8575, 'Oh My Baby [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c0daNHBXikiDCXZtICwRBMrtJ8E.jpg'),
(119644, 8575, 'Oh My Baby [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1SrMxipKumMxMG4zZBXAHfzhYVB.jpg'),
(119645, 8575, 'Oh My Baby [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tOJ7ujAueMOisJkAi0TPGwjhFcf.jpg'),
(119646, 8575, 'Oh My Baby [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/241700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sCGIFKm3zvnKWE2kP63ZVTKPefL.jpg'),
(119647, 8576, 'Sonhe Alto [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUY46RJjDpOjUY66wwULdidj15y.jpg'),
(119648, 8576, 'Sonhe Alto [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/avt19bmk4DU9q6w7heqbJyC7BNl.jpg'),
(119649, 8576, 'Sonhe Alto [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lEgRXWA5TlZK7Mk3N4cbC5D76ii.jpg'),
(119650, 8576, 'Sonhe Alto [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/git4nKKFbyFqPw7PdA1ShoVgpu5.jpg'),
(119651, 8576, 'Sonhe Alto [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6JWHkRAiMUBhWVAE6n5DcG5cf5r.jpg'),
(119652, 8576, 'Sonhe Alto [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yCXyZSfd4D2MUUtN2MER7ZUWD3T.jpg'),
(119653, 8576, 'Sonhe Alto [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kdtzi19vV4dz76vy6WGPrjGS8xj.jpg'),
(119654, 8576, 'Sonhe Alto [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cppvDuOHkKe2orFes6K3MMUlAdf.jpg'),
(119655, 8576, 'Sonhe Alto [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xpApdFOWph0KCu38bC79CaQ2JKn.jpg'),
(119656, 8576, 'Sonhe Alto [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3S4Dl6xwut4KVrpfuXNnzhmz4qf.jpg'),
(119657, 8576, 'Sonhe Alto [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r0iahNeXIZAQ0V5t7eBhp64MYr8.jpg'),
(119658, 8576, 'Sonhe Alto [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tAcVio2Wan56dQ7KNBJX1oct6vp.jpg'),
(119659, 8576, 'Sonhe Alto [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/njpKSXBPXvWIb5sY0FAvrkv5UW1.jpg'),
(119660, 8576, 'Sonhe Alto [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5UtE8LGXnUQcoZQdgxDrKbruuL7.jpg'),
(119661, 8576, 'Sonhe Alto [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t3f6KlwXoGh4Z2C5eq6jH4sFu3b.jpg'),
(119662, 8576, 'Sonhe Alto [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/241684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6dGni8zeAE6fpQFjsdbVnALs6vh.jpg'),
(119663, 8577, 'Carros Irado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119664, 8577, 'Carros Irado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119665, 8577, 'Carros Irado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119666, 8577, 'Carros Irado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119667, 8577, 'Carros Irado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119668, 8577, 'Carros Irado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119669, 8577, 'Carros Irado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119670, 8577, 'Carros Irado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119671, 8577, 'Carros Irado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119672, 8577, 'Carros Irado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119673, 8578, 'Carros Irado S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119674, 8578, 'Carros Irado S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119675, 8578, 'Carros Irado S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119676, 8578, 'Carros Irado S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119677, 8578, 'Carros Irado S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119678, 8578, 'Carros Irado S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119679, 8578, 'Carros Irado S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119680, 8578, 'Carros Irado S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119681, 8578, 'Carros Irado S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119682, 8578, 'Carros Irado S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119683, 8578, 'Carros Irado S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119684, 8578, 'Carros Irado S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119685, 8579, 'Carros Irado S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119686, 8579, 'Carros Irado S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119687, 8579, 'Carros Irado S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119688, 8579, 'Carros Irado S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119689, 8579, 'Carros Irado S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119690, 8579, 'Carros Irado S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119691, 8579, 'Carros Irado S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119692, 8579, 'Carros Irado S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119693, 8579, 'Carros Irado S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119694, 8579, 'Carros Irado S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119695, 8579, 'Carros Irado S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119696, 8579, 'Carros Irado S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119697, 8580, 'Carros Irado S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8GDYJe7BEfP8FYIJwBjEgkpkgwF.jpg'),
(119698, 8580, 'Carros Irado S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cTQTk97ZMb3Ra7RmSNj5V7buw7A.jpg'),
(119699, 8580, 'Carros Irado S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v2MaB3tXCE09WZUntHChPAuhuo6.jpg'),
(119700, 8580, 'Carros Irado S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lC3lUKAo9MOFO2iH95SY19Qhk8w.jpg'),
(119701, 8580, 'Carros Irado S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zdH4U1G5Z21kThdCcEOlPIt3QtJ.jpg'),
(119702, 8580, 'Carros Irado S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zZJqaP7XQ9tPv7yNunC38sbIgce.jpg'),
(119703, 8580, 'Carros Irado S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dULegez1OCCQZXmyzq7BFSNDDi.jpg'),
(119704, 8580, 'Carros Irado S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5SwKjDz7g2GO6PVkHnp8O6E6y30.jpg'),
(119705, 8580, 'Carros Irado S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nz2xRA7JDsRiBMXt8bBkLPmC0rP.jpg'),
(119706, 8580, 'Carros Irado S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y687qmvm0ZJRxWRtXfmVsv8Gsb1.jpg'),
(119707, 8580, 'Carros Irado S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qS43FNetDAXGa5fyb9gjxAvo8jM.jpg'),
(119708, 8580, 'Carros Irado S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119709, 8580, 'Carros Irado S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119710, 8580, 'Carros Irado S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119711, 8580, 'Carros Irado S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119712, 8580, 'Carros Irado S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119713, 8581, 'Carros Irado S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119714, 8581, 'Carros Irado S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119715, 8581, 'Carros Irado S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119716, 8581, 'Carros Irado S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119717, 8581, 'Carros Irado S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119718, 8581, 'Carros Irado S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119719, 8581, 'Carros Irado S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119720, 8581, 'Carros Irado S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119721, 8581, 'Carros Irado S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119722, 8581, 'Carros Irado S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119723, 8581, 'Carros Irado S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119724, 8581, 'Carros Irado S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119725, 8581, 'Carros Irado S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119726, 8581, 'Carros Irado S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119727, 8582, 'Carros Irado S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119728, 8582, 'Carros Irado S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119729, 8582, 'Carros Irado S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119730, 8582, 'Carros Irado S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119731, 8582, 'Carros Irado S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119732, 8582, 'Carros Irado S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119733, 8582, 'Carros Irado S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119734, 8582, 'Carros Irado S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119735, 8582, 'Carros Irado S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119736, 8582, 'Carros Irado S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119737, 8582, 'Carros Irado S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119738, 8582, 'Carros Irado S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119739, 8582, 'Carros Irado S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119740, 8582, 'Carros Irado S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119741, 8583, 'Carros Irado S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119742, 8583, 'Carros Irado S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119743, 8583, 'Carros Irado S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119744, 8583, 'Carros Irado S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119745, 8583, 'Carros Irado S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119746, 8583, 'Carros Irado S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119747, 8583, 'Carros Irado S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119748, 8583, 'Carros Irado S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119749, 8583, 'Carros Irado S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119750, 8583, 'Carros Irado S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119751, 8583, 'Carros Irado S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119752, 8583, 'Carros Irado S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119753, 8583, 'Carros Irado S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119754, 8583, 'Carros Irado S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119755, 8584, 'Carros Irado S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119756, 8584, 'Carros Irado S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119757, 8584, 'Carros Irado S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119758, 8584, 'Carros Irado S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119759, 8584, 'Carros Irado S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119760, 8584, 'Carros Irado S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119761, 8584, 'Carros Irado S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119762, 8584, 'Carros Irado S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119763, 8584, 'Carros Irado S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119764, 8584, 'Carros Irado S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119765, 8584, 'Carros Irado S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119766, 8584, 'Carros Irado S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119767, 8584, 'Carros Irado S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119768, 8584, 'Carros Irado S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/257000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119769, 8585, 'Carros Irado S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119770, 8585, 'Carros Irado S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119771, 8585, 'Carros Irado S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119772, 8585, 'Carros Irado S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119773, 8585, 'Carros Irado S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119774, 8585, 'Carros Irado S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119775, 8585, 'Carros Irado S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119776, 8585, 'Carros Irado S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119777, 8585, 'Carros Irado S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119778, 8585, 'Carros Irado S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119779, 8585, 'Carros Irado S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119780, 8585, 'Carros Irado S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119781, 8585, 'Carros Irado S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119782, 8585, 'Carros Irado S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/257014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119783, 8585, 'Carros Irado S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/257015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119784, 8585, 'Carros Irado S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/257016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119785, 8585, 'Carros Irado S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/257017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119786, 8585, 'Carros Irado S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/257018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119787, 8585, 'Carros Irado S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/257019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119788, 8585, 'Carros Irado S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/257020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wee7eFvWtSEQ4jadhz9l7caLE21.jpg'),
(119789, 8586, 'LEGO Masters S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/keXelWKyXGl8Ymr4a5gIb9HWbj4.jpg'),
(119790, 8586, 'LEGO Masters S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/afmsB1TF9iU2XOWJ4oYmlsv72kh.jpg'),
(119791, 8586, 'LEGO Masters S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cuRaXy34MGIxKa8VzG5QQcQUXp6.jpg'),
(119792, 8586, 'LEGO Masters S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cuRaXy34MGIxKa8VzG5QQcQUXp6.jpg'),
(119793, 8586, 'LEGO Masters S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cuRaXy34MGIxKa8VzG5QQcQUXp6.jpg'),
(119794, 8586, 'LEGO Masters S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cuRaXy34MGIxKa8VzG5QQcQUXp6.jpg'),
(119795, 8586, 'LEGO Masters S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cuRaXy34MGIxKa8VzG5QQcQUXp6.jpg'),
(119796, 8586, 'LEGO Masters S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cuRaXy34MGIxKa8VzG5QQcQUXp6.jpg'),
(119797, 8586, 'LEGO Masters S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cuRaXy34MGIxKa8VzG5QQcQUXp6.jpg'),
(119798, 8586, 'LEGO Masters S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cuRaXy34MGIxKa8VzG5QQcQUXp6.jpg'),
(119799, 8587, 'LEGO Masters S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/794370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cuRaXy34MGIxKa8VzG5QQcQUXp6.jpg'),
(119800, 8587, 'LEGO Masters S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/794371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cuRaXy34MGIxKa8VzG5QQcQUXp6.jpg'),
(119801, 8587, 'LEGO Masters S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/794372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cuRaXy34MGIxKa8VzG5QQcQUXp6.jpg'),
(119802, 8587, 'LEGO Masters S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/794373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cuRaXy34MGIxKa8VzG5QQcQUXp6.jpg'),
(119803, 8587, 'LEGO Masters S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/794374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cuRaXy34MGIxKa8VzG5QQcQUXp6.jpg'),
(119804, 8587, 'LEGO Masters S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/794375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cuRaXy34MGIxKa8VzG5QQcQUXp6.jpg'),
(119805, 8587, 'LEGO Masters S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/794376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cuRaXy34MGIxKa8VzG5QQcQUXp6.jpg'),
(119806, 8587, 'LEGO Masters S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/794377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cuRaXy34MGIxKa8VzG5QQcQUXp6.jpg'),
(119807, 8587, 'LEGO Masters S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/794378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cuRaXy34MGIxKa8VzG5QQcQUXp6.jpg'),
(119808, 8587, 'LEGO Masters S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/794379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cuRaXy34MGIxKa8VzG5QQcQUXp6.jpg'),
(119809, 8587, 'LEGO Masters S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/794380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cuRaXy34MGIxKa8VzG5QQcQUXp6.jpg'),
(119810, 8587, 'LEGO Masters S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/794381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cuRaXy34MGIxKa8VzG5QQcQUXp6.jpg'),
(119811, 8588, 'Portugal Show S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119812, 8588, 'Portugal Show S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119813, 8588, 'Portugal Show S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119814, 8588, 'Portugal Show S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119815, 8588, 'Portugal Show S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119816, 8588, 'Portugal Show S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119817, 8588, 'Portugal Show S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119818, 8588, 'Portugal Show S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119819, 8588, 'Portugal Show S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119820, 8588, 'Portugal Show S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119821, 8588, 'Portugal Show S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119822, 8588, 'Portugal Show S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119823, 8588, 'Portugal Show S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119824, 8588, 'Portugal Show S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/247784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119825, 8588, 'Portugal Show S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/247785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119826, 8588, 'Portugal Show S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/247786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119827, 8588, 'Portugal Show S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/247787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119828, 8588, 'Portugal Show S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/247788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119829, 8588, 'Portugal Show S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/247789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119830, 8588, 'Portugal Show S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/247790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119831, 8589, 'Portugal Show S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/388922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119832, 8589, 'Portugal Show S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/388923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119833, 8589, 'Portugal Show S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/394552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119834, 8589, 'Portugal Show S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/398455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119835, 8589, 'Portugal Show S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/400487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119836, 8589, 'Portugal Show S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/407204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119837, 8589, 'Portugal Show S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/407205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119838, 8589, 'Portugal Show S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/407206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119839, 8589, 'Portugal Show S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/411719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119840, 8589, 'Portugal Show S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/414664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119841, 8589, 'Portugal Show S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/414665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119842, 8589, 'Portugal Show S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/418238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119843, 8589, 'Portugal Show S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/421101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119844, 8589, 'Portugal Show S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/421102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119845, 8589, 'Portugal Show S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/426925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119846, 8589, 'Portugal Show S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/426926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119847, 8589, 'Portugal Show S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/429225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119848, 8589, 'Portugal Show S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/439219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119849, 8589, 'Portugal Show S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/441582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119850, 8589, 'Portugal Show S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/441583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/txytmqyqOuld9LFDzgKu8eMw0d3.jpg'),
(119851, 8590, 'Yu Gi Oh Go Rush [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/npVNNxXg71fou6tfoS3vtG2Bqjn.jpg'),
(119852, 8590, 'Yu Gi Oh Go Rush [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jLPdnZfXAB89kVgfqDWCfdixcte.jpg'),
(119853, 8590, 'Yu Gi Oh Go Rush [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/coRTi4hlstInVKtMPo7KRwBI26r.jpg'),
(119854, 8590, 'Yu Gi Oh Go Rush [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1aYHTXcdBzFJRnGuDrdFM6yJTFb.jpg'),
(119855, 8590, 'Yu Gi Oh Go Rush [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u0A6VqoP67uxGBuTpB306a9ZCZX.jpg'),
(119856, 8590, 'Yu Gi Oh Go Rush [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hZXSMgmYm0a8aikeOyA5hPQ7Npe.jpg'),
(119857, 8590, 'Yu Gi Oh Go Rush [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ze6HYYlMFKEglzwR5XFFaTSaTWu.jpg'),
(119858, 8590, 'Yu Gi Oh Go Rush [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLYf3HOk7FNDu1myEaQoq0JCAca.jpg'),
(119859, 8590, 'Yu Gi Oh Go Rush [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fZGMmsVewTuBMNb4Av1OhZwAGr3.jpg'),
(119860, 8590, 'Yu Gi Oh Go Rush [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/NiKIPh7r9alo5LeeVFFGeYORPl.jpg'),
(119861, 8590, 'Yu Gi Oh Go Rush [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sS15mqm101EL92gcLynjeaFMjFN.jpg'),
(119862, 8590, 'Yu Gi Oh Go Rush [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3m0LiktQJKV1PK9DiwYL61RoCJb.jpg'),
(119863, 8590, 'Yu Gi Oh Go Rush [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cOhgq37IyDSvsQH9SVkYUbvMWaT.jpg'),
(119864, 8590, 'Yu Gi Oh Go Rush [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/247249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rzEVU5UFPhW1ybCy5ySY91jSPwL.jpg'),
(119865, 8590, 'Yu Gi Oh Go Rush [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/247250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Qih8GjMOhpoBl99W1Sxoy7rQhI.jpg'),
(119866, 8590, 'Yu Gi Oh Go Rush [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/247251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3NPPEXrwRRsMX7RLNwRPmzy7NJx.jpg'),
(119867, 8590, 'Yu Gi Oh Go Rush [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/247252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tbbF8zNVykirmNQJsor1AWD0vLp.jpg'),
(119868, 8590, 'Yu Gi Oh Go Rush [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/247253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hGj62s5ysLcllEjZTpt8mG8k96T.jpg'),
(119869, 8590, 'Yu Gi Oh Go Rush [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/247254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ep9hoioGV6jQn1FENCJHuYpdigh.jpg'),
(119870, 8590, 'Yu Gi Oh Go Rush [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/247255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p00LIOEQ2SrcIby7K9aeyfdLqMF.jpg'),
(119871, 8590, 'Yu Gi Oh Go Rush [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/247256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4uJaw66jExwF7NPQB8c6GEkQxzo.jpg'),
(119872, 8590, 'Yu Gi Oh Go Rush [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/247257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWFtPVYk1qGdkLsmu9JyJCycJEC.jpg'),
(119873, 8590, 'Yu Gi Oh Go Rush [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/247258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mYrHqeRRpnwmBTl9rrVJtq0llAF.jpg'),
(119874, 8590, 'Yu Gi Oh Go Rush [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/247259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lWfbBn1amPTASIOXOFqA6kIO9jH.jpg'),
(119875, 8590, 'Yu Gi Oh Go Rush [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/247260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ncYzBQwFICvr4H1XrqGvjNg4yk0.jpg'),
(119876, 8590, 'Yu Gi Oh Go Rush [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/247261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/294YmK3Pp7bl7bfBA4MJYO2wDnM.jpg'),
(119877, 8590, 'Yu Gi Oh Go Rush [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/247262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oItRtxe0fAWH2MhHTNVOlJ4oA7E.jpg'),
(119878, 8590, 'Yu Gi Oh Go Rush [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/247263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qcoiSXBSXG17bRtwOw7tLtk5efn.jpg'),
(119879, 8590, 'Yu Gi Oh Go Rush [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/247264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zEhpyuktNjEgFKxgeUqtvLz7wUc.jpg'),
(119880, 8590, 'Yu Gi Oh Go Rush [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/247265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jXcF9SY5TgNsM1ls3KLb9ern9MZ.jpg'),
(119881, 8590, 'Yu Gi Oh Go Rush [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/247266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u2zKDCoxv5zTGPep0DXgok2dAS7.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(119882, 8590, 'Yu Gi Oh Go Rush [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/247267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24OzWt1y1ulGb795eN6XAqr3XQy.jpg'),
(119883, 8590, 'Yu Gi Oh Go Rush [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/247268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/meOJzXqbNgkKpW5U25sK7jEmigL.jpg'),
(119884, 8590, 'Yu Gi Oh Go Rush [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/247269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rQlK70JWyK6WilqBt2nhtqBCsy4.jpg'),
(119885, 8590, 'Yu Gi Oh Go Rush [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/247270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ycr88CFBz5QKfMHm3SB4F8RH610.jpg'),
(119886, 8590, 'Yu Gi Oh Go Rush [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/247271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oeGDzjzau5qrQb9G67yoDifkSfe.jpg'),
(119887, 8590, 'Yu Gi Oh Go Rush [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/247272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1KyS4HYDHhIu47bZTKMHmFQVLO5.jpg'),
(119888, 8590, 'Yu Gi Oh Go Rush [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/247273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bsJjz4ZWVW4xVD5QDfNyDJa6nmm.jpg'),
(119889, 8590, 'Yu Gi Oh Go Rush [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/247274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBJgRFgqE63C2Gnn4r6v42FPPYS.jpg'),
(119890, 8590, 'Yu Gi Oh Go Rush [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/247275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3xbheaIegMMhQ8PCB3lbjVDC0ie.jpg'),
(119891, 8590, 'Yu Gi Oh Go Rush [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/247276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ohYke3Q6HVdPM2AMYM4zzt3v4p.jpg'),
(119892, 8590, 'Yu Gi Oh Go Rush [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/247277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5nurrGz5LHzfArBIxHfRULD12Mh.jpg'),
(119893, 8590, 'Yu Gi Oh Go Rush [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/247278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jl6TTdEakDIXG0JRTnQsncYhoPl.jpg'),
(119894, 8590, 'Yu Gi Oh Go Rush [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/247279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ikmaH7aMc40dUcnGarHzVTx8SW2.jpg'),
(119895, 8590, 'Yu Gi Oh Go Rush [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/247280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rSHyh8cB6FuGGSFJEIeNx6gDMwi.jpg'),
(119896, 8590, 'Yu Gi Oh Go Rush [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/247281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wywtSsP6F0tDZYi0CEHowCI6lhK.jpg'),
(119897, 8590, 'Yu Gi Oh Go Rush [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/247282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/98eK8MLMFXNvw2uJM0eGY2N6hB5.jpg'),
(119898, 8590, 'Yu Gi Oh Go Rush [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/247283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJVAdnVvIbPN09F1iUBbS5fl1Nn.jpg'),
(119899, 8590, 'Yu Gi Oh Go Rush [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/247284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lKNGxKu1j0tSrsqP9DtGn8scxLS.jpg'),
(119900, 8590, 'Yu Gi Oh Go Rush [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/247285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uJ7rxIdKLezvhRMAv0dpqdOWzgx.jpg'),
(119901, 8590, 'Yu Gi Oh Go Rush [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/247286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1LHDJyuZjpv0DxRyhCGvIYzP34A.jpg'),
(119902, 8590, 'Yu Gi Oh Go Rush [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/247287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cfIoGfEH2D5ArU3gYhIjPd7C23q.jpg'),
(119903, 8590, 'Yu Gi Oh Go Rush [L] S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/247288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/baRWDNqAPq6gr8UaBGA8u642M2L.jpg'),
(119904, 8590, 'Yu Gi Oh Go Rush [L] S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/247289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yheoe2ygfDapSxQxTKEVhXPPVTj.jpg'),
(119905, 8590, 'Yu Gi Oh Go Rush [L] S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/247290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xLNtCZro4NKTqDZxIcRAFQsril4.jpg'),
(119906, 8590, 'Yu Gi Oh Go Rush [L] S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/247291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5okd1SR1cA3di4YQ6Npfrn42OHl.jpg'),
(119907, 8590, 'Yu Gi Oh Go Rush [L] S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/247292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wXotegSqcHqNN4a7uIcCZVTzXrs.jpg'),
(119908, 8590, 'Yu Gi Oh Go Rush [L] S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/247293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8oyd3uDiTHpbJs0dcYrGvgmeWmv.jpg'),
(119909, 8590, 'Yu Gi Oh Go Rush [L] S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/247294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pNUvpSZDUqSoY05nQo1h5JcMzNl.jpg'),
(119910, 8590, 'Yu Gi Oh Go Rush [L] S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/247295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iD7FtmQKXZ1ldMCERk0MfBcl0qN.jpg'),
(119911, 8590, 'Yu Gi Oh Go Rush [L] S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/247296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4iseZ4PnEdAvMQxKCvZ4BNPWeQo.jpg'),
(119912, 8590, 'Yu Gi Oh Go Rush [L] S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/247297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3K9jkmZsGJXNTQJ5dCSfk0cQi2c.jpg'),
(119913, 8590, 'Yu Gi Oh Go Rush [L] S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/247298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4HQvn3bFsSyDrkItxAZ3uE9pSWe.jpg'),
(119914, 8590, 'Yu Gi Oh Go Rush [L] S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/247299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1cgsNdfih3LeM4C9HhoKE2yB060.jpg'),
(119915, 8590, 'Yu Gi Oh Go Rush [L] S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/247300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aYIe3NTv9YPexprhLwlmdzNcgjQ.jpg'),
(119916, 8590, 'Yu Gi Oh Go Rush [L] S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/247301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hyWJ2xDhP3yBw5ZjbqBRfWz6ppR.jpg'),
(119917, 8590, 'Yu Gi Oh Go Rush [L] S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/247302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Zy4EYYSoYAP4ysa2ScgKfqJEpe.jpg'),
(119918, 8590, 'Yu Gi Oh Go Rush [L] S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/247303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u4oWOAwbxVlJpUMipK7sLdisHoU.jpg'),
(119919, 8590, 'Yu Gi Oh Go Rush [L] S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/247304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bn437ERSYbWI9HYBmkhbgA57H1b.jpg'),
(119920, 8590, 'Yu Gi Oh Go Rush [L] S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/247305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6lW9cyATC6W4dFuODKvljLznaR0.jpg'),
(119921, 8590, 'Yu Gi Oh Go Rush [L] S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/247306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qmlayP04tb714N477euSFkrovu7.jpg'),
(119922, 8590, 'Yu Gi Oh Go Rush [L] S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/247307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e9dfjxTGLu6eT5fHajxg07hfz8h.jpg'),
(119923, 8590, 'Yu Gi Oh Go Rush [L] S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/247308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eLdQC002dt5dxVN7u8UIx8PqlL0.jpg'),
(119924, 8590, 'Yu Gi Oh Go Rush [L] S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/247309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/efoYEyFfbhwotp8CoW6SEV0ceHk.jpg'),
(119925, 8590, 'Yu Gi Oh Go Rush [L] S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/247310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cOxlOqKBi9ynRoK9hkrgD3Z1VrV.jpg'),
(119926, 8590, 'Yu Gi Oh Go Rush [L] S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/247311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vPrrbciJH2A7ClGh0UfGYr361Nj.jpg'),
(119927, 8590, 'Yu Gi Oh Go Rush [L] S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/247312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ka77ESpJ2t4VrAQbl6kgRNjsp52.jpg'),
(119928, 8590, 'Yu Gi Oh Go Rush [L] S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/247313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gezhar4rBy0OsUz7bE7J5WFvqhh.jpg'),
(119929, 8590, 'Yu Gi Oh Go Rush [L] S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/247314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zVsc1VpzUtipRfxEjeqCh45QpPD.jpg'),
(119930, 8590, 'Yu Gi Oh Go Rush [L] S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/247315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119931, 8590, 'Yu Gi Oh Go Rush [L] S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/247316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119932, 8590, 'Yu Gi Oh Go Rush [L] S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/247317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119933, 8590, 'Yu Gi Oh Go Rush [L] S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/247318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119934, 8590, 'Yu Gi Oh Go Rush [L] S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/890880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119935, 8590, 'Yu Gi Oh Go Rush [L] S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/890881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119936, 8590, 'Yu Gi Oh Go Rush [L] S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/890882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119937, 8590, 'Yu Gi Oh Go Rush [L] S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/890883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119938, 8590, 'Yu Gi Oh Go Rush [L] S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/890884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119939, 8590, 'Yu Gi Oh Go Rush [L] S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/890885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119940, 8590, 'Yu Gi Oh Go Rush [L] S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/890886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119941, 8590, 'Yu Gi Oh Go Rush [L] S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/890887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119942, 8590, 'Yu Gi Oh Go Rush [L] S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/890888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119943, 8590, 'Yu Gi Oh Go Rush [L] S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/890889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119944, 8590, 'Yu Gi Oh Go Rush [L] S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/890890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119945, 8590, 'Yu Gi Oh Go Rush [L] S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/890891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119946, 8590, 'Yu Gi Oh Go Rush [L] S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/890892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119947, 8590, 'Yu Gi Oh Go Rush [L] S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/890893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119948, 8590, 'Yu Gi Oh Go Rush [L] S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/890894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119949, 8590, 'Yu Gi Oh Go Rush [L] S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/890895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119950, 8590, 'Yu Gi Oh Go Rush [L] S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/890896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119951, 8590, 'Yu Gi Oh Go Rush [L] S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/890897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119952, 8590, 'Yu Gi Oh Go Rush [L] S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/890898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119953, 8590, 'Yu Gi Oh Go Rush [L] S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/890899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119954, 8590, 'Yu Gi Oh Go Rush [L] S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/890900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119955, 8590, 'Yu Gi Oh Go Rush [L] S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/890901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119956, 8590, 'Yu Gi Oh Go Rush [L] S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/890902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119957, 8590, 'Yu Gi Oh Go Rush [L] S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/890903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119958, 8590, 'Yu Gi Oh Go Rush [L] S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/890904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119959, 8590, 'Yu Gi Oh Go Rush [L] S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/890905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119960, 8590, 'Yu Gi Oh Go Rush [L] S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/890906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119961, 8590, 'Yu Gi Oh Go Rush [L] S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/890907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119962, 8590, 'Yu Gi Oh Go Rush [L] S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/890908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119963, 8590, 'Yu Gi Oh Go Rush [L] S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/890909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119964, 8590, 'Yu Gi Oh Go Rush [L] S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/890910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119965, 8590, 'Yu Gi Oh Go Rush [L] S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/890911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119966, 8590, 'Yu Gi Oh Go Rush [L] S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/890912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119967, 8590, 'Yu Gi Oh Go Rush [L] S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/890913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119968, 8590, 'Yu Gi Oh Go Rush [L] S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/890914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119969, 8590, 'Yu Gi Oh Go Rush [L] S01 E119', 'http://sinalprivado.info:80/series/1533784/1533784/890915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119970, 8590, 'Yu Gi Oh Go Rush [L] S01 E120', 'http://sinalprivado.info:80/series/1533784/1533784/890916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119971, 8590, 'Yu Gi Oh Go Rush [L] S01 E121', 'http://sinalprivado.info:80/series/1533784/1533784/890917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119972, 8590, 'Yu Gi Oh Go Rush [L] S01 E122', 'http://sinalprivado.info:80/series/1533784/1533784/890918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119973, 8590, 'Yu Gi Oh Go Rush [L] S01 E123', 'http://sinalprivado.info:80/series/1533784/1533784/890919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119974, 8590, 'Yu Gi Oh Go Rush [L] S01 E124', 'http://sinalprivado.info:80/series/1533784/1533784/890920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119975, 8590, 'Yu Gi Oh Go Rush [L] S01 E125', 'http://sinalprivado.info:80/series/1533784/1533784/890921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119976, 8590, 'Yu Gi Oh Go Rush [L] S01 E126', 'http://sinalprivado.info:80/series/1533784/1533784/890922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119977, 8590, 'Yu Gi Oh Go Rush [L] S01 E127', 'http://sinalprivado.info:80/series/1533784/1533784/890923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119978, 8590, 'Yu Gi Oh Go Rush [L] S01 E128', 'http://sinalprivado.info:80/series/1533784/1533784/890924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119979, 8590, 'Yu Gi Oh Go Rush [L] S01 E129', 'http://sinalprivado.info:80/series/1533784/1533784/890925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119980, 8590, 'Yu Gi Oh Go Rush [L] S01 E130', 'http://sinalprivado.info:80/series/1533784/1533784/890926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119981, 8590, 'Yu Gi Oh Go Rush [L] S01 E131', 'http://sinalprivado.info:80/series/1533784/1533784/890927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119982, 8590, 'Yu Gi Oh Go Rush [L] S01 E132', 'http://sinalprivado.info:80/series/1533784/1533784/890928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119983, 8590, 'Yu Gi Oh Go Rush [L] S01 E133', 'http://sinalprivado.info:80/series/1533784/1533784/890929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119984, 8590, 'Yu Gi Oh Go Rush [L] S01 E134', 'http://sinalprivado.info:80/series/1533784/1533784/890930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119985, 8590, 'Yu Gi Oh Go Rush [L] S01 E135', 'http://sinalprivado.info:80/series/1533784/1533784/890931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119986, 8590, 'Yu Gi Oh Go Rush [L] S01 E136', 'http://sinalprivado.info:80/series/1533784/1533784/890932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119987, 8590, 'Yu Gi Oh Go Rush [L] S01 E137', 'http://sinalprivado.info:80/series/1533784/1533784/890933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119988, 8590, 'Yu Gi Oh Go Rush [L] S01 E138', 'http://sinalprivado.info:80/series/1533784/1533784/890934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119989, 8590, 'Yu Gi Oh Go Rush [L] S01 E139', 'http://sinalprivado.info:80/series/1533784/1533784/890935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119990, 8590, 'Yu Gi Oh Go Rush [L] S01 E140', 'http://sinalprivado.info:80/series/1533784/1533784/890936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119991, 8590, 'Yu Gi Oh Go Rush [L] S01 E141', 'http://sinalprivado.info:80/series/1533784/1533784/890937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119992, 8590, 'Yu Gi Oh Go Rush [L] S01 E142', 'http://sinalprivado.info:80/series/1533784/1533784/890938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119993, 8590, 'Yu Gi Oh Go Rush [L] S01 E143', 'http://sinalprivado.info:80/series/1533784/1533784/890939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119994, 8590, 'Yu Gi Oh Go Rush [L] S01 E144', 'http://sinalprivado.info:80/series/1533784/1533784/890940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119995, 8590, 'Yu Gi Oh Go Rush [L] S01 E145', 'http://sinalprivado.info:80/series/1533784/1533784/890941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119996, 8590, 'Yu Gi Oh Go Rush [L] S01 E146', 'http://sinalprivado.info:80/series/1533784/1533784/890942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119997, 8590, 'Yu Gi Oh Go Rush [L] S01 E147', 'http://sinalprivado.info:80/series/1533784/1533784/890943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119998, 8590, 'Yu Gi Oh Go Rush [L] S01 E148', 'http://sinalprivado.info:80/series/1533784/1533784/890944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(119999, 8590, 'Yu Gi Oh Go Rush [L] S01 E149', 'http://sinalprivado.info:80/series/1533784/1533784/890945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1FaQie0ayahBsljna8F3I0m45Rg.jpg'),
(120000, 8591, 'Fábrica de Casamentos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ix2yCiGFdXvQ5C9SZyraR5JgE22.jpg'),
(120001, 8591, 'Fábrica de Casamentos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hrmp2b9nB9cooaeCLnsmwOD3oWx.jpg'),
(120002, 8591, 'Fábrica de Casamentos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wh33dfO1nGqawVzLh3NXeZkvl3U.jpg'),
(120003, 8591, 'Fábrica de Casamentos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/soZrCLNnFymkKOjQj8KZxPRyGnr.jpg'),
(120004, 8591, 'Fábrica de Casamentos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jQfqCcsI2qKTPZBapxKdeXqRoa1.jpg'),
(120005, 8591, 'Fábrica de Casamentos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g5Cxxf78PvFnS3F5aVsEWYs4ve5.jpg'),
(120006, 8591, 'Fábrica de Casamentos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t2D8yf6KDcQzVsM8YcxdOECXJPu.jpg'),
(120007, 8591, 'Fábrica de Casamentos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5U4PGRvb8FfRPlxR5vnOuFpMQKs.jpg'),
(120008, 8591, 'Fábrica de Casamentos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qHCHIjfuux2c1QkwFVpOtK6QOdj.jpg'),
(120009, 8591, 'Fábrica de Casamentos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9TRbhrXJD0GZa7GeJKW4geJKJoF.jpg'),
(120010, 8591, 'Fábrica de Casamentos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pegZLStzQBHEmiLKFaZLr3MYeh9.jpg'),
(120011, 8591, 'Fábrica de Casamentos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5GJs3qLhlV8ce3Ims81mL5uXt9a.jpg'),
(120012, 8591, 'Fábrica de Casamentos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eXjvtyRBODDQcSZae2StXfAGftO.jpg'),
(120013, 8591, 'Fábrica de Casamentos S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qzHAcQQsjvY3t4Q2IjNfSSuyOQB.jpg'),
(120014, 8591, 'Fábrica de Casamentos S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2FZftuOYZxQRftyOvjCz8kt7hdQ.jpg'),
(120015, 8591, 'Fábrica de Casamentos S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/241539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nnrkBEmZNGaDWA9mwtt7TpXhnAE.jpg'),
(120016, 8592, 'Fábrica de Casamentos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xd0pnr0UF7uo31MKCLfLd0tUKmB.jpg'),
(120017, 8592, 'Fábrica de Casamentos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/epyvf64p1okGWwgJWiyKViCgG30.jpg'),
(120018, 8592, 'Fábrica de Casamentos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/66kp25gr8lmL6cCdjF3rVD7JCl5.jpg'),
(120019, 8592, 'Fábrica de Casamentos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sazZgJXTufULQoP0So5HOEhtqX4.jpg'),
(120020, 8592, 'Fábrica de Casamentos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9RZ7KzcM44tNK5CA3hJplVkfhG.jpg'),
(120021, 8592, 'Fábrica de Casamentos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lPfo9ArGkKDO09usLcGPXX704Ea.jpg'),
(120022, 8592, 'Fábrica de Casamentos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i4bBTOlyVorh6zmUGrpY5VBUuE.jpg'),
(120023, 8592, 'Fábrica de Casamentos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7AbGrYPovnRA5OvTdwjiDyHKTXU.jpg'),
(120024, 8592, 'Fábrica de Casamentos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kbni1VJ3cba4HDou8pb9eK2RHJA.jpg'),
(120025, 8592, 'Fábrica de Casamentos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpynXJd8NF45xcqt2z4T904mFnd.jpg'),
(120026, 8592, 'Fábrica de Casamentos S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bnaTh3gkJMXTLiEDpmRkCc8Npiy.jpg'),
(120027, 8592, 'Fábrica de Casamentos S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1lnvS3EAM54ajktA9eEtlZRz23G.jpg'),
(120028, 8592, 'Fábrica de Casamentos S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rNyBMwCMtQmk7TLB0u0ISlndgix.jpg'),
(120029, 8592, 'Fábrica de Casamentos S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hLOEJO78xCmO5PoccuCcGxA3pU.jpg'),
(120030, 8592, 'Fábrica de Casamentos S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCEzL52ANP7TexWgekd0FiylDHi.jpg'),
(120031, 8593, 'Fábrica de Casamentos S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zYnAVRToWjrGhvqCNsiYPX8lxMx.jpg'),
(120032, 8593, 'Fábrica de Casamentos S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eL4QLkktlYEcM7W7O23vaWhe2Cy.jpg'),
(120033, 8593, 'Fábrica de Casamentos S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/PnHSE8NFPIYwrwKt9yIbA2Mtux.jpg'),
(120034, 8593, 'Fábrica de Casamentos S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mEb3RTZJolkvLgqA8rtG6xD58Qd.jpg'),
(120035, 8593, 'Fábrica de Casamentos S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lvcXfTFuND69L0g5fUyHc7HAd2.jpg'),
(120036, 8593, 'Fábrica de Casamentos S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qSD61wZDcQCF9Fa6D5umvrYqeci.jpg'),
(120037, 8593, 'Fábrica de Casamentos S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hROeitRP4rNBbfbFmo93d8ea2KC.jpg'),
(120038, 8593, 'Fábrica de Casamentos S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nEIRWJK9CThq0q9vN0ouFlQup5J.jpg'),
(120039, 8593, 'Fábrica de Casamentos S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n76GErh3UeY6KjBiL9gr6pJfqOp.jpg'),
(120040, 8593, 'Fábrica de Casamentos S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hgRz3IHWOSDqpEkixCPam44grjp.jpg'),
(120041, 8593, 'Fábrica de Casamentos S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yVQpgF8r00313bNf9CHxUMIU33F.jpg'),
(120042, 8593, 'Fábrica de Casamentos S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sw05Q8juSgxUAvcZUUpo6bIFVwL.jpg'),
(120043, 8593, 'Fábrica de Casamentos S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wxssinMg9ZyAiLgGUn4pJtIHGvn.jpg'),
(120044, 8593, 'Fábrica de Casamentos S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qgJ0RdgRzw3cj78d4Av0pM8TLkh.jpg'),
(120045, 8594, 'Annika [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x7yx6BiaEbhh8lWAfeYl4lPmiJi.jpg'),
(120046, 8594, 'Annika [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2U01595zBgSVqNglWFDFlXJpOGZ.jpg'),
(120047, 8594, 'Annika [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yptejovcrLrdjnaugzrIU3e6EEK.jpg'),
(120048, 8594, 'Annika [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k6xqZNLwtqUzgVKM5YdKw4GNqxX.jpg'),
(120049, 8594, 'Annika [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rs5biFrLRGZ66eaR4l3c5arscwl.jpg'),
(120050, 8594, 'Annika [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zJN43eSUNTJjZKfAmqLzS8GbRvm.jpg'),
(120051, 8595, 'Annika [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7bAHqt1IzH1OLCQkEre9rMdhS3i.jpg'),
(120052, 8595, 'Annika [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gKwwbL2efs3C3vPEdFJv6keiXtS.jpg'),
(120053, 8595, 'Annika [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1VKuPYxL0fK1DNH5dTtnGRFbU0n.jpg'),
(120054, 8595, 'Annika [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTywzFDYTXflTkNnZE1N6jzNLPP.jpg'),
(120055, 8595, 'Annika [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jRoGLyOnTMyLhWajG0ye6KKw0h.jpg'),
(120056, 8595, 'Annika [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8jRoGLyOnTMyLhWajG0ye6KKw0h.jpg'),
(120057, 8596, 'Billy the Kid [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kf88vI6meL5sNadrLnItkqfNz2c.jpg'),
(120058, 8596, 'Billy the Kid [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AdcaUlQZwNWfodSa3nr6qQzUpBy.jpg'),
(120059, 8596, 'Billy the Kid [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dY5D2saqhlBEYFfIVp0Ymngf6tO.jpg'),
(120060, 8596, 'Billy the Kid [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xRvUEge7Z0eS3R40jhMBu4yZkxx.jpg'),
(120061, 8596, 'Billy the Kid [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qbljeKBxjPXQylgJL9cxNVD7a0L.jpg'),
(120062, 8596, 'Billy the Kid [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lu7cxFtgV3yFuMKKdtdQGtfKCin.jpg'),
(120063, 8596, 'Billy the Kid [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lUFHNoRhb3m5C3eGp0JGnHTT3jp.jpg'),
(120064, 8596, 'Billy the Kid [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jl2OP3GaWY0gQfwF2CR5uDmfo60.jpg'),
(120065, 8597, 'Billy the Kid [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7R68h5W0ozWt86uWhfqhivHLYNp.jpg'),
(120066, 8597, 'Billy the Kid [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hwsHUaVw6Cj83951EIQwcVzP45d.jpg'),
(120067, 8597, 'Billy the Kid [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hwsHUaVw6Cj83951EIQwcVzP45d.jpg'),
(120068, 8597, 'Billy the Kid [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hwsHUaVw6Cj83951EIQwcVzP45d.jpg'),
(120069, 8597, 'Billy the Kid [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449167.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/98zkNYOpELxtbKhHyKll7U4mmnU.jpg'),
(120070, 8597, 'Billy the Kid [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449168.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r4GZa9UGrqDFliD4CMQ8JVXPQRl.jpg'),
(120071, 8597, 'Billy the Kid [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449169.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eegYYH9ZBV8i85bDGotyToFMfG6.jpg'),
(120072, 8598, 'Billy the Kid [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/887313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hwsHUaVw6Cj83951EIQwcVzP45d.jpg'),
(120073, 8599, 'Blippi Wonders S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zbV63JOq86gz8jsxNzcJnzPPcYY.jpg'),
(120074, 8599, 'Blippi Wonders S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dY6xHg9nNzdoE2DuldrKb5c98NL.jpg'),
(120075, 8599, 'Blippi Wonders S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gIHcSz1XZGPGfCocljlZMR1kntq.jpg'),
(120076, 8599, 'Blippi Wonders S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eK42nlYoVq0xUgESkBPnlezlCXy.jpg'),
(120077, 8599, 'Blippi Wonders S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4kNHXT9PuhRcOUFajyDjgdVJ5Hh.jpg'),
(120078, 8599, 'Blippi Wonders S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p8Fd8ugFwlzcXqYdJkqFkxqrHaT.jpg'),
(120079, 8599, 'Blippi Wonders S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wkEwPKodk6i4XYLvgAJ21Ojdo8r.jpg'),
(120080, 8599, 'Blippi Wonders S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qAcpDx6Fjg5eIkpgUoAHFmsnIwe.jpg'),
(120081, 8599, 'Blippi Wonders S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wlG7nCme8HYt7XZiA1VOinNIlDJ.jpg'),
(120082, 8599, 'Blippi Wonders S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/efPxkHavwRsWoSSchQvOAq6Xtdh.jpg'),
(120083, 8599, 'Blippi Wonders S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vriRPdIDJQxjc1902S1IbEzpjPl.jpg'),
(120084, 8599, 'Blippi Wonders S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xiCwyfAfGXQai6WNqCXj5HtGdX6.jpg'),
(120085, 8599, 'Blippi Wonders S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v8x8SoxWVJwZmElLXgj4uTH5aQi.jpg'),
(120086, 8599, 'Blippi Wonders S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uMeDJtGXdbu5LgB2P3qrpAhkVyX.jpg'),
(120087, 8599, 'Blippi Wonders S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n5p9DXskATD0VqgUXG8a3DsZ9GN.jpg'),
(120088, 8599, 'Blippi Wonders S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/241224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rM2A0TFYpiCHoOQoGH5wT2qY12d.jpg'),
(120089, 8599, 'Blippi Wonders S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/241225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/trrNyiTV2WWnBBNUYjzEs0nKlK7.jpg'),
(120090, 8599, 'Blippi Wonders S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/241226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Rrdz9L68EYyWkPYZ38jPs8hMIO.jpg'),
(120091, 8599, 'Blippi Wonders S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/241227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5WzeymXpcAOB0tfSFbWTYpVv0ta.jpg'),
(120092, 8599, 'Blippi Wonders S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/241228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4zCgqQ9m7X0cNCKZAFN2U14MPPp.jpg'),
(120093, 8599, 'Blippi Wonders S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/241229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7flQz96uRsiQXBTCsxKotTAxcYE.jpg'),
(120094, 8599, 'Blippi Wonders S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/241230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kIncWOmk9O2AkNEPB7rkX4TFeOJ.jpg'),
(120095, 8599, 'Blippi Wonders S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/241231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4tULLXXY7Ip3hcOgwiuecVSoOr5.jpg'),
(120096, 8599, 'Blippi Wonders S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/241232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7rkSimaZltjZI4i4jnhxmZuFPxT.jpg'),
(120097, 8599, 'Blippi Wonders S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/241233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nP3lxc88uhEemX5286KkTaqNuO4.jpg'),
(120098, 8599, 'Blippi Wonders S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/241234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/69Fu0ZnLFyXLUZi8yyzuFph3kHi.jpg'),
(120099, 8600, 'Blippi Wonders S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120100, 8600, 'Blippi Wonders S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120101, 8600, 'Blippi Wonders S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120102, 8600, 'Blippi Wonders S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120103, 8600, 'Blippi Wonders S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120104, 8600, 'Blippi Wonders S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120105, 8600, 'Blippi Wonders S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120106, 8600, 'Blippi Wonders S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120107, 8600, 'Blippi Wonders S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120108, 8600, 'Blippi Wonders S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120109, 8600, 'Blippi Wonders S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120110, 8600, 'Blippi Wonders S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120111, 8600, 'Blippi Wonders S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120112, 8600, 'Blippi Wonders S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120113, 8600, 'Blippi Wonders S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120114, 8600, 'Blippi Wonders S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/241250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120115, 8600, 'Blippi Wonders S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/241251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120116, 8600, 'Blippi Wonders S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/241252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120117, 8600, 'Blippi Wonders S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/241253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120118, 8600, 'Blippi Wonders S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/241254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120119, 8600, 'Blippi Wonders S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/241255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120120, 8600, 'Blippi Wonders S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/241256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120121, 8600, 'Blippi Wonders S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/241257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120122, 8600, 'Blippi Wonders S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/241258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120123, 8600, 'Blippi Wonders S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/241259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120124, 8600, 'Blippi Wonders S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/241260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7uQIxacaoTsXI3eAHnvwmwCSy3b.jpg'),
(120125, 8601, 'Dinossauro Rei S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzyPwuk6q0yHEGCVS9dqBISR1OF.jpg'),
(120126, 8601, 'Dinossauro Rei S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDy0DQlwjreyr28NOdMjHdMjQGn.jpg'),
(120127, 8601, 'Dinossauro Rei S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBiHXXckwZ7aKO8PphcTtGPBCs9.jpg'),
(120128, 8601, 'Dinossauro Rei S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ZnQ5xPxZEBvCGyXftJTst2ukG1.jpg'),
(120129, 8601, 'Dinossauro Rei S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pxaosxGxfGrJ2D5Lxvzb6UpVBMV.jpg'),
(120130, 8601, 'Dinossauro Rei S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2X2BPLWI0db4lkqLdZn69DjmNhZ.jpg'),
(120131, 8601, 'Dinossauro Rei S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e4X4inlwOiHZRX59UUbWm4TW7rg.jpg'),
(120132, 8601, 'Dinossauro Rei S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMujyGRzM03c0OoQxdfK0Q6mfMU.jpg'),
(120133, 8601, 'Dinossauro Rei S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Ctj0wy2x4jidfrHglzeflDULTN.jpg'),
(120134, 8601, 'Dinossauro Rei S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lA54TJvWzMvJyyfO2tw6AqyZn0B.jpg'),
(120135, 8601, 'Dinossauro Rei S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ftjVUOUaIQCPrXEwdNQnWtcG74.jpg'),
(120136, 8601, 'Dinossauro Rei S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jwTxX2AJKQNJ6PCWTXt20Pit8hx.jpg'),
(120137, 8601, 'Dinossauro Rei S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fbI1DyBof5VuTNRtASMfQ3J6LXB.jpg'),
(120138, 8601, 'Dinossauro Rei S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tzOWHjrOKmFFOFrzoP2DYGQruYR.jpg'),
(120139, 8601, 'Dinossauro Rei S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ngePnV6DAXBvA0HCCnZfRSHQ2sk.jpg'),
(120140, 8601, 'Dinossauro Rei S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/241145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7XghtXz5vnUJ1Ebvdnkd82ya7V1.jpg'),
(120141, 8601, 'Dinossauro Rei S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/241146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/grxymeAy36U6y602hyiwSeaKRkI.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(120142, 8601, 'Dinossauro Rei S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/241147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mia30zeRjBqcFbcwXQi3RLJskHr.jpg'),
(120143, 8601, 'Dinossauro Rei S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/241148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xHdO38ciNZxvb8q8n9Wvt7l1tmn.jpg'),
(120144, 8601, 'Dinossauro Rei S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/241149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hPF3xqoZicVNcow94IZ9gjhfMW0.jpg'),
(120145, 8601, 'Dinossauro Rei S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/241150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mOGO6C6Tjfw0g1dCMW9WQMjR3JY.jpg'),
(120146, 8601, 'Dinossauro Rei S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/241151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6UFpPW3O1IS5Lgykxa8crzLvsAw.jpg'),
(120147, 8601, 'Dinossauro Rei S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/241152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6UFpPW3O1IS5Lgykxa8crzLvsAw.jpg'),
(120148, 8601, 'Dinossauro Rei S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/241153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cyUOuXudjxbDtnGxnRJVy6qxTgt.jpg'),
(120149, 8601, 'Dinossauro Rei S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/241154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qCd5LLbPtBmGrn76sLqzM4D9f0b.jpg'),
(120150, 8601, 'Dinossauro Rei S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/241155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/njc70iYWRjp74naqYvTbA7vBfyC.jpg'),
(120151, 8601, 'Dinossauro Rei S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/241156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pWarmEL28apwdKSICWz1LNRXfYg.jpg'),
(120152, 8601, 'Dinossauro Rei S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/241157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bsaeOvAzF4DhiBh8VHAMTXMhBq.jpg'),
(120153, 8601, 'Dinossauro Rei S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/241158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cfRcR3uIDPtWs8BY0SRZ0cUZHII.jpg'),
(120154, 8601, 'Dinossauro Rei S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/241159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rzyUXhG0RYZQzCosmsiN3P4Yt54.jpg'),
(120155, 8601, 'Dinossauro Rei S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/241160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n4tJFRjunJBRXedGncKq0K40Ppj.jpg'),
(120156, 8601, 'Dinossauro Rei S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/241161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9vs9s4FUu7WyQyUuiKg6Jp0G2R.jpg'),
(120157, 8601, 'Dinossauro Rei S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/241162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfF2vxbkQSFAsHV8pKhzAX3lPvX.jpg'),
(120158, 8601, 'Dinossauro Rei S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/241163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iKCQmiBBdj5HN3CJyRTKfvxxcuG.jpg'),
(120159, 8601, 'Dinossauro Rei S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/241164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qGPWqm6rKhEY2e2KNf9KzfezenJ.jpg'),
(120160, 8601, 'Dinossauro Rei S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/241165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j1e1M3P1izN2a0ANRUt3nW5bDPf.jpg'),
(120161, 8601, 'Dinossauro Rei S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/241166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQyc6cdKCYz45tyBjV1VbxbIj91.jpg'),
(120162, 8601, 'Dinossauro Rei S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/241167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2xxwuIcq8MNA9Je0naNoQ16pd0E.jpg'),
(120163, 8601, 'Dinossauro Rei S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/241168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dedOqigGbSOo93vo2N3B9ISDM9S.jpg'),
(120164, 8601, 'Dinossauro Rei S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/241169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/46ntJSBvMsd4bvMZl9DNxLMnzpN.jpg'),
(120165, 8601, 'Dinossauro Rei S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/241170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/85r7oH3fT5whVH4jHhuSW0uJiMh.jpg'),
(120166, 8601, 'Dinossauro Rei S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/241171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fqPzQ8qYGiTTF0PMjPUuZB1qeIp.jpg'),
(120167, 8601, 'Dinossauro Rei S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/241172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t6rjHn9VJmfJf7TNuN1TNsgS2nQ.jpg'),
(120168, 8601, 'Dinossauro Rei S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/241173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qpxhYm4j101hSecTUkPFne7zet9.jpg'),
(120169, 8601, 'Dinossauro Rei S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/241174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vmcKGpQRdViap84aX2ATjKYZ7wh.jpg'),
(120170, 8601, 'Dinossauro Rei S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/241175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1tqXgZSzolMOFD5caqfzcA54ewr.jpg'),
(120171, 8601, 'Dinossauro Rei S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/241176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ol3QKsFLQMm0DnvW6JB65r9Q3m1.jpg'),
(120172, 8601, 'Dinossauro Rei S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/241177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s2GJPAYqhWUj9nMcaFiI4WjkQVk.jpg'),
(120173, 8601, 'Dinossauro Rei S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/241178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5LTb5JavCpgpwqKUEQQld3oQIp6.jpg'),
(120174, 8602, 'Dinossauro Rei S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120175, 8602, 'Dinossauro Rei S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120176, 8602, 'Dinossauro Rei S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120177, 8602, 'Dinossauro Rei S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120178, 8602, 'Dinossauro Rei S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120179, 8602, 'Dinossauro Rei S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120180, 8602, 'Dinossauro Rei S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120181, 8602, 'Dinossauro Rei S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120182, 8602, 'Dinossauro Rei S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/241187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120183, 8602, 'Dinossauro Rei S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/241188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120184, 8602, 'Dinossauro Rei S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/241189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120185, 8602, 'Dinossauro Rei S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/241190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120186, 8602, 'Dinossauro Rei S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/241191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120187, 8602, 'Dinossauro Rei S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/241192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120188, 8602, 'Dinossauro Rei S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/241193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120189, 8602, 'Dinossauro Rei S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/241194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120190, 8602, 'Dinossauro Rei S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/241195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120191, 8602, 'Dinossauro Rei S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/241196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120192, 8602, 'Dinossauro Rei S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/241197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120193, 8602, 'Dinossauro Rei S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/241198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120194, 8602, 'Dinossauro Rei S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/241199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120195, 8602, 'Dinossauro Rei S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/241200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120196, 8602, 'Dinossauro Rei S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/241201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120197, 8602, 'Dinossauro Rei S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/241202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120198, 8602, 'Dinossauro Rei S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/241203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120199, 8602, 'Dinossauro Rei S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/241204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120200, 8602, 'Dinossauro Rei S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/241205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120201, 8602, 'Dinossauro Rei S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/241206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120202, 8602, 'Dinossauro Rei S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/241207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120203, 8602, 'Dinossauro Rei S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/241208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6KWd6u4sU6vXMA9b9Gj9M5NvtJ.jpg'),
(120204, 8603, 'Gigablaster S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120205, 8603, 'Gigablaster S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120206, 8603, 'Gigablaster S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120207, 8603, 'Gigablaster S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120208, 8603, 'Gigablaster S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120209, 8603, 'Gigablaster S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120210, 8603, 'Gigablaster S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120211, 8603, 'Gigablaster S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120212, 8603, 'Gigablaster S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120213, 8603, 'Gigablaster S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120214, 8603, 'Gigablaster S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120215, 8603, 'Gigablaster S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120216, 8603, 'Gigablaster S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120217, 8603, 'Gigablaster S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120218, 8603, 'Gigablaster S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120219, 8603, 'Gigablaster S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120220, 8603, 'Gigablaster S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/250567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120221, 8603, 'Gigablaster S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/250568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120222, 8603, 'Gigablaster S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/250569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120223, 8603, 'Gigablaster S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/250570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120224, 8603, 'Gigablaster S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/250571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120225, 8603, 'Gigablaster S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/250572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120226, 8603, 'Gigablaster S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/250573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120227, 8603, 'Gigablaster S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/250574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120228, 8603, 'Gigablaster S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/250575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120229, 8603, 'Gigablaster S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/250576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120230, 8604, 'Gigablaster S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120231, 8604, 'Gigablaster S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120232, 8604, 'Gigablaster S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120233, 8604, 'Gigablaster S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120234, 8604, 'Gigablaster S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120235, 8604, 'Gigablaster S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120236, 8604, 'Gigablaster S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120237, 8604, 'Gigablaster S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120238, 8604, 'Gigablaster S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120239, 8604, 'Gigablaster S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120240, 8604, 'Gigablaster S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120241, 8604, 'Gigablaster S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120242, 8604, 'Gigablaster S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120243, 8604, 'Gigablaster S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120244, 8604, 'Gigablaster S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120245, 8604, 'Gigablaster S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120246, 8604, 'Gigablaster S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/250593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120247, 8604, 'Gigablaster S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/250594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120248, 8604, 'Gigablaster S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/250595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120249, 8604, 'Gigablaster S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/250596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120250, 8604, 'Gigablaster S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/250597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120251, 8604, 'Gigablaster S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/250598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120252, 8604, 'Gigablaster S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/250599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120253, 8604, 'Gigablaster S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/250600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120254, 8604, 'Gigablaster S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/250601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120255, 8604, 'Gigablaster S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/250602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120256, 8605, 'Gigablaster S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120257, 8605, 'Gigablaster S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120258, 8605, 'Gigablaster S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120259, 8605, 'Gigablaster S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120260, 8605, 'Gigablaster S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120261, 8605, 'Gigablaster S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120262, 8605, 'Gigablaster S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120263, 8605, 'Gigablaster S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120264, 8605, 'Gigablaster S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120265, 8605, 'Gigablaster S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120266, 8605, 'Gigablaster S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120267, 8605, 'Gigablaster S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120268, 8605, 'Gigablaster S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120269, 8605, 'Gigablaster S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120270, 8605, 'Gigablaster S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120271, 8605, 'Gigablaster S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120272, 8605, 'Gigablaster S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/250619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120273, 8605, 'Gigablaster S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/250620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120274, 8605, 'Gigablaster S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/250621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120275, 8605, 'Gigablaster S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/250622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120276, 8605, 'Gigablaster S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/250623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120277, 8605, 'Gigablaster S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/250624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120278, 8605, 'Gigablaster S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/250625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120279, 8605, 'Gigablaster S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/250626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120280, 8605, 'Gigablaster S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/250627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120281, 8605, 'Gigablaster S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/250628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120282, 8606, 'Gigablaster S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120283, 8606, 'Gigablaster S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120284, 8606, 'Gigablaster S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120285, 8606, 'Gigablaster S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120286, 8606, 'Gigablaster S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120287, 8606, 'Gigablaster S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120288, 8606, 'Gigablaster S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120289, 8606, 'Gigablaster S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120290, 8606, 'Gigablaster S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120291, 8606, 'Gigablaster S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120292, 8606, 'Gigablaster S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120293, 8606, 'Gigablaster S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120294, 8606, 'Gigablaster S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120295, 8606, 'Gigablaster S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120296, 8606, 'Gigablaster S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120297, 8606, 'Gigablaster S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120298, 8606, 'Gigablaster S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/250645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120299, 8606, 'Gigablaster S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/250646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120300, 8606, 'Gigablaster S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/250647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120301, 8606, 'Gigablaster S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/250648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120302, 8606, 'Gigablaster S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/250649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120303, 8606, 'Gigablaster S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/250650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120304, 8606, 'Gigablaster S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/250651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120305, 8606, 'Gigablaster S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/250652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120306, 8606, 'Gigablaster S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/250653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120307, 8607, 'Gigablaster S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/893365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120308, 8607, 'Gigablaster S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/893366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120309, 8607, 'Gigablaster S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/893367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120310, 8607, 'Gigablaster S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/893368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120311, 8607, 'Gigablaster S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/893369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120312, 8607, 'Gigablaster S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/893370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120313, 8607, 'Gigablaster S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/893371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120314, 8607, 'Gigablaster S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/893372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120315, 8608, 'Gigablaster S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/893373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120316, 8608, 'Gigablaster S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/893374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120317, 8608, 'Gigablaster S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/893375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120318, 8608, 'Gigablaster S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/893376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120319, 8608, 'Gigablaster S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/893377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120320, 8608, 'Gigablaster S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/893378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120321, 8608, 'Gigablaster S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/893379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120322, 8608, 'Gigablaster S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/893380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oDj97ULgpbjwMhNUkZ174UuBlNm.jpg'),
(120323, 8609, 'Virei Vampira S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sL5JqT2lf2kkDxayHAtujjPEGt6.jpg'),
(120324, 8609, 'Virei Vampira S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uYbXKW3yEirEwQBW8t5CRC5sm3H.jpg'),
(120325, 8609, 'Virei Vampira S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qihrGM7XOdW1LL71LvTvtqe6FfP.jpg'),
(120326, 8609, 'Virei Vampira S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mApE0nl2wtIIN2zm6UA4mtXmNkg.jpg'),
(120327, 8609, 'Virei Vampira S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tmqfFe8Iy0b844fwi7GcXp6bU0U.jpg'),
(120328, 8609, 'Virei Vampira S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qJeLSxn49GZO8wAsdAlwPMMkgDf.jpg'),
(120329, 8609, 'Virei Vampira S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eyvfxn2Bu9eVBZB9fJvhJnifdmt.jpg'),
(120330, 8609, 'Virei Vampira S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/241129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bJrHGrrGo5EwBNZGdYRmUFjSeId.jpg'),
(120331, 8610, 'Virei Vampira S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c4MXxFdb9Z2LPtJgx7jsP8igkud.jpg'),
(120332, 8610, 'Virei Vampira S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c4MXxFdb9Z2LPtJgx7jsP8igkud.jpg'),
(120333, 8610, 'Virei Vampira S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c4MXxFdb9Z2LPtJgx7jsP8igkud.jpg'),
(120334, 8610, 'Virei Vampira S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/320937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c4MXxFdb9Z2LPtJgx7jsP8igkud.jpg'),
(120335, 8610, 'Virei Vampira S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c4MXxFdb9Z2LPtJgx7jsP8igkud.jpg'),
(120336, 8610, 'Virei Vampira S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c4MXxFdb9Z2LPtJgx7jsP8igkud.jpg'),
(120337, 8610, 'Virei Vampira S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/320940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c4MXxFdb9Z2LPtJgx7jsP8igkud.jpg'),
(120338, 8610, 'Virei Vampira S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/320941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c4MXxFdb9Z2LPtJgx7jsP8igkud.jpg'),
(120339, 8611, 'Aguas Impuras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/241028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wWapxAqrQECdJP7VqzFzUkAwEdC.jpg'),
(120340, 8611, 'Aguas Impuras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/241029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7ZQp8sXsXoiZWlxO4nMeAizKpe.jpg'),
(120341, 8611, 'Aguas Impuras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/241030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gP21s9oRoZDy65JNLDXsrXpMZ2H.jpg'),
(120342, 8611, 'Aguas Impuras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/241031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fTw1xIOokms8X1zCjtz6YGzmCC1.jpg'),
(120343, 8611, 'Aguas Impuras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/241032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2xgDPsf2yFfgrsK1E0UEMdnwc3I.jpg'),
(120344, 8611, 'Aguas Impuras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/241033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tfmRTJzpHVV42OPIZ0JcCmlgFQs.jpg'),
(120345, 8611, 'Aguas Impuras S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/241034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8f3lNL1B12bLFiXntki3XR5nK9C.jpg'),
(120346, 8612, 'As Fabulosas Aventuras de Moka S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120347, 8612, 'As Fabulosas Aventuras de Moka S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120348, 8612, 'As Fabulosas Aventuras de Moka S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120349, 8612, 'As Fabulosas Aventuras de Moka S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120350, 8612, 'As Fabulosas Aventuras de Moka S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120351, 8612, 'As Fabulosas Aventuras de Moka S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120352, 8612, 'As Fabulosas Aventuras de Moka S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120353, 8612, 'As Fabulosas Aventuras de Moka S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120354, 8612, 'As Fabulosas Aventuras de Moka S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120355, 8612, 'As Fabulosas Aventuras de Moka S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120356, 8612, 'As Fabulosas Aventuras de Moka S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120357, 8612, 'As Fabulosas Aventuras de Moka S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120358, 8612, 'As Fabulosas Aventuras de Moka S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/240962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120359, 8612, 'As Fabulosas Aventuras de Moka S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/240963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120360, 8612, 'As Fabulosas Aventuras de Moka S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/240964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120361, 8612, 'As Fabulosas Aventuras de Moka S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/240965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120362, 8612, 'As Fabulosas Aventuras de Moka S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/240966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120363, 8612, 'As Fabulosas Aventuras de Moka S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/240967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120364, 8612, 'As Fabulosas Aventuras de Moka S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/240968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120365, 8612, 'As Fabulosas Aventuras de Moka S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/240969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120366, 8612, 'As Fabulosas Aventuras de Moka S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/240970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120367, 8612, 'As Fabulosas Aventuras de Moka S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/240971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120368, 8612, 'As Fabulosas Aventuras de Moka S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/240972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120369, 8612, 'As Fabulosas Aventuras de Moka S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/240973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120370, 8612, 'As Fabulosas Aventuras de Moka S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/240974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120371, 8612, 'As Fabulosas Aventuras de Moka S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/240975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120372, 8612, 'As Fabulosas Aventuras de Moka S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/240976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120373, 8612, 'As Fabulosas Aventuras de Moka S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/240977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120374, 8612, 'As Fabulosas Aventuras de Moka S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/240978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120375, 8612, 'As Fabulosas Aventuras de Moka S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/240979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120376, 8612, 'As Fabulosas Aventuras de Moka S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/240980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120377, 8612, 'As Fabulosas Aventuras de Moka S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/240981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120378, 8612, 'As Fabulosas Aventuras de Moka S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/240982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120379, 8612, 'As Fabulosas Aventuras de Moka S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/240983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120380, 8612, 'As Fabulosas Aventuras de Moka S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/240984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120381, 8612, 'As Fabulosas Aventuras de Moka S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/240985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120382, 8612, 'As Fabulosas Aventuras de Moka S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/240986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120383, 8612, 'As Fabulosas Aventuras de Moka S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/240987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120384, 8612, 'As Fabulosas Aventuras de Moka S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/240988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120385, 8612, 'As Fabulosas Aventuras de Moka S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/240989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120386, 8612, 'As Fabulosas Aventuras de Moka S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/240990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120387, 8612, 'As Fabulosas Aventuras de Moka S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/240991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120388, 8612, 'As Fabulosas Aventuras de Moka S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/240992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120389, 8612, 'As Fabulosas Aventuras de Moka S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/240993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120390, 8612, 'As Fabulosas Aventuras de Moka S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/240994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120391, 8612, 'As Fabulosas Aventuras de Moka S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/240995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120392, 8612, 'As Fabulosas Aventuras de Moka S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/240996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120393, 8612, 'As Fabulosas Aventuras de Moka S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/240997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120394, 8612, 'As Fabulosas Aventuras de Moka S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/240998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120395, 8612, 'As Fabulosas Aventuras de Moka S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/240999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120396, 8612, 'As Fabulosas Aventuras de Moka S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/241000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120397, 8612, 'As Fabulosas Aventuras de Moka S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/241001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120398, 8612, 'As Fabulosas Aventuras de Moka S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/241002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120399, 8612, 'As Fabulosas Aventuras de Moka S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/241003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120400, 8612, 'As Fabulosas Aventuras de Moka S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/241004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120401, 8612, 'As Fabulosas Aventuras de Moka S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/241005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120402, 8612, 'As Fabulosas Aventuras de Moka S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/241006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(120403, 8612, 'As Fabulosas Aventuras de Moka S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/241007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120404, 8612, 'As Fabulosas Aventuras de Moka S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/241008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120405, 8612, 'As Fabulosas Aventuras de Moka S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/241009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120406, 8612, 'As Fabulosas Aventuras de Moka S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/241010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120407, 8612, 'As Fabulosas Aventuras de Moka S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/241011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120408, 8612, 'As Fabulosas Aventuras de Moka S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/241012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120409, 8612, 'As Fabulosas Aventuras de Moka S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/241013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120410, 8612, 'As Fabulosas Aventuras de Moka S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/241014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120411, 8612, 'As Fabulosas Aventuras de Moka S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/241015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120412, 8612, 'As Fabulosas Aventuras de Moka S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/241016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120413, 8612, 'As Fabulosas Aventuras de Moka S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/241017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120414, 8612, 'As Fabulosas Aventuras de Moka S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/241018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120415, 8612, 'As Fabulosas Aventuras de Moka S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/241019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120416, 8612, 'As Fabulosas Aventuras de Moka S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/241020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120417, 8612, 'As Fabulosas Aventuras de Moka S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/241021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120418, 8612, 'As Fabulosas Aventuras de Moka S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/241022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120419, 8612, 'As Fabulosas Aventuras de Moka S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/241023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120420, 8612, 'As Fabulosas Aventuras de Moka S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/241024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120421, 8612, 'As Fabulosas Aventuras de Moka S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/241025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120422, 8612, 'As Fabulosas Aventuras de Moka S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/241026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120423, 8612, 'As Fabulosas Aventuras de Moka S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/241027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a415VpWm41a5JlD92kq6xZp442K.jpg'),
(120424, 8613, 'Aventuras do Didi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120425, 8613, 'Aventuras do Didi S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120426, 8613, 'Aventuras do Didi S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120427, 8613, 'Aventuras do Didi S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120428, 8613, 'Aventuras do Didi S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120429, 8613, 'Aventuras do Didi S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120430, 8613, 'Aventuras do Didi S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120431, 8613, 'Aventuras do Didi S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120432, 8613, 'Aventuras do Didi S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120433, 8613, 'Aventuras do Didi S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120434, 8613, 'Aventuras do Didi S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120435, 8613, 'Aventuras do Didi S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120436, 8613, 'Aventuras do Didi S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/240897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120437, 8613, 'Aventuras do Didi S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/240898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120438, 8613, 'Aventuras do Didi S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/240899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120439, 8614, 'Aventuras do Didi S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120440, 8614, 'Aventuras do Didi S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120441, 8614, 'Aventuras do Didi S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120442, 8614, 'Aventuras do Didi S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120443, 8614, 'Aventuras do Didi S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120444, 8614, 'Aventuras do Didi S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120445, 8614, 'Aventuras do Didi S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120446, 8614, 'Aventuras do Didi S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120447, 8614, 'Aventuras do Didi S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120448, 8614, 'Aventuras do Didi S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120449, 8614, 'Aventuras do Didi S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120450, 8614, 'Aventuras do Didi S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120451, 8614, 'Aventuras do Didi S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/240912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120452, 8614, 'Aventuras do Didi S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/240913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120453, 8614, 'Aventuras do Didi S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/240914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120454, 8614, 'Aventuras do Didi S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/240915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120455, 8614, 'Aventuras do Didi S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/240916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120456, 8614, 'Aventuras do Didi S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/240917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120457, 8614, 'Aventuras do Didi S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/240918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120458, 8614, 'Aventuras do Didi S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/240919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120459, 8614, 'Aventuras do Didi S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/240920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120460, 8614, 'Aventuras do Didi S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/240921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120461, 8614, 'Aventuras do Didi S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/240922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120462, 8614, 'Aventuras do Didi S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/240923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120463, 8614, 'Aventuras do Didi S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/240924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120464, 8614, 'Aventuras do Didi S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/240925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120465, 8614, 'Aventuras do Didi S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/240926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120466, 8614, 'Aventuras do Didi S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/240927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120467, 8614, 'Aventuras do Didi S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/240928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120468, 8614, 'Aventuras do Didi S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/240929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120469, 8615, 'Aventuras do Didi S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120470, 8615, 'Aventuras do Didi S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120471, 8615, 'Aventuras do Didi S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120472, 8615, 'Aventuras do Didi S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120473, 8615, 'Aventuras do Didi S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120474, 8615, 'Aventuras do Didi S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120475, 8615, 'Aventuras do Didi S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120476, 8615, 'Aventuras do Didi S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120477, 8615, 'Aventuras do Didi S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120478, 8615, 'Aventuras do Didi S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120479, 8615, 'Aventuras do Didi S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120480, 8615, 'Aventuras do Didi S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120481, 8615, 'Aventuras do Didi S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/240942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120482, 8615, 'Aventuras do Didi S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/240943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120483, 8615, 'Aventuras do Didi S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/240944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120484, 8615, 'Aventuras do Didi S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/240945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120485, 8615, 'Aventuras do Didi S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/240946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120486, 8615, 'Aventuras do Didi S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/240947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120487, 8615, 'Aventuras do Didi S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/240948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120488, 8615, 'Aventuras do Didi S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/240949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7NKowhSN0SfK1VEcsfbFVWJ4NEM.jpg'),
(120489, 8616, 'Capitao Laserhawk Remix Blood Dragon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/won5DzaQa3AIjZBsf9Iu8Dfjudk.jpg'),
(120490, 8616, 'Capitao Laserhawk Remix Blood Dragon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dxvyoGupG1JihdAgD2gNLjOkAok.jpg'),
(120491, 8616, 'Capitao Laserhawk Remix Blood Dragon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mBtf84jvFkJYwGeJoBN42CZbevF.jpg'),
(120492, 8616, 'Capitao Laserhawk Remix Blood Dragon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7SyS0KowuRvKV8MufZMwYqrnLXo.jpg'),
(120493, 8616, 'Capitao Laserhawk Remix Blood Dragon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cXEy01hyWIaAdgmpjxI2xwteEOk.jpg'),
(120494, 8616, 'Capitao Laserhawk Remix Blood Dragon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9IWlXSACzM2QIVn32fls5zjkdvL.jpg'),
(120495, 8617, 'Cardfight Vanguard overDress [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8AmbEuGmvKdVjOpPVohopmqhKId.jpg'),
(120496, 8617, 'Cardfight Vanguard overDress [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hyjcZAwPDDhNMFX8Vj8gwWFxd4L.jpg'),
(120497, 8617, 'Cardfight Vanguard overDress [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oOn4NV5iBhpoYfZsRlq4bdztmyx.jpg'),
(120498, 8617, 'Cardfight Vanguard overDress [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pKzPDcREhWnxQC9Ctx3dZpG2RBH.jpg'),
(120499, 8617, 'Cardfight Vanguard overDress [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sRIDjpL7ziJrDllWckau7eu36mE.jpg'),
(120500, 8617, 'Cardfight Vanguard overDress [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3zG6upBVSxV9NreIrryWf11FYhK.jpg'),
(120501, 8617, 'Cardfight Vanguard overDress [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2gtcRz2xD5MWl5MfaXZOBtiLrmu.jpg'),
(120502, 8617, 'Cardfight Vanguard overDress [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9GSFegb6F5gFOn87Zq2Solbug2G.jpg'),
(120503, 8617, 'Cardfight Vanguard overDress [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qUoMlhmHJOd7x7almGGt3lM2hRP.jpg'),
(120504, 8617, 'Cardfight Vanguard overDress [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/52XM77BmnFgFRuqJHLX5z8ESFft.jpg'),
(120505, 8617, 'Cardfight Vanguard overDress [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s058od0Or3MRtf3s3gwkKiC9EoN.jpg'),
(120506, 8617, 'Cardfight Vanguard overDress [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fWiRo5tMVWx8KEMVBwDdE5Tlixg.jpg'),
(120507, 8618, 'Cardfight Vanguard overDress [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2l2EzPvGGPOgCYdETdUDwdSgSQB.jpg'),
(120508, 8618, 'Cardfight Vanguard overDress [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dKCXu88fNaHrm2NgIbuW0km9WDs.jpg'),
(120509, 8618, 'Cardfight Vanguard overDress [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Q8JUxprFmbp3Tq3Crg36D7Pfza.jpg'),
(120510, 8618, 'Cardfight Vanguard overDress [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kMvFYy0b2RgDrvktWvv4W7ETD5g.jpg'),
(120511, 8618, 'Cardfight Vanguard overDress [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8VgvfeYysbdkpqzfyoJWwe8wweg.jpg'),
(120512, 8618, 'Cardfight Vanguard overDress [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lz65mDEaJW3gKAOcLdIYwB5ph3W.jpg'),
(120513, 8618, 'Cardfight Vanguard overDress [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sl1IWg72AEQpN121xv92IfLKAff.jpg'),
(120514, 8618, 'Cardfight Vanguard overDress [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5uHLQPfKcdT1XL5okmkNXVOuaMq.jpg'),
(120515, 8618, 'Cardfight Vanguard overDress [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r4RdmmemcDs1Y3kQCX4tTMKgrcu.jpg'),
(120516, 8618, 'Cardfight Vanguard overDress [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4HbuBOhdIcm5h8Fy38qWAvKRqiG.jpg'),
(120517, 8618, 'Cardfight Vanguard overDress [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/28V8nZ3mlPQf10B6QCSrlFItJUr.jpg'),
(120518, 8618, 'Cardfight Vanguard overDress [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7S9L45kGYmREVJxjk8dtAVXWaEs.jpg'),
(120519, 8618, 'Cardfight Vanguard overDress [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sdNMwEGLzNSVQDAxv8kuzbKNqrj.jpg'),
(120520, 8619, 'Cardfight Vanguard overDress [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/19iDWspP030Zn0EHL8rt1CxSheO.jpg'),
(120521, 8619, 'Cardfight Vanguard overDress [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120522, 8619, 'Cardfight Vanguard overDress [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120523, 8619, 'Cardfight Vanguard overDress [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120524, 8619, 'Cardfight Vanguard overDress [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120525, 8619, 'Cardfight Vanguard overDress [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/apTGsMdq23MC3Bm4rUj36PxzBcB.jpg'),
(120526, 8619, 'Cardfight Vanguard overDress [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120527, 8619, 'Cardfight Vanguard overDress [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120528, 8619, 'Cardfight Vanguard overDress [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120529, 8619, 'Cardfight Vanguard overDress [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120530, 8619, 'Cardfight Vanguard overDress [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120531, 8619, 'Cardfight Vanguard overDress [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120532, 8619, 'Cardfight Vanguard overDress [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120533, 8620, 'Cardfight Vanguard overDress [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/htDk6GeANZvXZiDdjAgwYhWv9XW.jpg'),
(120534, 8620, 'Cardfight Vanguard overDress [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOueN0469GZrkLL7QoMiVPNkG8l.jpg'),
(120535, 8620, 'Cardfight Vanguard overDress [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x6DoleYs1DHn6qXGfc5e8lMPlJj.jpg'),
(120536, 8620, 'Cardfight Vanguard overDress [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a9uj761R4s7CvAyMEeQwEBknbtd.jpg'),
(120537, 8620, 'Cardfight Vanguard overDress [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ar6BordGrZZfgmxTuyZCh98JrdZ.jpg'),
(120538, 8620, 'Cardfight Vanguard overDress [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aqUjZoV0SDq6H4z1FdnYUQaqrDQ.jpg'),
(120539, 8620, 'Cardfight Vanguard overDress [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o0oPxJvW7IiaQXwYUMtxO21Zp4v.jpg'),
(120540, 8620, 'Cardfight Vanguard overDress [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9vew2G9ICnUBxIpFZ2pIoRWTXWV.jpg'),
(120541, 8620, 'Cardfight Vanguard overDress [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mEpTwX5Kq8YvXPNuhvWplEs6h4.jpg'),
(120542, 8620, 'Cardfight Vanguard overDress [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1tWeMpij10A4RjgKRyQi0trQmOa.jpg'),
(120543, 8620, 'Cardfight Vanguard overDress [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e6G3lxf2xYx5f6WSKLfcW0JUTY3.jpg'),
(120544, 8620, 'Cardfight Vanguard overDress [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXmr5eYRwfbN8NUvSH2cB1scb7R.jpg'),
(120545, 8621, 'Cardfight Vanguard overDress [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120546, 8621, 'Cardfight Vanguard overDress [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120547, 8621, 'Cardfight Vanguard overDress [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120548, 8621, 'Cardfight Vanguard overDress [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120549, 8621, 'Cardfight Vanguard overDress [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120550, 8621, 'Cardfight Vanguard overDress [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120551, 8621, 'Cardfight Vanguard overDress [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120552, 8621, 'Cardfight Vanguard overDress [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120553, 8621, 'Cardfight Vanguard overDress [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120554, 8621, 'Cardfight Vanguard overDress [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120555, 8621, 'Cardfight Vanguard overDress [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120556, 8621, 'Cardfight Vanguard overDress [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120557, 8621, 'Cardfight Vanguard overDress [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120558, 8622, 'Cardfight Vanguard overDress [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120559, 8622, 'Cardfight Vanguard overDress [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120560, 8622, 'Cardfight Vanguard overDress [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120561, 8622, 'Cardfight Vanguard overDress [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120562, 8622, 'Cardfight Vanguard overDress [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120563, 8622, 'Cardfight Vanguard overDress [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/276817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120564, 8622, 'Cardfight Vanguard overDress [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120565, 8622, 'Cardfight Vanguard overDress [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/298104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120566, 8622, 'Cardfight Vanguard overDress [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/305434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120567, 8622, 'Cardfight Vanguard overDress [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/309197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120568, 8622, 'Cardfight Vanguard overDress [L] S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/316187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120569, 8622, 'Cardfight Vanguard overDress [L] S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/326305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120570, 8622, 'Cardfight Vanguard overDress [L] S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/330755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120571, 8623, 'Cardfight Vanguard overDress [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120572, 8623, 'Cardfight Vanguard overDress [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/409377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120573, 8623, 'Cardfight Vanguard overDress [L] S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/419786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120574, 8623, 'Cardfight Vanguard overDress [L] S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/419787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120575, 8623, 'Cardfight Vanguard overDress [L] S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120576, 8623, 'Cardfight Vanguard overDress [L] S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/432600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120577, 8623, 'Cardfight Vanguard overDress [L] S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/437163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120578, 8623, 'Cardfight Vanguard overDress [L] S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/448299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120579, 8623, 'Cardfight Vanguard overDress [L] S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/448300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120580, 8623, 'Cardfight Vanguard overDress [L] S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/478538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120581, 8623, 'Cardfight Vanguard overDress [L] S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/478539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120582, 8623, 'Cardfight Vanguard overDress [L] S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/478540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120583, 8623, 'Cardfight Vanguard overDress [L] S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/478541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yOIWtLLMSFZkKizXXweTxEEQj6i.jpg'),
(120584, 8624, 'Codex 632 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/77PtQYEwOiFfto8Nadckod9O4Lo.jpg'),
(120585, 8624, 'Codex 632 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rhfQFDbvr9TnqCqoYUHW3ZjrPxF.jpg'),
(120586, 8624, 'Codex 632 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/voUb5IoepokgCaxnuF1jPs2JkhY.jpg'),
(120587, 8624, 'Codex 632 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lE7Fs2PJgQGkttTEyq7zph4E75F.jpg'),
(120588, 8624, 'Codex 632 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lE7Fs2PJgQGkttTEyq7zph4E75F.jpg'),
(120589, 8624, 'Codex 632 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lE7Fs2PJgQGkttTEyq7zph4E75F.jpg'),
(120590, 8625, 'Garotas em Chamas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xH4oHROIaNz1cYa5M4YzMHgIsvT.jpg'),
(120591, 8625, 'Garotas em Chamas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vjM7vVhuriHQOOqxxyMl1Z16L3Y.jpg'),
(120592, 8625, 'Garotas em Chamas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glYWL5kG0COuBWpDkmFdhkvg4Zl.jpg'),
(120593, 8625, 'Garotas em Chamas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2xfmc6ExGbpM0qfkPwhjK3xVOU.jpg'),
(120594, 8625, 'Garotas em Chamas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Chj4rz3FuuOaOqu2aUzqRNejFs.jpg'),
(120595, 8625, 'Garotas em Chamas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3aT6fUzO3QNfVFHyzUNUkPLlsVi.jpg'),
(120596, 8626, 'How To Be a Carioca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJOSq06l3uSvHGA1wNYNs8wpjMz.jpg'),
(120597, 8626, 'How To Be a Carioca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gt4sdZbCkTgHtCTZPDt0aFAKrKX.jpg'),
(120598, 8626, 'How To Be a Carioca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ompLBuLAMmjN2NjWzSL4PvNZzPq.jpg'),
(120599, 8626, 'How To Be a Carioca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dDly5I1gK7X98GdXYgP6iIRD480.jpg'),
(120600, 8626, 'How To Be a Carioca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oDOaGUFfXwzEw3W2HhHootVO3fu.jpg'),
(120601, 8626, 'How To Be a Carioca S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9L2Q30ftETfPEi3qotGuidWWFV6.jpg'),
(120602, 8627, 'Neon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uKEmHAL7uBele2adsD19uw2CwNs.jpg'),
(120603, 8627, 'Neon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/14DPWRyP82HWYE0gDfnZSkR9GBS.jpg'),
(120604, 8627, 'Neon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFjCQnY74GoIZpF1jM3LRzsW2zL.jpg'),
(120605, 8627, 'Neon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s9nXXPdApZPxMK6OWHig0wx6aI6.jpg'),
(120606, 8627, 'Neon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wfsBxWddMOxnBrVsBQ7CRX2OxPt.jpg'),
(120607, 8627, 'Neon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gD1lyy2An3FxxcJAmyxfvULRV2D.jpg'),
(120608, 8627, 'Neon S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/opDJWgTNydUZ34xIrYMaFiAHFiM.jpg'),
(120609, 8627, 'Neon S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kcEekDVdnj8g50bjJUfZH079bgC.jpg'),
(120610, 8628, 'Os Reinos da Ruina [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iG2qtp6r5HFPakBAD17Kx5ysmT8.jpg'),
(120611, 8628, 'Os Reinos da Ruina [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ax8ePIBGZCYhupvuGbtmqekuoo0.jpg'),
(120612, 8628, 'Os Reinos da Ruina [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qdF4MnYEzXP0E9IrMP5IfopyOMO.jpg'),
(120613, 8628, 'Os Reinos da Ruina [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qdF4MnYEzXP0E9IrMP5IfopyOMO.jpg'),
(120614, 8628, 'Os Reinos da Ruina [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qdF4MnYEzXP0E9IrMP5IfopyOMO.jpg'),
(120615, 8628, 'Os Reinos da Ruina [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qdF4MnYEzXP0E9IrMP5IfopyOMO.jpg'),
(120616, 8628, 'Os Reinos da Ruina [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qdF4MnYEzXP0E9IrMP5IfopyOMO.jpg'),
(120617, 8628, 'Os Reinos da Ruina [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qdF4MnYEzXP0E9IrMP5IfopyOMO.jpg'),
(120618, 8628, 'Os Reinos da Ruina [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qdF4MnYEzXP0E9IrMP5IfopyOMO.jpg'),
(120619, 8628, 'Os Reinos da Ruina [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qdF4MnYEzXP0E9IrMP5IfopyOMO.jpg'),
(120620, 8628, 'Os Reinos da Ruina [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qdF4MnYEzXP0E9IrMP5IfopyOMO.jpg'),
(120621, 8628, 'Os Reinos da Ruina [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qdF4MnYEzXP0E9IrMP5IfopyOMO.jpg'),
(120622, 8629, 'Payback [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2SmQEpTsauhJW1qVj0p2X9ot2CY.jpg'),
(120623, 8629, 'Payback [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uiHmuB4kmNxfcKfjjSdTBaTxXm1.jpg'),
(120624, 8629, 'Payback [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dcWpNaV1bF2ixb4kGZSvk8hz0wP.jpg'),
(120625, 8629, 'Payback [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gnuNdADsF17wt0Bt5PpfKGklxX8.jpg'),
(120626, 8629, 'Payback [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/304d8WxCSJavBT1OQALub77qA6j.jpg'),
(120627, 8629, 'Payback [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/thL16muQZ3z2hxaBVrn1ML4nHPr.jpg'),
(120628, 8630, 'Planeta dos Abutres S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2xhFCQfTe9SYEKKduGgMjHmgPGe.jpg'),
(120629, 8630, 'Planeta dos Abutres S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vPdGZPnPOmG9uJLOpS8hmn1KiNS.jpg'),
(120630, 8630, 'Planeta dos Abutres S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ofEMIshpcW9zYlthXrbSbGrhdn.jpg'),
(120631, 8630, 'Planeta dos Abutres S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sGEJyxvW5F9MTjPbXvInVFI5KYS.jpg'),
(120632, 8630, 'Planeta dos Abutres S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sGEJyxvW5F9MTjPbXvInVFI5KYS.jpg'),
(120633, 8630, 'Planeta dos Abutres S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sGEJyxvW5F9MTjPbXvInVFI5KYS.jpg'),
(120634, 8630, 'Planeta dos Abutres S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sGEJyxvW5F9MTjPbXvInVFI5KYS.jpg'),
(120635, 8630, 'Planeta dos Abutres S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sGEJyxvW5F9MTjPbXvInVFI5KYS.jpg'),
(120636, 8630, 'Planeta dos Abutres S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sGEJyxvW5F9MTjPbXvInVFI5KYS.jpg'),
(120637, 8630, 'Planeta dos Abutres S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sGEJyxvW5F9MTjPbXvInVFI5KYS.jpg'),
(120638, 8630, 'Planeta dos Abutres S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/238800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sGEJyxvW5F9MTjPbXvInVFI5KYS.jpg'),
(120639, 8630, 'Planeta dos Abutres S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/238801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sGEJyxvW5F9MTjPbXvInVFI5KYS.jpg'),
(120640, 8631, 'The Eddy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kyTvgJ9segeyiiB24xKBWualP3h.jpg'),
(120641, 8631, 'The Eddy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uG4TYostMdWftKFp83arJBSBHYY.jpg'),
(120642, 8631, 'The Eddy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQ6PVpeC7rBNxgoWuPIFFfIz1wI.jpg'),
(120643, 8631, 'The Eddy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7FOJ64XnavqTCmquK8UtbAJpSss.jpg'),
(120644, 8631, 'The Eddy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vS3mpQzMzqN79mlXuRhPsGst9rQ.jpg'),
(120645, 8631, 'The Eddy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eB1NNYDBquINNiq1mHunHvbvkcU.jpg'),
(120646, 8631, 'The Eddy S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wgeh8YhE9SG1hyxIqlFwPuUjin9.jpg'),
(120647, 8631, 'The Eddy S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6aP7nnESPnJSCMiHIGrlWmwxjRb.jpg'),
(120648, 8632, 'The Long Shadow [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gT3GbfJVf76MUydETpHjZC5Rrqz.jpg'),
(120649, 8632, 'The Long Shadow [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2wLRRzGbhyEVMcO8uzLnuMEVNIB.jpg'),
(120650, 8632, 'The Long Shadow [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lO3pAEsZqBPvrUHRjMMJSK3TogG.jpg'),
(120651, 8632, 'The Long Shadow [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wwwpmFy8qg9ytM2geRb8OlmxPkR.jpg'),
(120652, 8632, 'The Long Shadow [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wwwpmFy8qg9ytM2geRb8OlmxPkR.jpg'),
(120653, 8632, 'The Long Shadow [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wwwpmFy8qg9ytM2geRb8OlmxPkR.jpg'),
(120654, 8632, 'The Long Shadow [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wwwpmFy8qg9ytM2geRb8OlmxPkR.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(120655, 8633, 'Toaru Ossan no VRMMO Katsudouki [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfa58MPPin1VbePPBh9G2111EhX.jpg'),
(120656, 8633, 'Toaru Ossan no VRMMO Katsudouki [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bWKZZMyYRqD3sllK25oi28Pltlf.jpg'),
(120657, 8633, 'Toaru Ossan no VRMMO Katsudouki [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oc7o0B3GsdlDlqHJOpPe26yWoxS.jpg'),
(120658, 8633, 'Toaru Ossan no VRMMO Katsudouki [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sCLrdFdsweruRFLdN1DytcwHBZw.jpg'),
(120659, 8633, 'Toaru Ossan no VRMMO Katsudouki [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sCLrdFdsweruRFLdN1DytcwHBZw.jpg'),
(120660, 8633, 'Toaru Ossan no VRMMO Katsudouki [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sCLrdFdsweruRFLdN1DytcwHBZw.jpg'),
(120661, 8633, 'Toaru Ossan no VRMMO Katsudouki [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sCLrdFdsweruRFLdN1DytcwHBZw.jpg'),
(120662, 8633, 'Toaru Ossan no VRMMO Katsudouki [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sCLrdFdsweruRFLdN1DytcwHBZw.jpg'),
(120663, 8633, 'Toaru Ossan no VRMMO Katsudouki [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sCLrdFdsweruRFLdN1DytcwHBZw.jpg'),
(120664, 8633, 'Toaru Ossan no VRMMO Katsudouki [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sCLrdFdsweruRFLdN1DytcwHBZw.jpg'),
(120665, 8633, 'Toaru Ossan no VRMMO Katsudouki [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sCLrdFdsweruRFLdN1DytcwHBZw.jpg'),
(120666, 8634, 'Tom Jones [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUYbW50gMvtHegdP0JlcFI9n7oK.jpg'),
(120667, 8634, 'Tom Jones [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2vIzdP9gk82WhuMip3gy74VMVx.jpg'),
(120668, 8634, 'Tom Jones [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gnKqVlrJn1zKhcCT6euvu9dBXbM.jpg'),
(120669, 8634, 'Tom Jones [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gnKqVlrJn1zKhcCT6euvu9dBXbM.jpg'),
(120670, 8635, 'Undead Unluck [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mm24ssp8ngEmNAc2lNDK1LVQqp1.jpg'),
(120671, 8635, 'Undead Unluck [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/volxC7yHHs7T1F1yMTZ8zSo2aQs.jpg'),
(120672, 8635, 'Undead Unluck [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120673, 8635, 'Undead Unluck [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120674, 8635, 'Undead Unluck [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120675, 8635, 'Undead Unluck [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120676, 8635, 'Undead Unluck [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120677, 8635, 'Undead Unluck [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120678, 8635, 'Undead Unluck [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120679, 8635, 'Undead Unluck [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120680, 8635, 'Undead Unluck [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120681, 8635, 'Undead Unluck [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120682, 8635, 'Undead Unluck [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120683, 8635, 'Undead Unluck [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120684, 8635, 'Undead Unluck [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120685, 8635, 'Undead Unluck [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120686, 8635, 'Undead Unluck [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/274899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120687, 8635, 'Undead Unluck [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/274900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120688, 8635, 'Undead Unluck [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/279349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120689, 8635, 'Undead Unluck [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/288399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120690, 8635, 'Undead Unluck [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/296631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120691, 8635, 'Undead Unluck [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/298970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120692, 8635, 'Undead Unluck [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/309539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120693, 8635, 'Undead Unluck [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/309540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qC3eZxOiD9RkQ2sXWIxw26NwawZ.jpg'),
(120694, 8636, 'A Criatura S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fe7BzM7FjsxMV2XTkGmKPV4oXB3.jpg'),
(120695, 8636, 'A Criatura S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3dZJXrwfL7wD9EgG0Llp14Oc0HI.jpg'),
(120696, 8636, 'A Criatura S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jv9ca8kzFuWrPg9mcQsO9MVHM2x.jpg'),
(120697, 8636, 'A Criatura S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/amyUoQr2FIhLZ8Qqap3cQdBml7F.jpg'),
(120698, 8636, 'A Criatura S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/se0NLZgsmbJn8pIUB9nM6WsqGb1.jpg'),
(120699, 8636, 'A Criatura S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8gU1VgQmvNzLxVEQVDyq2r8Hwcm.jpg'),
(120700, 8636, 'A Criatura S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sPQeYq0k8EC79WE8Npg1sp2r8qp.jpg'),
(120701, 8636, 'A Criatura S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1RLir1lvclK8Zard27IRLjncG7Y.jpg'),
(120702, 8637, 'Doona S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q9IvTHyzOkY9k5wPfEKRBNqZkA7.jpg'),
(120703, 8637, 'Doona S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Tj1jcR2OiTI8Q2AUk1ok1UtlgK.jpg'),
(120704, 8637, 'Doona S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zrnJZQ1hnZdRRnE6YvE5PL4N4NM.jpg'),
(120705, 8637, 'Doona S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dVYmqMPuzSbUjlyeI9reac3IJpW.jpg'),
(120706, 8637, 'Doona S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jMQ1zVvoanKRM5EXmyhVBSwCmLX.jpg'),
(120707, 8637, 'Doona S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l0JdcTKTLt9g7j3wFOCMR70Kveb.jpg'),
(120708, 8637, 'Doona S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jQ1uErVpWLaBp6wU9Ofan3fkKnx.jpg'),
(120709, 8637, 'Doona S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jDsUbEl5T0BAwr3ILGGa5mCDzSt.jpg'),
(120710, 8637, 'Doona S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yyE2R6C30NKY9OPwd8IlQq1hCe0.jpg'),
(120711, 8638, 'Sobrevivendo a Amazonia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBaYLvQe8vAdzuLE3hsebK7U8li.jpg'),
(120712, 8638, 'Sobrevivendo a Amazonia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBaYLvQe8vAdzuLE3hsebK7U8li.jpg'),
(120713, 8638, 'Sobrevivendo a Amazonia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBaYLvQe8vAdzuLE3hsebK7U8li.jpg'),
(120714, 8638, 'Sobrevivendo a Amazonia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBaYLvQe8vAdzuLE3hsebK7U8li.jpg'),
(120715, 8638, 'Sobrevivendo a Amazonia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iBaYLvQe8vAdzuLE3hsebK7U8li.jpg'),
(120716, 8639, 'Tiny Toons Looniversidade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/de6tfdWDUaG4eiLNFcH0JPmf0ol.jpg'),
(120717, 8639, 'Tiny Toons Looniversidade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5sjPgzbY9LRLpUa8jm3QjDbXfE.jpg'),
(120718, 8639, 'Tiny Toons Looniversidade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3VFz1wkppAVBKCg2abYOwyr3Am7.jpg'),
(120719, 8639, 'Tiny Toons Looniversidade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0J2PHSseImTT14v9ST90jHppKr.jpg'),
(120720, 8639, 'Tiny Toons Looniversidade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mPS7AXJQ3uzwqm3VYWcPNt5P61p.jpg'),
(120721, 8639, 'Tiny Toons Looniversidade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bH75I4lBKgI0pvEDuWfpsPfcIrB.jpg'),
(120722, 8639, 'Tiny Toons Looniversidade S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h9Z2pA5HJjxsHwdYCGkVwvVR0um.jpg'),
(120723, 8639, 'Tiny Toons Looniversidade S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ydyWbXJBP3ruOqmJby2PhKEsqsG.jpg'),
(120724, 8639, 'Tiny Toons Looniversidade S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lr2SiYKUMfvkG1IdSK5cAbOe8ZL.jpg'),
(120725, 8639, 'Tiny Toons Looniversidade S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kShT6mbp0iHfZ5dMLRmPlIvZQi6.jpg'),
(120726, 8640, '8 em Istambul S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jH66JOwRDnCbW1GuJCToIOvta45.jpg'),
(120727, 8640, '8 em Istambul S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/noix3xb675JsNvGWlMWR0hWpsB0.jpg'),
(120728, 8640, '8 em Istambul S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bRR7Jo0Yi433QNXUrUlJZiZNjUK.jpg'),
(120729, 8640, '8 em Istambul S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t6SNO9spQdS0actOjUwKcv9P9WB.jpg'),
(120730, 8640, '8 em Istambul S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1kY9grzk2TDihBIzsklVqusYAq7.jpg'),
(120731, 8640, '8 em Istambul S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bOPEtW0GRJkW0UFJeVimzKNRI4A.jpg'),
(120732, 8640, '8 em Istambul S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n58TicPNGWBR2uMutyjxXgAOzkJ.jpg'),
(120733, 8640, '8 em Istambul S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oRYFo3vfE1jAYjX8uLtZpnvx7Le.jpg'),
(120734, 8641, 'A Australia Mortal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zVDmJQKZcWB3m1ddjZYkrNlCdJe.jpg'),
(120735, 8641, 'A Australia Mortal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zVDmJQKZcWB3m1ddjZYkrNlCdJe.jpg'),
(120736, 8641, 'A Australia Mortal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zVDmJQKZcWB3m1ddjZYkrNlCdJe.jpg'),
(120737, 8641, 'A Australia Mortal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zVDmJQKZcWB3m1ddjZYkrNlCdJe.jpg'),
(120738, 8642, 'B.A. O Futuro Esta Morto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zX0cW4XQx1QJ8rWqETQP36G3ZUR.jpg'),
(120739, 8642, 'B.A. O Futuro Esta Morto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cJHTEJlHqkUcboLtETqFY5SGsch.jpg'),
(120740, 8642, 'B.A. O Futuro Esta Morto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ckhxs6gIZ9icU8ngLt9m9f7hFaV.jpg'),
(120741, 8642, 'B.A. O Futuro Esta Morto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gEmz8c9iDH261jiiCKVcVXT06D6.jpg'),
(120742, 8642, 'B.A. O Futuro Esta Morto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gEmz8c9iDH261jiiCKVcVXT06D6.jpg'),
(120743, 8642, 'B.A. O Futuro Esta Morto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gEmz8c9iDH261jiiCKVcVXT06D6.jpg'),
(120744, 8642, 'B.A. O Futuro Esta Morto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gEmz8c9iDH261jiiCKVcVXT06D6.jpg'),
(120745, 8642, 'B.A. O Futuro Esta Morto S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gEmz8c9iDH261jiiCKVcVXT06D6.jpg'),
(120746, 8643, 'Batalha dos Alfas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120747, 8643, 'Batalha dos Alfas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120748, 8643, 'Batalha dos Alfas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120749, 8643, 'Batalha dos Alfas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120750, 8643, 'Batalha dos Alfas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120751, 8643, 'Batalha dos Alfas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120752, 8643, 'Batalha dos Alfas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120753, 8643, 'Batalha dos Alfas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120754, 8643, 'Batalha dos Alfas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120755, 8643, 'Batalha dos Alfas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120756, 8643, 'Batalha dos Alfas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120757, 8643, 'Batalha dos Alfas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120758, 8644, 'Batalha dos Alfas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120759, 8644, 'Batalha dos Alfas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120760, 8644, 'Batalha dos Alfas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120761, 8644, 'Batalha dos Alfas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120762, 8644, 'Batalha dos Alfas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120763, 8644, 'Batalha dos Alfas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120764, 8644, 'Batalha dos Alfas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120765, 8644, 'Batalha dos Alfas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120766, 8644, 'Batalha dos Alfas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120767, 8644, 'Batalha dos Alfas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120768, 8644, 'Batalha dos Alfas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120769, 8644, 'Batalha dos Alfas S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mpDWaG2XQAKisj48WvW0D7YgFD3.jpg'),
(120770, 8645, 'Color Rush [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/81iMHB6qVlioDLTbshl8WblnDl0.jpg'),
(120771, 8645, 'Color Rush [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ctEugiy3DLNaNMiDLLp72wAopdi.jpg'),
(120772, 8645, 'Color Rush [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9udpIshVsCFQcqwj26WdmW5XBW.jpg'),
(120773, 8645, 'Color Rush [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSqvEpSZlF2zeNpWlt71GNrojua.jpg'),
(120774, 8645, 'Color Rush [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p05GralneDzMuFcQyllmcacaTJV.jpg'),
(120775, 8645, 'Color Rush [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wvhUN3cKqCBkv6O83TxiO0N99Dw.jpg'),
(120776, 8645, 'Color Rush [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mH9Xuic6QuYel1INOL4MwMtDfwU.jpg'),
(120777, 8645, 'Color Rush [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aCEfjak2s2JczAqw8eX0YHmTO5y.jpg'),
(120778, 8646, 'Color Rush [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/330672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dy1tMGiQJC4gRwrka2BSYZTGnRf.jpg'),
(120779, 8646, 'Color Rush [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/330673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dy1tMGiQJC4gRwrka2BSYZTGnRf.jpg'),
(120780, 8646, 'Color Rush [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/330674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dy1tMGiQJC4gRwrka2BSYZTGnRf.jpg'),
(120781, 8646, 'Color Rush [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/330675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dy1tMGiQJC4gRwrka2BSYZTGnRf.jpg'),
(120782, 8646, 'Color Rush [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/330676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dy1tMGiQJC4gRwrka2BSYZTGnRf.jpg'),
(120783, 8646, 'Color Rush [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/330677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dy1tMGiQJC4gRwrka2BSYZTGnRf.jpg'),
(120784, 8646, 'Color Rush [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/330678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dy1tMGiQJC4gRwrka2BSYZTGnRf.jpg'),
(120785, 8646, 'Color Rush [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/330679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dy1tMGiQJC4gRwrka2BSYZTGnRf.jpg'),
(120786, 8647, 'Copenhagen Cowboy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUZ5VazJUhZ8gIs9WHmvWVCOn1g.jpg'),
(120787, 8647, 'Copenhagen Cowboy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wSZN5DSN1ISq2RjL6Ec4puqRjyn.jpg'),
(120788, 8647, 'Copenhagen Cowboy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cOxLNY6S4nizIA3VaaobkfnVMgG.jpg'),
(120789, 8647, 'Copenhagen Cowboy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OPgZ5qzF1CnGomMaihhGpyy3u9.jpg'),
(120790, 8647, 'Copenhagen Cowboy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/beDIsUSDUvmb6XssoWr9nF9j8LD.jpg'),
(120791, 8647, 'Copenhagen Cowboy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tdzLZBrll8fJMHmwN8yIxmibFSm.jpg'),
(120792, 8648, 'Criaturas Estranhas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7U0agXw5q8lKxYcRv9zO1eXtYHn.jpg'),
(120793, 8648, 'Criaturas Estranhas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7U0agXw5q8lKxYcRv9zO1eXtYHn.jpg'),
(120794, 8648, 'Criaturas Estranhas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7U0agXw5q8lKxYcRv9zO1eXtYHn.jpg'),
(120795, 8648, 'Criaturas Estranhas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7U0agXw5q8lKxYcRv9zO1eXtYHn.jpg'),
(120796, 8648, 'Criaturas Estranhas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7U0agXw5q8lKxYcRv9zO1eXtYHn.jpg'),
(120797, 8648, 'Criaturas Estranhas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7U0agXw5q8lKxYcRv9zO1eXtYHn.jpg'),
(120798, 8648, 'Criaturas Estranhas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7U0agXw5q8lKxYcRv9zO1eXtYHn.jpg'),
(120799, 8649, 'Criaturas Estranhas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7U0agXw5q8lKxYcRv9zO1eXtYHn.jpg'),
(120800, 8649, 'Criaturas Estranhas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7U0agXw5q8lKxYcRv9zO1eXtYHn.jpg'),
(120801, 8649, 'Criaturas Estranhas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7U0agXw5q8lKxYcRv9zO1eXtYHn.jpg'),
(120802, 8649, 'Criaturas Estranhas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7U0agXw5q8lKxYcRv9zO1eXtYHn.jpg'),
(120803, 8649, 'Criaturas Estranhas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7U0agXw5q8lKxYcRv9zO1eXtYHn.jpg'),
(120804, 8649, 'Criaturas Estranhas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7U0agXw5q8lKxYcRv9zO1eXtYHn.jpg'),
(120805, 8650, 'Diversao Animal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kfBemIOKMsnOTO7NwOkRm6fgh4l.jpg'),
(120806, 8650, 'Diversao Animal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4UUR2LwvXZaE9rR4YJkk10e0wOV.jpg'),
(120807, 8651, 'Dora a Aventureira S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n6CwkkaYWKyZaw3meZRbFNCnaFQ.jpg'),
(120808, 8651, 'Dora a Aventureira S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hAiGOKHdzRioC61n7VYWr74ABTE.jpg'),
(120809, 8651, 'Dora a Aventureira S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mSdoAFwpaKB8Tp0nb8U1hcHh47I.jpg'),
(120810, 8651, 'Dora a Aventureira S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gzUrKX3HP20GTXHkNKLyl3aRdDP.jpg'),
(120811, 8651, 'Dora a Aventureira S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7jxlsnercYK9TXDmRRXHZfiWirH.jpg'),
(120812, 8651, 'Dora a Aventureira S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bh95ySnhpIwInJ3b8apW66B96Hm.jpg'),
(120813, 8651, 'Dora a Aventureira S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lKvktOF0tJx6OvxlBkcqbVuG8od.jpg'),
(120814, 8651, 'Dora a Aventureira S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tWDTHlfYagPHoGwaKzpi0IWjHxT.jpg'),
(120815, 8651, 'Dora a Aventureira S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fzXtBnIu9vxFjVFpOV7gOtZJsH9.jpg'),
(120816, 8651, 'Dora a Aventureira S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rUNWxw6xaIoOXN1feR5O9DqKrxT.jpg'),
(120817, 8651, 'Dora a Aventureira S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMp7wpbfV6Y4HbuqItivOst5zql.jpg'),
(120818, 8651, 'Dora a Aventureira S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wASsiRZnV7SSGTeX206u78cGbii.jpg'),
(120819, 8651, 'Dora a Aventureira S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/240133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j6kD4hqUg9QzmPsiT7HjUUG3nUv.jpg'),
(120820, 8651, 'Dora a Aventureira S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/240134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5z8ylvnlTGu8xP1KvKCn0AQb2UP.jpg'),
(120821, 8651, 'Dora a Aventureira S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/240135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/khtc8dU6liaBRRUIq1KmtjifrdC.jpg'),
(120822, 8651, 'Dora a Aventureira S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/240136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nW3NDGcWOcmFgJtxAWBE8m6js7t.jpg'),
(120823, 8651, 'Dora a Aventureira S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/240137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rcx6RNAc5DVvrS58p5dklZRD3kX.jpg'),
(120824, 8651, 'Dora a Aventureira S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/240138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sBadOoiABD3aC2itt14rWlUksXf.jpg'),
(120825, 8651, 'Dora a Aventureira S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/240139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vwXDpveSPjyG5rFaV7zwvQUa7IF.jpg'),
(120826, 8651, 'Dora a Aventureira S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/240140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vk7BKwM06hY0PgWz5aBcYWrAAUC.jpg'),
(120827, 8651, 'Dora a Aventureira S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/240141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rDg5jq9BUkkNgz3Zhkg0gIgsfFs.jpg'),
(120828, 8651, 'Dora a Aventureira S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/240142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3P1gaH9GkazQb3iWCmRfo4AODon.jpg'),
(120829, 8651, 'Dora a Aventureira S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/240143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xSZ6XpOdomeylWvgBmsEXBgv3ed.jpg'),
(120830, 8651, 'Dora a Aventureira S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/240144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tsooKTBxvEBQBY4KaMSKfDSgnpT.jpg'),
(120831, 8651, 'Dora a Aventureira S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/240145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6q3KROjNpja7I6w0Yq1BU7YcyOP.jpg'),
(120832, 8651, 'Dora a Aventureira S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/240146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nHxfcHwISyiVgfHWXbUqAIHGelm.jpg'),
(120833, 8652, 'Dora a Aventureira S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/spnXAuGDHlKc2Yzu9dqgjpz48XG.jpg'),
(120834, 8652, 'Dora a Aventureira S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u0u4vuT4OQGHt6JigedPZCMOGb8.jpg'),
(120835, 8652, 'Dora a Aventureira S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCYog3hl30Aut8xrGM3hMnlls4X.jpg'),
(120836, 8652, 'Dora a Aventureira S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2jCUE5Z5AU4LtkuuTEXzHmEq9U4.jpg'),
(120837, 8652, 'Dora a Aventureira S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vL7PlJMHWQvGgv4fm8ulqdcNlpw.jpg'),
(120838, 8652, 'Dora a Aventureira S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n0FuPHkVTGV8WxlEdTVu5meO8qh.jpg'),
(120839, 8652, 'Dora a Aventureira S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUTjOpVtGVl6EaqqVUtj1CHS3KG.jpg'),
(120840, 8652, 'Dora a Aventureira S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dtX0FEhN13RqjMd8usxwHDM3WR3.jpg'),
(120841, 8652, 'Dora a Aventureira S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lWggIez5m8LmuHL4is9NLDhNDfV.jpg'),
(120842, 8652, 'Dora a Aventureira S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4jFWZhnaUbkoYwUylYHN9kEMZec.jpg'),
(120843, 8652, 'Dora a Aventureira S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w4oKb0j2rtwea5jlMk15Bb0XPlC.jpg'),
(120844, 8652, 'Dora a Aventureira S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Ah1uwyDRBDw9QWeQ6DGqgmAkJA.jpg'),
(120845, 8652, 'Dora a Aventureira S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/240159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Lsw2PWLq5WVxE6R8nscAig4orh.jpg'),
(120846, 8652, 'Dora a Aventureira S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/240160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f8v3ZiNBPZVIYw3V8MnfyL2IjbZ.jpg'),
(120847, 8652, 'Dora a Aventureira S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/240161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/siKLE91cm4CoBXypZV52qlxb1jE.jpg'),
(120848, 8652, 'Dora a Aventureira S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/240162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1IStoAeGPQhhcOs7aUmAJOFnABg.jpg'),
(120849, 8652, 'Dora a Aventureira S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/240163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lKQYALqFvNrzYpNVp6WamC9tSKz.jpg'),
(120850, 8652, 'Dora a Aventureira S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/240164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dRVx57hba4oyAYF9OrT7p89bTp.jpg'),
(120851, 8652, 'Dora a Aventureira S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/240165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/upmR5EFlqtVBQIuN82Q8IaHnaE7.jpg'),
(120852, 8652, 'Dora a Aventureira S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/240166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i4uVy6MwPIcy3vqNoys094bVxKC.jpg'),
(120853, 8652, 'Dora a Aventureira S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/240167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p5uxt0olA6fke4qGZWr16dchGia.jpg'),
(120854, 8652, 'Dora a Aventureira S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/240168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/LlFHBjHg1AXZy81YxkKt3HtJlu.jpg'),
(120855, 8652, 'Dora a Aventureira S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/240169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wjHEUIe8HfwJbdraeTaeciJfwTD.jpg'),
(120856, 8652, 'Dora a Aventureira S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/240170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4RLQLut03ypKmQfomwHN95j9erW.jpg'),
(120857, 8652, 'Dora a Aventureira S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/240171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wmGmtPee67DN549IP1M3XuoEF2W.jpg'),
(120858, 8652, 'Dora a Aventureira S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/240172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zuXqADO4KUqfUFxHWSy4WPzdZs7.jpg'),
(120859, 8653, 'Dora a Aventureira S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fiS84RN45Thbzsi6RozoLW0eHUL.jpg'),
(120860, 8653, 'Dora a Aventureira S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uEMbacrlrLInnIC4hLyRSBzXvMs.jpg'),
(120861, 8653, 'Dora a Aventureira S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/avibB5hUbtC0viQBduFgPOpPtq3.jpg'),
(120862, 8653, 'Dora a Aventureira S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mFX3s37YGTL6nRZLxphIvozNp1x.jpg'),
(120863, 8653, 'Dora a Aventureira S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfdkHz4kyaABePu58TTSZbrWHzi.jpg'),
(120864, 8653, 'Dora a Aventureira S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Yos5wThgMekxusqsaT4lr4n5I4.jpg'),
(120865, 8653, 'Dora a Aventureira S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m7Ew7QByaoRXdbFa68gX520pmUI.jpg'),
(120866, 8653, 'Dora a Aventureira S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xYt3BGijSk9bjbVHeh9wL2F84Cl.jpg'),
(120867, 8653, 'Dora a Aventureira S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y9EsbfdmIQzAOxOBk7YTdMTiQA3.jpg'),
(120868, 8653, 'Dora a Aventureira S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e4pAAVehVb7hORD4K6w8hpQbG9W.jpg'),
(120869, 8653, 'Dora a Aventureira S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dirlcjrJcI3h9m82wmEEAummZ81.jpg'),
(120870, 8653, 'Dora a Aventureira S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tnkrZ8F8vasSksJZoKFFeXRLncO.jpg'),
(120871, 8653, 'Dora a Aventureira S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/240185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/enoMiyVHe8zDGqsFrp3q9leYK6y.jpg'),
(120872, 8653, 'Dora a Aventureira S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/240186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hV2q3crGSp0csIl2SNzouf1ptaX.jpg'),
(120873, 8653, 'Dora a Aventureira S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/240187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/czonLLsSZByiNWHqLTcTS8nXviF.jpg'),
(120874, 8653, 'Dora a Aventureira S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/240188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybTCsrIeAWC8AhPa8z6wsQzWnbz.jpg'),
(120875, 8653, 'Dora a Aventureira S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/240189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/acqkon5pA7TFwWk86I3FxcvOc89.jpg'),
(120876, 8653, 'Dora a Aventureira S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/240190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lDTaeHi0yXRSqylhwLkCykDSWd2.jpg'),
(120877, 8653, 'Dora a Aventureira S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/240191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hgo35l9YzLGMGO2ktUlJJdES7Mh.jpg'),
(120878, 8653, 'Dora a Aventureira S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/240192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Ofp8QV4AFdLvSBz44pzQcGHAXi.jpg'),
(120879, 8653, 'Dora a Aventureira S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/240193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ceHCc1mZ5cgNVv1hYHKyiFKL2QX.jpg'),
(120880, 8653, 'Dora a Aventureira S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/240194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ip9LI89RfdTga3zaR90dLzXSibG.jpg'),
(120881, 8653, 'Dora a Aventureira S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/240195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oJv6nCq1rGvxA1x0vubtYxXy1a6.jpg'),
(120882, 8653, 'Dora a Aventureira S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/240196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tP2Wv3y1cBQRLiTqhMvc28d54Tb.jpg'),
(120883, 8653, 'Dora a Aventureira S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/240197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tP2Wv3y1cBQRLiTqhMvc28d54Tb.jpg'),
(120884, 8653, 'Dora a Aventureira S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/240198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tP2Wv3y1cBQRLiTqhMvc28d54Tb.jpg'),
(120885, 8654, 'Dora a Aventureira S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vglLOBpBeDmD9Y4Ka8mV4zIqmn7.jpg'),
(120886, 8654, 'Dora a Aventureira S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJ0e3cliJCnHFQKNmKHMTCGZKsI.jpg'),
(120887, 8654, 'Dora a Aventureira S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7WEuSzrQ6yIGOVPhapDbGtP2jxq.jpg'),
(120888, 8654, 'Dora a Aventureira S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ldUJK6ELFmKJ1n0PvNKP24zib7B.jpg'),
(120889, 8654, 'Dora a Aventureira S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/skzGu2GUL9kAtAh1MRtNQ0h5ISR.jpg'),
(120890, 8654, 'Dora a Aventureira S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5QM32XJfbA7f5WgAeEFYOcGtGRq.jpg'),
(120891, 8654, 'Dora a Aventureira S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6zZBaNuFdY23QW7TZCFknOMV4r2.jpg'),
(120892, 8654, 'Dora a Aventureira S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x47gBLEzOvqHYNEIuIUcL1KvrpN.jpg'),
(120893, 8654, 'Dora a Aventureira S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7gNQ6lXnNjXTj31GXL3OaGmTeU.jpg'),
(120894, 8654, 'Dora a Aventureira S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDILD5kiSFgPLYnE2RxDbiYYdAJ.jpg'),
(120895, 8654, 'Dora a Aventureira S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iIt6XhSaqwTmz7Qv8b6FhlyBFRv.jpg'),
(120896, 8654, 'Dora a Aventureira S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oskY8mpO4WJRO2pJqr1hfCgIiQR.jpg'),
(120897, 8654, 'Dora a Aventureira S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/240211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dH4yp9y2jLYMkcxdr6ZkNNK3ocx.jpg'),
(120898, 8654, 'Dora a Aventureira S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/240212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gnpaTJRP9xO5A5UuY82fdX01RO9.jpg'),
(120899, 8654, 'Dora a Aventureira S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/240213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8LIjaeqxwoMlmprvmlRqY7MwAT5.jpg'),
(120900, 8654, 'Dora a Aventureira S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/240214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/62JYrolq6Wbxe4OQeA8xIBBf2JV.jpg'),
(120901, 8654, 'Dora a Aventureira S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/240215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u4OyPFLL9dznHbs7YL8cdBlejRn.jpg'),
(120902, 8654, 'Dora a Aventureira S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/240216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/75K4csUTfnrMtDJwfLYRwwwVyD3.jpg'),
(120903, 8654, 'Dora a Aventureira S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/240217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zfVCLggofI8kLW9fLsg7HdoR4pQ.jpg'),
(120904, 8654, 'Dora a Aventureira S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/240218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ztor16tiaipCPR7Z8aW24HPWTKY.jpg'),
(120905, 8654, 'Dora a Aventureira S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/240219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bJcdz443RAsTR2OxkjtmDZhfajW.jpg'),
(120906, 8654, 'Dora a Aventureira S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/240220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tP2Wv3y1cBQRLiTqhMvc28d54Tb.jpg'),
(120907, 8655, 'Dora a Aventureira S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b7DZPOZlyBBd2ZKp8tbQzDjcHYe.jpg'),
(120908, 8655, 'Dora a Aventureira S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f46IArrlYZkQohtgnM6PHahSJvy.jpg'),
(120909, 8655, 'Dora a Aventureira S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jwpDZiAaP7LomM6IZTKG9C9Rh7z.jpg'),
(120910, 8655, 'Dora a Aventureira S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zpEFS3cFo4qHmOPYO8h2pgPfYOs.jpg'),
(120911, 8655, 'Dora a Aventureira S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqExufMvMHgAa5WmSzCfxJ8jpd3.jpg'),
(120912, 8655, 'Dora a Aventureira S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rxJSkM3BCCy6MgNi1fX2UdzfwPo.jpg'),
(120913, 8655, 'Dora a Aventureira S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pdhe7B8yvoOFdJnQnBv5viAjpR.jpg'),
(120914, 8655, 'Dora a Aventureira S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ArGEnUVobkw7qDPqzt02iWN4q.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(120915, 8655, 'Dora a Aventureira S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l2NUkELnJ646HVzGoQjeiwUtWPC.jpg'),
(120916, 8655, 'Dora a Aventureira S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Ma3mtv0Gs6a0ZfTJGGMzLJKS2n.jpg'),
(120917, 8655, 'Dora a Aventureira S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tzvgRFqWV6iCAObba5opxe3vEfV.jpg'),
(120918, 8655, 'Dora a Aventureira S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rhWNhAalPeVtO6YIVamuQDbCoix.jpg'),
(120919, 8655, 'Dora a Aventureira S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/240233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ekmw9ZidTlUM7w8ZX4FSTGZiYAz.jpg'),
(120920, 8655, 'Dora a Aventureira S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/240234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s35om6maSqZa4bJts59HwIgDec7.jpg'),
(120921, 8655, 'Dora a Aventureira S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/240235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lIzvdHl86dgK8TH9SQabNqT8jjy.jpg'),
(120922, 8655, 'Dora a Aventureira S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/240236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aIeCrauFzgiOSbFEavyZa9GSQ7o.jpg'),
(120923, 8656, 'Dora a Aventureira S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mshLwRu8NHpmRXMUPGV3Pi6yc7P.jpg'),
(120924, 8656, 'Dora a Aventureira S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqePqpFG3C3T9EsoutvR0ve2QXW.jpg'),
(120925, 8656, 'Dora a Aventureira S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4MrVKrC4WNISkaM1mFXHy38zVl3.jpg'),
(120926, 8656, 'Dora a Aventureira S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9A83iD34uBnPLBXTHlNIXR93IgX.jpg'),
(120927, 8656, 'Dora a Aventureira S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kbZMuT0SuIfuXzwRt2EUfIaCKnJ.jpg'),
(120928, 8656, 'Dora a Aventureira S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tM5PjizirPEep2k1iFixIaprbDL.jpg'),
(120929, 8656, 'Dora a Aventureira S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qcPFwF3lqouKzSeNWB9YXNsOcXH.jpg'),
(120930, 8656, 'Dora a Aventureira S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tP2Wv3y1cBQRLiTqhMvc28d54Tb.jpg'),
(120931, 8656, 'Dora a Aventureira S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24pdYy8exCVXhuqoBvzAc2iKRTN.jpg'),
(120932, 8656, 'Dora a Aventureira S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/446Zf6ic2IMasUTP3dEAlrNJJxr.jpg'),
(120933, 8656, 'Dora a Aventureira S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xSDiQui8YqwI8pLMyPPd7Uql9s5.jpg'),
(120934, 8656, 'Dora a Aventureira S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tP2Wv3y1cBQRLiTqhMvc28d54Tb.jpg'),
(120935, 8656, 'Dora a Aventureira S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/240249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6LZMArTLjs594NM3F3qtBRLq7n8.jpg'),
(120936, 8656, 'Dora a Aventureira S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/240250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2xpf46lSSH6v9xbS7bxfHRozMkS.jpg'),
(120937, 8656, 'Dora a Aventureira S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/240251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1inPZtjdE4OOYjMZXP8HGAdCN7m.jpg'),
(120938, 8656, 'Dora a Aventureira S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/240252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUF5Wt57fLDtRiM77TqJgKTDDBt.jpg'),
(120939, 8656, 'Dora a Aventureira S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/240253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mxhWBL8z8bboYB7EYCeZP7sMBDk.jpg'),
(120940, 8656, 'Dora a Aventureira S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/240254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tP2Wv3y1cBQRLiTqhMvc28d54Tb.jpg'),
(120941, 8656, 'Dora a Aventureira S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/240255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qLHAZdQfbHnVTFXu4u1kI0lH3OF.jpg'),
(120942, 8657, 'Dora a Aventureira S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3uy5hnnS0s9C5nYfJuEMoDZwqO9.jpg'),
(120943, 8657, 'Dora a Aventureira S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/FcxV4c8qzotfBw2DWXQsK9FqNN.jpg'),
(120944, 8657, 'Dora a Aventureira S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tP2Wv3y1cBQRLiTqhMvc28d54Tb.jpg'),
(120945, 8657, 'Dora a Aventureira S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aLEtgUDWqdDK6oJT3Z4okGgshb5.jpg'),
(120946, 8657, 'Dora a Aventureira S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zkMmzpPQnVNESDo2sabj5C2ci2f.jpg'),
(120947, 8657, 'Dora a Aventureira S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mUDEfgbY7EaDu6oWMEaBDjD0O9y.jpg'),
(120948, 8657, 'Dora a Aventureira S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/abkOGFaZF1lNuYRArQGkxcKW6DE.jpg'),
(120949, 8657, 'Dora a Aventureira S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rfeaNnq1fsEhb8ZgxFoOEwgSsxb.jpg'),
(120950, 8657, 'Dora a Aventureira S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWNYyf1pyPmT7n5jF81XN3IMb8b.jpg'),
(120951, 8657, 'Dora a Aventureira S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hIaqoT12lgVfgMFxfsZ5HqjVpdO.jpg'),
(120952, 8657, 'Dora a Aventureira S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uRHvO1SLOWmh4qcL552sEnSrm8e.jpg'),
(120953, 8657, 'Dora a Aventureira S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qSXxaLkfdbOXerOo3x1BavZ3Jt7.jpg'),
(120954, 8657, 'Dora a Aventureira S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/240268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2KGe79aLdmt99LEL0pvETUF2nq5.jpg'),
(120955, 8657, 'Dora a Aventureira S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/240269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/euEASq8V0MHRsZdwFHa94qPrHot.jpg'),
(120956, 8657, 'Dora a Aventureira S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/240270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i7YP5eYRRu9olacGmY2FjRXpyUR.jpg'),
(120957, 8657, 'Dora a Aventureira S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/240271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uUmVPIoAh3dQFLi4JfZIbsxpDKH.jpg'),
(120958, 8657, 'Dora a Aventureira S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/240272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mAyYO5xlWJF2JbuV7dGt4CJ6XCV.jpg'),
(120959, 8657, 'Dora a Aventureira S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/240273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tP2Wv3y1cBQRLiTqhMvc28d54Tb.jpg'),
(120960, 8657, 'Dora a Aventureira S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/240274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tP2Wv3y1cBQRLiTqhMvc28d54Tb.jpg'),
(120961, 8657, 'Dora a Aventureira S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/240275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tP2Wv3y1cBQRLiTqhMvc28d54Tb.jpg'),
(120962, 8658, 'Dora a Aventureira S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1FJvUhhETPDltm9x85H3MRY7qbk.jpg'),
(120963, 8658, 'Dora a Aventureira S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/46M4sAg7GY97oHqrE0MoiKq3WAf.jpg'),
(120964, 8658, 'Dora a Aventureira S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lUWmkspQb1JwR4jHjjP7r1DrnBs.jpg'),
(120965, 8658, 'Dora a Aventureira S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i2Pf0RDpBGZ9F2vij4OhpVffYd9.jpg'),
(120966, 8658, 'Dora a Aventureira S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/heE7Gubo29HiqgkrdcPoj3ct3sw.jpg'),
(120967, 8658, 'Dora a Aventureira S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTAdsnkL2AITxrGMbdCuOCZuZFM.jpg'),
(120968, 8658, 'Dora a Aventureira S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4TT7BTG5VhsdBe1mBwLTWV29Zm2.jpg'),
(120969, 8658, 'Dora a Aventureira S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jFmTK6jgP9qVNvJDpn4n4NfmzzW.jpg'),
(120970, 8658, 'Dora a Aventureira S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f29k3r6cIi8zQoDiSL5P18rbjDc.jpg'),
(120971, 8658, 'Dora a Aventureira S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dSebimaHk3sx36uS1zv4u2V71F.jpg'),
(120972, 8658, 'Dora a Aventureira S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n7Dgv6VH2M8CwQo1V3QjWAa9gDk.jpg'),
(120973, 8658, 'Dora a Aventureira S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfW6OHq0Ak5CKoeof0DEabtZ9ug.jpg'),
(120974, 8658, 'Dora a Aventureira S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/240288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xA1gq9HMOGj7HbtS1moHsWCbZlE.jpg'),
(120975, 8658, 'Dora a Aventureira S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/240289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n4bHKCLYhWCKUsHxsZ6TiWGIYKo.jpg'),
(120976, 8658, 'Dora a Aventureira S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/240290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7nKUE1MCmEFaS6E1eqfXEMFFyFl.jpg'),
(120977, 8658, 'Dora a Aventureira S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/240291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vkwSDquGj6IHgbZR34fiXVGYaRl.jpg'),
(120978, 8658, 'Dora a Aventureira S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/240292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/afONLdebbbwW2GkeYfVvD9GZCrH.jpg'),
(120979, 8658, 'Dora a Aventureira S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/240293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zEkBkWQwAWc6jidQkD0XgBHkAHY.jpg'),
(120980, 8658, 'Dora a Aventureira S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/240294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pXLiIoPhQmeBnhflnfcNelfxgRv.jpg'),
(120981, 8658, 'Dora a Aventureira S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/240295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8mP3hSahFbMNLNoUBQVHytix7g.jpg'),
(120982, 8659, 'Drag Den [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1nK8yDgJvTV5RJUQQmTdE2NNG3d.jpg'),
(120983, 8659, 'Drag Den [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x3B9wyj6flLIvYSDPMMaGWrdQq9.jpg'),
(120984, 8659, 'Drag Den [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/IxaccaFDa4i2t8ErSpRf1VngET.jpg'),
(120985, 8659, 'Drag Den [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d1iegt4fkBdiKZoR60t2WPhylKs.jpg'),
(120986, 8659, 'Drag Den [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMuAjugE1bdOZLZnrotGHmhJc9j.jpg'),
(120987, 8659, 'Drag Den [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d92Hu6uocQcFhk1DvDfyAx0Wg07.jpg'),
(120988, 8659, 'Drag Den [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e9fi9H3b1gSqhp896xYpKsIn01I.jpg'),
(120989, 8659, 'Drag Den [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dlgG9yf3dfaznY1q2OraLAovN9r.jpg'),
(120990, 8660, 'Copan S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240103.mp4', 'https://i.bj-share.info/135abfe5f7fe7d3beffe4ebaf2109281.jpg'),
(120991, 8660, 'Copan S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240104.mp4', 'https://i.bj-share.info/135abfe5f7fe7d3beffe4ebaf2109281.jpg'),
(120992, 8660, 'Copan S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240105.mp4', 'https://i.bj-share.info/135abfe5f7fe7d3beffe4ebaf2109281.jpg'),
(120993, 8660, 'Copan S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240106.mp4', 'https://i.bj-share.info/135abfe5f7fe7d3beffe4ebaf2109281.jpg'),
(120994, 8660, 'Copan S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240107.mp4', 'https://i.bj-share.info/135abfe5f7fe7d3beffe4ebaf2109281.jpg'),
(120995, 8660, 'Copan S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240108.mp4', 'https://i.bj-share.info/135abfe5f7fe7d3beffe4ebaf2109281.jpg'),
(120996, 8660, 'Copan S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240109.mp4', 'https://i.bj-share.info/135abfe5f7fe7d3beffe4ebaf2109281.jpg'),
(120997, 8660, 'Copan S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240110.mp4', 'https://i.bj-share.info/135abfe5f7fe7d3beffe4ebaf2109281.jpg'),
(120998, 8660, 'Copan S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240111.mp4', 'https://i.bj-share.info/135abfe5f7fe7d3beffe4ebaf2109281.jpg'),
(120999, 8660, 'Copan S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240112.mp4', 'https://i.bj-share.info/135abfe5f7fe7d3beffe4ebaf2109281.jpg'),
(121000, 8661, 'Idol Jihen [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bOQfQpSfqA5QNkVPf8YhPNZFI6z.jpg'),
(121001, 8661, 'Idol Jihen [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o3IFNkjEQtY5Mz0c2TPr3hiIylS.jpg'),
(121002, 8661, 'Idol Jihen [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t9C9txIwHIpp8Meg19YQ6XNcqw1.jpg'),
(121003, 8661, 'Idol Jihen [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ga5Zs9UD6hjbRBIC05Sqi5kJNW9.jpg'),
(121004, 8661, 'Idol Jihen [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c0XUwWggljMopR2ysHYp10QScrP.jpg'),
(121005, 8661, 'Idol Jihen [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lk8r1tAvdLXbQlFdO9DsCoMuCbv.jpg'),
(121006, 8661, 'Idol Jihen [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/egR2ajitNxRsR4J9fXdgBV6qk19.jpg'),
(121007, 8661, 'Idol Jihen [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9BAiu2lTx38lOp5XJ5wYUTbY0D2.jpg'),
(121008, 8661, 'Idol Jihen [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vEPW22NTnqrNajLSmxGeOxVSGxW.jpg'),
(121009, 8661, 'Idol Jihen [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kXZdinX0lzV6g0GkR5aUVhNAC15.jpg'),
(121010, 8661, 'Idol Jihen [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ufgqEOtOvZvEFfodLH7AUImRkeY.jpg'),
(121011, 8661, 'Idol Jihen [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5tw4dyAJfWKKOABkzb33IyDcO8s.jpg'),
(121012, 8662, 'KamiErabi GOD.app [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bQ61jiKgIeBfkf7a3s0aztoIXON.jpg'),
(121013, 8662, 'KamiErabi GOD.app [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6q7u0t8QUGKD3qzKq6hYFh2REwc.jpg'),
(121014, 8662, 'KamiErabi GOD.app [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9pSKz0QT85W1ilZ093MFtswJVwJ.jpg'),
(121015, 8662, 'KamiErabi GOD.app [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj14OOLCAy2npiXwUhNJzmPEIbh.jpg'),
(121016, 8662, 'KamiErabi GOD.app [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj14OOLCAy2npiXwUhNJzmPEIbh.jpg'),
(121017, 8662, 'KamiErabi GOD.app [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj14OOLCAy2npiXwUhNJzmPEIbh.jpg'),
(121018, 8662, 'KamiErabi GOD.app [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj14OOLCAy2npiXwUhNJzmPEIbh.jpg'),
(121019, 8662, 'KamiErabi GOD.app [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj14OOLCAy2npiXwUhNJzmPEIbh.jpg'),
(121020, 8662, 'KamiErabi GOD.app [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj14OOLCAy2npiXwUhNJzmPEIbh.jpg'),
(121021, 8662, 'KamiErabi GOD.app [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj14OOLCAy2npiXwUhNJzmPEIbh.jpg'),
(121022, 8662, 'KamiErabi GOD.app [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj14OOLCAy2npiXwUhNJzmPEIbh.jpg'),
(121023, 8662, 'KamiErabi GOD.app [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj14OOLCAy2npiXwUhNJzmPEIbh.jpg'),
(121024, 8663, 'KamiErabi GOD.app [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/635547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj14OOLCAy2npiXwUhNJzmPEIbh.jpg'),
(121025, 8663, 'KamiErabi GOD.app [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/635548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj14OOLCAy2npiXwUhNJzmPEIbh.jpg'),
(121026, 8663, 'KamiErabi GOD.app [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/635549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj14OOLCAy2npiXwUhNJzmPEIbh.jpg'),
(121027, 8663, 'KamiErabi GOD.app [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/635550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj14OOLCAy2npiXwUhNJzmPEIbh.jpg'),
(121028, 8663, 'KamiErabi GOD.app [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/635551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj14OOLCAy2npiXwUhNJzmPEIbh.jpg'),
(121029, 8663, 'KamiErabi GOD.app [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/635552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj14OOLCAy2npiXwUhNJzmPEIbh.jpg'),
(121030, 8663, 'KamiErabi GOD.app [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/635553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj14OOLCAy2npiXwUhNJzmPEIbh.jpg'),
(121031, 8663, 'KamiErabi GOD.app [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/509399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj14OOLCAy2npiXwUhNJzmPEIbh.jpg'),
(121032, 8663, 'KamiErabi GOD.app [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/515465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj14OOLCAy2npiXwUhNJzmPEIbh.jpg'),
(121033, 8663, 'KamiErabi GOD.app [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/518005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj14OOLCAy2npiXwUhNJzmPEIbh.jpg'),
(121034, 8663, 'KamiErabi GOD.app [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/523364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj14OOLCAy2npiXwUhNJzmPEIbh.jpg'),
(121035, 8663, 'KamiErabi GOD.app [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/639149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj14OOLCAy2npiXwUhNJzmPEIbh.jpg'),
(121036, 8664, 'Kiseki Dear To Me [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Jfx6JBWAkao77joV9ShkcL7GDE.jpg'),
(121037, 8664, 'Kiseki Dear To Me [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/36EmHKtIi4RoEaOALYaSSZsYLMZ.jpg'),
(121038, 8664, 'Kiseki Dear To Me [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3OidkRRzWL9fNCg101P2eAgvLCR.jpg'),
(121039, 8664, 'Kiseki Dear To Me [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pMbosXgOndx7BprtEYOFVZfA21e.jpg'),
(121040, 8664, 'Kiseki Dear To Me [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9eNAfjaz4HjJKfOKDu4Est5I1a7.jpg'),
(121041, 8664, 'Kiseki Dear To Me [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/IvTphcZFCCsfqKPAx0rWCZfGi4.jpg'),
(121042, 8664, 'Kiseki Dear To Me [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aGawyYV934RmzazW15bz4n0z1Ke.jpg'),
(121043, 8664, 'Kiseki Dear To Me [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3TOAKGGgyYIGN68hTr4AsjmtlQ.jpg'),
(121044, 8664, 'Kiseki Dear To Me [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tcpDzO1rafNAsnHAC6dreYmwg9T.jpg'),
(121045, 8664, 'Kiseki Dear To Me [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jFgMcN6Tx8YOpMn2vrmABCvHnrh.jpg'),
(121046, 8664, 'Kiseki Dear To Me [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUGw9Z2wws2fuiEG7lMLvm58xNw.jpg'),
(121047, 8664, 'Kiseki Dear To Me [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUGw9Z2wws2fuiEG7lMLvm58xNw.jpg'),
(121048, 8664, 'Kiseki Dear To Me [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUGw9Z2wws2fuiEG7lMLvm58xNw.jpg'),
(121049, 8665, 'Onde Seus Olhos se Prolongam [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9O1uD8U1kSLwnthRfp7br8zjq51.jpg'),
(121050, 8665, 'Onde Seus Olhos se Prolongam [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ZmTty7NYMQ4X0xUZPc2H2gGtoI.jpg'),
(121051, 8665, 'Onde Seus Olhos se Prolongam [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uLLdTO9LJnm0Ck2AbxbfvnNajGl.jpg'),
(121052, 8665, 'Onde Seus Olhos se Prolongam [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eD7pKzJ3ooTQfJD3jhxVUeYmhfF.jpg'),
(121053, 8665, 'Onde Seus Olhos se Prolongam [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCL2NrWhrAvbdw5CO3Ts6luPH6t.jpg'),
(121054, 8665, 'Onde Seus Olhos se Prolongam [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yAQwBAbMhl4ZPZXYXoEoS0cFYtZ.jpg'),
(121055, 8665, 'Onde Seus Olhos se Prolongam [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u37ZUGbvB9KvvQnSlaPj8ulANUu.jpg'),
(121056, 8665, 'Onde Seus Olhos se Prolongam [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g4WjKM45Rgc96rXpcE7FrVZ5bK7.jpg'),
(121057, 8665, 'Onde Seus Olhos se Prolongam [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2NYR7CXTQfm5JfMoav0LOAS94oc.jpg'),
(121058, 8666, 'Orgulho Alem da Tela S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nGAlHArU1fnSO6GEUeiDkGOy60T.jpg'),
(121059, 8666, 'Orgulho Alem da Tela S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xDzvyOozQivqh0xab3kfIGu4CAP.jpg'),
(121060, 8666, 'Orgulho Alem da Tela S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vcWPypBlQ7G3r7xcLxdpnpOYLoB.jpg'),
(121061, 8667, 'Pink Um Amor de Verao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hSdAQDtdaM2i0xLiNqxS010c8DZ.jpg'),
(121062, 8667, 'Pink Um Amor de Verao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hSdAQDtdaM2i0xLiNqxS010c8DZ.jpg'),
(121063, 8667, 'Pink Um Amor de Verao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hSdAQDtdaM2i0xLiNqxS010c8DZ.jpg'),
(121064, 8667, 'Pink Um Amor de Verao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hSdAQDtdaM2i0xLiNqxS010c8DZ.jpg'),
(121065, 8668, 'Pink Um Amor de Verao S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hSdAQDtdaM2i0xLiNqxS010c8DZ.jpg'),
(121066, 8668, 'Pink Um Amor de Verao S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hSdAQDtdaM2i0xLiNqxS010c8DZ.jpg'),
(121067, 8668, 'Pink Um Amor de Verao S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hSdAQDtdaM2i0xLiNqxS010c8DZ.jpg'),
(121068, 8668, 'Pink Um Amor de Verao S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hSdAQDtdaM2i0xLiNqxS010c8DZ.jpg'),
(121069, 8669, 'Pink Um Amor de Verao S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xePMWwhi0DDqIfrh2yUJrk0lGsY.jpg'),
(121070, 8669, 'Pink Um Amor de Verao S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/plX5xLZDyMDrVnfwmDvHZejDxJv.jpg'),
(121071, 8669, 'Pink Um Amor de Verao S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t42IJPTcs5hqH9NWg1wbRBkFjUJ.jpg'),
(121072, 8669, 'Pink Um Amor de Verao S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mOkWgvI1Iqs0r44o5Rl5wmlhNbx.jpg'),
(121073, 8670, 'Planeta Tubarao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yIHNfzCdtejtiOCiZ0JDQaoTf14.jpg'),
(121074, 8670, 'Planeta Tubarao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eYVa6MI8XcToNJqIyUzHBFDrIT2.jpg'),
(121075, 8670, 'Planeta Tubarao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7n44YEX2zHoeCad8ifKEaHLM32q.jpg'),
(121076, 8671, 'Reinos Ocultos da Africa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8lWo3T3x5fNMoG7rApPEKyELla9.jpg'),
(121077, 8671, 'Reinos Ocultos da Africa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8lWo3T3x5fNMoG7rApPEKyELla9.jpg'),
(121078, 8671, 'Reinos Ocultos da Africa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8lWo3T3x5fNMoG7rApPEKyELla9.jpg'),
(121079, 8671, 'Reinos Ocultos da Africa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8lWo3T3x5fNMoG7rApPEKyELla9.jpg'),
(121080, 8671, 'Reinos Ocultos da Africa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8lWo3T3x5fNMoG7rApPEKyELla9.jpg'),
(121081, 8671, 'Reinos Ocultos da Africa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8lWo3T3x5fNMoG7rApPEKyELla9.jpg'),
(121082, 8672, 'Sobrevivendo ao Paraiso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6O0EZxTgxC8aXlIr21ZgxGsJhma.jpg'),
(121083, 8672, 'Sobrevivendo ao Paraiso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/reZfErEGz6AmiUgvUBkTXLW02f.jpg'),
(121084, 8672, 'Sobrevivendo ao Paraiso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/99LUSPkvvIzGtfo8WGVSn6qgYON.jpg'),
(121085, 8672, 'Sobrevivendo ao Paraiso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kJJxAa0JcVjFCVJfZhr38WujgXQ.jpg'),
(121086, 8672, 'Sobrevivendo ao Paraiso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jXWCEiTZ2ehD7O8YludlNSyWFoq.jpg'),
(121087, 8672, 'Sobrevivendo ao Paraiso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hN8OuuoHHAUookofRAsXERq81yP.jpg'),
(121088, 8672, 'Sobrevivendo ao Paraiso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qkkYWXs92mD50f2IodtsolfVcvC.jpg'),
(121089, 8672, 'Sobrevivendo ao Paraiso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nX0prE9Zl1KJvdFeuScBn4CW5uu.jpg'),
(121090, 8672, 'Sobrevivendo ao Paraiso S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3pMPxN9vSRTm0QKLslksLlbuieG.jpg'),
(121091, 8673, 'Todo Tempo do Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAqNwoYEpyCny1JGV3rBuVNXd4O.jpg'),
(121092, 8673, 'Todo Tempo do Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAqNwoYEpyCny1JGV3rBuVNXd4O.jpg'),
(121093, 8673, 'Todo Tempo do Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAqNwoYEpyCny1JGV3rBuVNXd4O.jpg'),
(121094, 8673, 'Todo Tempo do Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAqNwoYEpyCny1JGV3rBuVNXd4O.jpg'),
(121095, 8673, 'Todo Tempo do Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAqNwoYEpyCny1JGV3rBuVNXd4O.jpg'),
(121096, 8673, 'Todo Tempo do Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAqNwoYEpyCny1JGV3rBuVNXd4O.jpg'),
(121097, 8673, 'Todo Tempo do Mundo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAqNwoYEpyCny1JGV3rBuVNXd4O.jpg'),
(121098, 8673, 'Todo Tempo do Mundo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAqNwoYEpyCny1JGV3rBuVNXd4O.jpg'),
(121099, 8673, 'Todo Tempo do Mundo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAqNwoYEpyCny1JGV3rBuVNXd4O.jpg'),
(121100, 8673, 'Todo Tempo do Mundo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAqNwoYEpyCny1JGV3rBuVNXd4O.jpg'),
(121101, 8673, 'Todo Tempo do Mundo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/240047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAqNwoYEpyCny1JGV3rBuVNXd4O.jpg'),
(121102, 8673, 'Todo Tempo do Mundo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/240048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAqNwoYEpyCny1JGV3rBuVNXd4O.jpg'),
(121103, 8674, 'Trillion Game [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i71gfJ1BMYjOYlzLSboYFSYmnCk.jpg'),
(121104, 8674, 'Trillion Game [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zNAaNJistHB7KT6ji08ftLsnuvB.jpg'),
(121105, 8674, 'Trillion Game [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4DrOOb37PcXxFGgc6A4U9gBuvnp.jpg'),
(121106, 8674, 'Trillion Game [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bRj1yln7VxUezOP7qYkO4PyHTTR.jpg'),
(121107, 8674, 'Trillion Game [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cZf03Ubby1fc01zK5mcu2DasQcD.jpg'),
(121108, 8674, 'Trillion Game [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8h7b4kApukUclIiUWITV3ARC4U7.jpg'),
(121109, 8674, 'Trillion Game [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c6LNoJiMOvxKcDlGJJawqdusc7Z.jpg'),
(121110, 8674, 'Trillion Game [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/91GY4JiE9NOhpgvrlnbtPE8k6WB.jpg'),
(121111, 8674, 'Trillion Game [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkBQlgcMkl9JEuUKL9c6cGQExT8.jpg'),
(121112, 8674, 'Trillion Game [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kRbtjLcfr9WSOGYdLLJKXqT1WV0.jpg'),
(121113, 8674, 'Trillion Game [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/677836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKWo0HdvMBo0WRaaAVTBIAgT1tM.jpg'),
(121114, 8674, 'Trillion Game [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/678292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKWo0HdvMBo0WRaaAVTBIAgT1tM.jpg'),
(121115, 8674, 'Trillion Game [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/687102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKWo0HdvMBo0WRaaAVTBIAgT1tM.jpg'),
(121116, 8674, 'Trillion Game [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/697320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKWo0HdvMBo0WRaaAVTBIAgT1tM.jpg'),
(121117, 8674, 'Trillion Game [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/703955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKWo0HdvMBo0WRaaAVTBIAgT1tM.jpg'),
(121118, 8674, 'Trillion Game [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/713183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKWo0HdvMBo0WRaaAVTBIAgT1tM.jpg'),
(121119, 8674, 'Trillion Game [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/716841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKWo0HdvMBo0WRaaAVTBIAgT1tM.jpg'),
(121120, 8674, 'Trillion Game [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/723678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKWo0HdvMBo0WRaaAVTBIAgT1tM.jpg'),
(121121, 8674, 'Trillion Game [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/730190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKWo0HdvMBo0WRaaAVTBIAgT1tM.jpg'),
(121122, 8674, 'Trillion Game [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/750144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKWo0HdvMBo0WRaaAVTBIAgT1tM.jpg'),
(121123, 8674, 'Trillion Game [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/750145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKWo0HdvMBo0WRaaAVTBIAgT1tM.jpg'),
(121124, 8675, 'Valley of Flood and Fire S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hp2hxSD7MXBfM081Lg9BEWeULbn.jpg'),
(121125, 8675, 'Valley of Flood and Fire S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hp2hxSD7MXBfM081Lg9BEWeULbn.jpg'),
(121126, 8675, 'Valley of Flood and Fire S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hp2hxSD7MXBfM081Lg9BEWeULbn.jpg'),
(121127, 8676, 'Wish You Sua Melodia Em Meu Coracao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lFIc9w91YURCHWO1lbj4TOAcjHG.jpg'),
(121128, 8676, 'Wish You Sua Melodia Em Meu Coracao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d3pW5EFzSfXu6bzp0DN9I3yP1O2.jpg'),
(121129, 8676, 'Wish You Sua Melodia Em Meu Coracao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSsPFFkukV0Y0CoYwOhcxTvwgyV.jpg'),
(121130, 8676, 'Wish You Sua Melodia Em Meu Coracao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f1i2SI0RJYGPEqsmbuBQzxNQSFE.jpg'),
(121131, 8676, 'Wish You Sua Melodia Em Meu Coracao [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13xlQnDC0b5O5TatO98fQYJlkaJ.jpg'),
(121132, 8676, 'Wish You Sua Melodia Em Meu Coracao [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6oBhtvOSOqFiARNBLXyQRsxTrGx.jpg'),
(121133, 8676, 'Wish You Sua Melodia Em Meu Coracao [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b7GoBKbei7LoEPgYH19dh78CV1Z.jpg'),
(121134, 8676, 'Wish You Sua Melodia Em Meu Coracao [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pGhUQpDTFxz3aXLONrrh3WkVSKq.jpg'),
(121135, 8677, 'Reunião de Família S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Q9w5WELZf6AyFj0Wrj3EyVEIYs.jpg'),
(121136, 8677, 'Reunião de Família S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/su253jNV4GRltIvwQEGS7TQSvGH.jpg'),
(121137, 8677, 'Reunião de Família S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/61QdLTjTQiD9QvuZVo5tZEWPefJ.jpg'),
(121138, 8677, 'Reunião de Família S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sWfocso48FA2W6uhiEASVkdxK8J.jpg'),
(121139, 8677, 'Reunião de Família S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/emEsTL54qbCnGGKQlkOGR5B6sac.jpg'),
(121140, 8677, 'Reunião de Família S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9qisMwbtFG6dckDq7RSDNcITtgK.jpg'),
(121141, 8677, 'Reunião de Família S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wlbdwd5GjXqM3eLM0c5stbyKbFn.jpg'),
(121142, 8677, 'Reunião de Família S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/liiQSFrmUhRDyDNnpfOyIcz9e42.jpg'),
(121143, 8677, 'Reunião de Família S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3Cl9652UwSg1tQh3s6iI9Je9NZ.jpg'),
(121144, 8677, 'Reunião de Família S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCJPdExXaH7qnOJKb512e9m5umX.jpg'),
(121145, 8678, 'Reunião de Família S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yGf10IPTBjo9P94ylA2k4niVbuH.jpg'),
(121146, 8678, 'Reunião de Família S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/38MM9eEcC59OSrTWGXfIXvwxyya.jpg'),
(121147, 8678, 'Reunião de Família S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ofPL6oDFZLCwjbdqo6PsFIGoLZy.jpg'),
(121148, 8678, 'Reunião de Família S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/FbIsqzZY3baUeW4A2bCec2nSpa.jpg'),
(121149, 8678, 'Reunião de Família S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDbMgve8EBYXnsKOSE57WmAhZ6O.jpg'),
(121150, 8678, 'Reunião de Família S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A64H8HzACtcWze0sv6746VOmptI.jpg'),
(121151, 8678, 'Reunião de Família S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6XxylLQvBmp92vgWljOD5nAdHAJ.jpg'),
(121152, 8678, 'Reunião de Família S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/737C0llT486HKNZt0ZxC3ezqeRU.jpg'),
(121153, 8678, 'Reunião de Família S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aEDFAxxAynXlSnOBUAyLolYVMjt.jpg'),
(121154, 8679, 'Reunião de Família S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q77crxIZqZL8bBSys6TXFGWS6v6.jpg'),
(121155, 8679, 'Reunião de Família S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/83ZRFgQ8QGRLJ6II1O9DJrb6mAY.jpg'),
(121156, 8679, 'Reunião de Família S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4LBPZwa1MskqnY7S1x0CSr744qc.jpg'),
(121157, 8679, 'Reunião de Família S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n0YuWPXeYaKnXTrHg1g1mqEJpCf.jpg'),
(121158, 8679, 'Reunião de Família S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hkbzVl1znQ6Nth42rDuzErYUUMP.jpg'),
(121159, 8679, 'Reunião de Família S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m72TBNmNfFbj7W9hIUlQuviQ6nu.jpg'),
(121160, 8679, 'Reunião de Família S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iOogQ05EOrgQ3Gz1oxJgbuSIRqU.jpg'),
(121161, 8679, 'Reunião de Família S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iqMlpAtqsc0JTIT1H11wBJqNJoa.jpg'),
(121162, 8680, 'Reunião de Família S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lkMzsV12DyyQDykBaxMDzo9ZwRx.jpg'),
(121163, 8680, 'Reunião de Família S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lkMzsV12DyyQDykBaxMDzo9ZwRx.jpg'),
(121164, 8680, 'Reunião de Família S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lkMzsV12DyyQDykBaxMDzo9ZwRx.jpg'),
(121165, 8680, 'Reunião de Família S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lkMzsV12DyyQDykBaxMDzo9ZwRx.jpg'),
(121166, 8680, 'Reunião de Família S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lkMzsV12DyyQDykBaxMDzo9ZwRx.jpg'),
(121167, 8680, 'Reunião de Família S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lkMzsV12DyyQDykBaxMDzo9ZwRx.jpg'),
(121168, 8680, 'Reunião de Família S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lkMzsV12DyyQDykBaxMDzo9ZwRx.jpg'),
(121169, 8681, 'Reunião de Família S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/240006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lkMzsV12DyyQDykBaxMDzo9ZwRx.jpg'),
(121170, 8681, 'Reunião de Família S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/240007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lkMzsV12DyyQDykBaxMDzo9ZwRx.jpg'),
(121171, 8681, 'Reunião de Família S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/240008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lkMzsV12DyyQDykBaxMDzo9ZwRx.jpg'),
(121172, 8681, 'Reunião de Família S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/240009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lkMzsV12DyyQDykBaxMDzo9ZwRx.jpg'),
(121173, 8681, 'Reunião de Família S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/240010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lkMzsV12DyyQDykBaxMDzo9ZwRx.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(121174, 8681, 'Reunião de Família S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/240011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lkMzsV12DyyQDykBaxMDzo9ZwRx.jpg'),
(121175, 8681, 'Reunião de Família S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/240012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lkMzsV12DyyQDykBaxMDzo9ZwRx.jpg'),
(121176, 8681, 'Reunião de Família S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/240013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lkMzsV12DyyQDykBaxMDzo9ZwRx.jpg'),
(121177, 8681, 'Reunião de Família S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/240014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lkMzsV12DyyQDykBaxMDzo9ZwRx.jpg'),
(121178, 8681, 'Reunião de Família S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/240015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lkMzsV12DyyQDykBaxMDzo9ZwRx.jpg'),
(121179, 8682, '100 Namoradas Que Te Amam Muuuuuito [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PqyJObGnb3OFFWcf6QTIuGLz4d.jpg'),
(121180, 8682, '100 Namoradas Que Te Amam Muuuuuito [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8OhHXcb7HJw1Z2BANJGZW1vJN98.jpg'),
(121181, 8682, '100 Namoradas Que Te Amam Muuuuuito [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pX8ElXIZHyQLbgA4HOjMWiDZDDq.jpg'),
(121182, 8682, '100 Namoradas Que Te Amam Muuuuuito [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pGzbIpOyqRl5wiU0wi1uaoFG8Av.jpg'),
(121183, 8682, '100 Namoradas Que Te Amam Muuuuuito [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pGzbIpOyqRl5wiU0wi1uaoFG8Av.jpg'),
(121184, 8682, '100 Namoradas Que Te Amam Muuuuuito [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pGzbIpOyqRl5wiU0wi1uaoFG8Av.jpg'),
(121185, 8682, '100 Namoradas Que Te Amam Muuuuuito [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pGzbIpOyqRl5wiU0wi1uaoFG8Av.jpg'),
(121186, 8682, '100 Namoradas Que Te Amam Muuuuuito [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pGzbIpOyqRl5wiU0wi1uaoFG8Av.jpg'),
(121187, 8682, '100 Namoradas Que Te Amam Muuuuuito [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pGzbIpOyqRl5wiU0wi1uaoFG8Av.jpg'),
(121188, 8682, '100 Namoradas Que Te Amam Muuuuuito [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pGzbIpOyqRl5wiU0wi1uaoFG8Av.jpg'),
(121189, 8682, '100 Namoradas Que Te Amam Muuuuuito [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pGzbIpOyqRl5wiU0wi1uaoFG8Av.jpg'),
(121190, 8682, '100 Namoradas Que Te Amam Muuuuuito [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pGzbIpOyqRl5wiU0wi1uaoFG8Av.jpg'),
(121191, 8683, '100 Namoradas Que Te Amam Muuuuuito [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/666412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pGzbIpOyqRl5wiU0wi1uaoFG8Av.jpg'),
(121192, 8683, '100 Namoradas Que Te Amam Muuuuuito [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/670050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pGzbIpOyqRl5wiU0wi1uaoFG8Av.jpg'),
(121193, 8683, '100 Namoradas Que Te Amam Muuuuuito [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/676162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pGzbIpOyqRl5wiU0wi1uaoFG8Av.jpg'),
(121194, 8683, '100 Namoradas Que Te Amam Muuuuuito [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/684214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pGzbIpOyqRl5wiU0wi1uaoFG8Av.jpg'),
(121195, 8683, '100 Namoradas Que Te Amam Muuuuuito [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/691996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pGzbIpOyqRl5wiU0wi1uaoFG8Av.jpg'),
(121196, 8683, '100 Namoradas Que Te Amam Muuuuuito [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/700387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pGzbIpOyqRl5wiU0wi1uaoFG8Av.jpg'),
(121197, 8683, '100 Namoradas Que Te Amam Muuuuuito [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/707697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pGzbIpOyqRl5wiU0wi1uaoFG8Av.jpg'),
(121198, 8683, '100 Namoradas Que Te Amam Muuuuuito [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/712216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pGzbIpOyqRl5wiU0wi1uaoFG8Av.jpg'),
(121199, 8683, '100 Namoradas Que Te Amam Muuuuuito [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/722509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pGzbIpOyqRl5wiU0wi1uaoFG8Av.jpg'),
(121200, 8683, '100 Namoradas Que Te Amam Muuuuuito [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/729512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pGzbIpOyqRl5wiU0wi1uaoFG8Av.jpg'),
(121201, 8683, '100 Namoradas Que Te Amam Muuuuuito [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/739505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pGzbIpOyqRl5wiU0wi1uaoFG8Av.jpg'),
(121202, 8683, '100 Namoradas Que Te Amam Muuuuuito [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/743451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pGzbIpOyqRl5wiU0wi1uaoFG8Av.jpg'),
(121203, 8684, '16bit Sensation Another Layer [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/FJ9sO8Qh34q1LVwuJFvLQJCjs7.jpg'),
(121204, 8684, '16bit Sensation Another Layer [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6tBeMVy30Q9LTxfZKBHkZKBh8Pw.jpg'),
(121205, 8684, '16bit Sensation Another Layer [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ocN2sIlsy2wYgYsJPC2tM1ndpzo.jpg'),
(121206, 8684, '16bit Sensation Another Layer [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kUIrSnRG1MFhIkUIhBdwRnbop9R.jpg'),
(121207, 8684, '16bit Sensation Another Layer [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kUIrSnRG1MFhIkUIhBdwRnbop9R.jpg'),
(121208, 8684, '16bit Sensation Another Layer [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kUIrSnRG1MFhIkUIhBdwRnbop9R.jpg'),
(121209, 8684, '16bit Sensation Another Layer [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kUIrSnRG1MFhIkUIhBdwRnbop9R.jpg'),
(121210, 8684, '16bit Sensation Another Layer [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kUIrSnRG1MFhIkUIhBdwRnbop9R.jpg'),
(121211, 8684, '16bit Sensation Another Layer [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kUIrSnRG1MFhIkUIhBdwRnbop9R.jpg'),
(121212, 8684, '16bit Sensation Another Layer [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kUIrSnRG1MFhIkUIhBdwRnbop9R.jpg'),
(121213, 8684, '16bit Sensation Another Layer [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kUIrSnRG1MFhIkUIhBdwRnbop9R.jpg'),
(121214, 8684, '16bit Sensation Another Layer [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kUIrSnRG1MFhIkUIhBdwRnbop9R.jpg'),
(121215, 8684, '16bit Sensation Another Layer [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kUIrSnRG1MFhIkUIhBdwRnbop9R.jpg'),
(121216, 8685, 'A Girl and Her Guard Dog [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1qzGZhziK33CV6j2Edbmtq1niF.jpg'),
(121217, 8685, 'A Girl and Her Guard Dog [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pWluFiz3F3u3GenWTKUHsjd0rKX.jpg'),
(121218, 8685, 'A Girl and Her Guard Dog [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fQnhu470bUP6PywDHqCSYazHwZG.jpg'),
(121219, 8685, 'A Girl and Her Guard Dog [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q4yKgLi6rY94QWYdOWJuxd6JPzo.jpg'),
(121220, 8685, 'A Girl and Her Guard Dog [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSS2RWAK9ZKUm7K70Nd6zzWuDu8.jpg'),
(121221, 8685, 'A Girl and Her Guard Dog [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSS2RWAK9ZKUm7K70Nd6zzWuDu8.jpg'),
(121222, 8685, 'A Girl and Her Guard Dog [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSS2RWAK9ZKUm7K70Nd6zzWuDu8.jpg'),
(121223, 8685, 'A Girl and Her Guard Dog [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSS2RWAK9ZKUm7K70Nd6zzWuDu8.jpg'),
(121224, 8685, 'A Girl and Her Guard Dog [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSS2RWAK9ZKUm7K70Nd6zzWuDu8.jpg'),
(121225, 8685, 'A Girl and Her Guard Dog [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSS2RWAK9ZKUm7K70Nd6zzWuDu8.jpg'),
(121226, 8685, 'A Girl and Her Guard Dog [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSS2RWAK9ZKUm7K70Nd6zzWuDu8.jpg'),
(121227, 8685, 'A Girl and Her Guard Dog [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSS2RWAK9ZKUm7K70Nd6zzWuDu8.jpg'),
(121228, 8685, 'A Girl and Her Guard Dog [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iSS2RWAK9ZKUm7K70Nd6zzWuDu8.jpg'),
(121229, 8686, 'A Returners Magic Should Be Special [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aAioEsMdIXrtv7bWuDbTDD0HfTl.jpg'),
(121230, 8686, 'A Returners Magic Should Be Special [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dYvT03kkz2kNrFhWBMQhsA5P0RB.jpg'),
(121231, 8686, 'A Returners Magic Should Be Special [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yY6oR4xJGGE0hloF5J26pR5zAv5.jpg'),
(121232, 8686, 'A Returners Magic Should Be Special [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/grwiUnGAZlqYJMug1JGqWpsgnj.jpg'),
(121233, 8686, 'A Returners Magic Should Be Special [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/grwiUnGAZlqYJMug1JGqWpsgnj.jpg'),
(121234, 8686, 'A Returners Magic Should Be Special [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/grwiUnGAZlqYJMug1JGqWpsgnj.jpg'),
(121235, 8686, 'A Returners Magic Should Be Special [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/grwiUnGAZlqYJMug1JGqWpsgnj.jpg'),
(121236, 8686, 'A Returners Magic Should Be Special [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/grwiUnGAZlqYJMug1JGqWpsgnj.jpg'),
(121237, 8686, 'A Returners Magic Should Be Special [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/grwiUnGAZlqYJMug1JGqWpsgnj.jpg'),
(121238, 8686, 'A Returners Magic Should Be Special [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/grwiUnGAZlqYJMug1JGqWpsgnj.jpg'),
(121239, 8686, 'A Returners Magic Should Be Special [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/grwiUnGAZlqYJMug1JGqWpsgnj.jpg'),
(121240, 8686, 'A Returners Magic Should Be Special [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/grwiUnGAZlqYJMug1JGqWpsgnj.jpg'),
(121241, 8687, 'A Vida no Nosso Planeta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q4ncSKSZ7odNgOduZzLclwa2mM5.jpg'),
(121242, 8687, 'A Vida no Nosso Planeta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vAWy4YQ76kpvpnNATP9QvxEvDc0.jpg'),
(121243, 8687, 'A Vida no Nosso Planeta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0RP6RqkEMjWEaD00nlzdHdO7ea.jpg'),
(121244, 8687, 'A Vida no Nosso Planeta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2D8At9iRjCHiHGuZ2Xu9b03zOKM.jpg'),
(121245, 8687, 'A Vida no Nosso Planeta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wwDQTnIFm4E7nWAGCCPm0iZ725m.jpg'),
(121246, 8687, 'A Vida no Nosso Planeta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8vPQS7dBgxd0U4xkqsPkUNXIaFp.jpg'),
(121247, 8687, 'A Vida no Nosso Planeta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ghEoccNbXDPHiMR3qZHbu9VostT.jpg'),
(121248, 8687, 'A Vida no Nosso Planeta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uW4W3sDUDqYbivYTuhJE6y4dqOl.jpg'),
(121249, 8688, 'BULLBUSTER [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7DkhdCY1j4qFjONNvkfZC0H0biD.jpg'),
(121250, 8688, 'BULLBUSTER [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/emfK0usc0iJKbNOd3IjA6CuewMM.jpg'),
(121251, 8688, 'BULLBUSTER [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hy72oV3IA94nXdnyiOhG0M7lS7W.jpg'),
(121252, 8688, 'BULLBUSTER [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wT4v5C1Bm3xgk0Uko0BEe5frD8U.jpg'),
(121253, 8688, 'BULLBUSTER [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wT4v5C1Bm3xgk0Uko0BEe5frD8U.jpg'),
(121254, 8688, 'BULLBUSTER [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wT4v5C1Bm3xgk0Uko0BEe5frD8U.jpg'),
(121255, 8688, 'BULLBUSTER [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wT4v5C1Bm3xgk0Uko0BEe5frD8U.jpg'),
(121256, 8688, 'BULLBUSTER [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wT4v5C1Bm3xgk0Uko0BEe5frD8U.jpg'),
(121257, 8688, 'BULLBUSTER [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wT4v5C1Bm3xgk0Uko0BEe5frD8U.jpg'),
(121258, 8688, 'BULLBUSTER [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wT4v5C1Bm3xgk0Uko0BEe5frD8U.jpg'),
(121259, 8688, 'BULLBUSTER [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wT4v5C1Bm3xgk0Uko0BEe5frD8U.jpg'),
(121260, 8688, 'BULLBUSTER [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wT4v5C1Bm3xgk0Uko0BEe5frD8U.jpg'),
(121261, 8689, 'Butareba The Story of a Man Turned into a Pig [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/enBt0HP1rhNTFarKLzj7F3oOVIh.jpg'),
(121262, 8689, 'Butareba The Story of a Man Turned into a Pig [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24pHf3GyJ08ijndg2qauSdFWk4b.jpg'),
(121263, 8689, 'Butareba The Story of a Man Turned into a Pig [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b3GcQa6bdLV0yDexSmWEQmZpuK5.jpg'),
(121264, 8690, 'Com Pocoes Eu Me Garanto [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hG8HKlHcJ4qGv9zkktpsjlayPqx.jpg'),
(121265, 8690, 'Com Pocoes Eu Me Garanto [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rMGPxDOEfjPC2XVP1jLmPkxUiV.jpg'),
(121266, 8690, 'Com Pocoes Eu Me Garanto [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gTGsnDkq4lJjXe2tw72DtfEUYl6.jpg'),
(121267, 8690, 'Com Pocoes Eu Me Garanto [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQc8hk0jJeajoDxVMD6KSv0rIiF.jpg'),
(121268, 8690, 'Com Pocoes Eu Me Garanto [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQc8hk0jJeajoDxVMD6KSv0rIiF.jpg'),
(121269, 8690, 'Com Pocoes Eu Me Garanto [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQc8hk0jJeajoDxVMD6KSv0rIiF.jpg'),
(121270, 8690, 'Com Pocoes Eu Me Garanto [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQc8hk0jJeajoDxVMD6KSv0rIiF.jpg'),
(121271, 8690, 'Com Pocoes Eu Me Garanto [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQc8hk0jJeajoDxVMD6KSv0rIiF.jpg'),
(121272, 8690, 'Com Pocoes Eu Me Garanto [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQc8hk0jJeajoDxVMD6KSv0rIiF.jpg'),
(121273, 8690, 'Com Pocoes Eu Me Garanto [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQc8hk0jJeajoDxVMD6KSv0rIiF.jpg'),
(121274, 8690, 'Com Pocoes Eu Me Garanto [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQc8hk0jJeajoDxVMD6KSv0rIiF.jpg'),
(121275, 8690, 'Com Pocoes Eu Me Garanto [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQc8hk0jJeajoDxVMD6KSv0rIiF.jpg'),
(121276, 8691, 'Dead Mount Death Play [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tKwLFS90e2bPSorTeCvOno4DQa1.jpg'),
(121277, 8691, 'Dead Mount Death Play [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xIgDvEa8ucGEIP6ODoJ7pbV9Y6p.jpg'),
(121278, 8691, 'Dead Mount Death Play [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i83VwY56DQtOSwdoI5DXjZaExb3.jpg'),
(121279, 8691, 'Dead Mount Death Play [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUnmbc77VRIf70HbEtuPZXpUsft.jpg'),
(121280, 8691, 'Dead Mount Death Play [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a0PAkfRqH0uHwU5hgjhPEJ4sqqS.jpg'),
(121281, 8691, 'Dead Mount Death Play [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xkqaeCtOxurWXZClkvFdMlyNopc.jpg'),
(121282, 8691, 'Dead Mount Death Play [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bzim2xKRcgxm6IlC2lJX39rdZHW.jpg'),
(121283, 8691, 'Dead Mount Death Play [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hgyYXYmiWSBeaJytM6tjbD38oJI.jpg'),
(121284, 8691, 'Dead Mount Death Play [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6AjnS620Q476lNWfiDJrIupxX1F.jpg'),
(121285, 8691, 'Dead Mount Death Play [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/egjTHEuwjYxK1VSjGmACkT5o1iD.jpg'),
(121286, 8691, 'Dead Mount Death Play [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9x1EcKSl3STwVz5S6qZpqHURtA.jpg'),
(121287, 8691, 'Dead Mount Death Play [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qdlBbyQQ8c5EqYXHA40yOU5IMXO.jpg'),
(121288, 8691, 'Dead Mount Death Play [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rfpFibe2JIuFLGZ9WPTrNlAYQnA.jpg'),
(121289, 8691, 'Dead Mount Death Play [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/257290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rfpFibe2JIuFLGZ9WPTrNlAYQnA.jpg'),
(121290, 8691, 'Dead Mount Death Play [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/257291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rfpFibe2JIuFLGZ9WPTrNlAYQnA.jpg'),
(121291, 8691, 'Dead Mount Death Play [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/257292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rfpFibe2JIuFLGZ9WPTrNlAYQnA.jpg'),
(121292, 8691, 'Dead Mount Death Play [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/257293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rfpFibe2JIuFLGZ9WPTrNlAYQnA.jpg'),
(121293, 8691, 'Dead Mount Death Play [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/257294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rfpFibe2JIuFLGZ9WPTrNlAYQnA.jpg'),
(121294, 8691, 'Dead Mount Death Play [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/257295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rfpFibe2JIuFLGZ9WPTrNlAYQnA.jpg'),
(121295, 8691, 'Dead Mount Death Play [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/257296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rfpFibe2JIuFLGZ9WPTrNlAYQnA.jpg'),
(121296, 8691, 'Dead Mount Death Play [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/257297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rfpFibe2JIuFLGZ9WPTrNlAYQnA.jpg'),
(121297, 8691, 'Dead Mount Death Play [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/257298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rfpFibe2JIuFLGZ9WPTrNlAYQnA.jpg'),
(121298, 8692, 'Dead Mount Death Play [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rfpFibe2JIuFLGZ9WPTrNlAYQnA.jpg'),
(121299, 8692, 'Dead Mount Death Play [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rfpFibe2JIuFLGZ9WPTrNlAYQnA.jpg'),
(121300, 8692, 'Dead Mount Death Play [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rfpFibe2JIuFLGZ9WPTrNlAYQnA.jpg'),
(121301, 8692, 'Dead Mount Death Play [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rfpFibe2JIuFLGZ9WPTrNlAYQnA.jpg'),
(121302, 8692, 'Dead Mount Death Play [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rfpFibe2JIuFLGZ9WPTrNlAYQnA.jpg'),
(121303, 8692, 'Dead Mount Death Play [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rfpFibe2JIuFLGZ9WPTrNlAYQnA.jpg'),
(121304, 8692, 'Dead Mount Death Play [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rfpFibe2JIuFLGZ9WPTrNlAYQnA.jpg'),
(121305, 8692, 'Dead Mount Death Play [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rfpFibe2JIuFLGZ9WPTrNlAYQnA.jpg'),
(121306, 8692, 'Dead Mount Death Play [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rfpFibe2JIuFLGZ9WPTrNlAYQnA.jpg'),
(121307, 8692, 'Dead Mount Death Play [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rfpFibe2JIuFLGZ9WPTrNlAYQnA.jpg'),
(121308, 8692, 'Dead Mount Death Play [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rfpFibe2JIuFLGZ9WPTrNlAYQnA.jpg'),
(121309, 8693, 'Galvao Olha o Que Ele Fez S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zdvlZSpXkp5fdrOZAKdRMSVIzr5.jpg'),
(121310, 8693, 'Galvao Olha o Que Ele Fez S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AlhIRhJseKZTjLBYgPuqUv3VgKp.jpg'),
(121311, 8693, 'Galvao Olha o Que Ele Fez S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kLKsF4zOaPdUGIHPwz0gsfExq0X.jpg'),
(121312, 8693, 'Galvao Olha o Que Ele Fez S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjqEBnTh2WHCykjZ4065ec35nkB.jpg'),
(121313, 8693, 'Galvao Olha o Que Ele Fez S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gRWiQPoM0CdxQMhXE97Nend2nWC.jpg'),
(121314, 8694, 'Girlfriend Girlfriend S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYRj8pcIqvlgGDCjn892xVAbdQ.jpg'),
(121315, 8694, 'Girlfriend Girlfriend S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3u4lleKv1peBR5CFe0HWXjH6jGV.jpg'),
(121316, 8694, 'Girlfriend Girlfriend S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvgq3k8mqG7yJYaJTjhiRp0Xyw9.jpg'),
(121317, 8694, 'Girlfriend Girlfriend S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y7BNhuVsQY4kqliATCguIDKSYUD.jpg'),
(121318, 8694, 'Girlfriend Girlfriend S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c3sPikqTlSWUD8nqeofD2VGAIU.jpg'),
(121319, 8694, 'Girlfriend Girlfriend S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e4aNjfXNxrmjUiBKO8mOFDEq3w7.jpg'),
(121320, 8694, 'Girlfriend Girlfriend S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wDnVfOdtyTOe1Z7wjVr1ACkSoLw.jpg'),
(121321, 8694, 'Girlfriend Girlfriend S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/NZNjpnaiXxcd6p0v450zdDWNj.jpg'),
(121322, 8694, 'Girlfriend Girlfriend S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/WEN8Z2iKAs6kyzrm0pGJxv4SXm.jpg'),
(121323, 8694, 'Girlfriend Girlfriend S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s6ODOgKVhrsOTETuRIsnV0E6EoJ.jpg'),
(121324, 8694, 'Girlfriend Girlfriend S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/258225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fkB8hoTVC2jTZLclHDDHXx5B3Oy.jpg'),
(121325, 8694, 'Girlfriend Girlfriend S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/258226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t313mc63AZTKbCLcfzgxIX6q03c.jpg'),
(121326, 8695, 'Girlfriend Girlfriend S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hVxmYEeWkVwJLTHV1nN7oU4UGjm.jpg'),
(121327, 8695, 'Girlfriend Girlfriend S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hVxmYEeWkVwJLTHV1nN7oU4UGjm.jpg'),
(121328, 8695, 'Girlfriend Girlfriend S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hVxmYEeWkVwJLTHV1nN7oU4UGjm.jpg'),
(121329, 8695, 'Girlfriend Girlfriend S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hVxmYEeWkVwJLTHV1nN7oU4UGjm.jpg'),
(121330, 8695, 'Girlfriend Girlfriend S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hVxmYEeWkVwJLTHV1nN7oU4UGjm.jpg'),
(121331, 8695, 'Girlfriend Girlfriend S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hVxmYEeWkVwJLTHV1nN7oU4UGjm.jpg'),
(121332, 8695, 'Girlfriend Girlfriend S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hVxmYEeWkVwJLTHV1nN7oU4UGjm.jpg'),
(121333, 8695, 'Girlfriend Girlfriend S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hVxmYEeWkVwJLTHV1nN7oU4UGjm.jpg'),
(121334, 8695, 'Girlfriend Girlfriend S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hVxmYEeWkVwJLTHV1nN7oU4UGjm.jpg'),
(121335, 8695, 'Girlfriend Girlfriend S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hVxmYEeWkVwJLTHV1nN7oU4UGjm.jpg'),
(121336, 8695, 'Girlfriend Girlfriend S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/258237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hVxmYEeWkVwJLTHV1nN7oU4UGjm.jpg'),
(121337, 8695, 'Girlfriend Girlfriend S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/258238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hVxmYEeWkVwJLTHV1nN7oU4UGjm.jpg'),
(121338, 8696, 'Girlfriend Girlfriend [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYRj8pcIqvlgGDCjn892xVAbdQ.jpg'),
(121339, 8696, 'Girlfriend Girlfriend [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3u4lleKv1peBR5CFe0HWXjH6jGV.jpg'),
(121340, 8696, 'Girlfriend Girlfriend [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvgq3k8mqG7yJYaJTjhiRp0Xyw9.jpg'),
(121341, 8696, 'Girlfriend Girlfriend [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y7BNhuVsQY4kqliATCguIDKSYUD.jpg'),
(121342, 8696, 'Girlfriend Girlfriend [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c3sPikqTlSWUD8nqeofD2VGAIU.jpg'),
(121343, 8696, 'Girlfriend Girlfriend [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e4aNjfXNxrmjUiBKO8mOFDEq3w7.jpg'),
(121344, 8696, 'Girlfriend Girlfriend [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wDnVfOdtyTOe1Z7wjVr1ACkSoLw.jpg'),
(121345, 8696, 'Girlfriend Girlfriend [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/NZNjpnaiXxcd6p0v450zdDWNj.jpg'),
(121346, 8696, 'Girlfriend Girlfriend [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/WEN8Z2iKAs6kyzrm0pGJxv4SXm.jpg'),
(121347, 8696, 'Girlfriend Girlfriend [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s6ODOgKVhrsOTETuRIsnV0E6EoJ.jpg'),
(121348, 8696, 'Girlfriend Girlfriend [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fkB8hoTVC2jTZLclHDDHXx5B3Oy.jpg'),
(121349, 8696, 'Girlfriend Girlfriend [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t313mc63AZTKbCLcfzgxIX6q03c.jpg'),
(121350, 8697, 'Girlfriend Girlfriend [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oukRpdRoMXY81cfplTyjBjBuFw7.jpg'),
(121351, 8697, 'Girlfriend Girlfriend [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7VEMx5ckKGl1sKBbjVmW5C43dhK.jpg'),
(121352, 8697, 'Girlfriend Girlfriend [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fpfJzaqwmPTsEfhKGrPmH2nB4Zo.jpg'),
(121353, 8697, 'Girlfriend Girlfriend [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hVxmYEeWkVwJLTHV1nN7oU4UGjm.jpg'),
(121354, 8697, 'Girlfriend Girlfriend [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hVxmYEeWkVwJLTHV1nN7oU4UGjm.jpg'),
(121355, 8697, 'Girlfriend Girlfriend [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hVxmYEeWkVwJLTHV1nN7oU4UGjm.jpg'),
(121356, 8697, 'Girlfriend Girlfriend [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hVxmYEeWkVwJLTHV1nN7oU4UGjm.jpg'),
(121357, 8697, 'Girlfriend Girlfriend [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hVxmYEeWkVwJLTHV1nN7oU4UGjm.jpg'),
(121358, 8697, 'Girlfriend Girlfriend [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hVxmYEeWkVwJLTHV1nN7oU4UGjm.jpg'),
(121359, 8697, 'Girlfriend Girlfriend [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hVxmYEeWkVwJLTHV1nN7oU4UGjm.jpg'),
(121360, 8697, 'Girlfriend Girlfriend [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hVxmYEeWkVwJLTHV1nN7oU4UGjm.jpg'),
(121361, 8697, 'Girlfriend Girlfriend [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hVxmYEeWkVwJLTHV1nN7oU4UGjm.jpg'),
(121362, 8698, 'Golden Kamuy [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zPfELAqB3LP6ZrCalZB1wR7ET1W.jpg'),
(121363, 8698, 'Golden Kamuy [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uI4rmqnYQlSUn77Wwqpq4MoTmD4.jpg'),
(121364, 8698, 'Golden Kamuy [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mmNDxevfpmiE59HjhcjmjN537zu.jpg'),
(121365, 8698, 'Golden Kamuy [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6zQIOfhsnAJDV8HJPFbvcsPVIRw.jpg'),
(121366, 8698, 'Golden Kamuy [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ccp8uFT4ckN6cpCriyALFhasCV2.jpg'),
(121367, 8698, 'Golden Kamuy [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iklDO2OcFpe0pO0wbNr35UvcQxS.jpg'),
(121368, 8698, 'Golden Kamuy [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/htAO55fZla6nq73bbe7HXTIUQvq.jpg'),
(121369, 8698, 'Golden Kamuy [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rBC2nvbC3cAz7AOsRkYLZx0HDU8.jpg'),
(121370, 8698, 'Golden Kamuy [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ogY0u2HSLuJMkMYlojsAhrtfcK.jpg'),
(121371, 8698, 'Golden Kamuy [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/960iAePoyNcXy99mugTwziJP9tC.jpg'),
(121372, 8699, 'Golden Kamuy [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121373, 8699, 'Golden Kamuy [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121374, 8699, 'Golden Kamuy [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121375, 8699, 'Golden Kamuy [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121376, 8699, 'Golden Kamuy [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121377, 8699, 'Golden Kamuy [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121378, 8699, 'Golden Kamuy [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121379, 8699, 'Golden Kamuy [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121380, 8699, 'Golden Kamuy [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121381, 8699, 'Golden Kamuy [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121382, 8699, 'Golden Kamuy [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121383, 8699, 'Golden Kamuy [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121384, 8700, 'Golden Kamuy [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121385, 8700, 'Golden Kamuy [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121386, 8700, 'Golden Kamuy [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121387, 8700, 'Golden Kamuy [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121388, 8700, 'Golden Kamuy [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121389, 8700, 'Golden Kamuy [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121390, 8700, 'Golden Kamuy [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121391, 8700, 'Golden Kamuy [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121392, 8700, 'Golden Kamuy [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121393, 8700, 'Golden Kamuy [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121394, 8700, 'Golden Kamuy [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121395, 8700, 'Golden Kamuy [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ab1QIcwCAQUgs8Z8pTJnVPkKS0m.jpg'),
(121396, 8701, 'Golden Kamuy [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/swCs1oN2DpJItOEuGLZLqXYpyQA.jpg'),
(121397, 8701, 'Golden Kamuy [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/446swrafWKKJCbM5VwVEa7DQtR1.jpg'),
(121398, 8701, 'Golden Kamuy [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gpFW5wigtxkLD7sSHT8tthySnFx.jpg'),
(121399, 8701, 'Golden Kamuy [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xGKjLcjqLaE4tFLDVSJmfQCtlRu.jpg'),
(121400, 8701, 'Golden Kamuy [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHCuXtkBP34pSzxr4jbwEObBZY5.jpg'),
(121401, 8701, 'Golden Kamuy [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2CLweJ5rKq8gvdtM9p4h4Bi7opk.jpg'),
(121402, 8701, 'Golden Kamuy [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uUE9u2TRzys0XJ76Cm62E3uLpK7.jpg'),
(121403, 8701, 'Golden Kamuy [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJ6E83tcY9Wqwa0tzIxoCJPQMab.jpg'),
(121404, 8701, 'Golden Kamuy [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1bFfntjVFrHwM1ZDzyhJdFs6GO0.jpg'),
(121405, 8701, 'Golden Kamuy [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2cWYAT0bi75Jy9AiS0Q3BQsdyzq.jpg'),
(121406, 8701, 'Golden Kamuy [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xpENm4bGm3qCISZwwQ9Hl0i2W0A.jpg'),
(121407, 8701, 'Golden Kamuy [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iqVKIlaYYWnYxKpRRTqq4WVGnMy.jpg'),
(121408, 8701, 'Golden Kamuy [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7kJwLH6x2LTkBdd7lQmlS2SX0Lu.jpg'),
(121409, 8702, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aTUwTR3LoPyt5HWYABwhDF821n1.jpg'),
(121410, 8702, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zsgi58vfAzPOyEuic7kJMEWIG6h.jpg'),
(121411, 8702, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xaZuJjYdW6N3Gax4AJdupcojyRu.jpg'),
(121412, 8702, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7XMW392KfwwFEOIkXOQXHAcUblt.jpg'),
(121413, 8702, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8tsH3Ij8Fz5c5ajjcuJ4wu5BVuS.jpg'),
(121414, 8702, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1AdqgflRuFoaGp3Ekc90SHtQRsd.jpg'),
(121415, 8702, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4UbfEiY33lo2XasR7Ziexv9yguk.jpg'),
(121416, 8702, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/beejQeHXRwgyom94vdeGnfkeKaI.jpg'),
(121417, 8702, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/beejQeHXRwgyom94vdeGnfkeKaI.jpg'),
(121418, 8702, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ycqTQ37OET86v80tIQCeJN3r3FJ.jpg'),
(121419, 8702, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fKhGdxcpGZIDUf3YlfaHxAK4K4f.jpg'),
(121420, 8702, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/krN1ccB9XOSWutFDn8zPrQasXv1.jpg'),
(121421, 8702, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nTA3B5GfxOd2uViYBZP6KRO5xQd.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(121422, 8703, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7UY360UYEiOfqv5GE7JBgQhPq4A.jpg'),
(121423, 8703, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rDve8VpDvDPmYDEwJvBV59ESgSM.jpg'),
(121424, 8703, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iqV2Tfm7cpccZgKA2jDVHBWwE3F.jpg'),
(121425, 8703, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nTA3B5GfxOd2uViYBZP6KRO5xQd.jpg'),
(121426, 8703, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nTA3B5GfxOd2uViYBZP6KRO5xQd.jpg'),
(121427, 8703, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nTA3B5GfxOd2uViYBZP6KRO5xQd.jpg'),
(121428, 8703, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nTA3B5GfxOd2uViYBZP6KRO5xQd.jpg'),
(121429, 8703, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nTA3B5GfxOd2uViYBZP6KRO5xQd.jpg'),
(121430, 8703, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nTA3B5GfxOd2uViYBZP6KRO5xQd.jpg'),
(121431, 8703, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nTA3B5GfxOd2uViYBZP6KRO5xQd.jpg'),
(121432, 8703, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nTA3B5GfxOd2uViYBZP6KRO5xQd.jpg'),
(121433, 8703, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nTA3B5GfxOd2uViYBZP6KRO5xQd.jpg'),
(121434, 8703, 'HYPNOSISMIC Division Rap Battle Rhyme Anima [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nTA3B5GfxOd2uViYBZP6KRO5xQd.jpg'),
(121435, 8704, 'Heaven Officials Blessing [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/po4UfSjrkiocrwsIXBQxya9Ruab.jpg'),
(121436, 8704, 'Heaven Officials Blessing [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rSDdv4facSfqjEGqCx7YKTgCIYC.jpg'),
(121437, 8704, 'Heaven Officials Blessing [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sK1r8sAX4TV221Ya34UQznFOl5K.jpg'),
(121438, 8704, 'Heaven Officials Blessing [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzPLEDvDgmZXEPCNf5uS5ucSYgB.jpg'),
(121439, 8704, 'Heaven Officials Blessing [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJ3n4E5ahbjLMJfIAOgzNs1aZTI.jpg'),
(121440, 8704, 'Heaven Officials Blessing [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8LHZuQ8yp5HIYnoiVZRaI1nYh45.jpg'),
(121441, 8704, 'Heaven Officials Blessing [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/syXld6I7R2myOHPWZ6afCdnDA0O.jpg'),
(121442, 8704, 'Heaven Officials Blessing [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2b9R5SkzFJTvjZ3iXHwJM6kIyo.jpg'),
(121443, 8704, 'Heaven Officials Blessing [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xXRvWL4v8rvBFqcXgw7xCbdMtb3.jpg'),
(121444, 8704, 'Heaven Officials Blessing [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kPeMqQTrovhNhHv9zBW9Xt7M5kd.jpg'),
(121445, 8704, 'Heaven Officials Blessing [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/261468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbXBGDwgrKDlk15lrFg2MDn73hc.jpg'),
(121446, 8704, 'Heaven Officials Blessing [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/261469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aDNWhM6F9BSP688AIRs4h7JePtf.jpg'),
(121447, 8704, 'Heaven Officials Blessing [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/261470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aDNWhM6F9BSP688AIRs4h7JePtf.jpg'),
(121448, 8705, 'Heaven Officials Blessing [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7SjTQFvNXvq4dCZXICjOVsbvbLV.jpg'),
(121449, 8705, 'Heaven Officials Blessing [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aDNWhM6F9BSP688AIRs4h7JePtf.jpg'),
(121450, 8705, 'Heaven Officials Blessing [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aDNWhM6F9BSP688AIRs4h7JePtf.jpg'),
(121451, 8705, 'Heaven Officials Blessing [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aDNWhM6F9BSP688AIRs4h7JePtf.jpg'),
(121452, 8705, 'Heaven Officials Blessing [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aDNWhM6F9BSP688AIRs4h7JePtf.jpg'),
(121453, 8705, 'Heaven Officials Blessing [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aDNWhM6F9BSP688AIRs4h7JePtf.jpg'),
(121454, 8705, 'Heaven Officials Blessing [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aDNWhM6F9BSP688AIRs4h7JePtf.jpg'),
(121455, 8705, 'Heaven Officials Blessing [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aDNWhM6F9BSP688AIRs4h7JePtf.jpg'),
(121456, 8705, 'Heaven Officials Blessing [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aDNWhM6F9BSP688AIRs4h7JePtf.jpg'),
(121457, 8705, 'Heaven Officials Blessing [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aDNWhM6F9BSP688AIRs4h7JePtf.jpg'),
(121458, 8705, 'Heaven Officials Blessing [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/261481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aDNWhM6F9BSP688AIRs4h7JePtf.jpg'),
(121459, 8706, 'Hibike Euphonium [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/apkpc5aB584fgaR45Xk2m3eWzgw.jpg'),
(121460, 8706, 'Hibike Euphonium [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4AVLf7TnwUR6syJ9u4O0XHaHYOg.jpg'),
(121461, 8706, 'Hibike Euphonium [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lZQTNFKNZ71UQfOvSMmRZnvbora.jpg'),
(121462, 8706, 'Hibike Euphonium [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r9CjMa4v7esjmRwPix61n79RXLD.jpg'),
(121463, 8706, 'Hibike Euphonium [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6avm7qJP4B9gi5K5mQPWTjnu7uT.jpg'),
(121464, 8706, 'Hibike Euphonium [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oXBO1P1n4jxEDZO6XAeQRuN75Jq.jpg'),
(121465, 8706, 'Hibike Euphonium [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4X2Z6985UFh37aWYk0zPT2wjPfB.jpg'),
(121466, 8706, 'Hibike Euphonium [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/znFqfP1u1cBKit3M55wj3IvMxRl.jpg'),
(121467, 8706, 'Hibike Euphonium [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pnzvbDhw0PYw8lbyKtoA2603ra.jpg'),
(121468, 8706, 'Hibike Euphonium [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zZyJgGif4ukrfWvaFuyNINAe4A2.jpg'),
(121469, 8706, 'Hibike Euphonium [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyC63OD5BDzjVE0W25ac3OQOsIe.jpg'),
(121470, 8706, 'Hibike Euphonium [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8E85SU02HnkwiV1ocHSuhkGhlKC.jpg'),
(121471, 8706, 'Hibike Euphonium [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ZMAWfoukXaOsAVuuTNSU3OrLqL.jpg'),
(121472, 8706, 'Hibike Euphonium [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/244005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5PwD9F9ot5z3CUvb95qXtk3PGsf.jpg'),
(121473, 8707, 'Icones da Vida Selvagem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mP3QreKui6D7xMpiRA1xBbRuGcN.jpg'),
(121474, 8707, 'Icones da Vida Selvagem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mP3QreKui6D7xMpiRA1xBbRuGcN.jpg'),
(121475, 8707, 'Icones da Vida Selvagem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mP3QreKui6D7xMpiRA1xBbRuGcN.jpg'),
(121476, 8707, 'Icones da Vida Selvagem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mP3QreKui6D7xMpiRA1xBbRuGcN.jpg'),
(121477, 8707, 'Icones da Vida Selvagem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mP3QreKui6D7xMpiRA1xBbRuGcN.jpg'),
(121478, 8707, 'Icones da Vida Selvagem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mP3QreKui6D7xMpiRA1xBbRuGcN.jpg'),
(121479, 8707, 'Icones da Vida Selvagem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mP3QreKui6D7xMpiRA1xBbRuGcN.jpg'),
(121480, 8707, 'Icones da Vida Selvagem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mP3QreKui6D7xMpiRA1xBbRuGcN.jpg'),
(121481, 8708, 'Icones da Vida Selvagem S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mP3QreKui6D7xMpiRA1xBbRuGcN.jpg'),
(121482, 8708, 'Icones da Vida Selvagem S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mP3QreKui6D7xMpiRA1xBbRuGcN.jpg'),
(121483, 8708, 'Icones da Vida Selvagem S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mP3QreKui6D7xMpiRA1xBbRuGcN.jpg'),
(121484, 8708, 'Icones da Vida Selvagem S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mP3QreKui6D7xMpiRA1xBbRuGcN.jpg'),
(121485, 8708, 'Icones da Vida Selvagem S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mP3QreKui6D7xMpiRA1xBbRuGcN.jpg'),
(121486, 8708, 'Icones da Vida Selvagem S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mP3QreKui6D7xMpiRA1xBbRuGcN.jpg'),
(121487, 8709, 'Idoly Pride [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8hOUt2BbwacTdoeChcuIQTHL4O3.jpg'),
(121488, 8709, 'Idoly Pride [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4hMshqDAhDYTawOCfqgvVGsCx2o.jpg'),
(121489, 8709, 'Idoly Pride [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tdZvTBjrhvk5bCAlawVE45oER4l.jpg'),
(121490, 8709, 'Idoly Pride [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVtfefaK4LJsMF2z3dqU8HljdNV.jpg'),
(121491, 8709, 'Idoly Pride [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/maqr60sTldww8JhhZhK92nWu5SW.jpg'),
(121492, 8709, 'Idoly Pride [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDutB5UIQUaxzotTWqhkmEIXCkX.jpg'),
(121493, 8709, 'Idoly Pride [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uDGVTkjF0rh09O71vReK3XsKdhX.jpg'),
(121494, 8709, 'Idoly Pride [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ZbFeDJ57OL6adMXE8oWoSZXiXi.jpg'),
(121495, 8709, 'Idoly Pride [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1iZwSUQw6cQc0HTCa0BUHLvmrwW.jpg'),
(121496, 8709, 'Idoly Pride [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pUBhydGOqtfJEL3DzMtqt0gtcRm.jpg'),
(121497, 8709, 'Idoly Pride [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3dqW8bfj5yghmdtsnkOk9J32awP.jpg'),
(121498, 8709, 'Idoly Pride [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/243977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kCvijAXed7naRg4df5zWh2bI5q3.jpg'),
(121499, 8710, 'MF GHOST [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5E7dA6uW6KjNFbHCGLheqNdnThb.jpg'),
(121500, 8710, 'MF GHOST [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zfvLZ3xhnRZwfnWxxkoi8TagFIA.jpg'),
(121501, 8710, 'MF GHOST [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lVON5snrFJ34eeke8bCEAGEqRXD.jpg'),
(121502, 8710, 'MF GHOST [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/60mNvaXo24KI7WdQSru9fpXJklI.jpg'),
(121503, 8710, 'MF GHOST [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1BykJhZ94oeOXV1WPp5TDIe29iK.jpg'),
(121504, 8710, 'MF GHOST [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1BykJhZ94oeOXV1WPp5TDIe29iK.jpg'),
(121505, 8710, 'MF GHOST [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1BykJhZ94oeOXV1WPp5TDIe29iK.jpg'),
(121506, 8710, 'MF GHOST [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1BykJhZ94oeOXV1WPp5TDIe29iK.jpg'),
(121507, 8710, 'MF GHOST [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1BykJhZ94oeOXV1WPp5TDIe29iK.jpg'),
(121508, 8710, 'MF GHOST [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1BykJhZ94oeOXV1WPp5TDIe29iK.jpg'),
(121509, 8710, 'MF GHOST [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1BykJhZ94oeOXV1WPp5TDIe29iK.jpg'),
(121510, 8710, 'MF GHOST [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1BykJhZ94oeOXV1WPp5TDIe29iK.jpg'),
(121511, 8711, 'MF GHOST [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/633761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1BykJhZ94oeOXV1WPp5TDIe29iK.jpg'),
(121512, 8711, 'MF GHOST [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/633762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1BykJhZ94oeOXV1WPp5TDIe29iK.jpg'),
(121513, 8711, 'MF GHOST [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/633763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1BykJhZ94oeOXV1WPp5TDIe29iK.jpg'),
(121514, 8711, 'MF GHOST [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/633764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1BykJhZ94oeOXV1WPp5TDIe29iK.jpg'),
(121515, 8711, 'MF GHOST [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/633765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1BykJhZ94oeOXV1WPp5TDIe29iK.jpg'),
(121516, 8711, 'MF GHOST [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/633766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1BykJhZ94oeOXV1WPp5TDIe29iK.jpg'),
(121517, 8711, 'MF GHOST [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/633767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1BykJhZ94oeOXV1WPp5TDIe29iK.jpg'),
(121518, 8711, 'MF GHOST [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/511694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1BykJhZ94oeOXV1WPp5TDIe29iK.jpg'),
(121519, 8711, 'MF GHOST [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/514438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1BykJhZ94oeOXV1WPp5TDIe29iK.jpg'),
(121520, 8711, 'MF GHOST [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/517954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1BykJhZ94oeOXV1WPp5TDIe29iK.jpg'),
(121521, 8711, 'MF GHOST [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/525371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1BykJhZ94oeOXV1WPp5TDIe29iK.jpg'),
(121522, 8711, 'MF GHOST [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/641745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1BykJhZ94oeOXV1WPp5TDIe29iK.jpg'),
(121523, 7554, 'Ninjago Ascensao dos Dragoes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uCkILTuS0NhJsdEta589FuLlgJF.jpg'),
(121524, 7554, 'Ninjago Ascensao dos Dragoes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/83GnqzB67r3WP13kENyzh7TH4gj.jpg'),
(121525, 7554, 'Ninjago Ascensao dos Dragoes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/peNgcHZhuZRPBaLz4VVvqvVDBvA.jpg'),
(121526, 7554, 'Ninjago Ascensao dos Dragoes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1etmGCObcJI3ImPwHQNpwfjpy7P.jpg'),
(121527, 7554, 'Ninjago Ascensao dos Dragoes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qdeWN5kQBLZrmm7yD1jfPUNSCzr.jpg'),
(121528, 7554, 'Ninjago Ascensao dos Dragoes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nPdTffCemiRjUbzthrapaMsZsqP.jpg'),
(121529, 7554, 'Ninjago Ascensao dos Dragoes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7WEoVKMo8sl9M4rJR4b2P5lR7Em.jpg'),
(121530, 7554, 'Ninjago Ascensao dos Dragoes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oJoRgQG84iJQJo5f5jQePoT5Pd7.jpg'),
(121531, 7554, 'Ninjago Ascensao dos Dragoes S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2WIVVXRZneRHTCBOaAsmJ9i0DfT.jpg'),
(121532, 7554, 'Ninjago Ascensao dos Dragoes S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vNFaVeFXrqrZJJhxe9t5XrGbFvv.jpg'),
(121533, 7554, 'Ninjago Ascensao dos Dragoes S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vrnn0c2QGGW2FuOAURSBY1iCaFd.jpg'),
(121534, 7554, 'Ninjago Ascensao dos Dragoes S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/243957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zCCCZJoomwrIV0zZhdmgOD7aBQU.jpg'),
(121535, 7554, 'Ninjago Ascensao dos Dragoes S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/243958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o3VRMHRZONtGwZFt44xA0wONUeS.jpg'),
(121536, 7554, 'Ninjago Ascensao dos Dragoes S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/243959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kunPunYaGcCkQarCiYgMpJK1Cn8.jpg'),
(121537, 7554, 'Ninjago Ascensao dos Dragoes S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/243960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o5T6vTGzBYtyasiO6rmqrUsM8Y7.jpg'),
(121538, 7554, 'Ninjago Ascensao dos Dragoes S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/243961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fNGLGURumeKABbCetLX5kbRRtZm.jpg'),
(121539, 7554, 'Ninjago Ascensao dos Dragoes S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/243962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/txaImcQiJRYD5HJIeQ4lgK9vYR7.jpg'),
(121540, 7554, 'Ninjago Ascensao dos Dragoes S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/243963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ciPorolwE6ION9tqvKtEhU6JHYY.jpg'),
(121541, 7554, 'Ninjago Ascensao dos Dragoes S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/243964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/onphdaWbjyscHRph1cgVMKLFxRS.jpg'),
(121542, 7554, 'Ninjago Ascensao dos Dragoes S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/243965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5yRDdSjRYqw8Gu3qmyV4vnjtd0E.jpg'),
(121543, 8712, 'Nova York Contra John Gotti S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u79K3qdNX0r7w9DvQ8gNvdEMoJG.jpg'),
(121544, 8712, 'Nova York Contra John Gotti S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tWZAKeOGbfK7dPtJhgFitPnPWYD.jpg'),
(121545, 8712, 'Nova York Contra John Gotti S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eVYEZEjL7OWphIXeLQRisfIC6jX.jpg'),
(121546, 8713, 'OVERTAKE [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aJQ152Vx0rySr055ehmFVMBwhAL.jpg'),
(121547, 8713, 'OVERTAKE [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svIt3CKdG7ZI6lRNhSIrsNvpUpb.jpg'),
(121548, 8713, 'OVERTAKE [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j8CY43n8Eu1jNR4C3Snsfvkji05.jpg'),
(121549, 8713, 'OVERTAKE [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tAcy5SEu4tW1GIc0GrR05NlKml.jpg'),
(121550, 8713, 'OVERTAKE [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gHB7pYtWIWwPoBXCBHy96i26r1.jpg'),
(121551, 8713, 'OVERTAKE [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gHB7pYtWIWwPoBXCBHy96i26r1.jpg'),
(121552, 8713, 'OVERTAKE [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gHB7pYtWIWwPoBXCBHy96i26r1.jpg'),
(121553, 8713, 'OVERTAKE [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gHB7pYtWIWwPoBXCBHy96i26r1.jpg'),
(121554, 8713, 'OVERTAKE [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gHB7pYtWIWwPoBXCBHy96i26r1.jpg'),
(121555, 8713, 'OVERTAKE [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gHB7pYtWIWwPoBXCBHy96i26r1.jpg'),
(121556, 8713, 'OVERTAKE [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gHB7pYtWIWwPoBXCBHy96i26r1.jpg'),
(121557, 8713, 'OVERTAKE [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gHB7pYtWIWwPoBXCBHy96i26r1.jpg'),
(121558, 8714, 'Os Mares da Arabia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8vZJBeaQrPvG8tfB2fT6vAD4Jrw.jpg'),
(121559, 8714, 'Os Mares da Arabia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8vZJBeaQrPvG8tfB2fT6vAD4Jrw.jpg'),
(121560, 8714, 'Os Mares da Arabia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8vZJBeaQrPvG8tfB2fT6vAD4Jrw.jpg'),
(121561, 8714, 'Os Mares da Arabia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8vZJBeaQrPvG8tfB2fT6vAD4Jrw.jpg'),
(121562, 8714, 'Os Mares da Arabia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8vZJBeaQrPvG8tfB2fT6vAD4Jrw.jpg'),
(121563, 8715, 'Os Supercaes e Seus Extraordinarios Trabalhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9QcqNMZZ64X2wrygrqFUfV2wgAn.jpg'),
(121564, 8715, 'Os Supercaes e Seus Extraordinarios Trabalhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9QcqNMZZ64X2wrygrqFUfV2wgAn.jpg'),
(121565, 8715, 'Os Supercaes e Seus Extraordinarios Trabalhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9QcqNMZZ64X2wrygrqFUfV2wgAn.jpg'),
(121566, 8715, 'Os Supercaes e Seus Extraordinarios Trabalhos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9QcqNMZZ64X2wrygrqFUfV2wgAn.jpg'),
(121567, 8715, 'Os Supercaes e Seus Extraordinarios Trabalhos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9QcqNMZZ64X2wrygrqFUfV2wgAn.jpg'),
(121568, 8716, 'Seijo no Maryoku wa Bannou Desu [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s6QpbioFpjgQ5AnKZUcEc71I5rz.jpg'),
(121569, 8716, 'Seijo no Maryoku wa Bannou Desu [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ApmDP0WYb3XV1KJA1tvCIk5CZ.jpg'),
(121570, 8716, 'Seijo no Maryoku wa Bannou Desu [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bi14y12pr0q2HkgIwdPhba9Ep9M.jpg'),
(121571, 8716, 'Seijo no Maryoku wa Bannou Desu [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7oSIIESxV4ytwCHmPsX3f3uGc9x.jpg'),
(121572, 8716, 'Seijo no Maryoku wa Bannou Desu [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4VlSrTlrCnE2ElPzd4Gz4hTcuOR.jpg'),
(121573, 8716, 'Seijo no Maryoku wa Bannou Desu [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iW4cxdQHddG2Y9cmn3SVfrLjZq5.jpg'),
(121574, 8716, 'Seijo no Maryoku wa Bannou Desu [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sJGqLaZG24XJHhkjGUEtYuBl1DO.jpg'),
(121575, 8716, 'Seijo no Maryoku wa Bannou Desu [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wA9sxtTxJvyILEUzacHYNdQiwj1.jpg'),
(121576, 8716, 'Seijo no Maryoku wa Bannou Desu [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3OizNn4OVElECrXJe5m0msFCjP5.jpg'),
(121577, 8716, 'Seijo no Maryoku wa Bannou Desu [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wRtBACer91C1xe7GkOT6dvkukOY.jpg'),
(121578, 8716, 'Seijo no Maryoku wa Bannou Desu [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zO4jESSxzPdRWujRLCfH3Lza5Zf.jpg'),
(121579, 8716, 'Seijo no Maryoku wa Bannou Desu [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7YnhCkWoYs0DArfgWhsOSYMgFCM.jpg'),
(121580, 8717, 'Seijo no Maryoku wa Bannou Desu [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2TYcmIWX0z3SFPECBKJ8uWt3Nr7.jpg'),
(121581, 8717, 'Seijo no Maryoku wa Bannou Desu [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2TYcmIWX0z3SFPECBKJ8uWt3Nr7.jpg'),
(121582, 8717, 'Seijo no Maryoku wa Bannou Desu [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2TYcmIWX0z3SFPECBKJ8uWt3Nr7.jpg'),
(121583, 8717, 'Seijo no Maryoku wa Bannou Desu [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2TYcmIWX0z3SFPECBKJ8uWt3Nr7.jpg'),
(121584, 8717, 'Seijo no Maryoku wa Bannou Desu [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2TYcmIWX0z3SFPECBKJ8uWt3Nr7.jpg'),
(121585, 8717, 'Seijo no Maryoku wa Bannou Desu [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2TYcmIWX0z3SFPECBKJ8uWt3Nr7.jpg'),
(121586, 8717, 'Seijo no Maryoku wa Bannou Desu [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2TYcmIWX0z3SFPECBKJ8uWt3Nr7.jpg'),
(121587, 8717, 'Seijo no Maryoku wa Bannou Desu [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2TYcmIWX0z3SFPECBKJ8uWt3Nr7.jpg'),
(121588, 8717, 'Seijo no Maryoku wa Bannou Desu [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2TYcmIWX0z3SFPECBKJ8uWt3Nr7.jpg'),
(121589, 8717, 'Seijo no Maryoku wa Bannou Desu [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2TYcmIWX0z3SFPECBKJ8uWt3Nr7.jpg'),
(121590, 8717, 'Seijo no Maryoku wa Bannou Desu [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2TYcmIWX0z3SFPECBKJ8uWt3Nr7.jpg'),
(121591, 8717, 'Seijo no Maryoku wa Bannou Desu [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2TYcmIWX0z3SFPECBKJ8uWt3Nr7.jpg'),
(121592, 8718, 'Stardust Telepath [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dLy9jONalJgV6YHUipio58RAtK.jpg'),
(121593, 8718, 'Stardust Telepath [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4bnSsWUdtYdH2E8SCx35qzOE8tD.jpg'),
(121594, 8718, 'Stardust Telepath [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bn2GQinQ2HtuqlMX9zuf449HnJ4.jpg'),
(121595, 8718, 'Stardust Telepath [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/us8PO2dwfTs3TTdS80g6GH3h1dl.jpg'),
(121596, 8718, 'Stardust Telepath [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/us8PO2dwfTs3TTdS80g6GH3h1dl.jpg'),
(121597, 8718, 'Stardust Telepath [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/us8PO2dwfTs3TTdS80g6GH3h1dl.jpg'),
(121598, 8718, 'Stardust Telepath [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/us8PO2dwfTs3TTdS80g6GH3h1dl.jpg'),
(121599, 8718, 'Stardust Telepath [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/us8PO2dwfTs3TTdS80g6GH3h1dl.jpg'),
(121600, 8718, 'Stardust Telepath [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/us8PO2dwfTs3TTdS80g6GH3h1dl.jpg'),
(121601, 8718, 'Stardust Telepath [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/us8PO2dwfTs3TTdS80g6GH3h1dl.jpg'),
(121602, 8718, 'Stardust Telepath [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/us8PO2dwfTs3TTdS80g6GH3h1dl.jpg'),
(121603, 8718, 'Stardust Telepath [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/us8PO2dwfTs3TTdS80g6GH3h1dl.jpg'),
(121604, 8719, 'The Family Circumstances of the Irregular Witch [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jRKR1tOXiKQyEaU7PCzpJh9ReLW.jpg'),
(121605, 8719, 'The Family Circumstances of the Irregular Witch [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/25ViPIu3YzOG4QLZ15U9kuB3Eib.jpg'),
(121606, 8719, 'The Family Circumstances of the Irregular Witch [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ZbZsSY4pJ4hWxKrq0zX6cdpWna.jpg'),
(121607, 8719, 'The Family Circumstances of the Irregular Witch [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7MORCrNbBTDAigy9m3qQmVEPx6Y.jpg'),
(121608, 8719, 'The Family Circumstances of the Irregular Witch [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fjPW3LZvw3Lxh1p8xb1ce2IFjXO.jpg'),
(121609, 8719, 'The Family Circumstances of the Irregular Witch [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i9LcXiYcXhQjYIBIJVzlwsRHzXq.jpg'),
(121610, 8719, 'The Family Circumstances of the Irregular Witch [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i9LcXiYcXhQjYIBIJVzlwsRHzXq.jpg'),
(121611, 8719, 'The Family Circumstances of the Irregular Witch [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i9LcXiYcXhQjYIBIJVzlwsRHzXq.jpg'),
(121612, 8719, 'The Family Circumstances of the Irregular Witch [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i9LcXiYcXhQjYIBIJVzlwsRHzXq.jpg'),
(121613, 8719, 'The Family Circumstances of the Irregular Witch [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i9LcXiYcXhQjYIBIJVzlwsRHzXq.jpg'),
(121614, 8719, 'The Family Circumstances of the Irregular Witch [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i9LcXiYcXhQjYIBIJVzlwsRHzXq.jpg'),
(121615, 8719, 'The Family Circumstances of the Irregular Witch [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i9LcXiYcXhQjYIBIJVzlwsRHzXq.jpg'),
(121616, 8720, 'The Faraway Paladin [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257372.mp4', 'http://timg.bdta.pro/images/74b75ab4131a3bd913284f83f0e9eb6a.jpg'),
(121617, 8720, 'The Faraway Paladin [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257373.mp4', 'http://timg.bdta.pro/images/854f233d1cafa257b4f68d8aef8488a8.jpg'),
(121618, 8720, 'The Faraway Paladin [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257374.mp4', 'http://timg.bdta.pro/images/7fc5b9ecb4f9ced34c90f1fefe33acd1.jpg'),
(121619, 8720, 'The Faraway Paladin [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257375.mp4', 'http://timg.bdta.pro/images/a7f778fd90a710384afd810a5d74ea56.jpg'),
(121620, 8720, 'The Faraway Paladin [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257376.mp4', 'http://timg.bdta.pro/images/52982db50c8402bf1c8c231b99ef19b4.jpg'),
(121621, 8720, 'The Faraway Paladin [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257377.mp4', 'http://timg.bdta.pro/images/34cedce72ee0f16fb0d9a0226a051a38.jpg'),
(121622, 8720, 'The Faraway Paladin [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257378.mp4', 'http://timg.bdta.pro/images/33cc642e360ed82e252f6d215be7246d.jpg'),
(121623, 8720, 'The Faraway Paladin [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257379.mp4', 'http://timg.bdta.pro/images/b5f97a0029460d0b35ecb411c70273f9.jpg'),
(121624, 8720, 'The Faraway Paladin [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257380.mp4', 'http://timg.bdta.pro/images/5b5d988e5cd72449605880c9907d5086.jpg'),
(121625, 8720, 'The Faraway Paladin [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257381.mp4', 'http://timg.bdta.pro/images/fbdd16dffc74e87090b9ae6f208e989a.jpg'),
(121626, 8720, 'The Faraway Paladin [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257382.mp4', 'http://timg.bdta.pro/images/f1e1b0a4fb97bf1b8f6aa15cbc577756.jpg'),
(121627, 8720, 'The Faraway Paladin [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257383.mp4', 'http://timg.bdta.pro/images/762a6f85bdef60df686d5e62f4d80d1f.jpg'),
(121628, 8721, 'The Faraway Paladin [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jY9HGhFJEEsHUeVC2mc8dLaeBLQ.jpg'),
(121629, 8721, 'The Faraway Paladin [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1D8P4RV7kT2HzkCELtp5OawpGvc.jpg'),
(121630, 8721, 'The Faraway Paladin [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zmD3mZqgf7G7nN6anNPsN7Bhev0.jpg'),
(121631, 8721, 'The Faraway Paladin [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257387.mp4', 'http://gstaticontent.com/images/5460c0dadb67539dfdc699f3a38d1fbf.jpg'),
(121632, 8721, 'The Faraway Paladin [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257388.mp4', 'http://gstaticontent.com/images/5460c0dadb67539dfdc699f3a38d1fbf.jpg'),
(121633, 8721, 'The Faraway Paladin [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257389.mp4', 'http://gstaticontent.com/images/5460c0dadb67539dfdc699f3a38d1fbf.jpg'),
(121634, 8721, 'The Faraway Paladin [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257390.mp4', 'http://gstaticontent.com/images/5460c0dadb67539dfdc699f3a38d1fbf.jpg'),
(121635, 8721, 'The Faraway Paladin [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257391.mp4', 'http://gstaticontent.com/images/5460c0dadb67539dfdc699f3a38d1fbf.jpg'),
(121636, 8721, 'The Faraway Paladin [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257392.mp4', 'http://gstaticontent.com/images/5460c0dadb67539dfdc699f3a38d1fbf.jpg'),
(121637, 8721, 'The Faraway Paladin [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257393.mp4', 'http://gstaticontent.com/images/5460c0dadb67539dfdc699f3a38d1fbf.jpg'),
(121638, 8721, 'The Faraway Paladin [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257394.mp4', 'http://gstaticontent.com/images/5460c0dadb67539dfdc699f3a38d1fbf.jpg'),
(121639, 8721, 'The Faraway Paladin [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257395.mp4', 'http://gstaticontent.com/images/5460c0dadb67539dfdc699f3a38d1fbf.jpg'),
(121640, 8722, 'The Yuzuki Familys Four Sons [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3FcpLLEUdKuOseTDX6vsWpLeswZ.jpg'),
(121641, 8722, 'The Yuzuki Familys Four Sons [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/12WCPyOF6pYTcR0oTayd8m7ErT9.jpg'),
(121642, 8722, 'The Yuzuki Familys Four Sons [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u5FvqmGQkO7pAVnHj2hMeGRHxbd.jpg'),
(121643, 8722, 'The Yuzuki Familys Four Sons [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/givT4xEjnNUhOpF2ORfH9mRmjQc.jpg'),
(121644, 8722, 'The Yuzuki Familys Four Sons [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/givT4xEjnNUhOpF2ORfH9mRmjQc.jpg'),
(121645, 8722, 'The Yuzuki Familys Four Sons [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/givT4xEjnNUhOpF2ORfH9mRmjQc.jpg'),
(121646, 8722, 'The Yuzuki Familys Four Sons [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/givT4xEjnNUhOpF2ORfH9mRmjQc.jpg'),
(121647, 8722, 'The Yuzuki Familys Four Sons [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/givT4xEjnNUhOpF2ORfH9mRmjQc.jpg'),
(121648, 8722, 'The Yuzuki Familys Four Sons [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/givT4xEjnNUhOpF2ORfH9mRmjQc.jpg'),
(121649, 8722, 'The Yuzuki Familys Four Sons [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/givT4xEjnNUhOpF2ORfH9mRmjQc.jpg'),
(121650, 8722, 'The Yuzuki Familys Four Sons [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/givT4xEjnNUhOpF2ORfH9mRmjQc.jpg'),
(121651, 8722, 'The Yuzuki Familys Four Sons [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/givT4xEjnNUhOpF2ORfH9mRmjQc.jpg'),
(121652, 8723, 'UNDER NINJA [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iwnbWylX6OVp0rcmxeazwt5LXqb.jpg'),
(121653, 8723, 'UNDER NINJA [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l6Xqs3fhgsUc2yWuddwFiWSit4C.jpg'),
(121654, 8723, 'UNDER NINJA [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dc5QnQKlD3Si30NpEpKl4AfSbjI.jpg'),
(121655, 8723, 'UNDER NINJA [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sGfndf3p37aSZ7RbV3t6n21xEjM.jpg'),
(121656, 8723, 'UNDER NINJA [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sGfndf3p37aSZ7RbV3t6n21xEjM.jpg'),
(121657, 8723, 'UNDER NINJA [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sGfndf3p37aSZ7RbV3t6n21xEjM.jpg'),
(121658, 8723, 'UNDER NINJA [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sGfndf3p37aSZ7RbV3t6n21xEjM.jpg'),
(121659, 8723, 'UNDER NINJA [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sGfndf3p37aSZ7RbV3t6n21xEjM.jpg'),
(121660, 8723, 'UNDER NINJA [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sGfndf3p37aSZ7RbV3t6n21xEjM.jpg'),
(121661, 8723, 'UNDER NINJA [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sGfndf3p37aSZ7RbV3t6n21xEjM.jpg'),
(121662, 8723, 'UNDER NINJA [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sGfndf3p37aSZ7RbV3t6n21xEjM.jpg'),
(121663, 8723, 'UNDER NINJA [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sGfndf3p37aSZ7RbV3t6n21xEjM.jpg'),
(121664, 8724, 'Um Lobo Como Eu [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243256.mp4', 'http://timg.bdta.pro/images/96de4589ccd74230911d2014fddb81f4.jpg'),
(121665, 8724, 'Um Lobo Como Eu [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243257.mp4', 'http://timg.bdta.pro/images/a42d791a0fb87b1fe9aa7ed9cb815ed8.jpg'),
(121666, 8724, 'Um Lobo Como Eu [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243258.mp4', 'http://timg.bdta.pro/images/8e6cf60b879bcbdcfe48886c93761359.jpg'),
(121667, 8724, 'Um Lobo Como Eu [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243259.mp4', 'http://timg.bdta.pro/images/9d7a2e22c0d0197ab5e4fee671e3ffd3.jpg'),
(121668, 8724, 'Um Lobo Como Eu [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243260.mp4', 'http://timg.bdta.pro/images/d5a362785e125afd1d7c8a2fe85a362c.jpg'),
(121669, 8724, 'Um Lobo Como Eu [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243261.mp4', 'http://timg.bdta.pro/images/f06c144d9e8906c5d85082635360fd82.jpg'),
(121670, 8725, 'Um Lobo Como Eu [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AkJ1QJDCY6mIlt9PBWCePftwm8q.jpg'),
(121671, 8725, 'Um Lobo Como Eu [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBmuBpVFuDbPylUuKdVjUra0o4H.jpg'),
(121672, 8725, 'Um Lobo Como Eu [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhIyG959R754aO0IOSwtB8u42Ka.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(121673, 8725, 'Um Lobo Como Eu [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aFFw0dPjqZv9JchLtjespW33xyy.jpg'),
(121674, 8725, 'Um Lobo Como Eu [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ffyL5b5rYAAC3V3bgrM9en7nKBR.jpg'),
(121675, 8725, 'Um Lobo Como Eu [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gGaLEJgNINWcGusTFfDUjkJaQRR.jpg'),
(121676, 8725, 'Um Lobo Como Eu [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243268.mp4', 'http://gstaticontent.com/images/55cdd8379e0f9cee48f9b625bfc26494.jpg'),
(121677, 8726, 'Umamusume Pretty Derby [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dtZC0tWCySfPw3uRRt3tK72EmM.jpg'),
(121678, 8726, 'Umamusume Pretty Derby [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4FH5NU9iqz9MbSsqyO6ydlIiNwd.jpg'),
(121679, 8726, 'Umamusume Pretty Derby [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g3DMOVn4zTECX0mkryI6paQjphC.jpg'),
(121680, 8726, 'Umamusume Pretty Derby [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yxr8V5RRAgQixUE1xRNoipo7j1y.jpg'),
(121681, 8726, 'Umamusume Pretty Derby [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8bsr1oMrOqtsiW4BN6Q2HXC5GH5.jpg'),
(121682, 8726, 'Umamusume Pretty Derby [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fFCDqQMWqUItZAccbj9CpZI0q14.jpg'),
(121683, 8726, 'Umamusume Pretty Derby [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fwu1r20e4S3XOhMPHP92fHPj98a.jpg'),
(121684, 8726, 'Umamusume Pretty Derby [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aSJQCVodE0A8syaxN8JC2rzeqEs.jpg'),
(121685, 8726, 'Umamusume Pretty Derby [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bigk0yJabu8fro50nWVYuboVof4.jpg'),
(121686, 8726, 'Umamusume Pretty Derby [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3UP4joq5u0moPgzX2LTk7b8jcoD.jpg'),
(121687, 8726, 'Umamusume Pretty Derby [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVKUCwvOPNBT87sFGZ6S8vHSLOD.jpg'),
(121688, 8726, 'Umamusume Pretty Derby [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3EaMFQvTOS2mh6zwhJ9BXZdeKv.jpg'),
(121689, 8726, 'Umamusume Pretty Derby [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dT0cHfXEUlPjdtOfxa6UDGVVgQj.jpg'),
(121690, 8727, 'Umamusume Pretty Derby [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aXvX9dVr2DLWGtkRgeKUZ5FqgVE.jpg'),
(121691, 8727, 'Umamusume Pretty Derby [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3XqIQA8wQLMqfxWIPMiDnNJ4yoN.jpg'),
(121692, 8727, 'Umamusume Pretty Derby [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6PkWThlyGJnybHHIHiFTBd8fZel.jpg'),
(121693, 8727, 'Umamusume Pretty Derby [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/etFPiNk7Xz9as3OBYvB0y6sgus6.jpg'),
(121694, 8727, 'Umamusume Pretty Derby [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZVuvc6WPyelM8Gi1nkTG8CZe6m.jpg'),
(121695, 8727, 'Umamusume Pretty Derby [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fElLqgS2SoYUK4KVzgzrS7EZHjz.jpg'),
(121696, 8727, 'Umamusume Pretty Derby [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/CWvWinC01B7U4U9IsAEQMxeWsQ.jpg'),
(121697, 8727, 'Umamusume Pretty Derby [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/emAVocCTwjyW1zO4BBfCGwlQWmg.jpg'),
(121698, 8727, 'Umamusume Pretty Derby [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hA4K9yB9cWxzD7EWz5IUkeY3GgQ.jpg'),
(121699, 8727, 'Umamusume Pretty Derby [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dlY4EvwmuwBASLbNdIkn74n8fp.jpg'),
(121700, 8727, 'Umamusume Pretty Derby [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7cyUdvdJMqan60HmmDBkd7yuNVa.jpg'),
(121701, 8727, 'Umamusume Pretty Derby [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/boC1UuZEADFmcgRdan9O0RhaqnH.jpg'),
(121702, 8727, 'Umamusume Pretty Derby [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6jb9U1YphQ6GrQDRANNubIFR8fp.jpg'),
(121703, 8728, 'Umamusume Pretty Derby [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/byq9EHv3yShNc4f8OlwwjwHFyZp.jpg'),
(121704, 8728, 'Umamusume Pretty Derby [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ArcH4uJYddmbgvZmhlrY6mrfll5.jpg'),
(121705, 8728, 'Umamusume Pretty Derby [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s0ENCPyj672e2rnUSbxOTZ7L6m9.jpg'),
(121706, 8728, 'Umamusume Pretty Derby [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMbcwRU8xeI63udEz6yk90X4rjb.jpg'),
(121707, 8728, 'Umamusume Pretty Derby [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMbcwRU8xeI63udEz6yk90X4rjb.jpg'),
(121708, 8728, 'Umamusume Pretty Derby [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMbcwRU8xeI63udEz6yk90X4rjb.jpg'),
(121709, 8728, 'Umamusume Pretty Derby [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMbcwRU8xeI63udEz6yk90X4rjb.jpg'),
(121710, 8728, 'Umamusume Pretty Derby [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMbcwRU8xeI63udEz6yk90X4rjb.jpg'),
(121711, 8728, 'Umamusume Pretty Derby [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMbcwRU8xeI63udEz6yk90X4rjb.jpg'),
(121712, 8728, 'Umamusume Pretty Derby [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMbcwRU8xeI63udEz6yk90X4rjb.jpg'),
(121713, 8728, 'Umamusume Pretty Derby [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMbcwRU8xeI63udEz6yk90X4rjb.jpg'),
(121714, 8728, 'Umamusume Pretty Derby [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMbcwRU8xeI63udEz6yk90X4rjb.jpg'),
(121715, 8728, 'Umamusume Pretty Derby [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMbcwRU8xeI63udEz6yk90X4rjb.jpg'),
(121716, 8729, 'A Terapia por Sebastian Fitzek S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zQ2jfn7idZPvWYx2EFeyPmjxV9o.jpg'),
(121717, 8729, 'A Terapia por Sebastian Fitzek S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kqX5IJdu3nbV6nUYy6EZRVKzLKd.jpg'),
(121718, 8729, 'A Terapia por Sebastian Fitzek S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2kALoi4SowpStqGuuarYH2PIEUa.jpg'),
(121719, 8729, 'A Terapia por Sebastian Fitzek S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ex4rMyR3RMLQ4Bb06syNbfbzmS.jpg'),
(121720, 8729, 'A Terapia por Sebastian Fitzek S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iObJFYmXW2CLxxpW3cAndN7EIfP.jpg'),
(121721, 8729, 'A Terapia por Sebastian Fitzek S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZbUM1hX0OsRNNLHSenLr432dlE.jpg'),
(121722, 8730, 'Capitao Tsubasa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6PrmdKwrC2h90jY5WVWtrc71Ka4.jpg'),
(121723, 8730, 'Capitao Tsubasa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rr8wTcSEE82HCmj8ZbFvXb5bs8x.jpg'),
(121724, 8730, 'Capitao Tsubasa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vkbFyHUaXP1qRIfIbn6kqtIFOUZ.jpg'),
(121725, 8730, 'Capitao Tsubasa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wmCjuBlDPiJq7ljyjCuvzoX7Bno.jpg'),
(121726, 8730, 'Capitao Tsubasa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/XCH5svpMfsk3hn3KnMqhgO8ggo.jpg'),
(121727, 8730, 'Capitao Tsubasa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5H2CX319NaoUmiQfs2qWhMoJBSK.jpg'),
(121728, 8730, 'Capitao Tsubasa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dogAzfq77M3CICm376uX7CJUze.jpg'),
(121729, 8730, 'Capitao Tsubasa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xoaEFtPbmWMxkb4OihC8DYZGszq.jpg'),
(121730, 8730, 'Capitao Tsubasa S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xiwZVQ1egfQmdVxp9QKTlAZfsmP.jpg'),
(121731, 8730, 'Capitao Tsubasa S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3xkBfZpYVY92QZ98v4qDeJQum63.jpg'),
(121732, 8730, 'Capitao Tsubasa S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4EsQIYXwQbxAEoutGU1mZsNsOtm.jpg'),
(121733, 8730, 'Capitao Tsubasa S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/243826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eOiX79pPFcGhaxspwQykWNLWdoa.jpg'),
(121734, 8730, 'Capitao Tsubasa S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/243827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/37Ek26F7HcazDXgNwHsQ1rw5rwv.jpg'),
(121735, 8730, 'Capitao Tsubasa S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/243828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/umozhMDIhwyDtuWaDrCsE765ZOz.jpg'),
(121736, 8730, 'Capitao Tsubasa S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/243829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ySIVrgrED6FVTLcdK7dQAeoQhtd.jpg'),
(121737, 8730, 'Capitao Tsubasa S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/243830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/GgEOQBR3lEp8R3enL9KwBnXzGY.jpg'),
(121738, 8730, 'Capitao Tsubasa S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/243831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9rlDhjs9wMhbpe0LYszPk3CABiu.jpg'),
(121739, 8730, 'Capitao Tsubasa S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/243832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9zLQi7nipzAtolG7qlO24tfsq2V.jpg'),
(121740, 8730, 'Capitao Tsubasa S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/243833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4d6j1zLJuAm28MBDLTO2fdJ821s.jpg'),
(121741, 8730, 'Capitao Tsubasa S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/243834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l3oOOWtQJKHAVDXi7XQysvMAfEZ.jpg'),
(121742, 8730, 'Capitao Tsubasa S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/243835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2DlyZt7ZOWf0y1SBSvQUkcblfrs.jpg'),
(121743, 8730, 'Capitao Tsubasa S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/243836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ae4bBg0yNBD2N3jjnZng1TC2dgl.jpg'),
(121744, 8730, 'Capitao Tsubasa S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/243837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fc4u18rr4m1j7bmOC9qArS0akL2.jpg'),
(121745, 8730, 'Capitao Tsubasa S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/243838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lbnPyD06kp9s5AiIriI7XQRYuSy.jpg'),
(121746, 8730, 'Capitao Tsubasa S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/243839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AgQSvDye1UW8JpW7sxfsuzSfdtX.jpg'),
(121747, 8730, 'Capitao Tsubasa S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/243840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dPSJl3zP9iFeBwMqYxyiEprOXZ0.jpg'),
(121748, 8730, 'Capitao Tsubasa S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/243841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/klQsNT24GZ5hdZRImrvTLvpRCSD.jpg'),
(121749, 8730, 'Capitao Tsubasa S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/243842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v9JZxdMlTRqtbPh93q86Na4anWL.jpg'),
(121750, 8730, 'Capitao Tsubasa S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/243843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1bChBoOngi0HkERjCwNqlNzuok6.jpg'),
(121751, 8730, 'Capitao Tsubasa S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/243844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0i29q3VyRLqnGuKv6kxk8Qu4qZ.jpg'),
(121752, 8730, 'Capitao Tsubasa S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/243845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b2S4SEajpFtdg5LzR8NoEhZFBBD.jpg'),
(121753, 8730, 'Capitao Tsubasa S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/243846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/askjDIdCgD6453idQ3hvRJ0wtXt.jpg'),
(121754, 8730, 'Capitao Tsubasa S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/243847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fTickUvT37xFfG9rMGi4nifrKKx.jpg'),
(121755, 8730, 'Capitao Tsubasa S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/243848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j0puDYScv1DxEFkXACGKR56Vt1S.jpg'),
(121756, 8730, 'Capitao Tsubasa S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/243849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u9QCKc5BTrJhOFfjJ0diBgRWmTM.jpg'),
(121757, 8730, 'Capitao Tsubasa S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/243850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nnvdh3BjC5fcwDUPqVopG5zclfj.jpg'),
(121758, 8730, 'Capitao Tsubasa S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/243851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1qELxoynATCXjG0CqzOrUxdV5YZ.jpg'),
(121759, 8730, 'Capitao Tsubasa S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/243852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4DUjVhns48UZNoG7723MwuvDjUI.jpg'),
(121760, 8730, 'Capitao Tsubasa S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/243853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8VJQR76p0e8brrp7cJobTG4dHAZ.jpg'),
(121761, 8730, 'Capitao Tsubasa S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/243854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oE0mATZzZSeNUoEpiOlvbsnJCZv.jpg'),
(121762, 8730, 'Capitao Tsubasa S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/243855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j4NDEtinkL36Xr0yuCnN4HGz9uz.jpg'),
(121763, 8730, 'Capitao Tsubasa S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/243856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rVQUfuTQus8Bq2WbbSMGqVbJH2S.jpg'),
(121764, 8730, 'Capitao Tsubasa S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/243857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rkHu38H1uc4QwZvCwyGdwL8bINj.jpg'),
(121765, 8730, 'Capitao Tsubasa S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/243858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8NAmHrZsLFNzUkcO5DqtYo0zDNk.jpg'),
(121766, 8730, 'Capitao Tsubasa S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/243859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aLzg21HXyXTXbD3XAMAhwQ1cdS2.jpg'),
(121767, 8730, 'Capitao Tsubasa S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/243860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bbwObEd69OJV39i0FEHuaNERg6N.jpg'),
(121768, 8730, 'Capitao Tsubasa S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/243861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5XNXIh0acMmyzekvYnpCNuOdNU7.jpg'),
(121769, 8730, 'Capitao Tsubasa S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/243862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4v9wQZhGZ2seB1sHkcUojTFAnoQ.jpg'),
(121770, 8730, 'Capitao Tsubasa S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/243863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTEJBEV16LxSSYhtWD9tatsRWZ3.jpg'),
(121771, 8730, 'Capitao Tsubasa S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/243864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qvcR8cJYmKR4v7atzFdYdUU7I2Y.jpg'),
(121772, 8730, 'Capitao Tsubasa S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/243865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pAn7VOVd10eWJLryomNsrgcVz13.jpg'),
(121773, 8730, 'Capitao Tsubasa S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/243866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pdOKMx9sXzcYnLQkCL98yXgtweE.jpg'),
(121774, 8731, 'Capitao Tsubasa [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6PrmdKwrC2h90jY5WVWtrc71Ka4.jpg'),
(121775, 8731, 'Capitao Tsubasa [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rr8wTcSEE82HCmj8ZbFvXb5bs8x.jpg'),
(121776, 8731, 'Capitao Tsubasa [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vkbFyHUaXP1qRIfIbn6kqtIFOUZ.jpg'),
(121777, 8731, 'Capitao Tsubasa [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wmCjuBlDPiJq7ljyjCuvzoX7Bno.jpg'),
(121778, 8731, 'Capitao Tsubasa [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/XCH5svpMfsk3hn3KnMqhgO8ggo.jpg'),
(121779, 8731, 'Capitao Tsubasa [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5H2CX319NaoUmiQfs2qWhMoJBSK.jpg'),
(121780, 8731, 'Capitao Tsubasa [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dogAzfq77M3CICm376uX7CJUze.jpg'),
(121781, 8731, 'Capitao Tsubasa [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xoaEFtPbmWMxkb4OihC8DYZGszq.jpg'),
(121782, 8731, 'Capitao Tsubasa [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/262686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xiwZVQ1egfQmdVxp9QKTlAZfsmP.jpg'),
(121783, 8731, 'Capitao Tsubasa [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/262687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3xkBfZpYVY92QZ98v4qDeJQum63.jpg'),
(121784, 8731, 'Capitao Tsubasa [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/262688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4EsQIYXwQbxAEoutGU1mZsNsOtm.jpg'),
(121785, 8731, 'Capitao Tsubasa [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/262689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eOiX79pPFcGhaxspwQykWNLWdoa.jpg'),
(121786, 8731, 'Capitao Tsubasa [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/262690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/37Ek26F7HcazDXgNwHsQ1rw5rwv.jpg'),
(121787, 8731, 'Capitao Tsubasa [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/262691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/umozhMDIhwyDtuWaDrCsE765ZOz.jpg'),
(121788, 8731, 'Capitao Tsubasa [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/262692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ySIVrgrED6FVTLcdK7dQAeoQhtd.jpg'),
(121789, 8731, 'Capitao Tsubasa [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/262693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/GgEOQBR3lEp8R3enL9KwBnXzGY.jpg'),
(121790, 8731, 'Capitao Tsubasa [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/262694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9rlDhjs9wMhbpe0LYszPk3CABiu.jpg'),
(121791, 8731, 'Capitao Tsubasa [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/262695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9zLQi7nipzAtolG7qlO24tfsq2V.jpg'),
(121792, 8731, 'Capitao Tsubasa [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/262696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4d6j1zLJuAm28MBDLTO2fdJ821s.jpg'),
(121793, 8731, 'Capitao Tsubasa [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/262697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l3oOOWtQJKHAVDXi7XQysvMAfEZ.jpg'),
(121794, 8731, 'Capitao Tsubasa [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/262698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2DlyZt7ZOWf0y1SBSvQUkcblfrs.jpg'),
(121795, 8731, 'Capitao Tsubasa [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/262699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ae4bBg0yNBD2N3jjnZng1TC2dgl.jpg'),
(121796, 8731, 'Capitao Tsubasa [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/262700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fc4u18rr4m1j7bmOC9qArS0akL2.jpg'),
(121797, 8731, 'Capitao Tsubasa [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/262701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lbnPyD06kp9s5AiIriI7XQRYuSy.jpg'),
(121798, 8731, 'Capitao Tsubasa [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/262702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AgQSvDye1UW8JpW7sxfsuzSfdtX.jpg'),
(121799, 8731, 'Capitao Tsubasa [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/262703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dPSJl3zP9iFeBwMqYxyiEprOXZ0.jpg'),
(121800, 8731, 'Capitao Tsubasa [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/262704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/klQsNT24GZ5hdZRImrvTLvpRCSD.jpg'),
(121801, 8731, 'Capitao Tsubasa [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/262705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v9JZxdMlTRqtbPh93q86Na4anWL.jpg'),
(121802, 8731, 'Capitao Tsubasa [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/262706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1bChBoOngi0HkERjCwNqlNzuok6.jpg'),
(121803, 8731, 'Capitao Tsubasa [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/262707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0i29q3VyRLqnGuKv6kxk8Qu4qZ.jpg'),
(121804, 8731, 'Capitao Tsubasa [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/262708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b2S4SEajpFtdg5LzR8NoEhZFBBD.jpg'),
(121805, 8731, 'Capitao Tsubasa [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/262709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/askjDIdCgD6453idQ3hvRJ0wtXt.jpg'),
(121806, 8731, 'Capitao Tsubasa [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/262710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fTickUvT37xFfG9rMGi4nifrKKx.jpg'),
(121807, 8731, 'Capitao Tsubasa [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/262711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j0puDYScv1DxEFkXACGKR56Vt1S.jpg'),
(121808, 8731, 'Capitao Tsubasa [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/262712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u9QCKc5BTrJhOFfjJ0diBgRWmTM.jpg'),
(121809, 8731, 'Capitao Tsubasa [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/262713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nnvdh3BjC5fcwDUPqVopG5zclfj.jpg'),
(121810, 8731, 'Capitao Tsubasa [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/262714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1qELxoynATCXjG0CqzOrUxdV5YZ.jpg'),
(121811, 8731, 'Capitao Tsubasa [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/262715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4DUjVhns48UZNoG7723MwuvDjUI.jpg'),
(121812, 8731, 'Capitao Tsubasa [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/262716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8VJQR76p0e8brrp7cJobTG4dHAZ.jpg'),
(121813, 8731, 'Capitao Tsubasa [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/262717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oE0mATZzZSeNUoEpiOlvbsnJCZv.jpg'),
(121814, 8731, 'Capitao Tsubasa [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/262718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j4NDEtinkL36Xr0yuCnN4HGz9uz.jpg'),
(121815, 8731, 'Capitao Tsubasa [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/262719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rVQUfuTQus8Bq2WbbSMGqVbJH2S.jpg'),
(121816, 8731, 'Capitao Tsubasa [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/262720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rkHu38H1uc4QwZvCwyGdwL8bINj.jpg'),
(121817, 8731, 'Capitao Tsubasa [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/262721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8NAmHrZsLFNzUkcO5DqtYo0zDNk.jpg'),
(121818, 8731, 'Capitao Tsubasa [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/262722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aLzg21HXyXTXbD3XAMAhwQ1cdS2.jpg'),
(121819, 8731, 'Capitao Tsubasa [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/262723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bbwObEd69OJV39i0FEHuaNERg6N.jpg'),
(121820, 8731, 'Capitao Tsubasa [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/262724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5XNXIh0acMmyzekvYnpCNuOdNU7.jpg'),
(121821, 8731, 'Capitao Tsubasa [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/262725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4v9wQZhGZ2seB1sHkcUojTFAnoQ.jpg'),
(121822, 8731, 'Capitao Tsubasa [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/262726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTEJBEV16LxSSYhtWD9tatsRWZ3.jpg'),
(121823, 8731, 'Capitao Tsubasa [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/262727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qvcR8cJYmKR4v7atzFdYdUU7I2Y.jpg'),
(121824, 8731, 'Capitao Tsubasa [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/262728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pAn7VOVd10eWJLryomNsrgcVz13.jpg'),
(121825, 8731, 'Capitao Tsubasa [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/262729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pdOKMx9sXzcYnLQkCL98yXgtweE.jpg'),
(121826, 8732, 'Capitao Tsubasa [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y9nv70OQYTBdYdFuPFcb4FwSWmi.jpg'),
(121827, 8732, 'Capitao Tsubasa [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qEQpPlbDLNdYigx0TNKBy31ECkd.jpg'),
(121828, 8732, 'Capitao Tsubasa [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/frndO48p796K9c7SCO2t0d0VUaC.jpg'),
(121829, 8732, 'Capitao Tsubasa [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/crJ754Y7zUQlgPjVwFBz7WoErzv.jpg'),
(121830, 8732, 'Capitao Tsubasa [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121831, 8732, 'Capitao Tsubasa [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121832, 8732, 'Capitao Tsubasa [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121833, 8732, 'Capitao Tsubasa [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121834, 8732, 'Capitao Tsubasa [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/262738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121835, 8732, 'Capitao Tsubasa [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/262739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121836, 8732, 'Capitao Tsubasa [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/262740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121837, 8732, 'Capitao Tsubasa [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/262741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121838, 8732, 'Capitao Tsubasa [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/262742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121839, 8732, 'Capitao Tsubasa [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/262743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121840, 8732, 'Capitao Tsubasa [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/262744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121841, 8732, 'Capitao Tsubasa [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/262745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121842, 8732, 'Capitao Tsubasa [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/262746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121843, 8732, 'Capitao Tsubasa [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/273242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121844, 8732, 'Capitao Tsubasa [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/276888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121845, 8732, 'Capitao Tsubasa [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/276889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121846, 8732, 'Capitao Tsubasa [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/283071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121847, 8732, 'Capitao Tsubasa [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/298178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121848, 8732, 'Capitao Tsubasa [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/298179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121849, 8732, 'Capitao Tsubasa [L] S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/303008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121850, 8732, 'Capitao Tsubasa [L] S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/309274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121851, 8732, 'Capitao Tsubasa [L] S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/323004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121852, 8732, 'Capitao Tsubasa [L] S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/326881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121853, 8732, 'Capitao Tsubasa [L] S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/326882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121854, 8732, 'Capitao Tsubasa [L] S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/345784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121855, 8732, 'Capitao Tsubasa [L] S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/345785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121856, 8732, 'Capitao Tsubasa [L] S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/345786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121857, 8732, 'Capitao Tsubasa [L] S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/362647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121858, 8732, 'Capitao Tsubasa [L] S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/362648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121859, 8732, 'Capitao Tsubasa [L] S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/383287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121860, 8732, 'Capitao Tsubasa [L] S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/383288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121861, 8732, 'Capitao Tsubasa [L] S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/383289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121862, 8732, 'Capitao Tsubasa [L] S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/417183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121863, 8732, 'Capitao Tsubasa [L] S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/417184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121864, 8732, 'Capitao Tsubasa [L] S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/417185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ebcN4fDDk9QdGTvVrD7TIa18za.jpg'),
(121865, 8733, 'Fim S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w7RbMmtyx0nWGdQbYTl0LyMaGkc.jpg'),
(121866, 8733, 'Fim S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AeDjGGrQ3MtAUVc8bKAGqBFY9eZ.jpg'),
(121867, 8733, 'Fim S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cMV2dXgotLxwH97Cy0FFD6y7hXl.jpg'),
(121868, 8733, 'Fim S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cMV2dXgotLxwH97Cy0FFD6y7hXl.jpg'),
(121869, 8733, 'Fim S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cMV2dXgotLxwH97Cy0FFD6y7hXl.jpg'),
(121870, 8733, 'Fim S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cMV2dXgotLxwH97Cy0FFD6y7hXl.jpg'),
(121871, 8733, 'Fim S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cMV2dXgotLxwH97Cy0FFD6y7hXl.jpg'),
(121872, 8733, 'Fim S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cMV2dXgotLxwH97Cy0FFD6y7hXl.jpg'),
(121873, 8733, 'Fim S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cMV2dXgotLxwH97Cy0FFD6y7hXl.jpg'),
(121874, 8733, 'Fim S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cMV2dXgotLxwH97Cy0FFD6y7hXl.jpg'),
(121875, 8734, 'Ilha da Tentacao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gurOVMyjaTDNHwFvD9lelPmRsiz.jpg'),
(121876, 8734, 'Ilha da Tentacao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/et6uPQTzt3Ejz1Y1rkQnWd6Ncml.jpg'),
(121877, 8734, 'Ilha da Tentacao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/et6uPQTzt3Ejz1Y1rkQnWd6Ncml.jpg'),
(121878, 8734, 'Ilha da Tentacao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121879, 8734, 'Ilha da Tentacao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121880, 8734, 'Ilha da Tentacao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121881, 8734, 'Ilha da Tentacao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121882, 8734, 'Ilha da Tentacao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121883, 8734, 'Ilha da Tentacao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121884, 8734, 'Ilha da Tentacao S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121885, 8734, 'Ilha da Tentacao S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121886, 8735, 'Ilha da Tentacao S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121887, 8735, 'Ilha da Tentacao S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121888, 8735, 'Ilha da Tentacao S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121889, 8735, 'Ilha da Tentacao S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121890, 8735, 'Ilha da Tentacao S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121891, 8735, 'Ilha da Tentacao S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121892, 8735, 'Ilha da Tentacao S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121893, 8735, 'Ilha da Tentacao S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121894, 8735, 'Ilha da Tentacao S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121895, 8735, 'Ilha da Tentacao S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121896, 8735, 'Ilha da Tentacao S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121897, 8735, 'Ilha da Tentacao S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/243802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121898, 8736, 'Ilha da Tentacao S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121899, 8736, 'Ilha da Tentacao S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121900, 8736, 'Ilha da Tentacao S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121901, 8736, 'Ilha da Tentacao S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121902, 8736, 'Ilha da Tentacao S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121903, 8736, 'Ilha da Tentacao S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121904, 8736, 'Ilha da Tentacao S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121905, 8736, 'Ilha da Tentacao S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121906, 8736, 'Ilha da Tentacao S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121907, 8736, 'Ilha da Tentacao S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121908, 8736, 'Ilha da Tentacao S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121909, 8736, 'Ilha da Tentacao S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/243814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/acolOR1yvXOOQXedBWdQgPusPyW.jpg'),
(121910, 8737, 'John Carpenters Suburban Screams [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vKLIjPxhWaxcMMWOJvt6OJ0hwtK.jpg'),
(121911, 8737, 'John Carpenters Suburban Screams [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2bKAR6XnT9cFhs00jWL1aigRhfL.jpg'),
(121912, 8737, 'John Carpenters Suburban Screams [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zVDMyECd9uRUQBcqsGIWnKkLlYb.jpg'),
(121913, 8737, 'John Carpenters Suburban Screams [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zVDMyECd9uRUQBcqsGIWnKkLlYb.jpg'),
(121914, 8737, 'John Carpenters Suburban Screams [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zVDMyECd9uRUQBcqsGIWnKkLlYb.jpg'),
(121915, 8737, 'John Carpenters Suburban Screams [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zVDMyECd9uRUQBcqsGIWnKkLlYb.jpg'),
(121916, 8738, 'Morangos com Acucar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AlsHUkjieS6n4WghtrlivC1KeFh.jpg'),
(121917, 8738, 'Morangos com Acucar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zgWM9KdIFvAsYmiQZboRuQFWrmt.jpg'),
(121918, 8738, 'Morangos com Acucar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtPv0mv47989THmy1u9kFMGF8wx.jpg'),
(121919, 8738, 'Morangos com Acucar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7FQZoRqrGCzakGGUDDFHlHPDCZN.jpg'),
(121920, 8738, 'Morangos com Acucar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5F8ZAbIuj5OUAUUjj2gUDEo5jeh.jpg'),
(121921, 8738, 'Morangos com Acucar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/94rwuZsw4bKKhcKtCj0gBTLXbED.jpg'),
(121922, 8738, 'Morangos com Acucar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4WClBWFowNyh2iBwEvY6LmKUIPK.jpg'),
(121923, 8738, 'Morangos com Acucar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i826RRZdG6Fc0ft7qzjB0JjvHhB.jpg'),
(121924, 8738, 'Morangos com Acucar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QZJFiGlnOxZGoCngrfyUPLx8O7.jpg'),
(121925, 8738, 'Morangos com Acucar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/58zQn3U0y94rPGrJp2ttstwOCvE.jpg'),
(121926, 8739, 'Morangos com Acucar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGN120mLdeWOkKsSqs94nkmgwI6.jpg'),
(121927, 8739, 'Morangos com Acucar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGN120mLdeWOkKsSqs94nkmgwI6.jpg'),
(121928, 8739, 'Morangos com Acucar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGN120mLdeWOkKsSqs94nkmgwI6.jpg'),
(121929, 8739, 'Morangos com Acucar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGN120mLdeWOkKsSqs94nkmgwI6.jpg'),
(121930, 8739, 'Morangos com Acucar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGN120mLdeWOkKsSqs94nkmgwI6.jpg'),
(121931, 8739, 'Morangos com Acucar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGN120mLdeWOkKsSqs94nkmgwI6.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(121932, 8739, 'Morangos com Acucar S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGN120mLdeWOkKsSqs94nkmgwI6.jpg'),
(121933, 8739, 'Morangos com Acucar S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGN120mLdeWOkKsSqs94nkmgwI6.jpg'),
(121934, 8739, 'Morangos com Acucar S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGN120mLdeWOkKsSqs94nkmgwI6.jpg'),
(121935, 8739, 'Morangos com Acucar S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGN120mLdeWOkKsSqs94nkmgwI6.jpg'),
(121936, 8740, 'Morangos com Acucar S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/447318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGN120mLdeWOkKsSqs94nkmgwI6.jpg'),
(121937, 8740, 'Morangos com Acucar S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/447319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGN120mLdeWOkKsSqs94nkmgwI6.jpg'),
(121938, 8740, 'Morangos com Acucar S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/447320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGN120mLdeWOkKsSqs94nkmgwI6.jpg'),
(121939, 8740, 'Morangos com Acucar S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/447321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGN120mLdeWOkKsSqs94nkmgwI6.jpg'),
(121940, 8740, 'Morangos com Acucar S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/447322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGN120mLdeWOkKsSqs94nkmgwI6.jpg'),
(121941, 8740, 'Morangos com Acucar S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/447323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGN120mLdeWOkKsSqs94nkmgwI6.jpg'),
(121942, 8740, 'Morangos com Acucar S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/447324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGN120mLdeWOkKsSqs94nkmgwI6.jpg'),
(121943, 8740, 'Morangos com Acucar S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/447325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGN120mLdeWOkKsSqs94nkmgwI6.jpg'),
(121944, 8740, 'Morangos com Acucar S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/447326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGN120mLdeWOkKsSqs94nkmgwI6.jpg'),
(121945, 8740, 'Morangos com Acucar S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/447327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qGN120mLdeWOkKsSqs94nkmgwI6.jpg'),
(121946, 8741, 'PLUTO S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mAqCVVw5VG3KZcI2O528LDlZcSZ.jpg'),
(121947, 8741, 'PLUTO S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/evYFDMR0DvhL7lt6CPyfbmKDfF4.jpg'),
(121948, 8741, 'PLUTO S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lfc90O04b6Xkvev0ciwdnyrMWaY.jpg'),
(121949, 8741, 'PLUTO S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4vCyaXmiadyMKEb0yWjyhWiGWQK.jpg'),
(121950, 8741, 'PLUTO S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e4Tfkzv0ab0FXg1BuBW7P7VYOFR.jpg'),
(121951, 8741, 'PLUTO S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wrXjDMt0mGDffEahR5ow3ICL2Tj.jpg'),
(121952, 8741, 'PLUTO S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6MW1AgghuwJ1MK8SSPHfSswrxxh.jpg'),
(121953, 8741, 'PLUTO S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qcDkAL5mrt81OGqMl2S3FkCATU1.jpg'),
(121954, 8742, 'Revolucao Cubana vs. O Mundo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tvpfkl8ci5RMk7gqkQTRQirZje1.jpg'),
(121955, 8742, 'Revolucao Cubana vs. O Mundo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tvpfkl8ci5RMk7gqkQTRQirZje1.jpg'),
(121956, 8743, 'Rotas da Escravidao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vPzBFyNFoHu0Wvtk0xkxaGcQLm2.jpg'),
(121957, 8743, 'Rotas da Escravidao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AeJ3jWOaBNNt2u2OA7TPPcsOx7l.jpg'),
(121958, 8743, 'Rotas da Escravidao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzpwD26bCeQFFUzt0pCzNo6Piem.jpg'),
(121959, 8743, 'Rotas da Escravidao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fvt0NXTRL1otITSvNvxWEf9WtjR.jpg'),
(121960, 8744, 'Yu Gi Oh Sevens [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ar32fAjLhLn47sZWxSrqABDDdJ.jpg'),
(121961, 8744, 'Yu Gi Oh Sevens [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uWbnKdp1GJopILWiQjl9KRQGTd8.jpg'),
(121962, 8744, 'Yu Gi Oh Sevens [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rIjYOnP2A5GQgkV6PaIsfLN7iry.jpg'),
(121963, 8744, 'Yu Gi Oh Sevens [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xvvgurvVsU6bxFcyVrlwxQ1srJz.jpg'),
(121964, 8744, 'Yu Gi Oh Sevens [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/87Pab4NQBJdQZSTCmQXuUG3f5PJ.jpg'),
(121965, 8744, 'Yu Gi Oh Sevens [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pdTvhhJHiWTvqTJtuLKWdHa24DF.jpg'),
(121966, 8744, 'Yu Gi Oh Sevens [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qXsvbaxbo20NsFR8IBECBMkx6TM.jpg'),
(121967, 8744, 'Yu Gi Oh Sevens [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7tuivtEGbdC8OknAtNLb2mmUO0y.jpg'),
(121968, 8744, 'Yu Gi Oh Sevens [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odm9H8x7mhkas6Yvxo11W4AuFZk.jpg'),
(121969, 8744, 'Yu Gi Oh Sevens [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9maUy4NqNgU1ACBVRE5eXjZpxG.jpg'),
(121970, 8744, 'Yu Gi Oh Sevens [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lVJb9aUTFXQVeNc82pFMUv9MpYH.jpg'),
(121971, 8744, 'Yu Gi Oh Sevens [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/243685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k1UKqteT5PMXnnKHMe7Hvr7Z5KX.jpg'),
(121972, 8744, 'Yu Gi Oh Sevens [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/243686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ogY2ZXjpVlD6jTamajIXbnGb0nD.jpg'),
(121973, 8744, 'Yu Gi Oh Sevens [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/243687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rKN3JD1NM4vo52ZKqZMd6FOMgTT.jpg'),
(121974, 8744, 'Yu Gi Oh Sevens [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/243688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8oQwQ43qKZpPobCKtL2UbzCQKHo.jpg'),
(121975, 8744, 'Yu Gi Oh Sevens [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/243689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ksbuzPTwIUdLayMpjrK45RwEzc.jpg'),
(121976, 8744, 'Yu Gi Oh Sevens [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/243690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rvxGU0tfcUZBFQWMyQG7nRUrt50.jpg'),
(121977, 8744, 'Yu Gi Oh Sevens [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/243691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mG4z5virAMGHGqmnIwdLgBYw0hB.jpg'),
(121978, 8744, 'Yu Gi Oh Sevens [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/243692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vjf8npPSXk1v8Ef1M2kgZXNC3Fg.jpg'),
(121979, 8744, 'Yu Gi Oh Sevens [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/243693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lgLWCMXqPhYvstXbKR6QBUUDt8j.jpg'),
(121980, 8744, 'Yu Gi Oh Sevens [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/243694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1aSAnHrlEewWrZ4ZWO3Bk0MCTnd.jpg'),
(121981, 8744, 'Yu Gi Oh Sevens [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/243695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0qaNb1odJmXsHjd0WpzKTX9p4b.jpg'),
(121982, 8744, 'Yu Gi Oh Sevens [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/243696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3YlVfsu5GpNDWF9Qda0nhXQJvS2.jpg'),
(121983, 8744, 'Yu Gi Oh Sevens [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/243697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/719yPlwaNQredw0JLQ9Eeiz57P7.jpg'),
(121984, 8744, 'Yu Gi Oh Sevens [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/243698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/axYeschN4Ec777SaVrF41ZTunqh.jpg'),
(121985, 8744, 'Yu Gi Oh Sevens [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/243699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9fgk6Ch0GnXT7QKgFz2k0IUkYqS.jpg'),
(121986, 8744, 'Yu Gi Oh Sevens [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/243700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iGxJd6ADWCPMAJ8bERFgBhO9Dvq.jpg'),
(121987, 8744, 'Yu Gi Oh Sevens [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/243701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qKy6ZAXY0SjRS1cNQuGk68cSZd8.jpg'),
(121988, 8744, 'Yu Gi Oh Sevens [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/243702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hRWeEOZHjW1Q6YitVnPHF7s7s97.jpg'),
(121989, 8744, 'Yu Gi Oh Sevens [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/243703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/56YZHrSz1rm2YsYEJM6v17wNjso.jpg'),
(121990, 8744, 'Yu Gi Oh Sevens [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/243704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yVTZDmkiJ0F3w7lCiQvYEtvpPrX.jpg'),
(121991, 8744, 'Yu Gi Oh Sevens [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/243705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hwELuMZmhVIjbv0YGXFGhCWGh5h.jpg'),
(121992, 8744, 'Yu Gi Oh Sevens [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/243706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4krHudI1SlI17IdvW5yrR4gmQXu.jpg'),
(121993, 8744, 'Yu Gi Oh Sevens [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/243707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2vQ85aeDXsGhhZYuV7yGUfp8ggp.jpg'),
(121994, 8744, 'Yu Gi Oh Sevens [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/243708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vx3MALXTJWkLj0YkuLuwmpCpdfj.jpg'),
(121995, 8744, 'Yu Gi Oh Sevens [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/243709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4cXlziWHoZVtjJE1JDRFEeCxk3d.jpg'),
(121996, 8744, 'Yu Gi Oh Sevens [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/243710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nUGDeBqo66ryVhtiGw2AoEtQSxQ.jpg'),
(121997, 8744, 'Yu Gi Oh Sevens [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/243711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUazi0hitTO6DH3jMxnZfHpd6Kn.jpg'),
(121998, 8744, 'Yu Gi Oh Sevens [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/243712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AuB4FB76AfaXZHXrtnHhr0J4qGn.jpg'),
(121999, 8744, 'Yu Gi Oh Sevens [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/243713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gB8LgWHYsp0hML9ULNS7DHClFrC.jpg'),
(122000, 8744, 'Yu Gi Oh Sevens [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/243714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgljW43sIg7GL6W20C80OI0iYC0.jpg'),
(122001, 8744, 'Yu Gi Oh Sevens [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/243715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pUlLGTbTEfwl9pmrmLlTsagRslZ.jpg'),
(122002, 8744, 'Yu Gi Oh Sevens [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/243716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfzybmQU8QM7Q5F4Wz93ulAtTmC.jpg'),
(122003, 8744, 'Yu Gi Oh Sevens [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/243717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9C1JPEKjHjh31JD7t3F9uo2LIYV.jpg'),
(122004, 8744, 'Yu Gi Oh Sevens [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/243718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vGzPYUfD3yAEa6w5rFJIZeoBno8.jpg'),
(122005, 8744, 'Yu Gi Oh Sevens [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/243719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6lcSLYonPUSvhfc0N6OMm9tQQyw.jpg'),
(122006, 8744, 'Yu Gi Oh Sevens [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/243720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xV69ylpBQnBseBbD6VGhQgCj5Iz.jpg'),
(122007, 8744, 'Yu Gi Oh Sevens [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/243721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ddO01JzZjmlKm21yWvHSlEcFJ4n.jpg'),
(122008, 8744, 'Yu Gi Oh Sevens [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/243722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lmlzGnTzU5h4icvBQNPFiaV0Bsi.jpg'),
(122009, 8744, 'Yu Gi Oh Sevens [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/243723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aauj1MrXPixM5PROLFA1qzGZKWy.jpg'),
(122010, 8744, 'Yu Gi Oh Sevens [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/243724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2EozqDM6vRhGBdi0EiZSzaEx1VT.jpg'),
(122011, 8744, 'Yu Gi Oh Sevens [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/243725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kB7Y6ESjHAFaohjnFdjq5NBZ60S.jpg'),
(122012, 8744, 'Yu Gi Oh Sevens [L] S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/243726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122013, 8744, 'Yu Gi Oh Sevens [L] S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/243727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122014, 8744, 'Yu Gi Oh Sevens [L] S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/243728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122015, 8744, 'Yu Gi Oh Sevens [L] S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/243729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122016, 8744, 'Yu Gi Oh Sevens [L] S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/243730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122017, 8744, 'Yu Gi Oh Sevens [L] S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/243731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122018, 8744, 'Yu Gi Oh Sevens [L] S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/243732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122019, 8744, 'Yu Gi Oh Sevens [L] S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/243733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122020, 8744, 'Yu Gi Oh Sevens [L] S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/243734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122021, 8744, 'Yu Gi Oh Sevens [L] S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/243735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122022, 8744, 'Yu Gi Oh Sevens [L] S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/243736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122023, 8744, 'Yu Gi Oh Sevens [L] S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/243737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122024, 8744, 'Yu Gi Oh Sevens [L] S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/243738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122025, 8744, 'Yu Gi Oh Sevens [L] S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/243739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122026, 8744, 'Yu Gi Oh Sevens [L] S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/243740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122027, 8744, 'Yu Gi Oh Sevens [L] S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/243741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122028, 8744, 'Yu Gi Oh Sevens [L] S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/243742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122029, 8744, 'Yu Gi Oh Sevens [L] S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/243743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122030, 8744, 'Yu Gi Oh Sevens [L] S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/243744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122031, 8744, 'Yu Gi Oh Sevens [L] S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/243745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122032, 8744, 'Yu Gi Oh Sevens [L] S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/243746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122033, 8744, 'Yu Gi Oh Sevens [L] S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/243747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122034, 8744, 'Yu Gi Oh Sevens [L] S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/243748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122035, 8744, 'Yu Gi Oh Sevens [L] S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/243749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122036, 8744, 'Yu Gi Oh Sevens [L] S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/243750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122037, 8744, 'Yu Gi Oh Sevens [L] S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/243751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122038, 8744, 'Yu Gi Oh Sevens [L] S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/243752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122039, 8744, 'Yu Gi Oh Sevens [L] S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/243753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122040, 8744, 'Yu Gi Oh Sevens [L] S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/243754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122041, 8744, 'Yu Gi Oh Sevens [L] S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/243755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122042, 8744, 'Yu Gi Oh Sevens [L] S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/243756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122043, 8744, 'Yu Gi Oh Sevens [L] S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/243757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122044, 8744, 'Yu Gi Oh Sevens [L] S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/243758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122045, 8744, 'Yu Gi Oh Sevens [L] S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/243759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122046, 8744, 'Yu Gi Oh Sevens [L] S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/243760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122047, 8744, 'Yu Gi Oh Sevens [L] S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/243761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122048, 8744, 'Yu Gi Oh Sevens [L] S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/243762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122049, 8744, 'Yu Gi Oh Sevens [L] S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/243763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122050, 8744, 'Yu Gi Oh Sevens [L] S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/243764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122051, 8744, 'Yu Gi Oh Sevens [L] S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/243765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0VEIeBiYlWX7bqspb9xm5p3JSL.jpg'),
(122052, 8745, '22 7 [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/582189.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jR5wMbEMZrrn28IOJGlKm764qrJ.jpg'),
(122053, 8745, '22 7 [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/582191.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sTAdUEXHcx0Q0nw3KxgSg501vo1.jpg'),
(122054, 8745, '22 7 [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/582193.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AcbclR5YWRwQSmlFQsKDJykZXz3.jpg'),
(122055, 8745, '22 7 [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/582195.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tUfQTcTIdtBWe1MHsIGx6fwpA6Z.jpg'),
(122056, 8745, '22 7 [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/582197.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wa0QeLRHFpuZDjTFKDIy3LIrR0H.jpg'),
(122057, 8745, '22 7 [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/582199.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/amlLLROu8ERS3GrSbj79HtN2nPC.jpg'),
(122058, 8745, '22 7 [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/582201.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oiR9AKgTeyWzOb9ldB8DUOY3rlU.jpg'),
(122059, 8745, '22 7 [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/582203.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9ztv0BGjaY7vbg8nnMlIuvU1TRL.jpg'),
(122060, 8745, '22 7 [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/582205.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4hbYl5wue3C14P55cCIZ2erGc0W.jpg'),
(122061, 8745, '22 7 [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/582207.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/33Y8176Hf2FeNAAQ8VM9Kh6j19V.jpg'),
(122062, 8745, '22 7 [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/582209.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vcU0I3Ran6bc1PWcWzjBC8vJ5j0.jpg'),
(122063, 8745, '22 7 [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/582211.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d7J89zbzjwbDv7moNVisNCligsb.jpg'),
(122064, 8746, 'A Filha de Deus Dalma Maradona [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mwBpyUvymQe0VGzM9yyqE3aw6PG.jpg'),
(122065, 8746, 'A Filha de Deus Dalma Maradona [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uKQ2JCQEfOqUang3G6yb5l7kuws.jpg'),
(122066, 8746, 'A Filha de Deus Dalma Maradona [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bjFqiz6qlqSqtFPxS451s5gNXzT.jpg'),
(122067, 8747, 'A Incrivel Madagascar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5OMIomJ4svwJ4bhuY0CP4pLE6D.jpg'),
(122068, 8747, 'A Incrivel Madagascar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5OMIomJ4svwJ4bhuY0CP4pLE6D.jpg'),
(122069, 8747, 'A Incrivel Madagascar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5OMIomJ4svwJ4bhuY0CP4pLE6D.jpg'),
(122070, 8748, 'Acampamento de Magia para Jovens Bruxos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mY5TGjkJCFiSOPWTDHkBfjCyCix.jpg'),
(122071, 8748, 'Acampamento de Magia para Jovens Bruxos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4CtrZWTw3DOdYCLFcMdeRU3dDUS.jpg'),
(122072, 8748, 'Acampamento de Magia para Jovens Bruxos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nzSKPHVPkdJ3TRUsUkfUg67VW5b.jpg'),
(122073, 8748, 'Acampamento de Magia para Jovens Bruxos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bVoSir8QxvnNXymlAYZSp1BwVYi.jpg'),
(122074, 8748, 'Acampamento de Magia para Jovens Bruxos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pdk4BzASeWFmWCT9447xtSUGzDG.jpg'),
(122075, 8748, 'Acampamento de Magia para Jovens Bruxos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7bOt5JFm1iN9AIG4qwUbMfiARjK.jpg'),
(122076, 8748, 'Acampamento de Magia para Jovens Bruxos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dpXuJxtq07hNc6Ij6jqkdp7Gt3P.jpg'),
(122077, 8748, 'Acampamento de Magia para Jovens Bruxos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lYS7D8AGJGXxybHgdSkgrMKtuuF.jpg'),
(122078, 8748, 'Acampamento de Magia para Jovens Bruxos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gAU8lUf1OQILocPJGdOYWbYKwze.jpg'),
(122079, 8749, 'Africa Garras e Mandibulas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdNhdbvz59FfigXerwBM7rGamLz.jpg'),
(122080, 8749, 'Africa Garras e Mandibulas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdNhdbvz59FfigXerwBM7rGamLz.jpg'),
(122081, 8749, 'Africa Garras e Mandibulas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdNhdbvz59FfigXerwBM7rGamLz.jpg'),
(122082, 8749, 'Africa Garras e Mandibulas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdNhdbvz59FfigXerwBM7rGamLz.jpg'),
(122083, 8750, 'Alegorias do Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oaXhukWGP0t5VaExfp1SHgvFYQl.jpg'),
(122084, 8750, 'Alegorias do Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oaXhukWGP0t5VaExfp1SHgvFYQl.jpg'),
(122085, 8750, 'Alegorias do Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oaXhukWGP0t5VaExfp1SHgvFYQl.jpg'),
(122086, 8750, 'Alegorias do Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oaXhukWGP0t5VaExfp1SHgvFYQl.jpg'),
(122087, 8750, 'Alegorias do Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oaXhukWGP0t5VaExfp1SHgvFYQl.jpg'),
(122088, 8750, 'Alegorias do Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oaXhukWGP0t5VaExfp1SHgvFYQl.jpg'),
(122089, 8750, 'Alegorias do Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oaXhukWGP0t5VaExfp1SHgvFYQl.jpg'),
(122090, 8750, 'Alegorias do Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oaXhukWGP0t5VaExfp1SHgvFYQl.jpg'),
(122091, 8750, 'Alegorias do Brasil S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oaXhukWGP0t5VaExfp1SHgvFYQl.jpg'),
(122092, 8750, 'Alegorias do Brasil S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oaXhukWGP0t5VaExfp1SHgvFYQl.jpg'),
(122093, 8750, 'Alegorias do Brasil S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oaXhukWGP0t5VaExfp1SHgvFYQl.jpg'),
(122094, 8750, 'Alegorias do Brasil S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/243627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oaXhukWGP0t5VaExfp1SHgvFYQl.jpg'),
(122095, 8750, 'Alegorias do Brasil S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/243628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oaXhukWGP0t5VaExfp1SHgvFYQl.jpg'),
(122096, 8751, 'Arqueologias em Busca dos Primeiros Brasileiros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMNSKF22DGBBBZuVjTzAcMmb0F6.jpg'),
(122097, 8751, 'Arqueologias em Busca dos Primeiros Brasileiros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMNSKF22DGBBBZuVjTzAcMmb0F6.jpg'),
(122098, 8751, 'Arqueologias em Busca dos Primeiros Brasileiros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMNSKF22DGBBBZuVjTzAcMmb0F6.jpg'),
(122099, 8751, 'Arqueologias em Busca dos Primeiros Brasileiros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMNSKF22DGBBBZuVjTzAcMmb0F6.jpg'),
(122100, 8751, 'Arqueologias em Busca dos Primeiros Brasileiros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMNSKF22DGBBBZuVjTzAcMmb0F6.jpg'),
(122101, 8751, 'Arqueologias em Busca dos Primeiros Brasileiros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMNSKF22DGBBBZuVjTzAcMmb0F6.jpg'),
(122102, 8752, 'BePlaying A Voz Por Tras do Som [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hm2Mmtsb7TLNo9X6ICxo1okSNBr.jpg'),
(122103, 8752, 'BePlaying A Voz Por Tras do Som [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dXVwBR9k0G3guLdgmKmH57wQC2D.jpg'),
(122104, 8752, 'BePlaying A Voz Por Tras do Som [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7QEHkmHCgweivvM8c7I1Q2SuyTD.jpg'),
(122105, 8752, 'BePlaying A Voz Por Tras do Som [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4CXh72Sa13npwgBoyZR2aa1tAdC.jpg'),
(122106, 8752, 'BePlaying A Voz Por Tras do Som [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/heMVtCjHqaaH2IrG4SyXTc5yRaX.jpg'),
(122107, 8752, 'BePlaying A Voz Por Tras do Som [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pARwaZqVh1J0bMgnUlfFE1s7yAw.jpg'),
(122108, 8753, 'Companheiros de Viagem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dKoLbwIeA8drdOdrn4xiocvqILU.jpg'),
(122109, 8753, 'Companheiros de Viagem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ca5dFdlge7sJ7gBwQA85J9yGcR6.jpg'),
(122110, 8753, 'Companheiros de Viagem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ca5dFdlge7sJ7gBwQA85J9yGcR6.jpg'),
(122111, 8753, 'Companheiros de Viagem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ca5dFdlge7sJ7gBwQA85J9yGcR6.jpg'),
(122112, 8753, 'Companheiros de Viagem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ca5dFdlge7sJ7gBwQA85J9yGcR6.jpg'),
(122113, 8753, 'Companheiros de Viagem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ca5dFdlge7sJ7gBwQA85J9yGcR6.jpg'),
(122114, 8753, 'Companheiros de Viagem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ca5dFdlge7sJ7gBwQA85J9yGcR6.jpg'),
(122115, 8753, 'Companheiros de Viagem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ca5dFdlge7sJ7gBwQA85J9yGcR6.jpg'),
(122116, 8754, 'Declinio dos Otomanos [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Icd7PFnbdfPYpu2pavugTJKVG9.jpg'),
(122117, 8754, 'Declinio dos Otomanos [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iY8HPNyyuiVGaXgkjCHP8qXaIHN.jpg'),
(122118, 8755, 'Gekidol [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/582151.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mPzBKqehfTTN4RD5bEz1zVHfJnd.jpg'),
(122119, 8755, 'Gekidol [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/582153.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vGJFOo1eBCbnIThTZcBgdkB4pUz.jpg'),
(122120, 8755, 'Gekidol [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/582155.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wfW2L3w3b1yaxf4DfXlXP36xW3h.jpg'),
(122121, 8755, 'Gekidol [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/582157.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ifXL8l5eW53pFS3Kl4ZoLTzM5JC.jpg'),
(122122, 8755, 'Gekidol [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/582159.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nwXUFVUIzq2eDqmKtPNvTRcukRv.jpg'),
(122123, 8755, 'Gekidol [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/582161.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uLyIrwVUN4QZxUW8hJvYsd3kUnX.jpg'),
(122124, 8755, 'Gekidol [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/582163.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7v6cXUdrwq9CZPGk0JJJ6ojuv0P.jpg'),
(122125, 8755, 'Gekidol [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/582165.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yA8P0Cu3R5EwKTPzUgD4eKw77Le.jpg'),
(122126, 8755, 'Gekidol [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/582167.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bRSenz4h9tt1pgqJcR0wUsaFEz.jpg'),
(122127, 8755, 'Gekidol [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/582169.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3RP0gwgPg28E3XzNthz4Xyzsjig.jpg'),
(122128, 8755, 'Gekidol [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/582171.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/geZWRYq1k3PhfiP0EuC6wXXaaiG.jpg'),
(122129, 8755, 'Gekidol [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/582173.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A3C5sVaEuPOjJVO0u3jgjXeA1W2.jpg'),
(122130, 8756, 'Go Diego Go S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qenKgoChkKssuR9laD9rHfkLaYU.jpg'),
(122131, 8756, 'Go Diego Go S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cjIJrpQDOPWoaCDzQCHzaIElp8k.jpg'),
(122132, 8756, 'Go Diego Go S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pPx2P6OBvRITFRASqpJNt4FyhKN.jpg'),
(122133, 8756, 'Go Diego Go S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0SkEnLo2b1abBDyHjy3W5RDwWy.jpg'),
(122134, 8756, 'Go Diego Go S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/55DoGonnztgDISexeg191qUcpiA.jpg'),
(122135, 8756, 'Go Diego Go S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xigjwVhg1M7WIkIPtom8UYv9LUl.jpg'),
(122136, 8756, 'Go Diego Go S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6VMLJxi0kNwOBRkJ2VhJo8dU4RN.jpg'),
(122137, 8756, 'Go Diego Go S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g6TqXBsu7guJCH7B79Gsg1bmx1O.jpg'),
(122138, 8756, 'Go Diego Go S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bEiRPOz2N2PcqVGtau2rCiIi3kT.jpg'),
(122139, 8756, 'Go Diego Go S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o5cVXue8mIIVGsbSH9z0I2Rljk1.jpg'),
(122140, 8756, 'Go Diego Go S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xq4YWYmj3szIHqmQhxCDNLHMt2L.jpg'),
(122141, 8756, 'Go Diego Go S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/243538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cFUILMEwZOGvqzZvJIChrGrrC29.jpg'),
(122142, 8756, 'Go Diego Go S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/243539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBx7V5Thvpp5nUWxKBljKT43HeM.jpg'),
(122143, 8756, 'Go Diego Go S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/243540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rClXikuEWHA0CAuVYatTXd0CwUB.jpg'),
(122144, 8756, 'Go Diego Go S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/243541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/75Xv41q43vJl2omjqbDbIm62nzr.jpg'),
(122145, 8756, 'Go Diego Go S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/243542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/75Xv41q43vJl2omjqbDbIm62nzr.jpg'),
(122146, 8756, 'Go Diego Go S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/243543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pmkpQHm5Ou7McFUp6Lukw4JW2Hi.jpg'),
(122147, 8756, 'Go Diego Go S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/243544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2dbQd2lBYo5GkXE88Ac2AoFvVl3.jpg'),
(122148, 8756, 'Go Diego Go S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/243545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rvvzt3vf5ivxUuvVvEFfIGIaEEU.jpg'),
(122149, 8757, 'Go Diego Go S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg'),
(122150, 8757, 'Go Diego Go S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/85XmNlco406n8s4aeK3hy5lrejV.jpg'),
(122151, 8757, 'Go Diego Go S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/43vS1ZcXU3cPvCRxdX6i4lJ4LTe.jpg'),
(122152, 8757, 'Go Diego Go S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7b8nwEbyQi9RABVkwffOgytnpQe.jpg'),
(122153, 8757, 'Go Diego Go S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qSmrY4Gqw190nvZvvnco4LmEqPb.jpg'),
(122154, 8757, 'Go Diego Go S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zpdNE1jnpE8MJvRs2NiaZE6gq79.jpg'),
(122155, 8757, 'Go Diego Go S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rsdxyTO14WQWDZMZd9mL1EpVxc7.jpg'),
(122156, 8757, 'Go Diego Go S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/asdusBRyv6dji2hKBIdUmBMZrrL.jpg'),
(122157, 8757, 'Go Diego Go S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/70CAuybsKFYZXCI4q2MScrsvUsM.jpg'),
(122158, 8757, 'Go Diego Go S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7yDlPjkhIGWhqaEBWJ0RUtgMf3e.jpg'),
(122159, 8757, 'Go Diego Go S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bXDZ4vaJZhBSqq0oBNeT6NdYPyV.jpg'),
(122160, 8757, 'Go Diego Go S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/243557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pjpseoqnRrTzrkDfkwi2EcUREjF.jpg'),
(122161, 8757, 'Go Diego Go S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/243558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ak5KjiQ9utWgIt2FoO5GkZmONaX.jpg'),
(122162, 8757, 'Go Diego Go S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/243559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1YkdKxBQw4exavj2NSaRn3y83su.jpg'),
(122163, 8757, 'Go Diego Go S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/243560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rwrc19H6fkfNI2HsJPIUFwiTw6P.jpg'),
(122164, 8757, 'Go Diego Go S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/243561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vNkt0EBIAwJSwhdKm7wiF4f94Qb.jpg'),
(122165, 8757, 'Go Diego Go S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/243562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sQ1wiV3LLbG8kV3clNqBSS1Sstc.jpg'),
(122166, 8757, 'Go Diego Go S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/243563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sQ1wiV3LLbG8kV3clNqBSS1Sstc.jpg'),
(122167, 8757, 'Go Diego Go S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/243564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg'),
(122168, 8758, 'Go Diego Go S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nD1MEwOL0earJI56IZt7dyVVqQf.jpg'),
(122169, 8758, 'Go Diego Go S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jRAhUDFlQ0kn2bFkWmhJrOKtZQU.jpg'),
(122170, 8758, 'Go Diego Go S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zkNsMs7lK4cScgvdD6P4Qh9DmEp.jpg'),
(122171, 8758, 'Go Diego Go S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jxLHTLv111iupu0ioZyNvMc7Oe1.jpg'),
(122172, 8758, 'Go Diego Go S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tbn3VdXPy6jI52NZ0TlRBr5rlel.jpg'),
(122173, 8758, 'Go Diego Go S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iju6hiQxmKRRIrjjR5ATv2PMMGh.jpg'),
(122174, 8758, 'Go Diego Go S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cS3RAMKzNoN8oECluybvXEJ4RzG.jpg'),
(122175, 8758, 'Go Diego Go S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pR3ERew9w21luulnmAdpS2HfdEK.jpg'),
(122176, 8758, 'Go Diego Go S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vtekk10hpXOYX525e7GfPnbhlF2.jpg'),
(122177, 8758, 'Go Diego Go S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1O0abJoJHrn0zQcmivuzg3cGPQN.jpg'),
(122178, 8758, 'Go Diego Go S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sEcA4XPCjYCV6t7mWWYXdGTygG0.jpg'),
(122179, 8758, 'Go Diego Go S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/243576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fLuXfbeDN5wcJY5vymI9nhihSlB.jpg'),
(122180, 8758, 'Go Diego Go S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/243577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5WD31XLVUs94WD2KDvKpi8oBBJH.jpg'),
(122181, 8758, 'Go Diego Go S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/243578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7FnYVZ3nfRrInlmzgsELRY660AC.jpg'),
(122182, 8758, 'Go Diego Go S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/243579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkav5I8ZBEEkXtlIcdjs1OSMHco.jpg'),
(122183, 8758, 'Go Diego Go S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/243580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg'),
(122184, 8758, 'Go Diego Go S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/243581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSXNY3zyqQqsL2cDIGk7tRT9wVX.jpg'),
(122185, 8758, 'Go Diego Go S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/243582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg'),
(122186, 8758, 'Go Diego Go S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/243583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg'),
(122187, 8758, 'Go Diego Go S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/243584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg'),
(122188, 8759, 'Go Diego Go S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg'),
(122189, 8759, 'Go Diego Go S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg'),
(122190, 8759, 'Go Diego Go S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg'),
(122191, 8759, 'Go Diego Go S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(122192, 8759, 'Go Diego Go S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg'),
(122193, 8759, 'Go Diego Go S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg'),
(122194, 8759, 'Go Diego Go S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg'),
(122195, 8759, 'Go Diego Go S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg'),
(122196, 8759, 'Go Diego Go S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg'),
(122197, 8759, 'Go Diego Go S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg'),
(122198, 8759, 'Go Diego Go S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AtsRvh5S4mneL6UuVwSDxfKbM7c.jpg'),
(122199, 8759, 'Go Diego Go S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/243596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg'),
(122200, 8759, 'Go Diego Go S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/243597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg'),
(122201, 8759, 'Go Diego Go S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/243598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg'),
(122202, 8759, 'Go Diego Go S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/243599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg'),
(122203, 8759, 'Go Diego Go S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/243600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg'),
(122204, 8759, 'Go Diego Go S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/243601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xn3U14CzlMJZdYRqIj36afpjsQl.jpg'),
(122205, 8760, 'Gundam Build Fighters [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122206, 8760, 'Gundam Build Fighters [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122207, 8760, 'Gundam Build Fighters [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122208, 8760, 'Gundam Build Fighters [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122209, 8760, 'Gundam Build Fighters [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122210, 8760, 'Gundam Build Fighters [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122211, 8760, 'Gundam Build Fighters [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122212, 8760, 'Gundam Build Fighters [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122213, 8760, 'Gundam Build Fighters [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/242844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122214, 8760, 'Gundam Build Fighters [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/242845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122215, 8760, 'Gundam Build Fighters [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/242846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122216, 8760, 'Gundam Build Fighters [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/242847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122217, 8760, 'Gundam Build Fighters [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/242848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122218, 8760, 'Gundam Build Fighters [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/242849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122219, 8760, 'Gundam Build Fighters [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/242850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122220, 8760, 'Gundam Build Fighters [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/242851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122221, 8760, 'Gundam Build Fighters [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/242852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122222, 8760, 'Gundam Build Fighters [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/242853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122223, 8760, 'Gundam Build Fighters [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/242854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122224, 8760, 'Gundam Build Fighters [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/242855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122225, 8760, 'Gundam Build Fighters [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/242856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122226, 8760, 'Gundam Build Fighters [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/242857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122227, 8760, 'Gundam Build Fighters [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/242858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122228, 8760, 'Gundam Build Fighters [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/242859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122229, 8760, 'Gundam Build Fighters [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/242860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bQqdf37rvLtSTwrsb2OpLX8a32W.jpg'),
(122230, 8761, 'Gundam Build Fighters [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/582093.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n8o4jdpmecmIGTrk3NrAr8PuYwV.jpg'),
(122231, 8761, 'Gundam Build Fighters [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/582095.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eFkNDFrVTdHc5Qgxlb23mlMMqfr.jpg'),
(122232, 8761, 'Gundam Build Fighters [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/582097.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wBmLXr0uT9PmhDHZJkV2x7jr7og.jpg'),
(122233, 8761, 'Gundam Build Fighters [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/582099.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/esr6xthlW5PQnBDs7s9fXKZUF2k.jpg'),
(122234, 8761, 'Gundam Build Fighters [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/582101.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vo9V44OoDC6SazDQzaQ2fkKk15o.jpg'),
(122235, 8761, 'Gundam Build Fighters [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/582103.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k7YhqSbtstrme1R5r7dE0R7cBAa.jpg'),
(122236, 8761, 'Gundam Build Fighters [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/582105.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gX8RCq7Qej08Ae8hr5uSriLMD8L.jpg'),
(122237, 8761, 'Gundam Build Fighters [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/582107.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7NyWZ2zrtvJnNEDsKktcqGn4Nf7.jpg'),
(122238, 8761, 'Gundam Build Fighters [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/582109.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kzlimuLvym0JSZBZLjHGDCb39vS.jpg'),
(122239, 8761, 'Gundam Build Fighters [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/582111.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m5zZcGJEtWe3iBY8wvb1gBVMbFj.jpg'),
(122240, 8761, 'Gundam Build Fighters [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/582113.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ktlGqO6ur4l2jT1MIKavv8zLz8C.jpg'),
(122241, 8761, 'Gundam Build Fighters [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/582115.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4HQBwVpI7Gpr5OL2b08d0AVc0oY.jpg'),
(122242, 8761, 'Gundam Build Fighters [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/582117.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5LwmXznOcMy98FMLmAXCukIMXyV.jpg'),
(122243, 8761, 'Gundam Build Fighters [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/582119.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7FQep2rJGqfzHKbTuREjPzT2r7U.jpg'),
(122244, 8761, 'Gundam Build Fighters [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/582121.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dVB64QTdBJRMXh8m66CvYMpAhxP.jpg'),
(122245, 8761, 'Gundam Build Fighters [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/582123.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2VA2XDQz5xAod4pU0E8bswnTRNr.jpg'),
(122246, 8761, 'Gundam Build Fighters [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/582125.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tWIH731EnpVqfnc241FYy8iFPRx.jpg'),
(122247, 8761, 'Gundam Build Fighters [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/582127.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tWIH731EnpVqfnc241FYy8iFPRx.jpg'),
(122248, 8761, 'Gundam Build Fighters [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/582129.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5bCnDU3mhdWOBnU0W9tWSfNDgWQ.jpg'),
(122249, 8761, 'Gundam Build Fighters [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/582131.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/59iwlSgzN2ryFuvSXwfXSYAnM6m.jpg'),
(122250, 8761, 'Gundam Build Fighters [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/582133.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/RmoaEQ7FDyVJRcAsNMC9oRzpv9.jpg'),
(122251, 8761, 'Gundam Build Fighters [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/582135.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/50IFlwUZaevoB2zCMXizPT779IV.jpg'),
(122252, 8761, 'Gundam Build Fighters [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/582137.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wiCrq762gcx7SQ1SmkQgFIxZpuN.jpg'),
(122253, 8761, 'Gundam Build Fighters [L] S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/582139.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7Hz4h32HtNWkxVV7qOp36Sjamrb.jpg'),
(122254, 8761, 'Gundam Build Fighters [L] S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/582141.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k9hHAuMqWoF2q1NG0B8wbAIhY39.jpg'),
(122255, 8762, 'Ilha dos Macacos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6a2Mpr55RD6TnYqIMKW0vzqVjOs.jpg'),
(122256, 8762, 'Ilha dos Macacos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svFnHfDgOB5ZsM2tZa0o0iHWsBa.jpg'),
(122257, 8762, 'Ilha dos Macacos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xwQDF8YeJ87rIskePdA65LEi5ul.jpg'),
(122258, 8763, 'Inconveniencias Historicas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lP9b6NUqSAIe9LyKCStemuSAI6i.jpg'),
(122259, 8763, 'Inconveniencias Historicas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lP9b6NUqSAIe9LyKCStemuSAI6i.jpg'),
(122260, 8763, 'Inconveniencias Historicas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lP9b6NUqSAIe9LyKCStemuSAI6i.jpg'),
(122261, 8763, 'Inconveniencias Historicas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lP9b6NUqSAIe9LyKCStemuSAI6i.jpg'),
(122262, 8763, 'Inconveniencias Historicas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lP9b6NUqSAIe9LyKCStemuSAI6i.jpg'),
(122263, 8763, 'Inconveniencias Historicas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lP9b6NUqSAIe9LyKCStemuSAI6i.jpg'),
(122264, 8763, 'Inconveniencias Historicas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lP9b6NUqSAIe9LyKCStemuSAI6i.jpg'),
(122265, 8763, 'Inconveniencias Historicas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lP9b6NUqSAIe9LyKCStemuSAI6i.jpg'),
(122266, 8763, 'Inconveniencias Historicas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lP9b6NUqSAIe9LyKCStemuSAI6i.jpg'),
(122267, 8763, 'Inconveniencias Historicas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lP9b6NUqSAIe9LyKCStemuSAI6i.jpg'),
(122268, 8764, 'Iosi O Espiao Arrependido S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uXZqDjX0dtmPWCZvZAPzhCdPmFG.jpg'),
(122269, 8764, 'Iosi O Espiao Arrependido S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a945uSqJBnYXxrcDkgdZPzO6WvI.jpg'),
(122270, 8764, 'Iosi O Espiao Arrependido S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2B94jtrODZDWN5SF6CkH1sKoC0i.jpg'),
(122271, 8764, 'Iosi O Espiao Arrependido S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2FWXa9mp2Q4y0jxFT1ygAehkt4Z.jpg'),
(122272, 8764, 'Iosi O Espiao Arrependido S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1bS9TbxU6cJ4f3w9gH3jpPHm41V.jpg'),
(122273, 8764, 'Iosi O Espiao Arrependido S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A9qTfWdZHYSSOrS2re0b6nV7lyW.jpg'),
(122274, 8764, 'Iosi O Espiao Arrependido S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wsaF2YD1S8guilnnTrBpjxdklit.jpg'),
(122275, 8764, 'Iosi O Espiao Arrependido S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xiNBxPJi1aB8tv2IG0L3K5dxSCa.jpg'),
(122276, 8765, 'Iosi O Espiao Arrependido S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nz6FrukdPbO4jtb3JhWqphYuVDS.jpg'),
(122277, 8765, 'Iosi O Espiao Arrependido S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nz6FrukdPbO4jtb3JhWqphYuVDS.jpg'),
(122278, 8765, 'Iosi O Espiao Arrependido S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nz6FrukdPbO4jtb3JhWqphYuVDS.jpg'),
(122279, 8765, 'Iosi O Espiao Arrependido S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nz6FrukdPbO4jtb3JhWqphYuVDS.jpg'),
(122280, 8765, 'Iosi O Espiao Arrependido S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nz6FrukdPbO4jtb3JhWqphYuVDS.jpg'),
(122281, 8765, 'Iosi O Espiao Arrependido S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nz6FrukdPbO4jtb3JhWqphYuVDS.jpg'),
(122282, 8765, 'Iosi O Espiao Arrependido S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nz6FrukdPbO4jtb3JhWqphYuVDS.jpg'),
(122283, 8765, 'Iosi O Espiao Arrependido S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nz6FrukdPbO4jtb3JhWqphYuVDS.jpg'),
(122284, 8766, 'Kirakira Precure A La Mode [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/581983.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5wpk676mt2accytOhWZA2RJjg8i.jpg'),
(122285, 8766, 'Kirakira Precure A La Mode [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/581985.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hVTQmf2CzfQCDuWPgnvYzJ1Uv5n.jpg'),
(122286, 8766, 'Kirakira Precure A La Mode [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/581987.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bvAbNAwIeDBZzpDWYjaseD0gDOl.jpg'),
(122287, 8766, 'Kirakira Precure A La Mode [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/581989.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c03M3VtLTe1U7E2BxOWhSrXD5dh.jpg'),
(122288, 8766, 'Kirakira Precure A La Mode [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/581991.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4Fn7uP1ew47drXgRVPsluIXScF1.jpg'),
(122289, 8766, 'Kirakira Precure A La Mode [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/581993.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o5MjmLvlEEsahfuhVFCKGRlDkpS.jpg'),
(122290, 8766, 'Kirakira Precure A La Mode [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/581995.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9WbjxLRrKz2sx7fCvkXUXGwIswO.jpg'),
(122291, 8766, 'Kirakira Precure A La Mode [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/581997.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wW9PPuVkAQCvh6oVLtnTMJXo1Ua.jpg'),
(122292, 8766, 'Kirakira Precure A La Mode [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/581999.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nYBIWST4CKHQAOAB0Xic0sv9pi0.jpg'),
(122293, 8766, 'Kirakira Precure A La Mode [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/582001.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hMVzTRklwBoMxIhk0NjW1MVfODQ.jpg'),
(122294, 8766, 'Kirakira Precure A La Mode [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/582003.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/10q5bKDn2n0zwwI2Idvm6icU6Nk.jpg'),
(122295, 8766, 'Kirakira Precure A La Mode [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/582005.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/96cXkEI0GdkZgG2pnK8xiwQHIth.jpg'),
(122296, 8766, 'Kirakira Precure A La Mode [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/582007.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ifxNhxmhPX9v3Tl0SwdvJVa1KcV.jpg'),
(122297, 8766, 'Kirakira Precure A La Mode [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/582009.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3qImErmOiC1KOhcQ6R5aVSFneky.jpg'),
(122298, 8766, 'Kirakira Precure A La Mode [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/582011.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4kOyDIKg0nNPvVddz7LDXwSHBLi.jpg'),
(122299, 8766, 'Kirakira Precure A La Mode [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/582013.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8g4Imji9t9O3z61f7fIz8wwbN1r.jpg'),
(122300, 8766, 'Kirakira Precure A La Mode [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/582015.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5OS3Loyo2JmuQ6QEzIO5g0q80QY.jpg'),
(122301, 8766, 'Kirakira Precure A La Mode [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/582017.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5J6VG4P7ob5FPDstWeRxFtDIIqM.jpg'),
(122302, 8766, 'Kirakira Precure A La Mode [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/582019.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oWU4QHw3VRbAmX5DUMg5ARRGhta.jpg'),
(122303, 8766, 'Kirakira Precure A La Mode [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/582021.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t3HgPsRzsRZFHtX2WGko1DlucMn.jpg'),
(122304, 8766, 'Kirakira Precure A La Mode [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/582023.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nzYYDZZVKslvJdtbyBazLsEbNGl.jpg'),
(122305, 8766, 'Kirakira Precure A La Mode [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/582025.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bsfZTZ4mMd9fOQcwMGngNEQb5nc.jpg'),
(122306, 8766, 'Kirakira Precure A La Mode [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/582027.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gbBLhrVqhT4QfqqrocxJAlXWlPD.jpg'),
(122307, 8766, 'Kirakira Precure A La Mode [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/582029.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gUlLotm7P9ENhdaWoMNk06IuPPW.jpg'),
(122308, 8766, 'Kirakira Precure A La Mode [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/582031.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/slpuxMAwfXt6130iKq23IB3nTd8.jpg'),
(122309, 8766, 'Kirakira Precure A La Mode [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/582033.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mcPe6OETfYdo7lCeF7UsDxKxBHY.jpg'),
(122310, 8766, 'Kirakira Precure A La Mode [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/582035.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jzvSWRI9QQUsZYgtuLOvg3eqkxJ.jpg'),
(122311, 8766, 'Kirakira Precure A La Mode [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/582037.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bHAs0u0mc3XGI4cYAowGqRnrFvB.jpg'),
(122312, 8766, 'Kirakira Precure A La Mode [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/582039.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dTznxKMi8sjmE7h2GuoADKlalG8.jpg'),
(122313, 8766, 'Kirakira Precure A La Mode [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/582041.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pLftPviC5YtHkl8meIefxQ4PLXL.jpg'),
(122314, 8766, 'Kirakira Precure A La Mode [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/582043.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l435uaF9qZIx0AU8lbWzcNuVXkP.jpg'),
(122315, 8766, 'Kirakira Precure A La Mode [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/582045.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AqFtXU67HPNNLOjZlC805KBNVpi.jpg'),
(122316, 8766, 'Kirakira Precure A La Mode [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/582047.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/twmE06zfw7nsIqkVKGhQoBWKOdh.jpg'),
(122317, 8766, 'Kirakira Precure A La Mode [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/582049.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nelSDAT3UBfDe30O50FlOeY17m8.jpg'),
(122318, 8766, 'Kirakira Precure A La Mode [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/582051.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wXIlEwkcMA7U1DAEQZc1H2EELYj.jpg'),
(122319, 8766, 'Kirakira Precure A La Mode [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/582053.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2L201EiWBynn58cFbrRuRbLINbj.jpg'),
(122320, 8766, 'Kirakira Precure A La Mode [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/242784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v7m1HeI6aRtdVoAsAk0GQmPUplD.jpg'),
(122321, 8766, 'Kirakira Precure A La Mode [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/242785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v7m1HeI6aRtdVoAsAk0GQmPUplD.jpg'),
(122322, 8766, 'Kirakira Precure A La Mode [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/242786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v7m1HeI6aRtdVoAsAk0GQmPUplD.jpg'),
(122323, 8766, 'Kirakira Precure A La Mode [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/242787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v7m1HeI6aRtdVoAsAk0GQmPUplD.jpg'),
(122324, 8766, 'Kirakira Precure A La Mode [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/242788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v7m1HeI6aRtdVoAsAk0GQmPUplD.jpg'),
(122325, 8766, 'Kirakira Precure A La Mode [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/242789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v7m1HeI6aRtdVoAsAk0GQmPUplD.jpg'),
(122326, 8766, 'Kirakira Precure A La Mode [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/242790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v7m1HeI6aRtdVoAsAk0GQmPUplD.jpg'),
(122327, 8766, 'Kirakira Precure A La Mode [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/242791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v7m1HeI6aRtdVoAsAk0GQmPUplD.jpg'),
(122328, 8766, 'Kirakira Precure A La Mode [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/242792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v7m1HeI6aRtdVoAsAk0GQmPUplD.jpg'),
(122329, 8766, 'Kirakira Precure A La Mode [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/242793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v7m1HeI6aRtdVoAsAk0GQmPUplD.jpg'),
(122330, 8766, 'Kirakira Precure A La Mode [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/242794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v7m1HeI6aRtdVoAsAk0GQmPUplD.jpg'),
(122331, 8766, 'Kirakira Precure A La Mode [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/242795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v7m1HeI6aRtdVoAsAk0GQmPUplD.jpg'),
(122332, 8766, 'Kirakira Precure A La Mode [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/242796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v7m1HeI6aRtdVoAsAk0GQmPUplD.jpg'),
(122333, 8767, 'Kiratto Pri Chan [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gwdCZeQgA2vVdc2sLGDL3Yy8DMb.jpg'),
(122334, 8767, 'Kiratto Pri Chan [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1KywOlz17S9OynoRmP2cfPGMV95.jpg'),
(122335, 8767, 'Kiratto Pri Chan [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3SVes7lQVbGdNb7ADCx80MCeBAc.jpg'),
(122336, 8767, 'Kiratto Pri Chan [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/581887.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zsnzw6dZ3oLyKTuWBtrATKvje6Y.jpg'),
(122337, 8767, 'Kiratto Pri Chan [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/581889.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uBJMSXlU3t2FCzRU2DHz45sENby.jpg'),
(122338, 8767, 'Kiratto Pri Chan [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/581891.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4Aa9eUMjCn6nNhuJubkndLYuWM7.jpg'),
(122339, 8767, 'Kiratto Pri Chan [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/581893.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vrX3UhlvQVIlYXf7yEtnaYveKmi.jpg'),
(122340, 8767, 'Kiratto Pri Chan [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/581895.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dPlewYvRTdwPkjukgajJV60d3Nj.jpg'),
(122341, 8767, 'Kiratto Pri Chan [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/581897.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/prNX13ohYIYXpKfbrIdoLoVaqfq.jpg'),
(122342, 8767, 'Kiratto Pri Chan [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/581899.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gwHpfRNzHLNUehLb3BmI2EhD21d.jpg'),
(122343, 8767, 'Kiratto Pri Chan [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/581901.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vdoAPcKDc8jVMp3BD1nTNdI3d5C.jpg'),
(122344, 8767, 'Kiratto Pri Chan [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/581903.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qLI7iwLjnoWLq9CCpCcvh0I6hJG.jpg'),
(122345, 8767, 'Kiratto Pri Chan [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/581905.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/shlpO8npiSrseREcethVIWLmuMc.jpg'),
(122346, 8767, 'Kiratto Pri Chan [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/581907.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zILKDa6Zc39YpDHjMOZPv7JVtmI.jpg'),
(122347, 8767, 'Kiratto Pri Chan [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/581909.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1vujoWA64TGLkhbvhEkUEHfyHkL.jpg'),
(122348, 8767, 'Kiratto Pri Chan [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/581911.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7xKWxkMe7cTYb4L1tkNOVFzPmzh.jpg'),
(122349, 8767, 'Kiratto Pri Chan [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/581913.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ekWOznKFdaxRtG4QpYVmYTlgBSX.jpg'),
(122350, 8767, 'Kiratto Pri Chan [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/581915.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mmKnED2964XJDknt9UupgSFNw6w.jpg'),
(122351, 8767, 'Kiratto Pri Chan [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/581917.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i8urjyampfGCHALq3miaVKcBqvB.jpg'),
(122352, 8767, 'Kiratto Pri Chan [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/581919.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pnoUeVziUBSiNgKmLdxS4zclqOx.jpg'),
(122353, 8767, 'Kiratto Pri Chan [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/581921.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uFkXIsM5GOMCSCCFamsMKlLWMYH.jpg'),
(122354, 8767, 'Kiratto Pri Chan [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/581923.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uUKhVHdQAdMm1rOOBCkJZfUIja0.jpg'),
(122355, 8767, 'Kiratto Pri Chan [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/581925.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uqxI0Gi3x8vOXBZTzE924YQTrIk.jpg'),
(122356, 8767, 'Kiratto Pri Chan [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/581927.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dzmPgGOHLW9SaUibkI3FqUnMNWL.jpg'),
(122357, 8767, 'Kiratto Pri Chan [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/581929.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kPSh7znr8ROMSRhqWI8KlCcbsLi.jpg'),
(122358, 8767, 'Kiratto Pri Chan [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/581931.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nfIiS5RAaRUtdAOt7R9W2etb0GH.jpg'),
(122359, 8767, 'Kiratto Pri Chan [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/581933.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yRuGBDvNm582xy5HhHOuFtriLnn.jpg'),
(122360, 8767, 'Kiratto Pri Chan [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/581935.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j3yDPqfrMNCpinSsveARetFZRM.jpg'),
(122361, 8767, 'Kiratto Pri Chan [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/581937.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5ZevVBaEYhiCKv42ooPc56SYg8W.jpg'),
(122362, 8767, 'Kiratto Pri Chan [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/581939.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yv4R9p1AXHSY4oOAArqLwMIrfh4.jpg'),
(122363, 8767, 'Kiratto Pri Chan [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/581941.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2P5gceKUTYPIokAVmQhVwVtNPg3.jpg'),
(122364, 8767, 'Kiratto Pri Chan [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/581943.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cVeX5tfGtuHySkOOK2FJQdTbvJm.jpg'),
(122365, 8767, 'Kiratto Pri Chan [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/581945.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1zDA73MAqJ0wyTpNqtpWnH4LKjJ.jpg'),
(122366, 8767, 'Kiratto Pri Chan [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/581947.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pgejLob6VGzlgTHH2vIe3IXEBYl.jpg'),
(122367, 8767, 'Kiratto Pri Chan [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/581949.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mepR7QqFAX6kfRJedo8kGGqAflj.jpg'),
(122368, 8767, 'Kiratto Pri Chan [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/581951.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uzM0qj3RqC1JD4iDgRoji6Uu8Wp.jpg'),
(122369, 8767, 'Kiratto Pri Chan [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/581953.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fob4FSlPAboJD1nWuRzkTivUkCC.jpg'),
(122370, 8767, 'Kiratto Pri Chan [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/581955.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p6p4fMelV1nZBVIPTXOEMp8Ipb0.jpg'),
(122371, 8767, 'Kiratto Pri Chan [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/581957.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2VEpGjEoFuCY6Qo2iplusta0i6M.jpg'),
(122372, 8767, 'Kiratto Pri Chan [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/581959.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vZMc2XLN98QluTNYEGPZ6orIHY2.jpg'),
(122373, 8767, 'Kiratto Pri Chan [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/581961.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gGC25O7Wls1KjNVYPhX3XXIdWGD.jpg'),
(122374, 8767, 'Kiratto Pri Chan [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/581963.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vyNVYpF6ulFeUB6sDuuSq8qmTFQ.jpg'),
(122375, 8767, 'Kiratto Pri Chan [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/581965.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zWvkN0lEKoFbM9TdB4kQJ100WhT.jpg'),
(122376, 8767, 'Kiratto Pri Chan [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/581967.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mHyef0qqrVURpgdzOzdk5oo3rKZ.jpg'),
(122377, 8767, 'Kiratto Pri Chan [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/581969.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/faIsLq47mUdwCyV76qCRf3Lb4er.jpg'),
(122378, 8767, 'Kiratto Pri Chan [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/581971.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7dp3ujNLxHoYYIHOehTfIplJ5iR.jpg'),
(122379, 8767, 'Kiratto Pri Chan [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/581973.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/76IfZAAFX46ubVnajdnQb44MVra.jpg'),
(122380, 8767, 'Kiratto Pri Chan [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/581975.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5lYU81fjpEBZVzclFlhXfZtD3Fc.jpg'),
(122381, 8767, 'Kiratto Pri Chan [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/581977.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cpWKcl6zL1yB7dQYJprkdr56DYa.jpg'),
(122382, 8767, 'Kiratto Pri Chan [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/581979.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gBZmQEnTjvvuaD0EzEsE0QhpnVj.jpg'),
(122383, 8767, 'Kiratto Pri Chan [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/581981.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/86ZkOhpMJIcfHgyBqgJ6OQYsB6x.jpg'),
(122384, 8768, 'Lontras Citadinas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mKZ1eYjJXhCjzwdzgyE7JH5YsFX.jpg'),
(122385, 8768, 'Lontras Citadinas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mKZ1eYjJXhCjzwdzgyE7JH5YsFX.jpg'),
(122386, 8768, 'Lontras Citadinas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mKZ1eYjJXhCjzwdzgyE7JH5YsFX.jpg'),
(122387, 8768, 'Lontras Citadinas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mKZ1eYjJXhCjzwdzgyE7JH5YsFX.jpg'),
(122388, 8768, 'Lontras Citadinas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mKZ1eYjJXhCjzwdzgyE7JH5YsFX.jpg'),
(122389, 8768, 'Lontras Citadinas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mKZ1eYjJXhCjzwdzgyE7JH5YsFX.jpg'),
(122390, 8769, 'Love Live Superstar A Escola de Idol [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xN8LoMx8275gqlcrqqUGgjtH7Pg.jpg'),
(122391, 8769, 'Love Live Superstar A Escola de Idol [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYoRgRObntX3Ld9cSo1px5PJljG.jpg'),
(122392, 8769, 'Love Live Superstar A Escola de Idol [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rAb7r1LjjjgEr6QpixgpzbRjP8K.jpg'),
(122393, 8769, 'Love Live Superstar A Escola de Idol [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vSUszDUQmmpWVAOiJhJlaQqvqZ2.jpg'),
(122394, 8769, 'Love Live Superstar A Escola de Idol [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ZvjCiXjHWrEvJiVfBzRE9qbSj7.jpg'),
(122395, 8769, 'Love Live Superstar A Escola de Idol [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9HiF0LY8BTN67dTBsIDz9sGikVq.jpg'),
(122396, 8769, 'Love Live Superstar A Escola de Idol [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7aux5CLc0rUAkIsKKJ1xkGmV31i.jpg'),
(122397, 8769, 'Love Live Superstar A Escola de Idol [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zf04pT4x0z8AsGNpr0XAsRnAq1t.jpg'),
(122398, 8769, 'Love Live Superstar A Escola de Idol [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c9SiUvYDuNK9UPvS6646S1lpncR.jpg'),
(122399, 8769, 'Love Live Superstar A Escola de Idol [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Av0fcyi5PLetxi9AY630eFUDuXj.jpg'),
(122400, 8769, 'Love Live Superstar A Escola de Idol [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n9Kbf05kWUQOtOB5lkAbju3px1w.jpg'),
(122401, 8770, 'O Poltergeist de Enfield [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wr0EiKVfTW4D4xqEdTySPLuP50g.jpg'),
(122402, 8770, 'O Poltergeist de Enfield [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yajLNxksE1b00TorweM0c8KYKSz.jpg'),
(122403, 8770, 'O Poltergeist de Enfield [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/izD1T6zh8DL3kYXdDrQaMdbNHfW.jpg'),
(122404, 8770, 'O Poltergeist de Enfield [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eBCTLO1GjnnWGlEDho5q7OEaEXP.jpg'),
(122405, 8771, 'Ochikobore Fruit Tart [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/581798.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/auq8sujtuBGdcRDMn54wasrWDJR.jpg'),
(122406, 8771, 'Ochikobore Fruit Tart [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/581800.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4WX03Y1E7JzFW9VZDaWBZ8ja83h.jpg'),
(122407, 8771, 'Ochikobore Fruit Tart [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/581802.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ttS96UkJQ8X4wpJhGA6diSCCMmq.jpg'),
(122408, 8771, 'Ochikobore Fruit Tart [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/581804.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ieWnuMj5GhcvoQNWzJ4JwJhV9Wp.jpg'),
(122409, 8771, 'Ochikobore Fruit Tart [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/581806.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/whbGJw96VSDdwO91dQN3xtFv2Tc.jpg'),
(122410, 8771, 'Ochikobore Fruit Tart [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/581808.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eCqgrFfLnjpBQ3D7fa7LZWktaYA.jpg'),
(122411, 8771, 'Ochikobore Fruit Tart [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/581810.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oVXuUTh4RDGOR0bkR6vUxiaByR2.jpg'),
(122412, 8771, 'Ochikobore Fruit Tart [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/581812.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bRwRtUd8tbSPxftFuDQ2HUs5LJX.jpg'),
(122413, 8771, 'Ochikobore Fruit Tart [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/581814.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jx4CKrcA3v5X3DuN1F5BvLVfJ23.jpg'),
(122414, 8771, 'Ochikobore Fruit Tart [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/581816.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gdBi8b50YKYctVoVy4xqrvL6Jfa.jpg'),
(122415, 8771, 'Ochikobore Fruit Tart [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/581818.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/blqK9MODKVB3Md6o3gAmVBwWPDT.jpg'),
(122416, 8771, 'Ochikobore Fruit Tart [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/581820.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gXWUut61rzgigSkzIn7XzMokRRG.jpg'),
(122417, 8772, 'Panelaco Ao Vivo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/saj5S3jK3S0VxTadyPvg4hVY7WG.jpg'),
(122418, 8772, 'Panelaco Ao Vivo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/saj5S3jK3S0VxTadyPvg4hVY7WG.jpg'),
(122419, 8772, 'Panelaco Ao Vivo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/saj5S3jK3S0VxTadyPvg4hVY7WG.jpg'),
(122420, 8772, 'Panelaco Ao Vivo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/saj5S3jK3S0VxTadyPvg4hVY7WG.jpg'),
(122421, 8772, 'Panelaco Ao Vivo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/saj5S3jK3S0VxTadyPvg4hVY7WG.jpg'),
(122422, 8772, 'Panelaco Ao Vivo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/saj5S3jK3S0VxTadyPvg4hVY7WG.jpg'),
(122423, 8772, 'Panelaco Ao Vivo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/saj5S3jK3S0VxTadyPvg4hVY7WG.jpg'),
(122424, 8772, 'Panelaco Ao Vivo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/saj5S3jK3S0VxTadyPvg4hVY7WG.jpg'),
(122425, 8772, 'Panelaco Ao Vivo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/saj5S3jK3S0VxTadyPvg4hVY7WG.jpg'),
(122426, 8772, 'Panelaco Ao Vivo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/saj5S3jK3S0VxTadyPvg4hVY7WG.jpg'),
(122427, 8772, 'Panelaco Ao Vivo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/saj5S3jK3S0VxTadyPvg4hVY7WG.jpg'),
(122428, 8772, 'Panelaco Ao Vivo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/243484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/saj5S3jK3S0VxTadyPvg4hVY7WG.jpg'),
(122429, 8772, 'Panelaco Ao Vivo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/243485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/saj5S3jK3S0VxTadyPvg4hVY7WG.jpg'),
(122430, 8772, 'Panelaco Ao Vivo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/243486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/saj5S3jK3S0VxTadyPvg4hVY7WG.jpg'),
(122431, 8772, 'Panelaco Ao Vivo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/243487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/saj5S3jK3S0VxTadyPvg4hVY7WG.jpg'),
(122432, 8772, 'Panelaco Ao Vivo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/243488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/saj5S3jK3S0VxTadyPvg4hVY7WG.jpg'),
(122433, 8772, 'Panelaco Ao Vivo S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/243489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/saj5S3jK3S0VxTadyPvg4hVY7WG.jpg'),
(122434, 8772, 'Panelaco Ao Vivo S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/243490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/saj5S3jK3S0VxTadyPvg4hVY7WG.jpg'),
(122435, 8772, 'Panelaco Ao Vivo S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/243491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/saj5S3jK3S0VxTadyPvg4hVY7WG.jpg'),
(122436, 8772, 'Panelaco Ao Vivo S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/243492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/saj5S3jK3S0VxTadyPvg4hVY7WG.jpg'),
(122437, 8773, 'Primeiros Amores S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yVWmDjk6L6VlGHIAphtm3pKmcrZ.jpg'),
(122438, 8773, 'Primeiros Amores S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63E6LLUIhTwIkak7I2HojAZbAxE.jpg'),
(122439, 8773, 'Primeiros Amores S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6AywcJXR79pz4yZyKAkKf2UiAy2.jpg'),
(122440, 8773, 'Primeiros Amores S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xkho2lM2pN0jMxLpyWgl0rbIzFQ.jpg'),
(122441, 8773, 'Primeiros Amores S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dDZa8s0YvFY8SkN0qLlKSUJnZ1I.jpg'),
(122442, 8773, 'Primeiros Amores S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wdiGDVkfQfghIkzUc6sR6hGyJHe.jpg'),
(122443, 8774, 'Sunny entre Estrelas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bqX4iQ6ECT6E9NZwugaNL8HOD1P.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(122444, 8774, 'Sunny entre Estrelas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wKTxG8EOGA91YCtRFTLA3neSB18.jpg'),
(122445, 8774, 'Sunny entre Estrelas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8PbEwdUiSGPpN1zrHoYd1x9M9vw.jpg'),
(122446, 8774, 'Sunny entre Estrelas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dUSczQTZPe79eprRfKKNoLE7Ymd.jpg'),
(122447, 8774, 'Sunny entre Estrelas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kAJRWp5B7Tz7t56fcSkrqPdg2qI.jpg'),
(122448, 8774, 'Sunny entre Estrelas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aax9hQZjLk0TLBIWsLco6KTwxnZ.jpg'),
(122449, 8774, 'Sunny entre Estrelas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/12kfAjuHdt1gpUJQEw9RCNBOgni.jpg'),
(122450, 8774, 'Sunny entre Estrelas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fd4TVOzL0BIGa136PEbb3iDZaDM.jpg'),
(122451, 8774, 'Sunny entre Estrelas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9KtKMyXhyUmBt5HZSh5jRToxRrC.jpg'),
(122452, 8774, 'Sunny entre Estrelas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lSrpX4RPYtZfCUWJ3aFoJeL3JtL.jpg'),
(122453, 8774, 'Sunny entre Estrelas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sRSAIl2taACZ4p4eH2nwGAzivsB.jpg'),
(122454, 8774, 'Sunny entre Estrelas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/243431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDGClDMCfo9fq6dAq8KCl3Xywlq.jpg'),
(122455, 8774, 'Sunny entre Estrelas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/243432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nYwSrFzLcT2bG79uyLPQsIpT3UU.jpg'),
(122456, 8774, 'Sunny entre Estrelas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/243433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iRRtEn0mJwo2SJvokcmB2Jv8WHi.jpg'),
(122457, 8774, 'Sunny entre Estrelas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/243434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5lPzNc7ruJJSGPter7rP4m2oNjk.jpg'),
(122458, 8774, 'Sunny entre Estrelas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/243435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sdpUdTzgxX7DaHlFzQy1QZxWDDz.jpg'),
(122459, 8774, 'Sunny entre Estrelas S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/243436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/csH6yBf50AIDpxeyJG0xHKTlAPH.jpg'),
(122460, 8774, 'Sunny entre Estrelas S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/243437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wpNK5WylH15uK3Z2kQe7EQ4WHwJ.jpg'),
(122461, 8774, 'Sunny entre Estrelas S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/243438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4KWbuBeLv6uDxohvK5YH1VjCVFQ.jpg'),
(122462, 8774, 'Sunny entre Estrelas S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/243439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d1qAsl5IrsI3245SGIccxaV8WrX.jpg'),
(122463, 8774, 'Sunny entre Estrelas S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/243440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4IzpiL2i6grC8M27RF16sRTVOoc.jpg'),
(122464, 8775, 'Sunny entre Estrelas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pE7LT4aBB3P0e9b4ZrZ1bGYjIbb.jpg'),
(122465, 8775, 'Sunny entre Estrelas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rgLMGQtSUzyg4z6SY1P3uo30Okr.jpg'),
(122466, 8775, 'Sunny entre Estrelas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xRzlrcJXcFqasaCbggsmq7R5WqL.jpg'),
(122467, 8775, 'Sunny entre Estrelas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hTv3feOQ2uCAi4Nw1GGROafjSmg.jpg'),
(122468, 8775, 'Sunny entre Estrelas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ha7BKrXCTnUtRb6FvC83oohEyGB.jpg'),
(122469, 8775, 'Sunny entre Estrelas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wQ37wwIGjIxNnaCb7krhZgF5pih.jpg'),
(122470, 8775, 'Sunny entre Estrelas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iUj6Ldg9RvwwQZz7zOWFV4TL1q0.jpg'),
(122471, 8775, 'Sunny entre Estrelas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Fy4eqOquWqeoLacPuhGeyILq4s.jpg'),
(122472, 8775, 'Sunny entre Estrelas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/co7AWNqr0jbISa7otd16gCbGciq.jpg'),
(122473, 8775, 'Sunny entre Estrelas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vA48cU5jTFJ6tR4okFLDDVwSR8J.jpg'),
(122474, 8775, 'Sunny entre Estrelas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2JyPH3v3m6cSUbhjaKWkx7tDCN7.jpg'),
(122475, 8775, 'Sunny entre Estrelas S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/243452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oI0xjbqZJVFgY6x7c7lsqB12gvs.jpg'),
(122476, 8775, 'Sunny entre Estrelas S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/243453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cJAPBgM9J4tzAmqpawls2uZAs4t.jpg'),
(122477, 8775, 'Sunny entre Estrelas S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/243454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wHPCzA13LRhobIeWAd3j1QED3tY.jpg'),
(122478, 8775, 'Sunny entre Estrelas S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/243455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cWve2jxjzINXx9CHaUsjXGm0Fke.jpg'),
(122479, 8775, 'Sunny entre Estrelas S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/243456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/huD0rWWkOqzGQ7XdyLA2UMNGn5O.jpg'),
(122480, 8775, 'Sunny entre Estrelas S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/243457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPUtgB0nAm3vsXPysyQAkXmLkLe.jpg'),
(122481, 8775, 'Sunny entre Estrelas S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/243458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ndB5IV6lfOyCtLOAHpzWuRmtql.jpg'),
(122482, 8775, 'Sunny entre Estrelas S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/243459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7H9xDFNKalSJKFzQUaFX9ehnNIH.jpg'),
(122483, 8775, 'Sunny entre Estrelas S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/243460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ut9OroFFqsqUnVBe65YQjbJkXm.jpg'),
(122484, 8775, 'Sunny entre Estrelas S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/243461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3pBU0TufkEa8a1DNHyBon9Sykg5.jpg'),
(122485, 8775, 'Sunny entre Estrelas S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/243462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qCvEhUz3jEJU5VK9zdpjrp3JAau.jpg'),
(122486, 8775, 'Sunny entre Estrelas S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/243463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eZzuiOProrl4cMSfDaYZE1K5Lvb.jpg'),
(122487, 8775, 'Sunny entre Estrelas S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/243464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x7TLcQgoC302wAnr2J2gXT7Lo9B.jpg'),
(122488, 8775, 'Sunny entre Estrelas S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/243465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5JMfg5FajOilYM2fMvDKt9L0WE2.jpg'),
(122489, 8775, 'Sunny entre Estrelas S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/243466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9lPFSFTLQjPDLes5dKdtzWG270O.jpg'),
(122490, 8776, 'Tore S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/74Igev4aOVTXn5H5oVgNAGz9s1F.jpg'),
(122491, 8776, 'Tore S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAqcpnZYazZHGPO0WSv4Sjb4ZBz.jpg'),
(122492, 8776, 'Tore S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/25xaur2IsZz6KnBR6MR9vl1Xgsq.jpg'),
(122493, 8776, 'Tore S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vxZXxGzXZnwCVfriGlmh2NLP7By.jpg'),
(122494, 8776, 'Tore S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glOeaseVSJBE2d8np3myq7EspSm.jpg'),
(122495, 8776, 'Tore S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dAAYNtTjRnmUdOJGAagglQqUHSj.jpg'),
(122496, 8777, 'Uma semana para Amelia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2YxKLwpPXfOKKYbR8B545wKz8I.jpg'),
(122497, 8777, 'Uma semana para Amelia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2gRu0YAHG6HTs2hrBQFDhJILyKS.jpg'),
(122498, 8777, 'Uma semana para Amelia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kdw8CYCudhEUdfeTXvZkb6LWMg1.jpg'),
(122499, 8777, 'Uma semana para Amelia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7ZfuPaRRVekmvUHK9WCV4VxHDQ.jpg'),
(122500, 8777, 'Uma semana para Amelia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4dlQw0zIw8gXzSlZmKkAWQgFpra.jpg'),
(122501, 8778, 'Wake Up Girl Zoo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/581774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UU5iQEXbm03bDFjHjhIwYZ85hq.jpg'),
(122502, 8778, 'Wake Up Girl Zoo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/581776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UU5iQEXbm03bDFjHjhIwYZ85hq.jpg'),
(122503, 8778, 'Wake Up Girl Zoo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/581778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UU5iQEXbm03bDFjHjhIwYZ85hq.jpg'),
(122504, 8778, 'Wake Up Girl Zoo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/581780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UU5iQEXbm03bDFjHjhIwYZ85hq.jpg'),
(122505, 8778, 'Wake Up Girl Zoo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/581782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UU5iQEXbm03bDFjHjhIwYZ85hq.jpg'),
(122506, 8778, 'Wake Up Girl Zoo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/581784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UU5iQEXbm03bDFjHjhIwYZ85hq.jpg'),
(122507, 8778, 'Wake Up Girl Zoo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/581786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UU5iQEXbm03bDFjHjhIwYZ85hq.jpg'),
(122508, 8778, 'Wake Up Girl Zoo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/581788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UU5iQEXbm03bDFjHjhIwYZ85hq.jpg'),
(122509, 8778, 'Wake Up Girl Zoo [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/581790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UU5iQEXbm03bDFjHjhIwYZ85hq.jpg'),
(122510, 8778, 'Wake Up Girl Zoo [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/581792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UU5iQEXbm03bDFjHjhIwYZ85hq.jpg'),
(122511, 8779, 'Wake Up Girls [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/581726.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wtQP4cc1DbF3vqCSQnRJSNXsUyc.jpg'),
(122512, 8779, 'Wake Up Girls [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/581728.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ojNIuZ0gTgMqvz2OkMWCV7BAdRr.jpg'),
(122513, 8779, 'Wake Up Girls [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/581730.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wlcbZrY7Ws8J1tYVr8yPCl1jn1W.jpg'),
(122514, 8779, 'Wake Up Girls [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/581732.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ozEyBOnSDKTgkrZZYy7lUbxSM7P.jpg'),
(122515, 8779, 'Wake Up Girls [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/581734.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rnHYmrjzAm3D0O6vG2XfxZ4knx.jpg'),
(122516, 8779, 'Wake Up Girls [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/581736.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rvI0qjS1xZ7X5TFdcjYkCLHQtTo.jpg'),
(122517, 8779, 'Wake Up Girls [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/581738.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rowMXoQSu9fAKl36jWEdP8OEfLo.jpg'),
(122518, 8779, 'Wake Up Girls [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/581740.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4C4znPqxfGXGIr0GrgkkFPgbJBA.jpg'),
(122519, 8779, 'Wake Up Girls [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/581742.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5ruKEHVPBh25Nkv9jcIKGork5zJ.jpg'),
(122520, 8779, 'Wake Up Girls [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/581744.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fbKxdVor0D0pPWfVFe8YDSyK9eR.jpg'),
(122521, 8779, 'Wake Up Girls [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/581746.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jKN9scYQAAt22RuMVsuHNeuJPLy.jpg'),
(122522, 8779, 'Wake Up Girls [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/581748.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8NRzfmepeCKkVP7gcfH3OMiW8xu.jpg'),
(122523, 8780, 'Wake Up Girls [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/581750.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AijctAOwt4kuLJ0rhvzd7BUkAQr.jpg'),
(122524, 8780, 'Wake Up Girls [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/581752.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h4tpdSNOkNZXjlzY4HLUJj5AEG9.jpg'),
(122525, 8780, 'Wake Up Girls [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/581754.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/upZqdbr7AeOxWxJTvnhCErZryK8.jpg'),
(122526, 8780, 'Wake Up Girls [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/581756.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/llGEOtTZV52de6YCuKFHJ7nU1pF.jpg'),
(122527, 8780, 'Wake Up Girls [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/581758.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6Uk8ngxwzUISYoQUtpfHAvxn75R.jpg'),
(122528, 8780, 'Wake Up Girls [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/581760.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pP3VNTS0mUWoI5chWeRAHCJviT7.jpg'),
(122529, 8780, 'Wake Up Girls [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/581762.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cSSK6ZBfrOyNW0MyN2ijpPHhlX8.jpg'),
(122530, 8780, 'Wake Up Girls [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/581764.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yYq0hSjUQ4zBiV0Sq1qZAbgtE65.jpg'),
(122531, 8780, 'Wake Up Girls [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/581766.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3vij59ehG0Dj4uxUCmHE1d7CZr7.jpg'),
(122532, 8780, 'Wake Up Girls [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/581768.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j06HsTBZyPhsQaYOIueRZhXLoMH.jpg'),
(122533, 8780, 'Wake Up Girls [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/581770.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b9P4VRhMKWjNz8X6TzJoMDa4CQP.jpg'),
(122534, 8780, 'Wake Up Girls [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/581772.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cGV0U6sFskqWj7eRm1hD63Hqppn.jpg'),
(122535, 8781, 'Corpos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/658Gx2ThuIGy5NEVhh0dOfwPUAT.jpg'),
(122536, 8781, 'Corpos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sN0cERxMPVdKtZHKLyjVuZJENrD.jpg'),
(122537, 8781, 'Corpos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rwZWnvHXbZB38ndjperlywwspXd.jpg'),
(122538, 8781, 'Corpos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7kDCrOYo68PyNJuqfavNAnKMLae.jpg'),
(122539, 8781, 'Corpos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uoouM9crCuLFvGrzxSHrn5NGxhH.jpg'),
(122540, 8781, 'Corpos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tSH0pEwwUSOiAfKQnJnvyyR9UJ3.jpg'),
(122541, 8781, 'Corpos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/epo10dKJQK1JSp2SI9t11ovmYsq.jpg'),
(122542, 8781, 'Corpos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dVPqqkVTJqZwvFZz3AdHT0UUKqe.jpg'),
(122543, 8782, 'A Garota do Cigarro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dE6JLT2ar3oHz1XCqQa5U978aeI.jpg'),
(122544, 8782, 'A Garota do Cigarro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yCRYLBGp9wkP7NSta28RK0SCnwB.jpg'),
(122545, 8782, 'A Garota do Cigarro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/daxwt3avX2pCuMcoTHKMWCbwUCu.jpg'),
(122546, 8782, 'A Garota do Cigarro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qhPS92JLzBo5bZZnvkk21kqrfMk.jpg'),
(122547, 8782, 'A Garota do Cigarro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u1MEOV5yIgbf51kuxdA3BFoukNO.jpg'),
(122548, 8783, 'Academia Unicornio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4j6AvZ6KHQktV5qDuKpyV0gC6kJ.jpg'),
(122549, 8783, 'Academia Unicornio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2YADIUPH8p0DPhw5OD1bc1IJPpF.jpg'),
(122550, 8783, 'Academia Unicornio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/twLsTyoBpitB8IXjflyeCCr7Rp5.jpg'),
(122551, 8783, 'Academia Unicornio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cJQwyRqTLSbhhvg8epdyglZPX9w.jpg'),
(122552, 8783, 'Academia Unicornio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iA87K7zA7PdtltfarM0LCzv5TQb.jpg'),
(122553, 8783, 'Academia Unicornio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yUwAOT2bSKYaQDlcbETNA5eU49B.jpg'),
(122554, 8783, 'Academia Unicornio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r8vVXWLoFg5zagqpVIOsNz8rz9H.jpg'),
(122555, 8783, 'Academia Unicornio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/96Eq1zmu5lhKDwnNjbmAbj41MT4.jpg'),
(122556, 8783, 'Academia Unicornio S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2rsKRKQ7zimoe7Sd9Z0IG8SxzDu.jpg'),
(122557, 8784, 'Ate que o Crime nos Separe O Assassinato do Casal Haysom [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o4awmdTnzrukJtR8QiemuSKKHdM.jpg'),
(122558, 8784, 'Ate que o Crime nos Separe O Assassinato do Casal Haysom [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yK2RovctHES1V3Y4THiHVCTjUv6.jpg'),
(122559, 8784, 'Ate que o Crime nos Separe O Assassinato do Casal Haysom [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2W8WXnan298tiqiDTVK93Z6jYwh.jpg'),
(122560, 8784, 'Ate que o Crime nos Separe O Assassinato do Casal Haysom [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9zvMeLsaRbwZnjEzaIfVT4XIPeZ.jpg'),
(122561, 8785, 'Carro Ostentacao com Will Castro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMfhHeGwnaj6xG5nObyJFbCugoj.jpg'),
(122562, 8785, 'Carro Ostentacao com Will Castro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMfhHeGwnaj6xG5nObyJFbCugoj.jpg'),
(122563, 8785, 'Carro Ostentacao com Will Castro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMfhHeGwnaj6xG5nObyJFbCugoj.jpg'),
(122564, 8785, 'Carro Ostentacao com Will Castro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMfhHeGwnaj6xG5nObyJFbCugoj.jpg'),
(122565, 8785, 'Carro Ostentacao com Will Castro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMfhHeGwnaj6xG5nObyJFbCugoj.jpg'),
(122566, 8785, 'Carro Ostentacao com Will Castro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMfhHeGwnaj6xG5nObyJFbCugoj.jpg'),
(122567, 8786, 'Carro Ostentacao com Will Castro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMfhHeGwnaj6xG5nObyJFbCugoj.jpg'),
(122568, 8786, 'Carro Ostentacao com Will Castro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMfhHeGwnaj6xG5nObyJFbCugoj.jpg'),
(122569, 8786, 'Carro Ostentacao com Will Castro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMfhHeGwnaj6xG5nObyJFbCugoj.jpg'),
(122570, 8786, 'Carro Ostentacao com Will Castro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMfhHeGwnaj6xG5nObyJFbCugoj.jpg'),
(122571, 8786, 'Carro Ostentacao com Will Castro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMfhHeGwnaj6xG5nObyJFbCugoj.jpg'),
(122572, 8786, 'Carro Ostentacao com Will Castro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMfhHeGwnaj6xG5nObyJFbCugoj.jpg'),
(122573, 8787, 'Carro Ostentacao com Will Castro S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMfhHeGwnaj6xG5nObyJFbCugoj.jpg'),
(122574, 8787, 'Carro Ostentacao com Will Castro S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMfhHeGwnaj6xG5nObyJFbCugoj.jpg'),
(122575, 8787, 'Carro Ostentacao com Will Castro S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMfhHeGwnaj6xG5nObyJFbCugoj.jpg'),
(122576, 8787, 'Carro Ostentacao com Will Castro S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMfhHeGwnaj6xG5nObyJFbCugoj.jpg'),
(122577, 8787, 'Carro Ostentacao com Will Castro S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMfhHeGwnaj6xG5nObyJFbCugoj.jpg'),
(122578, 8787, 'Carro Ostentacao com Will Castro S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMfhHeGwnaj6xG5nObyJFbCugoj.jpg'),
(122579, 8787, 'Carro Ostentacao com Will Castro S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMfhHeGwnaj6xG5nObyJFbCugoj.jpg'),
(122580, 8788, 'Delicious Party Pretty Cure [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lQjzF9SFSKWtsNj1d5J7IQu1c4N.jpg'),
(122581, 8788, 'Delicious Party Pretty Cure [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8mBqkPkkPriIwgDcEJn5bMcirn0.jpg'),
(122582, 8788, 'Delicious Party Pretty Cure [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bw9M8RTPDmP96HlrDjtZh6ozQD4.jpg'),
(122583, 8788, 'Delicious Party Pretty Cure [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vIsyjaVynTI3vuMHMn4jsV7wLLb.jpg'),
(122584, 8788, 'Delicious Party Pretty Cure [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c3SCgeMqakxFX1aVoU6zegJ5fZL.jpg'),
(122585, 8788, 'Delicious Party Pretty Cure [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pWvm7PkM55drPjEGWxZMD5kTENt.jpg'),
(122586, 8788, 'Delicious Party Pretty Cure [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v8aE8pGmyOy7iD9bcsCeh0vxqUu.jpg'),
(122587, 8788, 'Delicious Party Pretty Cure [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vl55oTGIZ3xJt8692wCY1ROrHsn.jpg'),
(122588, 8788, 'Delicious Party Pretty Cure [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xDDLaUDaOlFQQXTufCNEzsgdVoF.jpg'),
(122589, 8788, 'Delicious Party Pretty Cure [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZYMETx4t2EfRrMI7bpcjmcCEZ8.jpg'),
(122590, 8788, 'Delicious Party Pretty Cure [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/elMDrycviy1QO6x7TtaMwrJCwnw.jpg'),
(122591, 8788, 'Delicious Party Pretty Cure [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/243165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oGPkTQtqfGRmwB7KrveYMkVBDoB.jpg'),
(122592, 8788, 'Delicious Party Pretty Cure [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/243166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzKyioY0nxUcb34etjdJ7lg00Uy.jpg'),
(122593, 8788, 'Delicious Party Pretty Cure [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/243167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nmpYhuu9w3pOFMFaZOKo3wUUoly.jpg'),
(122594, 8788, 'Delicious Party Pretty Cure [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/243168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dducnEKYuq13b1dB5QrAF1axhCu.jpg'),
(122595, 8788, 'Delicious Party Pretty Cure [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/243169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aWiRYu838Co6lSxeNR0suuee2Wy.jpg'),
(122596, 8788, 'Delicious Party Pretty Cure [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/243170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7YwUZEyxElYDOCto9ZPWdrcjFDQ.jpg'),
(122597, 8788, 'Delicious Party Pretty Cure [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/243171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fLbMbIo2w4gGKI6IeilV79MdC3o.jpg'),
(122598, 8788, 'Delicious Party Pretty Cure [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/243172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qEg5WyzconR89ismOyc4gnm0YPU.jpg'),
(122599, 8788, 'Delicious Party Pretty Cure [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/243173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gLqEdjcQMRZuEjphgClw86cIqfr.jpg'),
(122600, 8788, 'Delicious Party Pretty Cure [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/243174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSCS4GiclQtkQNRjSKBXagOarBp.jpg'),
(122601, 8788, 'Delicious Party Pretty Cure [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/243175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wUN5o42Tz0CFOCEfqnMKxKhagv1.jpg'),
(122602, 8788, 'Delicious Party Pretty Cure [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/243176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nlEeNl6r4BN7u3QvKbXbVNNQKxk.jpg'),
(122603, 8788, 'Delicious Party Pretty Cure [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/243177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qnojbyTbtWhj59o3IKk6TFp6lao.jpg'),
(122604, 8788, 'Delicious Party Pretty Cure [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/243178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aRQHYwciWZx9Kb7jYrFBu2hwLCW.jpg'),
(122605, 8788, 'Delicious Party Pretty Cure [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/243179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yYLtWeAsz25iBi94fZnPWNZfN1e.jpg'),
(122606, 8788, 'Delicious Party Pretty Cure [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/243180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p5k8wuiUpqYO7SvsswpY0FViRKt.jpg'),
(122607, 8788, 'Delicious Party Pretty Cure [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/243181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/johOfvbeBbYPB7JI6s9NFSLZbkW.jpg'),
(122608, 8788, 'Delicious Party Pretty Cure [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/243182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/afZZYWeNzxNM2dcqto01vccUD8v.jpg'),
(122609, 8788, 'Delicious Party Pretty Cure [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/243183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nQAP6er1FdaUTbspVkHJOiepflj.jpg'),
(122610, 8788, 'Delicious Party Pretty Cure [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/243184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Ga7FovjETr1AvkTuzTzIegU8h4.jpg'),
(122611, 8788, 'Delicious Party Pretty Cure [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/243185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/riqO6b6w3v5SCsTUN4TzSQk775i.jpg'),
(122612, 8788, 'Delicious Party Pretty Cure [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/243186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1cqyzHfQ8PVV08zxFGIqeUVORMe.jpg'),
(122613, 8788, 'Delicious Party Pretty Cure [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/243187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pQFXQkshpSJppkv6q8Fmpl2QtBW.jpg'),
(122614, 8788, 'Delicious Party Pretty Cure [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/243188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8gkuSQVqk4PIX888Nx3pFrkhcdk.jpg'),
(122615, 8788, 'Delicious Party Pretty Cure [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/243189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7811EqRRhaDBzsIGVIheMspYVoL.jpg'),
(122616, 8788, 'Delicious Party Pretty Cure [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/243190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dScKIAAHs2STk74rr4NQChdubwk.jpg'),
(122617, 8788, 'Delicious Party Pretty Cure [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/243191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/23gR42QCR99FJUu2Wig5oosDBRw.jpg'),
(122618, 8788, 'Delicious Party Pretty Cure [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/243192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6lGtTL6ThqtqfaT7bR4XFDzxzom.jpg'),
(122619, 8788, 'Delicious Party Pretty Cure [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/243193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8dMlnmVjwPVr6yHO8pV6tqjFB0g.jpg'),
(122620, 8788, 'Delicious Party Pretty Cure [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/243194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jnTc0vCAguEVp2mTmD0Aa25WPcs.jpg'),
(122621, 8788, 'Delicious Party Pretty Cure [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/243195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ohdHYZSauy6Q6ph4odyXcggV7BW.jpg'),
(122622, 8788, 'Delicious Party Pretty Cure [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/243196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zl8MgO3Nn85p3LwEV72IrqC3Y4X.jpg'),
(122623, 8788, 'Delicious Party Pretty Cure [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/243197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y4efsqBoNEGhBq7ftmhO0RHKbvK.jpg'),
(122624, 8788, 'Delicious Party Pretty Cure [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/243198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xALpd47Nm18ukR55cYwxFJuibNj.jpg'),
(122625, 8789, 'Diario de um Jovem Medico [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vYAN8a0x4gjlvgDQYzrpyzA8DxY.jpg'),
(122626, 8789, 'Diario de um Jovem Medico [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Jam1FbRpAJS3LqMFvJQ2660h0W.jpg'),
(122627, 8789, 'Diario de um Jovem Medico [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iIh6yhAx0U2bn0PFUlBViP4V12h.jpg'),
(122628, 8789, 'Diario de um Jovem Medico [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7vNZPh9QNdbvTJwo2Sb8DNMUhP.jpg'),
(122629, 8790, 'Diario de um Jovem Medico [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udbvmULoZFUKcEmPCGAP5c8urU1.jpg'),
(122630, 8790, 'Diario de um Jovem Medico [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xoC8xJOGmXdGAKYn8tUtd9owoOU.jpg'),
(122631, 8790, 'Diario de um Jovem Medico [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7EQJaQ8RS29tVzuL6uKr1GfWdL7.jpg'),
(122632, 8790, 'Diario de um Jovem Medico [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mTTs4Hx2J1ErOdMAfRWSGrBPyeG.jpg'),
(122633, 8791, 'Doce Misterio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zz5B3GMFw2rvOBqzqcI29qYlB2Q.jpg'),
(122634, 8791, 'Doce Misterio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gix9pCpkD8yTRJmdGLHsoZprIp.jpg'),
(122635, 8791, 'Doce Misterio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fnX6Fr1VrAdN3k2QSE3XrHu2YF1.jpg'),
(122636, 8791, 'Doce Misterio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6d6smOAMTKq6zjfZzwatXx8P16M.jpg'),
(122637, 8791, 'Doce Misterio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6d6smOAMTKq6zjfZzwatXx8P16M.jpg'),
(122638, 8791, 'Doce Misterio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6d6smOAMTKq6zjfZzwatXx8P16M.jpg'),
(122639, 8791, 'Doce Misterio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6d6smOAMTKq6zjfZzwatXx8P16M.jpg'),
(122640, 8791, 'Doce Misterio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6d6smOAMTKq6zjfZzwatXx8P16M.jpg'),
(122641, 8792, 'Israel Ira EUA A Longa Guerra [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n54gigMXqr5YNYVhVN7ppUwBNAI.jpg'),
(122642, 8792, 'Israel Ira EUA A Longa Guerra [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n54gigMXqr5YNYVhVN7ppUwBNAI.jpg'),
(122643, 8793, 'Jornada nas Estrelas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Asrl6u2tugWf9EJN24uhQ9zvyo6.jpg'),
(122644, 8793, 'Jornada nas Estrelas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w0h16RvrPpymRcAlEO5j3WlzQiH.jpg'),
(122645, 8793, 'Jornada nas Estrelas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h24Wo5hwqETbpLpuhD1zefB63Xh.jpg'),
(122646, 8793, 'Jornada nas Estrelas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tiA6RZkXKElNBxT2MbHVfRRlhQc.jpg'),
(122647, 8793, 'Jornada nas Estrelas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9usSwy1IFzsc43XT9MBhGwM7fs5.jpg'),
(122648, 8793, 'Jornada nas Estrelas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zUj64Ecu98C5rdep86LTIVEiQ9V.jpg'),
(122649, 8793, 'Jornada nas Estrelas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6TmAMWtT9bsrEM5Y5z5uWViyE4A.jpg'),
(122650, 8793, 'Jornada nas Estrelas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dYpwq4WTSnh9X1qBRdlsE2ZrcD1.jpg'),
(122651, 8793, 'Jornada nas Estrelas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tuSlKUb9MPW24Agl5r8IMFm0szu.jpg'),
(122652, 8793, 'Jornada nas Estrelas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tv1SjxLsCM1gfrqwQD5QtroDR3s.jpg'),
(122653, 8793, 'Jornada nas Estrelas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u3ssgUN1wOzTeg0wtux1CMAIGhJ.jpg'),
(122654, 8793, 'Jornada nas Estrelas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/243075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bq1TgPibdwqZP2Kw1vKg0fOlO2B.jpg'),
(122655, 8793, 'Jornada nas Estrelas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/243076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hhQRsDwrnt7KmKpPVaEzaP9zANM.jpg'),
(122656, 8793, 'Jornada nas Estrelas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/243077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vkQKqatvLvkSSm0VRDn6Jb3RTQo.jpg'),
(122657, 8793, 'Jornada nas Estrelas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/243078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vqaSfJ2KWrPjfGT3vojbstBuKEk.jpg'),
(122658, 8793, 'Jornada nas Estrelas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/243079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iIQZOeGdXriDJ5LxTKxnDVMvcIP.jpg'),
(122659, 8793, 'Jornada nas Estrelas S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/243080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bNVOzWUWVpH89EsRlgze5ZbcOXL.jpg'),
(122660, 8793, 'Jornada nas Estrelas S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/243081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aYUWqtl3O7pFLDQE7KxDBJbk4Xs.jpg'),
(122661, 8793, 'Jornada nas Estrelas S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/243082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z9qcTFOtq2Avt2sfuJbcDpavUEY.jpg'),
(122662, 8793, 'Jornada nas Estrelas S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/243083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m17qQfdrKrX0yC53RmByn8AMepg.jpg'),
(122663, 8793, 'Jornada nas Estrelas S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/243084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iCK1ZejvPRy5x2H9V7x1DImB5dz.jpg'),
(122664, 8793, 'Jornada nas Estrelas S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/243085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fRCPuQiFHe5JzAVuG17UoMk9rD0.jpg'),
(122665, 8793, 'Jornada nas Estrelas S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/243086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4RtnxALrHRD0JDyfw976DkBvadH.jpg'),
(122666, 8793, 'Jornada nas Estrelas S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/243087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dHY3lAap0OjYDjY94xjsQUrXvQZ.jpg'),
(122667, 8793, 'Jornada nas Estrelas S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/243088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lPXnSXmJhkTDPTnvPzohOVleQuB.jpg'),
(122668, 8793, 'Jornada nas Estrelas S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/243089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8rnOc0lC87dHXXG4givFgwbXAy1.jpg'),
(122669, 8793, 'Jornada nas Estrelas S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/243090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A33I01xXCteLlrIR0Kizo0IAdEJ.jpg'),
(122670, 8793, 'Jornada nas Estrelas S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/243091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dfym3BzL5T1RTMND4l8r2s1YkrG.jpg'),
(122671, 8793, 'Jornada nas Estrelas S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/243092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j74k8SgqNJxCznjW7K4SQJyIjPM.jpg'),
(122672, 8793, 'Jornada nas Estrelas S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/243093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xH37StqHBet4ehmqUTWXULKi3ZK.jpg'),
(122673, 8794, 'Jornada nas Estrelas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/erSLT1qmZjEQUfWblSj19jiYg2w.jpg'),
(122674, 8794, 'Jornada nas Estrelas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vkPrwjJflA3yOjGPIqqPrp553Pg.jpg'),
(122675, 8794, 'Jornada nas Estrelas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A8HtPgJXvtSAgYiVrnN8jy17sez.jpg'),
(122676, 8794, 'Jornada nas Estrelas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6nZ2mNvDqjQw4nWajBxQZIHFSv.jpg'),
(122677, 8794, 'Jornada nas Estrelas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZ0qfUdpiDWSU0aGGjfA23LnbBC.jpg'),
(122678, 8794, 'Jornada nas Estrelas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/piUaUVh3glJF2O94UXbDgGkhErf.jpg'),
(122679, 8794, 'Jornada nas Estrelas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3WwsMTz4OoACWP7uWZm9A41yVAM.jpg'),
(122680, 8794, 'Jornada nas Estrelas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r9Xfl9aQ7yx0vWnNrIFpRcYhdSp.jpg'),
(122681, 8794, 'Jornada nas Estrelas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tasTIm4EK1Wpl0q2T4Lq1tJHkvh.jpg'),
(122682, 8794, 'Jornada nas Estrelas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8r6TQovaSQ55IJ4bRBljm8L8ycb.jpg'),
(122683, 8794, 'Jornada nas Estrelas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jHNBbj9u3Gy1N7CAW6WsPW76Axn.jpg'),
(122684, 8794, 'Jornada nas Estrelas S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/243105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wL9bG3kCXGF2xK0iasSbpPL1hr3.jpg'),
(122685, 8794, 'Jornada nas Estrelas S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/243106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5h2tq7M2tDWVRc3uZ136WFURGWk.jpg'),
(122686, 8794, 'Jornada nas Estrelas S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/243107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDxjbrjbZYuE8tusl0EEhhlZ7xF.jpg'),
(122687, 8794, 'Jornada nas Estrelas S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/243108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n9ZEWP3aX6c77pSLIOs3wuERp15.jpg'),
(122688, 8794, 'Jornada nas Estrelas S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/243109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6NTjXViWypDNqsb9EcyAYihlIj4.jpg'),
(122689, 8794, 'Jornada nas Estrelas S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/243110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1H2VMdn01f0YVedAGckyyTwZZw6.jpg'),
(122690, 8794, 'Jornada nas Estrelas S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/243111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/10ezo2xR7JEebX5ZnveWhegYjiV.jpg'),
(122691, 8794, 'Jornada nas Estrelas S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/243112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nYgA5QXvveMEukDe20u0WikoBiG.jpg'),
(122692, 8794, 'Jornada nas Estrelas S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/243113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/51xBF7QdGc7XIDFdCX3cE709ltr.jpg'),
(122693, 8794, 'Jornada nas Estrelas S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/243114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2h1HZ2dMCUu10kA1m4vWd68FSZ0.jpg'),
(122694, 8794, 'Jornada nas Estrelas S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/243115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Vb8hzX1n3i5RgAkoeM3AoBC8oT.jpg'),
(122695, 8794, 'Jornada nas Estrelas S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/243116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p8ZrsP0eOXYrbGE2VREHW2jj2zF.jpg'),
(122696, 8794, 'Jornada nas Estrelas S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/243117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w7WswCjhJ4MhLyMXuIzjciwsWc.jpg'),
(122697, 8794, 'Jornada nas Estrelas S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/243118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9fNHdjbGRKN1GfD4ofHGuRxWxxc.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(122698, 8794, 'Jornada nas Estrelas S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/243119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sRwOPL1BdCvszhhuMoc5wf4wcVd.jpg'),
(122699, 8795, 'Jornada nas Estrelas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nYLppkUscDGsKA8a9QTYOmLH4gF.jpg'),
(122700, 8795, 'Jornada nas Estrelas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqNOs5jEoACzfIdOM3oFvyzjT0f.jpg'),
(122701, 8795, 'Jornada nas Estrelas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t5pBoiEiTBg31EIdPqjz5cXPg7k.jpg'),
(122702, 8795, 'Jornada nas Estrelas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4tbDwvgDgH3G0Q5y1W4pBEbu8Kq.jpg'),
(122703, 8795, 'Jornada nas Estrelas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6e3R3nX8Uh0n5IDFi8sgRO9Ti1l.jpg'),
(122704, 8795, 'Jornada nas Estrelas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/43RWuGIg73TV6bbfq22JwUEdqJT.jpg'),
(122705, 8795, 'Jornada nas Estrelas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/efXADdNGGWxDux0cU9jKognIMDC.jpg'),
(122706, 8795, 'Jornada nas Estrelas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h93X8y9IPye8Nu8UFePRpGUzKBy.jpg'),
(122707, 8795, 'Jornada nas Estrelas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4xHsutnhORhZbbZ67rWyiYKyjaP.jpg'),
(122708, 8795, 'Jornada nas Estrelas S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t2OSCFNifndQQk08Yjt0VhTN3zi.jpg'),
(122709, 8795, 'Jornada nas Estrelas S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/243130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8oakE8k1xKbk3VZ8QqWOLgaPLVQ.jpg'),
(122710, 8795, 'Jornada nas Estrelas S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/243131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kn1vFOYEldd41a2iIKf24KjDz1u.jpg'),
(122711, 8795, 'Jornada nas Estrelas S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/243132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oB3oWkeeBf3lb6sNBjDNtjPvGlm.jpg'),
(122712, 8795, 'Jornada nas Estrelas S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/243133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dEBvHa99h6fjD4GNIi0u9JEI3fl.jpg'),
(122713, 8795, 'Jornada nas Estrelas S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/243134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/huq7Zn0LurFrnrB1NvD06SFDktj.jpg'),
(122714, 8795, 'Jornada nas Estrelas S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/243135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v7nrXQFANKGzmTcVPvZjzg4TUst.jpg'),
(122715, 8795, 'Jornada nas Estrelas S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/243136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5m015Dzx9I5eVolWn2eVbPgC4dB.jpg'),
(122716, 8795, 'Jornada nas Estrelas S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/243137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kNc9xEZtRQxJIIYGbZ9gUlT4T.jpg'),
(122717, 8795, 'Jornada nas Estrelas S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/243138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2L5IP12ra3wfBhpw5MkLmiT1CNa.jpg'),
(122718, 8795, 'Jornada nas Estrelas S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/243139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/50TXxvgEKlaBe3S30SKj3BrFdZU.jpg'),
(122719, 8795, 'Jornada nas Estrelas S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/243140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3WkFXQHiWo4sPwj4JqpfI1RdnEW.jpg'),
(122720, 8795, 'Jornada nas Estrelas S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/243141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pdx0rWvduaWfXXqQNgTQcB9Q03M.jpg'),
(122721, 8795, 'Jornada nas Estrelas S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/243142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xr9A2zx2csLMTCEzuBHq7noPsIC.jpg'),
(122722, 8795, 'Jornada nas Estrelas S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/243143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3liqUiBw9g4wnGdqt3lfPlhAP8Y.jpg'),
(122723, 8796, 'Misterios da Fe S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Z5NjArhl3adWMe7Mz6LQSGUlzb.jpg'),
(122724, 8796, 'Misterios da Fe S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sKgtMCKcnCjI1kuNYCkjRrsmdIz.jpg'),
(122725, 8796, 'Misterios da Fe S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mOkFqLJB7AER0Cq8BELiQua4w6S.jpg'),
(122726, 8796, 'Misterios da Fe S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/te1FD7By6T61uL1QvFb6bbyOlEq.jpg'),
(122727, 8797, 'Oficina de Superclassicos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mYyPvFrIWLzGYggG2yybeW2B6Mj.jpg'),
(122728, 8797, 'Oficina de Superclassicos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6oz1cgiIDumSaHlJxVw3WUuY6L3.jpg'),
(122729, 8797, 'Oficina de Superclassicos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sPEe02eLLS8xM2Cf8ZnQ8hdRbqO.jpg'),
(122730, 8797, 'Oficina de Superclassicos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Mp3VFPxTfCgEksEsFq4PrGx4Th.jpg'),
(122731, 8797, 'Oficina de Superclassicos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dldiFaEJXaHbsXWMm8iyyICROvJ.jpg'),
(122732, 8797, 'Oficina de Superclassicos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mMUZR847myt7Nl8ECcqFCwXJVTw.jpg'),
(122733, 8797, 'Oficina de Superclassicos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3p1YLDE8EnBwIzh7XX8Dqo7nZcB.jpg'),
(122734, 8797, 'Oficina de Superclassicos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFxBPt9y7u40C4xUSL61koilRsf.jpg'),
(122735, 8798, 'Oficina de Superclassicos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ely4OBNN3qMMbEuvsETQOEBJ4AF.jpg'),
(122736, 8798, 'Oficina de Superclassicos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eTnMnSPQmL98O4v1d1n5IN815Ts.jpg'),
(122737, 8798, 'Oficina de Superclassicos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tY4KRe6gVerx6r1N2FXTGGr7vPn.jpg'),
(122738, 8798, 'Oficina de Superclassicos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A0av34e1gupVhOjrjj0J9KORngn.jpg'),
(122739, 8798, 'Oficina de Superclassicos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zowgrJOxKMF0HFJO5pJuCsUFD21.jpg'),
(122740, 8798, 'Oficina de Superclassicos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5LUyVO5JoTqtsbU5M5y4dhcrCga.jpg'),
(122741, 8798, 'Oficina de Superclassicos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6vwYwaWsM5UtMTmzqdXCQeCtvuP.jpg'),
(122742, 8798, 'Oficina de Superclassicos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vtQ2Jvzq4KL8CeivB5dzpV0kpAw.jpg'),
(122743, 8798, 'Oficina de Superclassicos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6NrttcIWxk0cQ2sesyIekAvLEUs.jpg'),
(122744, 8798, 'Oficina de Superclassicos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6NrttcIWxk0cQ2sesyIekAvLEUs.jpg'),
(122745, 8799, 'Onimusha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bP02iyPOy20ZM2pk4rDAXxRoAil.jpg'),
(122746, 8799, 'Onimusha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63SibqcFLz5RtR2KOqh3a0npTq2.jpg'),
(122747, 8799, 'Onimusha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yg8qPuioU1WlzmamIS6IyjjrFBr.jpg'),
(122748, 8799, 'Onimusha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vgJfps8XdDvXw4hafC4O5oPUsBK.jpg'),
(122749, 8799, 'Onimusha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1xjQIjcdemmQZFb50s20TcuFZkQ.jpg'),
(122750, 8799, 'Onimusha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAFJXvADAfQCoklyPD8YQcVyC9p.jpg'),
(122751, 8799, 'Onimusha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tFifpfHpwyedtFj8W3OFpSShy9t.jpg'),
(122752, 8799, 'Onimusha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f7iE54moxIeNBdhb686gcH1lO8s.jpg'),
(122753, 8800, 'Queer Eye S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hVDB3YHBmsDTRBScYFm9cwXL8SH.jpg'),
(122754, 8800, 'Queer Eye S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nElKygmgG0WFe5Muj1Pkp8Me7pj.jpg'),
(122755, 8800, 'Queer Eye S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u43nSncLpWvmr0vPzfqF9o9eQYF.jpg'),
(122756, 8800, 'Queer Eye S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1tdjKtEMqCmSrJEFQBeLC44uNcn.jpg'),
(122757, 8800, 'Queer Eye S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tisKxrdLDxPUoPRgiUrFuZNQ4aj.jpg'),
(122758, 8800, 'Queer Eye S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/31JZcpBIHoODAn3izgdChFDO3gX.jpg'),
(122759, 8800, 'Queer Eye S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJZkLcbcrjXLj4GpV9ipZUcFe0u.jpg'),
(122760, 8800, 'Queer Eye S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ntCpsUWm0TKieYcNmLtVCddk2g2.jpg'),
(122761, 8801, 'Queer Eye S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3lEJbNS7k6GZ9ie0pXDKD50yMwl.jpg'),
(122762, 8801, 'Queer Eye S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bazX4OD7egYXnCPfKv3kGEk1gwv.jpg'),
(122763, 8801, 'Queer Eye S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lNLnLyfahTfRWezovyoq3T69re.jpg'),
(122764, 8801, 'Queer Eye S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nhI8ez5JuToHr8gaSShJrW70dUk.jpg'),
(122765, 8801, 'Queer Eye S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jtrk6Li98qeEHgzCEOuYlRHQhp8.jpg'),
(122766, 8801, 'Queer Eye S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wP0B3w3EYmPZpCb9E33eznvz55S.jpg'),
(122767, 8801, 'Queer Eye S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zSjr2ArFdkXjYKiOMlByZVYipoI.jpg'),
(122768, 8801, 'Queer Eye S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyN0djbr0BhFLi4v6P2OfSdS4T7.jpg'),
(122769, 8802, 'Queer Eye S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gBeTJX6JS5I7bv43YSy9zNrrBLR.jpg'),
(122770, 8802, 'Queer Eye S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q2IyJxYb4P3FwEVV0emISdIt3qu.jpg'),
(122771, 8802, 'Queer Eye S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6A3qgNOioRlWz7Ba8yBf6m4V3Rg.jpg'),
(122772, 8802, 'Queer Eye S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rmzQMqVG08GjRTe0fsCLiJAeOU1.jpg'),
(122773, 8802, 'Queer Eye S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3bRLykoTHnHBoJicaCzr1Jgpz1L.jpg'),
(122774, 8802, 'Queer Eye S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vLNAzGj1kFevshFSmsBgfMm8Zvd.jpg'),
(122775, 8802, 'Queer Eye S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4PEWZTX6HeiUMgTD4ZAIkWsDJDI.jpg'),
(122776, 8802, 'Queer Eye S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hyx6TEnIhuXzGatBiOi2CEck1xE.jpg'),
(122777, 8803, 'Queer Eye S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/noyAO8C70SccpmbRZtZb577C8uO.jpg'),
(122778, 8803, 'Queer Eye S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nzzFDw6wiPqU5vVx1sqmLeSwfgh.jpg'),
(122779, 8803, 'Queer Eye S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iZfAAOy8GH8Jc6uRaQiipWp0G0Z.jpg'),
(122780, 8803, 'Queer Eye S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rQKPOyYAoifwGfNKfRUIQrvDbnC.jpg'),
(122781, 8803, 'Queer Eye S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gHAvtAyaRODwH1ZdqH0KSFFkwno.jpg'),
(122782, 8803, 'Queer Eye S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l28jPM9E7QxupoIwbu6xHmVSB8E.jpg'),
(122783, 8803, 'Queer Eye S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c2opQ4t786NHjNVHVpx2gfQ31hU.jpg'),
(122784, 8803, 'Queer Eye S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qWILfAGV285GOH0MFbRz6RIYcVZ.jpg'),
(122785, 8804, 'Queer Eye S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a48SfA5k5KWhtTEcF7dUbHM6beb.jpg'),
(122786, 8804, 'Queer Eye S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hqKVp4uzVYLaHl3WyceBG25n9Og.jpg'),
(122787, 8804, 'Queer Eye S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s9i9lADRyQF6MwusiH1Tw0XHQA.jpg'),
(122788, 8804, 'Queer Eye S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3h2NQ3HION3hi52sgIbyizJUyHQ.jpg'),
(122789, 8804, 'Queer Eye S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhYPKGTbVva6NieEqHldlPMevjl.jpg'),
(122790, 8804, 'Queer Eye S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tUYXirNvO69m1EJTR35mnuTBMYY.jpg'),
(122791, 8804, 'Queer Eye S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cgNDcM8LQIIxeI5O8JpsDMHW72u.jpg'),
(122792, 8804, 'Queer Eye S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cINznBc6lg5ZmxHxHjV3TaGGjaC.jpg'),
(122793, 8804, 'Queer Eye S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r0WUQACNy8alHhfWRnY5ZIU5SoK.jpg'),
(122794, 8804, 'Queer Eye S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y2Zo4MM1axcVB0CoSKwSK9BVCmK.jpg'),
(122795, 8805, 'Queer Eye S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yK0YQ2OaHJqpCJxA1SbUflquB9c.jpg'),
(122796, 8805, 'Queer Eye S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nAgBiBvPoRK5JrsA2RugEz01Du2.jpg'),
(122797, 8805, 'Queer Eye S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7kfGL8e9o5b9VeLzSK6JYrgvxgR.jpg'),
(122798, 8805, 'Queer Eye S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5lyrM7p5QO8cPUnTskGG8dVdif.jpg'),
(122799, 8805, 'Queer Eye S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9dQmwXMv7xA0NWbyKw8uDMIOUIQ.jpg'),
(122800, 8805, 'Queer Eye S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bbZhhXOH1aA7er9CRjuFtCs7Reb.jpg'),
(122801, 8805, 'Queer Eye S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mGIG2ZPZrpugbdDhUONZTWRc2Uo.jpg'),
(122802, 8805, 'Queer Eye S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iO9v5aWBn5bTRmQ8HeXlzqksurP.jpg'),
(122803, 8805, 'Queer Eye S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kFfzEJIlKiCGnwdqSYFpMfJujvc.jpg'),
(122804, 8805, 'Queer Eye S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mzPmzDH0uOgbSuHxteRFoM77qMu.jpg'),
(122805, 8806, 'Queer Eye S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLFa7e4nZnIzklt4NPukLEnlyZw.jpg'),
(122806, 8806, 'Queer Eye S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/unwZ10rB2yZwMF20Oahj2EI97Sa.jpg'),
(122807, 8806, 'Queer Eye S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aTLCutBHftXKxAFOiMVoEZ0h4M7.jpg'),
(122808, 8806, 'Queer Eye S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lD9Q1xOE17Tmr8cewt6kWCwjaZF.jpg'),
(122809, 8806, 'Queer Eye S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/82aV0zMnArlNbWkLYnnmuZL5hPx.jpg'),
(122810, 8806, 'Queer Eye S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8kam2lfe1O9vMfRroeGiIE9MRN7.jpg'),
(122811, 8806, 'Queer Eye S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1d9kloDlFnnBrgctgqlQuJabxUG.jpg'),
(122812, 8807, 'Queer Eye S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9x2loam4P2YbDsjqIrzVeBgVMaP.jpg'),
(122813, 8807, 'Queer Eye S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9x2loam4P2YbDsjqIrzVeBgVMaP.jpg'),
(122814, 8807, 'Queer Eye S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9x2loam4P2YbDsjqIrzVeBgVMaP.jpg'),
(122815, 8807, 'Queer Eye S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9x2loam4P2YbDsjqIrzVeBgVMaP.jpg'),
(122816, 8807, 'Queer Eye S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9x2loam4P2YbDsjqIrzVeBgVMaP.jpg'),
(122817, 8807, 'Queer Eye S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9x2loam4P2YbDsjqIrzVeBgVMaP.jpg'),
(122818, 8808, 'The Vanishing Triangle [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gkvvFNlJISYCo8KW3lJS4qpQJ02.jpg'),
(122819, 8808, 'The Vanishing Triangle [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sl9aRZsUQiE9MZMeby54g0y8B4n.jpg'),
(122820, 8808, 'The Vanishing Triangle [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v7hZA4hoXV3iGCZ6Jym8fiDoNUl.jpg'),
(122821, 8808, 'The Vanishing Triangle [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v7hZA4hoXV3iGCZ6Jym8fiDoNUl.jpg'),
(122822, 8808, 'The Vanishing Triangle [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v7hZA4hoXV3iGCZ6Jym8fiDoNUl.jpg'),
(122823, 8809, 'Toda Luz que Nao Podemos Ver S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8JwfriiXedd5MUxuwaBDmakvHQy.jpg'),
(122824, 8809, 'Toda Luz que Nao Podemos Ver S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjL5G0vTNVQmYOTqiSJ1HO3xifM.jpg'),
(122825, 8809, 'Toda Luz que Nao Podemos Ver S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ztW4Yeq4U1dny3JkDbqR7usSfbe.jpg'),
(122826, 8809, 'Toda Luz que Nao Podemos Ver S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4YSwwFHnoCU0ZcrtyohM61I0HLS.jpg'),
(122827, 8810, 'Uma Maldicao de Familia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cYYJKoJRZMfbH8ZvOPEpHnwRvy3.jpg'),
(122828, 8810, 'Uma Maldicao de Familia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xpcpbWL0zlp4TnqLWIT1HUoLo6C.jpg'),
(122829, 8810, 'Uma Maldicao de Familia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/trdHVHtILp1lVTVoYG0X3Y1RyjR.jpg'),
(122830, 8810, 'Uma Maldicao de Familia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kRvNN6GoqkyKarAWOCzVcT3DeBv.jpg'),
(122831, 8810, 'Uma Maldicao de Familia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jg85IzDmK4uLr2SYRVYQrhvwdUh.jpg'),
(122832, 8810, 'Uma Maldicao de Familia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glIOS0KdEmrDfipjJmtBhEdYHRR.jpg'),
(122833, 8810, 'Uma Maldicao de Familia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qdzfNcVRxWPeTPSX5AsnlO1EkiE.jpg'),
(122834, 8810, 'Uma Maldicao de Familia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/243027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kw9h8UT54e2y1uEz3NzQEsBtHSr.jpg'),
(122835, 8810, 'Uma Maldicao de Familia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/243028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xkXGCwJUF5DJNDogPYfvBaiH06u.jpg'),
(122836, 8810, 'Uma Maldicao de Familia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/243029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Aoyqfvcx5vQe3Sk8lE1qrJskVo.jpg'),
(122837, 8811, 'Uma Maldicao de Familia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/484771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hMQUIJwAzncS10ZtoQtIfq3ZNUe.jpg'),
(122838, 8811, 'Uma Maldicao de Familia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/484772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hMQUIJwAzncS10ZtoQtIfq3ZNUe.jpg'),
(122839, 8811, 'Uma Maldicao de Familia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/484773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hMQUIJwAzncS10ZtoQtIfq3ZNUe.jpg'),
(122840, 8811, 'Uma Maldicao de Familia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/484774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hMQUIJwAzncS10ZtoQtIfq3ZNUe.jpg'),
(122841, 8811, 'Uma Maldicao de Familia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/484775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hMQUIJwAzncS10ZtoQtIfq3ZNUe.jpg'),
(122842, 8811, 'Uma Maldicao de Familia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/484776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hMQUIJwAzncS10ZtoQtIfq3ZNUe.jpg'),
(122843, 8811, 'Uma Maldicao de Familia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/484777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hMQUIJwAzncS10ZtoQtIfq3ZNUe.jpg'),
(122844, 8811, 'Uma Maldicao de Familia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/484778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hMQUIJwAzncS10ZtoQtIfq3ZNUe.jpg'),
(122845, 8811, 'Uma Maldicao de Familia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/484779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hMQUIJwAzncS10ZtoQtIfq3ZNUe.jpg'),
(122846, 8811, 'Uma Maldicao de Familia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/484780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hMQUIJwAzncS10ZtoQtIfq3ZNUe.jpg'),
(122847, 8812, 'Vale o Escrito A Guerra do Jogo do Bicho S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/243013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vEPLxeWpMKPNXUGC4WdEIimiOgP.jpg'),
(122848, 8812, 'Vale o Escrito A Guerra do Jogo do Bicho S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/243014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vEPLxeWpMKPNXUGC4WdEIimiOgP.jpg'),
(122849, 8812, 'Vale o Escrito A Guerra do Jogo do Bicho S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/243015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vEPLxeWpMKPNXUGC4WdEIimiOgP.jpg'),
(122850, 8812, 'Vale o Escrito A Guerra do Jogo do Bicho S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/243016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vEPLxeWpMKPNXUGC4WdEIimiOgP.jpg'),
(122851, 8812, 'Vale o Escrito A Guerra do Jogo do Bicho S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/243017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vEPLxeWpMKPNXUGC4WdEIimiOgP.jpg'),
(122852, 8812, 'Vale o Escrito A Guerra do Jogo do Bicho S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/243018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vEPLxeWpMKPNXUGC4WdEIimiOgP.jpg'),
(122853, 8812, 'Vale o Escrito A Guerra do Jogo do Bicho S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/243019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vEPLxeWpMKPNXUGC4WdEIimiOgP.jpg'),
(122854, 8813, 'A Gangue de Bogota S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4jpuAHXWUSRbjQbSPOoTJZ6EEjl.jpg'),
(122855, 8813, 'A Gangue de Bogota S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4jpuAHXWUSRbjQbSPOoTJZ6EEjl.jpg'),
(122856, 8813, 'A Gangue de Bogota S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4jpuAHXWUSRbjQbSPOoTJZ6EEjl.jpg'),
(122857, 8813, 'A Gangue de Bogota S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4jpuAHXWUSRbjQbSPOoTJZ6EEjl.jpg'),
(122858, 8813, 'A Gangue de Bogota S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4jpuAHXWUSRbjQbSPOoTJZ6EEjl.jpg'),
(122859, 8813, 'A Gangue de Bogota S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4jpuAHXWUSRbjQbSPOoTJZ6EEjl.jpg'),
(122860, 8813, 'A Gangue de Bogota S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4jpuAHXWUSRbjQbSPOoTJZ6EEjl.jpg'),
(122861, 8813, 'A Gangue de Bogota S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4jpuAHXWUSRbjQbSPOoTJZ6EEjl.jpg'),
(122862, 8814, 'Acapulco Shore S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vM4cQleo6hdKtMaFtSeZZrPnUpS.jpg'),
(122863, 8814, 'Acapulco Shore S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vM4cQleo6hdKtMaFtSeZZrPnUpS.jpg'),
(122864, 8814, 'Acapulco Shore S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vM4cQleo6hdKtMaFtSeZZrPnUpS.jpg'),
(122865, 8814, 'Acapulco Shore S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vM4cQleo6hdKtMaFtSeZZrPnUpS.jpg'),
(122866, 8814, 'Acapulco Shore S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vM4cQleo6hdKtMaFtSeZZrPnUpS.jpg'),
(122867, 8814, 'Acapulco Shore S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vM4cQleo6hdKtMaFtSeZZrPnUpS.jpg'),
(122868, 8814, 'Acapulco Shore S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vM4cQleo6hdKtMaFtSeZZrPnUpS.jpg'),
(122869, 8814, 'Acapulco Shore S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vM4cQleo6hdKtMaFtSeZZrPnUpS.jpg'),
(122870, 8814, 'Acapulco Shore S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vM4cQleo6hdKtMaFtSeZZrPnUpS.jpg'),
(122871, 8814, 'Acapulco Shore S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vM4cQleo6hdKtMaFtSeZZrPnUpS.jpg'),
(122872, 8814, 'Acapulco Shore S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vM4cQleo6hdKtMaFtSeZZrPnUpS.jpg'),
(122873, 8814, 'Acapulco Shore S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vM4cQleo6hdKtMaFtSeZZrPnUpS.jpg'),
(122874, 8814, 'Acapulco Shore S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vM4cQleo6hdKtMaFtSeZZrPnUpS.jpg'),
(122875, 8815, 'Ferry A Serie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oQoeP7ggQhlVFfBn6G3VXe3uKKj.jpg'),
(122876, 8815, 'Ferry A Serie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLCLffx3NBByaXnUr3HxrqvesS1.jpg'),
(122877, 8815, 'Ferry A Serie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzFthmQ2RToNv0f9qxVSaJWmJFV.jpg'),
(122878, 8815, 'Ferry A Serie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oZ9wQjyTjU2RNkkuYcBWy4Cj2qT.jpg'),
(122879, 8815, 'Ferry A Serie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/isvsvMoKD4uGGx4Itdeha9nnOuU.jpg'),
(122880, 8815, 'Ferry A Serie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m0BjbThZEggnMMau2IZHp7BJRd6.jpg'),
(122881, 8815, 'Ferry A Serie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bFqgDbRul8rSUOHsaVdTPyPpOHm.jpg'),
(122882, 8815, 'Ferry A Serie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yKIp2u1NnO1aPXgrS8zWrfb7NNq.jpg'),
(122883, 8816, 'Romanceiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zaIEiga5ZOetQd9JhlmPoSFgMBD.jpg'),
(122884, 8816, 'Romanceiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jcAs3i1tbuo20ukwI2FMhj28IKf.jpg'),
(122885, 8816, 'Romanceiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/trRCdDTUxAbCJrydXMGuw0dkh6b.jpg'),
(122886, 8816, 'Romanceiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMLaRFC8xXUK7qhtYa4BPS3B4gV.jpg'),
(122887, 8816, 'Romanceiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ghOjmasd0NsPJWzrNcpQTESMUOO.jpg'),
(122888, 8816, 'Romanceiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybykmLFkIcTRZNG15NrjdGNKDV9.jpg'),
(122889, 8817, 'Samurai de Olhos Azuis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzM5aXXe3r8LJy6FUmP4FMygLS.jpg'),
(122890, 8817, 'Samurai de Olhos Azuis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tCqgG8GS6tWHwajtK7DgkkRan1f.jpg'),
(122891, 8817, 'Samurai de Olhos Azuis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t2ITiB2IndJlpRJFBzeytYpdwfv.jpg'),
(122892, 8817, 'Samurai de Olhos Azuis S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ohDOvfMB27n5ByFvihD7hyVJ4W4.jpg'),
(122893, 8817, 'Samurai de Olhos Azuis S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6us6Sq1OTNu5AmaIyWmLvOzOxRz.jpg'),
(122894, 8817, 'Samurai de Olhos Azuis S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zuMuy0tdQEyGFNqx9dBJj2sUanc.jpg'),
(122895, 8817, 'Samurai de Olhos Azuis S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/242431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xp5KpZ9apvlJKSt6r8MPaMXf72e.jpg'),
(122896, 8817, 'Samurai de Olhos Azuis S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/242432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97zdCvgAZrOaVTP7hYvuJp56rXe.jpg'),
(122897, 8818, 'Waco The Aftermath S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/242419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kiUJAeCrfHxttnDlgIyxy1weBft.jpg'),
(122898, 8818, 'Waco The Aftermath S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/242420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzxctFac6TXbpCTj52xfIH5SSPk.jpg'),
(122899, 8818, 'Waco The Aftermath S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/242421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyXGJu9uiPZrBsE8hU5c8xCkard.jpg'),
(122900, 8818, 'Waco The Aftermath S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/242422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oSisvkbFmV1yiqjrGPYpN0A0mOC.jpg'),
(122901, 8818, 'Waco The Aftermath S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/242423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ncbxkQcbj7QicS8kxo2W96plvDs.jpg'),
(122902, 8818, 'Waco The Aftermath S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/242424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7xaVVAAhMJhc5VIRpRa48DLsRru.jpg'),
(122903, 8819, 'Sword Art Online S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lRnsUV4U0ljSzKrO8t38mrS284K.jpg'),
(122904, 8819, 'Sword Art Online S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hiBynS5SFi0ltxFsaYtq39C9k76.jpg'),
(122905, 8819, 'Sword Art Online S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kxBO1gp72V4uBWLSACzL3RvEjQ9.jpg'),
(122906, 8819, 'Sword Art Online S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xg8AqSOPUaEJvaG8GcdPsCIT2MI.jpg'),
(122907, 8819, 'Sword Art Online S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4r89kn8VYl2NahtGAOS1V552w71.jpg'),
(122908, 8819, 'Sword Art Online S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zz9Zw04cvobbS5Bf9MYKxptk9aQ.jpg'),
(122909, 8819, 'Sword Art Online S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iWGUPY39gmNrMmKAfkP8dalEVyz.jpg'),
(122910, 8819, 'Sword Art Online S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmajeWlA7OCpIT2H6JPXIo9Lwdw.jpg'),
(122911, 8819, 'Sword Art Online S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t2GBif2MdqYhZvQx755Y9xunQkF.jpg'),
(122912, 8819, 'Sword Art Online S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2A6GRQT5uDJhq9vc46fISn0CNzm.jpg'),
(122913, 8819, 'Sword Art Online S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tULdNWI4qoToSyO5PUEiwRWncAh.jpg'),
(122914, 8819, 'Sword Art Online S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k8rzVr0A4jtsskjRMLEM5NNlqfr.jpg'),
(122915, 8819, 'Sword Art Online S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ooI4fJvu4eUZgvRTQx1v3uzUTLU.jpg'),
(122916, 8819, 'Sword Art Online S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/239886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fcnSuM0WQyKODZ6BD1yUGJpDbIf.jpg'),
(122917, 8819, 'Sword Art Online S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/239887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sMmzH8KpSNV9dGEQ3LP1Xzeokfo.jpg'),
(122918, 8819, 'Sword Art Online S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/239888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/grHJC5Gk7fuk8jywVhs7UYXLiLG.jpg'),
(122919, 8819, 'Sword Art Online S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/239889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b702zYjB82kk0APiyCCYBn7fGJU.jpg'),
(122920, 8819, 'Sword Art Online S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/239890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kP5JiBHMtIuiTcntCZUe9ERzAYj.jpg'),
(122921, 8819, 'Sword Art Online S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/239891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMcIqPhChoBMpzqXG4CIUuEjKR3.jpg'),
(122922, 8819, 'Sword Art Online S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/239892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cOpNhZSFZv2ocUaGfZajDlHz7NK.jpg'),
(122923, 8819, 'Sword Art Online S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/239893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9AZUXEji3uy6yu7rtnb2iRuapYm.jpg'),
(122924, 8819, 'Sword Art Online S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/239894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d3Bl4GEYdM6rLO2BYoNz2esIAD7.jpg'),
(122925, 8819, 'Sword Art Online S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/239895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2OrvGXAS28CGhEs96FCAjkHDAUJ.jpg'),
(122926, 8819, 'Sword Art Online S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/239896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3hdDhZFnQ524Tjs5ehiyrDzXJjA.jpg'),
(122927, 8819, 'Sword Art Online S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/239897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oPuUnWxMttvfVXv99aVgXO3qxpV.jpg'),
(122928, 8820, 'Sword Art Online S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7OUSXOcIs9nzdLmLz0Bwdfhrm85.jpg'),
(122929, 8820, 'Sword Art Online S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1sCbBCi1nxPqVhowB4PvH9SJPZr.jpg'),
(122930, 8820, 'Sword Art Online S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uYykJcutnYPW8O7LAs0T7MvjXS7.jpg'),
(122931, 8820, 'Sword Art Online S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eJjflgwMR7kcUTOrolwqAlppb4f.jpg'),
(122932, 8820, 'Sword Art Online S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oJ9RjaDYoyky1neZvAWQRZLPA9E.jpg'),
(122933, 8820, 'Sword Art Online S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Q0KetmCeYoWSimDuRp5aQ1jWEJ.jpg'),
(122934, 8820, 'Sword Art Online S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Woe1gkRDZtZztJu1Spai6dUqDU.jpg'),
(122935, 8820, 'Sword Art Online S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3htNh1oP2IZjXTf2ej2H4ZynxKW.jpg'),
(122936, 8820, 'Sword Art Online S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ueDp5eL3maMX8ZzTcHUcOeccnbv.jpg'),
(122937, 8820, 'Sword Art Online S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vs3DpifrmbTGuEEzLDSXAqlhAtS.jpg'),
(122938, 8820, 'Sword Art Online S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/chqwmSxOydZpXiad2BMCsYrtUK0.jpg'),
(122939, 8820, 'Sword Art Online S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fH9uKZtzgbsTcIUcjlSOuNCVIoM.jpg'),
(122940, 8820, 'Sword Art Online S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rZCPOKK3iWsROkGe66IideIFYSl.jpg'),
(122941, 8820, 'Sword Art Online S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/239911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMF65VcMIJiUBaJnb0Flq6CZroz.jpg'),
(122942, 8820, 'Sword Art Online S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/239912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2e9oCP375GrV99oioySGjl5CVz0.jpg'),
(122943, 8820, 'Sword Art Online S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/239913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mYSSD9v7EGqPYOapdbIuNSUkcoA.jpg'),
(122944, 8820, 'Sword Art Online S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/239914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vIqsyFzN4IPJF0xTbmfB3hIYK7d.jpg'),
(122945, 8820, 'Sword Art Online S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/239915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9AVzrSS0syPcLXakRPROGF2REOA.jpg'),
(122946, 8820, 'Sword Art Online S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/239916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQZ4OVlfnc1tp1EZrysc7XiA29r.jpg'),
(122947, 8820, 'Sword Art Online S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/239917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1qwzt6MCPEDZxBbY1DIG8rcOqyp.jpg'),
(122948, 8820, 'Sword Art Online S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/239918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ifdlJmiQmUelFhTDvl56ur4QpyP.jpg'),
(122949, 8820, 'Sword Art Online S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/239919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwKmF4mpen4czxhWoUDEfJCrbSm.jpg'),
(122950, 8820, 'Sword Art Online S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/239920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/elqZmxx3KnUFRvzeXJ1Z1iMeABE.jpg'),
(122951, 8820, 'Sword Art Online S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/239921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gt2yB4qmF96FQHSwbBEuYwTUon1.jpg'),
(122952, 8821, 'Arvolandia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUZq5cUTSt7MkZ6URHEfQCjLC2A.jpg'),
(122953, 8821, 'Arvolandia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUZq5cUTSt7MkZ6URHEfQCjLC2A.jpg'),
(122954, 8821, 'Arvolandia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ifQ4pIiblYrr7AGQxT0aR8exE1o.jpg'),
(122955, 8821, 'Arvolandia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ifQ4pIiblYrr7AGQxT0aR8exE1o.jpg'),
(122956, 8821, 'Arvolandia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qMxdKAF72iXk7SMdJiMJBB930KD.jpg'),
(122957, 8821, 'Arvolandia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qMxdKAF72iXk7SMdJiMJBB930KD.jpg'),
(122958, 8821, 'Arvolandia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zQy24E60E17LmyHZMFQEPgAdpgP.jpg'),
(122959, 8821, 'Arvolandia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zQy24E60E17LmyHZMFQEPgAdpgP.jpg'),
(122960, 8821, 'Arvolandia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/szFvhib3V0KOSIU5XDzbQJfsuw0.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(122961, 8821, 'Arvolandia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/szFvhib3V0KOSIU5XDzbQJfsuw0.jpg'),
(122962, 8821, 'Arvolandia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jlF5oqxl3UsiR759zBw7fiOXQG8.jpg'),
(122963, 8821, 'Arvolandia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jlF5oqxl3UsiR759zBw7fiOXQG8.jpg'),
(122964, 8821, 'Arvolandia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1IbRtR6f8xDtpnpn2quNIjmsz9L.jpg'),
(122965, 8821, 'Arvolandia S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/239871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1IbRtR6f8xDtpnpn2quNIjmsz9L.jpg'),
(122966, 8821, 'Arvolandia S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/239872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oz2Q7VhgUlX45ilwleSp6Qtwnn1.jpg'),
(122967, 8822, 'Erin e Aaron S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fIsVjA6u4QiQlB9pBhIdsp8difS.jpg'),
(122968, 8822, 'Erin e Aaron S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iQiqSg1iyRuaiuiWLYKOnYDfLQM.jpg'),
(122969, 8822, 'Erin e Aaron S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aXmhfjR3uDYezG5oeRonehj7bVO.jpg'),
(122970, 8822, 'Erin e Aaron S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/88TgmsQPlDv1GC732zBAtdHzKDC.jpg'),
(122971, 8822, 'Erin e Aaron S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9TOCUz8RYGGK7Kpc7zEsllOtgFK.jpg'),
(122972, 8822, 'Erin e Aaron S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iTse3JfEaHjXBghf7ABEelwDjPr.jpg'),
(122973, 8822, 'Erin e Aaron S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ja17i3Ct5XTH0kPCPtiNoe00L6W.jpg'),
(122974, 8822, 'Erin e Aaron S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a9x0298fBHwToTK6QjlvhsB9OWE.jpg'),
(122975, 8822, 'Erin e Aaron S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ueVGS5ARBGzMzlctAISVzV6toY.jpg'),
(122976, 8822, 'Erin e Aaron S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oDTkecje9GXDe5eYKhUcVhiEnjg.jpg'),
(122977, 8822, 'Erin e Aaron S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vyDML8M3JxkqAriG8gvWGYYyhWy.jpg'),
(122978, 8822, 'Erin e Aaron S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/in6HyetubDzufPym8oLJgrDFxqz.jpg'),
(122979, 8822, 'Erin e Aaron S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/44QCq45NAugdXyVEFpxbVnLogSr.jpg'),
(122980, 8823, 'Garotas Malvadas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aU0RDNdfj0j98S7FAXyLNa4wVYX.jpg'),
(122981, 8823, 'Garotas Malvadas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1a7aF4fFme1CiyPOkawnq6l4uLZ.jpg'),
(122982, 8823, 'Garotas Malvadas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2UAmGn9NvlOjYGRiuh99k0dWmwz.jpg'),
(122983, 8823, 'Garotas Malvadas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ACEXyHdk5ajoBUMzqWovVYGy4v.jpg'),
(122984, 8823, 'Garotas Malvadas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/NqCpOWGTZqXIcaWpeDbs8wgewD.jpg'),
(122985, 8823, 'Garotas Malvadas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bBj9O1V2w7oZUFTiXjJ2VCKW15b.jpg'),
(122986, 8823, 'Garotas Malvadas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iGeyAl3VwEvMLRqxFIEX9G7xy3v.jpg'),
(122987, 8823, 'Garotas Malvadas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uU86Y4G9pg9TDWxvAB9MRx9HAH8.jpg'),
(122988, 8824, 'Garotas Malvadas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/464349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHrXnEQiwf1N65oVMmKrC6ra0L.jpg'),
(122989, 8824, 'Garotas Malvadas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/464350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHrXnEQiwf1N65oVMmKrC6ra0L.jpg'),
(122990, 8824, 'Garotas Malvadas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/464351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHrXnEQiwf1N65oVMmKrC6ra0L.jpg'),
(122991, 8824, 'Garotas Malvadas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/464352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHrXnEQiwf1N65oVMmKrC6ra0L.jpg'),
(122992, 8824, 'Garotas Malvadas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/464353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHrXnEQiwf1N65oVMmKrC6ra0L.jpg'),
(122993, 8824, 'Garotas Malvadas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/464354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHrXnEQiwf1N65oVMmKrC6ra0L.jpg'),
(122994, 8824, 'Garotas Malvadas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/464355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHrXnEQiwf1N65oVMmKrC6ra0L.jpg'),
(122995, 8824, 'Garotas Malvadas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/464356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHrXnEQiwf1N65oVMmKrC6ra0L.jpg'),
(122996, 8824, 'Garotas Malvadas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/464357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHrXnEQiwf1N65oVMmKrC6ra0L.jpg'),
(122997, 8824, 'Garotas Malvadas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/464358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlHrXnEQiwf1N65oVMmKrC6ra0L.jpg'),
(122998, 8825, 'Homem Chorao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKMsIvqGYN8vs6AzOVdW6yejtHm.jpg'),
(122999, 8825, 'Homem Chorao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKMsIvqGYN8vs6AzOVdW6yejtHm.jpg'),
(123000, 8825, 'Homem Chorao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKMsIvqGYN8vs6AzOVdW6yejtHm.jpg'),
(123001, 8825, 'Homem Chorao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKMsIvqGYN8vs6AzOVdW6yejtHm.jpg'),
(123002, 8825, 'Homem Chorao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKMsIvqGYN8vs6AzOVdW6yejtHm.jpg'),
(123003, 8825, 'Homem Chorao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKMsIvqGYN8vs6AzOVdW6yejtHm.jpg'),
(123004, 8825, 'Homem Chorao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKMsIvqGYN8vs6AzOVdW6yejtHm.jpg'),
(123005, 8825, 'Homem Chorao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKMsIvqGYN8vs6AzOVdW6yejtHm.jpg'),
(123006, 8825, 'Homem Chorao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKMsIvqGYN8vs6AzOVdW6yejtHm.jpg'),
(123007, 8825, 'Homem Chorao S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKMsIvqGYN8vs6AzOVdW6yejtHm.jpg'),
(123008, 8825, 'Homem Chorao S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKMsIvqGYN8vs6AzOVdW6yejtHm.jpg'),
(123009, 8826, 'Homem Chorao S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/478014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKMsIvqGYN8vs6AzOVdW6yejtHm.jpg'),
(123010, 8826, 'Homem Chorao S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/478015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKMsIvqGYN8vs6AzOVdW6yejtHm.jpg'),
(123011, 8826, 'Homem Chorao S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/478016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKMsIvqGYN8vs6AzOVdW6yejtHm.jpg'),
(123012, 8826, 'Homem Chorao S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/478017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKMsIvqGYN8vs6AzOVdW6yejtHm.jpg'),
(123013, 8826, 'Homem Chorao S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/478018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKMsIvqGYN8vs6AzOVdW6yejtHm.jpg'),
(123014, 8826, 'Homem Chorao S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/478019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKMsIvqGYN8vs6AzOVdW6yejtHm.jpg'),
(123015, 8826, 'Homem Chorao S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/478020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKMsIvqGYN8vs6AzOVdW6yejtHm.jpg'),
(123016, 8826, 'Homem Chorao S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/478021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKMsIvqGYN8vs6AzOVdW6yejtHm.jpg'),
(123017, 8826, 'Homem Chorao S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/478022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKMsIvqGYN8vs6AzOVdW6yejtHm.jpg'),
(123018, 8827, 'Homens da Lei: Bass Reeves S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a5CeIzvtzoFddk4Ch6X6Fc18FGb.jpg'),
(123019, 8827, 'Homens da Lei: Bass Reeves S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lPzGTUMF0ftSNqCkqGXdM0ASMDh.jpg'),
(123020, 8827, 'Homens da Lei: Bass Reeves S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5YvjqykQe2ZZK1C6qBXrM9EG1i.jpg'),
(123021, 8827, 'Homens da Lei: Bass Reeves S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5YvjqykQe2ZZK1C6qBXrM9EG1i.jpg'),
(123022, 8827, 'Homens da Lei: Bass Reeves S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5YvjqykQe2ZZK1C6qBXrM9EG1i.jpg'),
(123023, 8827, 'Homens da Lei: Bass Reeves S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5YvjqykQe2ZZK1C6qBXrM9EG1i.jpg'),
(123024, 8827, 'Homens da Lei: Bass Reeves S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5YvjqykQe2ZZK1C6qBXrM9EG1i.jpg'),
(123025, 8827, 'Homens da Lei: Bass Reeves S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5YvjqykQe2ZZK1C6qBXrM9EG1i.jpg'),
(123026, 8828, 'Maca e Cebolinha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iKNIwgItTldRD5D1bF2MY3y8ZhN.jpg'),
(123027, 8828, 'Maca e Cebolinha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q3kx4EqZfLsKiqeuOA2HLCLnVd3.jpg'),
(123028, 8828, 'Maca e Cebolinha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rd2ImlupaQdzWymlrmaWTY9ZklQ.jpg'),
(123029, 8828, 'Maca e Cebolinha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wCn1zx7huvoXIBcrn5XxPBE1nYw.jpg'),
(123030, 8828, 'Maca e Cebolinha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1fDn2b7uMS4xGqyYarnvFK5JQy4.jpg'),
(123031, 8828, 'Maca e Cebolinha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MiuxrAHjXnUEuUkVQL8OojY1rI.jpg'),
(123032, 8828, 'Maca e Cebolinha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pzY65RohmlWXSVUSXsPu2kRrzvv.jpg'),
(123033, 8828, 'Maca e Cebolinha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZVvckpb413gro8j8BAv3XR0wvB.jpg'),
(123034, 8828, 'Maca e Cebolinha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wzvqax4sBVJLeRkzuvG6boYmUKc.jpg'),
(123035, 8828, 'Maca e Cebolinha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3TIPMbCMKM1OFSECN1pIyJwIVnD.jpg'),
(123036, 8828, 'Maca e Cebolinha S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pcsSgHjGnr6RK6Tw8L0Z9EPfs9Z.jpg'),
(123037, 8828, 'Maca e Cebolinha S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQTkcMNb8bkqgVFx2BKR279Phf0.jpg'),
(123038, 8828, 'Maca e Cebolinha S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wK0rMYACliXeKV5g0c2ovDmBCu5.jpg'),
(123039, 8828, 'Maca e Cebolinha S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/239799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aKJoiR1aQTw8NnLWC31frPIAUez.jpg'),
(123040, 8828, 'Maca e Cebolinha S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/239800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ua2gWGX6f2CGN0idcAeuDCmcNkk.jpg'),
(123041, 8828, 'Maca e Cebolinha S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/239801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xqbyjbuTljvgcikQMyn2NDC4YjD.jpg'),
(123042, 8828, 'Maca e Cebolinha S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/239802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7YLZimrmc4eZ5TZPtAtWuaVjrrc.jpg'),
(123043, 8828, 'Maca e Cebolinha S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/239803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aaM2r1ORVtpafsJ0Mu6dwx1JgYn.jpg'),
(123044, 8828, 'Maca e Cebolinha S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/239804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gA9iPQqwVwh2ITNoGXo1wRXA4jG.jpg'),
(123045, 8828, 'Maca e Cebolinha S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/239805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w1SzJjAQaiE5lcts9vcl0wZvpRB.jpg'),
(123046, 8828, 'Maca e Cebolinha S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/239806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/93nrgMjPgtnO4415vypsGvvjqQd.jpg'),
(123047, 8828, 'Maca e Cebolinha S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/239807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2OP7IFdB6LVn0piM5MMOfG8YCit.jpg'),
(123048, 8828, 'Maca e Cebolinha S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/239808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9HrhZAPEK33GayahcvGqHWpwKDV.jpg'),
(123049, 8828, 'Maca e Cebolinha S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/239809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zpI3Db9uV4vFmC3EvDYwte5G8Oy.jpg'),
(123050, 8828, 'Maca e Cebolinha S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/239810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wdnIh5UUls3HqOyXfQuZdMFvGfB.jpg'),
(123051, 8828, 'Maca e Cebolinha S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/239811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i8pTfnJLtawvxWa2Su4VUx5tJqc.jpg'),
(123052, 8828, 'Maca e Cebolinha S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/239812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ltsrqlMOs0JysQWTMmkE5EN2voj.jpg'),
(123053, 8828, 'Maca e Cebolinha S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/239813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sUOSEEdg6fR7Y5AmAdpYYQAhDyi.jpg'),
(123054, 8828, 'Maca e Cebolinha S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/239814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bzOMQxm7LVh7jKqGJvokqByrEDY.jpg'),
(123055, 8828, 'Maca e Cebolinha S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/239815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mRO7CIFlSBvEDiOIxO4sL5sw9HZ.jpg'),
(123056, 8828, 'Maca e Cebolinha S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/239816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVOttwabgYAnwUtslGS4AT5hAEs.jpg'),
(123057, 8828, 'Maca e Cebolinha S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/239817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jtmuQDbhdPEwi11mK8WcA8o3br0.jpg'),
(123058, 8828, 'Maca e Cebolinha S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/239818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eGL07xIEu8Pz9uDBN2hdMnUEZ4Q.jpg'),
(123059, 8828, 'Maca e Cebolinha S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/239819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4LbDxBG24mIWqkrZqWDOM9xCDiN.jpg'),
(123060, 8828, 'Maca e Cebolinha S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/239820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ZOINeMX8IwGGmCvcNyZPg9ETt0.jpg'),
(123061, 8828, 'Maca e Cebolinha S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/239821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5GNukXEtmBuIshdj8z6GW6793K4.jpg'),
(123062, 8828, 'Maca e Cebolinha S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/239822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8byu5jbd0o9LSnwcSBxyaqaVUD1.jpg'),
(123063, 8828, 'Maca e Cebolinha S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/239823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/whAA7G4du1lvMUp0WPxUo1bfBNf.jpg'),
(123064, 8828, 'Maca e Cebolinha S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/239824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZb4doi3zg5QbYzzFs8dVDO1qw2.jpg'),
(123065, 8828, 'Maca e Cebolinha S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/239825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cRJAgbvG20t3QttX6xERKbwHTbC.jpg'),
(123066, 8829, 'Uma Dose Diaria de Sol S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rT8xy03NRf9lWARxZlFatFtisIp.jpg'),
(123067, 8829, 'Uma Dose Diaria de Sol S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jw9PJ5xd9P0Y0pHgvlOa0DvD9Ha.jpg'),
(123068, 8829, 'Uma Dose Diaria de Sol S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6gLn032Fljg7EMRiRWCd43bHBsY.jpg'),
(123069, 8829, 'Uma Dose Diaria de Sol S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xwcjtR7xHpGURd0wUAZbpdbKg5k.jpg'),
(123070, 8829, 'Uma Dose Diaria de Sol S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AgyHOte7hZmaoszTyMp4JouyUk.jpg'),
(123071, 8829, 'Uma Dose Diaria de Sol S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w19RrPFyNrV3zumw6R57XvR870G.jpg'),
(123072, 8829, 'Uma Dose Diaria de Sol S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ab4uOUpVM5qBqfkHZYStQUAgFf8.jpg'),
(123073, 8829, 'Uma Dose Diaria de Sol S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mvNOl2vlFpfsYQGJ102IpjWZ6Yr.jpg'),
(123074, 8829, 'Uma Dose Diaria de Sol S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6UyA8x43ytx4Gg0uaZmWgkxglsI.jpg'),
(123075, 8829, 'Uma Dose Diaria de Sol S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zQmammnTf9pnVwSyBTEDChONBZG.jpg'),
(123076, 8829, 'Uma Dose Diaria de Sol S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zW6H9wYFlRx6SbTrJCF1nauEH1f.jpg'),
(123077, 8829, 'Uma Dose Diaria de Sol S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kbY0Ozsd0ear1KEOlasRNZOjyqg.jpg'),
(123078, 8830, 'Beat Bugs S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123079, 8830, 'Beat Bugs S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123080, 8830, 'Beat Bugs S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123081, 8830, 'Beat Bugs S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123082, 8830, 'Beat Bugs S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123083, 8830, 'Beat Bugs S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123084, 8830, 'Beat Bugs S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123085, 8830, 'Beat Bugs S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123086, 8830, 'Beat Bugs S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123087, 8830, 'Beat Bugs S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123088, 8830, 'Beat Bugs S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123089, 8830, 'Beat Bugs S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123090, 8830, 'Beat Bugs S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123091, 8831, 'Beat Bugs S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123092, 8831, 'Beat Bugs S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123093, 8831, 'Beat Bugs S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123094, 8831, 'Beat Bugs S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123095, 8831, 'Beat Bugs S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123096, 8831, 'Beat Bugs S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123097, 8831, 'Beat Bugs S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123098, 8831, 'Beat Bugs S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123099, 8831, 'Beat Bugs S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123100, 8831, 'Beat Bugs S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123101, 8831, 'Beat Bugs S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123102, 8831, 'Beat Bugs S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123103, 8831, 'Beat Bugs S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123104, 8832, 'Beat Bugs S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123105, 8832, 'Beat Bugs S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123106, 8832, 'Beat Bugs S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123107, 8832, 'Beat Bugs S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123108, 8832, 'Beat Bugs S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123109, 8832, 'Beat Bugs S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123110, 8832, 'Beat Bugs S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123111, 8832, 'Beat Bugs S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123112, 8832, 'Beat Bugs S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123113, 8832, 'Beat Bugs S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123114, 8832, 'Beat Bugs S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123115, 8832, 'Beat Bugs S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123116, 8832, 'Beat Bugs S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123117, 8832, 'Beat Bugs S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/239761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123118, 8832, 'Beat Bugs S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/239762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123119, 8832, 'Beat Bugs S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/239763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123120, 8832, 'Beat Bugs S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/239764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123121, 8832, 'Beat Bugs S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/239765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123122, 8832, 'Beat Bugs S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/239766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123123, 8832, 'Beat Bugs S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/239767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123124, 8832, 'Beat Bugs S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/239768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123125, 8832, 'Beat Bugs S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/239769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123126, 8832, 'Beat Bugs S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/239770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123127, 8832, 'Beat Bugs S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/239771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123128, 8832, 'Beat Bugs S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/239772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123129, 8832, 'Beat Bugs S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/239773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVC1dtvG9CqWSkxixoj8R5X7w1b.jpg'),
(123130, 8833, 'Gigantossauro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y0uRclYd2RP2RBpnkoLzv13g3QT.jpg'),
(123131, 8833, 'Gigantossauro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jnXAR3GDZfXGHy7O2TNZd6kKtaK.jpg'),
(123132, 8833, 'Gigantossauro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123133, 8833, 'Gigantossauro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pTCltWnyVyHpo4CPmF1V3Y1OAMv.jpg'),
(123134, 8833, 'Gigantossauro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123135, 8833, 'Gigantossauro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6AwHs4RPKCp64NpP0rdSBFl3JQS.jpg'),
(123136, 8833, 'Gigantossauro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q2RcYEetJVPJU0QyrTtBlTwZIXy.jpg'),
(123137, 8833, 'Gigantossauro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjvvudltbgv8QxqX86TSjVH5Rzz.jpg'),
(123138, 8833, 'Gigantossauro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bWpLLegXjQBbVnovEJpArmLTIXY.jpg'),
(123139, 8833, 'Gigantossauro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shRv4ZyUTdItDAHBY8alMSgxI5f.jpg'),
(123140, 8833, 'Gigantossauro S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3JW8PAE7dSDD0jPrTptFAGjzAN3.jpg'),
(123141, 8833, 'Gigantossauro S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123142, 8833, 'Gigantossauro S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jWy4J8DgGSdPr0336wfmbSsLij0.jpg'),
(123143, 8833, 'Gigantossauro S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/239654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123144, 8833, 'Gigantossauro S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/239655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zrUuQMa4tqOIUWn7f6vivjTI53Y.jpg'),
(123145, 8833, 'Gigantossauro S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/239656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123146, 8833, 'Gigantossauro S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/239657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7HKInaAu0Vu5kO1TbuQBesNcIsT.jpg'),
(123147, 8833, 'Gigantossauro S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/239658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123148, 8833, 'Gigantossauro S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/239659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3IpZm7gWLAp4RCvIjeTEhoCSWI.jpg'),
(123149, 8833, 'Gigantossauro S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/239660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ekmZ5QrUmSsMCD3mZZ5EDiQv91V.jpg'),
(123150, 8833, 'Gigantossauro S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/239661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xR10VaCgjW9WVJQv2N3fI5j894L.jpg'),
(123151, 8833, 'Gigantossauro S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/239662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123152, 8833, 'Gigantossauro S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/239663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fnCHfhWzvmxAfEKCzRK3KRR1tZ7.jpg'),
(123153, 8833, 'Gigantossauro S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/239664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tCdO9qWhLCq9XFg85FJF5CQHT1C.jpg'),
(123154, 8833, 'Gigantossauro S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/239665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/KujABqINXUCS6Xr5aO8aopwols.jpg'),
(123155, 8833, 'Gigantossauro S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/239666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123156, 8834, 'Gigantossauro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123157, 8834, 'Gigantossauro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123158, 8834, 'Gigantossauro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123159, 8834, 'Gigantossauro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123160, 8834, 'Gigantossauro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123161, 8834, 'Gigantossauro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123162, 8834, 'Gigantossauro S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123163, 8834, 'Gigantossauro S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123164, 8834, 'Gigantossauro S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123165, 8834, 'Gigantossauro S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123166, 8834, 'Gigantossauro S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123167, 8834, 'Gigantossauro S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123168, 8834, 'Gigantossauro S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123169, 8834, 'Gigantossauro S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/239680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123170, 8834, 'Gigantossauro S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/239681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123171, 8834, 'Gigantossauro S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/239682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123172, 8834, 'Gigantossauro S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/239683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123173, 8834, 'Gigantossauro S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/239684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123174, 8834, 'Gigantossauro S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/239685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123175, 8834, 'Gigantossauro S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/239686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123176, 8834, 'Gigantossauro S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/239687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123177, 8834, 'Gigantossauro S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/239688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123178, 8834, 'Gigantossauro S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/239689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123179, 8834, 'Gigantossauro S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/239690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123180, 8834, 'Gigantossauro S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/239691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123181, 8834, 'Gigantossauro S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/239692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123182, 8835, 'Gigantossauro S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123183, 8835, 'Gigantossauro S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123184, 8835, 'Gigantossauro S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123185, 8835, 'Gigantossauro S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123186, 8835, 'Gigantossauro S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123187, 8835, 'Gigantossauro S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123188, 8835, 'Gigantossauro S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123189, 8835, 'Gigantossauro S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123190, 8835, 'Gigantossauro S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123191, 8835, 'Gigantossauro S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123192, 8835, 'Gigantossauro S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123193, 8835, 'Gigantossauro S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123194, 8835, 'Gigantossauro S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123195, 8835, 'Gigantossauro S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/239706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123196, 8835, 'Gigantossauro S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/239707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123197, 8835, 'Gigantossauro S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/239708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123198, 8835, 'Gigantossauro S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/239709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123199, 8835, 'Gigantossauro S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/239710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123200, 8835, 'Gigantossauro S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/239711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123201, 8835, 'Gigantossauro S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/239712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123202, 8835, 'Gigantossauro S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/239713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123203, 8835, 'Gigantossauro S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/239714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123204, 8835, 'Gigantossauro S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/239715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123205, 8835, 'Gigantossauro S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/239716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123206, 8835, 'Gigantossauro S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/239717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123207, 8835, 'Gigantossauro S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/239718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l3LxmCdyZCg7PlPaeID9CpHYKji.jpg'),
(123208, 8836, 'JFK One Day In America S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oGR7xbaFiNJ0jsCIlTcA0uDCrJI.jpg'),
(123209, 8836, 'JFK One Day In America S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o1Yya1JKTz11hSlShP8bD2h4j4Y.jpg'),
(123210, 8836, 'JFK One Day In America S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jWq7HjpggQ6TUKMNHuWkL7i0zaK.jpg'),
(123211, 8837, 'Oswaldo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/muZ8CNuCtiWViWJAiAsoz9fzUnm.jpg'),
(123212, 8837, 'Oswaldo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iX0rqqkuATa0sAfF5siiKE8NUE4.jpg'),
(123213, 8837, 'Oswaldo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bSvYLE5RxOeFtCag16unES0o2Kj.jpg'),
(123214, 8837, 'Oswaldo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzN4DYGm2JFSUx4ej7VeFy5lQfG.jpg'),
(123215, 8837, 'Oswaldo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lHxcvpStutdqMFyxo9qooK4YY7i.jpg'),
(123216, 8837, 'Oswaldo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yOvQqTpCiZVvXs1RnEMdHlxrQhl.jpg'),
(123217, 8837, 'Oswaldo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6IiKj7rrDL24ZUzV5fUKUudHA3v.jpg'),
(123218, 8837, 'Oswaldo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qqXLyYzEKd20xOYAaQaOAnvqTzm.jpg'),
(123219, 8837, 'Oswaldo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zb8RAsQYwmgjTHlduNExysGS2j4.jpg'),
(123220, 8837, 'Oswaldo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eQfHpgmIuHtshWu8YB9HelT6k6a.jpg'),
(123221, 8837, 'Oswaldo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kUsd8fOmfP9qHmoMpIN65MOz742.jpg'),
(123222, 8837, 'Oswaldo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5DP1TJsUSpkFoERZyKZFMT9isTW.jpg'),
(123223, 8837, 'Oswaldo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A954qOwuL77oYshExc9BdmaUMuQ.jpg'),
(123224, 8838, 'Oswaldo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cajmvThSLAYOJVUhoUx75PVqQgY.jpg'),
(123225, 8838, 'Oswaldo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vHYtUD1pMXcwawE1xxp2ACmesRx.jpg'),
(123226, 8838, 'Oswaldo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shEbEumiRxtVQIypA1CbNK0fyE3.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(123227, 8838, 'Oswaldo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xYk5R2tkXoh1PjLDQLP6n1GfA9V.jpg'),
(123228, 8838, 'Oswaldo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8Z1rYjucZMHR3o73G07xJm4qUz.jpg'),
(123229, 8838, 'Oswaldo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/653T1M2lSZNxlgas4xyZVVh9FBn.jpg'),
(123230, 8838, 'Oswaldo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eSBbWhz5NV3KN0kq1VVXdOD9k1l.jpg'),
(123231, 8838, 'Oswaldo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A1hmeKovF9Cvkdnb1XPMYNuZxeC.jpg'),
(123232, 8838, 'Oswaldo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/igQcLrsCecLug26JYtWzOzmce9p.jpg'),
(123233, 8838, 'Oswaldo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gN17BbIzmU85IsVzKWKd4EYm7UW.jpg'),
(123234, 8838, 'Oswaldo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1hG8T7C9VZfqkd3cJ8G6Z0E80Sn.jpg'),
(123235, 8838, 'Oswaldo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gb2Is8BLSFkQ2a2CZFrS6zt3gcC.jpg'),
(123236, 8838, 'Oswaldo S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e4dRua5kYcUv3eX08v09kumwmr6.jpg'),
(123237, 8839, 'Oswaldo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jqxHxFXoxM5Yx0EYHr5M521wV0Q.jpg'),
(123238, 8839, 'Oswaldo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u0deG8ndMuGhoYtmSI87JGUuHvz.jpg'),
(123239, 8839, 'Oswaldo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7OaqDGPJeiVg077BZs3M4I81sr.jpg'),
(123240, 8839, 'Oswaldo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1kwjseaMldlZXRzQOwxXVua7W2y.jpg'),
(123241, 8839, 'Oswaldo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bYRKGGpDJSkwDfFfBoLp2Hlu4S2.jpg'),
(123242, 8839, 'Oswaldo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e65Xw3TWQe8CgunW430dmBpJPl.jpg'),
(123243, 8839, 'Oswaldo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jLNcVpce6lhEyHHEfQSrpcfarat.jpg'),
(123244, 8839, 'Oswaldo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iFigZfgFTrtSk6y7podrTFvT0o1.jpg'),
(123245, 8839, 'Oswaldo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nGNXN1H3ibeTqLjsX5Ai0p4YBPB.jpg'),
(123246, 8839, 'Oswaldo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b6ZbfgQFzaoG6ZnmfI4N3yNgUiC.jpg'),
(123247, 8839, 'Oswaldo S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8eL9ZBNm5qHmNrXlP1D7v5YD8R5.jpg'),
(123248, 8839, 'Oswaldo S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/alhwpboVZyTezFwMUfcwQGbSiwX.jpg'),
(123249, 8839, 'Oswaldo S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wj63XqARg2o7bYScqgfkg57CxfR.jpg'),
(123250, 8840, 'Oswaldo S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eIuVSxVWOuTbblxj57ldELKj3Zn.jpg'),
(123251, 8840, 'Oswaldo S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/faaKUFMYJ5Xa1a2fVwNo1l8xyfr.jpg'),
(123252, 8840, 'Oswaldo S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/MaIaRp7mgsRntjHbUZ4vKjoKPc.jpg'),
(123253, 8840, 'Oswaldo S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/msz4Zb74nnHuzQoE5E3Y9Pceysi.jpg'),
(123254, 8840, 'Oswaldo S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nKAxOwoO139oLOY3wADycxl03sO.jpg'),
(123255, 8840, 'Oswaldo S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a9KtLqLmHkzLncFdX9N7iiNh2tj.jpg'),
(123256, 8840, 'Oswaldo S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ylUWvRDtz8BIM7LULEO1vcJ6vgQ.jpg'),
(123257, 8840, 'Oswaldo S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yhzn2lAr6G9tGxoPgJJV4Zft9oy.jpg'),
(123258, 8840, 'Oswaldo S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3SGGYZq05hjFmJDSL7ipE5buZM9.jpg'),
(123259, 8840, 'Oswaldo S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m3lseW4b874aSqUS6Opeo5QFMBL.jpg'),
(123260, 8840, 'Oswaldo S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2V9NxbbGC6XI0JyP6Mc3eGceBIN.jpg'),
(123261, 8840, 'Oswaldo S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mggXUdHF9RlohIaLCdTAkrMmSfY.jpg'),
(123262, 8840, 'Oswaldo S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dqED0hrc2ZXu8PX1YUswLIqgucs.jpg'),
(123263, 8841, 'Segredos do Miss America S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gViolxXjeaZe9llIUyuZ6Kbq7Wr.jpg'),
(123264, 8841, 'Segredos do Miss America S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dVZAugHlyX0cL2SHrdjpYXk28mR.jpg'),
(123265, 8841, 'Segredos do Miss America S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bmBPRhXTk1SzNE0mKbFCDgoUKk7.jpg'),
(123266, 8841, 'Segredos do Miss America S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7PM9KGMcefll2Gnqq5IerXr6GON.jpg'),
(123267, 8842, 'Sunset Milha de Ouro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7vpysP9mZ5Tbc1URj6a8V1uDbg.jpg'),
(123268, 8842, 'Sunset Milha de Ouro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aTN6RDVYedAiK4VYk7uo3JEjGWV.jpg'),
(123269, 8842, 'Sunset Milha de Ouro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sDd336dlJJzlhoWyvzFGiFoMbst.jpg'),
(123270, 8842, 'Sunset Milha de Ouro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8jlXGdQhJyu9XrddM0Tekatq7i6.jpg'),
(123271, 8842, 'Sunset Milha de Ouro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oJeV4mf2AE7fsA7hJvlnoYu1lrJ.jpg'),
(123272, 8842, 'Sunset Milha de Ouro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTqUsMbOoKoZ1gGtiQxmC4WchKb.jpg'),
(123273, 8842, 'Sunset Milha de Ouro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vW41PXnjGBYHIKfIFcXQZW9hOPv.jpg'),
(123274, 8842, 'Sunset Milha de Ouro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u73a5FVTCMjrgXSs3SKmwSRI405.jpg'),
(123275, 8843, 'Sunset Milha de Ouro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Gcn7m1GDxIbWGUnDslCpIpy3Ql.jpg'),
(123276, 8843, 'Sunset Milha de Ouro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/41hPrggmIyV350bBc03tycFJs80.jpg'),
(123277, 8843, 'Sunset Milha de Ouro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pZqpn1y83icaHTNtCIrd2bTtTIL.jpg'),
(123278, 8843, 'Sunset Milha de Ouro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aVb9CuMwnlAXuE20ZPCgeZhR0Gf.jpg'),
(123279, 8843, 'Sunset Milha de Ouro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n7crJJLRenDzODEphq5ddiqkUJ0.jpg'),
(123280, 8843, 'Sunset Milha de Ouro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vu5IUs4FgSd9NOBaZNksv69ZyHr.jpg'),
(123281, 8843, 'Sunset Milha de Ouro S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t4JhOH43iXJCVMXydlEzEiEptDC.jpg'),
(123282, 8843, 'Sunset Milha de Ouro S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jaNGbsOPNzueEcsBKwpP2VtTsUf.jpg'),
(123283, 8844, 'Sunset Milha de Ouro S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wiQ3SkpuTPV5GjNx3GayvZSkhqh.jpg'),
(123284, 8844, 'Sunset Milha de Ouro S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5uOm1BQSrtgl1EdLBbdkKGioM0m.jpg'),
(123285, 8844, 'Sunset Milha de Ouro S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zAhJ2bYzekbLmUmWJ8g5c9XdBaX.jpg'),
(123286, 8844, 'Sunset Milha de Ouro S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/abhwelphEPaegteEfRDCVHNsLK8.jpg'),
(123287, 8844, 'Sunset Milha de Ouro S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rxtdwSFKsMW7AOwm23lc4DTbLhB.jpg'),
(123288, 8844, 'Sunset Milha de Ouro S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OrocHI8ZcUgLn1ug9SetpYROrs.jpg'),
(123289, 8844, 'Sunset Milha de Ouro S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/djv6vW8NwQZykqNBXnLAEe6VvvR.jpg'),
(123290, 8844, 'Sunset Milha de Ouro S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jxv89hDRdxkUszzBXGB0nOQ79Az.jpg'),
(123291, 8845, 'Sunset Milha de Ouro S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jAolCQl95b7HXqRD8NamUV6kK7y.jpg'),
(123292, 8845, 'Sunset Milha de Ouro S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/43UykX3eB0mJLgzOz1RSN52nrkt.jpg'),
(123293, 8845, 'Sunset Milha de Ouro S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mJYvAUmf350iGMPrlBuNiOR6QCE.jpg'),
(123294, 8845, 'Sunset Milha de Ouro S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5pd2io28KYsPaXn56ZfY18N7kwV.jpg'),
(123295, 8845, 'Sunset Milha de Ouro S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHJacst1R6GXtT5f0FOJHekCL3v.jpg'),
(123296, 8845, 'Sunset Milha de Ouro S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q1DkzQqEjxGFmIGi16WThDpBrGg.jpg'),
(123297, 8845, 'Sunset Milha de Ouro S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7hsf3jCf75aq7TCIFgLAM1u8FzF.jpg'),
(123298, 8845, 'Sunset Milha de Ouro S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/auh0d5vAf7WB2ZVQpuWxuIjoJm9.jpg'),
(123299, 8845, 'Sunset Milha de Ouro S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p9jBt9x0ZWE0gWgJa3fwT37szJK.jpg'),
(123300, 8845, 'Sunset Milha de Ouro S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/245643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gwPI7aIbleLBdvQli1LQzXSCXEO.jpg'),
(123301, 8846, 'Sunset Milha de Ouro S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cNYVnpj1vKCnzXGbQ6r4lAYx7xJ.jpg'),
(123302, 8846, 'Sunset Milha de Ouro S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iG4janY3t2rNTkFCppyqRLO4ZIm.jpg'),
(123303, 8846, 'Sunset Milha de Ouro S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5oyHxo45JLKjtS8CU32KsH5DZN.jpg'),
(123304, 8846, 'Sunset Milha de Ouro S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wSkW1K44BssRUBnQSrXtdGTvrq1.jpg'),
(123305, 8846, 'Sunset Milha de Ouro S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9xLjFwWanMarbSdsrEkZ7Rx7P4.jpg'),
(123306, 8846, 'Sunset Milha de Ouro S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iqhAogGMEZVWVCB90IlXDiK1rg5.jpg'),
(123307, 8846, 'Sunset Milha de Ouro S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n0s75nrCDIVrlQsD7ztfLyVyKkt.jpg'),
(123308, 8846, 'Sunset Milha de Ouro S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kLjQ5azVNtplqbZHeJXwO6R0TtV.jpg'),
(123309, 8846, 'Sunset Milha de Ouro S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJIM3GQxr0pS3RwYb1X4c6aNXQZ.jpg'),
(123310, 8846, 'Sunset Milha de Ouro S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/245653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/msuBBpzU4vC7wcGtcH8vkbMu4Yt.jpg'),
(123311, 8846, 'Sunset Milha de Ouro S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/245654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dX3bzdTHhtOoad0GCadHnI1AE90.jpg'),
(123312, 8847, 'Sunset Milha de Ouro S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2bf8ic5IIy8DmgAB6Xe5hChfUA.jpg'),
(123313, 8847, 'Sunset Milha de Ouro S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/icVT8QSwLoHVgzW09VMK1irL1sB.jpg'),
(123314, 8847, 'Sunset Milha de Ouro S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ldtotacblb592Abm2lbXO34jx0.jpg'),
(123315, 8847, 'Sunset Milha de Ouro S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jbYb5KDybOdswGOgoY2uqYa6g0O.jpg'),
(123316, 8847, 'Sunset Milha de Ouro S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c5CRz31IXYdtZcZUD3KresHS5Rf.jpg'),
(123317, 8847, 'Sunset Milha de Ouro S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/elXjkwyHx5mNm22stWOzc6OqkRE.jpg'),
(123318, 8847, 'Sunset Milha de Ouro S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yMxHKRnj3AstTkPDqEDWdPspFgW.jpg'),
(123319, 8847, 'Sunset Milha de Ouro S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ljSmIK1hMtQtrPaO0SjcWrdyCiv.jpg'),
(123320, 8847, 'Sunset Milha de Ouro S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oJzC8wgQ8YXqLnJoSjG7G5oJTet.jpg'),
(123321, 8847, 'Sunset Milha de Ouro S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/245664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8sD0OftpVxRadM6TMCcXByz1BDa.jpg'),
(123322, 8847, 'Sunset Milha de Ouro S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/245665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6EULWW6oR5SM9o29cxNiyidtYAZ.jpg'),
(123323, 8848, 'Sunset Milha de Ouro S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/laVreEienjU2jvkhjA41Kug0bMC.jpg'),
(123324, 8848, 'Sunset Milha de Ouro S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gYJ1Piu7oxqaGJg71jKx5MJBIKn.jpg'),
(123325, 8848, 'Sunset Milha de Ouro S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNJ2kKxgLC4rqkaU8lUnW1RdIFW.jpg'),
(123326, 8848, 'Sunset Milha de Ouro S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rlGlFesXUPrqsHnt75iksJVmsnl.jpg'),
(123327, 8848, 'Sunset Milha de Ouro S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qcoBkEIA3yC2yHgGswQIGXZccOM.jpg'),
(123328, 8848, 'Sunset Milha de Ouro S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hrn3yUZOaUEiR09Ahrax8nxBHrw.jpg'),
(123329, 8848, 'Sunset Milha de Ouro S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Qg8jcSc93Wx9WAY3QLRauodEua.jpg'),
(123330, 8848, 'Sunset Milha de Ouro S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r5G8XFNCoyzumCivRtWFSMQyqp8.jpg'),
(123331, 8848, 'Sunset Milha de Ouro S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/li5hYmTJ7dluPQnWYnfGiAma88p.jpg'),
(123332, 8848, 'Sunset Milha de Ouro S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/245675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4rARkxT1foMHF9KdZQ08qQJRn6q.jpg'),
(123333, 8848, 'Sunset Milha de Ouro S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/245676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmOmY7vi3XgbKMsrYlCCG7hQPDb.jpg'),
(123334, 8848, 'Sunset Milha de Ouro S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/245677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123335, 8849, 'Sunset Milha de Ouro S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/890648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123336, 8849, 'Sunset Milha de Ouro S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/890649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123337, 8849, 'Sunset Milha de Ouro S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/890650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123338, 8849, 'Sunset Milha de Ouro S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/890651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123339, 8849, 'Sunset Milha de Ouro S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/890652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123340, 8849, 'Sunset Milha de Ouro S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/890653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123341, 8849, 'Sunset Milha de Ouro S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/890654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123342, 8849, 'Sunset Milha de Ouro S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/890655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123343, 8849, 'Sunset Milha de Ouro S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/890656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123344, 8849, 'Sunset Milha de Ouro S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/890657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123345, 8849, 'Sunset Milha de Ouro S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/890658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123346, 8850, 'Sunset Milha de Ouro S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/890659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123347, 8850, 'Sunset Milha de Ouro S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/890660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123348, 8850, 'Sunset Milha de Ouro S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/890661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123349, 8850, 'Sunset Milha de Ouro S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/890662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123350, 8850, 'Sunset Milha de Ouro S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/890663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123351, 8850, 'Sunset Milha de Ouro S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/890664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123352, 8850, 'Sunset Milha de Ouro S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/890665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123353, 8850, 'Sunset Milha de Ouro S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/890666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123354, 8850, 'Sunset Milha de Ouro S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/890667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123355, 8850, 'Sunset Milha de Ouro S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/890668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123356, 8850, 'Sunset Milha de Ouro S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/891826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u7oG5RKpXQC0c10jUvLfKYggKOY.jpg'),
(123357, 8851, 'Troca de Esposas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123358, 8851, 'Troca de Esposas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123359, 8851, 'Troca de Esposas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123360, 8851, 'Troca de Esposas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123361, 8851, 'Troca de Esposas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123362, 8851, 'Troca de Esposas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123363, 8851, 'Troca de Esposas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123364, 8851, 'Troca de Esposas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123365, 8851, 'Troca de Esposas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123366, 8851, 'Troca de Esposas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123367, 8851, 'Troca de Esposas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123368, 8852, 'Troca de Esposas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123369, 8852, 'Troca de Esposas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123370, 8852, 'Troca de Esposas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123371, 8852, 'Troca de Esposas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123372, 8852, 'Troca de Esposas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123373, 8852, 'Troca de Esposas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123374, 8852, 'Troca de Esposas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123375, 8852, 'Troca de Esposas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123376, 8852, 'Troca de Esposas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123377, 8852, 'Troca de Esposas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123378, 8852, 'Troca de Esposas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qJBKkMQ0eeomRMSXuH1akU0KvIk.jpg'),
(123379, 8853, 'Troca de Esposas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ngXB8Ub7JKwSuPhvuByru5hYUsx.jpg'),
(123380, 8853, 'Troca de Esposas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hqMDrSZWSinjNuM0kUB0sArGZ2i.jpg'),
(123381, 8853, 'Troca de Esposas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/joz2VpxwGxHXmh0KSzkp2YMlMvU.jpg'),
(123382, 8853, 'Troca de Esposas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3bNcg9jyYGPnztcZY0nyJv7KxUo.jpg'),
(123383, 8853, 'Troca de Esposas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a84u38L6JADsazec8DuxvtDhPza.jpg'),
(123384, 8853, 'Troca de Esposas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyRApx4e4LLNJQydk68xdbsU9P4.jpg'),
(123385, 8853, 'Troca de Esposas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8NiEk8qLeAQBcDxIeuMuXImjazG.jpg'),
(123386, 8853, 'Troca de Esposas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJ1GPZxgJWrVEIG05PCr7uiNxKR.jpg'),
(123387, 8853, 'Troca de Esposas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nsk9AAyi1Cx20zXs0DQNV4FFRkZ.jpg'),
(123388, 8853, 'Troca de Esposas S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nYpgrTWVsl4nzuZw5h5G5pvCXXT.jpg'),
(123389, 8853, 'Troca de Esposas S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yub3hdFOi5QpU8Ftwk5q2QThHnP.jpg'),
(123390, 8853, 'Troca de Esposas S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c6Drp9mkbEZ6BU0Qz5T1aEQM2pD.jpg'),
(123391, 8853, 'Troca de Esposas S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qlFy1nLsTkCT9WfGgpU3yGM3Fay.jpg'),
(123392, 8853, 'Troca de Esposas S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/239543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y4sEfHChqWPUAMTpCY1FE5OWpV6.jpg'),
(123393, 8853, 'Troca de Esposas S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/239544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4YeRn3WeajZoAZdqGHBXVXEckLa.jpg'),
(123394, 8853, 'Troca de Esposas S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/239545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yByCxqna8SxdeymzdwNg6tAkIPz.jpg'),
(123395, 7121, 'Ursinhos em Curso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aMHx7FahXQ1yQHIk5YR3hLq6htl.jpg'),
(123396, 7121, 'Ursinhos em Curso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqsv95zjehPEBIZPpyQuL4apo3r.jpg'),
(123397, 7121, 'Ursinhos em Curso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2NLDqKvJKWlwfmNoiLflzOxUYNL.jpg'),
(123398, 7121, 'Ursinhos em Curso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lG49PemmJ6tLeE5YKT93F8baTG.jpg'),
(123399, 7121, 'Ursinhos em Curso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hG6PUK1Vk0ZPsDeqYErZWB9Zx7L.jpg'),
(123400, 7121, 'Ursinhos em Curso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/abobcVGXKewB4Iw8cUnf4gUe2L8.jpg'),
(123401, 7121, 'Ursinhos em Curso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xlic0HX8e0QsgpKLaLgQD5O2Kf9.jpg'),
(123402, 7121, 'Ursinhos em Curso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qyn8Vfn2nJ1d6fE8IwKaIg4gkUg.jpg'),
(123403, 7121, 'Ursinhos em Curso S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xm7qt9iAu83RLZ98BR2UWBYCDdA.jpg'),
(123404, 7121, 'Ursinhos em Curso S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zG49eYJd1pUVNHEoWu4oCmVrGwt.jpg'),
(123405, 7121, 'Ursinhos em Curso S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8TzLv9vRcBtbJthjO7CoKs0kfBd.jpg'),
(123406, 7121, 'Ursinhos em Curso S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2u8cM4uPrepOP3jnKsOUXUwC2SE.jpg'),
(123407, 7121, 'Ursinhos em Curso S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1C2wmdD33DNOkdfZ9aPlomt83Gn.jpg'),
(123408, 7121, 'Ursinhos em Curso S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/239559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aqotg50tPERx0RRGWrf2dVRfzTj.jpg'),
(123409, 7121, 'Ursinhos em Curso S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/239560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iGpfdnjIAeNDszKwhPsBjYXw0o1.jpg'),
(123410, 7121, 'Ursinhos em Curso S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/239561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzhJIDTOCkhppJ3yGU60zkZQR8M.jpg'),
(123411, 7121, 'Ursinhos em Curso S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/239562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rFr0KUWS4OaERW4RGEJ2QtmbB0A.jpg'),
(123412, 7121, 'Ursinhos em Curso S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/239563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pCE0grCyEElOKtHurUV4kvxI511.jpg'),
(123413, 7121, 'Ursinhos em Curso S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/239564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/neWyW2wmIYcGmwWUsCf7FEBOEpz.jpg'),
(123414, 7121, 'Ursinhos em Curso S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/239565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y1gJrOQeMS126w7XhczbofxydOD.jpg'),
(123415, 7121, 'Ursinhos em Curso S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/239566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fiuAaYI5zZ06fTUdBF0oBqgrrwi.jpg'),
(123416, 7121, 'Ursinhos em Curso S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/239567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aupoitU5osFupo46FFPQ8j4enPO.jpg'),
(123417, 7121, 'Ursinhos em Curso S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/239568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5cyQo3WVw2Uqr455PGPYWWm5Cbq.jpg'),
(123418, 7121, 'Ursinhos em Curso S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/239569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9kPZNiwgDORh5hA0TCZKbAbFFCZ.jpg'),
(123419, 7121, 'Ursinhos em Curso S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/239570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hiFebRkSjJ2h3g1F3WzHweM9QWJ.jpg'),
(123420, 7121, 'Ursinhos em Curso S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/239571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7EvdFe6x78VH6fLGv2w45n0xZL.jpg'),
(123421, 7121, 'Ursinhos em Curso S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/239572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uSwvuuCRWM7AYvHtZCbSrmTJmD9.jpg'),
(123422, 7121, 'Ursinhos em Curso S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/239573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pePAQg9PhYthlhXnSlq2GthqB3u.jpg'),
(123423, 7121, 'Ursinhos em Curso S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/239574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e2cB28UlHswfNTfAnYGaRJQYflO.jpg'),
(123424, 7121, 'Ursinhos em Curso S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/239575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ltej9DP0zGOzEeERsdokSr6R54F.jpg'),
(123425, 7121, 'Ursinhos em Curso S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/239576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/euPMhmUAP5ovyKOvWwCTICAUn57.jpg'),
(123426, 7121, 'Ursinhos em Curso S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/239577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7B60b2M9r9ds2ILnRS32P6gmBNm.jpg'),
(123427, 7121, 'Ursinhos em Curso S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/239578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2Xasys5AQf0uiIVWOg29RJuuQB.jpg'),
(123428, 7121, 'Ursinhos em Curso S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/239579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jDC0WgI4wsr5pNoRs3Tnx1hanqH.jpg'),
(123429, 7121, 'Ursinhos em Curso S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/239580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5DyhT6n4HS6Z1aaMGmTdXsbaevr.jpg'),
(123430, 7121, 'Ursinhos em Curso S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/239581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dqHIDimgHRqxJZLoyrxsAFwgxRq.jpg'),
(123431, 7121, 'Ursinhos em Curso S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/239582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yqdUTL8qBO2oqRHldMixQAzxU8H.jpg'),
(123432, 7121, 'Ursinhos em Curso S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/239583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1lfsnpdxTOeJGgVesqJBVt7zzR.jpg'),
(123433, 7121, 'Ursinhos em Curso S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/239584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rrICw56FiMOApmh3H5oNVRKy1a0.jpg'),
(123434, 8854, 'Ursinhos em Curso S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/700444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123435, 8854, 'Ursinhos em Curso S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/700445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123436, 8854, 'Ursinhos em Curso S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/700446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123437, 8854, 'Ursinhos em Curso S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/700447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123438, 8854, 'Ursinhos em Curso S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/700448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123439, 8854, 'Ursinhos em Curso S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/700449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123440, 8854, 'Ursinhos em Curso S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/700450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123441, 8854, 'Ursinhos em Curso S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/700451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123442, 8854, 'Ursinhos em Curso S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/700452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123443, 8854, 'Ursinhos em Curso S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/700453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123444, 8854, 'Ursinhos em Curso S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/700454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123445, 8854, 'Ursinhos em Curso S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/700455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123446, 8854, 'Ursinhos em Curso S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/700456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123447, 8854, 'Ursinhos em Curso S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/700457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123448, 8854, 'Ursinhos em Curso S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/700458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123449, 8854, 'Ursinhos em Curso S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/700459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123450, 8854, 'Ursinhos em Curso S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/700460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123451, 8854, 'Ursinhos em Curso S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/700461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123452, 8854, 'Ursinhos em Curso S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/700462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123453, 8854, 'Ursinhos em Curso S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/700463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123454, 8854, 'Ursinhos em Curso S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/700464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123455, 8854, 'Ursinhos em Curso S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/700465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123456, 8854, 'Ursinhos em Curso S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/700466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123457, 8854, 'Ursinhos em Curso S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/700467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123458, 8854, 'Ursinhos em Curso S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/894855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123459, 8854, 'Ursinhos em Curso S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/894856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123460, 8854, 'Ursinhos em Curso S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/894857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123461, 8854, 'Ursinhos em Curso S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/894858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123462, 8854, 'Ursinhos em Curso S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/894859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123463, 8854, 'Ursinhos em Curso S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/894860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123464, 8854, 'Ursinhos em Curso S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/894861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123465, 8854, 'Ursinhos em Curso S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/894862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123466, 8854, 'Ursinhos em Curso S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/894863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123467, 8854, 'Ursinhos em Curso S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/894864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWyFYrEz0f2RXpRbqOoTov3ADt.jpg'),
(123468, 8855, 'Viagem a Portugal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ksjxLmPGzaEU7DahbJC82KU28yM.jpg'),
(123469, 8855, 'Viagem a Portugal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ksjxLmPGzaEU7DahbJC82KU28yM.jpg'),
(123470, 8855, 'Viagem a Portugal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ksjxLmPGzaEU7DahbJC82KU28yM.jpg'),
(123471, 8855, 'Viagem a Portugal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ksjxLmPGzaEU7DahbJC82KU28yM.jpg'),
(123472, 8855, 'Viagem a Portugal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ksjxLmPGzaEU7DahbJC82KU28yM.jpg'),
(123473, 8855, 'Viagem a Portugal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ksjxLmPGzaEU7DahbJC82KU28yM.jpg'),
(123474, 8856, 'A Bilionaria o Mordomo e o Namorado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6259lqrFdxTYtzdqQI9C7QkazY8.jpg'),
(123475, 8856, 'A Bilionaria o Mordomo e o Namorado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6259lqrFdxTYtzdqQI9C7QkazY8.jpg'),
(123476, 8856, 'A Bilionaria o Mordomo e o Namorado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6259lqrFdxTYtzdqQI9C7QkazY8.jpg'),
(123477, 8857, 'Dark Gathering [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ujDTfPytmQxPm4ODEk6QFyW0lu7.jpg'),
(123478, 8857, 'Dark Gathering [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/byv9fGJv0MPzZhJXHEsWF4sve0Y.jpg'),
(123479, 8857, 'Dark Gathering [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eP7M977x94rg8b7vqKTVW1EX7Cq.jpg'),
(123480, 8857, 'Dark Gathering [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qFZJOQxVXEhZ3S0qXQUFGZUf7Fb.jpg'),
(123481, 8857, 'Dark Gathering [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3UkqIHxvga7FSWfC0CR9wRhUmaG.jpg'),
(123482, 8857, 'Dark Gathering [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/skfTFXuwBMuDW2JSYexeyNj0kDl.jpg'),
(123483, 8857, 'Dark Gathering [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mcPodETUbSUDXVypv7fSXQt27gt.jpg'),
(123484, 8857, 'Dark Gathering [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kfRUfzA7hYDJKM6eCtXQsM6sl0c.jpg'),
(123485, 8857, 'Dark Gathering [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aHrm2pOPISFSUszqmINoLUHIh4U.jpg'),
(123486, 8857, 'Dark Gathering [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bqPp5sh0iBewXWNAUFDlHN3Gw2o.jpg'),
(123487, 8857, 'Dark Gathering [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ltsdrX5KxmxHTyiC41OH0i9cd5e.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(123488, 8857, 'Dark Gathering [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y37TF8eIsgaeVUlaO5uKSTB76PR.jpg'),
(123489, 8857, 'Dark Gathering [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2obQLRJolPfhqFtiLj3sDuqE5f.jpg'),
(123490, 8857, 'Dark Gathering [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/257323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vHuIBIw0Rg5tRnE44sn66Xjttnq.jpg'),
(123491, 8857, 'Dark Gathering [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/257324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mHVuVnYysBJu4irCWMzV6Bt102w.jpg'),
(123492, 8857, 'Dark Gathering [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/257325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fKG4SNJ5nnG6adPLxW1ed6SHmy0.jpg'),
(123493, 8857, 'Dark Gathering [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/257326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2gGkF6Q7JaKs9PfjtmpD3HywteO.jpg'),
(123494, 8857, 'Dark Gathering [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/257327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jcwmPfOaZmDRoaQysDRD3GTLEbP.jpg'),
(123495, 8857, 'Dark Gathering [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/257328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lNAJ5Oftfqn9gx1mBWKXuXIgbLq.jpg'),
(123496, 8857, 'Dark Gathering [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/257329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lNAJ5Oftfqn9gx1mBWKXuXIgbLq.jpg'),
(123497, 8857, 'Dark Gathering [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/257330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lNAJ5Oftfqn9gx1mBWKXuXIgbLq.jpg'),
(123498, 8857, 'Dark Gathering [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/257331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lNAJ5Oftfqn9gx1mBWKXuXIgbLq.jpg'),
(123499, 8857, 'Dark Gathering [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/257332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lNAJ5Oftfqn9gx1mBWKXuXIgbLq.jpg'),
(123500, 8857, 'Dark Gathering [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/257333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lNAJ5Oftfqn9gx1mBWKXuXIgbLq.jpg'),
(123501, 8857, 'Dark Gathering [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/257334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lNAJ5Oftfqn9gx1mBWKXuXIgbLq.jpg'),
(123502, 8858, 'Fugindo do Twin Flames S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9zs2k9BXFA5QFzHh77n0bcW7FYB.jpg'),
(123503, 8858, 'Fugindo do Twin Flames S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9zs2k9BXFA5QFzHh77n0bcW7FYB.jpg'),
(123504, 8858, 'Fugindo do Twin Flames S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9zs2k9BXFA5QFzHh77n0bcW7FYB.jpg'),
(123505, 8859, 'KAWAGOE BOYS SING Now or Never [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g5eYe32foI6DfoUCOfUk9VQ0rmC.jpg'),
(123506, 8859, 'KAWAGOE BOYS SING Now or Never [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uANXPZj0dQIG53zz8jnllrsVSnA.jpg'),
(123507, 8859, 'KAWAGOE BOYS SING Now or Never [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xdkniE6p3Sv3yTJ6r8oVW7uID7O.jpg'),
(123508, 8859, 'KAWAGOE BOYS SING Now or Never [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2K54UThaRL7vCTXT5HG3HXxPoB.jpg'),
(123509, 8859, 'KAWAGOE BOYS SING Now or Never [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4AG6I2ZUccYIZdnvLApRWnWJch3.jpg'),
(123510, 8859, 'KAWAGOE BOYS SING Now or Never [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o2l1z54hgEq5MuuwziH9sOeG6rx.jpg'),
(123511, 8859, 'KAWAGOE BOYS SING Now or Never [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o2l1z54hgEq5MuuwziH9sOeG6rx.jpg'),
(123512, 8859, 'KAWAGOE BOYS SING Now or Never [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o2l1z54hgEq5MuuwziH9sOeG6rx.jpg'),
(123513, 8859, 'KAWAGOE BOYS SING Now or Never [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o2l1z54hgEq5MuuwziH9sOeG6rx.jpg'),
(123514, 8859, 'KAWAGOE BOYS SING Now or Never [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o2l1z54hgEq5MuuwziH9sOeG6rx.jpg'),
(123515, 8859, 'KAWAGOE BOYS SING Now or Never [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/261408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o2l1z54hgEq5MuuwziH9sOeG6rx.jpg'),
(123516, 8859, 'KAWAGOE BOYS SING Now or Never [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/261409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o2l1z54hgEq5MuuwziH9sOeG6rx.jpg'),
(123517, 8860, 'Largados e Pelados A Competicao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123518, 8860, 'Largados e Pelados A Competicao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123519, 8860, 'Largados e Pelados A Competicao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123520, 8860, 'Largados e Pelados A Competicao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123521, 8860, 'Largados e Pelados A Competicao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123522, 8860, 'Largados e Pelados A Competicao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123523, 8860, 'Largados e Pelados A Competicao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123524, 8860, 'Largados e Pelados A Competicao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123525, 8860, 'Largados e Pelados A Competicao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123526, 8860, 'Largados e Pelados A Competicao S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123527, 8861, 'Largados e Pelados A Competicao S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/503270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123528, 8861, 'Largados e Pelados A Competicao S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/503271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123529, 8861, 'Largados e Pelados A Competicao S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/507759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123530, 8861, 'Largados e Pelados A Competicao S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/511708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123531, 8861, 'Largados e Pelados A Competicao S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/514453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123532, 8861, 'Largados e Pelados A Competicao S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/517978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123533, 8861, 'Largados e Pelados A Competicao S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/525388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123534, 8861, 'Largados e Pelados A Competicao S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/638567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123535, 8861, 'Largados e Pelados A Competicao S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/659133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123536, 8861, 'Largados e Pelados A Competicao S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/659134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123537, 8862, 'Largados e Pelados A Competicao S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/880056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123538, 8862, 'Largados e Pelados A Competicao S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/880881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123539, 8862, 'Largados e Pelados A Competicao S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/881950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123540, 8862, 'Largados e Pelados A Competicao S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/881951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123541, 8862, 'Largados e Pelados A Competicao S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/883550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123542, 8862, 'Largados e Pelados A Competicao S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/884055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123543, 8862, 'Largados e Pelados A Competicao S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/885778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123544, 8862, 'Largados e Pelados A Competicao S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/886251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123545, 8862, 'Largados e Pelados A Competicao S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/887744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ptDHCxxFUMdVO5WDi0LeICFbDw.jpg'),
(123546, 8863, 'Orphan Black Echoes [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kJyVhgugJm8imqz9WGEqgAJJbWT.jpg'),
(123547, 8863, 'Orphan Black Echoes [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zbKgrU791OFN7ZqYxDuKawPsiio.jpg'),
(123548, 8863, 'Orphan Black Echoes [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s6yJjbyZu5zaiDF1jlfOuzcnxwA.jpg'),
(123549, 8863, 'Orphan Black Echoes [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s6yJjbyZu5zaiDF1jlfOuzcnxwA.jpg'),
(123550, 8863, 'Orphan Black Echoes [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s6yJjbyZu5zaiDF1jlfOuzcnxwA.jpg'),
(123551, 8863, 'Orphan Black Echoes [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s6yJjbyZu5zaiDF1jlfOuzcnxwA.jpg'),
(123552, 8863, 'Orphan Black Echoes [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s6yJjbyZu5zaiDF1jlfOuzcnxwA.jpg'),
(123553, 8863, 'Orphan Black Echoes [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s6yJjbyZu5zaiDF1jlfOuzcnxwA.jpg'),
(123554, 8863, 'Orphan Black Echoes [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s6yJjbyZu5zaiDF1jlfOuzcnxwA.jpg'),
(123555, 8864, 'Os Bucaneiros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qXe6f0L0scAPQjagLzKZe2vKLt4.jpg'),
(123556, 8864, 'Os Bucaneiros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8dgAYPiQMJNs7gs61AMfmLf8Rtu.jpg'),
(123557, 8864, 'Os Bucaneiros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tfr9rbkMMn47TldFbdhcp1NTva0.jpg'),
(123558, 8864, 'Os Bucaneiros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y8uWvyxHqD0RyS1NCBpt0nwgWR.jpg'),
(123559, 8864, 'Os Bucaneiros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y8uWvyxHqD0RyS1NCBpt0nwgWR.jpg'),
(123560, 8864, 'Os Bucaneiros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y8uWvyxHqD0RyS1NCBpt0nwgWR.jpg'),
(123561, 8864, 'Os Bucaneiros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y8uWvyxHqD0RyS1NCBpt0nwgWR.jpg'),
(123562, 8864, 'Os Bucaneiros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y8uWvyxHqD0RyS1NCBpt0nwgWR.jpg'),
(123563, 8865, 'Os Bucaneiros S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/845339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y8uWvyxHqD0RyS1NCBpt0nwgWR.jpg'),
(123564, 8865, 'Os Bucaneiros S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/850424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y8uWvyxHqD0RyS1NCBpt0nwgWR.jpg'),
(123565, 8865, 'Os Bucaneiros S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/857174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y8uWvyxHqD0RyS1NCBpt0nwgWR.jpg'),
(123566, 8865, 'Os Bucaneiros S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/864363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y8uWvyxHqD0RyS1NCBpt0nwgWR.jpg'),
(123567, 8865, 'Os Bucaneiros S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/870236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y8uWvyxHqD0RyS1NCBpt0nwgWR.jpg'),
(123568, 8865, 'Os Bucaneiros S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/874165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y8uWvyxHqD0RyS1NCBpt0nwgWR.jpg'),
(123569, 8865, 'Os Bucaneiros S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/878867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y8uWvyxHqD0RyS1NCBpt0nwgWR.jpg'),
(123570, 8865, 'Os Bucaneiros S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/879977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y8uWvyxHqD0RyS1NCBpt0nwgWR.jpg'),
(123571, 8866, 'Time [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n1kaMJ2XZNMX8HydArJu6bT13OB.jpg'),
(123572, 8866, 'Time [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/93Vo85d0IifFFjwUW5CvmRvGIzW.jpg'),
(123573, 8866, 'Time [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sRoDMH722blLSPBB5Sfvwldjjlm.jpg'),
(123574, 8867, 'Time [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rQhVK6ru4vtLuhECTVqX62xDCV.jpg'),
(123575, 8867, 'Time [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUSeRzX6ow9JX3ZvSH1BxHZtEDW.jpg'),
(123576, 8867, 'Time [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nSxE6STKTRWb5XLNJgH6q2AKGas.jpg'),
(123577, 8868, 'Ultimas Ferias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d2zyEKRAQFIt5SreoQMNnKt4H5J.jpg'),
(123578, 8868, 'Ultimas Ferias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d2zyEKRAQFIt5SreoQMNnKt4H5J.jpg'),
(123579, 8868, 'Ultimas Ferias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d2zyEKRAQFIt5SreoQMNnKt4H5J.jpg'),
(123580, 8868, 'Ultimas Ferias S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d2zyEKRAQFIt5SreoQMNnKt4H5J.jpg'),
(123581, 8868, 'Ultimas Ferias S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d2zyEKRAQFIt5SreoQMNnKt4H5J.jpg'),
(123582, 8868, 'Ultimas Ferias S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d2zyEKRAQFIt5SreoQMNnKt4H5J.jpg'),
(123583, 8868, 'Ultimas Ferias S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d2zyEKRAQFIt5SreoQMNnKt4H5J.jpg'),
(123584, 8868, 'Ultimas Ferias S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d2zyEKRAQFIt5SreoQMNnKt4H5J.jpg'),
(123585, 8869, 'Confusões de Leslie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bs2tGyMX8eaUU66yIjOgnjKA8Px.jpg'),
(123586, 8869, 'Confusões de Leslie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9nlKDqVCfBU8vtNUVKjnUhWhzv3.jpg'),
(123587, 8869, 'Confusões de Leslie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yxLQd6JGC2aKGAReY4N5jzljP0o.jpg'),
(123588, 8869, 'Confusões de Leslie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Bc1CKAwm8lezkq4Hcg99qTw4oH.jpg'),
(123589, 8869, 'Confusões de Leslie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/puQKYn7DD7C5CmuE07PJFWKkTcS.jpg'),
(123590, 8869, 'Confusões de Leslie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vBHPwZmzsoCODYdJO5Ymz2uyH3O.jpg'),
(123591, 8870, 'Confusões de Leslie S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/op8s6NnkTIS4favcW6QF5XUAdxL.jpg'),
(123592, 8870, 'Confusões de Leslie S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hLQKV7w6IURMCHXIk4rnuh6ypIT.jpg'),
(123593, 8870, 'Confusões de Leslie S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4gHnfTWsah3ED9hIZDUmGWYSN2K.jpg'),
(123594, 8870, 'Confusões de Leslie S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kk16HuRcl17dlch0CUzSgQs09LG.jpg'),
(123595, 8870, 'Confusões de Leslie S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qCalFFcJl44J2jl0X72ukT5pweP.jpg'),
(123596, 8870, 'Confusões de Leslie S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQIWlAA9aNqTVCCQNQWtrAwtMFM.jpg'),
(123597, 8870, 'Confusões de Leslie S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2X8w5mUapfEUtEnnduFG5igBkW1.jpg'),
(123598, 8870, 'Confusões de Leslie S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wbu8MXeDdLSKsbPsJikpUUw16tH.jpg'),
(123599, 8870, 'Confusões de Leslie S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5qsLbwEpCwI2klJ0ba7sq0srtf.jpg'),
(123600, 8870, 'Confusões de Leslie S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jORB3rauZ29vQuh4r6fNdg9UOYo.jpg'),
(123601, 8870, 'Confusões de Leslie S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/je49qpYIVWVTlX3qrGRnzkutmO6.jpg'),
(123602, 8870, 'Confusões de Leslie S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ykX5G8XeaXyJdGKoFWdfdZDuzqL.jpg'),
(123603, 8870, 'Confusões de Leslie S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c9kaj7PWx5k6KKQKCscqP57H1pS.jpg'),
(123604, 8870, 'Confusões de Leslie S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/239181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1sMUkXqBhTGQ6lTxzz5ufFiEKky.jpg'),
(123605, 8870, 'Confusões de Leslie S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/239182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lBsNbHFN9yPtM3G3JALUjQtQM6P.jpg'),
(123606, 8870, 'Confusões de Leslie S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/239183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Qp2YJpB33OkJXFBnxkIlswe8Yf.jpg'),
(123607, 8870, 'Confusões de Leslie S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/239184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zXNuXGZoiDwi4Qgnazq1CwSvwYc.jpg'),
(123608, 8870, 'Confusões de Leslie S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/239185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZjZbww4eGRyx2Hq9Ds7UpdBZnR.jpg'),
(123609, 8870, 'Confusões de Leslie S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/239186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3dV2Pcw73vBBhTrsg7nMzdScTtm.jpg'),
(123610, 8870, 'Confusões de Leslie S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/239187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aP6czOjWr9XpoZFL90CqfEdiSJD.jpg'),
(123611, 8870, 'Confusões de Leslie S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/239188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lLtREc2ALNu5JxXAqbaYNOav3bI.jpg'),
(123612, 8870, 'Confusões de Leslie S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/239189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ahv7yf8872nxHdbkgPU99didd1A.jpg'),
(123613, 8870, 'Confusões de Leslie S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/239190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cwIgDU3p76rKlvdV47FK29ZR5ZT.jpg'),
(123614, 8870, 'Confusões de Leslie S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/239191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8z2VGXRz0GJXev2tMA8Yae2yGui.jpg'),
(123615, 8871, 'Confusões de Leslie S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/28LveFsLafGd6eTIsIqHBeoyP74.jpg'),
(123616, 8871, 'Confusões de Leslie S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/803OAyUIaOkjzXYmQkZ4F13aaWC.jpg'),
(123617, 8871, 'Confusões de Leslie S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AtiutnONMGyVi0iUmDCOvi00hEi.jpg'),
(123618, 8871, 'Confusões de Leslie S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nZrVuAURf8KFYz37maf8L5upX5x.jpg'),
(123619, 8871, 'Confusões de Leslie S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3F3GlVkh5r44y4y2TVwDRlcGdZG.jpg'),
(123620, 8871, 'Confusões de Leslie S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vsTbcxXIE14VaolRemfM6cF5mC2.jpg'),
(123621, 8871, 'Confusões de Leslie S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iAsSm0pSRU7zKHFISH2cQMxBhJf.jpg'),
(123622, 8871, 'Confusões de Leslie S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qtZbUhYWLeZuXFHOsNMSull0p2a.jpg'),
(123623, 8871, 'Confusões de Leslie S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fN6MKiJQSxP8CFDO0JiRuFb9olP.jpg'),
(123624, 8871, 'Confusões de Leslie S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g85EbXZ8ulMB75l9TpwhzccVTyN.jpg'),
(123625, 8871, 'Confusões de Leslie S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iptAaQ0I5Sa1jSOdstr25JYq2Nw.jpg'),
(123626, 8871, 'Confusões de Leslie S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/P1rC7dexr6Rxysp34SbPJ4yEMx.jpg'),
(123627, 8871, 'Confusões de Leslie S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dhZgFvKDnOUeHHKJWnvTs20CjIR.jpg'),
(123628, 8871, 'Confusões de Leslie S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/239205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4dNEDSC954Ml3WZd9B6vB9eU8KR.jpg'),
(123629, 8871, 'Confusões de Leslie S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/239206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vtsxv2WUphq1AFNJbxfs18dCsYf.jpg'),
(123630, 8871, 'Confusões de Leslie S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/239207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbvAjTtlEYme3uuJg2ZqKRHEEIB.jpg'),
(123631, 8872, 'Confusões de Leslie S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eCGwh8gtCaUCs9wzyk5r3vi2wzw.jpg'),
(123632, 8872, 'Confusões de Leslie S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bzB2hm4mCzOt6YyQVskmk1w1MsC.jpg'),
(123633, 8872, 'Confusões de Leslie S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ludRZYnv5LA9YzyDZbpJubiVDqo.jpg'),
(123634, 8872, 'Confusões de Leslie S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZpmkTYLPVwDnQ961EadP4LEPi3.jpg'),
(123635, 8872, 'Confusões de Leslie S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nLPVhU7wNtoZNgYd3U9DXIWkvzn.jpg'),
(123636, 8872, 'Confusões de Leslie S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7qFj3IZeeS4xKOQmC9fNjtfki0w.jpg'),
(123637, 8872, 'Confusões de Leslie S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A8zX0aQfxXcZyhOuVisbykFH1lM.jpg'),
(123638, 8872, 'Confusões de Leslie S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tE5HR6Ezpry7Qqi8tJawA95iHVU.jpg'),
(123639, 8872, 'Confusões de Leslie S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPv5g4yxaoAI85OKbM5xIjoEzWY.jpg'),
(123640, 8872, 'Confusões de Leslie S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nytms2DzQZutA8xcrg4Q9Ka7K7R.jpg'),
(123641, 8872, 'Confusões de Leslie S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhfHQZWfUD55gBctlntaXMHYGy.jpg'),
(123642, 8872, 'Confusões de Leslie S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fx9XCP8DcHfQHH4AYt76sgT9lGq.jpg'),
(123643, 8872, 'Confusões de Leslie S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zwVveBPQ5hyesVgvNQj62ja61mR.jpg'),
(123644, 8872, 'Confusões de Leslie S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/239221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v2IsszgpDUxgXI87lY9wb3pDZf7.jpg'),
(123645, 8872, 'Confusões de Leslie S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/239222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kg4OxNksELcI6N7LC6ulfGFw8s6.jpg'),
(123646, 8872, 'Confusões de Leslie S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/239223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xjY2aDQKEqGNNUEALditgo6EPnE.jpg'),
(123647, 8872, 'Confusões de Leslie S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/239224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yKlvhNc7urdD9EnhCwEbkzR1OiY.jpg'),
(123648, 8872, 'Confusões de Leslie S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/239225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mKI8znK474tqlQ9pUlK7zCZgo0O.jpg'),
(123649, 8872, 'Confusões de Leslie S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/239226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sEg51Fqi5Z6SH9fOEUM1ZcoWS8P.jpg'),
(123650, 8872, 'Confusões de Leslie S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/239227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ogqB655EhFLX2fbf1VYbsJZPzad.jpg'),
(123651, 8872, 'Confusões de Leslie S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/239228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/spIRC4TbXZKIuzUDp1vHHrB6PIW.jpg'),
(123652, 8872, 'Confusões de Leslie S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/239229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i6wOfRi5L6JKQV5ONoxCOLUsAUF.jpg'),
(123653, 8873, 'Confusões de Leslie S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tfY5uDHNnnK5L7IqVuaMmUMuEcv.jpg'),
(123654, 8873, 'Confusões de Leslie S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ij9fGOetPLAUPJ2WnzE8eEM93KJ.jpg'),
(123655, 8873, 'Confusões de Leslie S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qkjKGlIkKbfL7GpF9FqIkI0e1Gq.jpg'),
(123656, 8873, 'Confusões de Leslie S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gnaFG4RetuBseScvv2J1scFSN5i.jpg'),
(123657, 8873, 'Confusões de Leslie S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shemUSr5qOlY2B71ix86ic3GOZ.jpg'),
(123658, 8873, 'Confusões de Leslie S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lrgknVo3XSYoxsDLUpvd4ADR908.jpg'),
(123659, 8873, 'Confusões de Leslie S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yZO2fSziFGPU2D61RySwvY19bgP.jpg'),
(123660, 8873, 'Confusões de Leslie S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f7ez5EkXguOpSQf2jTjMV5Q3ynY.jpg'),
(123661, 8873, 'Confusões de Leslie S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9WweQTZIULmnWTT1T1240L0vGb.jpg'),
(123662, 8873, 'Confusões de Leslie S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m955xzsN79O2Qyi9YJk17YLq1vw.jpg'),
(123663, 8873, 'Confusões de Leslie S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9XXlf5dpzOwfwYtACJfphuNwdmu.jpg'),
(123664, 8873, 'Confusões de Leslie S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jQjfgms1hVLSbbTTWiIa1TZO5SL.jpg'),
(123665, 8873, 'Confusões de Leslie S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5CQPLZoS8OuDxNvaAe7Dp66e7cb.jpg'),
(123666, 8873, 'Confusões de Leslie S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/239243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AlxTM8rotWVgClDyPFUqpoSxuZi.jpg'),
(123667, 8873, 'Confusões de Leslie S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/239244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4FJBhDsUb7L5Gjaw2njTnPZgaUR.jpg'),
(123668, 8873, 'Confusões de Leslie S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/239245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9oZQItWvUlJaSf7ss3t0d2bBQCh.jpg'),
(123669, 8873, 'Confusões de Leslie S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/239246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2MbstijNRON7py73mSyIzwjMNwT.jpg'),
(123670, 8873, 'Confusões de Leslie S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/239247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pAIZrZXLTSUhnpaIwtBkRdpUbsE.jpg'),
(123671, 8873, 'Confusões de Leslie S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/239248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rhIDJsu1VKfb6It3Uqlv81OOgjC.jpg'),
(123672, 8873, 'Confusões de Leslie S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/239249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kYDhVul3UMLGIFxkzj3taT8IXb9.jpg'),
(123673, 8873, 'Confusões de Leslie S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/239250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wTWZ4wch3EqQBdjj6BljVOLYQwI.jpg'),
(123674, 8873, 'Confusões de Leslie S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/239251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zpF5sDZwKej7DQoDjksk6ax6Qnv.jpg'),
(123675, 8874, 'Confusões de Leslie S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mACiOfr2mNnylq4IGqqKDLMcK8f.jpg'),
(123676, 8874, 'Confusões de Leslie S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nfiMB2VjQG20wuCIVJTdrc1eyPH.jpg'),
(123677, 8874, 'Confusões de Leslie S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xPSpNSacmDmZDLLLxgeOGRbBGU3.jpg'),
(123678, 8874, 'Confusões de Leslie S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/srwc7G8CSuRud4NoDtTAuujY45u.jpg'),
(123679, 8874, 'Confusões de Leslie S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uExjhwKVDtV4puKUIBY17n5uU5F.jpg'),
(123680, 8874, 'Confusões de Leslie S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v4bU1abHSKZN0c4y9u0t7sehGd2.jpg'),
(123681, 8874, 'Confusões de Leslie S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ePXAoCSpYgqSThQ571psI3rgxH.jpg'),
(123682, 8874, 'Confusões de Leslie S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x4ke0ziwB7t97NwslfNNwGLRt19.jpg'),
(123683, 8874, 'Confusões de Leslie S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sOPRTqKW4JYEHNNezigZHSM3dsp.jpg'),
(123684, 8874, 'Confusões de Leslie S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mnw0el2H7AQl1i3RSQjuSzjznBj.jpg'),
(123685, 8874, 'Confusões de Leslie S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5kOAMTWX7UCzFzlYqpWNqRTn3r5.jpg'),
(123686, 8874, 'Confusões de Leslie S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nsLNHxCW2YiNeNzMr0m5YTlbU9D.jpg'),
(123687, 8874, 'Confusões de Leslie S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8eJ6bIEKfalNZp9ojsJvgFEPCYm.jpg'),
(123688, 8874, 'Confusões de Leslie S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/239265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jsaNGcZPLIcL5uyvEYzialutJJh.jpg'),
(123689, 8874, 'Confusões de Leslie S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/239266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Xy0aK6A1Ia9ZLVQEkjc5bqCDgR.jpg'),
(123690, 8874, 'Confusões de Leslie S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/239267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nKGBKuRetawguVzmSJO0vmdfKRR.jpg'),
(123691, 8874, 'Confusões de Leslie S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/239268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eDbky30oJpzIjLlPXBlMTkOQQZi.jpg'),
(123692, 8874, 'Confusões de Leslie S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/239269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d9EQJmZb45LiQoYzFDKfKpQKpoP.jpg'),
(123693, 8874, 'Confusões de Leslie S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/239270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gHvPMw3GMGuACFADh4fKK8RQKlP.jpg'),
(123694, 8874, 'Confusões de Leslie S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/239271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dHcTELFzjDmwb8fqNfXF2uAhPsO.jpg'),
(123695, 8874, 'Confusões de Leslie S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/239272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Du8MBmew9Lb8v2GgaDAUPMmll.jpg'),
(123696, 8874, 'Confusões de Leslie S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/239273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qDpuiKDxylzF0VEz5khXqHG3xGl.jpg'),
(123697, 8875, 'Confusões de Leslie S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1IU6BqFgUhTPYrvAh0pJ1kgh3BM.jpg'),
(123698, 8875, 'Confusões de Leslie S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qjJtXKOasnTuee4iuNPVYkvFLEU.jpg'),
(123699, 8875, 'Confusões de Leslie S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cGcbFXL4SS6YyDFeV4CArvU1erj.jpg'),
(123700, 8875, 'Confusões de Leslie S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hYQx6P8i91YcAZCtmIRtaxlBPxp.jpg'),
(123701, 8875, 'Confusões de Leslie S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gfDcEhEDUFzAqXvKccI6ILuNQ4Q.jpg'),
(123702, 8875, 'Confusões de Leslie S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5n6xm4gpIDl4oJnjOkO6k34Qk3e.jpg'),
(123703, 8875, 'Confusões de Leslie S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQagjmq20NZLxwiqIy3m9OYdeo1.jpg'),
(123704, 8875, 'Confusões de Leslie S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cdFOLlPPUTtlh3NfAyxZnDUAiXS.jpg'),
(123705, 8875, 'Confusões de Leslie S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qcfWtuqlBkHs9na1K5XizsEIPVT.jpg'),
(123706, 8875, 'Confusões de Leslie S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1XUlvMFBk9eYXPsDm6oOCrgHJqn.jpg'),
(123707, 8875, 'Confusões de Leslie S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4WG0X25bsA6uIqLiBYBQJVjRzwv.jpg'),
(123708, 8875, 'Confusões de Leslie S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iIM2EjDCuOVUTsJkuFmEBdQJpsz.jpg'),
(123709, 8875, 'Confusões de Leslie S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nbDXxgvnA59Ks5F3vX9hiDawmto.jpg'),
(123710, 8876, 'Akuma kun S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dD2ejf3HBntcuq8ca9FiznemjDW.jpg'),
(123711, 8876, 'Akuma kun S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7gVjg3Ws38iXvVikCTWMtQmJ67O.jpg'),
(123712, 8876, 'Akuma kun S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p7F2PDbrCYGuxQBvV9DSbbWzvHh.jpg'),
(123713, 8876, 'Akuma kun S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shtNuBNBU8QM8mXlKrJxecoAJsx.jpg'),
(123714, 8876, 'Akuma kun S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/802gsiw1QO7iCMs43cBP3pxLa5t.jpg'),
(123715, 8876, 'Akuma kun S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pb2lZUk5yz7l8HDjw4a1EVMMYlT.jpg'),
(123716, 8876, 'Akuma kun S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yaMHmAufVdSg456zzlpV8QHpV67.jpg'),
(123717, 8876, 'Akuma kun S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kWHNpdyixSVWq6Y5NLzYhS2HQk9.jpg'),
(123718, 8876, 'Akuma kun S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5I0MHGkaoPQf909aq8jkz7m5Yc6.jpg'),
(123719, 8876, 'Akuma kun S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ZDU6rqk45tX6ku2hRtOPIu1Gat.jpg'),
(123720, 8876, 'Akuma kun S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gxnRRusJNcREdAbAlO5JVcbWTRl.jpg'),
(123721, 8876, 'Akuma kun S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ktmrxz6vVSMG8c2S0wRHdzpt7t.jpg'),
(123722, 8877, 'Bella e os Bulldogs S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123723, 8877, 'Bella e os Bulldogs S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123724, 8877, 'Bella e os Bulldogs S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123725, 8877, 'Bella e os Bulldogs S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cvL9x0K8m9UknuLa9jq9sOx2sZd.jpg'),
(123726, 8877, 'Bella e os Bulldogs S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123727, 8877, 'Bella e os Bulldogs S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kd2DJE6t5JI669DINVOQMDUqzGJ.jpg'),
(123728, 8877, 'Bella e os Bulldogs S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123729, 8877, 'Bella e os Bulldogs S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123730, 8877, 'Bella e os Bulldogs S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123731, 8877, 'Bella e os Bulldogs S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zg3Bbv3IW7a4iHqi4BwW92qmXvI.jpg'),
(123732, 8877, 'Bella e os Bulldogs S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5TbWAA4cHikm0pSezx0S5opOqfR.jpg'),
(123733, 8877, 'Bella e os Bulldogs S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jq4FXnIQJeTzxtMpCG3UptxmOyr.jpg'),
(123734, 8877, 'Bella e os Bulldogs S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/84oG1wuXYc62FWUJs2E58JgquLs.jpg'),
(123735, 8877, 'Bella e os Bulldogs S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/239123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FyGyqPvaHoceNAVk8pvc2vucu1.jpg'),
(123736, 8877, 'Bella e os Bulldogs S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/239124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1cdvWFfJEAwuojz6jffN5k3g421.jpg'),
(123737, 8877, 'Bella e os Bulldogs S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/239125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g5WK0yWdjoS1hQjs6nmWvJMt08V.jpg'),
(123738, 8877, 'Bella e os Bulldogs S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/239126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eTUZDsIh5wosvv3O1TqHhuET0Vw.jpg'),
(123739, 8877, 'Bella e os Bulldogs S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/239127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1NdmLeal0M8mu8TgZdOJX8nT0GE.jpg'),
(123740, 8877, 'Bella e os Bulldogs S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/239128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ahMQNB2374r4rpymxNvWm6ro5JA.jpg'),
(123741, 8877, 'Bella e os Bulldogs S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/239129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123742, 8878, 'Bella e os Bulldogs S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123743, 8878, 'Bella e os Bulldogs S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123744, 8878, 'Bella e os Bulldogs S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(123745, 8878, 'Bella e os Bulldogs S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123746, 8878, 'Bella e os Bulldogs S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/WbDEmSTw66gNun5JsDf4wvd1Od.jpg'),
(123747, 8878, 'Bella e os Bulldogs S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123748, 8878, 'Bella e os Bulldogs S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123749, 8878, 'Bella e os Bulldogs S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123750, 8878, 'Bella e os Bulldogs S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123751, 8878, 'Bella e os Bulldogs S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123752, 8878, 'Bella e os Bulldogs S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/239140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123753, 8878, 'Bella e os Bulldogs S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/239141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123754, 8878, 'Bella e os Bulldogs S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/239142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123755, 8878, 'Bella e os Bulldogs S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/239143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123756, 8878, 'Bella e os Bulldogs S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/239144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123757, 8878, 'Bella e os Bulldogs S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/239145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123758, 8878, 'Bella e os Bulldogs S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/239146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123759, 8878, 'Bella e os Bulldogs S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/239147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123760, 8878, 'Bella e os Bulldogs S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/239148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123761, 8878, 'Bella e os Bulldogs S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/239149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVLc4ICHDq68C6Z5v24ggAhCHa.jpg'),
(123762, 8879, 'De La Calle S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/anfXJwxuVT3EpDuZv0pBi2SxWVP.jpg'),
(123763, 8879, 'De La Calle S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYuYTHAArZmdT5KinpGIzK4tQxo.jpg'),
(123764, 8879, 'De La Calle S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYuYTHAArZmdT5KinpGIzK4tQxo.jpg'),
(123765, 8879, 'De La Calle S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYuYTHAArZmdT5KinpGIzK4tQxo.jpg'),
(123766, 8879, 'De La Calle S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYuYTHAArZmdT5KinpGIzK4tQxo.jpg'),
(123767, 8879, 'De La Calle S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYuYTHAArZmdT5KinpGIzK4tQxo.jpg'),
(123768, 8879, 'De La Calle S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYuYTHAArZmdT5KinpGIzK4tQxo.jpg'),
(123769, 8879, 'De La Calle S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYuYTHAArZmdT5KinpGIzK4tQxo.jpg'),
(123770, 8880, 'Encontrados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8LLCQPFwmbAQLMEUWL6A542cTD2.jpg'),
(123771, 8880, 'Encontrados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hmdJFHEBp6pIZtVX6FY3Tlp2PUJ.jpg'),
(123772, 8880, 'Encontrados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2kqjmDJwLEROor4sq0ZBlUGdNxA.jpg'),
(123773, 8880, 'Encontrados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9jjN7ggNgGrFhHNAxmVNgmBtRZ6.jpg'),
(123774, 8880, 'Encontrados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rVyEHuyONrSs0YbqBCqgET9pRNK.jpg'),
(123775, 8880, 'Encontrados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123776, 8880, 'Encontrados S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123777, 8880, 'Encontrados S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123778, 8880, 'Encontrados S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/262665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123779, 8880, 'Encontrados S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/262666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123780, 8880, 'Encontrados S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/262667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123781, 8880, 'Encontrados S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/262668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123782, 8880, 'Encontrados S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/262669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123783, 8881, 'Encontrados S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/478370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123784, 8881, 'Encontrados S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/483215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123785, 8881, 'Encontrados S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/491327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123786, 8881, 'Encontrados S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/492869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123787, 8881, 'Encontrados S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/499160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123788, 8881, 'Encontrados S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/514508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123789, 8881, 'Encontrados S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/514509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123790, 8881, 'Encontrados S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/514510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123791, 8881, 'Encontrados S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/675810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123792, 8881, 'Encontrados S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/679838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123793, 8881, 'Encontrados S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/687701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123794, 8881, 'Encontrados S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/702036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123795, 8881, 'Encontrados S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/707902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123796, 8881, 'Encontrados S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/718599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123797, 8881, 'Encontrados S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/730539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123798, 8881, 'Encontrados S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/742785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123799, 8881, 'Encontrados S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/767600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123800, 8881, 'Encontrados S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/776800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123801, 8881, 'Encontrados S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/780749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123802, 8881, 'Encontrados S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/796090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123803, 8881, 'Encontrados S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/801451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123804, 8881, 'Encontrados S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/813442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(123805, 8882, 'Fazendas e Sonhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nixNlJOHN9jkPcPyql1I8c2AElb.jpg'),
(123806, 8882, 'Fazendas e Sonhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nixNlJOHN9jkPcPyql1I8c2AElb.jpg'),
(123807, 8882, 'Fazendas e Sonhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nixNlJOHN9jkPcPyql1I8c2AElb.jpg'),
(123808, 8882, 'Fazendas e Sonhos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nixNlJOHN9jkPcPyql1I8c2AElb.jpg'),
(123809, 8882, 'Fazendas e Sonhos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nixNlJOHN9jkPcPyql1I8c2AElb.jpg'),
(123810, 8882, 'Fazendas e Sonhos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nixNlJOHN9jkPcPyql1I8c2AElb.jpg'),
(123811, 8883, 'Vai Processar [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/239086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y34hLUYbj6v8plp9LJ1IaeUBrGM.jpg'),
(123812, 8883, 'Vai Processar [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/239087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yayDAqWN0CvGb6tmtoAsEjjSmct.jpg'),
(123813, 8883, 'Vai Processar [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/239088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s4auE9SkiC7CsocghfyOKnduZ0N.jpg'),
(123814, 8883, 'Vai Processar [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/239089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAQlHOp8gqhTgcu3IlXct0AyfZA.jpg'),
(123815, 8883, 'Vai Processar [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/239090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/93FjuGRGYScDQIhlGv0ZAXZt0eP.jpg'),
(123816, 8883, 'Vai Processar [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/239091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/klPrKceKMofLdU9t54hj6VPtpNN.jpg'),
(123817, 8883, 'Vai Processar [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/239092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/JbjGCQx1lPkZcLDvJo6hzKhqoT.jpg'),
(123818, 8883, 'Vai Processar [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/239093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/MU6sI2eFA6HDlh1H7AZqnzDaY9.jpg'),
(123819, 8883, 'Vai Processar [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/239094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7bltQuh2MgtCTQFUE3xVaq7hpPu.jpg'),
(123820, 8883, 'Vai Processar [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/239095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ZjDeHuJY0a2icsxKIcya0KH52g.jpg'),
(123821, 8884, '007 Estrada para o Milhao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/thWH3TY0Tq5Nc963AG4hzqBJHAY.jpg'),
(123822, 8884, '007 Estrada para o Milhao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8I80o1PT0tvahLlD6LoRR9W8rJ5.jpg'),
(123823, 8884, '007 Estrada para o Milhao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zPEoZHUfRUFZUpMPx7X0uHz0n3W.jpg'),
(123824, 8884, '007 Estrada para o Milhao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8bmJibzar1jwDtUse0bzFGfadTN.jpg'),
(123825, 8884, '007 Estrada para o Milhao [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eOuwbM3FA5J61dnbO2glKRkf6yK.jpg'),
(123826, 8884, '007 Estrada para o Milhao [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o0aLL4SPaY1vdn39BrNSzAjfuzs.jpg'),
(123827, 8884, '007 Estrada para o Milhao [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7XE9jXMy5by4nJDCClVJstpZEkN.jpg'),
(123828, 8884, '007 Estrada para o Milhao [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8laG10L6VjE30IR8HEK0tqdkMjn.jpg'),
(123829, 8885, '007 Estrada para o Milhao [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/882857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3zpKGjsVn3wRT4RtU34e0GKcooH.jpg'),
(123830, 8885, '007 Estrada para o Milhao [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/882858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3zpKGjsVn3wRT4RtU34e0GKcooH.jpg'),
(123831, 8885, '007 Estrada para o Milhao [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/882859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3zpKGjsVn3wRT4RtU34e0GKcooH.jpg'),
(123832, 8885, '007 Estrada para o Milhao [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/882860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3zpKGjsVn3wRT4RtU34e0GKcooH.jpg'),
(123833, 8885, '007 Estrada para o Milhao [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/882861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3zpKGjsVn3wRT4RtU34e0GKcooH.jpg'),
(123834, 8885, '007 Estrada para o Milhao [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/882862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3zpKGjsVn3wRT4RtU34e0GKcooH.jpg'),
(123835, 8885, '007 Estrada para o Milhao [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/882863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3zpKGjsVn3wRT4RtU34e0GKcooH.jpg'),
(123836, 8885, '007 Estrada para o Milhao [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/882864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3zpKGjsVn3wRT4RtU34e0GKcooH.jpg'),
(123837, 8886, 'Amor Aqui e Agora [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6CfXBHk1NKV3zmLiHWOYWMjMPry.jpg'),
(123838, 8886, 'Amor Aqui e Agora [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tprjdIQKf4gv9myl2y3KdQTrFwq.jpg'),
(123839, 8886, 'Amor Aqui e Agora [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kQjqEE1a4x88yo8DVO7p66m6loU.jpg'),
(123840, 8886, 'Amor Aqui e Agora [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/69VySeEOhivtRKTqMUzfEAw22wD.jpg'),
(123841, 8886, 'Amor Aqui e Agora [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4PmfHJ7UubDtyVUWkCJFFwf2u6j.jpg'),
(123842, 8886, 'Amor Aqui e Agora [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gyfE5oHC2SDX4hPAbeZlmSewBGw.jpg'),
(123843, 8886, 'Amor Aqui e Agora [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yd1669GBpynRgGXRFTE72iqklDc.jpg'),
(123844, 8886, 'Amor Aqui e Agora [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Gr3yokuifkcHkmRx4XGhgB1I5h.jpg'),
(123845, 8886, 'Amor Aqui e Agora [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ixpyfpEkMBMBo9NAvdvwXDJU5XJ.jpg'),
(123846, 8886, 'Amor Aqui e Agora [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0884C1hgkx0zN9pvL5khgr3Qzp.jpg'),
(123847, 8887, 'Amor Fora da Caixa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5msqYlu7Dyd1eSSr0rMz0hvZfRd.jpg'),
(123848, 8887, 'Amor Fora da Caixa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/98U96Eu61pHLx1Tghbl0wtm8NSP.jpg'),
(123849, 8887, 'Amor Fora da Caixa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iGUFN4BfY5xK1jLqDEFMgN9IHk3.jpg'),
(123850, 8887, 'Amor Fora da Caixa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bvR8ZED1PV945L0t0tWJSTBRAOC.jpg'),
(123851, 8887, 'Amor Fora da Caixa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6pncaXwe9dfXWrdsVcv3IDyJwpb.jpg'),
(123852, 8887, 'Amor Fora da Caixa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7S0P3E8GW8HMLciAVr59SGhIBX.jpg'),
(123853, 8887, 'Amor Fora da Caixa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9rxw7VMnXgezA0PZ0BxGnjEVPz.jpg'),
(123854, 8888, 'Criminosos [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iTnFKtUmamnYnNMb8qv71DMoXT5.jpg'),
(123855, 8888, 'Criminosos [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nwOSY1ucI3BZdiBRWiuECCfk1pM.jpg'),
(123856, 8888, 'Criminosos [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sOuGNmMSON6WY5P91yeqrdXw3ty.jpg'),
(123857, 8888, 'Criminosos [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ZRy7TumNY333qQQhbjgbqMTCuh.jpg'),
(123858, 8888, 'Criminosos [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/33pGvtC5zzW8eT9hYfj9qUcNp4R.jpg'),
(123859, 8888, 'Criminosos [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d7rp82g8P5Dvq1tXhF1edboUoTm.jpg'),
(123860, 8888, 'Criminosos [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kKABxlDysuvkQyVhLglYLdCgoLo.jpg'),
(123861, 8888, 'Criminosos [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tzfkVRwJwVkawiqkmS5GpdSWmFE.jpg'),
(123862, 8889, 'Diva a Deriva S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/64fveKHpRFSRamoVvOVELHczywo.jpg'),
(123863, 8889, 'Diva a Deriva S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zGB9qRXDPNCgyOip2fj6WUkrZbV.jpg'),
(123864, 8889, 'Diva a Deriva S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hoIxD4v4OC0Aq0VjhalapvuK2Ec.jpg'),
(123865, 8889, 'Diva a Deriva S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hoIxD4v4OC0Aq0VjhalapvuK2Ec.jpg'),
(123866, 8889, 'Diva a Deriva S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hoIxD4v4OC0Aq0VjhalapvuK2Ec.jpg'),
(123867, 8889, 'Diva a Deriva S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hoIxD4v4OC0Aq0VjhalapvuK2Ec.jpg'),
(123868, 8889, 'Diva a Deriva S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hoIxD4v4OC0Aq0VjhalapvuK2Ec.jpg'),
(123869, 8889, 'Diva a Deriva S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hoIxD4v4OC0Aq0VjhalapvuK2Ec.jpg'),
(123870, 8889, 'Diva a Deriva S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hoIxD4v4OC0Aq0VjhalapvuK2Ec.jpg'),
(123871, 8889, 'Diva a Deriva S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hoIxD4v4OC0Aq0VjhalapvuK2Ec.jpg'),
(123872, 8889, 'Diva a Deriva S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hoIxD4v4OC0Aq0VjhalapvuK2Ec.jpg'),
(123873, 8889, 'Diva a Deriva S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hoIxD4v4OC0Aq0VjhalapvuK2Ec.jpg'),
(123874, 8890, 'Em Busca do Unicornio [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3w0du4SoYV3cvxGapXtn0yK2hxV.jpg'),
(123875, 8890, 'Em Busca do Unicornio [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oPRNXjorP0IZHg5gR86gUDKvWFE.jpg'),
(123876, 8890, 'Em Busca do Unicornio [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kOg9KURg2kIrvYePwZiD4Qi82Oe.jpg'),
(123877, 8890, 'Em Busca do Unicornio [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bKnCSih9uG4VJOyNjA2DRrY7fnj.jpg'),
(123878, 8890, 'Em Busca do Unicornio [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uhPuWkN73IEfsBLHnTete5ODEwt.jpg'),
(123879, 8890, 'Em Busca do Unicornio [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bOU4FZmrE5j44ZuZgSh7M2SbFhM.jpg'),
(123880, 8890, 'Em Busca do Unicornio [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oekrXIGt8XYeNnTRn2m1BGJ9ijG.jpg'),
(123881, 8890, 'Em Busca do Unicornio [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iyua60qqnaS8nEAOZqyy5UIfbtU.jpg'),
(123882, 8890, 'Em Busca do Unicornio [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEW9A38iznK0NcNRvaMUFG5gdJD.jpg'),
(123883, 8890, 'Em Busca do Unicornio [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/RC8gaxotpwFoGbetUJbXpKjSQ8.jpg'),
(123884, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/slwxhhmA44bVhcvCt2j28FPg2Bm.jpg'),
(123885, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gYQzwO0O4dLeFwHbVCjfgZz0cQN.jpg'),
(123886, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmEsWIEflC9GKtaBEyAb4XDVKoS.jpg'),
(123887, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sgiRXsGFokII9R0GFxCtkwxi7Oa.jpg'),
(123888, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mSFNUHAs1cyOt7TWp6itjjkzuFs.jpg'),
(123889, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7G80cppFXwqZ2vGqtZZf9QD1Lei.jpg'),
(123890, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iXd8MILKgxrJFcZVCnhsJgcybSL.jpg'),
(123891, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZnvRmivE9tv9MeM7QVPHMkqUJJ.jpg'),
(123892, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/emZetKx9Bp7RvGhlQC2uGX3jpHJ.jpg'),
(123893, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2AznhgR5RkefrjD6Yqm0sQtD0dC.jpg'),
(123894, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/238682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vOkV7TmNhke7ew2wJevrAXnh6A6.jpg'),
(123895, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/238683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2jzfiQ3zHosYo4cxbcPl3A4QXsW.jpg'),
(123896, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/238684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cBWMVWwMyBfidY6AA1g7WrScECy.jpg'),
(123897, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/238685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/73ogwS3JGwZQ9mWVsjssAYM5H5E.jpg'),
(123898, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/238686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i5Vj8JVufl84Kk4DSY43sU7PoXH.jpg'),
(123899, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/238687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/clGrw3SLwHbiGyjHV57tIfmAnCs.jpg'),
(123900, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/238688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ynAGBPadQpOgLdyEjdJXLN8pjCR.jpg'),
(123901, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/238689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lR5xyQ6Zu16mx2trou4Chq1I7Vl.jpg'),
(123902, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/238690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bm1ndBnMJcj3ifFAR7CXg9Thszt.jpg'),
(123903, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/238691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h7S9PFHdsXtoybZJPK2DLwe1nMD.jpg'),
(123904, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/238692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gbU4HFHevPl0KcvlUKaRzw12O4H.jpg'),
(123905, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/238693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xmJUXve0FA66diFMrarSuHrkGkr.jpg'),
(123906, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/238694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a1PYgxMRYIgDZ4ErsSUBZXwDihI.jpg'),
(123907, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/238695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zfOcoLAAvy7Jax8Yhu9aGaXkAY2.jpg'),
(123908, 8891, 'Mobile Suit Gundam Iron Blooded Orphans [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/238696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8AgLpzbBdQbJaZLhS7B8gIKo2UR.jpg'),
(123909, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123910, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123911, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123912, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123913, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123914, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/238702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123915, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/238703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123916, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/238704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123917, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/238705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123918, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/238706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123919, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/238707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123920, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/238708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123921, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/238709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123922, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/238710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123923, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/238711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123924, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/238712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123925, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/238713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123926, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/238714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123927, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/238715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123928, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/238716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123929, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/238717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123930, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/238718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123931, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/238719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123932, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/238720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123933, 8892, 'Mobile Suit Gundam Iron Blooded Orphans [L] S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/238721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lw1Y8nMmcvjlB6AdUPL4A0XkcO.jpg'),
(123934, 8893, 'O Circo da Paixao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z81YAMUP6WaRvT8LMg4uLB8KjlT.jpg'),
(123935, 8893, 'O Circo da Paixao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gqbdjn5tMe3kKa3HrrVVLUwnA3I.jpg'),
(123936, 8893, 'O Circo da Paixao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gqbdjn5tMe3kKa3HrrVVLUwnA3I.jpg'),
(123937, 8893, 'O Circo da Paixao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gqbdjn5tMe3kKa3HrrVVLUwnA3I.jpg'),
(123938, 8893, 'O Circo da Paixao [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gqbdjn5tMe3kKa3HrrVVLUwnA3I.jpg'),
(123939, 8893, 'O Circo da Paixao [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gqbdjn5tMe3kKa3HrrVVLUwnA3I.jpg'),
(123940, 8893, 'O Circo da Paixao [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gqbdjn5tMe3kKa3HrrVVLUwnA3I.jpg'),
(123941, 8894, 'Pictoline A Vida Secreta da sua Mente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/238667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aPO3yPvyfO0msFcnucL0nNDU5SH.jpg'),
(123942, 8894, 'Pictoline A Vida Secreta da sua Mente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/238668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dTtH4UTxA04V1PPa94FMKGIL0IL.jpg'),
(123943, 8894, 'Pictoline A Vida Secreta da sua Mente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/238669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9pvdNgSmyEkzHRC3jt18YrrSH80.jpg'),
(123944, 8894, 'Pictoline A Vida Secreta da sua Mente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/238670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p1nsa3AQZUwQmrZmRysfiEHnoY2.jpg'),
(123945, 8894, 'Pictoline A Vida Secreta da sua Mente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/238671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fRejo4JftDkynDeBDBBthtjDWtS.jpg'),
(123946, 8895, 'Robbie Williams [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3SsTXgeFJlnPqTqzV6psQyclQlI.jpg'),
(123947, 8895, 'Robbie Williams [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzgfmhRxuaTPVF2kg03NGsPDWP2.jpg'),
(123948, 8895, 'Robbie Williams [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yN4tW6pI42uIpQ7BBzHz5lb9Gnn.jpg'),
(123949, 8895, 'Robbie Williams [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/21bOarBsi0y59dR7BfehHrrKKh7.jpg'),
(123950, 8896, 'The Curse S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/29uNsAYnKAs4VDBgEh8pX9c9ZMh.jpg'),
(123951, 8896, 'The Curse S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k2qJPaGFdyFXEEJpwG5HrmeNpjv.jpg'),
(123952, 8896, 'The Curse S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k2qJPaGFdyFXEEJpwG5HrmeNpjv.jpg'),
(123953, 8896, 'The Curse S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k2qJPaGFdyFXEEJpwG5HrmeNpjv.jpg'),
(123954, 8896, 'The Curse S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k2qJPaGFdyFXEEJpwG5HrmeNpjv.jpg'),
(123955, 8896, 'The Curse S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k2qJPaGFdyFXEEJpwG5HrmeNpjv.jpg'),
(123956, 8896, 'The Curse S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k2qJPaGFdyFXEEJpwG5HrmeNpjv.jpg'),
(123957, 8896, 'The Curse S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k2qJPaGFdyFXEEJpwG5HrmeNpjv.jpg'),
(123958, 8896, 'The Curse S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k2qJPaGFdyFXEEJpwG5HrmeNpjv.jpg'),
(123959, 8896, 'The Curse S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k2qJPaGFdyFXEEJpwG5HrmeNpjv.jpg'),
(123960, 8897, 'The Iceblade Sorcerer Shall Rule the World S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/adjfww8KtZj59vWC0HYzsrSYW85.jpg'),
(123961, 8897, 'The Iceblade Sorcerer Shall Rule the World S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zaMyy0AeDxagVU5qomQ9d2rfzE8.jpg'),
(123962, 8897, 'The Iceblade Sorcerer Shall Rule the World S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f3pDyYvryIStHwrqVDLlFdAw5po.jpg'),
(123963, 8897, 'The Iceblade Sorcerer Shall Rule the World S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aHGZON57kDAmodcbuIuW85dPHpJ.jpg'),
(123964, 8897, 'The Iceblade Sorcerer Shall Rule the World S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vVKgcOy0jhqmIGZr5NuxjXb52oE.jpg'),
(123965, 8897, 'The Iceblade Sorcerer Shall Rule the World S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hOk3BJhL115nfZzoZUMf6ZfznBN.jpg'),
(123966, 8897, 'The Iceblade Sorcerer Shall Rule the World S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8XDe5WJefnnHxgtM0O7wlv9Wgl2.jpg'),
(123967, 8897, 'The Iceblade Sorcerer Shall Rule the World S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u0AIrfmUUxSOhGcpbptmAknH8TA.jpg'),
(123968, 8897, 'The Iceblade Sorcerer Shall Rule the World S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9tnmdOnf2nQC1VRyBcFU8T3b1ma.jpg'),
(123969, 8897, 'The Iceblade Sorcerer Shall Rule the World S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/YMFqUrqRwMSaZEsxr0lQfk6aFG.jpg'),
(123970, 8897, 'The Iceblade Sorcerer Shall Rule the World S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kwpwioYm74faSaRKVwf7UnzdzW7.jpg'),
(123971, 8897, 'The Iceblade Sorcerer Shall Rule the World S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uVqsuh8qrNX8tkQDpDF7nDZdg0w.jpg'),
(123972, 8898, 'Unigata S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xgx3bVT1Bqvphi4nlc5AJ4dkNVO.jpg'),
(123973, 8898, 'Unigata S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rwvOwqDfpR5nY1O9meVuNuURLVj.jpg'),
(123974, 8898, 'Unigata S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sEyCXHRHsA3KmdmbT0jzFGlxGw2.jpg'),
(123975, 8898, 'Unigata S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3q5ETylhPFydEt9DeoHo7hYo3Jx.jpg'),
(123976, 8898, 'Unigata S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Txdeql5ZA7J8ISiIiLMDNKNl7j.jpg'),
(123977, 8898, 'Unigata S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6RdLSyZNcFWbJEDKmusgx90N1rC.jpg'),
(123978, 8898, 'Unigata S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vYDy0CWFIg4eVSzSSUqatKY7x0R.jpg'),
(123979, 8898, 'Unigata S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iccBujFc5RR4UkcDxM5woHEVu0Z.jpg'),
(123980, 8898, 'Unigata S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vfg3vqfNsnPTL6cMsSkKXoJrlWK.jpg'),
(123981, 8898, 'Unigata S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7QTWJBYtXfEMsqfYmuptvHlhQ3X.jpg'),
(123982, 8898, 'Unigata S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/99uQd3szhpr3YQ0sHbh3FhFJQMy.jpg'),
(123983, 8898, 'Unigata S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eye6AdfqyfCH8PEfNrKjYACGC68.jpg'),
(123984, 8898, 'Unigata S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nfSzNMK2fAu5FnH5JhRvNUWEc7y.jpg'),
(123985, 8898, 'Unigata S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/247834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qTsyQu7Qypd3yK4WVL68VqxsMcA.jpg'),
(123986, 8898, 'Unigata S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/247835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iAH7gPDKgqa2ZWGdihyKhoew7Xk.jpg'),
(123987, 8898, 'Unigata S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/247836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ojgKYrgIs9HMchKXssLoQERTNJ7.jpg'),
(123988, 8898, 'Unigata S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/247837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yrrSCnILxjF3ri9IAySZRq4gZDA.jpg'),
(123989, 8898, 'Unigata S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/247838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVSzayRZJFfmvZzKkTf3zX1U1CW.jpg'),
(123990, 8898, 'Unigata S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/247839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d2Nzv6d7KqeS1rEDQSGcoL8WYI4.jpg'),
(123991, 8898, 'Unigata S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/247840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wi5EwP8PNXfYusAJBlDWhQtVGyP.jpg'),
(123992, 8898, 'Unigata S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/247841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glocGPTszEKYPlGfrykqkUo7nij.jpg'),
(123993, 8898, 'Unigata S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/247842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9EBmQo8fcuO6qrsLlWul62bOJ0f.jpg'),
(123994, 8898, 'Unigata S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/247843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9U1RKxLLfk02SpMmFEFfalxuW36.jpg'),
(123995, 8898, 'Unigata S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/247844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7QT5guT5I1FzMkyay5uejaaiSTy.jpg'),
(123996, 8898, 'Unigata S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/247845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xR9cDiY3W0POMUVI99GthTjsI12.jpg'),
(123997, 8898, 'Unigata S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/247846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yfMHwp9EbuFCQeiBwrLbZX9RNmw.jpg'),
(123998, 8898, 'Unigata S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/247847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m5VyGpwNyP0wt1lCJMG6vWuCBIL.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(123999, 8898, 'Unigata S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/247848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1KnpPCHvDcZjtMexpJK9Wgy4YKq.jpg'),
(124000, 8898, 'Unigata S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/247849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sh9t9g1WSLTGlFxHHzBphuqfzyj.jpg'),
(124001, 8898, 'Unigata S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/247850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDnmhxzaQxQJY1hCv01FfBk7Yru.jpg'),
(124002, 8898, 'Unigata S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/247851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yBfUmBdvyf29VkC2xkNw6QGqjTo.jpg'),
(124003, 8898, 'Unigata S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/247852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7jWc5XnTViTyMRGDtJ4DNk9wvnv.jpg'),
(124004, 8898, 'Unigata S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/247853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sWfge1IZ3jGB7qOfXQQ8WabnTNQ.jpg'),
(124005, 8898, 'Unigata S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/247854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4mRUpkzRKrp8h6C4DBmKblSF0rA.jpg'),
(124006, 8898, 'Unigata S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/247855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qIindFMAOrEyS0VIOCD7oHHuczE.jpg'),
(124007, 8898, 'Unigata S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/247856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fLE6iQiPugpYwTfLhFOiKHJ7I8j.jpg'),
(124008, 8898, 'Unigata S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/247857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sy72BywFpkYKghsjaQggYM28Coi.jpg'),
(124009, 8898, 'Unigata S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/247858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xDI6Qih2FyIOWdu6uu5kaNdZjOT.jpg'),
(124010, 8898, 'Unigata S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/247859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hCqhWoMSEM0GmwVXGpf2zQWJxZn.jpg'),
(124011, 8898, 'Unigata S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/247860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/olzFKwcf7pQ3aop4KUNrBrr9x7f.jpg'),
(124012, 8899, 'Unigata S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dI1Pwn4uTEpnU2zZSfAiFXvkczB.jpg'),
(124013, 8899, 'Unigata S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qrgpKSGuiRlmOmca3TrYTbINbX7.jpg'),
(124014, 8899, 'Unigata S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iv4s8ppeNhxRZV8pIV6R2ON2DOi.jpg'),
(124015, 8899, 'Unigata S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lYRNhjqIkkJh2UUSgC34LyGINL1.jpg'),
(124016, 8899, 'Unigata S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/meBbqsq8e4sfDAGHcQ7CH8ZxKto.jpg'),
(124017, 8899, 'Unigata S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hXkVMDQBtQP2DKwaGR6HuoXvAR1.jpg'),
(124018, 8899, 'Unigata S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2H1q03ahfS7UwvHPh6uTCJ8q5nn.jpg'),
(124019, 8899, 'Unigata S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eI4lOWF7qM8HSo4qZchptBxOK6N.jpg'),
(124020, 8899, 'Unigata S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4dZi5pJUFpEcVeZO6uXHhc19AUA.jpg'),
(124021, 8899, 'Unigata S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7OMmueBmWhWvRhZgZEhgKS490M.jpg'),
(124022, 8899, 'Unigata S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7tkdc9eQos9nhNsj2ZiliPQazBw.jpg'),
(124023, 8899, 'Unigata S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iYQq0GuFDuVWSUBOp3UeCz0HGKO.jpg'),
(124024, 8899, 'Unigata S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jJULJxyfE2v1J7MIA8ElXmj1j62.jpg'),
(124025, 8899, 'Unigata S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/247874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9NvIaRcTxgGkWr42SZW4swgPF33.jpg'),
(124026, 8899, 'Unigata S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/247875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7M3mojnKreGlxr9Oq9FqBO6DhaW.jpg'),
(124027, 8899, 'Unigata S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/247876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tFila6RSTphK3WX3rerR6BxyWiS.jpg'),
(124028, 8899, 'Unigata S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/247877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2T9cRJ38OqGwHLYWrFRBn3RmnFc.jpg'),
(124029, 8899, 'Unigata S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/247878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vddiTxCPeRYzTOvnKcjetGHFrQU.jpg'),
(124030, 8899, 'Unigata S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/247879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uYljdcbQ4minYl8yJqkEpBO8f1i.jpg'),
(124031, 8899, 'Unigata S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/247880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8FpmvoGLJVchg5anH3z7zym3mS6.jpg'),
(124032, 8899, 'Unigata S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/247881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Hn2nl6rEuGAyNkLSW23bObsdtQ.jpg'),
(124033, 8899, 'Unigata S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/247882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hUNRxHAY44qXBphLKgZlEawnysy.jpg'),
(124034, 8899, 'Unigata S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/247883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lHhpXxHRWoQb8Jr3x6IEO4G7xZ.jpg'),
(124035, 8899, 'Unigata S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/247884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFetm1BEkHhXp14PbTLsVdMhUiN.jpg'),
(124036, 8899, 'Unigata S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/247885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hixU4V0dcvdLgClW5Ghsij8X4Qg.jpg'),
(124037, 8899, 'Unigata S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/247886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ZfLtalJieTB3wo7KDqvy7K6uSI.jpg'),
(124038, 8899, 'Unigata S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/247887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/otSPQDUuhhw2ygKy3fl7tisliaH.jpg'),
(124039, 8899, 'Unigata S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/247888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rjJdYhmWbY932YixJCg4JcxxX7F.jpg'),
(124040, 8899, 'Unigata S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/247889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nhmSSmhzJGBNa4aAF5OEsbxLgbL.jpg'),
(124041, 8899, 'Unigata S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/247890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p0FDBfczEzMk9fDienlVkAF94XT.jpg'),
(124042, 8899, 'Unigata S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/247891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGaJV2wI6XyZzV9UsfGtrWpQhGK.jpg'),
(124043, 8899, 'Unigata S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/247892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ljpuHzXr9rLI38dYQetqVrXkPBv.jpg'),
(124044, 8899, 'Unigata S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/247893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8aGFec5KwFkh4pXHAxuBv6nGAhu.jpg'),
(124045, 8899, 'Unigata S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/247894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOyt3iepsHXB7342nz24Tq9yiV2.jpg'),
(124046, 8899, 'Unigata S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/247895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/drUcZXbcW9aTb28gUGgh9n6ozga.jpg'),
(124047, 8899, 'Unigata S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/247896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6asHNfXTTAv1U171BfwyJCzABzn.jpg'),
(124048, 8899, 'Unigata S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/247897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uQtFsYSNjH0mbZ4SDJaeYmCMxio.jpg'),
(124049, 8899, 'Unigata S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/247898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xHivxGr5WTyFyVSq4xYisXOdpZ3.jpg'),
(124050, 8899, 'Unigata S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/247899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFIK7MRDW4Pc34BqRRsui4SSVtj.jpg'),
(124051, 8900, 'Unigata S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qQGSCuwSNPhhC9qoDuSsAJdP9kx.jpg'),
(124052, 8900, 'Unigata S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2bbh54KBFE9unLttU93g9hSkd7V.jpg'),
(124053, 8900, 'Unigata S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dGX0xWM4mLyQnBtWig09sXfI2b3.jpg'),
(124054, 8900, 'Unigata S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ur478kC45r2rOji2G2mJ2TgrLvh.jpg'),
(124055, 8900, 'Unigata S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w9JAlXmLmFw3jWBqqIDF0Xt4RlS.jpg'),
(124056, 8900, 'Unigata S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pUeaB6tALZiGqVX0jn4mtcGTc6Y.jpg'),
(124057, 8900, 'Unigata S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jxQvaHwt7u4eKSfOkHMkjX4eBl2.jpg'),
(124058, 8900, 'Unigata S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iQNuIm9IdRGKf3UJz5iswxh0JBL.jpg'),
(124059, 8900, 'Unigata S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kea07SPPwUckUwAi9oShhqcBqLf.jpg'),
(124060, 8900, 'Unigata S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3lQJFUPr7kd5xFNRTFTC3hi0OO5.jpg'),
(124061, 8900, 'Unigata S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rubZCs36UvbW9G8Rn2kV2gJyux.jpg'),
(124062, 8900, 'Unigata S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i0PEB5yykaJIjXNUSGDPkUxvH5m.jpg'),
(124063, 8900, 'Unigata S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Df7TsBPEe3xmAqRZcg5NVuLRAR.jpg'),
(124064, 8900, 'Unigata S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/247913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rlGccstPWLfDqLHNjlhd22slPyN.jpg'),
(124065, 8900, 'Unigata S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/247914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/emMrlzfVdK1NA3lpHFjD0oX1IxY.jpg'),
(124066, 8900, 'Unigata S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/247915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u3O3nDIa2KzEIh3E3MIlhabmwBe.jpg'),
(124067, 8900, 'Unigata S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/247916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/U39Rb6ZOQbOrULgrvlqTxVWUSw.jpg'),
(124068, 8900, 'Unigata S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/247917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6lT91xtupSOUcjTOR1weDM0fTqk.jpg'),
(124069, 8900, 'Unigata S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/247918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9iOyqu3G5XNIgW7CxKkc6Gzebi8.jpg'),
(124070, 8900, 'Unigata S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/247919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dPRrBHQopKr4F5QnurAFiIYIkI3.jpg'),
(124071, 8900, 'Unigata S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/247920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ipmsQON427ynjngUKd5XjFr1BtV.jpg'),
(124072, 8900, 'Unigata S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/247921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nZC4fQop9q510EZIRpGVAVspjFt.jpg'),
(124073, 8900, 'Unigata S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/247922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lQDf7wR2rtst27byvST4r3m4jWd.jpg'),
(124074, 8900, 'Unigata S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/247923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFypIGTP2WrZdQDN3kqL4Q5IfNv.jpg'),
(124075, 8901, 'Vigilante [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/497LrWMCZMwSvo1m4tVajz1ZGMZ.jpg'),
(124076, 8901, 'Vigilante [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nIwENhmkT16OrxcIHqhKDEZslHC.jpg'),
(124077, 8901, 'Vigilante [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pgvRl9Bkq7ccIIzBemzVTbJElZT.jpg'),
(124078, 8901, 'Vigilante [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pgvRl9Bkq7ccIIzBemzVTbJElZT.jpg'),
(124079, 8901, 'Vigilante [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pgvRl9Bkq7ccIIzBemzVTbJElZT.jpg'),
(124080, 8901, 'Vigilante [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pgvRl9Bkq7ccIIzBemzVTbJElZT.jpg'),
(124081, 8901, 'Vigilante [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pgvRl9Bkq7ccIIzBemzVTbJElZT.jpg'),
(124082, 8901, 'Vigilante [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pgvRl9Bkq7ccIIzBemzVTbJElZT.jpg'),
(124083, 8902, 'A Mao do Eurico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fh7xHJ43luudlRENEdBXRVaX8U4.jpg'),
(124084, 8902, 'A Mao do Eurico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fh7xHJ43luudlRENEdBXRVaX8U4.jpg'),
(124085, 8902, 'A Mao do Eurico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fh7xHJ43luudlRENEdBXRVaX8U4.jpg'),
(124086, 8902, 'A Mao do Eurico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fh7xHJ43luudlRENEdBXRVaX8U4.jpg'),
(124087, 8902, 'A Mao do Eurico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fh7xHJ43luudlRENEdBXRVaX8U4.jpg'),
(124088, 8903, 'Assassinato no Fim do Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dNS5N20wowE6EoxEWwxzqviLGzo.jpg'),
(124089, 8903, 'Assassinato no Fim do Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qiHJdGNgiHD760vIZvMejtmPDaH.jpg'),
(124090, 8903, 'Assassinato no Fim do Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/547YhZEJyUsQbYJgxJdngRolvcp.jpg'),
(124091, 8903, 'Assassinato no Fim do Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/547YhZEJyUsQbYJgxJdngRolvcp.jpg'),
(124092, 8903, 'Assassinato no Fim do Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/547YhZEJyUsQbYJgxJdngRolvcp.jpg'),
(124093, 8903, 'Assassinato no Fim do Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/547YhZEJyUsQbYJgxJdngRolvcp.jpg'),
(124094, 8903, 'Assassinato no Fim do Mundo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/547YhZEJyUsQbYJgxJdngRolvcp.jpg'),
(124095, 8904, 'Boca do Lixo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9xRdpEdfJiWLYDocY3Fb85PIGZF.jpg'),
(124096, 8904, 'Boca do Lixo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t8GjfXGocNhohnpUqYnle80HFtC.jpg'),
(124097, 8904, 'Boca do Lixo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xlf03SWE53McMIMvnSe32PVZU1B.jpg'),
(124098, 8904, 'Boca do Lixo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/atZgRQXm5seDGen5i48KfGkkrGz.jpg'),
(124099, 8904, 'Boca do Lixo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/atZgRQXm5seDGen5i48KfGkkrGz.jpg'),
(124100, 8904, 'Boca do Lixo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/atZgRQXm5seDGen5i48KfGkkrGz.jpg'),
(124101, 8904, 'Boca do Lixo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/atZgRQXm5seDGen5i48KfGkkrGz.jpg'),
(124102, 8904, 'Boca do Lixo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/atZgRQXm5seDGen5i48KfGkkrGz.jpg'),
(124103, 8905, 'Candy Cruz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lLEqzkgWRgx4BWYt0rnL9w6GLWa.jpg'),
(124104, 8905, 'Candy Cruz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cZ6ZkyrEDu5ImLzmpRfcZhAzD6v.jpg'),
(124105, 8905, 'Candy Cruz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/alqrIllr4OaJvg7buh094fdJM6f.jpg'),
(124106, 8905, 'Candy Cruz S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4j2LDCscNs17EfPKNEeSN9YFri0.jpg'),
(124107, 8905, 'Candy Cruz S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aNQVjumbeZGo3n4FMw3u0IpHN1Y.jpg'),
(124108, 8905, 'Candy Cruz S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7H01aIKwPxjszgM3Ng6y0GKaLzO.jpg'),
(124109, 8905, 'Candy Cruz S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xrsFN3f4rTCCc2COYZAYvZiBA80.jpg'),
(124110, 8905, 'Candy Cruz S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/osPv9jCt410vwoelorODy0dbzv4.jpg'),
(124111, 8905, 'Candy Cruz S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1teFMhqnQUsCGcijHZsqzgKO43k.jpg'),
(124112, 8905, 'Candy Cruz S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oMymyajLIYv4ELqgnUndlbuZ2G6.jpg'),
(124113, 8906, 'Como Se Tornar um Chefe do Crime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qOZbdS32sNez4jpQ71pLfXylPxL.jpg'),
(124114, 8906, 'Como Se Tornar um Chefe do Crime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rfPp5WgGhvgJfazTMcfM5SVZMsX.jpg'),
(124115, 8906, 'Como Se Tornar um Chefe do Crime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wrgof7DR6b8UhcN54CxcJEbgPWb.jpg'),
(124116, 8906, 'Como Se Tornar um Chefe do Crime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2BePqUlXnlSH4eXqQvAb2eJ1gY.jpg'),
(124117, 8906, 'Como Se Tornar um Chefe do Crime S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/go6CWPYbQyTxYTlbHXZIPFMKjl1.jpg'),
(124118, 8906, 'Como Se Tornar um Chefe do Crime S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ggKj0z8uqZAfz4cDy87DRIMBAse.jpg'),
(124119, 8907, 'DNA DO CRIME S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JQtBFxDXGbGIathNQR6ncZA1VW.jpg'),
(124120, 8907, 'DNA DO CRIME S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8XnXdcJm3euFfFaWMhMIGEvrib.jpg'),
(124121, 8907, 'DNA DO CRIME S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r3E2ORYSWh9YEun9OtgkiWLg4FR.jpg'),
(124122, 8907, 'DNA DO CRIME S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lgk5SjZphRtiInQK3XLkiTkUaiO.jpg'),
(124123, 8907, 'DNA DO CRIME S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yLaqhsvo7OpcxNuOv0JxiVT7GIx.jpg'),
(124124, 8907, 'DNA DO CRIME S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nUFiBA0zPbz2L08QSoujkD0CsbB.jpg'),
(124125, 8907, 'DNA DO CRIME S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7wlCRzGx9roPN27wD6UF4ug5toW.jpg'),
(124126, 8907, 'DNA DO CRIME S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ozhBQ5gjQwhpUOGiOt3ba8NtvDw.jpg'),
(124127, 8908, 'DNA DO CRIME S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/828128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cqg7OXDPSWSCsfAs9BuBp0r7kO3.jpg'),
(124128, 8908, 'DNA DO CRIME S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/828129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cqg7OXDPSWSCsfAs9BuBp0r7kO3.jpg'),
(124129, 8908, 'DNA DO CRIME S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/828130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cqg7OXDPSWSCsfAs9BuBp0r7kO3.jpg'),
(124130, 8908, 'DNA DO CRIME S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/828131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cqg7OXDPSWSCsfAs9BuBp0r7kO3.jpg'),
(124131, 8908, 'DNA DO CRIME S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/828132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cqg7OXDPSWSCsfAs9BuBp0r7kO3.jpg'),
(124132, 8908, 'DNA DO CRIME S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/828133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cqg7OXDPSWSCsfAs9BuBp0r7kO3.jpg'),
(124133, 8908, 'DNA DO CRIME S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/828134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cqg7OXDPSWSCsfAs9BuBp0r7kO3.jpg'),
(124134, 8908, 'DNA DO CRIME S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/828135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cqg7OXDPSWSCsfAs9BuBp0r7kO3.jpg'),
(124135, 8909, 'Gargulas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nv9I18ve82Nf7EQwh9D1IiOk8wI.jpg'),
(124136, 8909, 'Gargulas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kKT2VbkqH8UUHBcQxBdGyZMQ8VO.jpg'),
(124137, 8909, 'Gargulas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uL2flnCv4fH1kxbcOJyava8PSQh.jpg'),
(124138, 8909, 'Gargulas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ilhI9Uu98BmyZIfBkWWmhI8br9p.jpg'),
(124139, 8909, 'Gargulas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzGQOchGoW5f3n7p0PqI2aKIhRz.jpg'),
(124140, 8909, 'Gargulas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gDy1JTsh0UbNbubiviWQdVE5Rur.jpg'),
(124141, 8909, 'Gargulas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eS9j1Akulri46EQrtZNRrEcMmna.jpg'),
(124142, 8909, 'Gargulas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3tNZ3yYydfrqbhK29GxNmVpnDnn.jpg'),
(124143, 8909, 'Gargulas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sVllZbUdqvFjgi8FDnHuu3VAnCG.jpg'),
(124144, 8909, 'Gargulas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e297uxX3YDf6BUuadawoyMAlUuW.jpg'),
(124145, 8909, 'Gargulas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mlPiBNlz29NytBnT3OFKFjjx5Kk.jpg'),
(124146, 8909, 'Gargulas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yLnwrzHciD08qA4Gxcoydzwqzh.jpg'),
(124147, 8909, 'Gargulas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yXTRWhXQdTBz20A1n9gINopWwhv.jpg'),
(124148, 8910, 'Gargulas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g2IneCtIF6Ygk1kOR4S00T4zike.jpg'),
(124149, 8910, 'Gargulas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dSoq3gfcNjSxzpwHf2GvKCR7fV8.jpg'),
(124150, 8910, 'Gargulas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tnKxDtL7TkynsiqPgvUoJ2SMfFC.jpg'),
(124151, 8910, 'Gargulas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1p4QiaeuEYjsZtOd5k07EFjV8HU.jpg'),
(124152, 8910, 'Gargulas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqX79vVpRR9dikCgAQe5Mvkkhjp.jpg'),
(124153, 8910, 'Gargulas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fThau2LOj3SADnnC8kQlJVZCvtD.jpg'),
(124154, 8910, 'Gargulas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZKEw1kFzdpWnh7j9cL4Qd92TYp.jpg'),
(124155, 8910, 'Gargulas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vThOoGqWZjj1NJq2MfdBMlSzyrW.jpg'),
(124156, 8910, 'Gargulas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wqXRCNd9jYlFFDiIsKs0PhBsyZi.jpg'),
(124157, 8910, 'Gargulas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xWT1h3ql9HBmucQinaxC2aMBk1m.jpg'),
(124158, 8910, 'Gargulas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yZ5l1UAGEh9wZynVf2jMSoXk5qW.jpg'),
(124159, 8910, 'Gargulas S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k6YMYIUBn1TzWeeL2lzMHeyuVal.jpg'),
(124160, 8910, 'Gargulas S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w4PD5oSVymBPmC6VK6D9PxtTMEf.jpg'),
(124161, 8910, 'Gargulas S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/247152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s58mWcndCNv6UOTZ2o1alZgdz1i.jpg'),
(124162, 8910, 'Gargulas S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/247153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jmnPgaOraZIUUiZeHYDUiyjFqPz.jpg'),
(124163, 8910, 'Gargulas S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/247154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDRgSskrA30flcY3xeAKC7L29W.jpg'),
(124164, 8910, 'Gargulas S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/247155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lXxOygmIXV0Hfd2z8fglv9DdSTh.jpg'),
(124165, 8910, 'Gargulas S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/247156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzvGXfJp5iFacGWoT4FLbIVoirJ.jpg'),
(124166, 8910, 'Gargulas S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/247157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sMcyG3mOzbiuWeShAaH5l5wbTtm.jpg'),
(124167, 8910, 'Gargulas S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/247158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/opIfueewEXT24EqaIGbS1Pl18J2.jpg'),
(124168, 8910, 'Gargulas S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/247159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4sUiJLE6h38LcL4PCFnfIZzZ8FF.jpg'),
(124169, 8910, 'Gargulas S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/247160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lI9uNbDoPm6Z5g2be3v8sStE7Er.jpg'),
(124170, 8910, 'Gargulas S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/247161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eQICkDffZNa6xtlfTeKKeMtidCc.jpg'),
(124171, 8910, 'Gargulas S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/247162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4bTFYZqVxaOSNdYTRkK5busWkOy.jpg'),
(124172, 8910, 'Gargulas S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/247163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rUXBLgg5m7SBDklgZUjcQ3UEo9C.jpg'),
(124173, 8910, 'Gargulas S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/247164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/atkpiVW9mHgBAzCxeJEKAHmfuft.jpg'),
(124174, 8910, 'Gargulas S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/247165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cGcMH6Efrd59qKQ0sI72PDARLjh.jpg'),
(124175, 8910, 'Gargulas S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/247166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/B0MF17WQycEMgoEkoy0LPFf53r.jpg'),
(124176, 8910, 'Gargulas S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/247167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQfHeW0xAUFVcLLd45snFIMchGo.jpg'),
(124177, 8910, 'Gargulas S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/247168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6QzMyGFRG8nVHj7TDr40ZNJJPw5.jpg'),
(124178, 8910, 'Gargulas S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/247169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m1WLxB1xaW6tTPhMkOq1ySZYucm.jpg'),
(124179, 8910, 'Gargulas S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/247170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wNEhMmXX0GFySXEKZrNBAvSMxSQ.jpg'),
(124180, 8910, 'Gargulas S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/247171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bImBYyirdBOxc9wegbFl4xiYmcy.jpg'),
(124181, 8910, 'Gargulas S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/247172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l5GJoxENYBX4Nd4aYGrL0vOhVSx.jpg'),
(124182, 8910, 'Gargulas S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/247173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bDgs8jYGs09joypej4Smfy6rCyA.jpg'),
(124183, 8910, 'Gargulas S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/247174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pS6IAfbrW8YcPfiQRY6mos9dHKT.jpg'),
(124184, 8910, 'Gargulas S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/247175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sGyKjB46iMI7ABHhw2UwT1UpUQB.jpg'),
(124185, 8910, 'Gargulas S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/247176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Ve9q8TltJNzfGq34sVhekDO1i9.jpg'),
(124186, 8910, 'Gargulas S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/247177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iL3gMzDIASjcDgLuAyyOqdBYSrV.jpg'),
(124187, 8910, 'Gargulas S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/247178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kd4b3p3QBDKOXWWsskP2pqiW38a.jpg'),
(124188, 8910, 'Gargulas S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/247179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k84AyanYDuEqN18LurGuR61stVe.jpg'),
(124189, 8910, 'Gargulas S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/247180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glSrW87ZxJRwc6Drgeda3KaXmN9.jpg'),
(124190, 8910, 'Gargulas S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/247181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yMbkcs3s2WIi6LDX874OQtJjrXq.jpg'),
(124191, 8910, 'Gargulas S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/247182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iBUxzZsoKOshvkSuFtM6FDCEchL.jpg'),
(124192, 8910, 'Gargulas S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/247183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yrOWgFmjsfNlrfEAUJQD9WVxUlH.jpg'),
(124193, 8910, 'Gargulas S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/247184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qmQ8jVztTDYQguDtQyYbtVLOJEM.jpg'),
(124194, 8910, 'Gargulas S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/247185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8qL3sYPmHuI26w1yQXpqNzf1cQC.jpg'),
(124195, 8910, 'Gargulas S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/247186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lEpBWQJA0ONgTkTODZMafpCqSFL.jpg'),
(124196, 8910, 'Gargulas S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/247187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d9PX7Uliau1I63vSSOIsLDTqITy.jpg'),
(124197, 8910, 'Gargulas S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/247188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/36fa0zhvoBKqZ2i4nK9RjgRS8A9.jpg'),
(124198, 8910, 'Gargulas S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/247189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qMEHSXtazvAGI9ZR6kkVoAyvMqy.jpg'),
(124199, 8910, 'Gargulas S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/247190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bcEtViHgMPJzM0dkpbc2xnA01uy.jpg'),
(124200, 8911, 'Gargulas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hNrTmVU1M2WXzGCnCCjfmCeg4sT.jpg'),
(124201, 8911, 'Gargulas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Vk0cec9ciAA1caNuJgyd1j4MJ7.jpg'),
(124202, 8911, 'Gargulas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/160yeu3CqA9JmbIRvDIBBUJfqjS.jpg'),
(124203, 8911, 'Gargulas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ku2ZX39EocOeQfC2UhdUjadseug.jpg'),
(124204, 8911, 'Gargulas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aqej44YukZoEGxPdBGP2vZCf4wu.jpg'),
(124205, 8911, 'Gargulas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eXf7KjAL6KC9YivWupE3zAmsBoW.jpg'),
(124206, 8911, 'Gargulas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rQW7h7whjc4wEx792QgnREbuEbY.jpg'),
(124207, 8911, 'Gargulas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e7MzI1SmKogY4XOrc7nl9x5ztF8.jpg'),
(124208, 8911, 'Gargulas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCv71R9L1pI8jU8e5l0fGQ9NIeo.jpg'),
(124209, 8911, 'Gargulas S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yncxg5X7JOqfDMXn7pDFLcjuHbd.jpg'),
(124210, 8911, 'Gargulas S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eLlpGSChgFVBkxkf9QJSs7EGyTE.jpg'),
(124211, 8911, 'Gargulas S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xeMYpSDAbL7sQT67lLAxaAhJLzU.jpg'),
(124212, 8911, 'Gargulas S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rrPTGFkBKgz8FuzBYqUVc7cDTaT.jpg'),
(124213, 8912, 'Let Love S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/15CwCXywMyWhDrkN7dCzrntkQgF.jpg'),
(124214, 8912, 'Let Love S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/17bM4IpDuYbSG8myTVaply20PZw.jpg'),
(124215, 8912, 'Let Love S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o3wvBPQUU4YIfMjxS4a8uryciZm.jpg'),
(124216, 8912, 'Let Love S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cRTDubgzKPXvWTU8v1oTfhgyHIe.jpg'),
(124217, 8912, 'Let Love S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wDuDPFIt5byCqyCOoQpV7OpeJHo.jpg'),
(124218, 8912, 'Let Love S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ntX13b6tcISBH8sAaIaPivXijLS.jpg'),
(124219, 8912, 'Let Love S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ntX13b6tcISBH8sAaIaPivXijLS.jpg'),
(124220, 8912, 'Let Love S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ntX13b6tcISBH8sAaIaPivXijLS.jpg'),
(124221, 8912, 'Let Love S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ntX13b6tcISBH8sAaIaPivXijLS.jpg'),
(124222, 8912, 'Let Love S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ntX13b6tcISBH8sAaIaPivXijLS.jpg'),
(124223, 8912, 'Let Love S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ntX13b6tcISBH8sAaIaPivXijLS.jpg'),
(124224, 8912, 'Let Love S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ntX13b6tcISBH8sAaIaPivXijLS.jpg'),
(124225, 8912, 'Let Love S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ntX13b6tcISBH8sAaIaPivXijLS.jpg'),
(124226, 8912, 'Let Love S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ntX13b6tcISBH8sAaIaPivXijLS.jpg'),
(124227, 8912, 'Let Love S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ntX13b6tcISBH8sAaIaPivXijLS.jpg'),
(124228, 8912, 'Let Love S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ntX13b6tcISBH8sAaIaPivXijLS.jpg'),
(124229, 8913, 'No Corre Partiu Entrega S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s3qJyVvA46eAkHt1xHqKAVCljsE.jpg'),
(124230, 8913, 'No Corre Partiu Entrega S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124231, 8913, 'No Corre Partiu Entrega S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124232, 8913, 'No Corre Partiu Entrega S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124233, 8913, 'No Corre Partiu Entrega S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124234, 8913, 'No Corre Partiu Entrega S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124235, 8913, 'No Corre Partiu Entrega S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124236, 8913, 'No Corre Partiu Entrega S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124237, 8913, 'No Corre Partiu Entrega S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124238, 8913, 'No Corre Partiu Entrega S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124239, 8913, 'No Corre Partiu Entrega S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124240, 8913, 'No Corre Partiu Entrega S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124241, 8913, 'No Corre Partiu Entrega S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124242, 8913, 'No Corre Partiu Entrega S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/248678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124243, 8913, 'No Corre Partiu Entrega S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/248679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124244, 8913, 'No Corre Partiu Entrega S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/248680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124245, 8913, 'No Corre Partiu Entrega S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/248681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124246, 8913, 'No Corre Partiu Entrega S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/248682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124247, 8913, 'No Corre Partiu Entrega S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/248683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124248, 8913, 'No Corre Partiu Entrega S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/248684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124249, 8914, 'No Corre Partiu Entrega S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/436066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124250, 8914, 'No Corre Partiu Entrega S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/436067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124251, 8914, 'No Corre Partiu Entrega S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/436068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124252, 8914, 'No Corre Partiu Entrega S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/436069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124253, 8914, 'No Corre Partiu Entrega S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/441834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124254, 8914, 'No Corre Partiu Entrega S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/441835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124255, 8914, 'No Corre Partiu Entrega S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/441836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124256, 8914, 'No Corre Partiu Entrega S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/441837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124257, 8914, 'No Corre Partiu Entrega S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/441838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124258, 8914, 'No Corre Partiu Entrega S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/444546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124259, 8914, 'No Corre Partiu Entrega S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/447264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124260, 8914, 'No Corre Partiu Entrega S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/447265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124261, 8914, 'No Corre Partiu Entrega S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/447266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124262, 8914, 'No Corre Partiu Entrega S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/447267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124263, 8914, 'No Corre Partiu Entrega S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/447268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jyOOpL7zaaFrbfpXspbbozLRTKv.jpg'),
(124264, 8915, 'O Desastre de Chernobyl S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/myb2VUOMS7TK0CfK4BqcC6cIVtr.jpg'),
(124265, 8915, 'O Desastre de Chernobyl S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dTVv07Dyu56g4Sxyxjygiqx1ObG.jpg'),
(124266, 8915, 'O Desastre de Chernobyl S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wSiqDRsIgmgFnk5IGmRgme8HW3G.jpg'),
(124267, 8916, 'O Universo Misterios Revelados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNBiBDRksSXwlueMQ7BrdcUyuDE.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(124268, 8916, 'O Universo Misterios Revelados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNBiBDRksSXwlueMQ7BrdcUyuDE.jpg'),
(124269, 8916, 'O Universo Misterios Revelados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNBiBDRksSXwlueMQ7BrdcUyuDE.jpg'),
(124270, 8916, 'O Universo Misterios Revelados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNBiBDRksSXwlueMQ7BrdcUyuDE.jpg'),
(124271, 8917, 'Os Celtas A Historia Nao Contada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKfiEONp0FU0rZBbzJlkLLr03c9.jpg'),
(124272, 8917, 'Os Celtas A Historia Nao Contada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKfiEONp0FU0rZBbzJlkLLr03c9.jpg'),
(124273, 8917, 'Os Celtas A Historia Nao Contada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hKfiEONp0FU0rZBbzJlkLLr03c9.jpg'),
(124274, 8918, 'Anderson Spider Silva S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQ9ssSTOZ7iJdSZOGDQAKJP4Dh6.jpg'),
(124275, 8918, 'Anderson Spider Silva S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r6dnAMhRIMWKL5BDwFIayv3006b.jpg'),
(124276, 8918, 'Anderson Spider Silva S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Fv5lZuGkKr8pmNC2lEW33UVYmp.jpg'),
(124277, 8918, 'Anderson Spider Silva S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9bjjaVsljnA3ybYeqAGj2hc7bDG.jpg'),
(124278, 8918, 'Anderson Spider Silva S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bXo6hJh1evVnCHKLpXPgQECIayI.jpg'),
(124279, 8919, 'Beyblade Burst Rise S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bTgxQMmfKl1Vvk0MJKGfhSQIIZP.jpg'),
(124280, 8919, 'Beyblade Burst Rise S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124281, 8919, 'Beyblade Burst Rise S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124282, 8919, 'Beyblade Burst Rise S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124283, 8919, 'Beyblade Burst Rise S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124284, 8919, 'Beyblade Burst Rise S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124285, 8919, 'Beyblade Burst Rise S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124286, 8919, 'Beyblade Burst Rise S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124287, 8919, 'Beyblade Burst Rise S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124288, 8919, 'Beyblade Burst Rise S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124289, 8919, 'Beyblade Burst Rise S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124290, 8919, 'Beyblade Burst Rise S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124291, 8919, 'Beyblade Burst Rise S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124292, 8919, 'Beyblade Burst Rise S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/247098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124293, 8919, 'Beyblade Burst Rise S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/247099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124294, 8919, 'Beyblade Burst Rise S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/247100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124295, 8919, 'Beyblade Burst Rise S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/247101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124296, 8919, 'Beyblade Burst Rise S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/247102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124297, 8919, 'Beyblade Burst Rise S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/247103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124298, 8919, 'Beyblade Burst Rise S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/247104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124299, 8919, 'Beyblade Burst Rise S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/247105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124300, 8919, 'Beyblade Burst Rise S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/247106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124301, 8919, 'Beyblade Burst Rise S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/247107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124302, 8919, 'Beyblade Burst Rise S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/247108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124303, 8919, 'Beyblade Burst Rise S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/247109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124304, 8919, 'Beyblade Burst Rise S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/247110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124305, 8920, 'Beyblade Burst Surge S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bTgxQMmfKl1Vvk0MJKGfhSQIIZP.jpg'),
(124306, 8920, 'Beyblade Burst Surge S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124307, 8920, 'Beyblade Burst Surge S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124308, 8920, 'Beyblade Burst Surge S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124309, 8920, 'Beyblade Burst Surge S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124310, 8920, 'Beyblade Burst Surge S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124311, 8920, 'Beyblade Burst Surge S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124312, 8920, 'Beyblade Burst Surge S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124313, 8920, 'Beyblade Burst Surge S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124314, 8920, 'Beyblade Burst Surge S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124315, 8920, 'Beyblade Burst Surge S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124316, 8920, 'Beyblade Burst Surge S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124317, 8920, 'Beyblade Burst Surge S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124318, 8920, 'Beyblade Burst Surge S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/247072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124319, 8920, 'Beyblade Burst Surge S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/247073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124320, 8920, 'Beyblade Burst Surge S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/247074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124321, 8920, 'Beyblade Burst Surge S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/247075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124322, 8920, 'Beyblade Burst Surge S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/247076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124323, 8920, 'Beyblade Burst Surge S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/247077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124324, 8920, 'Beyblade Burst Surge S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/247078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124325, 8920, 'Beyblade Burst Surge S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/247079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124326, 8920, 'Beyblade Burst Surge S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/247080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124327, 8920, 'Beyblade Burst Surge S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/247081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124328, 8920, 'Beyblade Burst Surge S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/247082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124329, 8920, 'Beyblade Burst Surge S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/247083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124330, 8920, 'Beyblade Burst Surge S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/247084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(124331, 8921, 'Casas Sobre Rodas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2vRTlnNF7CrFV1x0XHd3ZKJd2XD.jpg'),
(124332, 8921, 'Casas Sobre Rodas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hZbm5sliboKUmIBf07FFGDmSXFs.jpg'),
(124333, 8921, 'Casas Sobre Rodas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/JY6LQMaTeqhlByHfS6qW7b0zrX.jpg'),
(124334, 8921, 'Casas Sobre Rodas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dDFgSNuY2JfaLMg41DalS369J8N.jpg'),
(124335, 8921, 'Casas Sobre Rodas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnnCycNYQ5yrNdliPpWDZHLQXsf.jpg'),
(124336, 8921, 'Casas Sobre Rodas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bp4oUlYOxxLomEoA2TDuhYQmV9w.jpg'),
(124337, 8921, 'Casas Sobre Rodas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jfm7SwQCFkzXIeC12iFG0RVSpvm.jpg'),
(124338, 8921, 'Casas Sobre Rodas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aGINkHaNVOmJZQTcbBe9x5dDqtW.jpg'),
(124339, 8922, 'De Volta a Grande Festa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/na44SdZfVnyhm25aAmXIpv2tQuc.jpg'),
(124340, 8922, 'De Volta a Grande Festa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l2F9iO3NcU5naogPI33H0RzQFAD.jpg'),
(124341, 8922, 'De Volta a Grande Festa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBWu8Jm3CYzIHDhZ6OyttLwNKD.jpg'),
(124342, 8922, 'De Volta a Grande Festa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1d1O1RJlX63YCDTLP3uss1v5dkl.jpg'),
(124343, 8923, 'Grag Hearts Drag S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qXnnpV2B3gRpb8despGhbNB6Thk.jpg'),
(124344, 8923, 'Grag Hearts Drag S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qXnnpV2B3gRpb8despGhbNB6Thk.jpg'),
(124345, 8924, 'Homem Aranha Acao Sem Limites S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbMwjYtpyprMm6rIzysF4xzMN4l.jpg'),
(124346, 8924, 'Homem Aranha Acao Sem Limites S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kxDJqsj3rQWbw92aalchRaarnf3.jpg'),
(124347, 8924, 'Homem Aranha Acao Sem Limites S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uXFdI6U3z4TtSg2D2VS2JXCwTbZ.jpg'),
(124348, 8924, 'Homem Aranha Acao Sem Limites S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8N0OWxPhL38zvbe6LCIPuxRHAPV.jpg'),
(124349, 8924, 'Homem Aranha Acao Sem Limites S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wESC5As3eRZOlUWXDmqCC8loqji.jpg'),
(124350, 8924, 'Homem Aranha Acao Sem Limites S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zYGsauf7kMwz2BDRJeeRsbakt5U.jpg'),
(124351, 8924, 'Homem Aranha Acao Sem Limites S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lQETxWfckkdEn2AwUTVdf3XJMBL.jpg'),
(124352, 8924, 'Homem Aranha Acao Sem Limites S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wI5qo8vYoazxfuis38fle3B1gdk.jpg'),
(124353, 8924, 'Homem Aranha Acao Sem Limites S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z5b73IWJ5J2DvhiBAq7av3G7yHg.jpg'),
(124354, 8924, 'Homem Aranha Acao Sem Limites S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sk2nJrjQZHEcIjfsmlFqgrVR5ie.jpg'),
(124355, 8924, 'Homem Aranha Acao Sem Limites S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s96FqOWvlxsyx1XGTiRMTbc69Xv.jpg'),
(124356, 8924, 'Homem Aranha Acao Sem Limites S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7hkOK6Z7zzi3brVwzjUbPQiAuIM.jpg'),
(124357, 8924, 'Homem Aranha Acao Sem Limites S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/icnt9O0EVyZgmNS9VauvULhV5od.jpg'),
(124358, 7534, 'Irmaos Construtores e a Fabrica de Sonhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(124359, 7534, 'Irmaos Construtores e a Fabrica de Sonhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(124360, 7534, 'Irmaos Construtores e a Fabrica de Sonhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(124361, 7534, 'Irmaos Construtores e a Fabrica de Sonhos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(124362, 7534, 'Irmaos Construtores e a Fabrica de Sonhos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(124363, 7534, 'Irmaos Construtores e a Fabrica de Sonhos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(124364, 7534, 'Irmaos Construtores e a Fabrica de Sonhos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(124365, 7534, 'Irmaos Construtores e a Fabrica de Sonhos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(124366, 7534, 'Irmaos Construtores e a Fabrica de Sonhos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(124367, 7534, 'Irmaos Construtores e a Fabrica de Sonhos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(124368, 7534, 'Irmaos Construtores e a Fabrica de Sonhos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(124369, 7534, 'Irmaos Construtores e a Fabrica de Sonhos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(124370, 7534, 'Irmaos Construtores e a Fabrica de Sonhos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(124371, 7534, 'Irmaos Construtores e a Fabrica de Sonhos S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/247032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(124372, 7534, 'Irmaos Construtores e a Fabrica de Sonhos S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/247033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kINJzPc2FX2fH41yK02YpGX5KvH.jpg'),
(124373, 8925, 'Munich Games S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzjySp7Lsen26pL20qbaaEVZomv.jpg'),
(124374, 8925, 'Munich Games S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6E7HoEUzCnbZlVlWRcvdlD9qlGv.jpg'),
(124375, 8925, 'Munich Games S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lmBlIglcj9Odt4ycIqtmUk7y70S.jpg'),
(124376, 8925, 'Munich Games S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eLJ2UjOKpnAbYcfT3DuYBPyTMIl.jpg'),
(124377, 8925, 'Munich Games S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vDywclh8Ip3vnXIfZiQwbWNIJWD.jpg'),
(124378, 8925, 'Munich Games S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lsw2s8BbRjH6d8zZrrnLoU0FisV.jpg'),
(124379, 8926, 'Os Vingadores A Serie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/247000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r8ANLqEwO2NP9JPj0Vh4arW7aQ.jpg'),
(124380, 8926, 'Os Vingadores A Serie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/247001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uQhffGs1lsbzbi5hw8Mnc7eYqbY.jpg'),
(124381, 8926, 'Os Vingadores A Serie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/247002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m9XCipx7ha3JOkwq8aCSFAEiT0M.jpg'),
(124382, 8926, 'Os Vingadores A Serie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/247003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gD6EhCauBswYKnoeAH0pCAX9u62.jpg'),
(124383, 8926, 'Os Vingadores A Serie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/247004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z2tbTF0XpYmekrE2QF8SCxMTBf3.jpg'),
(124384, 8926, 'Os Vingadores A Serie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/247005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/phakSaeB0myMVCsJ4cnXh5xd3Gw.jpg'),
(124385, 8926, 'Os Vingadores A Serie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/247006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/25uDcST18pZak547Ig8TQwUT0kY.jpg'),
(124386, 8926, 'Os Vingadores A Serie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/247007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/epKJRukW9kgejqYCuENCGaWwug6.jpg'),
(124387, 8926, 'Os Vingadores A Serie S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/247008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9EWzmvwQcjbRgJSYyOkiSeDEUpy.jpg'),
(124388, 8926, 'Os Vingadores A Serie S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/247009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wP0GRGJxowBfVg7QbngYqY11VjX.jpg'),
(124389, 8926, 'Os Vingadores A Serie S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/247010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bfe1QyrzogYtN9qBCDoqX3Bppi3.jpg'),
(124390, 8926, 'Os Vingadores A Serie S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/247011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/geHu60HDDQBli3pDjumtimzDoOa.jpg'),
(124391, 8926, 'Os Vingadores A Serie S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/247012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p9ObUTrHRquFGUbZnEnFKcUTfU4.jpg'),
(124392, 8927, 'Relembre S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pKzd5uPuLY3kMJbMAODNV1KloKJ.jpg'),
(124393, 8927, 'Relembre S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vl13X7B3XSOl3kraU5SSotsyXU7.jpg'),
(124394, 8927, 'Relembre S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kkGLn9TmZ2iZaes1mvK7hsQX2zL.jpg'),
(124395, 8927, 'Relembre S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hVQ6tRElY501LRdCDhpGP59Kx0f.jpg'),
(124396, 8927, 'Relembre S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oD9a3W6Vdbh8xUJhu8tvAvc4PY4.jpg'),
(124397, 8928, 'So Eu e Ela S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lbXNu9SRojr9AZisfALecG6D9G8.jpg'),
(124398, 8928, 'So Eu e Ela S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lbXNu9SRojr9AZisfALecG6D9G8.jpg'),
(124399, 8928, 'So Eu e Ela S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lbXNu9SRojr9AZisfALecG6D9G8.jpg'),
(124400, 8928, 'So Eu e Ela S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lbXNu9SRojr9AZisfALecG6D9G8.jpg'),
(124401, 8928, 'So Eu e Ela S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lbXNu9SRojr9AZisfALecG6D9G8.jpg'),
(124402, 8928, 'So Eu e Ela S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lbXNu9SRojr9AZisfALecG6D9G8.jpg'),
(124403, 8928, 'So Eu e Ela S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lbXNu9SRojr9AZisfALecG6D9G8.jpg'),
(124404, 8929, 'Suburra Eterna S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yjIHli05DXCkYGHAa5OKCyMLFjQ.jpg'),
(124405, 8929, 'Suburra Eterna S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9hfrXW4wir1mq42Eht7MWgQfrrt.jpg'),
(124406, 8929, 'Suburra Eterna S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jbTPPZ0PCXT2TQ3DsJnNZPLhi4y.jpg'),
(124407, 8929, 'Suburra Eterna S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8UA08OoaRoMWuO6TxFuckwhJG4J.jpg'),
(124408, 8929, 'Suburra Eterna S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3SMVWb20TJ53MLlPRYqRxPkEgVi.jpg'),
(124409, 8929, 'Suburra Eterna S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jM0YuOa0ofRFGh47MGYEbmxSebf.jpg'),
(124410, 8929, 'Suburra Eterna S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hkz6ldKwElieE2kLcOwX5SjmJHp.jpg'),
(124411, 8929, 'Suburra Eterna S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n5lijcsUY1ovsy66oyd2IKcNLPe.jpg'),
(124412, 8930, 'Talking Tom and Friends S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bYsUVUghSz2bcDRkhnNymRKjT5M.jpg'),
(124413, 8930, 'Talking Tom and Friends S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uaRXyYZgSyfbbtgp9OdfO9KiB4X.jpg'),
(124414, 8930, 'Talking Tom and Friends S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/en0CgFq0Glkck74DibPrZUNbcmY.jpg'),
(124415, 8930, 'Talking Tom and Friends S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jqz2k0SCBTmG0vqIFt4AJxXwFRK.jpg'),
(124416, 8930, 'Talking Tom and Friends S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mqiDaq6vI8NpjbXV2ldPnrMD4cg.jpg'),
(124417, 8930, 'Talking Tom and Friends S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/llRTe4MWiGw485BrraYNABfTVsq.jpg'),
(124418, 8930, 'Talking Tom and Friends S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/basU8KuXKkBB6aWchzX3Kpx11mK.jpg'),
(124419, 8930, 'Talking Tom and Friends S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u9mvDetAjyRiv3epIIkSQfSHmZp.jpg'),
(124420, 8930, 'Talking Tom and Friends S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tFGVY5kxW1SJ0ECUwhmlRh6AYRo.jpg'),
(124421, 8930, 'Talking Tom and Friends S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Ov5FqiKXIfMaEPlOudfFVx6AAO.jpg'),
(124422, 8930, 'Talking Tom and Friends S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Ov5FqiKXIfMaEPlOudfFVx6AAO.jpg'),
(124423, 8930, 'Talking Tom and Friends S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kwVq1bajL0JzrgivAnr1T6ztrye.jpg'),
(124424, 8930, 'Talking Tom and Friends S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/246914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eNBYeYIY9bYAAB05PJ0U2K4N081.jpg'),
(124425, 8930, 'Talking Tom and Friends S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/246915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2bPBFULS5YGuhegnjoeD9eEA3x0.jpg'),
(124426, 8930, 'Talking Tom and Friends S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/246916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bWMb09niRDFavotJMwtKVes1s62.jpg'),
(124427, 8930, 'Talking Tom and Friends S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/246917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vigrn6tMyczylnRAu9vvB6mFhXz.jpg'),
(124428, 8930, 'Talking Tom and Friends S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/246918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/luNteevo2rQV60GQkMw51syYErJ.jpg'),
(124429, 8930, 'Talking Tom and Friends S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/246919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j4Xz7JNiyXQXP5XbJ10qNm0GEt3.jpg'),
(124430, 8930, 'Talking Tom and Friends S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/246920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udubDi4Nl9Ayk6PT7FdNc5T6qnF.jpg'),
(124431, 8930, 'Talking Tom and Friends S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/246921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dV7lvTb4bWkFyckjl2NV9zbmCYK.jpg'),
(124432, 8930, 'Talking Tom and Friends S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/246922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xvp9LbAu9PvwlyIWLEfOZDfAUzQ.jpg'),
(124433, 8930, 'Talking Tom and Friends S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/246923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rcFaLPckil0GYZEhUjrTaKYba1W.jpg'),
(124434, 8930, 'Talking Tom and Friends S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/246924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ftXKkAWgEV8oAmEg2teNDtlHIcn.jpg'),
(124435, 8930, 'Talking Tom and Friends S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/246925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hriaZ2fQSaYwp3Vh4Di0ltIYqmj.jpg'),
(124436, 8930, 'Talking Tom and Friends S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/246926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2vGftzCFCCTkDMZIUrP3tmZUqJO.jpg'),
(124437, 8930, 'Talking Tom and Friends S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/246927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sRZzLAMIQAjdK2HN50qhT9k8ZZM.jpg'),
(124438, 8930, 'Talking Tom and Friends S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/246928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/WXQC6cagBr5UpU8DXN6rtd7lXp.jpg'),
(124439, 8930, 'Talking Tom and Friends S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/246929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ceuPQ6uw0NMsb3WhxT1X9XykYdY.jpg'),
(124440, 8930, 'Talking Tom and Friends S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/246930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a8XqusqOC9Bm1Y24cWaRNrDkhR2.jpg'),
(124441, 8930, 'Talking Tom and Friends S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/246931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zp0aa98ieS4BLUtR4iRCwSR7YiD.jpg'),
(124442, 8930, 'Talking Tom and Friends S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/246932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qz6HztBRW6RtSbfjxpqjiF8ydbJ.jpg'),
(124443, 8930, 'Talking Tom and Friends S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/246933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lpFgURY7XsoNSoCnQ14cGKx3y41.jpg'),
(124444, 8930, 'Talking Tom and Friends S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/246934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kp3koKZmL2kKPYNl5D24Ie69ipa.jpg'),
(124445, 8930, 'Talking Tom and Friends S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/246935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xmPSgir7olprAwPMmNTpJyniwkX.jpg'),
(124446, 8930, 'Talking Tom and Friends S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/246936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QH2maJrqngfRb9Ke4ViBM2RF3x.jpg'),
(124447, 8930, 'Talking Tom and Friends S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/246937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/stx2aypLCAGlKtmBco73acQxPZo.jpg'),
(124448, 8930, 'Talking Tom and Friends S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/246938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ajH1c7WOzyLZJbiW1PcAFNqxNmv.jpg'),
(124449, 8930, 'Talking Tom and Friends S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/246939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cpXy6bfy5CoU980aB1gZQge4Y8E.jpg'),
(124450, 8930, 'Talking Tom and Friends S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/246940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n0r7UETNAhvokKLyPQxnv6ySLzw.jpg'),
(124451, 8930, 'Talking Tom and Friends S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/246941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmLYn88T3fesF3R1Q1YYWfpehPr.jpg'),
(124452, 8930, 'Talking Tom and Friends S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/246942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aM3jLaG3ZLWObHl759lN41Hd4KN.jpg'),
(124453, 8930, 'Talking Tom and Friends S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/246943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aT49ayQtu7tWW4HG3wfl2zC30Zj.jpg'),
(124454, 8930, 'Talking Tom and Friends S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/246944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9D2eGbRsBtfZUsJlwOu8V3Xz9iD.jpg'),
(124455, 8930, 'Talking Tom and Friends S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/246945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8xjI41F9rbk2J9sMHl7RVyRdVq8.jpg'),
(124456, 8930, 'Talking Tom and Friends S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/246946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iyu6UqdFuPP08j0uq6G7SigzySb.jpg'),
(124457, 8930, 'Talking Tom and Friends S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/246947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5eaeEZC4Uy76o37pSHuoUvu1spc.jpg'),
(124458, 8930, 'Talking Tom and Friends S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/246948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i33EeEGaOtmz9h3OxTbBl881tNF.jpg'),
(124459, 8930, 'Talking Tom and Friends S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/246949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dVzCAYwwo3rDknD0apnMZIWodUx.jpg'),
(124460, 8930, 'Talking Tom and Friends S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/246950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jAKD6xcxkR1HP3s2M1G2RtgtN3M.jpg'),
(124461, 8930, 'Talking Tom and Friends S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/246951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/utT7dPpqyabXtZmwPL7HJwQbfij.jpg'),
(124462, 8930, 'Talking Tom and Friends S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/246952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4FNdBCKBo4FiJRpZIwNyE3Bjkw1.jpg'),
(124463, 8930, 'Talking Tom and Friends S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/246953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124464, 8931, 'Talking Tom and Friends S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oydKYxiqTk6hZZ0XV3lWG4NHnB5.jpg'),
(124465, 8931, 'Talking Tom and Friends S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zAX0Et2Hq4BPGPDd73Os5tV5J5H.jpg'),
(124466, 8931, 'Talking Tom and Friends S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iwFU5NfAYQuwjj4E9GaNA7EDUvm.jpg'),
(124467, 8931, 'Talking Tom and Friends S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QzYriSQiu9BlNognxuVBhOBrsx.jpg'),
(124468, 8931, 'Talking Tom and Friends S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ezaepfvbW75qkM2StZC5PHTdpDe.jpg'),
(124469, 8931, 'Talking Tom and Friends S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pULG0bnfdNLtxvMCprYrDgCJ3D3.jpg'),
(124470, 8931, 'Talking Tom and Friends S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zXyb8qla7J4wx1GTNiAcVjGpb9z.jpg'),
(124471, 8931, 'Talking Tom and Friends S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cBKHNRROFz5aT0yID3waczQS2FE.jpg'),
(124472, 8931, 'Talking Tom and Friends S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3NJpiExgqJ7uzAJ7nj5SAPF8Ly5.jpg'),
(124473, 8931, 'Talking Tom and Friends S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sU5p8V866u0LsA0kpv8YvIqehfK.jpg'),
(124474, 8931, 'Talking Tom and Friends S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJLEY7IFQFnH3CHROE6TI7ImFcP.jpg'),
(124475, 8931, 'Talking Tom and Friends S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mjNqsxYuB9KVMrIqIBn7iKyWbVA.jpg'),
(124476, 8931, 'Talking Tom and Friends S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/246966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqMAv1fVrKntaB4Tj7McdHlknUt.jpg'),
(124477, 8931, 'Talking Tom and Friends S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/246967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bn2T0xA0dK4eSP0HkpseFLyvK7D.jpg'),
(124478, 8931, 'Talking Tom and Friends S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/246968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gmx4tYsEPfvbA7oWlpULS3Pc0y6.jpg'),
(124479, 8931, 'Talking Tom and Friends S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/246969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jqT98xMM2ysv1cgEnTYC8xOum4L.jpg'),
(124480, 8931, 'Talking Tom and Friends S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/246970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f60yhl2rBEyNucRLJCFZAAKsnBJ.jpg'),
(124481, 8931, 'Talking Tom and Friends S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/246971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/17leNROZhC1dI959BkK8xiXmeVQ.jpg'),
(124482, 8931, 'Talking Tom and Friends S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/246972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yLngNAyLq4zsWzlIkXKaPhbThMq.jpg'),
(124483, 8931, 'Talking Tom and Friends S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/246973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aLLQ53jjTTPLmalpr8TALWRvLSE.jpg'),
(124484, 8931, 'Talking Tom and Friends S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/246974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/avtuYQXhDZdPngmdPz6v3VjTt5L.jpg'),
(124485, 8931, 'Talking Tom and Friends S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/246975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZZ3xo1XchUAZ3CgNVIJ4ov2RDd.jpg'),
(124486, 8931, 'Talking Tom and Friends S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/246976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ppSllQsmaI2tycYlWiX242aceyX.jpg'),
(124487, 8931, 'Talking Tom and Friends S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/246977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjei99E17xJTcJFEUkjXodbHeWG.jpg'),
(124488, 8931, 'Talking Tom and Friends S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/246978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/55Wwi2syvW9F8HM9pWvwWW7tYEj.jpg'),
(124489, 8931, 'Talking Tom and Friends S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/246979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dL5eR5NwltJ3KtPOvN5Fzp4x75r.jpg'),
(124490, 8932, 'Talking Tom and Friends S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/856712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124491, 8932, 'Talking Tom and Friends S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/856713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124492, 8932, 'Talking Tom and Friends S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/856714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124493, 8932, 'Talking Tom and Friends S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/856715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124494, 8932, 'Talking Tom and Friends S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/856716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124495, 8932, 'Talking Tom and Friends S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/856717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124496, 8932, 'Talking Tom and Friends S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/856718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124497, 8932, 'Talking Tom and Friends S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/856719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124498, 8932, 'Talking Tom and Friends S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/856720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124499, 8932, 'Talking Tom and Friends S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/856721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124500, 8932, 'Talking Tom and Friends S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/856722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124501, 8932, 'Talking Tom and Friends S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/856723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124502, 8932, 'Talking Tom and Friends S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/856724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124503, 8932, 'Talking Tom and Friends S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/856725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124504, 8932, 'Talking Tom and Friends S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/856726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124505, 8932, 'Talking Tom and Friends S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/856727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124506, 8932, 'Talking Tom and Friends S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/856728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124507, 8932, 'Talking Tom and Friends S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/856729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124508, 8932, 'Talking Tom and Friends S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/856730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124509, 8932, 'Talking Tom and Friends S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/856731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124510, 8932, 'Talking Tom and Friends S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/856732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124511, 8932, 'Talking Tom and Friends S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/856733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124512, 8932, 'Talking Tom and Friends S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/856734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124513, 8932, 'Talking Tom and Friends S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/856735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124514, 8932, 'Talking Tom and Friends S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/856736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124515, 8932, 'Talking Tom and Friends S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/856737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124516, 8933, 'Talking Tom and Friends S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/856738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124517, 8933, 'Talking Tom and Friends S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/856739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124518, 8933, 'Talking Tom and Friends S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/856740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124519, 8933, 'Talking Tom and Friends S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/856741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124520, 8933, 'Talking Tom and Friends S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/856742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124521, 8933, 'Talking Tom and Friends S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/856743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(124522, 8933, 'Talking Tom and Friends S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/856744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124523, 8933, 'Talking Tom and Friends S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/856745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124524, 8933, 'Talking Tom and Friends S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/856746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124525, 8933, 'Talking Tom and Friends S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/856747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124526, 8933, 'Talking Tom and Friends S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/856748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124527, 8933, 'Talking Tom and Friends S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/856749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124528, 8933, 'Talking Tom and Friends S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/856750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124529, 8933, 'Talking Tom and Friends S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/856751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124530, 8933, 'Talking Tom and Friends S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/856752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124531, 8933, 'Talking Tom and Friends S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/856753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124532, 8933, 'Talking Tom and Friends S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/856754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124533, 8933, 'Talking Tom and Friends S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/856755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124534, 8933, 'Talking Tom and Friends S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/856756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124535, 8933, 'Talking Tom and Friends S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/856757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124536, 8933, 'Talking Tom and Friends S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/856758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124537, 8933, 'Talking Tom and Friends S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/856759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124538, 8933, 'Talking Tom and Friends S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/856760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124539, 8933, 'Talking Tom and Friends S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/856761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124540, 8933, 'Talking Tom and Friends S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/856762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124541, 8933, 'Talking Tom and Friends S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/856763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u6We7ht3z8bSIaUF8P7DEwopOPi.jpg'),
(124542, 8934, 'Veterinarios do Texas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tTybZCRH9hgAwZitw1BQsYNxeIN.jpg'),
(124543, 8934, 'Veterinarios do Texas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1CysuqABa553E2ix8m8FQcrAVN1.jpg'),
(124544, 8934, 'Veterinarios do Texas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oma37XRxnXJvjoRNAYe2MtFaRvW.jpg'),
(124545, 8934, 'Veterinarios do Texas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6DsrigRzASkmH6zXPCP15TZFrhR.jpg'),
(124546, 8934, 'Veterinarios do Texas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4j4AEIxa8ERXwoVPYzjjQcW4JrB.jpg'),
(124547, 8934, 'Veterinarios do Texas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xy6FJVukwcbFdTk7TBgLiYsnwge.jpg'),
(124548, 8934, 'Veterinarios do Texas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iVXiAqHNR0RsADLIv7UcbE9Fhzq.jpg'),
(124549, 8934, 'Veterinarios do Texas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZlad0G0t4WjlG2K3LE4WMIpt4u.jpg'),
(124550, 8935, 'Veterinarios do Texas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sRs8p5RFrJsyjznnkLcCa1v77fV.jpg'),
(124551, 8935, 'Veterinarios do Texas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124552, 8935, 'Veterinarios do Texas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124553, 8935, 'Veterinarios do Texas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124554, 8935, 'Veterinarios do Texas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124555, 8935, 'Veterinarios do Texas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124556, 8935, 'Veterinarios do Texas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124557, 8935, 'Veterinarios do Texas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124558, 8936, 'Veterinarios do Texas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124559, 8936, 'Veterinarios do Texas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124560, 8936, 'Veterinarios do Texas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124561, 8936, 'Veterinarios do Texas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124562, 8936, 'Veterinarios do Texas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124563, 8936, 'Veterinarios do Texas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124564, 8936, 'Veterinarios do Texas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124565, 8936, 'Veterinarios do Texas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124566, 8937, 'Veterinarios do Texas S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124567, 8937, 'Veterinarios do Texas S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124568, 8937, 'Veterinarios do Texas S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124569, 8937, 'Veterinarios do Texas S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124570, 8937, 'Veterinarios do Texas S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124571, 8937, 'Veterinarios do Texas S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124572, 8937, 'Veterinarios do Texas S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124573, 8937, 'Veterinarios do Texas S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124574, 8937, 'Veterinarios do Texas S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124575, 8937, 'Veterinarios do Texas S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124576, 8938, 'Veterinarios do Texas S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124577, 8938, 'Veterinarios do Texas S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124578, 8938, 'Veterinarios do Texas S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124579, 8938, 'Veterinarios do Texas S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124580, 8938, 'Veterinarios do Texas S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124581, 8938, 'Veterinarios do Texas S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124582, 8938, 'Veterinarios do Texas S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124583, 8938, 'Veterinarios do Texas S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124584, 8939, 'Veterinarios do Texas S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124585, 8939, 'Veterinarios do Texas S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124586, 8939, 'Veterinarios do Texas S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124587, 8939, 'Veterinarios do Texas S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124588, 8939, 'Veterinarios do Texas S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124589, 8939, 'Veterinarios do Texas S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124590, 8939, 'Veterinarios do Texas S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124591, 8939, 'Veterinarios do Texas S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a0y9XqfFn2xD8GVSPDHOWeN8r9z.jpg'),
(124592, 8940, 'WWII Corrida para a Vitoria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g0Vygy76b5OlIjL9xFKxH5ZK9VW.jpg'),
(124593, 8940, 'WWII Corrida para a Vitoria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g0Vygy76b5OlIjL9xFKxH5ZK9VW.jpg'),
(124594, 8940, 'WWII Corrida para a Vitoria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g0Vygy76b5OlIjL9xFKxH5ZK9VW.jpg'),
(124595, 8940, 'WWII Corrida para a Vitoria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g0Vygy76b5OlIjL9xFKxH5ZK9VW.jpg'),
(124596, 8940, 'WWII Corrida para a Vitoria S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g0Vygy76b5OlIjL9xFKxH5ZK9VW.jpg'),
(124597, 8940, 'WWII Corrida para a Vitoria S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g0Vygy76b5OlIjL9xFKxH5ZK9VW.jpg'),
(124598, 8941, 'Encontrados [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8LLCQPFwmbAQLMEUWL6A542cTD2.jpg'),
(124599, 8941, 'Encontrados [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hmdJFHEBp6pIZtVX6FY3Tlp2PUJ.jpg'),
(124600, 8941, 'Encontrados [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2kqjmDJwLEROor4sq0ZBlUGdNxA.jpg'),
(124601, 8941, 'Encontrados [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9jjN7ggNgGrFhHNAxmVNgmBtRZ6.jpg'),
(124602, 8941, 'Encontrados [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rVyEHuyONrSs0YbqBCqgET9pRNK.jpg'),
(124603, 8941, 'Encontrados [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/31ftgJix44kpmDvJkDzoP1eCjQg.jpg'),
(124604, 8941, 'Encontrados [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(124605, 8941, 'Encontrados [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(124606, 8941, 'Encontrados [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(124607, 8941, 'Encontrados [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vmzPIARDxVBASB6elgkA4ETc946.jpg'),
(124608, 5221, 'O Túnel Do Tempo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ndYRFk8jCyWStTv3A3Z9IcB8dS.jpg'),
(124609, 5221, 'O Túnel Do Tempo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yAgqkAwf99TbBUljS53jPVV6s5B.jpg'),
(124610, 5221, 'O Túnel Do Tempo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qMdkQTPmMjjiih85U2BOM80F8nI.jpg'),
(124611, 5221, 'O Túnel Do Tempo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWnFDAZH45HjSC7uZyfaQy1CSKx.jpg'),
(124612, 5221, 'O Túnel Do Tempo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4IUej5zci8V9y4JfWxR8ZpQenVZ.jpg'),
(124613, 5221, 'O Túnel Do Tempo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWzJzkIztkWEObWnOl33d3iJH2v.jpg'),
(124614, 5221, 'O Túnel Do Tempo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6vpWIjysTTYRsTDi0pqYkLm8EJw.jpg'),
(124615, 5221, 'O Túnel Do Tempo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7QrdJFwoHlM4CWnzS3btzV8Cdij.jpg'),
(124616, 5221, 'O Túnel Do Tempo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qNPldDE61Lx1MM4aQeGmiMGjn6s.jpg'),
(124617, 5221, 'O Túnel Do Tempo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBlGOTWIiuLqPjFDcqvynRosyda.jpg'),
(124618, 5221, 'O Túnel Do Tempo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8zh8jYDRt1RbqkHiO0xMm78ECTx.jpg'),
(124619, 5221, 'O Túnel Do Tempo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dvwt8np5L1Z1MmlsD7xOyByMPV.jpg'),
(124620, 5221, 'O Túnel Do Tempo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/246409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5Pd30zVmwWIvVsBjZlzr2izmx5.jpg'),
(124621, 5221, 'O Túnel Do Tempo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/246410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pdLbUR9iaMK4HopcA3dcCNROSy.jpg'),
(124622, 5221, 'O Túnel Do Tempo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/246411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6jJxngPM7A5xS051ddBvcNDsTzq.jpg'),
(124623, 5221, 'O Túnel Do Tempo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/246412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/19IuNc8Rspgwp75LQfuUxJw942O.jpg'),
(124624, 5221, 'O Túnel Do Tempo S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/246413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5K7ErtH1PICz2fsXhpJR6wEvwbr.jpg'),
(124625, 5221, 'O Túnel Do Tempo S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/246414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5N309642zyA4bxf1mXWQ36CbCZr.jpg'),
(124626, 5221, 'O Túnel Do Tempo S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/246415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9xvnTohfIHJbo2ThUFyFKgHriYJ.jpg'),
(124627, 5221, 'O Túnel Do Tempo S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/246416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOlMoKzSwSxkIGRetBQ8xkFC5wh.jpg'),
(124628, 5221, 'O Túnel Do Tempo S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/246417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tttleyJpWRBylKqgBMKC7cJuoaJ.jpg'),
(124629, 5221, 'O Túnel Do Tempo S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/246418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pRbTYfU9CWQvIF2O7AUVcQQiOXH.jpg'),
(124630, 5221, 'O Túnel Do Tempo S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/246419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1KHB4p5bDqNRuD0wiSfTwtmiMeh.jpg'),
(124631, 5221, 'O Túnel Do Tempo S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/246420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xEcDIWSyZaMhICANgMn4g66QokP.jpg'),
(124632, 5221, 'O Túnel Do Tempo S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/246421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7UUp0cb8aYCye0A7vbINmULNAdp.jpg'),
(124633, 5221, 'O Túnel Do Tempo S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/246422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jvH3S3ZB27L1vSVwy9YWCTPrPlL.jpg'),
(124634, 5221, 'O Túnel Do Tempo S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/246423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/MHoHxAwYGGXjznQTsbS32mztYN.jpg'),
(124635, 5221, 'O Túnel Do Tempo S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/246424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/roO0OcM3PLbXH7AaX28vYg1Fhiw.jpg'),
(124636, 5221, 'O Túnel Do Tempo S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/246425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zOVJvNzSL7JKHOIHx82CyRRYVgc.jpg'),
(124637, 5221, 'O Túnel Do Tempo S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/246426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/imKl5qKvdpulNbzXuLEISGTPaV2.jpg'),
(124638, 8942, 'CSI: Vegas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zbovhZ4L3PD0KW0bm9ZHbrZFPgh.jpg'),
(124639, 8942, 'CSI: Vegas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qqriIpD224gZlTgWp9AxoB8cjel.jpg'),
(124640, 8942, 'CSI: Vegas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2yC5AEjBqD9NNNJGYH1m3JNUH3M.jpg'),
(124641, 8942, 'CSI: Vegas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124642, 8942, 'CSI: Vegas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124643, 8942, 'CSI: Vegas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124644, 8942, 'CSI: Vegas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124645, 8942, 'CSI: Vegas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124646, 8942, 'CSI: Vegas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/262755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124647, 8942, 'CSI: Vegas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/262756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124648, 8943, 'CSI: Vegas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124649, 8943, 'CSI: Vegas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124650, 8943, 'CSI: Vegas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124651, 8943, 'CSI: Vegas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/271672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124652, 8943, 'CSI: Vegas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/378251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124653, 8943, 'CSI: Vegas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/378252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124654, 8943, 'CSI: Vegas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/378253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124655, 8943, 'CSI: Vegas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/378254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124656, 8943, 'CSI: Vegas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/378255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124657, 8943, 'CSI: Vegas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/378256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124658, 8943, 'CSI: Vegas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/378257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124659, 8943, 'CSI: Vegas S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/378258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124660, 8943, 'CSI: Vegas S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/378259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124661, 8943, 'CSI: Vegas S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/378260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124662, 8943, 'CSI: Vegas S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/378261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124663, 8943, 'CSI: Vegas S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/378262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124664, 8943, 'CSI: Vegas S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/378263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124665, 8943, 'CSI: Vegas S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/378264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124666, 8943, 'CSI: Vegas S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/378265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124667, 8943, 'CSI: Vegas S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/378266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124668, 8943, 'CSI: Vegas S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/378267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124669, 8944, 'CSI: Vegas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/283086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124670, 8944, 'CSI: Vegas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/415315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1XUoN5QaV34wmDwYuJ41g7q4aL6.jpg'),
(124671, 8944, 'CSI: Vegas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124672, 8944, 'CSI: Vegas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/309290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124673, 8944, 'CSI: Vegas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/318892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124674, 8944, 'CSI: Vegas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/345802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124675, 8944, 'CSI: Vegas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/345803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124676, 8944, 'CSI: Vegas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124677, 8944, 'CSI: Vegas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/360957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124678, 8944, 'CSI: Vegas S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/360958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7x1DwPyjVCFekAj6QBeS6DIOODf.jpg'),
(124679, 8945, '1883 [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246387.mp4', 'http://timg.bdta.pro/images/3e6fd9217684b580efdc9b8b22f2f761.jpg'),
(124680, 8945, '1883 [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246388.mp4', 'http://timg.bdta.pro/images/62dd77811fc69f3b92c5aee598ce9038.jpg'),
(124681, 8945, '1883 [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246389.mp4', 'http://timg.bdta.pro/images/8b50754ea85782416de0ea04dc10086c.jpg'),
(124682, 8945, '1883 [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246390.mp4', 'http://timg.bdta.pro/images/42cde72d929feb25f4ed023bb1349d95.jpg'),
(124683, 8945, '1883 [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246391.mp4', 'http://timg.bdta.pro/images/c5770ca8389aba67a92e897d2cdb4206.jpg'),
(124684, 8945, '1883 [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246392.mp4', 'http://timg.bdta.pro/images/c7949addcaea718be5a02099bc7bb5f9.jpg'),
(124685, 8945, '1883 [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246393.mp4', 'http://timg.bdta.pro/images/c3b65ec5a5a6f58b1dffd2450ea03e63.jpg'),
(124686, 8945, '1883 [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246394.mp4', 'http://timg.bdta.pro/images/24fc65ee8ccc2375e201f12dfd18dc4e.jpg'),
(124687, 8945, '1883 [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246395.mp4', 'http://timg.bdta.pro/images/ebb9e25a3bf0652ca27bd8f64ff2ece0.jpg'),
(124688, 8945, '1883 [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246396.mp4', 'http://timg.bdta.pro/images/b5a38bd44137cbd7800e7a482aeb77dd.jpg'),
(124689, 8946, 'Amar e Para os Fortes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ggRiDInzsgwn4rBWJOoHy1uoLVt.jpg'),
(124690, 8946, 'Amar e Para os Fortes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g5hMPooZsocHD7IvynrLlSOlY84.jpg'),
(124691, 8946, 'Amar e Para os Fortes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eVwJlWUcwpkUWO3IiHHoPThgI9O.jpg'),
(124692, 8946, 'Amar e Para os Fortes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kAPVCT8v9IGKsOGOzg7B3KLgCEQ.jpg'),
(124693, 8946, 'Amar e Para os Fortes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gwKrTU8byCsPoIffyxiIkERUOpz.jpg'),
(124694, 8946, 'Amar e Para os Fortes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sgi0FOUqqTCXmIaLXyxxjTovwMp.jpg'),
(124695, 8946, 'Amar e Para os Fortes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLZdpeNIlBtAhkd7HZHaV3rJHEM.jpg'),
(124696, 8947, 'Beacon 23 [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5r7IKAjA8Z7aIf3ZXLPc9x8XTGx.jpg'),
(124697, 8947, 'Beacon 23 [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gHKfdOGRUDKsQSr4pyeAzHU4zeY.jpg'),
(124698, 8947, 'Beacon 23 [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iflPBIRvxeyXw1RlTqmI7yGtbP5.jpg'),
(124699, 8947, 'Beacon 23 [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eRxsR91zTxo3fqNLuBd5AVcv8p1.jpg'),
(124700, 8947, 'Beacon 23 [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bTBrTHGT8sUorqwp7LYuJJFVcmH.jpg'),
(124701, 8947, 'Beacon 23 [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/GAN0oepMm3Bra7uJEbjHjHPn0g.jpg'),
(124702, 8947, 'Beacon 23 [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iflPBIRvxeyXw1RlTqmI7yGtbP5.jpg'),
(124703, 8948, 'Beacon 23 [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/375408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iflPBIRvxeyXw1RlTqmI7yGtbP5.jpg'),
(124704, 8948, 'Beacon 23 [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/380103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iflPBIRvxeyXw1RlTqmI7yGtbP5.jpg'),
(124705, 8948, 'Beacon 23 [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/380104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iflPBIRvxeyXw1RlTqmI7yGtbP5.jpg'),
(124706, 8948, 'Beacon 23 [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/380105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iflPBIRvxeyXw1RlTqmI7yGtbP5.jpg'),
(124707, 8948, 'Beacon 23 [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/380106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iflPBIRvxeyXw1RlTqmI7yGtbP5.jpg'),
(124708, 8948, 'Beacon 23 [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/403664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iflPBIRvxeyXw1RlTqmI7yGtbP5.jpg'),
(124709, 8948, 'Beacon 23 [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/403665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iflPBIRvxeyXw1RlTqmI7yGtbP5.jpg'),
(124710, 8948, 'Beacon 23 [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/419806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iflPBIRvxeyXw1RlTqmI7yGtbP5.jpg'),
(124711, 8949, 'Helck [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ry00iiSdu56JbTVq7m2khW9HAAV.jpg'),
(124712, 8949, 'Helck [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sYFbTfabwDuiaDENbNA7MjPSniL.jpg'),
(124713, 8949, 'Helck [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dAji7OGfVYjtMWjgKBj3D3FYK6H.jpg'),
(124714, 8949, 'Helck [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hjTO6aihWHbFct2mmYEaAw4UoEQ.jpg'),
(124715, 8949, 'Helck [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z4KhCpwRPQJL8OxzshNfctaikYq.jpg'),
(124716, 8949, 'Helck [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/psxPZhXMGxevqmdKlDoURVytj8t.jpg'),
(124717, 8949, 'Helck [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7a48qdI6UXBeTqsY9GXGUXG6K90.jpg'),
(124718, 8949, 'Helck [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h0F3garceue5sLRH1cToNvT8yfd.jpg'),
(124719, 8949, 'Helck [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgSL6Cn5RYq1JpOv8s9jkEn2Hhg.jpg'),
(124720, 8949, 'Helck [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Vd2zlW6cXsWd0XhrgFqf3O37fy.jpg'),
(124721, 8949, 'Helck [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l1PQ3mPPy13T0B1ycnq4EpZXQzP.jpg'),
(124722, 8949, 'Helck [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6GVva0mdilz6v0PZl25tFglmkNa.jpg'),
(124723, 8949, 'Helck [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4MUSvKfQOepLisOmKDbPebFFCwx.jpg'),
(124724, 8949, 'Helck [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/257635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4480xKzpECm9ohzGxJPuXG3sy3b.jpg'),
(124725, 8949, 'Helck [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/257636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m8wyz3P305Hbx2E4bSS49NtC1Oe.jpg'),
(124726, 8949, 'Helck [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/257637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sOSkAtU7v7wpbJnFb1j7ClxjT0s.jpg'),
(124727, 8949, 'Helck [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/257638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cr65STeECx0wxv9nAWGBgpsI65n.jpg'),
(124728, 8949, 'Helck [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/257639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ktkPhojZ0CDDzg0MpzIlN0CWVvL.jpg'),
(124729, 8949, 'Helck [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/257640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v5wOOuYbwflgVss3D3jS6y42Ljf.jpg'),
(124730, 8949, 'Helck [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/257641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v5wOOuYbwflgVss3D3jS6y42Ljf.jpg'),
(124731, 8949, 'Helck [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/257642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v5wOOuYbwflgVss3D3jS6y42Ljf.jpg'),
(124732, 8949, 'Helck [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/257643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v5wOOuYbwflgVss3D3jS6y42Ljf.jpg'),
(124733, 8949, 'Helck [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/257644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v5wOOuYbwflgVss3D3jS6y42Ljf.jpg'),
(124734, 8949, 'Helck [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/257645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v5wOOuYbwflgVss3D3jS6y42Ljf.jpg'),
(124735, 8950, 'Hitlers Secret Sex Life [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bOAbbHpUUu3vud1JYn0DC2rkIHx.jpg'),
(124736, 8950, 'Hitlers Secret Sex Life [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bOAbbHpUUu3vud1JYn0DC2rkIHx.jpg'),
(124737, 8950, 'Hitlers Secret Sex Life [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bOAbbHpUUu3vud1JYn0DC2rkIHx.jpg'),
(124738, 8950, 'Hitlers Secret Sex Life [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bOAbbHpUUu3vud1JYn0DC2rkIHx.jpg'),
(124739, 8951, 'Monarch - Legado de Monstros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3IYqVM2jEHn8j9ZVETE0VcNvGoz.jpg'),
(124740, 8951, 'Monarch - Legado de Monstros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3IYqVM2jEHn8j9ZVETE0VcNvGoz.jpg'),
(124741, 8951, 'Monarch - Legado de Monstros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3IYqVM2jEHn8j9ZVETE0VcNvGoz.jpg'),
(124742, 8951, 'Monarch - Legado de Monstros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3IYqVM2jEHn8j9ZVETE0VcNvGoz.jpg'),
(124743, 8951, 'Monarch - Legado de Monstros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3IYqVM2jEHn8j9ZVETE0VcNvGoz.jpg'),
(124744, 8951, 'Monarch - Legado de Monstros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3IYqVM2jEHn8j9ZVETE0VcNvGoz.jpg'),
(124745, 8951, 'Monarch - Legado de Monstros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3IYqVM2jEHn8j9ZVETE0VcNvGoz.jpg'),
(124746, 8951, 'Monarch - Legado de Monstros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3IYqVM2jEHn8j9ZVETE0VcNvGoz.jpg'),
(124747, 8951, 'Monarch - Legado de Monstros S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3IYqVM2jEHn8j9ZVETE0VcNvGoz.jpg'),
(124748, 8951, 'Monarch - Legado de Monstros S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3IYqVM2jEHn8j9ZVETE0VcNvGoz.jpg'),
(124749, 8952, 'Os Leoes da Sicilia [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/beozChgwkj6u2OHoJPbVU7vUCFq.jpg'),
(124750, 8952, 'Os Leoes da Sicilia [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1HLb00Z5gIgniMkCP6iWXy2l48j.jpg'),
(124751, 8952, 'Os Leoes da Sicilia [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3lFdTUsxTYuf5iXfOWqrdm31F3M.jpg'),
(124752, 8952, 'Os Leoes da Sicilia [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uRXn7qal1sDr62IkHHlkfVDcnBr.jpg'),
(124753, 8952, 'Os Leoes da Sicilia [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qgyTGY3uA7u1tHxnxXZaBysxrSx.jpg'),
(124754, 8952, 'Os Leoes da Sicilia [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jKIHlF1Paq7LdseRaucRAI7GKdg.jpg'),
(124755, 8952, 'Os Leoes da Sicilia [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bsNqVGz6fI6nW7mTYqwZZoFDEA1.jpg'),
(124756, 8952, 'Os Leoes da Sicilia [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zW1HvJQrqeekqzIQxuU8tue3O3v.jpg'),
(124757, 8953, 'Radiante [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9S4fluG1Lg2rjgeKuBjtOZrAkiP.jpg'),
(124758, 8953, 'Radiante [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qvFxlMTVsqUnxld0AYulgEyzhZj.jpg'),
(124759, 8953, 'Radiante [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/evmVCRwBtFQwHYs55Na8HSlsOvM.jpg'),
(124760, 8953, 'Radiante [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hcvJUfFsgTt0ZjcJRWc3O28In2e.jpg'),
(124761, 8953, 'Radiante [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ums8N5zf2h0fWJ6MUw6MeItvG6.jpg'),
(124762, 8953, 'Radiante [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A155x59Tjd1NzxTvayPpM7ikAcM.jpg'),
(124763, 8953, 'Radiante [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pS1Qiuy28TSqQTEBVGfMVUHST7D.jpg'),
(124764, 8953, 'Radiante [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mycieRrmZP1fPuCW0aYMH3uMm01.jpg'),
(124765, 8953, 'Radiante [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/246364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5uhHzJw66TLZTiiqiiA8KGf42sy.jpg'),
(124766, 8953, 'Radiante [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/246365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/croI8uwuRPQfJABhYqvQWkgKxhb.jpg'),
(124767, 8953, 'Radiante [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/246366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAUlOwlMcVQ7izdMXo8wBzMOxa6.jpg'),
(124768, 8953, 'Radiante [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/246367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hymaGQAqtdHSXxrLccKdxtGh6Rm.jpg'),
(124769, 8954, 'Sou Seu Fa. A Festa Continua [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v1RyA4Ayn8npkoqTP8CV3udog56.jpg'),
(124770, 8954, 'Sou Seu Fa. A Festa Continua [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v1RyA4Ayn8npkoqTP8CV3udog56.jpg'),
(124771, 8954, 'Sou Seu Fa. A Festa Continua [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v1RyA4Ayn8npkoqTP8CV3udog56.jpg'),
(124772, 8954, 'Sou Seu Fa. A Festa Continua [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v1RyA4Ayn8npkoqTP8CV3udog56.jpg'),
(124773, 8954, 'Sou Seu Fa. A Festa Continua [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v1RyA4Ayn8npkoqTP8CV3udog56.jpg'),
(124774, 8954, 'Sou Seu Fa. A Festa Continua [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v1RyA4Ayn8npkoqTP8CV3udog56.jpg'),
(124775, 8954, 'Sou Seu Fa. A Festa Continua [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v1RyA4Ayn8npkoqTP8CV3udog56.jpg'),
(124776, 8954, 'Sou Seu Fa. A Festa Continua [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v1RyA4Ayn8npkoqTP8CV3udog56.jpg'),
(124777, 8955, 'Fome de Respostas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cBY9G9ZPgNTl33HzP2ngPpy2EvF.jpg'),
(124778, 8955, 'Fome de Respostas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cBY9G9ZPgNTl33HzP2ngPpy2EvF.jpg'),
(124779, 8955, 'Fome de Respostas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cBY9G9ZPgNTl33HzP2ngPpy2EvF.jpg'),
(124780, 8955, 'Fome de Respostas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cBY9G9ZPgNTl33HzP2ngPpy2EvF.jpg'),
(124781, 8956, 'Herois dos Trilhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0h8xeI2tIIRWSssCeyozD1fTAf.jpg'),
(124782, 8956, 'Herois dos Trilhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0h8xeI2tIIRWSssCeyozD1fTAf.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(124783, 8956, 'Herois dos Trilhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0h8xeI2tIIRWSssCeyozD1fTAf.jpg'),
(124784, 8956, 'Herois dos Trilhos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0h8xeI2tIIRWSssCeyozD1fTAf.jpg'),
(124785, 8957, 'Hot Wheels A Batalha da Customizacao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v23ctwBQ91592x1TtRMOOGkZ9hx.jpg'),
(124786, 8957, 'Hot Wheels A Batalha da Customizacao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Peftn2jqKiD7meG3kmsFBov2K4.jpg'),
(124787, 8957, 'Hot Wheels A Batalha da Customizacao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/72kIJeTuKK2VUXlqljPqih3RNHc.jpg'),
(124788, 8957, 'Hot Wheels A Batalha da Customizacao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jeGtS2hD7PZzVDpND1VImQ8PNca.jpg'),
(124789, 8957, 'Hot Wheels A Batalha da Customizacao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7CKJWLW7GZ5D7iDpZsFUaaQfg3L.jpg'),
(124790, 8957, 'Hot Wheels A Batalha da Customizacao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ydrBKJWxQYCLiXpxX4MeX7WBXqI.jpg'),
(124791, 8957, 'Hot Wheels A Batalha da Customizacao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSK3qF4KFx2zAHHasbXm1ETtsUE.jpg'),
(124792, 8957, 'Hot Wheels A Batalha da Customizacao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSK3qF4KFx2zAHHasbXm1ETtsUE.jpg'),
(124793, 8957, 'Hot Wheels A Batalha da Customizacao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSK3qF4KFx2zAHHasbXm1ETtsUE.jpg'),
(124794, 8957, 'Hot Wheels A Batalha da Customizacao S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pSK3qF4KFx2zAHHasbXm1ETtsUE.jpg'),
(124795, 8958, 'Scott Pilgrim A Serie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/246129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q3eIJSxZO2zXig4Ni3oo8md6mWS.jpg'),
(124796, 8958, 'Scott Pilgrim A Serie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/246130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l5KY9oQToDlm7IE0Crem81unYYK.jpg'),
(124797, 8958, 'Scott Pilgrim A Serie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/246131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oIDhyfYp2NrVOWZKCyHmxCxLsPj.jpg'),
(124798, 8958, 'Scott Pilgrim A Serie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/246132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tijvdUst0B3JD7IMyBlEP3jwOIg.jpg'),
(124799, 8958, 'Scott Pilgrim A Serie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/246133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/elP1A7AiF83zFclChgQvElz4rDF.jpg'),
(124800, 8958, 'Scott Pilgrim A Serie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/246134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4KCMO6yLKbH4SSXFm2Dv5HjhDOw.jpg'),
(124801, 8958, 'Scott Pilgrim A Serie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/246135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/krz9V21IErIOtjJoY8aY9PVhLrX.jpg'),
(124802, 8958, 'Scott Pilgrim A Serie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/246136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xCkHgTlNF75wVJVo10E2FCBwwP7.jpg'),
(124803, 8959, 'All Creatures Great e Small [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124804, 8959, 'All Creatures Great e Small [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124805, 8959, 'All Creatures Great e Small [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124806, 8959, 'All Creatures Great e Small [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124807, 8959, 'All Creatures Great e Small [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124808, 8959, 'All Creatures Great e Small [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124809, 8959, 'All Creatures Great e Small [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124810, 8960, 'All Creatures Great e Small [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124811, 8960, 'All Creatures Great e Small [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124812, 8960, 'All Creatures Great e Small [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124813, 8960, 'All Creatures Great e Small [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124814, 8960, 'All Creatures Great e Small [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124815, 8960, 'All Creatures Great e Small [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124816, 8960, 'All Creatures Great e Small [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124817, 8961, 'All Creatures Great e Small [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124818, 8961, 'All Creatures Great e Small [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124819, 8961, 'All Creatures Great e Small [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124820, 8961, 'All Creatures Great e Small [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124821, 8961, 'All Creatures Great e Small [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124822, 8961, 'All Creatures Great e Small [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124823, 8961, 'All Creatures Great e Small [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124824, 8962, 'All Creatures Great e Small [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124825, 8962, 'All Creatures Great e Small [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124826, 8962, 'All Creatures Great e Small [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124827, 8962, 'All Creatures Great e Small [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124828, 8962, 'All Creatures Great e Small [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124829, 8962, 'All Creatures Great e Small [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124830, 8963, 'All Creatures Great e Small [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/485936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124831, 8963, 'All Creatures Great e Small [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/641579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124832, 8963, 'All Creatures Great e Small [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/641580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124833, 8963, 'All Creatures Great e Small [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/641581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124834, 8963, 'All Creatures Great e Small [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/641582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124835, 8963, 'All Creatures Great e Small [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124836, 8963, 'All Creatures Great e Small [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx5QnlPODgxOgENxzu9bvXxBTtD.jpg'),
(124837, 8964, 'Amor Fora das Grades S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/430448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124838, 8964, 'Amor Fora das Grades S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/430449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124839, 8964, 'Amor Fora das Grades S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/430450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124840, 8964, 'Amor Fora das Grades S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/430451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124841, 8964, 'Amor Fora das Grades S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/430452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124842, 8964, 'Amor Fora das Grades S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/430453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124843, 8964, 'Amor Fora das Grades S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/430454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124844, 8965, 'Amor Fora das Grades S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/430455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124845, 8965, 'Amor Fora das Grades S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/430456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124846, 8965, 'Amor Fora das Grades S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/430457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124847, 8965, 'Amor Fora das Grades S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/430458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124848, 8965, 'Amor Fora das Grades S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/430459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124849, 8965, 'Amor Fora das Grades S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/430460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124850, 8965, 'Amor Fora das Grades S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/430461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124851, 8965, 'Amor Fora das Grades S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/430462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124852, 8965, 'Amor Fora das Grades S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/430463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124853, 8965, 'Amor Fora das Grades S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/430464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124854, 8965, 'Amor Fora das Grades S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/430465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124855, 8965, 'Amor Fora das Grades S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/430466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124856, 8966, 'Amor Fora das Grades S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pYVWdCcoydJ0wseNIJPDxnGaQBk.jpg'),
(124857, 8966, 'Amor Fora das Grades S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124858, 8966, 'Amor Fora das Grades S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124859, 8966, 'Amor Fora das Grades S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124860, 8966, 'Amor Fora das Grades S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124861, 8966, 'Amor Fora das Grades S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124862, 8966, 'Amor Fora das Grades S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124863, 8966, 'Amor Fora das Grades S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124864, 8966, 'Amor Fora das Grades S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124865, 8966, 'Amor Fora das Grades S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/245479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124866, 8966, 'Amor Fora das Grades S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/245480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124867, 8966, 'Amor Fora das Grades S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/245481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124868, 8966, 'Amor Fora das Grades S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/245482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124869, 8966, 'Amor Fora das Grades S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/245483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124870, 8966, 'Amor Fora das Grades S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/245484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124871, 8966, 'Amor Fora das Grades S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/245485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124872, 8966, 'Amor Fora das Grades S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/245486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124873, 8967, 'Amor Fora das Grades S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mwcRb1doJzt6myVgRrvvYj3uuoB.jpg'),
(124874, 8967, 'Amor Fora das Grades S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c81vOsjESa86GiXIosqzuPfqqTz.jpg'),
(124875, 8967, 'Amor Fora das Grades S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zZAGkM7XMuaeyKd8iIJGRJPY7NE.jpg'),
(124876, 8967, 'Amor Fora das Grades S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9yHjDTj76xCoGcP3hQNfqfMnoB6.jpg'),
(124877, 8967, 'Amor Fora das Grades S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fIw4iOKAAqkdsWO6z3GQHsBojDi.jpg'),
(124878, 8967, 'Amor Fora das Grades S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2g5H3MRrqFHPtzce11g06LOzpgE.jpg'),
(124879, 8967, 'Amor Fora das Grades S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8jXl9YrSxO15gLOxq1eEnsk7SKB.jpg'),
(124880, 8967, 'Amor Fora das Grades S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6qQIlAH7nyWHQGDwbK5g1IeTA9J.jpg'),
(124881, 8968, 'Amor Fora das Grades S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d7f0C1TY4nKWJDlj9J3IYvcVQCt.jpg'),
(124882, 8968, 'Amor Fora das Grades S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Gztts15V5zhcLDdwY632qUk0gK.jpg'),
(124883, 8968, 'Amor Fora das Grades S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tGbrhBbiaQ7a1hGTSgLBSs01aOE.jpg'),
(124884, 8968, 'Amor Fora das Grades S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2sMFeQQu5TJcHfINDltPKTY3Bo.jpg'),
(124885, 8968, 'Amor Fora das Grades S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wI6fSpc1aum2FWi0xUMc29J3jgD.jpg'),
(124886, 8968, 'Amor Fora das Grades S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3THdwXO7NTXhdEIAhjEIXOCYxmF.jpg'),
(124887, 8969, 'Amor Fora das Grades S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124888, 8969, 'Amor Fora das Grades S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124889, 8969, 'Amor Fora das Grades S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124890, 8969, 'Amor Fora das Grades S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124891, 8969, 'Amor Fora das Grades S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124892, 8969, 'Amor Fora das Grades S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124893, 8969, 'Amor Fora das Grades S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124894, 8969, 'Amor Fora das Grades S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124895, 8969, 'Amor Fora das Grades S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124896, 8969, 'Amor Fora das Grades S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/245510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124897, 8970, 'Amor Fora das Grades S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/422548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124898, 8970, 'Amor Fora das Grades S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/422549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124899, 8970, 'Amor Fora das Grades S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/422550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124900, 8970, 'Amor Fora das Grades S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/422551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124901, 8970, 'Amor Fora das Grades S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/403759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124902, 8970, 'Amor Fora das Grades S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/403760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124903, 8970, 'Amor Fora das Grades S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/403761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124904, 8970, 'Amor Fora das Grades S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/403762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124905, 8970, 'Amor Fora das Grades S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/403763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124906, 8970, 'Amor Fora das Grades S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/403764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124907, 8971, 'Amor Fora das Grades S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/710232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124908, 8971, 'Amor Fora das Grades S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/710233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124909, 8971, 'Amor Fora das Grades S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/710234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124910, 8971, 'Amor Fora das Grades S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/710235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124911, 8971, 'Amor Fora das Grades S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/710236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124912, 8971, 'Amor Fora das Grades S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/710237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124913, 8971, 'Amor Fora das Grades S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/710238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124914, 8971, 'Amor Fora das Grades S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/710239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124915, 8971, 'Amor Fora das Grades S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/710240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124916, 8971, 'Amor Fora das Grades S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/710241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6dc2A7cc2i0YmTfnPlnmzvAp0Qp.jpg'),
(124917, 8972, 'Cirurgia Plastica Vai Encarar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xf6bKsc9BJDO2quF6IUEQ0KCWun.jpg'),
(124918, 8972, 'Cirurgia Plastica Vai Encarar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xf6bKsc9BJDO2quF6IUEQ0KCWun.jpg'),
(124919, 8972, 'Cirurgia Plastica Vai Encarar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xf6bKsc9BJDO2quF6IUEQ0KCWun.jpg'),
(124920, 8972, 'Cirurgia Plastica Vai Encarar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xf6bKsc9BJDO2quF6IUEQ0KCWun.jpg'),
(124921, 8972, 'Cirurgia Plastica Vai Encarar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xf6bKsc9BJDO2quF6IUEQ0KCWun.jpg'),
(124922, 8972, 'Cirurgia Plastica Vai Encarar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xf6bKsc9BJDO2quF6IUEQ0KCWun.jpg'),
(124923, 8973, 'Como Treinar Seu Dragao As Lendas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hcldqxiA5NEJ2Q7mZGqeq4nNQH9.jpg'),
(124924, 8973, 'Como Treinar Seu Dragao As Lendas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hcldqxiA5NEJ2Q7mZGqeq4nNQH9.jpg'),
(124925, 8973, 'Como Treinar Seu Dragao As Lendas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hcldqxiA5NEJ2Q7mZGqeq4nNQH9.jpg'),
(124926, 8974, 'Escola do Rock S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/590921.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vZeCgByLKeZas7khRZPP0VKhHCV.jpg'),
(124927, 8974, 'Escola do Rock S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/590922.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p0bAelfr4pq1IqW40jKFulZfiVm.jpg'),
(124928, 8974, 'Escola do Rock S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/590923.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uTEhJgKQT5Bv0pdmM9Q9ANUgVN7.jpg'),
(124929, 8974, 'Escola do Rock S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zFCIaw8CEzD8EBZvasc8RUfpQNT.jpg'),
(124930, 8974, 'Escola do Rock S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8BqF5qsF8UbRjyxI1hZsSklSFj8.jpg'),
(124931, 8974, 'Escola do Rock S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZUBl8vF0O7PBtYuE9xIzaJr07V.jpg'),
(124932, 8974, 'Escola do Rock S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tFqlA5DkiFtP3EQExaOC5gdmT6x.jpg'),
(124933, 8974, 'Escola do Rock S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9iRH8hFDbZyv7f8vt1zzYykAfOT.jpg'),
(124934, 8974, 'Escola do Rock S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9uRxVhvM6o6jXCvBbw6sUY9e8fD.jpg'),
(124935, 8974, 'Escola do Rock S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6gyF7Gt77NOtIpYWBVdJtveY4RD.jpg'),
(124936, 8974, 'Escola do Rock S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/99SURVePfOe47hRNpGpD1dTpAmE.jpg'),
(124937, 8974, 'Escola do Rock S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zxh3j2eVd21F2kkYac8kBHtK1MA.jpg'),
(124938, 8975, 'Escola do Rock S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dDRaLZKFunsVp3LWKhqpq5Jck6s.jpg'),
(124939, 8975, 'Escola do Rock S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sIC7iXJrHVsEJjIBOcxHKhCqoip.jpg'),
(124940, 8975, 'Escola do Rock S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kza2Ry9a0Js9tWCQnk0LkwKGcqE.jpg'),
(124941, 8975, 'Escola do Rock S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6RJ86xzbX1sRVwMmZwv4X7sLHOS.jpg'),
(124942, 8975, 'Escola do Rock S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mlYUpyWZwusO2KahG8ehV5oxBUD.jpg'),
(124943, 8975, 'Escola do Rock S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eemEhhZQcH6bUXS5iBquZQ2u44m.jpg'),
(124944, 8975, 'Escola do Rock S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTyW66QmpTg1oJYLxakCQu4hgyx.jpg'),
(124945, 8975, 'Escola do Rock S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/95go8t5eunDUe0c2m2wOhqbfNs9.jpg'),
(124946, 8975, 'Escola do Rock S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vdoxv4DrkKMKXnTkq08mVx0txt9.jpg'),
(124947, 8975, 'Escola do Rock S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k5pKdaEHtSWaiRmgMbVJATR6ESZ.jpg'),
(124948, 8975, 'Escola do Rock S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDrN8KMhfO7aSORbDTmL1UplVAW.jpg'),
(124949, 8975, 'Escola do Rock S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/okLCKFGiJaaGiJZz028qXM0aEGL.jpg'),
(124950, 8975, 'Escola do Rock S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9xddLNpXdgqfwYMyvPp1Gcq6rXQ.jpg'),
(124951, 8976, 'Escola do Rock S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/il0Up3ZBTtkc7vJQPbveLSHlzfO.jpg'),
(124952, 8976, 'Escola do Rock S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rM4xn5UlNf98E6dYd5TxRRGnMnF.jpg'),
(124953, 8976, 'Escola do Rock S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1uP5lqfKaUI3Cdeox5pPhVN1uo0.jpg'),
(124954, 8976, 'Escola do Rock S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3J1MjGpttnZP6Bw2gPw9TgcScJp.jpg'),
(124955, 8976, 'Escola do Rock S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vN2Cn1vvyDsSOX0OYo2jwIipInK.jpg'),
(124956, 8976, 'Escola do Rock S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6YTX4EsvpBDLL8cfVEejgL4itUO.jpg'),
(124957, 8976, 'Escola do Rock S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yd6dLwEOu71DfoVucG7mzavAitZ.jpg'),
(124958, 8976, 'Escola do Rock S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ILSE3k9gIKC2EJLhCHMw2j9V2X.jpg'),
(124959, 8976, 'Escola do Rock S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hkP17KiG5fcdPiukrs9aA2H5cag.jpg'),
(124960, 8976, 'Escola do Rock S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kYwB1SGAnKmaOhrKRgACes7a3MY.jpg'),
(124961, 8976, 'Escola do Rock S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/niX5poNboJwl0BHfCl60YbdDbf2.jpg'),
(124962, 8976, 'Escola do Rock S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hDbkOnkDbEOOZkuYLVuvIYBuBCx.jpg'),
(124963, 8976, 'Escola do Rock S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lJaUuQJNTLyP3nU75fKYMPcvUYk.jpg'),
(124964, 8976, 'Escola do Rock S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yGs2iRDdreul8R4yHjy1aEqilWX.jpg'),
(124965, 8976, 'Escola do Rock S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mGGgB8uy9vBa32NgR5lqaWjp1qn.jpg'),
(124966, 8976, 'Escola do Rock S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ss2Z09FBUYcUq1n0Y9bWR5Angi.jpg'),
(124967, 8976, 'Escola do Rock S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AiiZZdTxW3IsY8UIi3a92u0oGeB.jpg'),
(124968, 8976, 'Escola do Rock S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/265320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzAL5y5eEjT5WpOMSF9MdVyMnUR.jpg'),
(124969, 8976, 'Escola do Rock S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/265321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7u8MQ36V1fK7xmeNXqcqAevqClS.jpg'),
(124970, 8976, 'Escola do Rock S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/265322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cRS3GoWIYumZTCGR3KLmiqsgJTQ.jpg'),
(124971, 8977, 'Ginger S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/809beDomsq3hJgFSKcx539QUmp7.jpg'),
(124972, 8977, 'Ginger S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qsoNuNStZSMO2GohiuMHcGKIOMD.jpg'),
(124973, 8977, 'Ginger S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kXZ9KE9JhbIjgvwu9P1UL4jRarm.jpg'),
(124974, 8977, 'Ginger S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8pXoqCWJeXxp14ScMpcfh0GQE9z.jpg'),
(124975, 8977, 'Ginger S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tb5Prnn10z79w3m4sSSqLb1Xxvr.jpg'),
(124976, 8977, 'Ginger S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWmc26GuJXdtdLsOb8kgksTlKOP.jpg'),
(124977, 8977, 'Ginger S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2G9bll38Z5623EuHHPHd7DYjHTo.jpg'),
(124978, 8977, 'Ginger S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rVsudewpQOoQV9psE6vpa7DhO5n.jpg'),
(124979, 8977, 'Ginger S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3R3JeExm32TwByvbsWgzn8FpRr5.jpg'),
(124980, 8977, 'Ginger S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pRxWWweV0orJnwno4UVnzpLTHnM.jpg'),
(124981, 8977, 'Ginger S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7xVdcStL2QFN9fNIGq6dClSNK5J.jpg'),
(124982, 8977, 'Ginger S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glDWvRoInmVzQI54zjEMBJ0pD9J.jpg'),
(124983, 8977, 'Ginger S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cbecYToA6kl9zEFu1TzjkfppCQv.jpg'),
(124984, 8977, 'Ginger S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/244680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(124985, 8977, 'Ginger S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/244681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(124986, 8977, 'Ginger S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/244682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(124987, 8977, 'Ginger S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/244683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(124988, 8977, 'Ginger S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/244684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(124989, 8977, 'Ginger S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/244685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(124990, 8977, 'Ginger S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/244686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(124991, 8978, 'Ginger S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1mKItsv8LaaRrHUXfFHSH7mGBeH.jpg'),
(124992, 8978, 'Ginger S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qW37M8pco94RjVc0FQjngLeRVV2.jpg'),
(124993, 8978, 'Ginger S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rF9skOHmkvLuqgyQlyCnQqPdlKm.jpg'),
(124994, 8978, 'Ginger S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ewYuvLzzEVtQiQjMhJfhjFT2LRO.jpg'),
(124995, 8978, 'Ginger S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AkMKkYWNRBBWnfxDaxbbIeNfsNh.jpg'),
(124996, 8978, 'Ginger S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wg8ChcRze5Rj5pN3pfRjWjMObrZ.jpg'),
(124997, 8978, 'Ginger S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xlTmWrVKXczwLzIePg7BzTV5H5R.jpg'),
(124998, 8978, 'Ginger S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1IOubpgwNyZaoQWojU60gUbsoE7.jpg'),
(124999, 8978, 'Ginger S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zPZBYQDbMHJRcHF9N2mGmshF12r.jpg'),
(125000, 8978, 'Ginger S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/22tSDVev6C9rzVjZPR9SgSeoX9Z.jpg'),
(125001, 8978, 'Ginger S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hb7Hc3QKtxUtijZnp6IOf1slT77.jpg'),
(125002, 8978, 'Ginger S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m77JdovqfCSuHig4VBEyxJZtKwk.jpg'),
(125003, 8978, 'Ginger S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5AV9U4zYjPGTaSxcm7FAsoqQI6i.jpg'),
(125004, 8978, 'Ginger S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/244700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5pfuYK5CBeIrewhKrIkp6DvA55d.jpg'),
(125005, 8978, 'Ginger S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/244701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1OLaNXCGySzY5T8f2mwq5QDIuna.jpg'),
(125006, 8978, 'Ginger S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/244702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTKU8EzN73DwbPN3qeoOsJu0YvP.jpg'),
(125007, 8978, 'Ginger S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/244703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/coyAAHeL1jrAU4JhhRUDrdAyssT.jpg'),
(125008, 8978, 'Ginger S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/244704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5VzdupODzoZybcZqOgl7XgesEn2.jpg'),
(125009, 8978, 'Ginger S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/244705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1pt9vGllmFokqMxvqJ2yudrHTKN.jpg'),
(125010, 8979, 'Ginger S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(125011, 8979, 'Ginger S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(125012, 8979, 'Ginger S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(125013, 8979, 'Ginger S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(125014, 8979, 'Ginger S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(125015, 8979, 'Ginger S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(125016, 8979, 'Ginger S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(125017, 8979, 'Ginger S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(125018, 8979, 'Ginger S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(125019, 8979, 'Ginger S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(125020, 8979, 'Ginger S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(125021, 8979, 'Ginger S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(125022, 8979, 'Ginger S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(125023, 8979, 'Ginger S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/244719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(125024, 8979, 'Ginger S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/244720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(125025, 8979, 'Ginger S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/244721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(125026, 8979, 'Ginger S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/244722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(125027, 8979, 'Ginger S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/244723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ktwPaU4S7ni0YaMOhIEvLYARjbg.jpg'),
(125028, 8980, 'Kit de Sobrevivencia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x2XbWNOE3cSedcSSKjCTSDFesuz.jpg'),
(125029, 8980, 'Kit de Sobrevivencia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/beml2UH4vLZqLC7Oj270K8jGeNA.jpg'),
(125030, 8980, 'Kit de Sobrevivencia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dpJlpIbPxgDscsSmke1z3yUdphp.jpg'),
(125031, 8980, 'Kit de Sobrevivencia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ghtpVXY8eghPodSrPfHxGVjGXNC.jpg'),
(125032, 8980, 'Kit de Sobrevivencia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fEJT5kyIlrD1vWiw10IQbw8Tymw.jpg'),
(125033, 8980, 'Kit de Sobrevivencia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1j5zfIPYF5gHfZv86c6mIRG1imJ.jpg'),
(125034, 8980, 'Kit de Sobrevivencia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/giHK9BfZWuPTJWcweLThnqKlCUy.jpg'),
(125035, 8980, 'Kit de Sobrevivencia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tfbs1rCTrKdDkcedF3S6l0ElhfH.jpg'),
(125036, 510, 'O Mundo Perdido S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nVF1jIPkmi2AQHICDPWSzwQ61Ta.jpg'),
(125037, 510, 'O Mundo Perdido S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x3mM42diPpAmUfk6Jyegi2mKTdb.jpg'),
(125038, 510, 'O Mundo Perdido S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dQ6ErLQUTvBVz0ur0LaC5BPBQG9.jpg'),
(125039, 510, 'O Mundo Perdido S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3pLy3C0qI1HLleYiTVJSE34Ukod.jpg'),
(125040, 510, 'O Mundo Perdido S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cNWpW7IjjgpL47cPh7qxI2q3kWB.jpg'),
(125041, 510, 'O Mundo Perdido S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/57BaIHyKxEZLerUb7tAk9c0hcbt.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(125042, 510, 'O Mundo Perdido S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4nuXqtajMi5JdFmeH4BSHRV3t9F.jpg'),
(125043, 510, 'O Mundo Perdido S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7uaQctLVEqEJDbyjp5urHhkzPL4.jpg'),
(125044, 510, 'O Mundo Perdido S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/riWLEgHPU5ENYyD79AjJ92ryRZb.jpg'),
(125045, 510, 'O Mundo Perdido S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/245396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/enmlJUg1fMpdR2c165DTgutxMYy.jpg'),
(125046, 510, 'O Mundo Perdido S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/245397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJFyA8jlJX7G2vHcdWYs363zWrz.jpg'),
(125047, 510, 'O Mundo Perdido S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/245398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q2Rq704NCHY5sF8OGNFgBMMyGzB.jpg'),
(125048, 510, 'O Mundo Perdido S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/245399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yUuHCriV2VRMKi1hjlG7Eksjk2Y.jpg'),
(125049, 510, 'O Mundo Perdido S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/245400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3wKnejVL3hX8BsPuVb86jjSrkIe.jpg'),
(125050, 510, 'O Mundo Perdido S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/245401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lcsIicX1lACtTCiR0MD28P2aSMA.jpg'),
(125051, 510, 'O Mundo Perdido S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/245402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6s4JHf6tq3Qxk6MppVnzv3RLKBN.jpg'),
(125052, 510, 'O Mundo Perdido S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/245403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pjKhXSFTpc2dryeoa70kCiEYWnC.jpg'),
(125053, 510, 'O Mundo Perdido S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/245404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r0aUlodiMxJDKTw18eB3TRrKFCd.jpg'),
(125054, 510, 'O Mundo Perdido S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/245405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xcYqSCyRi77EKquVzlrKHtkuJJM.jpg'),
(125055, 510, 'O Mundo Perdido S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/245406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1nTpw0LXlLnAm2HrW3V2teb3c6n.jpg'),
(125056, 510, 'O Mundo Perdido S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/245407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ptT10nlta03jwtIGOvJnzjlRiFb.jpg'),
(125057, 510, 'O Mundo Perdido S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/245408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AmzSflgwYdHSIyXfRrsq4uY6skr.jpg'),
(125058, 511, 'O Mundo Perdido S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125059, 511, 'O Mundo Perdido S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125060, 511, 'O Mundo Perdido S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125061, 511, 'O Mundo Perdido S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125062, 511, 'O Mundo Perdido S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125063, 511, 'O Mundo Perdido S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125064, 511, 'O Mundo Perdido S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125065, 511, 'O Mundo Perdido S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125066, 511, 'O Mundo Perdido S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125067, 511, 'O Mundo Perdido S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/245418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125068, 511, 'O Mundo Perdido S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/245419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125069, 511, 'O Mundo Perdido S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/245420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125070, 511, 'O Mundo Perdido S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/245421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCZRHDiDyHUCFunzfa8vWlesM5j.jpg'),
(125071, 511, 'O Mundo Perdido S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/245422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iWxk6Y6FOoxXQwx54wYfW16yicc.jpg'),
(125072, 511, 'O Mundo Perdido S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/245423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDdXYeT0uXxLJhuPB8ilpHbjd1t.jpg'),
(125073, 511, 'O Mundo Perdido S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/245424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hgONRgoPW5TNp4o5DERTjDmwXRM.jpg'),
(125074, 511, 'O Mundo Perdido S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/245425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qT1wbLxxmYLayytU4YVHUFl796N.jpg'),
(125075, 511, 'O Mundo Perdido S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/245426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125076, 511, 'O Mundo Perdido S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/245427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125077, 511, 'O Mundo Perdido S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/245428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125078, 511, 'O Mundo Perdido S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/245429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125079, 511, 'O Mundo Perdido S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/245430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125080, 512, 'O Mundo Perdido S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125081, 512, 'O Mundo Perdido S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125082, 512, 'O Mundo Perdido S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125083, 512, 'O Mundo Perdido S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125084, 512, 'O Mundo Perdido S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125085, 512, 'O Mundo Perdido S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125086, 512, 'O Mundo Perdido S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125087, 512, 'O Mundo Perdido S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125088, 512, 'O Mundo Perdido S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125089, 512, 'O Mundo Perdido S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/245440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125090, 512, 'O Mundo Perdido S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/245441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125091, 512, 'O Mundo Perdido S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/245442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125092, 512, 'O Mundo Perdido S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/245443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125093, 512, 'O Mundo Perdido S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/245444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125094, 512, 'O Mundo Perdido S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/245445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125095, 512, 'O Mundo Perdido S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/245446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125096, 512, 'O Mundo Perdido S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/245447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125097, 512, 'O Mundo Perdido S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/245448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125098, 512, 'O Mundo Perdido S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/245449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125099, 512, 'O Mundo Perdido S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/245450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125100, 512, 'O Mundo Perdido S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/245451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125101, 512, 'O Mundo Perdido S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/245452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iCpCsyJ1CYLQOp4y52ctrAco9oj.jpg'),
(125102, 8981, 'Pesadelos da Cirurgia Plastica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jLX6yrypdbHZTFsW9re0mA6N4Ih.jpg'),
(125103, 8981, 'Pesadelos da Cirurgia Plastica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jLX6yrypdbHZTFsW9re0mA6N4Ih.jpg'),
(125104, 8981, 'Pesadelos da Cirurgia Plastica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jLX6yrypdbHZTFsW9re0mA6N4Ih.jpg'),
(125105, 8981, 'Pesadelos da Cirurgia Plastica S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jLX6yrypdbHZTFsW9re0mA6N4Ih.jpg'),
(125106, 8981, 'Pesadelos da Cirurgia Plastica S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jLX6yrypdbHZTFsW9re0mA6N4Ih.jpg'),
(125107, 8981, 'Pesadelos da Cirurgia Plastica S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jLX6yrypdbHZTFsW9re0mA6N4Ih.jpg'),
(125108, 8982, 'Spirit Cavalgando Livre S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJYUWTH1qyTL0us4dix6wasN0A.jpg'),
(125109, 8982, 'Spirit Cavalgando Livre S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJYUWTH1qyTL0us4dix6wasN0A.jpg'),
(125110, 8982, 'Spirit Cavalgando Livre S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJYUWTH1qyTL0us4dix6wasN0A.jpg'),
(125111, 8982, 'Spirit Cavalgando Livre S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJYUWTH1qyTL0us4dix6wasN0A.jpg'),
(125112, 8982, 'Spirit Cavalgando Livre S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJYUWTH1qyTL0us4dix6wasN0A.jpg'),
(125113, 8982, 'Spirit Cavalgando Livre S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJYUWTH1qyTL0us4dix6wasN0A.jpg'),
(125114, 8983, 'Spirit Cavalgando Livre S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJYUWTH1qyTL0us4dix6wasN0A.jpg'),
(125115, 8983, 'Spirit Cavalgando Livre S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJYUWTH1qyTL0us4dix6wasN0A.jpg'),
(125116, 8983, 'Spirit Cavalgando Livre S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJYUWTH1qyTL0us4dix6wasN0A.jpg'),
(125117, 8983, 'Spirit Cavalgando Livre S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJYUWTH1qyTL0us4dix6wasN0A.jpg'),
(125118, 8983, 'Spirit Cavalgando Livre S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJYUWTH1qyTL0us4dix6wasN0A.jpg'),
(125119, 8983, 'Spirit Cavalgando Livre S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJYUWTH1qyTL0us4dix6wasN0A.jpg'),
(125120, 8983, 'Spirit Cavalgando Livre S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJYUWTH1qyTL0us4dix6wasN0A.jpg'),
(125121, 8984, 'Spirit Cavalgando Livre S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJYUWTH1qyTL0us4dix6wasN0A.jpg'),
(125122, 8984, 'Spirit Cavalgando Livre S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJYUWTH1qyTL0us4dix6wasN0A.jpg'),
(125123, 8984, 'Spirit Cavalgando Livre S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJYUWTH1qyTL0us4dix6wasN0A.jpg'),
(125124, 8984, 'Spirit Cavalgando Livre S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJYUWTH1qyTL0us4dix6wasN0A.jpg'),
(125125, 8984, 'Spirit Cavalgando Livre S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJYUWTH1qyTL0us4dix6wasN0A.jpg'),
(125126, 8984, 'Spirit Cavalgando Livre S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJYUWTH1qyTL0us4dix6wasN0A.jpg'),
(125127, 8985, 'Spirit Cavalgando Livre S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZeyGIkMFf0cvnPbaED0KiC706A.jpg'),
(125128, 8985, 'Spirit Cavalgando Livre S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uq17mSj89aJ1h5YG0P42qhZEt1i.jpg'),
(125129, 8985, 'Spirit Cavalgando Livre S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yu7mejuVLezcmAsfH7nrR6SqtBg.jpg'),
(125130, 8985, 'Spirit Cavalgando Livre S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hkcOfW2IX1lDY4RTLXvOCUU8Uv7.jpg'),
(125131, 8985, 'Spirit Cavalgando Livre S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bFYRmwY1HyMY96APRrHED2DUDtr.jpg'),
(125132, 8985, 'Spirit Cavalgando Livre S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b1mK6lYvq8fAJBS5TWb6K1ZoB3D.jpg'),
(125133, 8985, 'Spirit Cavalgando Livre S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qJx1AnCgweip0hUwrdHFOS2w1tf.jpg'),
(125134, 8986, 'Spirit Cavalgando Livre S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wdClZuNILLyKVqNBwP9mkZw87Kl.jpg'),
(125135, 8986, 'Spirit Cavalgando Livre S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vnTYKVyWoFJGfLxK2hSjEnH1LcR.jpg'),
(125136, 8986, 'Spirit Cavalgando Livre S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fFz3WZnyVqDHfbdb7HSTAyuv3lC.jpg'),
(125137, 8986, 'Spirit Cavalgando Livre S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Sen5menTqO23EqJeXESyNZvIJf.jpg'),
(125138, 8986, 'Spirit Cavalgando Livre S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7htrIq6nrK3M0L91zksjsv4EFC2.jpg'),
(125139, 8986, 'Spirit Cavalgando Livre S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/smGiFNLue33wKheKLTQzOzYQbZd.jpg'),
(125140, 8987, 'Spirit Cavalgando Livre S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nuSh5tptmH6NJ9qCfVf9lHl2UeO.jpg'),
(125141, 8987, 'Spirit Cavalgando Livre S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Twmq1Zkd37RzS5mGXPeDUrxBlA.jpg'),
(125142, 8987, 'Spirit Cavalgando Livre S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8KOM45o9DbAR49ch8BCyTNvKOC1.jpg'),
(125143, 8987, 'Spirit Cavalgando Livre S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gNd2bBMD4M0b6eElzjJg9w9PhA.jpg'),
(125144, 8987, 'Spirit Cavalgando Livre S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wdKzaJcCvLILUyizKSISroeCaNu.jpg'),
(125145, 8987, 'Spirit Cavalgando Livre S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fd0vmjf6QqsmSXLcprYhkgJ96by.jpg'),
(125146, 8987, 'Spirit Cavalgando Livre S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6uyn9uiKmmD3y6Ab67s0OGumntc.jpg'),
(125147, 8988, 'Spirit Cavalgando Livre S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9UWoBK4bmtAjbPF0fpExw70IZyg.jpg'),
(125148, 8988, 'Spirit Cavalgando Livre S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSLFdYsGfkCDO2nnsvu32u0sjzh.jpg'),
(125149, 8988, 'Spirit Cavalgando Livre S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/526MlFWsnMmmxAlB1l6sDsWHCu3.jpg'),
(125150, 8988, 'Spirit Cavalgando Livre S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6TNQTDdmelLYytLV08mSHErLYKM.jpg'),
(125151, 8988, 'Spirit Cavalgando Livre S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lqkM4Ubxl90ZX56FhS8KmFBFAvn.jpg'),
(125152, 8988, 'Spirit Cavalgando Livre S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oL0eaJNmstFYKEAHlxM9p392tqn.jpg'),
(125153, 8989, 'Bonnie e Clyde S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nBx1uz5Tj5aiiuztYolZJbvYhtJ.jpg'),
(125154, 8989, 'Bonnie e Clyde S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nBx1uz5Tj5aiiuztYolZJbvYhtJ.jpg'),
(125155, 8990, 'Ancient Empires [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vO1Al4ufOvRe37lJMuKGiqlyu5a.jpg'),
(125156, 8990, 'Ancient Empires [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vMcyo5RuSGujCjfkrrKxrV9vUYS.jpg'),
(125157, 8990, 'Ancient Empires [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/otNw4MSXcTR87G0GGcrwcDNtae.jpg'),
(125158, 8991, 'Apaixonados por Carros com Swizz Beatz [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QMfZYWrGzvk7KU6qvRfpOQB7TL.jpg'),
(125159, 8991, 'Apaixonados por Carros com Swizz Beatz [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dNqkaIoXcIqniGibD4qnqINfVAR.jpg'),
(125160, 8991, 'Apaixonados por Carros com Swizz Beatz [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/owiIIyvCguwrHuYmRoeQReH7lf8.jpg'),
(125161, 8991, 'Apaixonados por Carros com Swizz Beatz [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o6DCHftFcjA8uXpAdDcArhDY4P3.jpg'),
(125162, 8991, 'Apaixonados por Carros com Swizz Beatz [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aoFFeXxG87EU4jpcjoWijdM7XzZ.jpg'),
(125163, 8991, 'Apaixonados por Carros com Swizz Beatz [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ckdpVccFFpJOzyuQOhQicbgxNuz.jpg'),
(125164, 8992, 'Eu Sou Franky S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v8xlqL2CKPdebt5tSTswDKO3nuc.jpg'),
(125165, 8992, 'Eu Sou Franky S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qUbZ3hPyMHpZnZUWPqBgmV6u9qn.jpg'),
(125166, 8992, 'Eu Sou Franky S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/phEP465StSI0o9m5W5Z0XjUqu3p.jpg'),
(125167, 8992, 'Eu Sou Franky S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eJTsVN7IretrGgkF2Ecstd8oKoX.jpg'),
(125168, 8992, 'Eu Sou Franky S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97gHHjiB4JUiYX9VyVkx61a36N8.jpg'),
(125169, 8992, 'Eu Sou Franky S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bonOt1XjQly799uJdR3ER74KV8K.jpg'),
(125170, 8992, 'Eu Sou Franky S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a2zHvYLMNzl2TlPvz1cbj8OIt4Q.jpg'),
(125171, 8992, 'Eu Sou Franky S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gt9VsTa0LmiPHDYbmsrTHsq3HIc.jpg'),
(125172, 8992, 'Eu Sou Franky S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sssSF4HYCymjIZX1Xj5au6mQnXG.jpg'),
(125173, 8992, 'Eu Sou Franky S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/245112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iWmW3bcQLi0CO2I3A03GXSVNh1R.jpg'),
(125174, 8992, 'Eu Sou Franky S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/245113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ul9dI2VilIIof9MleGQo5mmeWpm.jpg'),
(125175, 8992, 'Eu Sou Franky S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/245114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZs6iPjtHEaCrw5J7sEOKDaynGX.jpg'),
(125176, 8992, 'Eu Sou Franky S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/245115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cFxcsG5uKT1N222J4ReDe9nnuxI.jpg'),
(125177, 8992, 'Eu Sou Franky S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/245116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d189Lejl3jg6jrzAhCPXPrP2beS.jpg'),
(125178, 8992, 'Eu Sou Franky S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/245117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cJFzejibnb1bTFslckegeEWaT5V.jpg'),
(125179, 8992, 'Eu Sou Franky S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/245118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQwWTtIOYFar3tY0skl6qZOkpgL.jpg'),
(125180, 8992, 'Eu Sou Franky S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/245119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jO3gq7Yu3bwMf29boAb3bmT0EZ4.jpg'),
(125181, 8992, 'Eu Sou Franky S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/245120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dyVnMGXWnEvFHdnnNs9zm2NYvlx.jpg'),
(125182, 8992, 'Eu Sou Franky S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/245121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A5W8MmUY0qg04s7HTrWxLJQQ9GL.jpg'),
(125183, 8992, 'Eu Sou Franky S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/245122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/prZcke1dKgIQvQYk8NO1BEr8d8V.jpg'),
(125184, 8992, 'Eu Sou Franky S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/245123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x1GPty18hfLYZREh4e8PygbjOme.jpg'),
(125185, 8992, 'Eu Sou Franky S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/245124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7xnnWgNxiNKzk758XMKbcmume97.jpg'),
(125186, 8992, 'Eu Sou Franky S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/245125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQU2Fi3n5rzBYtt3YlYhDTXRzNI.jpg'),
(125187, 8992, 'Eu Sou Franky S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/245126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cUEH6EPd727aHqtOQcAwKdfqJrS.jpg'),
(125188, 8992, 'Eu Sou Franky S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/245127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/obH4bZfTTxM6DvEYdkUz6pIr8Kf.jpg'),
(125189, 8992, 'Eu Sou Franky S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/245128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUyD2Bjx8MP7b0aAR5a8PGqqn5E.jpg'),
(125190, 8992, 'Eu Sou Franky S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/245129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/240A3AjY9gUcuFkdyPyZFGdZLOp.jpg'),
(125191, 8992, 'Eu Sou Franky S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/245130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gPUameoQkrLa80GiDduNjhr4Jbe.jpg'),
(125192, 8992, 'Eu Sou Franky S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/245131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwxaZrMtJ4AVUHKYJTWXC6PrDB0.jpg'),
(125193, 8992, 'Eu Sou Franky S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/245132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vKSUKvJsejbAg73Csv5GyxaqSHR.jpg'),
(125194, 8992, 'Eu Sou Franky S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/245133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u4vJH1lVvkfOGK8ZIL76XMbaeqf.jpg'),
(125195, 8992, 'Eu Sou Franky S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/245134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1uX1acgKXIuPtHbJ8MfjydV2Pap.jpg'),
(125196, 8992, 'Eu Sou Franky S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/245135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ukrNo25MTzYh15HZxi3LjCbWS8A.jpg'),
(125197, 8992, 'Eu Sou Franky S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/245136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyJqcKvXBRpd59PSXRH0pZtfeD4.jpg'),
(125198, 8992, 'Eu Sou Franky S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/245137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/noFrTZOIHmc8DszfMXK2gFk34zN.jpg'),
(125199, 8992, 'Eu Sou Franky S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/245138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJSer7l8jJMynwPw6SmIBiOSrtG.jpg'),
(125200, 8992, 'Eu Sou Franky S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/245139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/maxwnlYuIbqSEsZC5nONk849ADO.jpg'),
(125201, 8992, 'Eu Sou Franky S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/245140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rUwfRvCCwKY61NqJDbNs5VmraQC.jpg'),
(125202, 8992, 'Eu Sou Franky S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/245141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7B5aTUUBU5UGiZwFMsPkvsuJ14X.jpg'),
(125203, 8992, 'Eu Sou Franky S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/245142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8An663P4EEFTKbcHnLbEMn3r475.jpg'),
(125204, 8992, 'Eu Sou Franky S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/245143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ewmAtr9KRq4KtbBN5FcBz14TYnR.jpg'),
(125205, 8992, 'Eu Sou Franky S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/245144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/frqQzTvuAmiVWwb1lqyk79eNdRP.jpg'),
(125206, 8992, 'Eu Sou Franky S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/245145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9WxLJZITCliM59r0yTAist8T8tg.jpg'),
(125207, 8992, 'Eu Sou Franky S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/245146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mQDBYhsA574tFDoTraINzS0kIIL.jpg'),
(125208, 8992, 'Eu Sou Franky S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/245147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzrNgX9ON36ZTn2W0Rh5PldfpPD.jpg'),
(125209, 8992, 'Eu Sou Franky S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/245148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/npZPRHJbm1SLs85lfnv2jicG4yH.jpg'),
(125210, 8992, 'Eu Sou Franky S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/245149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2UwOyXE4lmBeDAthokVFMIYc1RJ.jpg'),
(125211, 8992, 'Eu Sou Franky S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/245150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cbpP9V04gkiwk7BfeB53qlxn4l4.jpg'),
(125212, 8992, 'Eu Sou Franky S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/245151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8b6rmqfXL8giaVp2YpnTwQ8N494.jpg'),
(125213, 8992, 'Eu Sou Franky S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/245152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5cEw3i5jqXV6L0xXi3tYbKBNVnP.jpg'),
(125214, 8992, 'Eu Sou Franky S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/245153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e651evohxEjzbVEc77eAek4OQob.jpg'),
(125215, 8992, 'Eu Sou Franky S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/245154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hUHsMkR3oe4v70UqWYNV3BvFPyD.jpg'),
(125216, 8992, 'Eu Sou Franky S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/245155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vObhHjcJzuRnaA2ZzarOrGbKy59.jpg'),
(125217, 8992, 'Eu Sou Franky S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/245156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Am8pdn5WFpEkoA5kM9Qh17WFsK.jpg'),
(125218, 8992, 'Eu Sou Franky S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/245157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xm0fMtYrpSbuNlXcFydbjQqliR3.jpg'),
(125219, 8992, 'Eu Sou Franky S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/245158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/whfPGRR49BOWfqZoktxeQ0CWezk.jpg'),
(125220, 8992, 'Eu Sou Franky S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/245159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8xos3YWXRUQsv0z91DQr34j04pA.jpg'),
(125221, 8992, 'Eu Sou Franky S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/245160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHt9B0johFaGWWz2M7HPuiBqlo8.jpg'),
(125222, 8992, 'Eu Sou Franky S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/245161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uyJUvAMrnotLuA1HqAOINoNaWs5.jpg'),
(125223, 8992, 'Eu Sou Franky S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/245162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/senNacLlg5N9FWDrSiZDkbFNZ1A.jpg'),
(125224, 8993, 'Eu Sou Franky S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AlZ8S8W3IFZxfZisUtmvJtiZVY.jpg'),
(125225, 8993, 'Eu Sou Franky S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pI7jH8R8vuRiM85zl887zjKxMUt.jpg'),
(125226, 8993, 'Eu Sou Franky S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzlG6wu2SXfkFd8oZ4g8MkU9L9K.jpg'),
(125227, 8993, 'Eu Sou Franky S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pbFy78AvbJaL6JszK0lwNfYZQ2m.jpg'),
(125228, 8993, 'Eu Sou Franky S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBWoV0oEQJRRFAQOXMB7CTY3xic.jpg'),
(125229, 8993, 'Eu Sou Franky S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8MiDjhqjt01JYy4D7ZCwcp4ltBX.jpg'),
(125230, 8993, 'Eu Sou Franky S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sUyaXLhHSJ74PVfD1RV5Vwl1KJ8.jpg'),
(125231, 8993, 'Eu Sou Franky S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u4L7TlIgSXSfzffUngYwWuiMwxj.jpg'),
(125232, 8993, 'Eu Sou Franky S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5G8uUwj0ZKP5AFedScs1tNXmOwp.jpg'),
(125233, 8993, 'Eu Sou Franky S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/245172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ewUMuAxXmKLJFx3oO4ksPklcdQ.jpg'),
(125234, 8993, 'Eu Sou Franky S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/245173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xntndcTg0wbqEGklW8ewbo1OxAl.jpg'),
(125235, 8993, 'Eu Sou Franky S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/245174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o9YeOf9yxEfz008HZtkptz4tnLe.jpg'),
(125236, 8993, 'Eu Sou Franky S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/245175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vGvEzERvG9VsPwZYJifTVr2SZGl.jpg'),
(125237, 8993, 'Eu Sou Franky S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/245176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iIkkP0PlmCMjqiOhVzQUDZqyxEu.jpg'),
(125238, 8993, 'Eu Sou Franky S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/245177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9AQ5z11rJ9ujv0Vu0uOslvGQEPU.jpg'),
(125239, 8993, 'Eu Sou Franky S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/245178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vHUUgM3B2dnmQKYVqARQMUpIuJM.jpg'),
(125240, 8993, 'Eu Sou Franky S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/245179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7shp7XT8L9BJSvQWYXneNf9Dyc.jpg'),
(125241, 8993, 'Eu Sou Franky S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/245180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wxNHaqdquwKlfEfK5q0iBtyeLVO.jpg'),
(125242, 8993, 'Eu Sou Franky S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/245181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w0WUqxUiawlVmjMdlRDbb7gGNUw.jpg'),
(125243, 8993, 'Eu Sou Franky S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/245182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eRP2kV8duA7XNRulknSwU0bSNHO.jpg'),
(125244, 8993, 'Eu Sou Franky S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/245183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yhBUnDzyZtNWyJ9X7LrsDJuPeW3.jpg'),
(125245, 8993, 'Eu Sou Franky S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/245184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ceDc6Mm6VWyIcAcd0WcZsC2ZgEs.jpg'),
(125246, 8993, 'Eu Sou Franky S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/245185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Zch4HNcyXWIArMVZbmJSiqWrh9.jpg'),
(125247, 8993, 'Eu Sou Franky S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/245186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kfBV4uIi6iuqwjDy5EO79utkFh8.jpg'),
(125248, 8993, 'Eu Sou Franky S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/245187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xik35ijaJOHWcaS7sdCAydlUVg0.jpg'),
(125249, 8993, 'Eu Sou Franky S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/245188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8sDHBRKpNZFVNQKEDRI19VNRFZd.jpg'),
(125250, 8993, 'Eu Sou Franky S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/245189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5GR6xjJNx09OrcItk0NWpnP6sbO.jpg'),
(125251, 8993, 'Eu Sou Franky S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/245190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1K3qauhs47xdn2dkMYKx1Mkca7x.jpg'),
(125252, 8993, 'Eu Sou Franky S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/245191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dhoCpOP2nPu6HWcDfrP9wpidEqc.jpg'),
(125253, 8993, 'Eu Sou Franky S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/245192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2KwrL2I3rv9YHJq5QSdjVWCdQS.jpg'),
(125254, 8993, 'Eu Sou Franky S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/245193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8BiGtb90rMCaqyFiFJw3JNllhB9.jpg'),
(125255, 8993, 'Eu Sou Franky S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/245194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vNh2y57nnv8lfjWczgPERcmAqSg.jpg'),
(125256, 8993, 'Eu Sou Franky S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/245195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jDE1pwxfMpJDG40zBZEBFglAxS2.jpg'),
(125257, 8993, 'Eu Sou Franky S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/245196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6MPVz02jp3dyeXMvdWeAKaJqdxX.jpg'),
(125258, 8993, 'Eu Sou Franky S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/245197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ga3tbMJeolVab5BWDUQRiUOwQxy.jpg'),
(125259, 8993, 'Eu Sou Franky S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/245198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJpoWDLpRlUIuwX9bp2sjMCGg8g.jpg'),
(125260, 8993, 'Eu Sou Franky S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/245199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odiK4TsGQcRl1dBGsY5klXsJGRr.jpg'),
(125261, 8993, 'Eu Sou Franky S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/245200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zS8t2eCEiVYhBHc3w716yfnO4m8.jpg'),
(125262, 8993, 'Eu Sou Franky S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/245201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1GVVokG6OMHYd2HCtB9QnEoSi4s.jpg'),
(125263, 8993, 'Eu Sou Franky S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/245202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ofsi1G0AkPDyr8ciFY2FuvyKJd.jpg'),
(125264, 8993, 'Eu Sou Franky S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/245203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5qwoaRUaDZyJZxG8qTIEv6sSbmy.jpg'),
(125265, 8993, 'Eu Sou Franky S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/245204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e89Sp5odK1sD3lk4XLVNjLMXaLN.jpg'),
(125266, 8993, 'Eu Sou Franky S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/245205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cMBxILLxRkwX2KkdGPRNrTg29xe.jpg'),
(125267, 8993, 'Eu Sou Franky S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/245206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jx1Jnp0uaFjQiKasKzRmX6Q4Aru.jpg'),
(125268, 8993, 'Eu Sou Franky S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/245207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c2icfc5C11jF78bDSP2PWDwUA2l.jpg'),
(125269, 8993, 'Eu Sou Franky S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/245208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3yLqXrXxNVEqxetX6frWs4HfypG.jpg'),
(125270, 8993, 'Eu Sou Franky S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/245209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jtwGNdvzyFhsttir8eLSdpfMUlO.jpg'),
(125271, 8993, 'Eu Sou Franky S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/245210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jO5iIz8tABJao5KKuhvPInd2fo5.jpg'),
(125272, 8993, 'Eu Sou Franky S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/245211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mjatGBPGUfmam1k0gfznB2QE28B.jpg'),
(125273, 8993, 'Eu Sou Franky S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/245212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xUKk3GIPKanmkzAMocKCEhPuNkw.jpg'),
(125274, 8993, 'Eu Sou Franky S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/245213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u8obrtzeAXBYOVx2eSwiAKK6r8I.jpg'),
(125275, 8993, 'Eu Sou Franky S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/245214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3K4mzeYBjmpPOqO4mdzortQwtco.jpg'),
(125276, 8993, 'Eu Sou Franky S02 E53', 'http://sinalprivado.info:80/series/1533784/1533784/245215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8rH4yTkfNeoRR6xXOC4DjmlvD1O.jpg'),
(125277, 8993, 'Eu Sou Franky S02 E54', 'http://sinalprivado.info:80/series/1533784/1533784/245216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ozIU6Log00DAbY2XlYCSm3JU6QO.jpg'),
(125278, 8993, 'Eu Sou Franky S02 E55', 'http://sinalprivado.info:80/series/1533784/1533784/245217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lS9fdtPLlOQpHTxjleY1rNNM2mP.jpg'),
(125279, 8993, 'Eu Sou Franky S02 E56', 'http://sinalprivado.info:80/series/1533784/1533784/245218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/NrD1qWkA1MT3zcJHgA5SS7kSU0.jpg'),
(125280, 8993, 'Eu Sou Franky S02 E57', 'http://sinalprivado.info:80/series/1533784/1533784/245219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wcCVwiSM2IPkfsoxSVPiGWBoYjB.jpg'),
(125281, 8993, 'Eu Sou Franky S02 E58', 'http://sinalprivado.info:80/series/1533784/1533784/245220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sDba7aTmyNYgBnaWLjrekuWvrWs.jpg'),
(125282, 8993, 'Eu Sou Franky S02 E59', 'http://sinalprivado.info:80/series/1533784/1533784/245221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lpwOb9qAV6w8AitQPFf07KU0Ot9.jpg'),
(125283, 8993, 'Eu Sou Franky S02 E60', 'http://sinalprivado.info:80/series/1533784/1533784/245222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9rjnE9vogq7W0qfo2Da2Dg3AVc8.jpg'),
(125284, 8993, 'Eu Sou Franky S02 E61', 'http://sinalprivado.info:80/series/1533784/1533784/245223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g0c4XUuMs1jVV0YC26HPeM40Bkn.jpg'),
(125285, 8993, 'Eu Sou Franky S02 E62', 'http://sinalprivado.info:80/series/1533784/1533784/245224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3mVrriEGZaruVdSJSZzWgoIIQym.jpg'),
(125286, 8993, 'Eu Sou Franky S02 E63', 'http://sinalprivado.info:80/series/1533784/1533784/245225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zJxCgQXbMHZ3mZ6AbvDIDuMXJgy.jpg'),
(125287, 8993, 'Eu Sou Franky S02 E64', 'http://sinalprivado.info:80/series/1533784/1533784/245226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Rqyd8JuywXrKgkHO9luRIpGw4k.jpg'),
(125288, 8993, 'Eu Sou Franky S02 E65', 'http://sinalprivado.info:80/series/1533784/1533784/245227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iHwbZIVIexbVVQxWCio8sN5DCsA.jpg'),
(125289, 8993, 'Eu Sou Franky S02 E66', 'http://sinalprivado.info:80/series/1533784/1533784/245228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4PxdZogpSoyHcq1Jg0yS3Jz2o4M.jpg'),
(125290, 8993, 'Eu Sou Franky S02 E67', 'http://sinalprivado.info:80/series/1533784/1533784/245229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cgI2wlCIyUSLw6s8dWMifjNb4RU.jpg'),
(125291, 8993, 'Eu Sou Franky S02 E68', 'http://sinalprivado.info:80/series/1533784/1533784/245230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lXS1hEfj3g1DIg1IGUSxGVDRMc6.jpg'),
(125292, 8993, 'Eu Sou Franky S02 E69', 'http://sinalprivado.info:80/series/1533784/1533784/245231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tq9R3840XfEvF4Ze9sjmyVX74Og.jpg'),
(125293, 8993, 'Eu Sou Franky S02 E70', 'http://sinalprivado.info:80/series/1533784/1533784/245232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pjmbKBdkcaM2jo8z8fey5wIhWD5.jpg'),
(125294, 8993, 'Eu Sou Franky S02 E71', 'http://sinalprivado.info:80/series/1533784/1533784/245233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pnqhKhodVWpHA9vdpsnd4eCnmtW.jpg'),
(125295, 8993, 'Eu Sou Franky S02 E72', 'http://sinalprivado.info:80/series/1533784/1533784/245234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wJQn8QA60950WXhXT3S2vqCECjh.jpg'),
(125296, 8993, 'Eu Sou Franky S02 E73', 'http://sinalprivado.info:80/series/1533784/1533784/245235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lFK8w9MmMEX6qS8siin0hDpJs3.jpg'),
(125297, 8993, 'Eu Sou Franky S02 E74', 'http://sinalprivado.info:80/series/1533784/1533784/245236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/orZETVXcjgAijiyNhEOOaXaTAOy.jpg'),
(125298, 8993, 'Eu Sou Franky S02 E75', 'http://sinalprivado.info:80/series/1533784/1533784/245237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8qHekb58cyiYc3XjLI4gsGZ5Ui7.jpg'),
(125299, 8993, 'Eu Sou Franky S02 E76', 'http://sinalprivado.info:80/series/1533784/1533784/245238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvW0C3273MFPA9gZReCl9ueTcgD.jpg'),
(125300, 8993, 'Eu Sou Franky S02 E77', 'http://sinalprivado.info:80/series/1533784/1533784/245239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ox19q1pAgFsOa3VhZTuQ6oIqMu.jpg'),
(125301, 8993, 'Eu Sou Franky S02 E78', 'http://sinalprivado.info:80/series/1533784/1533784/245240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p8tpdNARyiEyJO4wahteROyemZg.jpg'),
(125302, 8993, 'Eu Sou Franky S02 E79', 'http://sinalprivado.info:80/series/1533784/1533784/245241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7S6nCYLUt2ew9xuQrKuOewsGZ9B.jpg'),
(125303, 8993, 'Eu Sou Franky S02 E80', 'http://sinalprivado.info:80/series/1533784/1533784/245242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ADnN0iWt7tEoSM8nRoNEIVOFK7.jpg'),
(125304, 8993, 'Eu Sou Franky S02 E81', 'http://sinalprivado.info:80/series/1533784/1533784/245243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rrL4gOTaBcp4EaA0G6FpM4TzRWp.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(125305, 8993, 'Eu Sou Franky S02 E82', 'http://sinalprivado.info:80/series/1533784/1533784/245244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bS65wu6lNnV7VbQaosD5AvxoTIr.jpg'),
(125306, 8993, 'Eu Sou Franky S02 E83', 'http://sinalprivado.info:80/series/1533784/1533784/245245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5BcVP3qtbQEG8wjD5xf45ZMRMKJ.jpg'),
(125307, 8993, 'Eu Sou Franky S02 E84', 'http://sinalprivado.info:80/series/1533784/1533784/245246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dINuXc6Ufp0D4EZk23V7pA8TEdh.jpg'),
(125308, 8993, 'Eu Sou Franky S02 E85', 'http://sinalprivado.info:80/series/1533784/1533784/245247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/skVeilU4trZ69PKPurtVMtbREBv.jpg'),
(125309, 8993, 'Eu Sou Franky S02 E86', 'http://sinalprivado.info:80/series/1533784/1533784/245248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jPJEDVKvQbDbJmaeoUBmfoLpR49.jpg'),
(125310, 8993, 'Eu Sou Franky S02 E87', 'http://sinalprivado.info:80/series/1533784/1533784/245249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Jnp6lXdOn4hVEazxI5Rnrnk4S0.jpg'),
(125311, 8993, 'Eu Sou Franky S02 E88', 'http://sinalprivado.info:80/series/1533784/1533784/245250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8c4udAjVmKT15bBHQeBqYcfU2s3.jpg'),
(125312, 8993, 'Eu Sou Franky S02 E89', 'http://sinalprivado.info:80/series/1533784/1533784/245251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v1kTnyhfKNoF9QRBHV436thIvK8.jpg'),
(125313, 8993, 'Eu Sou Franky S02 E90', 'http://sinalprivado.info:80/series/1533784/1533784/245252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tLpQoKyjDeG5KMb3JYBTyD1loLo.jpg'),
(125314, 8993, 'Eu Sou Franky S02 E91', 'http://sinalprivado.info:80/series/1533784/1533784/245253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/72cM6Qo7ySfV43KIT1IOwSWyije.jpg'),
(125315, 8993, 'Eu Sou Franky S02 E92', 'http://sinalprivado.info:80/series/1533784/1533784/245254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUXGIvdZ63anzAzusVQOpDH4lXH.jpg'),
(125316, 8993, 'Eu Sou Franky S02 E93', 'http://sinalprivado.info:80/series/1533784/1533784/245255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t2E9QFOpuODWe6BRDb1KZDsmJB.jpg'),
(125317, 8993, 'Eu Sou Franky S02 E94', 'http://sinalprivado.info:80/series/1533784/1533784/245256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2X5zGBMWpeeHyhmxXixLnoXNBib.jpg'),
(125318, 8993, 'Eu Sou Franky S02 E95', 'http://sinalprivado.info:80/series/1533784/1533784/245257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3hb9wjEC2Io4KdxFikeg3wy1I6Y.jpg'),
(125319, 8993, 'Eu Sou Franky S02 E96', 'http://sinalprivado.info:80/series/1533784/1533784/245258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nKNGjIdXUMgRqviVFRpx0L7NM86.jpg'),
(125320, 8993, 'Eu Sou Franky S02 E97', 'http://sinalprivado.info:80/series/1533784/1533784/245259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iHNfE07MFwyengzmcdWCEtjFX8q.jpg'),
(125321, 8993, 'Eu Sou Franky S02 E98', 'http://sinalprivado.info:80/series/1533784/1533784/245260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x4Q2nvRmGkIIqFLBzqGCQ36pDEQ.jpg'),
(125322, 8993, 'Eu Sou Franky S02 E99', 'http://sinalprivado.info:80/series/1533784/1533784/245261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aOg6VctszigEcaTZyM7JdqhedB2.jpg'),
(125323, 8993, 'Eu Sou Franky S02 E100', 'http://sinalprivado.info:80/series/1533784/1533784/245262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bM6jlYtzwPfq9NGsbxIUUTA6LsJ.jpg'),
(125324, 8994, 'Mineradores Digitais [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ixfyR5SWbk4g0q7Mq7EhGwdlBtW.jpg'),
(125325, 8994, 'Mineradores Digitais [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/586637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ixfyR5SWbk4g0q7Mq7EhGwdlBtW.jpg'),
(125326, 8994, 'Mineradores Digitais [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/586639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ixfyR5SWbk4g0q7Mq7EhGwdlBtW.jpg'),
(125327, 8994, 'Mineradores Digitais [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/586641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ixfyR5SWbk4g0q7Mq7EhGwdlBtW.jpg'),
(125328, 8994, 'Mineradores Digitais [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/586643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ixfyR5SWbk4g0q7Mq7EhGwdlBtW.jpg'),
(125329, 8994, 'Mineradores Digitais [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/586645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ixfyR5SWbk4g0q7Mq7EhGwdlBtW.jpg'),
(125330, 8994, 'Mineradores Digitais [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ixfyR5SWbk4g0q7Mq7EhGwdlBtW.jpg'),
(125331, 8994, 'Mineradores Digitais [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ixfyR5SWbk4g0q7Mq7EhGwdlBtW.jpg'),
(125332, 8994, 'Mineradores Digitais [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ixfyR5SWbk4g0q7Mq7EhGwdlBtW.jpg'),
(125333, 8994, 'Mineradores Digitais [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ixfyR5SWbk4g0q7Mq7EhGwdlBtW.jpg'),
(125334, 8994, 'Mineradores Digitais [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ixfyR5SWbk4g0q7Mq7EhGwdlBtW.jpg'),
(125335, 8995, 'Nada para Ver Aqui [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/inKolINCBYMhI4jRs8cLbajngIN.jpg'),
(125336, 8995, 'Nada para Ver Aqui [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iKZKr3sD67WnI5qlPwzIcw5BREL.jpg'),
(125337, 8995, 'Nada para Ver Aqui [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tTn3A1CZZg8rch5M8zsMk4sicMu.jpg'),
(125338, 8995, 'Nada para Ver Aqui [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kurecAYjWYTLBdQDkUHWmxqbYJI.jpg'),
(125339, 8995, 'Nada para Ver Aqui [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/disUu4hBofAv1KLxIPRwM4zdu05.jpg'),
(125340, 8995, 'Nada para Ver Aqui [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bTmsZyFYFlmF8Vblodkh1elPpml.jpg'),
(125341, 8995, 'Nada para Ver Aqui [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8VVaKB8DkQNfRT25vY61GDuzN8k.jpg'),
(125342, 8995, 'Nada para Ver Aqui [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iegmdF8YozOSM8bTti7jAlTjadF.jpg'),
(125343, 8996, 'O Voto de Morte [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ipGg686VJqDU3PA2yd87T7dIjPT.jpg'),
(125344, 8996, 'O Voto de Morte [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m4L5mrJ0Tj9ANlfzQvkyVPjzryB.jpg'),
(125345, 8996, 'O Voto de Morte [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wpXBvKbk4Glith8M7mEuP8Dwa20.jpg'),
(125346, 8996, 'O Voto de Morte [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eGh6sCtuQ28FuQ3m9aREmnrK0Z1.jpg'),
(125347, 8996, 'O Voto de Morte [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6nqfJfSkEvWoc1bj3mAsP2O3sd9.jpg'),
(125348, 8996, 'O Voto de Morte [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ksl89oFIV9b9tgRuCNIBT7g1SK4.jpg'),
(125349, 8996, 'O Voto de Morte [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bP0K0uswatk8ZDpNYehFAizdtXL.jpg'),
(125350, 8996, 'O Voto de Morte [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6v0mG4tJYdxbUTHhbReVmLoyobn.jpg'),
(125351, 8996, 'O Voto de Morte [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOVAyGlv3kxAbRhlEqbIXM7kvlz.jpg'),
(125352, 8996, 'O Voto de Morte [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/245282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jkERH0NvaWIapuWc2YNluspLWIF.jpg'),
(125353, 8996, 'O Voto de Morte [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/245283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/myfeYANEEF9vDYR6FqiY7MFMv6E.jpg'),
(125354, 8996, 'O Voto de Morte [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/245284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/87jzOqall2LN2bieOXNDTSjRYS7.jpg'),
(125355, 8997, 'Projeto Lazaro [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kIu4vbVZTSJBwhHoz5z5RESP9hk.jpg'),
(125356, 8997, 'Projeto Lazaro [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ppF4b7rmPN49T1QZrJlaTwae63m.jpg'),
(125357, 8997, 'Projeto Lazaro [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1eQaBJUBDoxivm3uiiiEzyiFT9d.jpg'),
(125358, 8997, 'Projeto Lazaro [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5WmZBg9iLJVSpW2O8vcPJWKBjfD.jpg'),
(125359, 8997, 'Projeto Lazaro [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i3EEOiM8zXNuuK8MlSuiJfUlyXd.jpg'),
(125360, 8997, 'Projeto Lazaro [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCYSipcsIm9t8qzYuRoNT0mAPDa.jpg'),
(125361, 8997, 'Projeto Lazaro [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/peKUiDnvaiy1TPT9JKgGYkMAdlo.jpg'),
(125362, 8997, 'Projeto Lazaro [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gbGlmN05lSrXZdKtffA4llTqwVH.jpg'),
(125363, 8998, 'Projeto Lazaro [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8XIk0kHu50vK2ra4Bswv0sZL68i.jpg'),
(125364, 8998, 'Projeto Lazaro [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xw7GkWtmPQDU8qzfKshFEN038sj.jpg'),
(125365, 8998, 'Projeto Lazaro [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xw7GkWtmPQDU8qzfKshFEN038sj.jpg'),
(125366, 8998, 'Projeto Lazaro [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xw7GkWtmPQDU8qzfKshFEN038sj.jpg'),
(125367, 8998, 'Projeto Lazaro [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xw7GkWtmPQDU8qzfKshFEN038sj.jpg'),
(125368, 8998, 'Projeto Lazaro [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xw7GkWtmPQDU8qzfKshFEN038sj.jpg'),
(125369, 8998, 'Projeto Lazaro [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xw7GkWtmPQDU8qzfKshFEN038sj.jpg'),
(125370, 8998, 'Projeto Lazaro [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xw7GkWtmPQDU8qzfKshFEN038sj.jpg'),
(125371, 8999, 'Resistencia Negra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uXWAg97bSFoiDsfUfRRqu5Q14t5.jpg'),
(125372, 8999, 'Resistencia Negra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uXWAg97bSFoiDsfUfRRqu5Q14t5.jpg'),
(125373, 8999, 'Resistencia Negra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uXWAg97bSFoiDsfUfRRqu5Q14t5.jpg'),
(125374, 8999, 'Resistencia Negra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uXWAg97bSFoiDsfUfRRqu5Q14t5.jpg'),
(125375, 8999, 'Resistencia Negra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uXWAg97bSFoiDsfUfRRqu5Q14t5.jpg'),
(125376, 9000, 'The Producers [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aSvEu1UgIdFVpPyn7rmBDGSc18D.jpg'),
(125377, 9000, 'The Producers [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xqEBt6mZN3FRqnRMAdjZJVBxvex.jpg'),
(125378, 9000, 'The Producers [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pxhO2btctoxvsHJT8l0vl43IDWE.jpg'),
(125379, 9000, 'The Producers [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zQU48BbWNjW9P07e4sypPPW6db0.jpg'),
(125380, 9000, 'The Producers [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4pakkfTvLNJPIA57kgwfZFHDleV.jpg'),
(125381, 9000, 'The Producers [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzZtR6xbQs6WRnRP8TJNEHlEHlI.jpg'),
(125382, 9000, 'The Producers [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i6uATylVe0lrj94mlC9IIhGYbMS.jpg'),
(125383, 9000, 'The Producers [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e8A0h8GgIfjH8eWs7XLp2a3F8gc.jpg'),
(125384, 9000, 'The Producers [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Lm5qkk7DO4oUrDRIKuxT3Z7leE.jpg'),
(125385, 9000, 'The Producers [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/245272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n2uqpNLjq4teP8sI9rx7zmY3ZQm.jpg'),
(125386, 9001, 'As Mais Incriveis Viagens de Animais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rhUP4DrDa1HZOuYmSDYWQ2WNlbg.jpg'),
(125387, 9001, 'As Mais Incriveis Viagens de Animais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5wsLIE2jhDkUYBQdCAGl95QkFjt.jpg'),
(125388, 9001, 'As Mais Incriveis Viagens de Animais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tfDjxGZg3AyiT7dIbmFfswmOFJn.jpg'),
(125389, 9001, 'As Mais Incriveis Viagens de Animais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yURwtIL1cbAbLrVdhxJgenjNQqE.jpg'),
(125390, 9001, 'As Mais Incriveis Viagens de Animais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fnWayFheMqNcCysc0K5SbuIWZv9.jpg'),
(125391, 9001, 'As Mais Incriveis Viagens de Animais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gdHpNhV5seIZRxcJi0zMxffXl2h.jpg'),
(125392, 9001, 'As Mais Incriveis Viagens de Animais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pSe9d7Mb8L4fJvj3rJF56TVbgVz.jpg'),
(125393, 9002, 'Barbearia do Pao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125394, 9002, 'Barbearia do Pao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125395, 9002, 'Barbearia do Pao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125396, 9002, 'Barbearia do Pao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125397, 9002, 'Barbearia do Pao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125398, 9002, 'Barbearia do Pao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125399, 9002, 'Barbearia do Pao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125400, 9002, 'Barbearia do Pao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125401, 9002, 'Barbearia do Pao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125402, 9002, 'Barbearia do Pao S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/245040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125403, 9002, 'Barbearia do Pao S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/245041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125404, 9002, 'Barbearia do Pao S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/245042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125405, 9002, 'Barbearia do Pao S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/245043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125406, 9002, 'Barbearia do Pao S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/245044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125407, 9002, 'Barbearia do Pao S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/245045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125408, 9002, 'Barbearia do Pao S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/245046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125409, 9002, 'Barbearia do Pao S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/245047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125410, 9002, 'Barbearia do Pao S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/245048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125411, 9002, 'Barbearia do Pao S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/245049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125412, 9002, 'Barbearia do Pao S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/245050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125413, 9002, 'Barbearia do Pao S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/245051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125414, 9002, 'Barbearia do Pao S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/245052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125415, 9002, 'Barbearia do Pao S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/245053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125416, 9002, 'Barbearia do Pao S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/245054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125417, 9002, 'Barbearia do Pao S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/245055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125418, 9002, 'Barbearia do Pao S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/245056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125419, 9002, 'Barbearia do Pao S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/245057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125420, 9002, 'Barbearia do Pao S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/245058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125421, 9002, 'Barbearia do Pao S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/245059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125422, 9002, 'Barbearia do Pao S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/245060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125423, 9002, 'Barbearia do Pao S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/245061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125424, 9002, 'Barbearia do Pao S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/245062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125425, 9002, 'Barbearia do Pao S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/245063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125426, 9002, 'Barbearia do Pao S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/245064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125427, 9002, 'Barbearia do Pao S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/245065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125428, 9002, 'Barbearia do Pao S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/245066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125429, 9002, 'Barbearia do Pao S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/245067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125430, 9002, 'Barbearia do Pao S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/245068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125431, 9002, 'Barbearia do Pao S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/245069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125432, 9003, 'Barbearia do Pao S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125433, 9003, 'Barbearia do Pao S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125434, 9003, 'Barbearia do Pao S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125435, 9003, 'Barbearia do Pao S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125436, 9003, 'Barbearia do Pao S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125437, 9003, 'Barbearia do Pao S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125438, 9003, 'Barbearia do Pao S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125439, 9003, 'Barbearia do Pao S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125440, 9003, 'Barbearia do Pao S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125441, 9003, 'Barbearia do Pao S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/245079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125442, 9003, 'Barbearia do Pao S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/245080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125443, 9003, 'Barbearia do Pao S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/245081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125444, 9003, 'Barbearia do Pao S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/245082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125445, 9003, 'Barbearia do Pao S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/245083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125446, 9003, 'Barbearia do Pao S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/245084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125447, 9003, 'Barbearia do Pao S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/245085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125448, 9003, 'Barbearia do Pao S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/245086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125449, 9003, 'Barbearia do Pao S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/245087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125450, 9003, 'Barbearia do Pao S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/245088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125451, 9003, 'Barbearia do Pao S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/245089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125452, 9003, 'Barbearia do Pao S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/245090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125453, 9003, 'Barbearia do Pao S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/245091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125454, 9003, 'Barbearia do Pao S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/245092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125455, 9003, 'Barbearia do Pao S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/245093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125456, 9003, 'Barbearia do Pao S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/245094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125457, 9003, 'Barbearia do Pao S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/245095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVieeabAjMxgvQ3y06JIxfXocfH.jpg'),
(125458, 9004, 'Beleza Verdadeira S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/245015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3a9GqnAjzfBlBjiERXxSL5KrprJ.jpg'),
(125459, 9004, 'Beleza Verdadeira S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/245016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/scJfGyeBGmdWhIVJtYeaTSWaoUU.jpg'),
(125460, 9004, 'Beleza Verdadeira S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/245017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6VzjESP6ybZjhshwI3Jts5HHPU1.jpg'),
(125461, 9004, 'Beleza Verdadeira S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/245018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kI4xtpjolAAOeFO0x364E440Uh6.jpg'),
(125462, 9004, 'Beleza Verdadeira S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/245019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/83XxlOW2TzbweRbrHlhqzga6ruD.jpg'),
(125463, 9004, 'Beleza Verdadeira S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/245020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/17hXG6uMjqpMkJz6RImTCI9xSmO.jpg'),
(125464, 9004, 'Beleza Verdadeira S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/245021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rXJQZyX1TMkoGzdtGplzXqZClap.jpg'),
(125465, 9004, 'Beleza Verdadeira S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/245022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5gjY4MMpdDXqW5BMk2WdaU9OTP3.jpg'),
(125466, 9004, 'Beleza Verdadeira S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/245023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oIw5BC71XLHx9476cFRJatsNyoF.jpg'),
(125467, 9004, 'Beleza Verdadeira S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/245024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b7D9EvIqm6GaK7r55HvvYKvJ6OB.jpg'),
(125468, 9004, 'Beleza Verdadeira S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/245025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQ54ddqYg0KyR7zzqsxWHyBaakj.jpg'),
(125469, 9004, 'Beleza Verdadeira S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/245026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h5WGoprfvqES0yXawXYoNvvF37R.jpg'),
(125470, 9004, 'Beleza Verdadeira S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/245027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yL1bJfenXoIGsILxmqgfn4Q7iR1.jpg'),
(125471, 9004, 'Beleza Verdadeira S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/245028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/swxXz5sFywkY5Neuoxv351Vms6B.jpg'),
(125472, 9004, 'Beleza Verdadeira S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/245029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6bsxciPIGCVLqAoMJvCe0XZ7dUq.jpg'),
(125473, 9004, 'Beleza Verdadeira S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/245030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/36nhKe9zIKeSCZitc3ot0f5fwHR.jpg'),
(125474, 9005, 'Bubu e as Corujinhas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125475, 9005, 'Bubu e as Corujinhas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125476, 9005, 'Bubu e as Corujinhas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125477, 9005, 'Bubu e as Corujinhas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125478, 9005, 'Bubu e as Corujinhas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125479, 9005, 'Bubu e as Corujinhas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125480, 9005, 'Bubu e as Corujinhas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125481, 9005, 'Bubu e as Corujinhas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125482, 9005, 'Bubu e as Corujinhas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125483, 9005, 'Bubu e as Corujinhas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125484, 9005, 'Bubu e as Corujinhas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125485, 9005, 'Bubu e as Corujinhas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125486, 9005, 'Bubu e as Corujinhas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125487, 9005, 'Bubu e as Corujinhas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/244976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125488, 9005, 'Bubu e as Corujinhas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/244977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125489, 9005, 'Bubu e as Corujinhas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/244978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125490, 9005, 'Bubu e as Corujinhas S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/244979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125491, 9005, 'Bubu e as Corujinhas S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/244980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125492, 9005, 'Bubu e as Corujinhas S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/244981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125493, 9005, 'Bubu e as Corujinhas S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/244982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125494, 9005, 'Bubu e as Corujinhas S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/244983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125495, 9005, 'Bubu e as Corujinhas S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/244984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125496, 9005, 'Bubu e as Corujinhas S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/244985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125497, 9005, 'Bubu e as Corujinhas S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/244986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125498, 9005, 'Bubu e as Corujinhas S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/244987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125499, 9005, 'Bubu e as Corujinhas S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/244988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125500, 9006, 'Bubu e as Corujinhas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125501, 9006, 'Bubu e as Corujinhas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125502, 9006, 'Bubu e as Corujinhas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125503, 9006, 'Bubu e as Corujinhas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125504, 9006, 'Bubu e as Corujinhas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125505, 9006, 'Bubu e as Corujinhas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125506, 9006, 'Bubu e as Corujinhas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125507, 9006, 'Bubu e as Corujinhas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125508, 9006, 'Bubu e as Corujinhas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125509, 9006, 'Bubu e as Corujinhas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125510, 9006, 'Bubu e as Corujinhas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125511, 9006, 'Bubu e as Corujinhas S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/245000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125512, 9006, 'Bubu e as Corujinhas S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/245001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125513, 9006, 'Bubu e as Corujinhas S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/245002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125514, 9006, 'Bubu e as Corujinhas S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/245003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125515, 9006, 'Bubu e as Corujinhas S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/245004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125516, 9006, 'Bubu e as Corujinhas S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/245005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125517, 9006, 'Bubu e as Corujinhas S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/245006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125518, 9006, 'Bubu e as Corujinhas S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/245007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125519, 9006, 'Bubu e as Corujinhas S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/245008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125520, 9006, 'Bubu e as Corujinhas S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/245009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125521, 9006, 'Bubu e as Corujinhas S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/245010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125522, 9006, 'Bubu e as Corujinhas S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/245011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125523, 9006, 'Bubu e as Corujinhas S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/245012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125524, 9006, 'Bubu e as Corujinhas S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/245013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125525, 9006, 'Bubu e as Corujinhas S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/245014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3TYLrlIyIO8Fm9JHnYVZjNpu1X.jpg'),
(125526, 9007, 'Gordon Ramsay Do Inferno ao Paraiso em 24h S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wCQdmp2gO12md1WdCmHRhjyD1Z8.jpg'),
(125527, 9007, 'Gordon Ramsay Do Inferno ao Paraiso em 24h S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uwBeUZLqUOyD0aEgqQd3tauvirM.jpg'),
(125528, 9007, 'Gordon Ramsay Do Inferno ao Paraiso em 24h S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u1Cah9F3rIiDSeXXpHLiZkfsKkK.jpg'),
(125529, 9007, 'Gordon Ramsay Do Inferno ao Paraiso em 24h S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1VCRmOGd1rFOMh8lvxOsU9XBgf6.jpg'),
(125530, 9007, 'Gordon Ramsay Do Inferno ao Paraiso em 24h S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUq2KdRhS4tubehmiA0OJyiTvd2.jpg'),
(125531, 9007, 'Gordon Ramsay Do Inferno ao Paraiso em 24h S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nCr7MCwegApuFOHVf8xhpckkEl2.jpg'),
(125532, 9007, 'Gordon Ramsay Do Inferno ao Paraiso em 24h S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24n0ccxjthAzcxldrKKw2MRr61G.jpg'),
(125533, 9007, 'Gordon Ramsay Do Inferno ao Paraiso em 24h S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aMGcQxvOWrlVLcK7oxctCKF6zhl.jpg'),
(125534, 9008, 'Gordon Ramsay Do Inferno ao Paraiso em 24h S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUJlLoFjPQy2Z9TmJquntAOYEZu.jpg'),
(125535, 9008, 'Gordon Ramsay Do Inferno ao Paraiso em 24h S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUJlLoFjPQy2Z9TmJquntAOYEZu.jpg'),
(125536, 9008, 'Gordon Ramsay Do Inferno ao Paraiso em 24h S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUJlLoFjPQy2Z9TmJquntAOYEZu.jpg'),
(125537, 9008, 'Gordon Ramsay Do Inferno ao Paraiso em 24h S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUJlLoFjPQy2Z9TmJquntAOYEZu.jpg'),
(125538, 9008, 'Gordon Ramsay Do Inferno ao Paraiso em 24h S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUJlLoFjPQy2Z9TmJquntAOYEZu.jpg'),
(125539, 9008, 'Gordon Ramsay Do Inferno ao Paraiso em 24h S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUJlLoFjPQy2Z9TmJquntAOYEZu.jpg'),
(125540, 9008, 'Gordon Ramsay Do Inferno ao Paraiso em 24h S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUJlLoFjPQy2Z9TmJquntAOYEZu.jpg'),
(125541, 9008, 'Gordon Ramsay Do Inferno ao Paraiso em 24h S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUJlLoFjPQy2Z9TmJquntAOYEZu.jpg'),
(125542, 9008, 'Gordon Ramsay Do Inferno ao Paraiso em 24h S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUJlLoFjPQy2Z9TmJquntAOYEZu.jpg'),
(125543, 9008, 'Gordon Ramsay Do Inferno ao Paraiso em 24h S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUJlLoFjPQy2Z9TmJquntAOYEZu.jpg'),
(125544, 9009, 'Gordon Ramsay Do Inferno ao Paraiso em 24h S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qwm3ss8PVcy4WpdHpr60ArIiPBn.jpg'),
(125545, 9009, 'Gordon Ramsay Do Inferno ao Paraiso em 24h S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2MsjMAenMoB1xUX3IkoX3wb8yYr.jpg'),
(125546, 9009, 'Gordon Ramsay Do Inferno ao Paraiso em 24h S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/405767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oyH9sCISzwz4MVatDx4hPzX87nX.jpg'),
(125547, 9010, 'Peixonauta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Ml8hKh0mQwBQxOWsl3cH13l6Y5.jpg'),
(125548, 9010, 'Peixonauta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oIInaruyBnY6Wya55foefiFIByQ.jpg'),
(125549, 9010, 'Peixonauta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7KJzq9nvlFYleOhePn76TvOstDT.jpg'),
(125550, 9010, 'Peixonauta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7KJzq9nvlFYleOhePn76TvOstDT.jpg'),
(125551, 9010, 'Peixonauta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhLXUZbp3SLMiM3vpSr3P7ykPS2.jpg'),
(125552, 9010, 'Peixonauta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkXKY2QYVBS0cUu4f1f0VCgE003.jpg'),
(125553, 9010, 'Peixonauta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125554, 9010, 'Peixonauta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125555, 9010, 'Peixonauta S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125556, 9010, 'Peixonauta S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125557, 9010, 'Peixonauta S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125558, 9010, 'Peixonauta S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125559, 9010, 'Peixonauta S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125560, 9010, 'Peixonauta S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/244872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125561, 9010, 'Peixonauta S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/244873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(125562, 9010, 'Peixonauta S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/244874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125563, 9010, 'Peixonauta S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/244875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125564, 9010, 'Peixonauta S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/244876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125565, 9010, 'Peixonauta S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/244877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125566, 9010, 'Peixonauta S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/244878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125567, 9010, 'Peixonauta S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/244879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125568, 9010, 'Peixonauta S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/244880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125569, 9010, 'Peixonauta S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/244881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125570, 9010, 'Peixonauta S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/244882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125571, 9010, 'Peixonauta S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/244883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125572, 9010, 'Peixonauta S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/244884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125573, 9010, 'Peixonauta S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/244885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125574, 9010, 'Peixonauta S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/244886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125575, 9010, 'Peixonauta S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/244887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125576, 9010, 'Peixonauta S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/244888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125577, 9010, 'Peixonauta S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/244889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125578, 9010, 'Peixonauta S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/244890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125579, 9010, 'Peixonauta S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/244891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125580, 9010, 'Peixonauta S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/244892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125581, 9010, 'Peixonauta S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/244893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125582, 9010, 'Peixonauta S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/244894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125583, 9010, 'Peixonauta S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/244895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125584, 9010, 'Peixonauta S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/244896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125585, 9010, 'Peixonauta S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/244897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125586, 9010, 'Peixonauta S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/244898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125587, 9010, 'Peixonauta S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/244899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125588, 9010, 'Peixonauta S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/244900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125589, 9010, 'Peixonauta S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/244901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125590, 9010, 'Peixonauta S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/244902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125591, 9010, 'Peixonauta S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/244903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125592, 9010, 'Peixonauta S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/244904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125593, 9010, 'Peixonauta S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/244905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125594, 9010, 'Peixonauta S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/244906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125595, 9010, 'Peixonauta S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/244907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125596, 9010, 'Peixonauta S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/244908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125597, 9010, 'Peixonauta S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/244909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125598, 9010, 'Peixonauta S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/244910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125599, 9011, 'Peixonauta S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125600, 9011, 'Peixonauta S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125601, 9011, 'Peixonauta S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125602, 9011, 'Peixonauta S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125603, 9011, 'Peixonauta S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125604, 9011, 'Peixonauta S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125605, 9011, 'Peixonauta S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125606, 9011, 'Peixonauta S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125607, 9011, 'Peixonauta S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125608, 9011, 'Peixonauta S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125609, 9011, 'Peixonauta S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125610, 9011, 'Peixonauta S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125611, 9011, 'Peixonauta S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125612, 9011, 'Peixonauta S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/244924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125613, 9011, 'Peixonauta S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/244925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125614, 9011, 'Peixonauta S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/244926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125615, 9011, 'Peixonauta S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/244927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125616, 9011, 'Peixonauta S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/244928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125617, 9011, 'Peixonauta S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/244929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125618, 9011, 'Peixonauta S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/244930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125619, 9011, 'Peixonauta S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/244931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125620, 9011, 'Peixonauta S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/244932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125621, 9011, 'Peixonauta S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/244933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125622, 9011, 'Peixonauta S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/244934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125623, 9011, 'Peixonauta S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/244935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125624, 9011, 'Peixonauta S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/244936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125625, 9011, 'Peixonauta S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/244937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125626, 9011, 'Peixonauta S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/244938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125627, 9011, 'Peixonauta S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/244939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125628, 9011, 'Peixonauta S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/244940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125629, 9011, 'Peixonauta S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/244941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125630, 9011, 'Peixonauta S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/244942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125631, 9011, 'Peixonauta S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/244943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125632, 9011, 'Peixonauta S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/244944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125633, 9011, 'Peixonauta S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/244945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125634, 9011, 'Peixonauta S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/244946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125635, 9011, 'Peixonauta S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/244947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125636, 9011, 'Peixonauta S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/244948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125637, 9011, 'Peixonauta S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/244949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125638, 9011, 'Peixonauta S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/244950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125639, 9011, 'Peixonauta S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/244951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125640, 9011, 'Peixonauta S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/244952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125641, 9011, 'Peixonauta S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/244953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125642, 9011, 'Peixonauta S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/244954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125643, 9011, 'Peixonauta S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/244955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125644, 9011, 'Peixonauta S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/244956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125645, 9011, 'Peixonauta S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/244957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125646, 9011, 'Peixonauta S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/244958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125647, 9011, 'Peixonauta S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/244959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125648, 9011, 'Peixonauta S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/244960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125649, 9011, 'Peixonauta S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/244961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125650, 9011, 'Peixonauta S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/244962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cy1jxlpJGG74aQ9mM0QDcbK4EFa.jpg'),
(125651, 9012, 'Porto Papel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9EZokC6DkfJeefNtooxDFgPfUPo.jpg'),
(125652, 9012, 'Porto Papel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wzMpenCHYPL0HC67fuLu51qVAXq.jpg'),
(125653, 9012, 'Porto Papel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vncoPTGvLnr5InLOaodKHQLptou.jpg'),
(125654, 9012, 'Porto Papel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dpwQ73hHGR1DXCZRCEO03u30R6P.jpg'),
(125655, 9012, 'Porto Papel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2rFCwF2eFAl9ajlA7jofq06kNQr.jpg'),
(125656, 9012, 'Porto Papel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1LELFRIluA5x0wZ4Bsq5CGwugP0.jpg'),
(125657, 9012, 'Porto Papel S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8SPEAyO2yPBZctEZRdj9KsQZeEm.jpg'),
(125658, 9012, 'Porto Papel S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/30ImFKeGnWoAEHhlAEXcV3j498x.jpg'),
(125659, 9012, 'Porto Papel S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7cbCdegVtLg6loiSaWOMiA9jrL5.jpg'),
(125660, 9012, 'Porto Papel S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7aVWP0cgL19cYVaJ05UO3OkNgRD.jpg'),
(125661, 9012, 'Porto Papel S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v2n5oxpe562WYfkRoQeBNPvFMqn.jpg'),
(125662, 9012, 'Porto Papel S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rSo0ANGabrlyzjFzhuLxC1OzCqV.jpg'),
(125663, 9012, 'Porto Papel S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vDnrxRp7HmZK1kf06FNLUpqC6vX.jpg'),
(125664, 9012, 'Porto Papel S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/244820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f7DMJsp73mztP0abe5zYiVgJ9ol.jpg'),
(125665, 9012, 'Porto Papel S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/244821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vXJgroCV0uzwYAagTW4N5ODqNHU.jpg'),
(125666, 9012, 'Porto Papel S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/244822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ezIWcJRdHVrGhrEli4bcf6vVocJ.jpg'),
(125667, 9012, 'Porto Papel S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/244823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/19B8hcUhweMxnoFXXAxqCWAzlyU.jpg'),
(125668, 9012, 'Porto Papel S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/244824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gybjccEFxTYpk2wo8q5aTe6wAeX.jpg'),
(125669, 9012, 'Porto Papel S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/244825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vL6SLK7GZVqogefFrBWIMaemayw.jpg'),
(125670, 9012, 'Porto Papel S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/244826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lj51peQ7JMJG5zm7KFahjVn9AyQ.jpg'),
(125671, 9012, 'Porto Papel S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/244827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/UoNurBo22bH26cuUVY9MgOTdLU.jpg'),
(125672, 9012, 'Porto Papel S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/244828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xCGygwJlaK4BNUF7XPS84YPalA4.jpg'),
(125673, 9012, 'Porto Papel S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/244829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/58iHQpOD9jd2Ih7yHc9D73azo6l.jpg'),
(125674, 9012, 'Porto Papel S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/244830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gb6u47cuVlxyoM9y2ORPHxvWneb.jpg'),
(125675, 9012, 'Porto Papel S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/244831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ap22Ct9ARmhrdocd2BzXANATRBE.jpg'),
(125676, 9012, 'Porto Papel S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/244832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBwWt1aOCxOy6bDOv7mZs2pVjAZ.jpg'),
(125677, 9013, 'Porto Papel S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125678, 9013, 'Porto Papel S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125679, 9013, 'Porto Papel S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125680, 9013, 'Porto Papel S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125681, 9013, 'Porto Papel S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125682, 9013, 'Porto Papel S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125683, 9013, 'Porto Papel S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125684, 9013, 'Porto Papel S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125685, 9013, 'Porto Papel S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125686, 9013, 'Porto Papel S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125687, 9013, 'Porto Papel S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125688, 9013, 'Porto Papel S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125689, 9013, 'Porto Papel S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125690, 9013, 'Porto Papel S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/244846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125691, 9013, 'Porto Papel S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/244847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125692, 9013, 'Porto Papel S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/244848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125693, 9013, 'Porto Papel S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/244849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125694, 9013, 'Porto Papel S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/244850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125695, 9013, 'Porto Papel S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/244851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125696, 9013, 'Porto Papel S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/244852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125697, 9013, 'Porto Papel S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/244853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125698, 9013, 'Porto Papel S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/244854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125699, 9013, 'Porto Papel S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/244855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125700, 9013, 'Porto Papel S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/244856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125701, 9013, 'Porto Papel S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/244857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125702, 9013, 'Porto Papel S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/244858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uo7E9FPUj7Iib6ToQxSFmniUfQh.jpg'),
(125703, 9014, 'Round 6 O Desafio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUolfAUop5JtKkO0fSq33r9KCKW.jpg'),
(125704, 9014, 'Round 6 O Desafio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUolfAUop5JtKkO0fSq33r9KCKW.jpg'),
(125705, 9014, 'Round 6 O Desafio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUolfAUop5JtKkO0fSq33r9KCKW.jpg'),
(125706, 9014, 'Round 6 O Desafio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUolfAUop5JtKkO0fSq33r9KCKW.jpg'),
(125707, 9014, 'Round 6 O Desafio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUolfAUop5JtKkO0fSq33r9KCKW.jpg'),
(125708, 9014, 'Round 6 O Desafio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUolfAUop5JtKkO0fSq33r9KCKW.jpg'),
(125709, 9014, 'Round 6 O Desafio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUolfAUop5JtKkO0fSq33r9KCKW.jpg'),
(125710, 9014, 'Round 6 O Desafio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUolfAUop5JtKkO0fSq33r9KCKW.jpg'),
(125711, 9014, 'Round 6 O Desafio S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUolfAUop5JtKkO0fSq33r9KCKW.jpg'),
(125712, 9014, 'Round 6 O Desafio S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUolfAUop5JtKkO0fSq33r9KCKW.jpg'),
(125713, 9015, 'Round 6 O Desafio S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/891834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUolfAUop5JtKkO0fSq33r9KCKW.jpg'),
(125714, 9015, 'Round 6 O Desafio S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/891835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUolfAUop5JtKkO0fSq33r9KCKW.jpg'),
(125715, 9015, 'Round 6 O Desafio S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/891836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUolfAUop5JtKkO0fSq33r9KCKW.jpg'),
(125716, 9015, 'Round 6 O Desafio S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/891837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUolfAUop5JtKkO0fSq33r9KCKW.jpg'),
(125717, 9015, 'Round 6 O Desafio S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/892420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUolfAUop5JtKkO0fSq33r9KCKW.jpg'),
(125718, 9015, 'Round 6 O Desafio S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/892421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUolfAUop5JtKkO0fSq33r9KCKW.jpg'),
(125719, 9015, 'Round 6 O Desafio S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/892422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUolfAUop5JtKkO0fSq33r9KCKW.jpg'),
(125720, 9015, 'Round 6 O Desafio S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/892423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUolfAUop5JtKkO0fSq33r9KCKW.jpg'),
(125721, 9015, 'Round 6 O Desafio S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/893066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sUolfAUop5JtKkO0fSq33r9KCKW.jpg'),
(125722, 9016, 'Samurai 7 [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fjgNdjGf55cC1jovQSEVgS4szZ0.jpg'),
(125723, 9016, 'Samurai 7 [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eoBCWeDCs6emGRnsQCLdwwTA95C.jpg'),
(125724, 9016, 'Samurai 7 [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6MgYAPYOM3rH3a9zYQmhpmz90CY.jpg'),
(125725, 9016, 'Samurai 7 [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/142ht17pzX9IXMzLtL4KSy3eZ75.jpg'),
(125726, 9016, 'Samurai 7 [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xdApmIvm84ikwRWNEyKJOsIufbv.jpg'),
(125727, 9016, 'Samurai 7 [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sOvdfzakP7minc1eg1NVj0zI5Yi.jpg'),
(125728, 9016, 'Samurai 7 [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z3YMygBhZd7k7i45nmG1P61zmKV.jpg'),
(125729, 9016, 'Samurai 7 [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/du70vm3vdvHnmGYvDfQ1QaMj5RY.jpg'),
(125730, 9016, 'Samurai 7 [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j5IxvUscYy4FzMc6Ijnm4JlVOHM.jpg'),
(125731, 9016, 'Samurai 7 [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1zS5f2TPYGSoTx5ZcW7zDKOdMPs.jpg'),
(125732, 9016, 'Samurai 7 [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/esTsXLcBA7rVEHWUjngBxdQdOYD.jpg'),
(125733, 9016, 'Samurai 7 [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zfXk9P4FF5xNonNEmfqZv9c0E8O.jpg'),
(125734, 9016, 'Samurai 7 [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dNgFeQTApEHfXngZudFMjaZAvNv.jpg'),
(125735, 9016, 'Samurai 7 [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/244794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oLJw1ARVLnq9werZPXox6TKnZ4x.jpg'),
(125736, 9016, 'Samurai 7 [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/244795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FVl74aebFWLdxFenka7m9lfOU4.jpg'),
(125737, 9016, 'Samurai 7 [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/244796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Mghp6dYwyYIxzhutR47O4PbBSw.jpg'),
(125738, 9016, 'Samurai 7 [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/244797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sF6PxzCIpGmcoln2tzqIC0tvyaK.jpg'),
(125739, 9016, 'Samurai 7 [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/244798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9cVnHoD5GbUFJ6P6rTSc2VGSdw.jpg'),
(125740, 9016, 'Samurai 7 [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/244799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4geuBS1Q9LUmGDPkWXosEXmn7A6.jpg'),
(125741, 9016, 'Samurai 7 [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/244800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/onDx5ZROBPHq5EumgVEYBltDq4K.jpg'),
(125742, 9016, 'Samurai 7 [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/244801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8QruTO3Q9tGs3o1KD49HmbdIBH1.jpg'),
(125743, 9016, 'Samurai 7 [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/244802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eDb17AacLWcWCOFXj9Ld0Qhx7aT.jpg'),
(125744, 9016, 'Samurai 7 [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/244803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l82DepFmzWreE2624hPC0ouX1TX.jpg'),
(125745, 9016, 'Samurai 7 [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/244804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mzIbay1UwO1d8I00bCC9Cfe58j0.jpg'),
(125746, 9016, 'Samurai 7 [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/244805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q8H1wb4bIWW2w52qMme38Hjc1mW.jpg'),
(125747, 9016, 'Samurai 7 [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/244806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dyiRnj0nM1qqLXZGJTiIwbiaUC6.jpg'),
(125748, 9017, 'Trolls O ritmo continua S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iHk1WIT5RjHvCIXluHT8CCJycNR.jpg'),
(125749, 9017, 'Trolls O ritmo continua S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xfyfkWhJU63kOrPOVXG5ZdJHNuz.jpg'),
(125750, 9017, 'Trolls O ritmo continua S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xfyfkWhJU63kOrPOVXG5ZdJHNuz.jpg'),
(125751, 9017, 'Trolls O ritmo continua S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Ku1FBlLmNpVcSq0xv9hlKwmxfE.jpg'),
(125752, 9017, 'Trolls O ritmo continua S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xfyfkWhJU63kOrPOVXG5ZdJHNuz.jpg'),
(125753, 9017, 'Trolls O ritmo continua S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mvM9OqGkbHQXmz24iVMfTWJTraq.jpg'),
(125754, 9018, 'Trolls O ritmo continua S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fHRCj5Bws9uq9kJsr2ddZI0NiM8.jpg'),
(125755, 9018, 'Trolls O ritmo continua S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xfyfkWhJU63kOrPOVXG5ZdJHNuz.jpg'),
(125756, 9018, 'Trolls O ritmo continua S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xfyfkWhJU63kOrPOVXG5ZdJHNuz.jpg'),
(125757, 9018, 'Trolls O ritmo continua S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1OeOfHqfd0BFBTu4ZBLNCfomgKv.jpg'),
(125758, 9018, 'Trolls O ritmo continua S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xfyfkWhJU63kOrPOVXG5ZdJHNuz.jpg'),
(125759, 9018, 'Trolls O ritmo continua S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xfyfkWhJU63kOrPOVXG5ZdJHNuz.jpg'),
(125760, 9019, 'Trolls O ritmo continua S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j57gYM4CuJuXVHQEgE3WeazyLQy.jpg'),
(125761, 9019, 'Trolls O ritmo continua S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xfyfkWhJU63kOrPOVXG5ZdJHNuz.jpg'),
(125762, 9019, 'Trolls O ritmo continua S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5utg9LmvQ0IScdFDdhDLpr2JuHI.jpg'),
(125763, 9019, 'Trolls O ritmo continua S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xfyfkWhJU63kOrPOVXG5ZdJHNuz.jpg'),
(125764, 9019, 'Trolls O ritmo continua S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/IBTPLxMy7idHjtJtzTf5DAp6wn.jpg'),
(125765, 9019, 'Trolls O ritmo continua S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xfyfkWhJU63kOrPOVXG5ZdJHNuz.jpg'),
(125766, 9019, 'Trolls O ritmo continua S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8gZFvkiVDm9Kx6ih8KfQty4xXuM.jpg'),
(125767, 9020, 'Trolls O ritmo continua S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xfyfkWhJU63kOrPOVXG5ZdJHNuz.jpg'),
(125768, 9020, 'Trolls O ritmo continua S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xfyfkWhJU63kOrPOVXG5ZdJHNuz.jpg'),
(125769, 9020, 'Trolls O ritmo continua S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uMAiMOhBjtYU91hS1j81Qud5HM7.jpg'),
(125770, 9020, 'Trolls O ritmo continua S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xfyfkWhJU63kOrPOVXG5ZdJHNuz.jpg'),
(125771, 9020, 'Trolls O ritmo continua S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xfyfkWhJU63kOrPOVXG5ZdJHNuz.jpg'),
(125772, 9020, 'Trolls O ritmo continua S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8r3mgT9tdLXsYR7N4E4aHX3oPWm.jpg'),
(125773, 9020, 'Trolls O ritmo continua S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xfyfkWhJU63kOrPOVXG5ZdJHNuz.jpg'),
(125774, 9021, 'Codename Annika [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qWD4Hgj1HK132TnQzk3DPcJYhfm.jpg'),
(125775, 9021, 'Codename Annika [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r5xPGmMh6JVOh5RzoB46CoC005S.jpg'),
(125776, 9021, 'Codename Annika [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r5xPGmMh6JVOh5RzoB46CoC005S.jpg'),
(125777, 9021, 'Codename Annika [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r5xPGmMh6JVOh5RzoB46CoC005S.jpg'),
(125778, 9021, 'Codename Annika [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r5xPGmMh6JVOh5RzoB46CoC005S.jpg'),
(125779, 9021, 'Codename Annika [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r5xPGmMh6JVOh5RzoB46CoC005S.jpg'),
(125780, 9022, 'Rocket Power S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h3PeNFoXBpqmywQnyDxeViAfSek.jpg'),
(125781, 9022, 'Rocket Power S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6lxrRebWIyvKRrKpFVSVa4NoRUm.jpg'),
(125782, 9022, 'Rocket Power S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/34dmPInvjvFIHONN9X4ALtSrFy4.jpg'),
(125783, 9022, 'Rocket Power S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/XSTwt7PpRmXzqT09wiFtS0K2tr.jpg'),
(125784, 9022, 'Rocket Power S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5IAPp35tZiMwCJ1V3Nr8oyETaLv.jpg'),
(125785, 9022, 'Rocket Power S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tiorRMtljR8Qg4rSkey19toFfnm.jpg'),
(125786, 9022, 'Rocket Power S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOOYTEL66JuOAHx6VdqJDLILuUX.jpg'),
(125787, 9022, 'Rocket Power S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A5sJUbkm8Z1Wio9kZK1CoXS0wgd.jpg'),
(125788, 9022, 'Rocket Power S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lXeRVa9BbbHGZmT9kh04vQaHV1z.jpg'),
(125789, 9022, 'Rocket Power S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/56YKnm3hv5qFXSRpGGGUX4FPFMM.jpg'),
(125790, 9022, 'Rocket Power S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/44tLTagWqvjTpMSek9F0lI2wAO5.jpg'),
(125791, 9022, 'Rocket Power S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uswTNS7LZLVy0AAhNiXxzr5kfJ8.jpg'),
(125792, 9022, 'Rocket Power S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6QcuRCZtm41AbGsxJvIOrSxFoR.jpg'),
(125793, 9022, 'Rocket Power S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/244414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tEZke0nh8ITvq8cC5zL9qmR1WEu.jpg'),
(125794, 9022, 'Rocket Power S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/244415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vkD5gc1M6j15TQuW6dWkI0mvvum.jpg'),
(125795, 9022, 'Rocket Power S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/244416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZt1GqG1KlVN7B8htbhncqDBKAH.jpg'),
(125796, 9022, 'Rocket Power S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/244417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7aXu29FOZrVg2LSBb0erFDshFDZ.jpg'),
(125797, 9022, 'Rocket Power S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/244418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v0n3sEyaCBj1gH5dyaRGCod7jDQ.jpg'),
(125798, 9022, 'Rocket Power S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/244419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rcpGUPNcPzAq28D8Tf3fVp3dC5z.jpg'),
(125799, 9022, 'Rocket Power S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/244420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fSI6SD5Y0YuojU86wENVF8HzMSQ.jpg'),
(125800, 9023, 'Rocket Power S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/agNnlSIomPYeudKJNriV7tf5di0.jpg'),
(125801, 9023, 'Rocket Power S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7DeaZBsO9Igd9Vv7sMbDC7atJpC.jpg'),
(125802, 9023, 'Rocket Power S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lr8AyLygFTRTkiuXdK0JsH8tLsS.jpg'),
(125803, 9023, 'Rocket Power S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/exM9aQJOwRGwxxl4BMIybdTJmaH.jpg'),
(125804, 9023, 'Rocket Power S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wLDDs74fOmJ0Qf3ThOKs4lJAcNS.jpg'),
(125805, 9023, 'Rocket Power S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cIgqRTyr2ahrfbweycYYdySlB5y.jpg'),
(125806, 9023, 'Rocket Power S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ynk5dDKTkhUMvCM1iy8Ds2r8R9N.jpg'),
(125807, 9023, 'Rocket Power S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQcCqvEDqrqkRtRMXPZocRwBbGt.jpg'),
(125808, 9023, 'Rocket Power S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lIeorj87NdajM7HLur1M5I9AUXy.jpg'),
(125809, 9023, 'Rocket Power S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/57uKWOQD6JoZ6LWl6nmFAFRFdMq.jpg'),
(125810, 9023, 'Rocket Power S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWPYp1PjYpxgNNMpsFEBC8deOX.jpg'),
(125811, 9023, 'Rocket Power S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5DjqHXIo0yOKIKtIJH60PzFjeCe.jpg'),
(125812, 9023, 'Rocket Power S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ao7phgDbr0y0r9KnfnyQEWdtHEU.jpg'),
(125813, 9023, 'Rocket Power S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/244434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hAv25PYgWXrsmXrxX2611m2b2ey.jpg'),
(125814, 9023, 'Rocket Power S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/244435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/94OX3Ln12upKPyMf9SAGfRnDzxi.jpg'),
(125815, 9023, 'Rocket Power S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/244436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWPYp1PjYpxgNNMpsFEBC8deOX.jpg'),
(125816, 9023, 'Rocket Power S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/244437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/krBz89y2HQuxQkL1rn5g2SDckXF.jpg'),
(125817, 9023, 'Rocket Power S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/244438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWPYp1PjYpxgNNMpsFEBC8deOX.jpg'),
(125818, 9024, 'Rocket Power S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aTOcDaUYyVluvOZuRLfH9U1KQXl.jpg'),
(125819, 9024, 'Rocket Power S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JOe2aUWpEYb6rUkCr3EniswTRK.jpg'),
(125820, 9024, 'Rocket Power S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uNYCLnBnwGf8k6tePamUdRyUz79.jpg'),
(125821, 9024, 'Rocket Power S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/id03vD6xTnKaiSIL9Y8ZNA5cws.jpg'),
(125822, 9024, 'Rocket Power S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iapS85QUL983UlahNdL8fRNRFE3.jpg'),
(125823, 9024, 'Rocket Power S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ebLEAL3pbjEo3rnf3bQmnDw1Wxr.jpg'),
(125824, 9024, 'Rocket Power S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A0trcDxxWnAErk1uOsTzcyKPh0Z.jpg'),
(125825, 9024, 'Rocket Power S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/icjYxL3Y3bR7hVtkSyinBvlVh8r.jpg'),
(125826, 9024, 'Rocket Power S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWPYp1PjYpxgNNMpsFEBC8deOX.jpg'),
(125827, 9024, 'Rocket Power S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/54pn9gNII26evAmZkQv7Ukc75AX.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(125828, 9024, 'Rocket Power S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8T5uyIc1RzAKOqUr3mnY5ag27EG.jpg'),
(125829, 9024, 'Rocket Power S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yGW3KBJnLqQwp5TFZtsgeFbFgzg.jpg'),
(125830, 9024, 'Rocket Power S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mnepYzyEXVoqIM9PwgaUCQpUvCA.jpg'),
(125831, 9024, 'Rocket Power S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/244452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/znmhQSthHs7GrecV1ZVcx2wrmI8.jpg'),
(125832, 9024, 'Rocket Power S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/244453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mCGIIfecuLYhtsqxXBDIXpEjKnY.jpg'),
(125833, 9024, 'Rocket Power S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/244454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWPYp1PjYpxgNNMpsFEBC8deOX.jpg'),
(125834, 9024, 'Rocket Power S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/244455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWPYp1PjYpxgNNMpsFEBC8deOX.jpg'),
(125835, 9024, 'Rocket Power S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/244456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vOt5EasjJM3ZhmYpuXKMnlJbDp.jpg'),
(125836, 9024, 'Rocket Power S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/244457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kwwQZEVLHorrVJ4VtfxWgkVVEkK.jpg'),
(125837, 9024, 'Rocket Power S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/244458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oDxxT1ieHdHBC1QI2AAyXLRLben.jpg'),
(125838, 9025, 'Rocket Power S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWPYp1PjYpxgNNMpsFEBC8deOX.jpg'),
(125839, 9025, 'Rocket Power S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWPYp1PjYpxgNNMpsFEBC8deOX.jpg'),
(125840, 9025, 'Rocket Power S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWPYp1PjYpxgNNMpsFEBC8deOX.jpg'),
(125841, 9025, 'Rocket Power S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWPYp1PjYpxgNNMpsFEBC8deOX.jpg'),
(125842, 9025, 'Rocket Power S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWPYp1PjYpxgNNMpsFEBC8deOX.jpg'),
(125843, 9025, 'Rocket Power S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWPYp1PjYpxgNNMpsFEBC8deOX.jpg'),
(125844, 9025, 'Rocket Power S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWPYp1PjYpxgNNMpsFEBC8deOX.jpg'),
(125845, 9025, 'Rocket Power S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWPYp1PjYpxgNNMpsFEBC8deOX.jpg'),
(125846, 9025, 'Rocket Power S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWPYp1PjYpxgNNMpsFEBC8deOX.jpg'),
(125847, 9025, 'Rocket Power S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWPYp1PjYpxgNNMpsFEBC8deOX.jpg'),
(125848, 9025, 'Rocket Power S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWPYp1PjYpxgNNMpsFEBC8deOX.jpg'),
(125849, 9026, 'The Mick S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nZWVpY8l5oXLdSAMjhurp0ipZzq.jpg'),
(125850, 9026, 'The Mick S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6tZUsgNcCnz3nG0ZfaVTtGNsb1X.jpg'),
(125851, 9026, 'The Mick S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/haRWIis0IK0ZC1MAYuc7DhDBKyH.jpg'),
(125852, 9026, 'The Mick S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wEBhGDnE1OQGinOkWCrqe2481qU.jpg'),
(125853, 9026, 'The Mick S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8iwLkmikfHKoodEqZ9SNHOATvnm.jpg'),
(125854, 9026, 'The Mick S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bjgyc5tq9kLVpeCNlTH5Mcz1MDz.jpg'),
(125855, 9026, 'The Mick S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hGIZxeDKoSy1Sokr2cfJGTI32Oi.jpg'),
(125856, 9026, 'The Mick S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9zimwJ6DXoXeG5PV4jG66mODnww.jpg'),
(125857, 9026, 'The Mick S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x9m4YCH9r9KsmWAREU0goOFtxx3.jpg'),
(125858, 9026, 'The Mick S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/50D4XH7VG1xLHfMYEKexUK0DNmZ.jpg'),
(125859, 9026, 'The Mick S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jIPhFiJyMBBgDqyJCNdXQJZi42u.jpg'),
(125860, 9026, 'The Mick S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kIzVlUayYhLF59fNY3JyaBsAYTx.jpg'),
(125861, 9026, 'The Mick S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4vgOdKjPOrEoUJbnevHTJd40X3T.jpg'),
(125862, 9026, 'The Mick S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/244198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHKglbOAeinOzFqphhJei1KZDBa.jpg'),
(125863, 9026, 'The Mick S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/244199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ad9NZclrcnGjFzuGsw73LwhCkBt.jpg'),
(125864, 9026, 'The Mick S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/244200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ddbRGQAwSMIeYA5OdCPo9M9LF4f.jpg'),
(125865, 9026, 'The Mick S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/244201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ee1smzKQuowUlEmSZZsJDLJa7qh.jpg'),
(125866, 9027, 'The Mick S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kz9Z0bKQFWPjxU2Lqyqgj4ARKlq.jpg'),
(125867, 9027, 'The Mick S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tfoKAZQt1YHfWknMQz4fHY5zUWo.jpg'),
(125868, 9027, 'The Mick S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3b2CJxk5H4kcxxEPaSTzvHWYvFX.jpg'),
(125869, 9027, 'The Mick S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/umVfmXf4F4kQG61NG7d1ArHffhM.jpg'),
(125870, 9027, 'The Mick S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3wwtg2gTELB4cbJLhjjuMVB0nRs.jpg'),
(125871, 9027, 'The Mick S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Opdp7R6NnFJdxxli2QQPdib2gg.jpg'),
(125872, 9027, 'The Mick S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sAu2GOktnBD1cc4t5o7EjSj1HTi.jpg'),
(125873, 9027, 'The Mick S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/33AL1S66j7HcAfwqAtBExP0j2wZ.jpg'),
(125874, 9027, 'The Mick S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ypfpcItbSS4GyXomSg4Bt1VnD6U.jpg'),
(125875, 9027, 'The Mick S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aJOwuDyg4NXeblrZ2LSZvR5RewO.jpg'),
(125876, 9027, 'The Mick S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xv0Szbk2y8UXZcjShAngQhdbXYp.jpg'),
(125877, 9027, 'The Mick S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBOehgic1aJQ76eTlqg29M9MBkM.jpg'),
(125878, 9027, 'The Mick S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/DjJb5KKPBAN7hPVXQ6Ag4AQFeF.jpg'),
(125879, 9027, 'The Mick S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/244215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iu69m0ye9Vy4LaWr9EWDK2AtjkQ.jpg'),
(125880, 9027, 'The Mick S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/244216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yf0UfrgFhu0T07hEmlTJgsE0OsO.jpg'),
(125881, 9027, 'The Mick S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/244217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uLMEAfNXpeU6lnqfqU0ZB2FzUS7.jpg'),
(125882, 9027, 'The Mick S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/244218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/14c6H93xOgdmiJPjRKK5U0aUaK4.jpg'),
(125883, 9027, 'The Mick S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/244219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hbr6wjuqD90YGoV9m5m5ntD3fK3.jpg'),
(125884, 9027, 'The Mick S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/244220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iCk4AHUv5qV9cO5Whmzmx4HLUhl.jpg'),
(125885, 9027, 'The Mick S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/244221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/go2WgEcXl6zMxC7fk9J3RPJVmdy.jpg'),
(125886, 9028, 'My Daemon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mFmd67buMTfO3OLQVPHNAufjilY.jpg'),
(125887, 9028, 'My Daemon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3TkPsFO70ddRoBbpYF66mM6DBQk.jpg'),
(125888, 9028, 'My Daemon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zX8trYN8WoScMEfLePqsVuJxnPG.jpg'),
(125889, 9028, 'My Daemon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hRS4JZEGpzLjapPChVgrqOrT9Oo.jpg'),
(125890, 9028, 'My Daemon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtfQCrd1kCtuSq8cNmQdzrtBp3E.jpg'),
(125891, 9028, 'My Daemon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AqG1cOogiW7YtZe2RMgD6UeUAZK.jpg'),
(125892, 9028, 'My Daemon S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nTIcTeOU4cVHUFsXngalNoeHvAE.jpg'),
(125893, 9028, 'My Daemon S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5UsHBqS3nloMsK8GzNGlkmgWFkL.jpg'),
(125894, 9028, 'My Daemon S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oiRXEmC4FexHlvRNoZABLHrNcBu.jpg'),
(125895, 9028, 'My Daemon S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vgjo9hSbd2aiYGAOlGe12bxoOKp.jpg'),
(125896, 9028, 'My Daemon S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ndQB8EgtbRbacNaC2aAQVD91Gyf.jpg'),
(125897, 9028, 'My Daemon S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5VtCFXvtWKZ7QoO7zRar74g8dxl.jpg'),
(125898, 9028, 'My Daemon S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8MLvr4orJozfW9MFGHAT5B9vYPU.jpg'),
(125899, 9029, 'Turma CoComelon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eJYeNwCiF9kDzYejid0invHvEdz.jpg'),
(125900, 9029, 'Turma CoComelon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eJYeNwCiF9kDzYejid0invHvEdz.jpg'),
(125901, 9029, 'Turma CoComelon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eJYeNwCiF9kDzYejid0invHvEdz.jpg'),
(125902, 9029, 'Turma CoComelon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eJYeNwCiF9kDzYejid0invHvEdz.jpg'),
(125903, 9029, 'Turma CoComelon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eJYeNwCiF9kDzYejid0invHvEdz.jpg'),
(125904, 9029, 'Turma CoComelon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eJYeNwCiF9kDzYejid0invHvEdz.jpg'),
(125905, 9029, 'Turma CoComelon S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eJYeNwCiF9kDzYejid0invHvEdz.jpg'),
(125906, 9029, 'Turma CoComelon S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eJYeNwCiF9kDzYejid0invHvEdz.jpg'),
(125907, 9029, 'Turma CoComelon S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eJYeNwCiF9kDzYejid0invHvEdz.jpg'),
(125908, 9030, 'Um Trilhao de Dolares S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6nf4rDjaHVal6RPr66PkR1DJCdD.jpg'),
(125909, 9030, 'Um Trilhao de Dolares S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/twLTJNljf4rFQZaVFFJVKuusWaw.jpg'),
(125910, 9030, 'Um Trilhao de Dolares S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dJlWjhmQ7Nmbc8GZD33xcERJ8Vw.jpg'),
(125911, 9030, 'Um Trilhao de Dolares S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dJlWjhmQ7Nmbc8GZD33xcERJ8Vw.jpg'),
(125912, 9030, 'Um Trilhao de Dolares S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dJlWjhmQ7Nmbc8GZD33xcERJ8Vw.jpg'),
(125913, 9030, 'Um Trilhao de Dolares S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dJlWjhmQ7Nmbc8GZD33xcERJ8Vw.jpg'),
(125914, 9031, 'Super Choque S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xqeSlW4aF0GBwgmvOUDllpSQO4t.jpg'),
(125915, 9031, 'Super Choque S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/inx6VM87aSmb70hRYLe2Pa2D89A.jpg'),
(125916, 9031, 'Super Choque S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4eM8ZB8507N456ZCYNx52pLRsVB.jpg'),
(125917, 9031, 'Super Choque S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8n30aJWvHGWDoaX2O1RAxs7H9ME.jpg'),
(125918, 9031, 'Super Choque S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ruBwOCQpLowdtmm8nAwnrTX4uVc.jpg'),
(125919, 9031, 'Super Choque S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/spquZvfryMO4huwlJhTr3rYzE1A.jpg'),
(125920, 9031, 'Super Choque S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vPe1pNA0QYp403i0GPFmk8cnffW.jpg'),
(125921, 9031, 'Super Choque S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2uqAyhRpSHAYbeGxG9TyCpANkYq.jpg'),
(125922, 9031, 'Super Choque S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6cKHZCcrFl3iRj3JGVMXVG7WsJ7.jpg'),
(125923, 9031, 'Super Choque S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3UI54EKC2ImxeWcrr3GXutKvdrr.jpg'),
(125924, 9031, 'Super Choque S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iTyXIfJjiA0mWUdRskELCFil7CM.jpg'),
(125925, 9031, 'Super Choque S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9q6eTxu9PA0DpUeix5FrJlbtY3j.jpg'),
(125926, 9031, 'Super Choque S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8LOcvzwQ4P2yKX5d6QbrXl9klNI.jpg'),
(125927, 9032, 'Super Choque S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTYT6ZzWJxIGGQpKyh6dj4ZAiVO.jpg'),
(125928, 9032, 'Super Choque S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5sVZotac4Wco7G8Cd6jbu8tKpCD.jpg'),
(125929, 9032, 'Super Choque S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kukMCtqZb4o40vz8R1x5SgsYZN8.jpg'),
(125930, 9032, 'Super Choque S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v0LUoZVjiiFUKwg5jnZLFMlFmSF.jpg'),
(125931, 9032, 'Super Choque S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4bNJBUYPYRU9gZnp6Eb0qlDLhDy.jpg'),
(125932, 9032, 'Super Choque S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tbXHVz8ZJe6Ij4age9lK5ncrPwd.jpg'),
(125933, 9032, 'Super Choque S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a2TwtbRTskytIZ8mFnctWLSyWpO.jpg'),
(125934, 9032, 'Super Choque S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3CbQckrZciUaDOVxmrO8TYwxD8N.jpg'),
(125935, 9032, 'Super Choque S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n8cDFtjHcEGARMQWEtn2WxeKmDx.jpg'),
(125936, 9032, 'Super Choque S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/YEERQMG4UrP0rCFDAUnQPdxEDQ.jpg'),
(125937, 9032, 'Super Choque S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zz6uns9G1xeYiqavAXyXVPxFKmu.jpg'),
(125938, 9032, 'Super Choque S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/CAzxjYTUQoq2jeUnn0z6BugdIP.jpg'),
(125939, 9032, 'Super Choque S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/CAzxjYTUQoq2jeUnn0z6BugdIP.jpg'),
(125940, 9033, 'Super Choque S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c6HrYrLLI0Hy6hiRux2nnGKQ9SW.jpg'),
(125941, 9033, 'Super Choque S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5hxjbW7RSdnajv9A1gQKbpyuoRW.jpg'),
(125942, 9033, 'Super Choque S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A0ZfIc34vZfUBCgv824PnYLPlNN.jpg'),
(125943, 9033, 'Super Choque S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9X3fiFoYhYmrXiXjz0AIVOIp09M.jpg'),
(125944, 9033, 'Super Choque S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qocPHdCy8k3HwoAmGqrsPsLpGXa.jpg'),
(125945, 9033, 'Super Choque S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1wLiQxi8yGejTcfgmizFpHRR9ve.jpg'),
(125946, 9033, 'Super Choque S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eaSV5IUxBqyHFR7CTJcNmeBI9G3.jpg'),
(125947, 9033, 'Super Choque S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o6ML65r4ITN3LIYWoXyqPFBuSCc.jpg'),
(125948, 9033, 'Super Choque S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vHuBFMtsWbxflHA72M1gHSZ4M1j.jpg'),
(125949, 9033, 'Super Choque S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gL8L1xNs2YAUsT9pHo4hDrrgoHQ.jpg'),
(125950, 9033, 'Super Choque S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/laSdAK7YjBkNQ7IoC5rCEpPCnTV.jpg'),
(125951, 9033, 'Super Choque S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/JxhtoSXHwJY6UnEX5KLJVhtbJq.jpg'),
(125952, 9033, 'Super Choque S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cw9Xh8ZWOuU4aYAzij0r6gh8GGm.jpg'),
(125953, 9034, 'Super Choque S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qB2XU0qkq1m9QYZnyxvz9Bf3sPx.jpg'),
(125954, 9034, 'Super Choque S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fh1Qonx2yAS5JOVNjB7cvGtiynY.jpg'),
(125955, 9034, 'Super Choque S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ApHb2GZYPJnhBHZqXPfVyE0okHb.jpg'),
(125956, 9034, 'Super Choque S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oVqbc1XRwjJ8vbUnr2C7yVlK3yN.jpg'),
(125957, 9034, 'Super Choque S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ad9avUQg6FrWEggojHCs73USbAu.jpg'),
(125958, 9034, 'Super Choque S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cJONnxLtL4B52R0y6ZcqFbVEO8E.jpg'),
(125959, 9034, 'Super Choque S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/21H3Z1cXsdUar103rHCYPF4LT8L.jpg'),
(125960, 9034, 'Super Choque S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vitKFVLWq3NsR0NwDLClHxja1SG.jpg'),
(125961, 9034, 'Super Choque S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eG87Vz0qgNISPRfd0m8WSuh1ZO7.jpg'),
(125962, 9034, 'Super Choque S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qaUMAi08vC85fKc87BB6zQpV7dD.jpg'),
(125963, 9034, 'Super Choque S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1J1RD4AjqZFQLfy9ELiCR8f4ISF.jpg'),
(125964, 9034, 'Super Choque S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWZ8YuM5TEgJQuIOoYMFnmO307i.jpg'),
(125965, 9034, 'Super Choque S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6q05fsYy75K9ftB1mUh2EM9zH0U.jpg'),
(125966, 9035, 'Abraham Lincoln [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tOpof4g0dAHe60bm7cKncIbAOdh.jpg'),
(125967, 9035, 'Abraham Lincoln [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tM23iqEPAJUAIAryD294BZo93UY.jpg'),
(125968, 9035, 'Abraham Lincoln [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iQq1nPQsmFJXNQbZ4xLwlPSrWbD.jpg'),
(125969, 9036, 'Busca Implacável S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3vdqUm1egVyE81yXtYidqVhR9GF.jpg'),
(125970, 9036, 'Busca Implacável S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k4c2LOuvWprSqdshwqwzTbosF7j.jpg'),
(125971, 9036, 'Busca Implacável S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rmGm02UkZqfQ0CiLAzoGk29NAJz.jpg'),
(125972, 9036, 'Busca Implacável S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k7l1Mqws9xooabC3DAfrWSf7nwl.jpg'),
(125973, 9036, 'Busca Implacável S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ofB8pelR958mUoUlykPo5kziIPF.jpg'),
(125974, 9036, 'Busca Implacável S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1pOrw5P2M00AkXkfnaqzl0vxWB.jpg'),
(125975, 9036, 'Busca Implacável S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aNCcpLsLY6mRvjaY3ZkZUXuckwv.jpg'),
(125976, 9036, 'Busca Implacável S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1oZZiJdFCFZKV6umuS8QJH0OXhX.jpg'),
(125977, 9036, 'Busca Implacável S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oycPHTO0Op9hJQrMLjJOWAOxrDU.jpg'),
(125978, 9036, 'Busca Implacável S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fXilBNKytziKS7UBGAkTJOJathw.jpg'),
(125979, 9037, 'Busca Implacável S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5TgdridU2w1pVsbQB2pt1xvazBX.jpg'),
(125980, 9037, 'Busca Implacável S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5TgdridU2w1pVsbQB2pt1xvazBX.jpg'),
(125981, 9037, 'Busca Implacável S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5TgdridU2w1pVsbQB2pt1xvazBX.jpg'),
(125982, 9037, 'Busca Implacável S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5TgdridU2w1pVsbQB2pt1xvazBX.jpg'),
(125983, 9037, 'Busca Implacável S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5TgdridU2w1pVsbQB2pt1xvazBX.jpg'),
(125984, 9037, 'Busca Implacável S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5TgdridU2w1pVsbQB2pt1xvazBX.jpg'),
(125985, 9037, 'Busca Implacável S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5TgdridU2w1pVsbQB2pt1xvazBX.jpg'),
(125986, 9037, 'Busca Implacável S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5TgdridU2w1pVsbQB2pt1xvazBX.jpg'),
(125987, 9037, 'Busca Implacável S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5TgdridU2w1pVsbQB2pt1xvazBX.jpg'),
(125988, 9037, 'Busca Implacável S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5TgdridU2w1pVsbQB2pt1xvazBX.jpg'),
(125989, 9037, 'Busca Implacável S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5TgdridU2w1pVsbQB2pt1xvazBX.jpg'),
(125990, 9037, 'Busca Implacável S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5TgdridU2w1pVsbQB2pt1xvazBX.jpg'),
(125991, 9037, 'Busca Implacável S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/244104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5TgdridU2w1pVsbQB2pt1xvazBX.jpg'),
(125992, 9037, 'Busca Implacável S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/244105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5TgdridU2w1pVsbQB2pt1xvazBX.jpg'),
(125993, 9037, 'Busca Implacável S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/244106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5TgdridU2w1pVsbQB2pt1xvazBX.jpg'),
(125994, 9037, 'Busca Implacável S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/244107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5TgdridU2w1pVsbQB2pt1xvazBX.jpg'),
(125995, 9038, 'O Assassino do Rio Green Caca Ao Monstro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fJ7r8NHXqmEXMN9fZaQnFZQl6gz.jpg'),
(125996, 9038, 'O Assassino do Rio Green Caca Ao Monstro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fJ7r8NHXqmEXMN9fZaQnFZQl6gz.jpg'),
(125997, 9038, 'O Assassino do Rio Green Caca Ao Monstro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fJ7r8NHXqmEXMN9fZaQnFZQl6gz.jpg'),
(125998, 9038, 'O Assassino do Rio Green Caca Ao Monstro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fJ7r8NHXqmEXMN9fZaQnFZQl6gz.jpg'),
(125999, 9039, 'Ololade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nITszxZ1CDwu2Ml1xFvnDF81sbV.jpg'),
(126000, 9039, 'Ololade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nITszxZ1CDwu2Ml1xFvnDF81sbV.jpg'),
(126001, 9039, 'Ololade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nITszxZ1CDwu2Ml1xFvnDF81sbV.jpg'),
(126002, 9039, 'Ololade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nITszxZ1CDwu2Ml1xFvnDF81sbV.jpg'),
(126003, 9039, 'Ololade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nITszxZ1CDwu2Ml1xFvnDF81sbV.jpg'),
(126004, 9039, 'Ololade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nITszxZ1CDwu2Ml1xFvnDF81sbV.jpg'),
(126005, 9040, 'Sozinhos Habilidades de Sobrevivencia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHAXtRirVpP5mG675xHsUXkWleK.jpg'),
(126006, 9040, 'Sozinhos Habilidades de Sobrevivencia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/msKlZFYN0HZ2uHqp8uFf6675H4u.jpg'),
(126007, 9040, 'Sozinhos Habilidades de Sobrevivencia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4xRQ0UV7V6W9FtmcV1J81ejzgkM.jpg'),
(126008, 9040, 'Sozinhos Habilidades de Sobrevivencia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/CFUo1XQMleSCiM1mRcCaQA4JUr.jpg'),
(126009, 9040, 'Sozinhos Habilidades de Sobrevivencia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o5oUwlQha0cFGOyxOV4PpvcuNPe.jpg'),
(126010, 9040, 'Sozinhos Habilidades de Sobrevivencia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oFj9zmypxhfzwh1R6jKYAaka1IM.jpg'),
(126011, 9040, 'Sozinhos Habilidades de Sobrevivencia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/244066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9uqjLcRR2ZqBucm1pqFYTI5QYx6.jpg'),
(126012, 9040, 'Sozinhos Habilidades de Sobrevivencia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/244067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgkmv6VQ4dRIfoCth1vOvXfNXPf.jpg'),
(126013, 9040, 'Sozinhos Habilidades de Sobrevivencia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/244068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6J09FaaOzFTpPNp1NNHP7TbCajG.jpg'),
(126014, 9040, 'Sozinhos Habilidades de Sobrevivencia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/244069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLZfgpQVnBncTvWDw9f21cPjAPs.jpg'),
(126015, 9040, 'Sozinhos Habilidades de Sobrevivencia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/244070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Dd3UPaiuq7W0KkNrjU1l1GHMvQ.jpg'),
(126016, 9040, 'Sozinhos Habilidades de Sobrevivencia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/244071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iI0XU6AuilAq7l5m2NKg7ZWmzD2.jpg'),
(126017, 9041, 'Uma Familia Quase Perfeita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/244054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5xmbBXhPXTSdBG6JXSlKawYVKS2.jpg'),
(126018, 9041, 'Uma Familia Quase Perfeita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/244055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5xmbBXhPXTSdBG6JXSlKawYVKS2.jpg'),
(126019, 9041, 'Uma Familia Quase Perfeita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/244056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5xmbBXhPXTSdBG6JXSlKawYVKS2.jpg'),
(126020, 9041, 'Uma Familia Quase Perfeita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/244057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5xmbBXhPXTSdBG6JXSlKawYVKS2.jpg'),
(126021, 9041, 'Uma Familia Quase Perfeita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/244058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5xmbBXhPXTSdBG6JXSlKawYVKS2.jpg'),
(126022, 9041, 'Uma Familia Quase Perfeita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/244059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5xmbBXhPXTSdBG6JXSlKawYVKS2.jpg'),
(126023, 9042, 'Vilarejo Macabro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mDX8YPhfrf2COoLzzuNyxn37Jav.jpg'),
(126024, 9042, 'Vilarejo Macabro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oxNugFKu3HsIUbNtZ0zQr6YdxBn.jpg'),
(126025, 9042, 'Vilarejo Macabro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xjKAntJjwdHiMsif6dwpjcvt3Do.jpg'),
(126026, 9042, 'Vilarejo Macabro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ngCZrk6tnjB0Ze2l8AEBVgcmdNJ.jpg'),
(126027, 9042, 'Vilarejo Macabro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rn3FZkRnRVxfMIFnYLOLxt4YkSy.jpg'),
(126028, 9042, 'Vilarejo Macabro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oTaCl1Sh5xk57ATnU4RkOQ1VxPa.jpg'),
(126029, 9043, 'Sansão e Dalila S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3bdxncan9iyCtQkgy1NwILR6h9A.jpg'),
(126030, 9043, 'Sansão e Dalila S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3bdxncan9iyCtQkgy1NwILR6h9A.jpg'),
(126031, 9043, 'Sansão e Dalila S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3bdxncan9iyCtQkgy1NwILR6h9A.jpg'),
(126032, 9043, 'Sansão e Dalila S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3bdxncan9iyCtQkgy1NwILR6h9A.jpg'),
(126033, 9043, 'Sansão e Dalila S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3bdxncan9iyCtQkgy1NwILR6h9A.jpg'),
(126034, 9043, 'Sansão e Dalila S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3bdxncan9iyCtQkgy1NwILR6h9A.jpg'),
(126035, 9043, 'Sansão e Dalila S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3bdxncan9iyCtQkgy1NwILR6h9A.jpg'),
(126036, 9043, 'Sansão e Dalila S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3bdxncan9iyCtQkgy1NwILR6h9A.jpg'),
(126037, 9043, 'Sansão e Dalila S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3bdxncan9iyCtQkgy1NwILR6h9A.jpg'),
(126038, 9043, 'Sansão e Dalila S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3bdxncan9iyCtQkgy1NwILR6h9A.jpg'),
(126039, 9043, 'Sansão e Dalila S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3bdxncan9iyCtQkgy1NwILR6h9A.jpg'),
(126040, 9043, 'Sansão e Dalila S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3bdxncan9iyCtQkgy1NwILR6h9A.jpg'),
(126041, 9043, 'Sansão e Dalila S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3bdxncan9iyCtQkgy1NwILR6h9A.jpg'),
(126042, 9043, 'Sansão e Dalila S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3bdxncan9iyCtQkgy1NwILR6h9A.jpg'),
(126043, 9043, 'Sansão e Dalila S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3bdxncan9iyCtQkgy1NwILR6h9A.jpg'),
(126044, 9043, 'Sansão e Dalila S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3bdxncan9iyCtQkgy1NwILR6h9A.jpg'),
(126045, 9043, 'Sansão e Dalila S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/250993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3bdxncan9iyCtQkgy1NwILR6h9A.jpg'),
(126046, 9043, 'Sansão e Dalila S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/250994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3bdxncan9iyCtQkgy1NwILR6h9A.jpg'),
(126047, 6209, 'A Trama S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27ZvQGDi9cgPdRgRULtWZkVLqc6.jpg'),
(126048, 6209, 'A Trama S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27ZvQGDi9cgPdRgRULtWZkVLqc6.jpg'),
(126049, 6209, 'A Trama S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27ZvQGDi9cgPdRgRULtWZkVLqc6.jpg'),
(126050, 6209, 'A Trama S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27ZvQGDi9cgPdRgRULtWZkVLqc6.jpg'),
(126051, 6209, 'A Trama S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27ZvQGDi9cgPdRgRULtWZkVLqc6.jpg'),
(126052, 6209, 'A Trama S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27ZvQGDi9cgPdRgRULtWZkVLqc6.jpg'),
(126053, 9044, 'Academia de Vampiros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9H0iOu9BXeHw5543UYXDaAaqhBU.jpg'),
(126054, 9044, 'Academia de Vampiros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ClL35rs4ZokI87mWYPcHMhT6tw.jpg'),
(126055, 9044, 'Academia de Vampiros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bXia1U7o1QF9vIEZl8WZdtEZrql.jpg'),
(126056, 9044, 'Academia de Vampiros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7GRYyV6bR9YVWDUvXSfArs8Kc0x.jpg'),
(126057, 9044, 'Academia de Vampiros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A4busx2mfSVu7JQZP3NOfhM3AdT.jpg'),
(126058, 9044, 'Academia de Vampiros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/amF4LiAyxh6SP1Ehe1XRKdbbmKw.jpg'),
(126059, 9044, 'Academia de Vampiros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wQ87k13XSuziOrBeExlclC0avBp.jpg'),
(126060, 9044, 'Academia de Vampiros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yKyMs1Ih5TDDziLDRXSy7yksgCL.jpg'),
(126061, 9044, 'Academia de Vampiros S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/349UoRb1oASPfssxxGqJYNSfpEA.jpg'),
(126062, 9044, 'Academia de Vampiros S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k2qCRhV0qDOh259fTxMmHWcIVMM.jpg'),
(126063, 9045, 'Rio Connection S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/syTwKTIlhZ1GBWjrNEzdpCowbkE.jpg'),
(126064, 9045, 'Rio Connection S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/syTwKTIlhZ1GBWjrNEzdpCowbkE.jpg'),
(126065, 9045, 'Rio Connection S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/syTwKTIlhZ1GBWjrNEzdpCowbkE.jpg'),
(126066, 9045, 'Rio Connection S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/syTwKTIlhZ1GBWjrNEzdpCowbkE.jpg'),
(126067, 9045, 'Rio Connection S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/syTwKTIlhZ1GBWjrNEzdpCowbkE.jpg'),
(126068, 9045, 'Rio Connection S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/syTwKTIlhZ1GBWjrNEzdpCowbkE.jpg'),
(126069, 9045, 'Rio Connection S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/syTwKTIlhZ1GBWjrNEzdpCowbkE.jpg'),
(126070, 9045, 'Rio Connection S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/syTwKTIlhZ1GBWjrNEzdpCowbkE.jpg'),
(126071, 9046, 'Alice e Lewis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126072, 9046, 'Alice e Lewis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126073, 9046, 'Alice e Lewis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126074, 9046, 'Alice e Lewis S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126075, 9046, 'Alice e Lewis S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126076, 9046, 'Alice e Lewis S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126077, 9046, 'Alice e Lewis S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126078, 9046, 'Alice e Lewis S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126079, 9046, 'Alice e Lewis S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126080, 9046, 'Alice e Lewis S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126081, 9046, 'Alice e Lewis S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126082, 9046, 'Alice e Lewis S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126083, 9046, 'Alice e Lewis S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126084, 9046, 'Alice e Lewis S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126085, 9046, 'Alice e Lewis S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126086, 9046, 'Alice e Lewis S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126087, 9046, 'Alice e Lewis S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/250434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126088, 9046, 'Alice e Lewis S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/250435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126089, 9046, 'Alice e Lewis S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/250436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126090, 9046, 'Alice e Lewis S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/250437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nNvlWW77kIcPnjWFeW39KNVd7Aa.jpg'),
(126091, 9046, 'Alice e Lewis S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/250438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126092, 9046, 'Alice e Lewis S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/250439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6HDbq7UVK88Etzz6RVh5Of7cE6.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(126093, 9046, 'Alice e Lewis S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/250440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126094, 9046, 'Alice e Lewis S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/250441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svOmhSO7dnUlWrVwSgN372YVfK8.jpg'),
(126095, 9046, 'Alice e Lewis S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/250442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lmJRtD71hj2SL25jvZrKmnSQSxR.jpg'),
(126096, 9046, 'Alice e Lewis S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/250443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126097, 9046, 'Alice e Lewis S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/250444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126098, 9046, 'Alice e Lewis S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/250445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126099, 9046, 'Alice e Lewis S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/250446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126100, 9046, 'Alice e Lewis S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/250447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126101, 9046, 'Alice e Lewis S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/250448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126102, 9046, 'Alice e Lewis S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/250449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126103, 9046, 'Alice e Lewis S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/250450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126104, 9046, 'Alice e Lewis S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/250451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126105, 9046, 'Alice e Lewis S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/250452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126106, 9046, 'Alice e Lewis S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/250453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126107, 9046, 'Alice e Lewis S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/250454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126108, 9046, 'Alice e Lewis S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/250455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126109, 9046, 'Alice e Lewis S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/250456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126110, 9046, 'Alice e Lewis S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/250457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126111, 9046, 'Alice e Lewis S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/250458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126112, 9046, 'Alice e Lewis S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/250459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126113, 9046, 'Alice e Lewis S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/250460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126114, 9046, 'Alice e Lewis S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/250461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126115, 9046, 'Alice e Lewis S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/250462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126116, 9046, 'Alice e Lewis S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/250463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126117, 9046, 'Alice e Lewis S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/250464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126118, 9046, 'Alice e Lewis S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/250465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126119, 9046, 'Alice e Lewis S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/250466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126120, 9046, 'Alice e Lewis S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/250467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126121, 9046, 'Alice e Lewis S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/250468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126122, 9046, 'Alice e Lewis S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/250469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126123, 9047, 'Alice e Lewis S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126124, 9047, 'Alice e Lewis S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126125, 9047, 'Alice e Lewis S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126126, 9047, 'Alice e Lewis S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126127, 9047, 'Alice e Lewis S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126128, 9047, 'Alice e Lewis S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126129, 9047, 'Alice e Lewis S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126130, 9047, 'Alice e Lewis S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126131, 9047, 'Alice e Lewis S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126132, 9047, 'Alice e Lewis S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126133, 9047, 'Alice e Lewis S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126134, 9047, 'Alice e Lewis S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126135, 9047, 'Alice e Lewis S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126136, 9047, 'Alice e Lewis S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126137, 9047, 'Alice e Lewis S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126138, 9047, 'Alice e Lewis S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126139, 9047, 'Alice e Lewis S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/250486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126140, 9047, 'Alice e Lewis S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/250487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126141, 9047, 'Alice e Lewis S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/250488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126142, 9047, 'Alice e Lewis S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/250489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126143, 9047, 'Alice e Lewis S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/250490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126144, 9047, 'Alice e Lewis S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/250491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126145, 9047, 'Alice e Lewis S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/250492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126146, 9047, 'Alice e Lewis S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/250493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vki6GgB73u4rnPZBLccQ0T3SCXk.jpg'),
(126147, 9048, 'Alice na Doceria das Maravilhas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126148, 9048, 'Alice na Doceria das Maravilhas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126149, 9048, 'Alice na Doceria das Maravilhas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126150, 9048, 'Alice na Doceria das Maravilhas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126151, 9048, 'Alice na Doceria das Maravilhas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126152, 9048, 'Alice na Doceria das Maravilhas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126153, 9048, 'Alice na Doceria das Maravilhas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126154, 9048, 'Alice na Doceria das Maravilhas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126155, 9048, 'Alice na Doceria das Maravilhas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126156, 9048, 'Alice na Doceria das Maravilhas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126157, 9048, 'Alice na Doceria das Maravilhas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126158, 9048, 'Alice na Doceria das Maravilhas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126159, 9048, 'Alice na Doceria das Maravilhas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126160, 9048, 'Alice na Doceria das Maravilhas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126161, 9048, 'Alice na Doceria das Maravilhas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126162, 9048, 'Alice na Doceria das Maravilhas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126163, 9048, 'Alice na Doceria das Maravilhas S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/250409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126164, 9048, 'Alice na Doceria das Maravilhas S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/250410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126165, 9048, 'Alice na Doceria das Maravilhas S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/250411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126166, 9048, 'Alice na Doceria das Maravilhas S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/250412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126167, 9048, 'Alice na Doceria das Maravilhas S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/250413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126168, 9048, 'Alice na Doceria das Maravilhas S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/250414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126169, 9048, 'Alice na Doceria das Maravilhas S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/250415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126170, 9048, 'Alice na Doceria das Maravilhas S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/250416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126171, 9048, 'Alice na Doceria das Maravilhas S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/250417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yGrFwcZgPmzCSN4GfXDS6YSVbYV.jpg'),
(126172, 9049, 'Angelica 50 e Tanto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3I5lgfBjlDDhrQq6GTT1qfKW0l2.jpg'),
(126173, 9049, 'Angelica 50 e Tanto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3I5lgfBjlDDhrQq6GTT1qfKW0l2.jpg'),
(126174, 9049, 'Angelica 50 e Tanto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3I5lgfBjlDDhrQq6GTT1qfKW0l2.jpg'),
(126175, 9049, 'Angelica 50 e Tanto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3I5lgfBjlDDhrQq6GTT1qfKW0l2.jpg'),
(126176, 9049, 'Angelica 50 e Tanto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3I5lgfBjlDDhrQq6GTT1qfKW0l2.jpg'),
(126177, 9050, 'Bem Vindos a Australia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3a0bC5Uf660obGBzxXL1Qb5ihkl.jpg'),
(126178, 9050, 'Bem Vindos a Australia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8FzoAhmVN1WboDX1hgaJgVbAR7J.jpg'),
(126179, 9050, 'Bem Vindos a Australia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pBAfrdkEXpUiPZH8oFRICFgOars.jpg'),
(126180, 9050, 'Bem Vindos a Australia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7dSy2RQTTDGmcZ8Jc6poEBH3002.jpg'),
(126181, 9050, 'Bem Vindos a Australia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fbdaumaRmdTy6HAGjBXLK6Z6IMU.jpg'),
(126182, 9050, 'Bem Vindos a Australia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cJV7agaoE3G4ahI6BDBqelQVN0Y.jpg'),
(126183, 9051, 'Cirurgioes No Limite da Vida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i73vwHcDvEXIcASzSnxChnrm6iE.jpg'),
(126184, 9051, 'Cirurgioes No Limite da Vida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mzuNF0bxfP4caVNO0H6CfD8pVpF.jpg'),
(126185, 9051, 'Cirurgioes No Limite da Vida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3vC81emjcXm4bxrTKLpKoukD3Yl.jpg'),
(126186, 9051, 'Cirurgioes No Limite da Vida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126187, 9051, 'Cirurgioes No Limite da Vida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126188, 9051, 'Cirurgioes No Limite da Vida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126189, 9051, 'Cirurgioes No Limite da Vida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126190, 9051, 'Cirurgioes No Limite da Vida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126191, 9051, 'Cirurgioes No Limite da Vida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126192, 9051, 'Cirurgioes No Limite da Vida S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126193, 9051, 'Cirurgioes No Limite da Vida S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126194, 9051, 'Cirurgioes No Limite da Vida S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126195, 9051, 'Cirurgioes No Limite da Vida S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126196, 9051, 'Cirurgioes No Limite da Vida S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/276728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126197, 9051, 'Cirurgioes No Limite da Vida S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/276729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126198, 9051, 'Cirurgioes No Limite da Vida S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/276730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126199, 9051, 'Cirurgioes No Limite da Vida S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/276731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126200, 9051, 'Cirurgioes No Limite da Vida S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/276732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126201, 9051, 'Cirurgioes No Limite da Vida S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/276733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126202, 9051, 'Cirurgioes No Limite da Vida S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/281454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126203, 9051, 'Cirurgioes No Limite da Vida S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/287759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126204, 9051, 'Cirurgioes No Limite da Vida S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/295798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126205, 9051, 'Cirurgioes No Limite da Vida S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/302932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126206, 9051, 'Cirurgioes No Limite da Vida S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/309113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126207, 9051, 'Cirurgioes No Limite da Vida S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/312543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j47d3VTdhc1d8Q5CyjSxHItO1p4.jpg'),
(126208, 9052, 'Clubinho Pikwik S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126209, 9052, 'Clubinho Pikwik S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126210, 9052, 'Clubinho Pikwik S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126211, 9052, 'Clubinho Pikwik S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126212, 9052, 'Clubinho Pikwik S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126213, 9052, 'Clubinho Pikwik S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126214, 9052, 'Clubinho Pikwik S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126215, 9052, 'Clubinho Pikwik S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126216, 9052, 'Clubinho Pikwik S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126217, 9052, 'Clubinho Pikwik S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126218, 9052, 'Clubinho Pikwik S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126219, 9052, 'Clubinho Pikwik S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126220, 9052, 'Clubinho Pikwik S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126221, 9052, 'Clubinho Pikwik S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126222, 9052, 'Clubinho Pikwik S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126223, 9052, 'Clubinho Pikwik S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126224, 9052, 'Clubinho Pikwik S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/250346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126225, 9052, 'Clubinho Pikwik S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/250347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126226, 9052, 'Clubinho Pikwik S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/250348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126227, 9052, 'Clubinho Pikwik S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/250349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126228, 9052, 'Clubinho Pikwik S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/250350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126229, 9052, 'Clubinho Pikwik S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/250351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126230, 9052, 'Clubinho Pikwik S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/250352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126231, 9052, 'Clubinho Pikwik S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/250353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126232, 9052, 'Clubinho Pikwik S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/250354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126233, 9052, 'Clubinho Pikwik S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/250355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126234, 9052, 'Clubinho Pikwik S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/250356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126235, 9052, 'Clubinho Pikwik S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/250357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126236, 9052, 'Clubinho Pikwik S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/250358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126237, 9052, 'Clubinho Pikwik S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/250359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126238, 9052, 'Clubinho Pikwik S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/250360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126239, 9052, 'Clubinho Pikwik S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/250361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126240, 9052, 'Clubinho Pikwik S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/250362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126241, 9052, 'Clubinho Pikwik S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/250363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126242, 9052, 'Clubinho Pikwik S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/250364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126243, 9052, 'Clubinho Pikwik S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/250365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126244, 9052, 'Clubinho Pikwik S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/250366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126245, 9052, 'Clubinho Pikwik S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/250367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126246, 9052, 'Clubinho Pikwik S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/250368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126247, 9052, 'Clubinho Pikwik S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/250369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126248, 9052, 'Clubinho Pikwik S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/250370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126249, 9052, 'Clubinho Pikwik S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/250371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126250, 9052, 'Clubinho Pikwik S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/250372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126251, 9052, 'Clubinho Pikwik S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/250373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126252, 9052, 'Clubinho Pikwik S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/250374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126253, 9052, 'Clubinho Pikwik S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/250375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126254, 9052, 'Clubinho Pikwik S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/250376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126255, 9052, 'Clubinho Pikwik S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/250377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126256, 9052, 'Clubinho Pikwik S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/250378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126257, 9052, 'Clubinho Pikwik S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/250379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126258, 9052, 'Clubinho Pikwik S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/250380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126259, 9052, 'Clubinho Pikwik S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/250381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2Cy2ibLU0sTggfhrkIA5AXHBYW.jpg'),
(126260, 9053, 'Deer Squad S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126261, 9053, 'Deer Squad S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126262, 9053, 'Deer Squad S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126263, 9053, 'Deer Squad S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126264, 9053, 'Deer Squad S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126265, 9053, 'Deer Squad S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126266, 9053, 'Deer Squad S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126267, 9053, 'Deer Squad S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126268, 9053, 'Deer Squad S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126269, 9053, 'Deer Squad S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126270, 9053, 'Deer Squad S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126271, 9053, 'Deer Squad S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126272, 9053, 'Deer Squad S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126273, 9053, 'Deer Squad S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126274, 9053, 'Deer Squad S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126275, 9053, 'Deer Squad S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126276, 9053, 'Deer Squad S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/250307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126277, 9053, 'Deer Squad S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/250308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126278, 9053, 'Deer Squad S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/250309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126279, 9054, 'Deer Squad S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126280, 9054, 'Deer Squad S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126281, 9054, 'Deer Squad S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126282, 9054, 'Deer Squad S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126283, 9054, 'Deer Squad S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126284, 9054, 'Deer Squad S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126285, 9054, 'Deer Squad S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126286, 9054, 'Deer Squad S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126287, 9054, 'Deer Squad S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126288, 9054, 'Deer Squad S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126289, 9054, 'Deer Squad S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126290, 9054, 'Deer Squad S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126291, 9054, 'Deer Squad S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126292, 9054, 'Deer Squad S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126293, 9054, 'Deer Squad S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126294, 9054, 'Deer Squad S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126295, 9054, 'Deer Squad S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/250326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126296, 9054, 'Deer Squad S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/250327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126297, 9054, 'Deer Squad S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/250328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126298, 9054, 'Deer Squad S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/250329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mX2ufYlYGEIyieypljCfYgAYcd0.jpg'),
(126299, 9055, 'Inspiracao e Design com Jean Stoffer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/41bYd0izZxgHJ8iMnyXkcx3Fqme.jpg'),
(126300, 9055, 'Inspiracao e Design com Jean Stoffer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oitLOTccs477oCpTYJLZxkHBemq.jpg'),
(126301, 9055, 'Inspiracao e Design com Jean Stoffer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oitLOTccs477oCpTYJLZxkHBemq.jpg'),
(126302, 9055, 'Inspiracao e Design com Jean Stoffer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oitLOTccs477oCpTYJLZxkHBemq.jpg'),
(126303, 9055, 'Inspiracao e Design com Jean Stoffer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oitLOTccs477oCpTYJLZxkHBemq.jpg'),
(126304, 9055, 'Inspiracao e Design com Jean Stoffer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oitLOTccs477oCpTYJLZxkHBemq.jpg'),
(126305, 9056, 'Inspiracao e Design com Jean Stoffer S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dtzPGB6e1IlK2FCLvujQSWAXM1M.jpg'),
(126306, 9056, 'Inspiracao e Design com Jean Stoffer S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bTvjUvVcTamK3UclylXFlFjhOiP.jpg'),
(126307, 9056, 'Inspiracao e Design com Jean Stoffer S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7IEahvRStYFOedjuSH8EDMwG7eN.jpg'),
(126308, 9056, 'Inspiracao e Design com Jean Stoffer S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dFUU114zGX1fWr4QkIKsO2YXz9k.jpg'),
(126309, 9056, 'Inspiracao e Design com Jean Stoffer S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZ4RjNgw7Dj7gTl1pO4qrKFdCSR.jpg'),
(126310, 9056, 'Inspiracao e Design com Jean Stoffer S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yyWg3uXTZJvJUBPy8ocpGRvPtXD.jpg'),
(126311, 9056, 'Inspiracao e Design com Jean Stoffer S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oitLOTccs477oCpTYJLZxkHBemq.jpg'),
(126312, 9056, 'Inspiracao e Design com Jean Stoffer S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oitLOTccs477oCpTYJLZxkHBemq.jpg'),
(126313, 9057, 'Linguas da Nossa Lingua S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mQEFHSoz5oWfuCwsXTyFwKR1aYA.jpg'),
(126314, 9057, 'Linguas da Nossa Lingua S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mQEFHSoz5oWfuCwsXTyFwKR1aYA.jpg'),
(126315, 9057, 'Linguas da Nossa Lingua S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mQEFHSoz5oWfuCwsXTyFwKR1aYA.jpg'),
(126316, 9057, 'Linguas da Nossa Lingua S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mQEFHSoz5oWfuCwsXTyFwKR1aYA.jpg'),
(126317, 9058, 'Money e Violence S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126318, 9058, 'Money e Violence S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126319, 9058, 'Money e Violence S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126320, 9058, 'Money e Violence S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126321, 9058, 'Money e Violence S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126322, 9058, 'Money e Violence S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126323, 9058, 'Money e Violence S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126324, 9058, 'Money e Violence S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126325, 9058, 'Money e Violence S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126326, 9058, 'Money e Violence S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126327, 9058, 'Money e Violence S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126328, 9058, 'Money e Violence S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126329, 9058, 'Money e Violence S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126330, 9058, 'Money e Violence S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126331, 9058, 'Money e Violence S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126332, 9058, 'Money e Violence S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126333, 9058, 'Money e Violence S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/250270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126334, 9058, 'Money e Violence S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/250271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126335, 9058, 'Money e Violence S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/250272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126336, 9058, 'Money e Violence S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/250273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126337, 9058, 'Money e Violence S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/250274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126338, 9058, 'Money e Violence S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/250275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126339, 9058, 'Money e Violence S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/250276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126340, 9058, 'Money e Violence S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/250277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126341, 9058, 'Money e Violence S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/250278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126342, 9059, 'Money e Violence S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126343, 9059, 'Money e Violence S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126344, 9059, 'Money e Violence S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126345, 9059, 'Money e Violence S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126346, 9059, 'Money e Violence S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126347, 9059, 'Money e Violence S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126348, 9059, 'Money e Violence S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126349, 9059, 'Money e Violence S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126350, 9059, 'Money e Violence S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(126351, 9059, 'Money e Violence S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126352, 9059, 'Money e Violence S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126353, 9059, 'Money e Violence S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPW1ppqZKCLd35E9kQJU19J48kD.jpg'),
(126354, 9060, 'O Bombeiro Sam S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7v3gzy1uXqDypJj5FCWmFIFBRWu.jpg'),
(126355, 9060, 'O Bombeiro Sam S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkRoPrXwNbCcu1JEZLQqgbQsTom.jpg'),
(126356, 9060, 'O Bombeiro Sam S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lOcRDyECC43utTMwz7XEpNDkdUv.jpg'),
(126357, 9060, 'O Bombeiro Sam S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gbqIs33sqcTH6yJZ5JqeUudhSsQ.jpg'),
(126358, 9060, 'O Bombeiro Sam S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8bJbV6ClZOL084fbU2wFsVdVVXp.jpg'),
(126359, 9060, 'O Bombeiro Sam S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx2OU067ZVfnp0BKZhHUlNIqIg0.jpg'),
(126360, 9060, 'O Bombeiro Sam S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s9jcH56dJDSjvBMI5drVs0Gw35i.jpg'),
(126361, 9060, 'O Bombeiro Sam S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8P6VkA0e5H3BFGEzfzFxNExqeiq.jpg'),
(126362, 9060, 'O Bombeiro Sam S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1PpyKeWHPwWpIXjIE0kdJ058CQK.jpg'),
(126363, 9060, 'O Bombeiro Sam S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ef8yxbjrdm4g1pMc3Y5ESvucDYw.jpg'),
(126364, 9060, 'O Bombeiro Sam S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iqXpJEoleuB5LUbb1HDaSBDWxYU.jpg'),
(126365, 9060, 'O Bombeiro Sam S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx2OU067ZVfnp0BKZhHUlNIqIg0.jpg'),
(126366, 9060, 'O Bombeiro Sam S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mAHg8LVPiMIl4T4tVOZAfY8KmzP.jpg'),
(126367, 9060, 'O Bombeiro Sam S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s0V0wR50wdSJIlJ6A6aRR82otCP.jpg'),
(126368, 9060, 'O Bombeiro Sam S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kkd7RlSWPVoqJwqo62kOEbfdUR2.jpg'),
(126369, 9060, 'O Bombeiro Sam S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xnEgwLCQ6yw124cdSKasiHxRLme.jpg'),
(126370, 9060, 'O Bombeiro Sam S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/250244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/clrnc9vCwOXbo1XkPDXilPBzed0.jpg'),
(126371, 9060, 'O Bombeiro Sam S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/250245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5AaLSf8UitbJ8bTAj7y6t7Fa8z0.jpg'),
(126372, 9060, 'O Bombeiro Sam S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/250246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zXnc2CRNX1bK8NOonuGDIpyKnov.jpg'),
(126373, 9060, 'O Bombeiro Sam S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/250247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qJC6hXnCAudUmMCUVvbYB71c5gh.jpg'),
(126374, 9060, 'O Bombeiro Sam S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/250248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eI41qZy72xXaNNNGV5T197XzEes.jpg'),
(126375, 9060, 'O Bombeiro Sam S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/250249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx2OU067ZVfnp0BKZhHUlNIqIg0.jpg'),
(126376, 9060, 'O Bombeiro Sam S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/250250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx2OU067ZVfnp0BKZhHUlNIqIg0.jpg'),
(126377, 9060, 'O Bombeiro Sam S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/250251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zGWfY6DuvJWitR3zZP78va6gejP.jpg'),
(126378, 9060, 'O Bombeiro Sam S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/250252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xt9jMFkwrVEThxKD9q7vlX6gXGn.jpg'),
(126379, 9060, 'O Bombeiro Sam S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/250253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cx2OU067ZVfnp0BKZhHUlNIqIg0.jpg'),
(126380, 9061, 'Onmyoji S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5x1KrMgEpm8qHsuSmmKIDgBLJf6.jpg'),
(126381, 9061, 'Onmyoji S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lznRdepkUxnl6NS5uADOG3gUpUo.jpg'),
(126382, 9061, 'Onmyoji S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gdwhP5Jwh4LCvdUR3SjaryHygEJ.jpg'),
(126383, 9061, 'Onmyoji S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4cQbWAeF40sFskOvGfsl6LgR5N3.jpg'),
(126384, 9061, 'Onmyoji S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6yBay7sPYyX40WQ4QJf2daESdxp.jpg'),
(126385, 9061, 'Onmyoji S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qeFktzZZ3NXRZUi7VmBStmKu6u9.jpg'),
(126386, 9061, 'Onmyoji S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/so0Ztv4Ne7sgsC5ZytXgrbaWHxX.jpg'),
(126387, 9061, 'Onmyoji S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYpP9DYy3NflE5tte6HMNRkg2t2.jpg'),
(126388, 9061, 'Onmyoji S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6fSPFi77MPsukl4v1IJkaQBkMs.jpg'),
(126389, 9061, 'Onmyoji S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nk7bbUSze5MwhLdocQUz6PEWbIP.jpg'),
(126390, 9061, 'Onmyoji S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5KoaGN2FlCip5uhWZXDGBVs0KH5.jpg'),
(126391, 9061, 'Onmyoji S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2fFmUW2cKxXpJpDLdNH9OGAYMD.jpg'),
(126392, 9061, 'Onmyoji S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o7ZtJQNLkzTIrwSYo9GKlmAZJUh.jpg'),
(126393, 9062, 'Orgulho e Familia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1t82iHiI1M1itN1JPyUa00TZMjo.jpg'),
(126394, 9062, 'Orgulho e Familia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1t82iHiI1M1itN1JPyUa00TZMjo.jpg'),
(126395, 9062, 'Orgulho e Familia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1t82iHiI1M1itN1JPyUa00TZMjo.jpg'),
(126396, 9062, 'Orgulho e Familia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1t82iHiI1M1itN1JPyUa00TZMjo.jpg'),
(126397, 9063, 'Petit S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126398, 9063, 'Petit S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126399, 9063, 'Petit S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126400, 9063, 'Petit S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126401, 9063, 'Petit S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126402, 9063, 'Petit S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126403, 9063, 'Petit S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126404, 9063, 'Petit S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126405, 9063, 'Petit S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126406, 9063, 'Petit S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126407, 9063, 'Petit S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126408, 9063, 'Petit S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126409, 9063, 'Petit S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126410, 9063, 'Petit S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126411, 9063, 'Petit S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126412, 9063, 'Petit S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126413, 9063, 'Petit S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/250188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126414, 9063, 'Petit S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/250189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126415, 9063, 'Petit S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/250190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126416, 9063, 'Petit S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/250191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126417, 9063, 'Petit S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/250192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126418, 9063, 'Petit S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/250193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126419, 9063, 'Petit S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/250194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126420, 9063, 'Petit S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/250195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126421, 9063, 'Petit S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/250196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126422, 9063, 'Petit S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/250197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126423, 9064, 'Petit S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126424, 9064, 'Petit S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126425, 9064, 'Petit S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126426, 9064, 'Petit S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126427, 9064, 'Petit S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126428, 9064, 'Petit S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126429, 9064, 'Petit S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126430, 9064, 'Petit S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126431, 9064, 'Petit S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126432, 9064, 'Petit S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126433, 9064, 'Petit S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126434, 9064, 'Petit S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126435, 9064, 'Petit S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oL8PtlvKMAr1RYvVKC7Q3s85yyL.jpg'),
(126436, 9065, 'Team Umizoomi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rbC6E58kv8Aw8j66H2B0AsgVnua.jpg'),
(126437, 9065, 'Team Umizoomi S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2rfm9xW9FKfC656WaqHMULdiEbS.jpg'),
(126438, 9065, 'Team Umizoomi S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LFHFCnVf8AUudsWs5Nk9Ayonrg.jpg'),
(126439, 9065, 'Team Umizoomi S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTG9ZYStBYJrgTlI0ecCTywf0Xj.jpg'),
(126440, 9065, 'Team Umizoomi S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qpUrskRso2t1JFJyu1LzLuHYg5o.jpg'),
(126441, 9065, 'Team Umizoomi S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hOWG5HeJgsTO30RGkOa4rDas418.jpg'),
(126442, 9065, 'Team Umizoomi S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sTRCZJg7wDOwFlLWRH7vv2JGqyg.jpg'),
(126443, 9065, 'Team Umizoomi S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pWMbm7Am8sPZurLmfQmr1bjIvoW.jpg'),
(126444, 9065, 'Team Umizoomi S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x8dD9G4y9C96kFyVRyQr1ZJKD4B.jpg'),
(126445, 9065, 'Team Umizoomi S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s03hyZUb2L3sKDiuU9tOnseBSw3.jpg'),
(126446, 9065, 'Team Umizoomi S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oByrfGbcLobe9nde9edFA5570zj.jpg'),
(126447, 9065, 'Team Umizoomi S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nBMUglLecgjVGWJVpJdVsm0pyGW.jpg'),
(126448, 9065, 'Team Umizoomi S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dIqlj4crBBvvm7WO7uRUNBNLH3K.jpg'),
(126449, 9065, 'Team Umizoomi S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q1xVBAjNhHyDZHwNGrvgf7in6aX.jpg'),
(126450, 9065, 'Team Umizoomi S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4G9rZwNsrcGib1wonPE9RcRl4eY.jpg'),
(126451, 9065, 'Team Umizoomi S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dLlLc0aoKHFp5r0jpl22m0ZJjk9.jpg'),
(126452, 9065, 'Team Umizoomi S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/250108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aRC1IqvdESDftOspLuHIwTNi4Ui.jpg'),
(126453, 9065, 'Team Umizoomi S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/250109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ceafkNZKoLfduxmhhKM2BI06a70.jpg'),
(126454, 9065, 'Team Umizoomi S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/250110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y6r9ITJ7Y2RGEyrJNz9ItMZsNnW.jpg'),
(126455, 9065, 'Team Umizoomi S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/250111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g47dEdm38NQk0wJJbJtMYzG1YlU.jpg'),
(126456, 9066, 'Team Umizoomi S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cw2Wy5Rr5Ac5M4PMZUtfEUcSmuP.jpg'),
(126457, 9066, 'Team Umizoomi S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1K99r1aawqRfi2Ds4o3Th0VxwzA.jpg'),
(126458, 9066, 'Team Umizoomi S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLtZO27N1utKVmtbXQ1SRMi9D6d.jpg'),
(126459, 9066, 'Team Umizoomi S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vwAALmLmOz7UkdDOtTElvlDNhfM.jpg'),
(126460, 9066, 'Team Umizoomi S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c1RuMEDFaxaLHCmtRxhYUZT2I3l.jpg'),
(126461, 9066, 'Team Umizoomi S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xrZ8a8CRKcU1JsOHVgMwfEJM4Dw.jpg'),
(126462, 9066, 'Team Umizoomi S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4I1w3tOmwd6QnyzzxFE5ntZXcY9.jpg'),
(126463, 9066, 'Team Umizoomi S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wXX272prqCxYQ7PjAWZJWMap5Tp.jpg'),
(126464, 9066, 'Team Umizoomi S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTndByiZUYGhKF2ZM8vRe0T1xDz.jpg'),
(126465, 9066, 'Team Umizoomi S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3TAcSCNX7ysmMYhTtRTwiermzVM.jpg'),
(126466, 9066, 'Team Umizoomi S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rLIQvRSvVGrEd8jexK6zsr9mIqM.jpg'),
(126467, 9066, 'Team Umizoomi S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oXl9ItLcCyA8uJkABivAHQsbT1v.jpg'),
(126468, 9066, 'Team Umizoomi S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nHISh8w1yGFORCBb5ayFCgSXplV.jpg'),
(126469, 9066, 'Team Umizoomi S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQlROLWiKSL7m7utbDIQxQQrRg2.jpg'),
(126470, 9066, 'Team Umizoomi S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/etdfWcFzais4cut6AQ8wydXPiM6.jpg'),
(126471, 9066, 'Team Umizoomi S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u8nPwhiC8aiLn7f8a9OHDzL0cGe.jpg'),
(126472, 9066, 'Team Umizoomi S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/250128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jknyLEb3QlX3I2adiuwb2ekTTH0.jpg'),
(126473, 9066, 'Team Umizoomi S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/250129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kWSe1kTpGNxMr6KlcDrZUKpJTVd.jpg'),
(126474, 9066, 'Team Umizoomi S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/250130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Ps4vAlMhXST3CmhyBfQWZmAJUF.jpg'),
(126475, 9066, 'Team Umizoomi S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/250131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rkazNA0SjDKz4psw9VKnA0QNd7M.jpg'),
(126476, 9067, 'Team Umizoomi S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9OjDMgsEG1KMSrJULL0eV79z3dw.jpg'),
(126477, 9067, 'Team Umizoomi S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126478, 9067, 'Team Umizoomi S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dTwQu5RQ0B8JQS8wA121nqaMzlF.jpg'),
(126479, 9067, 'Team Umizoomi S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4kum2xH7nAZq21ReMb6BrGTaxKl.jpg'),
(126480, 9067, 'Team Umizoomi S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dcnwFMGuMpIa9HbHuYEcEOVlIYM.jpg'),
(126481, 9067, 'Team Umizoomi S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126482, 9067, 'Team Umizoomi S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hTwTfdIraC8Nd3hdH2gK0ggFJaI.jpg'),
(126483, 9067, 'Team Umizoomi S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/emJmMYSgeCQTGxWKAk6xJtc8Gme.jpg'),
(126484, 9067, 'Team Umizoomi S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/428swR58DhJpAQoIyDtmZVU5HZz.jpg'),
(126485, 9067, 'Team Umizoomi S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126486, 9067, 'Team Umizoomi S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2mTeqpHoxCr0r8povY36drX6ARg.jpg'),
(126487, 9067, 'Team Umizoomi S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126488, 9067, 'Team Umizoomi S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bfyRv2iJdKHlLXJq7R9C7fnXIqN.jpg'),
(126489, 9067, 'Team Umizoomi S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126490, 9067, 'Team Umizoomi S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126491, 9067, 'Team Umizoomi S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126492, 9067, 'Team Umizoomi S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/250148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126493, 9067, 'Team Umizoomi S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/250149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126494, 9067, 'Team Umizoomi S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/250150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3eoav33VUHxjAtkpqygoBsmofo.jpg'),
(126495, 9067, 'Team Umizoomi S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/250151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126496, 9068, 'Team Umizoomi S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pmz8A4PehNmt5R0GwxErzrbrLC.jpg'),
(126497, 9068, 'Team Umizoomi S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vOq8ym0hsrl1SePj7cI9t43G2BR.jpg'),
(126498, 9068, 'Team Umizoomi S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aJXqSMLHvuOZzCn0oIL9GWIKi87.jpg'),
(126499, 9068, 'Team Umizoomi S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yOJzpc5owrjAWnmss6qvlNZmBOG.jpg'),
(126500, 9068, 'Team Umizoomi S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vAX3SdNKZyTAIs2ae2zYRjydoJ0.jpg'),
(126501, 9068, 'Team Umizoomi S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hbjgkepUnjmJ6fGEJs6NOf7lGf0.jpg'),
(126502, 9068, 'Team Umizoomi S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126503, 9068, 'Team Umizoomi S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126504, 9068, 'Team Umizoomi S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126505, 9068, 'Team Umizoomi S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126506, 9068, 'Team Umizoomi S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126507, 9068, 'Team Umizoomi S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126508, 9068, 'Team Umizoomi S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126509, 9068, 'Team Umizoomi S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126510, 9068, 'Team Umizoomi S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126511, 9068, 'Team Umizoomi S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126512, 9068, 'Team Umizoomi S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/250168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126513, 9068, 'Team Umizoomi S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/250169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126514, 9068, 'Team Umizoomi S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/250170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126515, 9068, 'Team Umizoomi S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/250171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y090DrGOIK5LyrCq3GeA8TZZ4lY.jpg'),
(126516, 9069, 'Traidores da Patria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r6hUnwstfy802BJVrSsU0DrBLeB.jpg'),
(126517, 9069, 'Traidores da Patria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r6hUnwstfy802BJVrSsU0DrBLeB.jpg'),
(126518, 9069, 'Traidores da Patria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r6hUnwstfy802BJVrSsU0DrBLeB.jpg'),
(126519, 9069, 'Traidores da Patria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r6hUnwstfy802BJVrSsU0DrBLeB.jpg'),
(126520, 9069, 'Traidores da Patria S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r6hUnwstfy802BJVrSsU0DrBLeB.jpg'),
(126521, 9070, 'A Magia de Aruna S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m5U1sO0cqdP75wDoNTqtgHNXXh4.jpg'),
(126522, 9070, 'A Magia de Aruna S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xR1DWiuK1Uecouo3uPWJoWDzXoL.jpg'),
(126523, 9070, 'A Magia de Aruna S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Lg9ByCKCwMwcjoJdtuAphuogSj.jpg'),
(126524, 9070, 'A Magia de Aruna S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cwjo5ZIOvDlH7Qo13K05j4qZuXM.jpg'),
(126525, 9070, 'A Magia de Aruna S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8C1MYrESBnRLu3L7R4jpDnooQXE.jpg'),
(126526, 9070, 'A Magia de Aruna S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uoxJwj0PEfFZQxKb8O9SPzFagEg.jpg'),
(126527, 9071, 'Beyblade Burst Turbo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bTgxQMmfKl1Vvk0MJKGfhSQIIZP.jpg'),
(126528, 9071, 'Beyblade Burst Turbo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126529, 9071, 'Beyblade Burst Turbo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126530, 9071, 'Beyblade Burst Turbo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126531, 9071, 'Beyblade Burst Turbo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126532, 9071, 'Beyblade Burst Turbo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126533, 9071, 'Beyblade Burst Turbo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126534, 9071, 'Beyblade Burst Turbo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126535, 9071, 'Beyblade Burst Turbo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/250038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126536, 9071, 'Beyblade Burst Turbo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/250039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126537, 9071, 'Beyblade Burst Turbo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/250040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126538, 9071, 'Beyblade Burst Turbo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/250041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126539, 9071, 'Beyblade Burst Turbo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/250042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126540, 9071, 'Beyblade Burst Turbo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126541, 9071, 'Beyblade Burst Turbo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126542, 9071, 'Beyblade Burst Turbo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126543, 9071, 'Beyblade Burst Turbo S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/250046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126544, 9071, 'Beyblade Burst Turbo S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/250047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126545, 9071, 'Beyblade Burst Turbo S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/250048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126546, 9071, 'Beyblade Burst Turbo S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/250049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126547, 9071, 'Beyblade Burst Turbo S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/250050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126548, 9071, 'Beyblade Burst Turbo S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/250051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126549, 9071, 'Beyblade Burst Turbo S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/250052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126550, 9071, 'Beyblade Burst Turbo S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/250053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126551, 9071, 'Beyblade Burst Turbo S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/250054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126552, 9071, 'Beyblade Burst Turbo S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/250055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126553, 9071, 'Beyblade Burst Turbo S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/250056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126554, 9071, 'Beyblade Burst Turbo S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/250057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126555, 9071, 'Beyblade Burst Turbo S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/250058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126556, 9071, 'Beyblade Burst Turbo S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/250059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126557, 9071, 'Beyblade Burst Turbo S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/250060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126558, 9071, 'Beyblade Burst Turbo S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/250061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126559, 9071, 'Beyblade Burst Turbo S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/250062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126560, 9071, 'Beyblade Burst Turbo S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/250063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126561, 9071, 'Beyblade Burst Turbo S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/250064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126562, 9071, 'Beyblade Burst Turbo S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/250065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126563, 9071, 'Beyblade Burst Turbo S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/250066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126564, 9071, 'Beyblade Burst Turbo S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/250067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126565, 9071, 'Beyblade Burst Turbo S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/250068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126566, 9071, 'Beyblade Burst Turbo S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/250069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126567, 9071, 'Beyblade Burst Turbo S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/250070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126568, 9071, 'Beyblade Burst Turbo S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/250071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126569, 9071, 'Beyblade Burst Turbo S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/250072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126570, 9071, 'Beyblade Burst Turbo S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/250073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126571, 9071, 'Beyblade Burst Turbo S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/250074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126572, 9071, 'Beyblade Burst Turbo S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/250075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126573, 9071, 'Beyblade Burst Turbo S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/250076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126574, 9071, 'Beyblade Burst Turbo S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/250077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126575, 9071, 'Beyblade Burst Turbo S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/250078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126576, 9071, 'Beyblade Burst Turbo S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/250079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126577, 9071, 'Beyblade Burst Turbo S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/250080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7gNPKHaW3VB2UlDVxpfcTQBPk9N.jpg'),
(126578, 9072, 'Bookie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pxENGRP3itRH1SdAzj2TjiQvXKo.jpg'),
(126579, 9072, 'Bookie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dD5jxtH4S859QEPNRMspWZD2QBN.jpg'),
(126580, 9072, 'Bookie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIefkOAbeoDPLsmiMpACrg5N6Ov.jpg'),
(126581, 9072, 'Bookie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIefkOAbeoDPLsmiMpACrg5N6Ov.jpg'),
(126582, 9072, 'Bookie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIefkOAbeoDPLsmiMpACrg5N6Ov.jpg'),
(126583, 9072, 'Bookie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIefkOAbeoDPLsmiMpACrg5N6Ov.jpg'),
(126584, 9072, 'Bookie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIefkOAbeoDPLsmiMpACrg5N6Ov.jpg'),
(126585, 9072, 'Bookie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIefkOAbeoDPLsmiMpACrg5N6Ov.jpg'),
(126586, 9073, 'Bookie S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/523584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIefkOAbeoDPLsmiMpACrg5N6Ov.jpg'),
(126587, 9073, 'Bookie S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/639318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIefkOAbeoDPLsmiMpACrg5N6Ov.jpg'),
(126588, 9073, 'Bookie S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/644178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIefkOAbeoDPLsmiMpACrg5N6Ov.jpg'),
(126589, 9073, 'Bookie S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/659680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIefkOAbeoDPLsmiMpACrg5N6Ov.jpg'),
(126590, 9073, 'Bookie S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/663101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIefkOAbeoDPLsmiMpACrg5N6Ov.jpg'),
(126591, 9073, 'Bookie S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/665421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIefkOAbeoDPLsmiMpACrg5N6Ov.jpg'),
(126592, 9073, 'Bookie S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/677747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIefkOAbeoDPLsmiMpACrg5N6Ov.jpg'),
(126593, 9073, 'Bookie S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/680578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIefkOAbeoDPLsmiMpACrg5N6Ov.jpg'),
(126594, 9074, 'Cirurgiao do Mal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/BYQ7NI6kvhgXNAwIigTBKEfnym.jpg'),
(126595, 9074, 'Cirurgiao do Mal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oG55eAClPLRBSfGksZV8iLdUEoL.jpg'),
(126596, 9074, 'Cirurgiao do Mal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hM5YjtrprWaNrDtLEaZJmRukFHD.jpg'),
(126597, 9075, 'Explosivos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cSyj501K4OnxeMKlc2K0MHkE08e.jpg'),
(126598, 9075, 'Explosivos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w4S3PIuyTDS9YuDLODWs9AMnGWF.jpg'),
(126599, 9075, 'Explosivos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bk1N5YmaFirNGlXXcviSZlTYdnl.jpg'),
(126600, 9075, 'Explosivos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/le0fI0oBGimDWJf1hMNmwFfpmXE.jpg'),
(126601, 9075, 'Explosivos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1GVZYTEhIA3pcggThdZA0zjPzcf.jpg'),
(126602, 9075, 'Explosivos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A58cXPasnSDBdmd6zEewjcP0Qra.jpg'),
(126603, 9075, 'Explosivos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/250025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q3zjopLVSZv6geTG5VTei7b6AWO.jpg'),
(126604, 9075, 'Explosivos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/250026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yEfJ7G37EYMYSQT0JIoohcQ4t9x.jpg'),
(126605, 9076, 'Misterios da Antiguidade com Albert Lin S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/250013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n9je6kPhE38fZa5RALLev5slobJ.jpg'),
(126606, 9076, 'Misterios da Antiguidade com Albert Lin S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/250014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6G3THy4RaiTrV0LVAoUwLYZwXlK.jpg'),
(126607, 9076, 'Misterios da Antiguidade com Albert Lin S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/250015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nby88Gf2QzX9ddMApL1qHQqAIRg.jpg'),
(126608, 9076, 'Misterios da Antiguidade com Albert Lin S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/250016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6gg5IvM8tJzurqY5AGgvs8kzOnz.jpg'),
(126609, 9076, 'Misterios da Antiguidade com Albert Lin S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/250017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eyf8Mmq4Yb84KLpu23ZIfw5cSFz.jpg'),
(126610, 9076, 'Misterios da Antiguidade com Albert Lin S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/250018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gTP6V6a0C7ibuBTN53smQOz67c4.jpg'),
(126611, 9077, 'Rusty Rivets S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9A4FQOcplvTLMjdWu6IH3ALRaI1.jpg'),
(126612, 9077, 'Rusty Rivets S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZCr2ICDfA2BlflEYEDmQGvTpnn.jpg'),
(126613, 9077, 'Rusty Rivets S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mDHjwFOYRDDxfukJyIgV7maHm3g.jpg'),
(126614, 9077, 'Rusty Rivets S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126615, 9077, 'Rusty Rivets S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nTAMRUdYgPKrNYbAo0lEHjN5VKN.jpg'),
(126616, 9077, 'Rusty Rivets S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(126617, 9077, 'Rusty Rivets S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sHrnpNZkHHGuFeeX5fu5dJuPqnM.jpg'),
(126618, 9077, 'Rusty Rivets S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126619, 9077, 'Rusty Rivets S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBfGdd4Svb9WPqrD6lrJN8YGOS.jpg'),
(126620, 9077, 'Rusty Rivets S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126621, 9077, 'Rusty Rivets S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zfbkTdOFaxqJnaZtrduswmglZXZ.jpg'),
(126622, 9077, 'Rusty Rivets S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126623, 9077, 'Rusty Rivets S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/saxYaJhJDlQ5ymdVZ5Y0G3V76z4.jpg'),
(126624, 9077, 'Rusty Rivets S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126625, 9077, 'Rusty Rivets S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wQF1JWkOdAaCuz8aibDxDf5C5R2.jpg'),
(126626, 9077, 'Rusty Rivets S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qOGCYmiUTIaGKUUZ2SKAPMUk9LI.jpg'),
(126627, 9077, 'Rusty Rivets S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/249977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lhEEIe8TKg2omesSdA2EFIc0yeh.jpg'),
(126628, 9077, 'Rusty Rivets S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/249978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126629, 9077, 'Rusty Rivets S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/249979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hl3USgPcyCSUvKbEYPbTmvc0880.jpg'),
(126630, 9077, 'Rusty Rivets S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/249980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126631, 9077, 'Rusty Rivets S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/249981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8QzJi9ANvW5ieCOkLn5QbV5Jx6j.jpg'),
(126632, 9077, 'Rusty Rivets S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/249982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126633, 9077, 'Rusty Rivets S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/249983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9RbQL8tSKeoCh8TbBLQhihaZOaU.jpg'),
(126634, 9077, 'Rusty Rivets S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/249984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126635, 9077, 'Rusty Rivets S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/249985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mL6MeYNFlTZA4gvZusXlEtORSU3.jpg'),
(126636, 9077, 'Rusty Rivets S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/249986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126637, 9078, 'Rusty Rivets S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qaRT1ZWolFGQRqujGaUzyUeeCxT.jpg'),
(126638, 9078, 'Rusty Rivets S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126639, 9078, 'Rusty Rivets S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aEEu28KicOvTJE0DxR9F5V9M3Od.jpg'),
(126640, 9078, 'Rusty Rivets S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sM6KIpqIZReCRzRKNFYJK2EvBQp.jpg'),
(126641, 9078, 'Rusty Rivets S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126642, 9078, 'Rusty Rivets S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l0TLrYR7QJd0naC6Avi53xCeBjG.jpg'),
(126643, 9078, 'Rusty Rivets S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126644, 9078, 'Rusty Rivets S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9iOEwa5rr1pkHDln3sOXotFlgZF.jpg'),
(126645, 9078, 'Rusty Rivets S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126646, 9078, 'Rusty Rivets S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKa8RJvyw8ybtppiSrZPDDFbGi3.jpg'),
(126647, 9078, 'Rusty Rivets S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126648, 9078, 'Rusty Rivets S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5kQMrArUACsEVnHmMc47r9aTOLR.jpg'),
(126649, 9078, 'Rusty Rivets S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126650, 9078, 'Rusty Rivets S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/250000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tj645loogHTmj9fP3BkgCuGp6cx.jpg'),
(126651, 9078, 'Rusty Rivets S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/250001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126652, 9078, 'Rusty Rivets S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/250002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126653, 9078, 'Rusty Rivets S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/250003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126654, 9078, 'Rusty Rivets S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/250004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126655, 9078, 'Rusty Rivets S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/250005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126656, 9078, 'Rusty Rivets S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/250006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126657, 9078, 'Rusty Rivets S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/250007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126658, 9078, 'Rusty Rivets S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/250008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126659, 9078, 'Rusty Rivets S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/250009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126660, 9078, 'Rusty Rivets S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/250010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126661, 9078, 'Rusty Rivets S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/250011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2yzJGmOMN0eIsowImAb7LuAOQ7.jpg'),
(126662, 9078, 'Rusty Rivets S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/250012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jf3d0j1EzzE0rgYnF9iBELh4dpP.jpg'),
(126663, 9079, 'Zig e Sharko S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AXQU96sP473X5YcYL6Mwf3cCwq.jpg'),
(126664, 9079, 'Zig e Sharko S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i9KEDxzomgyxFk28GplxhbwNZdv.jpg'),
(126665, 9079, 'Zig e Sharko S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oeM9nZfJrxv9ExezZmd7auYWEZW.jpg'),
(126666, 9079, 'Zig e Sharko S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hbg6D15KWqbQFQSSL2yKYtKShxQ.jpg'),
(126667, 9079, 'Zig e Sharko S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCchEgU40KBJTlR0zjO4iTej507.jpg'),
(126668, 9079, 'Zig e Sharko S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/86RHP1zwUophxHjwTID7IZJ33Ej.jpg'),
(126669, 9079, 'Zig e Sharko S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gzEpPCR5TKYxdfikkMgyyegmg69.jpg'),
(126670, 9079, 'Zig e Sharko S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOP3JJkWjnM9ega1AOolqbDdBVI.jpg'),
(126671, 9079, 'Zig e Sharko S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1kIs6bNopEoLmPVzpnCxNrudhRD.jpg'),
(126672, 9079, 'Zig e Sharko S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aTaFXZMMHbC6xgrHOfYKiBHZewv.jpg'),
(126673, 9079, 'Zig e Sharko S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j6EFmJTbul4phWGAh5qIOyiJ400.jpg'),
(126674, 9079, 'Zig e Sharko S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8A2tk5goxMdplVYweFVOohb8jce.jpg'),
(126675, 9079, 'Zig e Sharko S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6tAsy4MZiTU0AeFBvzrIzcfpXJ1.jpg'),
(126676, 9079, 'Zig e Sharko S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ug6vuBitBgV0mO06yo8TAnOocY.jpg'),
(126677, 9079, 'Zig e Sharko S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ufQQjLFzeuBJMuULv9SOX7uxSFH.jpg'),
(126678, 9079, 'Zig e Sharko S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJMSD8om0S8PCptGBOI5NJwgpcM.jpg'),
(126679, 9079, 'Zig e Sharko S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/249899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yZC0deq4t8IFv1Xh4rEl47W40d1.jpg'),
(126680, 9079, 'Zig e Sharko S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/249900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9cdAzgjXLJtZVB5lKd8cCRcITj6.jpg'),
(126681, 9079, 'Zig e Sharko S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/249901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oYvIfnPLekdOK9nzljpUpEgrS97.jpg'),
(126682, 9079, 'Zig e Sharko S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/249902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zngKHmf2wN5Y9hveh3LccG7nM3C.jpg'),
(126683, 9079, 'Zig e Sharko S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/249903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDfKRg3xu19apReOjBIwjyNqISt.jpg'),
(126684, 9079, 'Zig e Sharko S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/249904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4HibXipHjQ1unKW0IqE7mkgaTci.jpg'),
(126685, 9079, 'Zig e Sharko S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/249905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fS7JxHhfh8Gp3oG8Zu7lB96PFjm.jpg'),
(126686, 9079, 'Zig e Sharko S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/249906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dtXOMC0uwZh1QrBziODI84l64Cx.jpg'),
(126687, 9079, 'Zig e Sharko S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/249907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yksa8LyLj9YLkhRozuRGIgQib9.jpg'),
(126688, 9079, 'Zig e Sharko S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/249908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7oeQf8sELLpQZb9mRtLpu0A40ga.jpg'),
(126689, 9080, 'Zig e Sharko S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7fPoPNwtGP0poJ9aXcIvJU6kmZU.jpg'),
(126690, 9080, 'Zig e Sharko S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/amcSYeZdtWWIOXCsnYvKrOGQcAO.jpg'),
(126691, 9080, 'Zig e Sharko S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z6OWttbX2jivN1jmi9RuuXEtf22.jpg'),
(126692, 9080, 'Zig e Sharko S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bGPxiT2WESwCZ1pLoOccxoJzKPm.jpg'),
(126693, 9080, 'Zig e Sharko S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/78nzxrgdeg7Zu94avsi8D4OQFkC.jpg'),
(126694, 9080, 'Zig e Sharko S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wppDslsTVlQWLhJ7vLr3fcRK6wt.jpg'),
(126695, 9080, 'Zig e Sharko S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uIqQgukF2YeKtKGotoXseFdeme2.jpg'),
(126696, 9080, 'Zig e Sharko S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dtyOUHX1uzVHp44ePbXhUrO88c2.jpg'),
(126697, 9080, 'Zig e Sharko S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1e4B5jW4kRjR52kkXDF0N3P1FzK.jpg'),
(126698, 9080, 'Zig e Sharko S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fg1CLQY3rzlXckcRn1V5gkvpJJp.jpg'),
(126699, 9080, 'Zig e Sharko S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7m9ucVmUDVgIl73nqENuE32PPSO.jpg'),
(126700, 9080, 'Zig e Sharko S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bkat39eFYDKlqjNyhArAwEsa6Xq.jpg'),
(126701, 9080, 'Zig e Sharko S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pOZk9dZ8AvGxtznsz2MHk3gREeb.jpg'),
(126702, 9080, 'Zig e Sharko S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rVqPg0JnMp4gSViHg1SibMmNFsZ.jpg'),
(126703, 9080, 'Zig e Sharko S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i8LbGxFgyTnsT1PugQyPDgkY3Id.jpg'),
(126704, 9080, 'Zig e Sharko S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pmXAU7R9pfxmjyNbF1ZBM3lVGo0.jpg'),
(126705, 9080, 'Zig e Sharko S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/249925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/46mMO25r80yDFUoD97RJeu0sea4.jpg'),
(126706, 9080, 'Zig e Sharko S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/249926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xBP6LWXn4eOZ6uWycjTJ20RUB1y.jpg'),
(126707, 9080, 'Zig e Sharko S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/249927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dio60P7b3PtSWqDacvP4x5ZWai.jpg'),
(126708, 9080, 'Zig e Sharko S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/249928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVSrvbhg6JaHMFnqls80GthdIBx.jpg'),
(126709, 9080, 'Zig e Sharko S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/249929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xnaCb5AYWIVsvT2HRmWTbvrCBA3.jpg'),
(126710, 9080, 'Zig e Sharko S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/249930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zaTgsGOPIwCqyhCSr3IrGDByOAO.jpg'),
(126711, 9080, 'Zig e Sharko S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/249931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xY4RhFmxwMlKtNa3GD6IY8Pq3cG.jpg'),
(126712, 9080, 'Zig e Sharko S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/249932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yJubzwCC1ZV8qXAWI7FbFWpXZWt.jpg'),
(126713, 9080, 'Zig e Sharko S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/249933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ceLMz3fgvxr6B9TjG4gfVKpHi7c.jpg'),
(126714, 9080, 'Zig e Sharko S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/249934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4CCdmWOZZNFNNICpdd4EX3fzAY3.jpg'),
(126715, 9081, 'Zig e Sharko S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5AQ1dfk3MWbfwZuwG7eYpKEk4uy.jpg'),
(126716, 9081, 'Zig e Sharko S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wqeW9Mup1iuBWYR1Qmfsu1Nnq5J.jpg'),
(126717, 9081, 'Zig e Sharko S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3JNNeyCf8R8DkXPpwpGHtLxLinH.jpg'),
(126718, 9081, 'Zig e Sharko S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4hxqsHng81JAMuqwp8S5A14TeKv.jpg'),
(126719, 9081, 'Zig e Sharko S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hmziKIBWorKhAZS2BsMfY9QQGF7.jpg'),
(126720, 9081, 'Zig e Sharko S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d6wW73o2JKyC1FliErHZllKAeCW.jpg'),
(126721, 9081, 'Zig e Sharko S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zOCkzKT9EVCt2LRy6n4SSryXZ6f.jpg'),
(126722, 9081, 'Zig e Sharko S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/krnWc2X4Ciy7DpxYcw8e0Ks4YOO.jpg'),
(126723, 9081, 'Zig e Sharko S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yR4Zss7sfeGenNXjSelt7c47rvi.jpg'),
(126724, 9081, 'Zig e Sharko S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5c3KDSjCEZ0T0W7WmpHiwksVjkW.jpg'),
(126725, 9081, 'Zig e Sharko S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wn2s1SKWidhrItiQQHgYIsCKeMT.jpg'),
(126726, 9081, 'Zig e Sharko S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oDVcArH3hVstDi6oPA7mW0zotbr.jpg'),
(126727, 9081, 'Zig e Sharko S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/luLlBiarWnyBZsPLQThgLoBT4RA.jpg'),
(126728, 9081, 'Zig e Sharko S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/33PFs8xnoLjTw5p9mz4ciMm1vC0.jpg'),
(126729, 9081, 'Zig e Sharko S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7MXKCqgD7EQoS5eOeCzc5CjCBV8.jpg'),
(126730, 9081, 'Zig e Sharko S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/konBT3ESi2VuTG5nvBh4W9I7O7w.jpg'),
(126731, 9081, 'Zig e Sharko S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/249951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pPFGcv0NmBOUIe4V2axAApQhEjr.jpg'),
(126732, 9081, 'Zig e Sharko S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/249952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rwcpBpOkaQwDClVWVItO1pwPXev.jpg'),
(126733, 9081, 'Zig e Sharko S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/249953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQ4MAokjpgWq7BWtWh7uHsGY05Y.jpg'),
(126734, 9081, 'Zig e Sharko S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/249954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cNnuynF3gSfCNLoNOe4KLBPixTG.jpg'),
(126735, 9081, 'Zig e Sharko S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/249955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4li8G2FiAsGbWqBfA0jEe0ixOsz.jpg'),
(126736, 9081, 'Zig e Sharko S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/249956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7oYiU1qEiUJRpbtclbUqxCEb2PW.jpg'),
(126737, 9081, 'Zig e Sharko S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/249957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tCWpJ1xW18RL480fKIsx9TSXxSt.jpg'),
(126738, 9081, 'Zig e Sharko S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/249958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iC9AdfZlGPMmlHfQ3bTCl5SNxtx.jpg'),
(126739, 9081, 'Zig e Sharko S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/249959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7TUk28dsfBTwQtdVXdDSj7MssSb.jpg'),
(126740, 9081, 'Zig e Sharko S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/249960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f8F6qkqCPDhsLpOEQbbbZYYgySl.jpg'),
(126741, 9082, 'Betinho No Fio da Navalha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2KzfEZwfmWN9NzM3Jvgc94M2U5F.jpg'),
(126742, 9082, 'Betinho No Fio da Navalha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2KzfEZwfmWN9NzM3Jvgc94M2U5F.jpg'),
(126743, 9082, 'Betinho No Fio da Navalha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2KzfEZwfmWN9NzM3Jvgc94M2U5F.jpg'),
(126744, 9082, 'Betinho No Fio da Navalha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2KzfEZwfmWN9NzM3Jvgc94M2U5F.jpg'),
(126745, 9082, 'Betinho No Fio da Navalha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2KzfEZwfmWN9NzM3Jvgc94M2U5F.jpg'),
(126746, 9082, 'Betinho No Fio da Navalha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2KzfEZwfmWN9NzM3Jvgc94M2U5F.jpg'),
(126747, 9082, 'Betinho No Fio da Navalha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2KzfEZwfmWN9NzM3Jvgc94M2U5F.jpg'),
(126748, 9082, 'Betinho No Fio da Navalha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2KzfEZwfmWN9NzM3Jvgc94M2U5F.jpg'),
(126749, 9083, 'Brawn Uma Historia Incrivel da F1 [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iqgIqVahu0o23My0HqYUn7YpV9t.jpg'),
(126750, 9083, 'Brawn Uma Historia Incrivel da F1 [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8obUIpo9ejxdyQW0xeez2sKmyiI.jpg'),
(126751, 9083, 'Brawn Uma Historia Incrivel da F1 [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lfOqzqbhAJ50vNSbpUm8Kc7oimV.jpg'),
(126752, 9083, 'Brawn Uma Historia Incrivel da F1 [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pEedWLDlufyCNO0ERwC3qTQQQDB.jpg'),
(126753, 9084, 'Cirurgias e Artimanhas [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2sPRo9J4RUWnEQwBcHKYu00cjAY.jpg'),
(126754, 9084, 'Cirurgias e Artimanhas [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8NRRGKwxu0i8KEiCjpAaTEV8JA.jpg'),
(126755, 9084, 'Cirurgias e Artimanhas [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m6puJIghDCzHPNa7K2eBugwxsiL.jpg'),
(126756, 9084, 'Cirurgias e Artimanhas [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3eclgrcGQ81K8x0nz8vlFDzeTzz.jpg'),
(126757, 9084, 'Cirurgias e Artimanhas [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kR7lmvWFqpA7s4MMVtVdNMDRKNn.jpg'),
(126758, 9084, 'Cirurgias e Artimanhas [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7AvIW5GAqFlkIOwSmhynZDr6w6v.jpg'),
(126759, 9084, 'Cirurgias e Artimanhas [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wzSKUzckDbifz0CItbSTnU9yXfU.jpg'),
(126760, 9084, 'Cirurgias e Artimanhas [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6mYVRcC69ktlF2QVa2KARIWPKlC.jpg'),
(126761, 9085, 'Comedy Royale [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJtP241691qBdtVINFWfl2uELKu.jpg'),
(126762, 9085, 'Comedy Royale [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AjPmCEhbcoqZdHBlsgrm01YBA4y.jpg'),
(126763, 9085, 'Comedy Royale [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dpbflO3cVy8VCVc2P4NWU766Vlb.jpg'),
(126764, 9085, 'Comedy Royale [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fzUbKBmHKb1wQ1D852VGfRQg5W2.jpg'),
(126765, 9085, 'Comedy Royale [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHxS3GchOUKViisxHfUkD1FP73c.jpg'),
(126766, 9085, 'Comedy Royale [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDU4E5Qel9OWmp3U7bfGmz5yb83.jpg'),
(126767, 9086, 'Melancia Cintilante [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cF4DWGVOBRRE1xXcuCjkL9lF11Y.jpg'),
(126768, 9086, 'Melancia Cintilante [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mQbPrPoouvIUHrEW06sPKrcbOrM.jpg'),
(126769, 9086, 'Melancia Cintilante [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sn25iaQqoFQw4RfDuJGmHMdthUz.jpg'),
(126770, 9086, 'Melancia Cintilante [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pcdzw13xs01obX0CR8xanjXV0kK.jpg'),
(126771, 9086, 'Melancia Cintilante [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5MHp5AovdydnJfj8HywMipakbQ2.jpg'),
(126772, 9086, 'Melancia Cintilante [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJehEPeA9s15K2pLWqt37X4VlIk.jpg'),
(126773, 9086, 'Melancia Cintilante [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ceijUHfEpE3xiwTNb3YDwImV9V.jpg'),
(126774, 9086, 'Melancia Cintilante [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ab4b6jQWoRqOTFMzxtcxDse0yJj.jpg'),
(126775, 9086, 'Melancia Cintilante [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5DZwU7ZPbPYQtIFYzYkuTwLaDg.jpg'),
(126776, 9086, 'Melancia Cintilante [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3qwGcg5n6bzSdHSXXJEUWES11BF.jpg'),
(126777, 9086, 'Melancia Cintilante [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDPxV8jXuD71ZPbay5OFHQUTB3s.jpg'),
(126778, 9086, 'Melancia Cintilante [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qU2NZk798peFNAPQT4YIWKznTqk.jpg'),
(126779, 9086, 'Melancia Cintilante [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/niLXedPmYMYDnb6IrJC64YFstLL.jpg'),
(126780, 9086, 'Melancia Cintilante [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGluphQYFuNfvwxm9ecxRun3F1r.jpg'),
(126781, 9086, 'Melancia Cintilante [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zewAoWXcyrqVtP0kyfmhFScIAn7.jpg'),
(126782, 9086, 'Melancia Cintilante [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zDKcgwXCxZ3GZzQz6HOy24zrYz7.jpg'),
(126783, 9087, 'Meu Querido Zelador [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wSmN7HYZik94xMch5VeYloVBN0w.jpg'),
(126784, 9087, 'Meu Querido Zelador [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dv5uEUN8fqmdSOomtdUlvEsC4mP.jpg'),
(126785, 9087, 'Meu Querido Zelador [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m4TgfAN7nihW6qPKfTZCv8wm6qD.jpg'),
(126786, 9087, 'Meu Querido Zelador [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aYCA0jVCSKbsJBqyWztZS0W8I9d.jpg'),
(126787, 9087, 'Meu Querido Zelador [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aY5FxLbAb1D2aIcwrhBCfN2Y8vP.jpg'),
(126788, 9087, 'Meu Querido Zelador [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkTEtGTytLFViKoaaPpc5WCddc1.jpg'),
(126789, 9087, 'Meu Querido Zelador [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iYN4ZpDzZ6LNOPZqs6KpfsnglDi.jpg'),
(126790, 9087, 'Meu Querido Zelador [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lTn7r9eNPJHyvsEm3Smok6M763s.jpg'),
(126791, 9087, 'Meu Querido Zelador [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gb9zlX9tocLkyaEXVfENprIgdbH.jpg'),
(126792, 9087, 'Meu Querido Zelador [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dqfAPZdsOSwQKBl1fosJNnepYXA.jpg'),
(126793, 9087, 'Meu Querido Zelador [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jNBNWE5KRh4yWMMHwFKOc9dOXkU.jpg'),
(126794, 9088, 'Meu Querido Zelador [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/irkD4oHDdLMyB6i0b0iUUeFseOA.jpg'),
(126795, 9088, 'Meu Querido Zelador [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/irkD4oHDdLMyB6i0b0iUUeFseOA.jpg'),
(126796, 9088, 'Meu Querido Zelador [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/irkD4oHDdLMyB6i0b0iUUeFseOA.jpg'),
(126797, 9088, 'Meu Querido Zelador [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/irkD4oHDdLMyB6i0b0iUUeFseOA.jpg'),
(126798, 9088, 'Meu Querido Zelador [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/irkD4oHDdLMyB6i0b0iUUeFseOA.jpg'),
(126799, 9088, 'Meu Querido Zelador [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/irkD4oHDdLMyB6i0b0iUUeFseOA.jpg'),
(126800, 9088, 'Meu Querido Zelador [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/irkD4oHDdLMyB6i0b0iUUeFseOA.jpg'),
(126801, 9089, 'Meu Querido Zelador [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/441915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/irkD4oHDdLMyB6i0b0iUUeFseOA.jpg'),
(126802, 9089, 'Meu Querido Zelador [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/441916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/irkD4oHDdLMyB6i0b0iUUeFseOA.jpg'),
(126803, 9089, 'Meu Querido Zelador [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/441917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/irkD4oHDdLMyB6i0b0iUUeFseOA.jpg'),
(126804, 9089, 'Meu Querido Zelador [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/441918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/irkD4oHDdLMyB6i0b0iUUeFseOA.jpg'),
(126805, 9089, 'Meu Querido Zelador [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/441919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/irkD4oHDdLMyB6i0b0iUUeFseOA.jpg'),
(126806, 9089, 'Meu Querido Zelador [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/441920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/irkD4oHDdLMyB6i0b0iUUeFseOA.jpg'),
(126807, 9089, 'Meu Querido Zelador [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/441921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/irkD4oHDdLMyB6i0b0iUUeFseOA.jpg'),
(126808, 9090, 'Nos Seus Sonhos [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hgA6b0qtQihINTQKfJRvLuy6P4Z.jpg'),
(126809, 9090, 'Nos Seus Sonhos [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hIO5c5sJfyqhnHhmQa08MiFfym6.jpg'),
(126810, 9090, 'Nos Seus Sonhos [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybmoDTQPkf2t2j5jss5dYhPzBT3.jpg'),
(126811, 9090, 'Nos Seus Sonhos [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e55amVSF10xGKusPoCz4gOlxJ6b.jpg'),
(126812, 9090, 'Nos Seus Sonhos [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bOKEfZzCLPC6n7N2oAkE3ND7PFe.jpg'),
(126813, 9090, 'Nos Seus Sonhos [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/66UG2jz8LGhYTyh8HaY9rH8Ltmq.jpg'),
(126814, 9091, 'Um Bom Dia para Ser um Cachorro [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kXd0ZGNYORkncDh1ECFEc17ZICy.jpg'),
(126815, 9091, 'Um Bom Dia para Ser um Cachorro [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c4m7X8vPBMgcmDPdrSbp35rm1pI.jpg'),
(126816, 9091, 'Um Bom Dia para Ser um Cachorro [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/75WK4DDvq5IeuJ0mi5EysfOarQC.jpg'),
(126817, 9091, 'Um Bom Dia para Ser um Cachorro [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1wXMCmYrT7bLu6b5TpT5WoDfVFj.jpg'),
(126818, 9091, 'Um Bom Dia para Ser um Cachorro [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v3NqMcK3tkUXHSpWs0UYVdUruXD.jpg'),
(126819, 9091, 'Um Bom Dia para Ser um Cachorro [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ylPdby4iyeJ8uAp6JunUAz4YJAv.jpg'),
(126820, 9091, 'Um Bom Dia para Ser um Cachorro [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AumrH7FEyoKcs13QoJybSu63LFi.jpg'),
(126821, 9091, 'Um Bom Dia para Ser um Cachorro [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zMN176vUT6tnUg3BfFYCAl6c28N.jpg'),
(126822, 9091, 'Um Bom Dia para Ser um Cachorro [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v3NqMcK3tkUXHSpWs0UYVdUruXD.jpg'),
(126823, 9091, 'Um Bom Dia para Ser um Cachorro [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v3NqMcK3tkUXHSpWs0UYVdUruXD.jpg'),
(126824, 9091, 'Um Bom Dia para Ser um Cachorro [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/258952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v3NqMcK3tkUXHSpWs0UYVdUruXD.jpg'),
(126825, 9091, 'Um Bom Dia para Ser um Cachorro [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/258953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v3NqMcK3tkUXHSpWs0UYVdUruXD.jpg'),
(126826, 9091, 'Um Bom Dia para Ser um Cachorro [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/258954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v3NqMcK3tkUXHSpWs0UYVdUruXD.jpg'),
(126827, 9091, 'Um Bom Dia para Ser um Cachorro [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/258955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v3NqMcK3tkUXHSpWs0UYVdUruXD.jpg'),
(126828, 9092, 'Verified Stand Up [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lg6H327AMGdYvgbBTmt5SdIL6x3.jpg'),
(126829, 9092, 'Verified Stand Up [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q6KltSye55ZqoYup3grU2lxFqk8.jpg'),
(126830, 9093, 'Beyblade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nXOYXTQFQYF5pTtZujAwJAFjWDo.jpg'),
(126831, 9093, 'Beyblade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qAB0NSRGgfiI14zBr9hPa7H77zd.jpg'),
(126832, 9093, 'Beyblade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2DU7qk5nQx9XLXVv9r9v4yuJND6.jpg'),
(126833, 9093, 'Beyblade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ciZTYIns9WgTW5r7ufPk4I0SaZr.jpg'),
(126834, 9093, 'Beyblade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iUDm46v6EIOP3YFyuM3FeomKkGF.jpg'),
(126835, 9093, 'Beyblade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c72OaIjblBWRSIzLI3ZSNBZJXI5.jpg'),
(126836, 9093, 'Beyblade S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2eXElojI9YxrGsPY6UfWNPpIJR8.jpg'),
(126837, 9093, 'Beyblade S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iv9Sp6dNhfye2OMHfFuJ5QxvO7U.jpg'),
(126838, 9093, 'Beyblade S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zFVco2PnqGm61JPB6leY0X57KIL.jpg'),
(126839, 9093, 'Beyblade S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fpSU0ZkpmkRcDPKATHDgdiGKA92.jpg'),
(126840, 9093, 'Beyblade S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z68FtkDQKacdx8gsF6e7hllpvAN.jpg'),
(126841, 9093, 'Beyblade S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f650MbzDVqcxPtEInapGJzy3IbK.jpg'),
(126842, 9093, 'Beyblade S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2VH8O9NjU86d9MmZQuMduQvwKDT.jpg'),
(126843, 9093, 'Beyblade S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pSwcNfYjfvABEYKvJ5TtTvJApiS.jpg'),
(126844, 9093, 'Beyblade S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sqFSGCOYNaEHAAa0UdNkuL7fUko.jpg'),
(126845, 9093, 'Beyblade S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sHwDbdl9vsmhi2eq0wrh8xEOQGu.jpg'),
(126846, 9093, 'Beyblade S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/249162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/34ogt7GA0ZCGXwvIbDwgerCP6im.jpg'),
(126847, 9093, 'Beyblade S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/249163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aB3jDrQVKivB8HAK0tE9TvTrbaV.jpg'),
(126848, 9093, 'Beyblade S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/249164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fq1uQITiDuWCBWcOm6Kfzpvhb9k.jpg'),
(126849, 9093, 'Beyblade S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/249165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wa0D32jYZDrJtCJOSc9gpXPi1wb.jpg'),
(126850, 9093, 'Beyblade S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/249166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5RZixHUFNI9N2M5XMw85JIp1aHv.jpg'),
(126851, 9093, 'Beyblade S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/249167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7A3y9Q328gQLtNS7h1dSiYny5sA.jpg'),
(126852, 9093, 'Beyblade S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/249168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7odwumBDG54tmISYoY6kfNztUjO.jpg'),
(126853, 9093, 'Beyblade S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/249169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g6lbWmzwVOryI8ovHBTYtQisSRm.jpg'),
(126854, 9093, 'Beyblade S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/249170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/adRSNy5AFJwPVcyNJIVs3jIJPFT.jpg'),
(126855, 9093, 'Beyblade S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/249171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/716asjFp4VSanTgpF1qte7NIgZL.jpg'),
(126856, 9093, 'Beyblade S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/249172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hnrOfqr5q684y3JYv2HTy6wSUOW.jpg'),
(126857, 9093, 'Beyblade S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/249173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/unkLCQcXf7xX5bjYm5iKGbEpwSZ.jpg'),
(126858, 9093, 'Beyblade S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/249174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i4KunNnbxGqJUN27K3QcH5HXLGd.jpg'),
(126859, 9093, 'Beyblade S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/249175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A1WGdigLffDPmLFwt8S2BkTYD7m.jpg'),
(126860, 9093, 'Beyblade S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/249176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uDAF3rptlZhFIk3DZykAOgEYW6j.jpg'),
(126861, 9093, 'Beyblade S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/249177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/XKeSVEsHfqGsMJMSebgR1oWzdr.jpg'),
(126862, 9093, 'Beyblade S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/249178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJYx3TRw5EuMmnngla9jVcoq4jC.jpg'),
(126863, 9093, 'Beyblade S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/249179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nnShE8UcfqyfT8Q78RX95A9ToPn.jpg'),
(126864, 9093, 'Beyblade S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/249180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8fIPb7pkVveJOmqiddPlVc9aYWU.jpg'),
(126865, 9093, 'Beyblade S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/249181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4KqlkLwy3WybF9fKP94ZmaQrvJC.jpg'),
(126866, 9093, 'Beyblade S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/249182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eT2MtTrJ8TxyAa4gfYDhCUKMWB6.jpg'),
(126867, 9093, 'Beyblade S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/249183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9KAg1LbhfY5LtbCZuxuuLXGeKFD.jpg'),
(126868, 9093, 'Beyblade S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/249184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9LFzqFz1YzKwdVcdNkBuUaWcxJ0.jpg'),
(126869, 9093, 'Beyblade S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/249185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xSZWaKeH5wADbR1elbVPWQF2Dp3.jpg'),
(126870, 9093, 'Beyblade S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/249186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqE1nduMG8lQWOfmJqtPZMQD2YG.jpg'),
(126871, 9093, 'Beyblade S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/249187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZ2Oyy4IhEBY2C5cSjxMxOT4Yqg.jpg'),
(126872, 9093, 'Beyblade S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/249188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7cDezQQ6ilgjc81teceaaHvuJoo.jpg'),
(126873, 9093, 'Beyblade S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/249189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5XnCwYhxSiD13dnskflh19UKCVJ.jpg'),
(126874, 9093, 'Beyblade S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/249190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qbesBX9OpwQMcRCrM19jfKOnrsa.jpg'),
(126875, 9093, 'Beyblade S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/249191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1JqCUXCsCsMGoga9JqMaBseOgI0.jpg'),
(126876, 9093, 'Beyblade S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/249192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kHhCDxOJFq2003iQugAxXpij6ee.jpg'),
(126877, 9093, 'Beyblade S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/249193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cwiKlCvatcnw9tLbvuokG4WimRU.jpg'),
(126878, 9093, 'Beyblade S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/249194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AsRtPA6rvGibMPVhgbWLdmxghdp.jpg'),
(126879, 9093, 'Beyblade S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/249195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AjAIloFtUKny46V4NIki4wffSI.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(126880, 9093, 'Beyblade S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/249196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nVGQtcUXOwMddeRBHyRzZKBEy7J.jpg'),
(126881, 9094, 'Digimon Zero Two S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fP1j1ut04szf7Tgm4aiBk2nzTom.jpg'),
(126882, 9094, 'Digimon Zero Two S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8WPwmvH6d6smfEgzrUGyWedShbG.jpg'),
(126883, 9094, 'Digimon Zero Two S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s7Umz0R80mLV4ClTPzG78PgKsT6.jpg'),
(126884, 9094, 'Digimon Zero Two S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/umiSys9Wg6UtZ2r0D8APOctTfk8.jpg'),
(126885, 9094, 'Digimon Zero Two S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ztP73lyxw6nDO7oAH2Gh3sMH6xa.jpg'),
(126886, 9094, 'Digimon Zero Two S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gKUQDKrhpsbaw5msr6K8z5kDEyB.jpg'),
(126887, 9094, 'Digimon Zero Two S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fddNo67ebbwZ7B3sY21krMXjh9E.jpg'),
(126888, 9094, 'Digimon Zero Two S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A64swirY8PqYCa4DKdQCv3z0n7D.jpg'),
(126889, 9094, 'Digimon Zero Two S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mUTAz8M3EhMDexH0nCzs8hbbkIw.jpg'),
(126890, 9094, 'Digimon Zero Two S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svFE3H5yhdU2hkzAAMuDsUzd5OS.jpg'),
(126891, 9094, 'Digimon Zero Two S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eSGk1tBCcA2mOF714Tqkeu5EAjG.jpg'),
(126892, 9094, 'Digimon Zero Two S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fj6yOD0YV7mTHDcTXsjWRJ75AuS.jpg'),
(126893, 9094, 'Digimon Zero Two S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Uze67s60xU7GMUdeKVDm6dFOvY.jpg'),
(126894, 9094, 'Digimon Zero Two S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vyPad1Eaqr8SE0hiwCjjZFemzVb.jpg'),
(126895, 9094, 'Digimon Zero Two S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9DdjfmLYmpuTXUAkiPTooAs4ECS.jpg'),
(126896, 9094, 'Digimon Zero Two S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bRLsbRDYxjR9xiPmlAlxG8Ca7ML.jpg'),
(126897, 9094, 'Digimon Zero Two S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/249112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x4u3Cfuux7JKTlwfiA3jD9Hnxqo.jpg'),
(126898, 9094, 'Digimon Zero Two S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/249113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pCXWJiv2SKv25jynlVz0SySULAb.jpg'),
(126899, 9094, 'Digimon Zero Two S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/249114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9dT7BAkdX2DA166StbWa5r6DbGS.jpg'),
(126900, 9094, 'Digimon Zero Two S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/249115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5UijWrgiaoPYcI5aj8aaOlJHukw.jpg'),
(126901, 9094, 'Digimon Zero Two S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/249116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUcJ7m1vlNoO2MMGECaOALoCvs2.jpg'),
(126902, 9094, 'Digimon Zero Two S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/249117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6R5NlW5ofRm0c6vEDCyRngTVs2P.jpg'),
(126903, 9094, 'Digimon Zero Two S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/249118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iGaGOPHX5ZDGzDbxxmaWSVYe2Yf.jpg'),
(126904, 9094, 'Digimon Zero Two S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/249119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ieqeq5CZPlPxfPGfocW1i6ET0RP.jpg'),
(126905, 9094, 'Digimon Zero Two S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/249120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/912oMMIqzJn151olBsSc5WNfiip.jpg'),
(126906, 9094, 'Digimon Zero Two S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/249121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qqe9FcPttiskXSRm49GGFxFt3Lk.jpg'),
(126907, 9094, 'Digimon Zero Two S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/249122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wAc5JOtJ4eAtduD7VCUxBHLVEPn.jpg'),
(126908, 9094, 'Digimon Zero Two S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/249123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bPuLoPlz5HDIIgHCosCI3jMLltS.jpg'),
(126909, 9094, 'Digimon Zero Two S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/249124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7wB40aqy2Dv4rrvAeChewzmoxfl.jpg'),
(126910, 9094, 'Digimon Zero Two S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/249125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzDZAItZB9k148kjqf7Cg3DS4i.jpg'),
(126911, 9094, 'Digimon Zero Two S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/249126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHdzSLmYtHBc4rVOUE1zZ8xd4FO.jpg'),
(126912, 9094, 'Digimon Zero Two S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/249127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vo65JogUpMxiYSeogdX2c3I6UZE.jpg'),
(126913, 9094, 'Digimon Zero Two S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/249128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p5L3yA4DtVpTlLdS9zgEntadC65.jpg'),
(126914, 9094, 'Digimon Zero Two S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/249129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m3zoHPTONrZe4i9FWgoh7lBhH2d.jpg'),
(126915, 9094, 'Digimon Zero Two S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/249130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aA4HYuUJtntNP89ttPOIKIJast.jpg'),
(126916, 9094, 'Digimon Zero Two S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/249131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5OYzF0dwRewxko2gyozg99WmJdH.jpg'),
(126917, 9094, 'Digimon Zero Two S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/249132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/whlggUYF40vlF7Gwgfvl9VT10I9.jpg'),
(126918, 9094, 'Digimon Zero Two S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/249133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tLT0Kk5CLHyLTvStsnanWpD9SGx.jpg'),
(126919, 9094, 'Digimon Zero Two S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/249134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6jaFzlAt5S6CdqpM2nCVrKDLEqi.jpg'),
(126920, 9094, 'Digimon Zero Two S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/249135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/27KE6DGICFTqRF0EhXbOMwy63wP.jpg'),
(126921, 9094, 'Digimon Zero Two S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/249136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tN01tawrOVVLozHybiYd30Ol0tF.jpg'),
(126922, 9094, 'Digimon Zero Two S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/249137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eiDWc5xVF3eQVX4PA3P78DT6SAm.jpg'),
(126923, 9094, 'Digimon Zero Two S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/249138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3giWzcG6zVyGIcfrR7KAnE0Tw3Z.jpg'),
(126924, 9094, 'Digimon Zero Two S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/249139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Ry0rjTSvFU7kLeMl8BVHTrmUz7.jpg'),
(126925, 9094, 'Digimon Zero Two S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/249140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5XcSRMInVuQOBD17NxpHodE2R8l.jpg'),
(126926, 9094, 'Digimon Zero Two S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/249141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yRUsJItSaVTLOXUp7XeVHpz29CK.jpg'),
(126927, 9094, 'Digimon Zero Two S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/249142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7opyjVd9sbFbPumVkuwXAbFX71.jpg'),
(126928, 9094, 'Digimon Zero Two S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/249143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3lGGwkKvYyzhIXQLFSiNoDggwYA.jpg'),
(126929, 9094, 'Digimon Zero Two S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/249144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f7jIuTkd7i4PCpjN78JGTdjZvWa.jpg'),
(126930, 9094, 'Digimon Zero Two S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/249145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jPfdoc3tRJDTMfubEkXptBKMRqk.jpg'),
(126931, 9095, 'Digimon Digital Monsters S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/249042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fYCDgkGMroaukOlfiPJIEXRaFam.jpg'),
(126932, 9095, 'Digimon Digital Monsters S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/249043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qaB6sWNWVnpORc08MVOuQUwKpji.jpg'),
(126933, 9095, 'Digimon Digital Monsters S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/249044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/avo4GjEeyEtJcDpn7CkW1x63Ojq.jpg'),
(126934, 9095, 'Digimon Digital Monsters S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/249045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kEmeDs6Nn1dgkGlkfp5sWskZQKa.jpg'),
(126935, 9095, 'Digimon Digital Monsters S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/249046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfsIemViX9Yn0Q1kCdNuOQkhtVo.jpg'),
(126936, 9095, 'Digimon Digital Monsters S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/249047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dTJJg6wCOfxKCeOfmxtcWO18kWO.jpg'),
(126937, 9095, 'Digimon Digital Monsters S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/249048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t1paGSIi8ZVSbh9oDslDS5ZN5Ma.jpg'),
(126938, 9095, 'Digimon Digital Monsters S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/249049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZd8OhEBkjFxPRIgJrPhc1zeC8Z.jpg'),
(126939, 9095, 'Digimon Digital Monsters S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/249050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sHKqbeBMY7fkXaQNoaaHn1vQlBV.jpg'),
(126940, 9095, 'Digimon Digital Monsters S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/At3sGTO67TMAgFJqZsgobtcfn3A.jpg'),
(126941, 9095, 'Digimon Digital Monsters S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tFrddgS2cck8JnQSgQrCNpD8N8I.jpg'),
(126942, 9095, 'Digimon Digital Monsters S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cAjyslcjKMtZkFPjpLgRslX2vId.jpg'),
(126943, 9095, 'Digimon Digital Monsters S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bUuZFPfPu6hmdXnNo9ycnUoWev2.jpg'),
(126944, 9095, 'Digimon Digital Monsters S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sbyvKAssX57U5x7J4wheUDN965w.jpg'),
(126945, 9095, 'Digimon Digital Monsters S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7NQFoizUP0zboiGQPfdb9RUjkuY.jpg'),
(126946, 9095, 'Digimon Digital Monsters S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zKEaV0ksPBxdOdeDoJp5LXHobYS.jpg'),
(126947, 9095, 'Digimon Digital Monsters S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/249058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9eCjbdIWkeHQq9zJhcxvRyPAy4j.jpg'),
(126948, 9095, 'Digimon Digital Monsters S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/249059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k2H1fcdxgtxeCnFWwghfop8CNOo.jpg'),
(126949, 9095, 'Digimon Digital Monsters S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/249060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cAgqwqZKtjY7VxKsp8YKxN7ZoQR.jpg'),
(126950, 9095, 'Digimon Digital Monsters S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/249061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xUPqSLJ0WWkjz77tP1pTRFzsYvS.jpg'),
(126951, 9095, 'Digimon Digital Monsters S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/249062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oBy4CNQXzBRKArcb1Auy0wLOnVf.jpg'),
(126952, 9095, 'Digimon Digital Monsters S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/249063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bkVI2774zb6Hpp3ZnvBxo9Cg1Av.jpg'),
(126953, 9095, 'Digimon Digital Monsters S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/249064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8IM9oZgFqcWNFPNWOKRvoTO3fB.jpg'),
(126954, 9095, 'Digimon Digital Monsters S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/249065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iUwww37V9c990sOD3Lmc5xwlWN2.jpg'),
(126955, 9095, 'Digimon Digital Monsters S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/249066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qFydzIHXeNyvGI60a0lH6dUaZvD.jpg'),
(126956, 9095, 'Digimon Digital Monsters S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/249067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vPtajjrZ0dz0wHoMlmT5qho5P5A.jpg'),
(126957, 9095, 'Digimon Digital Monsters S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/249068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pRRRlKZOIE2CvWcJuGbPnAvqHET.jpg'),
(126958, 9095, 'Digimon Digital Monsters S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/249069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cNac8wPyWfigUeLSXi0gsgmXc5h.jpg'),
(126959, 9095, 'Digimon Digital Monsters S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/249070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lKwwFS6LfDsF4e1pGqn9I1lknEB.jpg'),
(126960, 9095, 'Digimon Digital Monsters S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/249071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jjfuHoGNgPuwzwe7duVvGaGzJjm.jpg'),
(126961, 9095, 'Digimon Digital Monsters S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/249072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1WQq1QQIg58eSijpnmZtpsE4prP.jpg'),
(126962, 9095, 'Digimon Digital Monsters S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/249073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vQg5hZv7cONCH7nkzKj72q4HuFs.jpg'),
(126963, 9095, 'Digimon Digital Monsters S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/249074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aIZMEtofAwYUS61biIGyJvNiTAn.jpg'),
(126964, 9095, 'Digimon Digital Monsters S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/249075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1t0GeLMMaRoaePK2Pp3R7XC39ko.jpg'),
(126965, 9095, 'Digimon Digital Monsters S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/249076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTVUHEpfDWxJj1f3Sy8Y0nTlA4V.jpg'),
(126966, 9095, 'Digimon Digital Monsters S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/249077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cOXDSYsONTfzRKKxZbMrfwRteoU.jpg'),
(126967, 9095, 'Digimon Digital Monsters S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/249078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AkKlUUR4kSPKme6LtpYkybi8PCC.jpg'),
(126968, 9095, 'Digimon Digital Monsters S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/249079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cm7pTbHiPR90TKPYohv7iBuabSu.jpg'),
(126969, 9095, 'Digimon Digital Monsters S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/249080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/58pyeIXAekuBZ8RJs6nNShA1rf.jpg'),
(126970, 9095, 'Digimon Digital Monsters S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/249081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oXT1mcyUo0lvVV3IYuJSNNFPNYQ.jpg'),
(126971, 9095, 'Digimon Digital Monsters S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/249082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQTDw3pCAzNRkltzANyaYZhyQlD.jpg'),
(126972, 9095, 'Digimon Digital Monsters S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/249083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sC6wyktc6lx08sQbZevEqnSgylP.jpg'),
(126973, 9095, 'Digimon Digital Monsters S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/249084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nTNb72wMmwbFoDq2UxAqdf7pzn9.jpg'),
(126974, 9095, 'Digimon Digital Monsters S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/249085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7PEuByc0hlFH7GyNthtOSeJIWAd.jpg'),
(126975, 9095, 'Digimon Digital Monsters S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/249086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ai2svAoB4M9wziXq6jiIXvkaZ1v.jpg'),
(126976, 9095, 'Digimon Digital Monsters S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/249087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ZAxEg7JLXD6pBBzMWJvVBP6EJm.jpg'),
(126977, 9095, 'Digimon Digital Monsters S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/249088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mDzfS301GAyvFM5uLXIVWkCSShP.jpg'),
(126978, 9095, 'Digimon Digital Monsters S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/249089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eFjGvd138mkjE83XmEQEpj8vmfC.jpg'),
(126979, 9095, 'Digimon Digital Monsters S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/249090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l6F7r1puDadPjfbHcbrTEEP8BUE.jpg'),
(126980, 9095, 'Digimon Digital Monsters S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/249091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dESQ3CiaLWt9e1c6cUkjjSYvl1w.jpg'),
(126981, 9095, 'Digimon Digital Monsters S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/249092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ZfSeutTb8SajruQDNcM97EskDF.jpg'),
(126982, 9095, 'Digimon Digital Monsters S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/249093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2PRFEiLhZSqCyKSlQyGTsuBSnOx.jpg'),
(126983, 9095, 'Digimon Digital Monsters S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/249094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/roRCF3HQiuM2Y1KE6BDbFcWjKNq.jpg'),
(126984, 9095, 'Digimon Digital Monsters S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/249095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1p8Knbc01WLq4fGjbcdRvnO4s4h.jpg'),
(126985, 9096, 'Digimon Tamers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xWumk83JxsDfzoyf3s0nKGxRBCl.jpg'),
(126986, 9096, 'Digimon Tamers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qvKdk1GZGtkjS0t0cScXPnef5zV.jpg'),
(126987, 9096, 'Digimon Tamers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0RTXxY4ivjIommdJxpZxPuqRHj.jpg'),
(126988, 9096, 'Digimon Tamers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5tKA3FcyFpq9nqMyeDY0OLOQe5y.jpg'),
(126989, 9096, 'Digimon Tamers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sN5av2QFuqxsYTfs1TP93BxgsET.jpg'),
(126990, 9096, 'Digimon Tamers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vwOTv2P2VPMCbp6FoGRWKavywEn.jpg'),
(126991, 9096, 'Digimon Tamers S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ePfAA9kAi2ccUriVJhifHAQnnt.jpg'),
(126992, 9096, 'Digimon Tamers S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c1ztrsH19XziQ0Jx1FI4hHcuYC5.jpg'),
(126993, 9096, 'Digimon Tamers S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5rvchbPmzPNNKWSYcN74Uw2WkTM.jpg'),
(126994, 9096, 'Digimon Tamers S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/249000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j149lEjTjXNRz7cvVrRzIYSoNM6.jpg'),
(126995, 9096, 'Digimon Tamers S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/249001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iP64o8nJObSQoBO55LAEsJmg9OO.jpg'),
(126996, 9096, 'Digimon Tamers S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/249002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ylZh9Lx4CMTP8TrxeV1Z1IBeDB.jpg'),
(126997, 9096, 'Digimon Tamers S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/249003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1XMJm0N5J359Oj4w328gcaIYY7q.jpg'),
(126998, 9096, 'Digimon Tamers S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/249004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97wbX7e3nzJNx51KNaNTU03D4t0.jpg'),
(126999, 9096, 'Digimon Tamers S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/249005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rZkciERbh86l1PHQLitaxPknurg.jpg'),
(127000, 9096, 'Digimon Tamers S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/249006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9zbhqTQc7OU51s3DsRKoKjqSyyQ.jpg'),
(127001, 9096, 'Digimon Tamers S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/249007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/daCowQkFSs5A5MJe5B6wfkkyTls.jpg'),
(127002, 9096, 'Digimon Tamers S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/249008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sANNufs7Kftiu4elcwSP8bpsAaL.jpg'),
(127003, 9096, 'Digimon Tamers S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/249009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hlzp7BOimp87XMPP3gwCmKqLyQ8.jpg'),
(127004, 9096, 'Digimon Tamers S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/249010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jU05HjJzw5ZIG32YslRco6i7Hgd.jpg'),
(127005, 9096, 'Digimon Tamers S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/249011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4SRywlq0XsmOqrHoMdBDwglYxXr.jpg'),
(127006, 9096, 'Digimon Tamers S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/249012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVgdDjAVPlP3cqVhwrUFBglHzE0.jpg'),
(127007, 9096, 'Digimon Tamers S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/249013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h89T6x1r9kAR3PHriNEYTaTZAql.jpg'),
(127008, 9096, 'Digimon Tamers S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/249014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/grd581vQsB5o04ME5echDTanHUM.jpg'),
(127009, 9096, 'Digimon Tamers S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/249015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tj6Q4D2A4bM0QzfaRk1K2ozHMH7.jpg'),
(127010, 9096, 'Digimon Tamers S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/249016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/khBA4GshKgE1E0it8cPl7UXLoap.jpg'),
(127011, 9096, 'Digimon Tamers S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/249017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/71IvAS7FaigkZfgnsCMOi1uSiIq.jpg'),
(127012, 9096, 'Digimon Tamers S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/249018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hKgC5zxt5Z75GH8nSykNm4a0RQV.jpg'),
(127013, 9096, 'Digimon Tamers S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/249019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/htjfIWqXpAjOzmVD4WLp1ssBePb.jpg'),
(127014, 9096, 'Digimon Tamers S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/249020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tuGxesmufbqFxduBjJV6tCOmoEA.jpg'),
(127015, 9096, 'Digimon Tamers S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/249021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kRy8ssjcw5Dh8PrVKuRyhuHezPH.jpg'),
(127016, 9096, 'Digimon Tamers S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/249022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uu7fYHjQCcPTdQNHof3IjSfa9hW.jpg'),
(127017, 9096, 'Digimon Tamers S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/249023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r3ZPWzjwYDKVQbAfJYKi9ruE8Ne.jpg'),
(127018, 9096, 'Digimon Tamers S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/249024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pnY8EOROrwPjs6dS53wA3YRyrj0.jpg'),
(127019, 9096, 'Digimon Tamers S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/249025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/epsPa0utU2bnodeHGQUqlJ4qOId.jpg'),
(127020, 9096, 'Digimon Tamers S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/249026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8amY4V0JQfrnH8iZva86kusx2K7.jpg'),
(127021, 9096, 'Digimon Tamers S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/249027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kGkpwaBCyinoWr0ECORTipEZoue.jpg'),
(127022, 9096, 'Digimon Tamers S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/249028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xVIg7rFsK21JRnmhmDC2TpIHLNz.jpg'),
(127023, 9096, 'Digimon Tamers S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/249029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sYNeBJ7aZyOEA4IjeulvRPkykeE.jpg'),
(127024, 9096, 'Digimon Tamers S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/249030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u6dOT9OVoB3OtI025JerEEau1fv.jpg'),
(127025, 9096, 'Digimon Tamers S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/249031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9HNUidzgXHkYsRAjmQYtKSL5EQB.jpg'),
(127026, 9096, 'Digimon Tamers S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/249032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/BiCPw9IsjRiGTBe7xMsyG9JsAX.jpg'),
(127027, 9096, 'Digimon Tamers S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/249033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p1i41oTiNrSROSJ2YJDaTibZ9z2.jpg'),
(127028, 9096, 'Digimon Tamers S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/249034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i19CUgxLw6oSPTJc9TWzyErfa1F.jpg'),
(127029, 9096, 'Digimon Tamers S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/249035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dPnfWw00KHIKih6ccbLVIr4gRTL.jpg'),
(127030, 9096, 'Digimon Tamers S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/249036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/19843ljMclkQl78pSoCJ5Kb7yob.jpg'),
(127031, 9096, 'Digimon Tamers S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/249037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e7f36CjkVhSyQAaywTR5MMuuoCz.jpg'),
(127032, 9096, 'Digimon Tamers S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/249038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ROmLCquji7MaFBf0ITD0n8yrLa.jpg'),
(127033, 9096, 'Digimon Tamers S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/249039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9IKtPvji1mbztj48isfR5hhWuGz.jpg'),
(127034, 9096, 'Digimon Tamers S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/249040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hGpMO40msYsRx3Dz8C2QOZI0BDD.jpg'),
(127035, 9096, 'Digimon Tamers S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/249041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/usYgx2BaCfgIc0QyhihBPU57XcF.jpg'),
(127036, 9097, 'Ben 10: Força Alienígena S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ESPvUHWEuK3ycpLO76Rh4LG64u.jpg'),
(127037, 9097, 'Ben 10: Força Alienígena S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o3bRkG43BamvVxG3NftsBzhACy4.jpg'),
(127038, 9097, 'Ben 10: Força Alienígena S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xreOMeREwGdVh5Fcq1YJSPtYgTy.jpg'),
(127039, 9097, 'Ben 10: Força Alienígena S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y7ZlInG4kn010fjFoBmhuNQHRdJ.jpg'),
(127040, 9097, 'Ben 10: Força Alienígena S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iBUjWMxZEfCKfPNxcG6NtTHMhjb.jpg'),
(127041, 9097, 'Ben 10: Força Alienígena S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iX6aDOD48pyk7iFVEi7OGvmcXTv.jpg'),
(127042, 9097, 'Ben 10: Força Alienígena S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bJpgP2K9R73HiJ60J0hk5UXFdIj.jpg'),
(127043, 9097, 'Ben 10: Força Alienígena S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lTpeaMayum2TJz2bqD0iJCDplOc.jpg'),
(127044, 9097, 'Ben 10: Força Alienígena S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2iUfYMlnbQBGZnakhPeUXOqjzIr.jpg'),
(127045, 9097, 'Ben 10: Força Alienígena S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7Uf0FRaQDQcwTRzk4y1UH7DXoC.jpg'),
(127046, 9097, 'Ben 10: Força Alienígena S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/evzy1W2PMSUqcwSDGv1Lhb3S2hk.jpg'),
(127047, 9097, 'Ben 10: Força Alienígena S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ze1RoBUQN8UZbE4CtE7MLWP8Ki.jpg'),
(127048, 9097, 'Ben 10: Força Alienígena S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ulwJTJguIRrx49OSK3g9qNjhWn.jpg'),
(127049, 9098, 'Ben 10: Força Alienígena S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7bz6JKBYgaIENcwN4aCvaSnWu74.jpg'),
(127050, 9098, 'Ben 10: Força Alienígena S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sOrMsF8FpHr2YavAYOyeUUQ9X8.jpg'),
(127051, 9098, 'Ben 10: Força Alienígena S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bXcL3lbh3AHvZOhiu4n3QUohtXT.jpg'),
(127052, 9098, 'Ben 10: Força Alienígena S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/byxef9EV6hYsXLqJsrNxlUatsDK.jpg'),
(127053, 9098, 'Ben 10: Força Alienígena S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vNyY4NtMkbWp4gMsFXgTEE57hvs.jpg'),
(127054, 9098, 'Ben 10: Força Alienígena S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cFKRuToZxIuslM8hEYdZYd5rP2d.jpg'),
(127055, 9098, 'Ben 10: Força Alienígena S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fY1OIrYQQzSnifAXOqCUrxcD68B.jpg'),
(127056, 9098, 'Ben 10: Força Alienígena S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jIVXOJAQuPhSIB7nNbOwscyXod3.jpg'),
(127057, 9098, 'Ben 10: Força Alienígena S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bM5ud1L9vHLL2ukFN6UCcywy54X.jpg'),
(127058, 9098, 'Ben 10: Força Alienígena S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eBT7FTA1f70dFWu4t7UKicvJHkZ.jpg'),
(127059, 9098, 'Ben 10: Força Alienígena S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6TrubL7Hja8i34Yrn4NM5YXbw2h.jpg'),
(127060, 9098, 'Ben 10: Força Alienígena S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xWfheLkwSmQB4EyN9JTBQauDuI1.jpg'),
(127061, 9098, 'Ben 10: Força Alienígena S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7RNZC9trtdUgKaT3jW0M4EPBaTN.jpg'),
(127062, 9099, 'Ben 10: Força Alienígena S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gof9o8oe4trjIIBg4TKOH7QVmsk.jpg'),
(127063, 9099, 'Ben 10: Força Alienígena S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/66tsQoUv51XFuwgI1N9aXZvyGTV.jpg'),
(127064, 9099, 'Ben 10: Força Alienígena S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wWgolU3OBbku9WecZxzO5QI4Ua8.jpg'),
(127065, 9099, 'Ben 10: Força Alienígena S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i0iXRChojbpRWy54vwf44qHfG6p.jpg'),
(127066, 9099, 'Ben 10: Força Alienígena S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCD0bSU06IxlpxMxhnTwLKU1wcQ.jpg'),
(127067, 9099, 'Ben 10: Força Alienígena S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hi6FnbAlA3h0rNE5oiHRX96Jsqb.jpg'),
(127068, 9099, 'Ben 10: Força Alienígena S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tHvoWfU3EmFw1n6Bqpw32jbPSa4.jpg'),
(127069, 9099, 'Ben 10: Força Alienígena S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rAKShHOppVPAHBrGH0nzv4MwpSF.jpg'),
(127070, 9099, 'Ben 10: Força Alienígena S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ukdYWufJ3QkGpAhwoEEmKAAhgxb.jpg'),
(127071, 9099, 'Ben 10: Força Alienígena S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mqxtedSldy9kYpS4vonRZG0LJb2.jpg'),
(127072, 9099, 'Ben 10: Força Alienígena S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eDAjCFQ8fnMn35oYemYXMcXlGJU.jpg'),
(127073, 9099, 'Ben 10: Força Alienígena S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3cwqiUbLxIaQ8jMELqZKOd9Abdb.jpg'),
(127074, 9099, 'Ben 10: Força Alienígena S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wEeK4uzTRMBqsuILGa54R1xAvDD.jpg'),
(127075, 9099, 'Ben 10: Força Alienígena S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/248984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1EwOLPMpG5WA3KwfQ62KfPry9UT.jpg'),
(127076, 9099, 'Ben 10: Força Alienígena S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/248985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JJTbywPrkl4nhNtYkDiOjhKYVn.jpg'),
(127077, 9099, 'Ben 10: Força Alienígena S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/248986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9XFaDvzDuj4DTqENTwIzyaFDKDc.jpg'),
(127078, 9099, 'Ben 10: Força Alienígena S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/248987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l5dfkvgSetnZq5YmicXOHPHmvX1.jpg'),
(127079, 9099, 'Ben 10: Força Alienígena S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/248988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nMMpnbeSCJZKTGql2ieZLCfnSjJ.jpg'),
(127080, 9099, 'Ben 10: Força Alienígena S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/248989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ba2A00pA6KyJru883MJsT5A0KOB.jpg'),
(127081, 9099, 'Ben 10: Força Alienígena S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/248990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jREWGNCqKKXbioLcf0CYfoacsi8.jpg'),
(127082, 9100, 'A Historia Delas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1jzYHqjDbGxGP3o4XedtTMYlthX.jpg'),
(127083, 9100, 'A Historia Delas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1jzYHqjDbGxGP3o4XedtTMYlthX.jpg'),
(127084, 9100, 'A Historia Delas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1jzYHqjDbGxGP3o4XedtTMYlthX.jpg'),
(127085, 9100, 'A Historia Delas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1jzYHqjDbGxGP3o4XedtTMYlthX.jpg'),
(127086, 9100, 'A Historia Delas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1jzYHqjDbGxGP3o4XedtTMYlthX.jpg'),
(127087, 9100, 'A Historia Delas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1jzYHqjDbGxGP3o4XedtTMYlthX.jpg'),
(127088, 9100, 'A Historia Delas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1jzYHqjDbGxGP3o4XedtTMYlthX.jpg'),
(127089, 9100, 'A Historia Delas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1jzYHqjDbGxGP3o4XedtTMYlthX.jpg'),
(127090, 9101, 'Amor como um Romance Coreano S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3CuHJjkdgHyH67mHpXhavJqEP0.jpg'),
(127091, 9101, 'Amor como um Romance Coreano S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5wEKFdVBQ8gSH0afaccMSCQjuzb.jpg'),
(127092, 9101, 'Amor como um Romance Coreano S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zw7fu7BhVf50uanxiGEXRejT2EP.jpg'),
(127093, 9101, 'Amor como um Romance Coreano S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQWJ2zkvVeimNz7op9glznHWT8a.jpg'),
(127094, 9101, 'Amor como um Romance Coreano S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/viXisDysFZOX4f6GuypD9OnouhE.jpg'),
(127095, 9101, 'Amor como um Romance Coreano S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/30UewO41yRBGYTsKdnuz38aDRBG.jpg'),
(127096, 9101, 'Amor como um Romance Coreano S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZJMn2nUPu9lsIqXEkVoPahwJgF.jpg'),
(127097, 9101, 'Amor como um Romance Coreano S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWlQuTMe46qvZZp4109k1gbVJwR.jpg'),
(127098, 9101, 'Amor como um Romance Coreano S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWlQuTMe46qvZZp4109k1gbVJwR.jpg'),
(127099, 9101, 'Amor como um Romance Coreano S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWlQuTMe46qvZZp4109k1gbVJwR.jpg'),
(127100, 9101, 'Amor como um Romance Coreano S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWlQuTMe46qvZZp4109k1gbVJwR.jpg'),
(127101, 9102, 'Chef Kath Fang Legado de Familia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SFcewZEVACxCc1wU3iA6kKepyy.jpg'),
(127102, 9102, 'Chef Kath Fang Legado de Familia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SFcewZEVACxCc1wU3iA6kKepyy.jpg'),
(127103, 9102, 'Chef Kath Fang Legado de Familia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SFcewZEVACxCc1wU3iA6kKepyy.jpg'),
(127104, 9102, 'Chef Kath Fang Legado de Familia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SFcewZEVACxCc1wU3iA6kKepyy.jpg'),
(127105, 9102, 'Chef Kath Fang Legado de Familia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SFcewZEVACxCc1wU3iA6kKepyy.jpg'),
(127106, 9102, 'Chef Kath Fang Legado de Familia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7SFcewZEVACxCc1wU3iA6kKepyy.jpg'),
(127107, 9103, 'Familia Analogica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fkPdv4Qy46pI8kugHVrzjfLrWQr.jpg'),
(127108, 9103, 'Familia Analogica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s1QAo6k6DgxGlvWvLScXvNc6EDO.jpg'),
(127109, 9103, 'Familia Analogica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ctnkXO9IKK0qc9maYl7LVhrr1G9.jpg'),
(127110, 9103, 'Familia Analogica S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sv68yPNZE0jbOGQFSxXR72INCty.jpg'),
(127111, 9103, 'Familia Analogica S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zlkMVUHKbN15pfgl0IqpHB8NECw.jpg'),
(127112, 9103, 'Familia Analogica S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xT915Kkt2XWOGyRKp990q7zpkZ6.jpg'),
(127113, 9103, 'Familia Analogica S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/anXaaF0Iqk7rID53AyK2Zr2RszB.jpg'),
(127114, 9103, 'Familia Analogica S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4tNxO6XEmxuh6FAQ7DjFd8ZE1wG.jpg'),
(127115, 9104, 'Hairstyle The Talent Show Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bJbD0tYWEdUKbHmMVuMfvaagUnb.jpg'),
(127116, 9104, 'Hairstyle The Talent Show Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bJbD0tYWEdUKbHmMVuMfvaagUnb.jpg'),
(127117, 9104, 'Hairstyle The Talent Show Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bJbD0tYWEdUKbHmMVuMfvaagUnb.jpg'),
(127118, 9104, 'Hairstyle The Talent Show Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bJbD0tYWEdUKbHmMVuMfvaagUnb.jpg'),
(127119, 9104, 'Hairstyle The Talent Show Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bJbD0tYWEdUKbHmMVuMfvaagUnb.jpg'),
(127120, 9104, 'Hairstyle The Talent Show Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bJbD0tYWEdUKbHmMVuMfvaagUnb.jpg'),
(127121, 9105, 'Marselha em Perigo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t4I4EKoZOQ7dQ8qiaAg0IzCkzHN.jpg'),
(127122, 9105, 'Marselha em Perigo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ZLEmCZR5TU2mwE2CeHGOlJCUUF.jpg'),
(127123, 9105, 'Marselha em Perigo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kgGkhgWgGUcIR1Jm2cvQ1SeERQ2.jpg'),
(127124, 9105, 'Marselha em Perigo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AdCrGMDEr6aPFSjdVWkmysvjBRX.jpg'),
(127125, 9105, 'Marselha em Perigo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p16yvnHthC7UI4cXOwA8x730lgz.jpg'),
(127126, 9105, 'Marselha em Perigo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6JbUciemb3mHxKtnvQbPBF5SzC.jpg'),
(127127, 9106, 'Minha Vida com a Familia Walter S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4C4e04oPukV9oN77kBbB3FLHmcJ.jpg'),
(127128, 9106, 'Minha Vida com a Familia Walter S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vLiGXz7hwp8plPTDE4fHKF0tqJP.jpg'),
(127129, 9106, 'Minha Vida com a Familia Walter S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2DYd7HQQ2ATsR2QEp5DNJyl4Wye.jpg'),
(127130, 9106, 'Minha Vida com a Familia Walter S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rqOYvCEfNzi4oe2ri9lTmT2Glgo.jpg'),
(127131, 9106, 'Minha Vida com a Familia Walter S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dYyiWWgeUPA48b8kB7SwvzlSu49.jpg'),
(127132, 9106, 'Minha Vida com a Familia Walter S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vD3aBDnCl4bsyGaHcWl9ozbrrmr.jpg'),
(127133, 9106, 'Minha Vida com a Familia Walter S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iP8bMlo8ug1BOzdIBaQBCXMgvSA.jpg'),
(127134, 9106, 'Minha Vida com a Familia Walter S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a5dIjS6PgaTdUCuEEO92jRvRpBx.jpg'),
(127135, 9106, 'Minha Vida com a Familia Walter S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/26QioQ2LcS71MLGUl5cOVvEGffF.jpg'),
(127136, 9106, 'Minha Vida com a Familia Walter S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3GCxWKyprG9tCNWfgInMSg4v4PX.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(127137, 9107, 'Minha Vida com a Familia Walter S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/881314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jg3YdxDNlxay0NWTxgAPif647Hj.jpg'),
(127138, 9107, 'Minha Vida com a Familia Walter S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/881315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jg3YdxDNlxay0NWTxgAPif647Hj.jpg'),
(127139, 9107, 'Minha Vida com a Familia Walter S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/881316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jg3YdxDNlxay0NWTxgAPif647Hj.jpg'),
(127140, 9107, 'Minha Vida com a Familia Walter S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/881317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jg3YdxDNlxay0NWTxgAPif647Hj.jpg'),
(127141, 9107, 'Minha Vida com a Familia Walter S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/881318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jg3YdxDNlxay0NWTxgAPif647Hj.jpg'),
(127142, 9107, 'Minha Vida com a Familia Walter S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/881319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jg3YdxDNlxay0NWTxgAPif647Hj.jpg'),
(127143, 9107, 'Minha Vida com a Familia Walter S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/881320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jg3YdxDNlxay0NWTxgAPif647Hj.jpg'),
(127144, 9107, 'Minha Vida com a Familia Walter S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/881321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jg3YdxDNlxay0NWTxgAPif647Hj.jpg'),
(127145, 9107, 'Minha Vida com a Familia Walter S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/881322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jg3YdxDNlxay0NWTxgAPif647Hj.jpg'),
(127146, 9107, 'Minha Vida com a Familia Walter S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/881323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jg3YdxDNlxay0NWTxgAPif647Hj.jpg'),
(127147, 9108, 'Pesca Mortal O Retorno do Viking S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9hEoaJHPduUF91U8XdzpiR95K9p.jpg'),
(127148, 9108, 'Pesca Mortal O Retorno do Viking S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/akItLlcp0uGNxPKbd1FWsqkdJg7.jpg'),
(127149, 9108, 'Pesca Mortal O Retorno do Viking S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7VQDFzOHCERVBRZ2v3WQPt3NJrC.jpg'),
(127150, 9108, 'Pesca Mortal O Retorno do Viking S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ekGy4FU4dEhn34oKL3H4Cge7SUg.jpg'),
(127151, 9108, 'Pesca Mortal O Retorno do Viking S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nSFZHo7PQAcYpDjhsmhBffA6BnB.jpg'),
(127152, 9108, 'Pesca Mortal O Retorno do Viking S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y3BCWMOyUOtR2DvMZwpTT0654yM.jpg'),
(127153, 9108, 'Pesca Mortal O Retorno do Viking S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dKy21uHd9MFUv9iMq9pvkikSWH.jpg'),
(127154, 9108, 'Pesca Mortal O Retorno do Viking S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1croxnlicfWnPREcgvvDQZOcGcW.jpg'),
(127155, 9108, 'Pesca Mortal O Retorno do Viking S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wOQubb0tRD3ohoaYnCIRzRIGiUH.jpg'),
(127156, 9108, 'Pesca Mortal O Retorno do Viking S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wOQubb0tRD3ohoaYnCIRzRIGiUH.jpg'),
(127157, 9109, 'Protetores do Pantano S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8gRR1mY1PaCVNlJEmlPAQseuJS0.jpg'),
(127158, 9109, 'Protetores do Pantano S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oNq8e1ajSFhWiP1RLilGs4eI8Mq.jpg'),
(127159, 9109, 'Protetores do Pantano S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8dc1LND98LC6cgW9WsBajb07eCk.jpg'),
(127160, 9109, 'Protetores do Pantano S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AhQIRq9qk5dybQovIbQqZIYLWzs.jpg'),
(127161, 9109, 'Protetores do Pantano S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qlDnNF0XJpARKd9rA11nL20Yovk.jpg'),
(127162, 9109, 'Protetores do Pantano S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1zKPLaqHrOGoI2ede8zKKXtwsCr.jpg'),
(127163, 9109, 'Protetores do Pantano S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1zKPLaqHrOGoI2ede8zKKXtwsCr.jpg'),
(127164, 9110, 'Protetores do Pantano S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3QO1zrbjgHrcDU1eOKnlkqqliTN.jpg'),
(127165, 9110, 'Protetores do Pantano S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/J1YVpq5IW52W4nZYAP2E86xXX.jpg'),
(127166, 9110, 'Protetores do Pantano S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kixIUshLlUx4o9CLZvr3euLCiiR.jpg'),
(127167, 9110, 'Protetores do Pantano S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dLduJCmMuFlSYMUQin1peu5xqmf.jpg'),
(127168, 9110, 'Protetores do Pantano S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5nNwnHqY1GMLLZxoaI1w2eAvUmF.jpg'),
(127169, 9110, 'Protetores do Pantano S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ijwN6VAOEKxeryzptHSnIbrm7DY.jpg'),
(127170, 9110, 'Protetores do Pantano S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1zKPLaqHrOGoI2ede8zKKXtwsCr.jpg'),
(127171, 9110, 'Protetores do Pantano S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1zKPLaqHrOGoI2ede8zKKXtwsCr.jpg'),
(127172, 9111, 'Tara Duncan S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e8cATrWCsh2PjZHVk7PIZDH19pz.jpg'),
(127173, 9111, 'Tara Duncan S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3cmrAGKnlpj10MxPzbPP4Fpz6Ds.jpg'),
(127174, 9111, 'Tara Duncan S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xBioZ4gOrdzQiQOW2Apl7G1i6HD.jpg'),
(127175, 9111, 'Tara Duncan S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cENcoO9fss8x7DoRc5PrdJECBcl.jpg'),
(127176, 9111, 'Tara Duncan S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/62tHKlOuZ0ZTrOjCOKy9yllV6Hl.jpg'),
(127177, 9111, 'Tara Duncan S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6YU4fNqzArb1N39AqdzkAGmH2Jq.jpg'),
(127178, 9111, 'Tara Duncan S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jrgC1UgE9RWzs3TfQRCtbbScV2i.jpg'),
(127179, 9111, 'Tara Duncan S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/27vYpUX2F0AejtVCSvbmvw4cNRd.jpg'),
(127180, 9111, 'Tara Duncan S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xO5zRbTZCcs6bCzvGyWg0vKEAtI.jpg'),
(127181, 9111, 'Tara Duncan S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2H21oH6u7cviFFhlL0aKC0dCuKx.jpg'),
(127182, 9111, 'Tara Duncan S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fREYAhEZBWxkZAVYZg7p1S3Ifc7.jpg'),
(127183, 9111, 'Tara Duncan S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3sFj2gllzwnOVNjZvb6E58T3bOY.jpg'),
(127184, 9111, 'Tara Duncan S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hyBplfRJuu5BHbNyKaGXDuONeC9.jpg'),
(127185, 9111, 'Tara Duncan S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/248792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jnngFMWhH5Rx0S16zdWqHdkLXfN.jpg'),
(127186, 9111, 'Tara Duncan S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/248793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t4LB2TSDUcIeCX6ixwHIuSDO0b.jpg'),
(127187, 9111, 'Tara Duncan S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/248794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3qFky7Z0k2RUTifdr180iERmT9a.jpg'),
(127188, 9111, 'Tara Duncan S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/248795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/os6He4JkBacHv1f7PKQS6hdWnxX.jpg'),
(127189, 9111, 'Tara Duncan S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/248796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6iV6fckMxdxWLcBvKucYL2JtQr3.jpg'),
(127190, 9111, 'Tara Duncan S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/248797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ekKPLAVKKSoTQf9zFuM2sVOZj1h.jpg'),
(127191, 9111, 'Tara Duncan S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/248798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6gA0RGXF6GfzyXNJR88dXHTrTNK.jpg'),
(127192, 9111, 'Tara Duncan S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/248799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCWBOuhtuNmM4DKbXbtgWsfRuYH.jpg'),
(127193, 9111, 'Tara Duncan S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/248800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127194, 9111, 'Tara Duncan S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/248801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127195, 9111, 'Tara Duncan S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/248802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127196, 9111, 'Tara Duncan S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/248803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127197, 9111, 'Tara Duncan S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/248804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127198, 9111, 'Tara Duncan S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/248805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/raiNH6r7C2dPIZzMbGr64lSq35D.jpg'),
(127199, 9111, 'Tara Duncan S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/248806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3NZF19KfZlxc3RWUXn5qt7Ekrbq.jpg'),
(127200, 9111, 'Tara Duncan S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/248807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/owWEG0zE6OBv6ONSMdxzhRpUNIT.jpg'),
(127201, 9111, 'Tara Duncan S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/248808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oGGJKxVda84MXWy0R8tnRzEKc0u.jpg'),
(127202, 9111, 'Tara Duncan S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/248809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zknpfLiS6eXp5owQFrEfwTf5iBK.jpg'),
(127203, 9111, 'Tara Duncan S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/248810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eAub58gyq0AKrGMNNlkdUKVRfwu.jpg'),
(127204, 9111, 'Tara Duncan S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/248811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127205, 9111, 'Tara Duncan S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/248812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127206, 9111, 'Tara Duncan S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/248813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127207, 9111, 'Tara Duncan S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/248814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127208, 9111, 'Tara Duncan S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/248815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l7GBqVCI5m5E4yCdq5StHmjQ7o7.jpg'),
(127209, 9111, 'Tara Duncan S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/248816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127210, 9111, 'Tara Duncan S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/248817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/va0Gqf7vLkPO4LlzIFMtG1pMmRK.jpg'),
(127211, 9111, 'Tara Duncan S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/248818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/va0Gqf7vLkPO4LlzIFMtG1pMmRK.jpg'),
(127212, 9111, 'Tara Duncan S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/248819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127213, 9111, 'Tara Duncan S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/248820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127214, 9111, 'Tara Duncan S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/248821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127215, 9111, 'Tara Duncan S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/248822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127216, 9111, 'Tara Duncan S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/248823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127217, 9111, 'Tara Duncan S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/248824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127218, 9111, 'Tara Duncan S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/248825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127219, 9111, 'Tara Duncan S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/248826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127220, 9111, 'Tara Duncan S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/248827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127221, 9111, 'Tara Duncan S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/248828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127222, 9111, 'Tara Duncan S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/248829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127223, 9111, 'Tara Duncan S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/248830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNtTFFgM8Qrv3h4UyQRmUZ9hpYm.jpg'),
(127224, 9112, 'Te Vejo No After S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Y0VPs2lnBUPwUYMXtnVXBRc8NK.jpg'),
(127225, 9112, 'Te Vejo No After S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Y0VPs2lnBUPwUYMXtnVXBRc8NK.jpg'),
(127226, 9112, 'Te Vejo No After S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Y0VPs2lnBUPwUYMXtnVXBRc8NK.jpg'),
(127227, 9112, 'Te Vejo No After S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Y0VPs2lnBUPwUYMXtnVXBRc8NK.jpg'),
(127228, 9112, 'Te Vejo No After S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Y0VPs2lnBUPwUYMXtnVXBRc8NK.jpg'),
(127229, 9112, 'Te Vejo No After S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Y0VPs2lnBUPwUYMXtnVXBRc8NK.jpg'),
(127230, 9112, 'Te Vejo No After S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Y0VPs2lnBUPwUYMXtnVXBRc8NK.jpg'),
(127231, 9112, 'Te Vejo No After S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Y0VPs2lnBUPwUYMXtnVXBRc8NK.jpg'),
(127232, 9112, 'Te Vejo No After S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Y0VPs2lnBUPwUYMXtnVXBRc8NK.jpg'),
(127233, 9112, 'Te Vejo No After S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Y0VPs2lnBUPwUYMXtnVXBRc8NK.jpg'),
(127234, 9113, 'Vozes da Segunda Guerra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b143eV3hcy7URrUNOeTy0YJTAAc.jpg'),
(127235, 9113, 'Vozes da Segunda Guerra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9KUnVMawH3bazMriwNh7mvRHhWA.jpg'),
(127236, 9113, 'Vozes da Segunda Guerra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4uCjduZRoxXC9ZIxtmn7OVPHaw.jpg'),
(127237, 9113, 'Vozes da Segunda Guerra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cyAjG5B5KHmh1fcFTUEfu9kKtxL.jpg'),
(127238, 9113, 'Vozes da Segunda Guerra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cV9b2dtlg61bd4LeyWEQwWHAIyZ.jpg'),
(127239, 9113, 'Vozes da Segunda Guerra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/njvkRoPxvmaWzmEPDqqR92hYK8i.jpg'),
(127240, 9114, 'Nem Tao Perfeitos Assim S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mQU0TV2nMMwIxh1CzbwhNOQLOY1.jpg'),
(127241, 9114, 'Nem Tao Perfeitos Assim S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgjgUhH5lq0zZTFOaxMJiFgseJE.jpg'),
(127242, 9114, 'Nem Tao Perfeitos Assim S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d7GF9QRTjSryP9RQxBS03O2ncp8.jpg'),
(127243, 9114, 'Nem Tao Perfeitos Assim S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jLW6fq5UMTEERR3CWf5Ti5vAUex.jpg'),
(127244, 9114, 'Nem Tao Perfeitos Assim S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nSwJ0aHBLqLpKOJ5ueMkyBaBCBf.jpg'),
(127245, 9114, 'Nem Tao Perfeitos Assim S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4nEIjkV31uc7P5aANuVuueStzLU.jpg'),
(127246, 9114, 'Nem Tao Perfeitos Assim S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uXYuef6wfEvcXD7WsZDqQItTb6O.jpg'),
(127247, 9114, 'Nem Tao Perfeitos Assim S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/64ROdPR1W7N8aHIQ6SJrwErBG1b.jpg'),
(127248, 9114, 'Nem Tao Perfeitos Assim S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ud7HwjPtXwMVyLMBU8x2I8elxiK.jpg'),
(127249, 9114, 'Nem Tao Perfeitos Assim S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qiMQA43ZpvSsFpLkmtSa6NDktod.jpg'),
(127250, 9115, 'Nem Tao Perfeitos Assim S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/741418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bePoIXbV8ZNSAwDq2WmL8Nn6Npk.jpg'),
(127251, 9115, 'Nem Tao Perfeitos Assim S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/741419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bePoIXbV8ZNSAwDq2WmL8Nn6Npk.jpg'),
(127252, 9115, 'Nem Tao Perfeitos Assim S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/741420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bePoIXbV8ZNSAwDq2WmL8Nn6Npk.jpg'),
(127253, 9115, 'Nem Tao Perfeitos Assim S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/741421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bePoIXbV8ZNSAwDq2WmL8Nn6Npk.jpg'),
(127254, 9115, 'Nem Tao Perfeitos Assim S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/741422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bePoIXbV8ZNSAwDq2WmL8Nn6Npk.jpg'),
(127255, 9115, 'Nem Tao Perfeitos Assim S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/741423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bePoIXbV8ZNSAwDq2WmL8Nn6Npk.jpg'),
(127256, 9115, 'Nem Tao Perfeitos Assim S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/741424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bePoIXbV8ZNSAwDq2WmL8Nn6Npk.jpg'),
(127257, 9115, 'Nem Tao Perfeitos Assim S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/741425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bePoIXbV8ZNSAwDq2WmL8Nn6Npk.jpg'),
(127258, 9116, 'A Selecao dos EUA na Copa do Mundo Feminina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vo5DUITITwxzAqDH42jCf6Isobx.jpg'),
(127259, 9116, 'A Selecao dos EUA na Copa do Mundo Feminina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnZCYvjM7jhigjuU42WdfelbCAA.jpg'),
(127260, 9116, 'A Selecao dos EUA na Copa do Mundo Feminina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v5S8f48O6HkinB7d3gBJjIQwy3U.jpg'),
(127261, 9116, 'A Selecao dos EUA na Copa do Mundo Feminina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t2bs0CA7zDl4Xa98k4urZrQ3qRM.jpg'),
(127262, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dcfHKLYS55YXwZtOaLMe5YItjHg.jpg'),
(127263, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hN06377Q3OStGL6CyzhIgfw8ijr.jpg'),
(127264, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dNl5OFSTM5Qzf3MC0saS9ByytYa.jpg'),
(127265, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/IszJBgm0pAFpX71eNEh2ES1WIQ.jpg'),
(127266, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCzxOTNww05BhdpGzyq0P4GylYb.jpg'),
(127267, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j7zkWZlSFwgR0cokvpCB45rI6qs.jpg'),
(127268, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sNM4HhBZJgTWjrSCUfsJWY5DAPd.jpg'),
(127269, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yo5IIz4VKasBR6TJe8mQqfTHyFX.jpg'),
(127270, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qFLzTrHB4D6nAjlVIoC6PI578sU.jpg'),
(127271, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tI1M6WdX9Lo6rvDZvEWp1q4Murq.jpg'),
(127272, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Af45VEdHadrthUJwSnruO42iDEZ.jpg'),
(127273, 7622, 'Campfire Cooking in Another World with My Absurd Skill S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fHiK7A5zOwYRz1ast5jMVeiwSm.jpg'),
(127274, 9117, 'Campfire Cooking in Another World with My Absurd Skill S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/889102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6IZkTbgZEkzeVPKqfe644mSxbfF.jpg'),
(127275, 9117, 'Campfire Cooking in Another World with My Absurd Skill S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/889103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6IZkTbgZEkzeVPKqfe644mSxbfF.jpg'),
(127276, 9117, 'Campfire Cooking in Another World with My Absurd Skill S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/890713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6IZkTbgZEkzeVPKqfe644mSxbfF.jpg'),
(127277, 9117, 'Campfire Cooking in Another World with My Absurd Skill S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/890714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6IZkTbgZEkzeVPKqfe644mSxbfF.jpg'),
(127278, 9117, 'Campfire Cooking in Another World with My Absurd Skill S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/891892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6IZkTbgZEkzeVPKqfe644mSxbfF.jpg'),
(127279, 9117, 'Campfire Cooking in Another World with My Absurd Skill S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/892482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6IZkTbgZEkzeVPKqfe644mSxbfF.jpg'),
(127280, 9117, 'Campfire Cooking in Another World with My Absurd Skill S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/893160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6IZkTbgZEkzeVPKqfe644mSxbfF.jpg'),
(127281, 9117, 'Campfire Cooking in Another World with My Absurd Skill S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/893480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6IZkTbgZEkzeVPKqfe644mSxbfF.jpg'),
(127282, 9117, 'Campfire Cooking in Another World with My Absurd Skill S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/894236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6IZkTbgZEkzeVPKqfe644mSxbfF.jpg'),
(127283, 9117, 'Campfire Cooking in Another World with My Absurd Skill S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/895906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6IZkTbgZEkzeVPKqfe644mSxbfF.jpg'),
(127284, 9117, 'Campfire Cooking in Another World with My Absurd Skill S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/896497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6IZkTbgZEkzeVPKqfe644mSxbfF.jpg'),
(127285, 9117, 'Campfire Cooking in Another World with My Absurd Skill S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/897469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6IZkTbgZEkzeVPKqfe644mSxbfF.jpg'),
(127286, 9118, 'Como Criar um Escandalo Sexual S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqkiIefwUyY0x1ju3M9pkcIUPWl.jpg'),
(127287, 9118, 'Como Criar um Escandalo Sexual S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5rSpCpwltupTjhJnGQZqrbpH5x1.jpg'),
(127288, 9118, 'Como Criar um Escandalo Sexual S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/68H6AhOHtcv1X9eqp2pPHdZ4aIz.jpg'),
(127289, 9119, 'Os Farad S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1MZeVLxSRB6c2q2D8DRdGK1e0Aw.jpg'),
(127290, 9119, 'Os Farad S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p9aPlRLS4Cwkquw52lKzbxuF7t4.jpg'),
(127291, 9119, 'Os Farad S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5e9V6H0UHDOLxlFN1vTZCtG3M9.jpg'),
(127292, 9119, 'Os Farad S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kNtHwoQmeFhCIyXCMKJffOgfCj5.jpg'),
(127293, 9119, 'Os Farad S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7Hk1ydua62LpKkRaTIzRHtUJfy.jpg'),
(127294, 9119, 'Os Farad S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lRCiiwHWaONhL1IxArDBNpqQM1K.jpg'),
(127295, 9119, 'Os Farad S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sYYHtmA5fZHjykdXOF4eDADiINw.jpg'),
(127296, 9119, 'Os Farad S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6KR5Gt5vj1bEamOxDNLBDi6AOtA.jpg'),
(127297, 9120, 'Shasha e Milo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zAm9IaMbMa1AuNhFOCRbq9MDlWl.jpg'),
(127298, 9120, 'Shasha e Milo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zAm9IaMbMa1AuNhFOCRbq9MDlWl.jpg'),
(127299, 9120, 'Shasha e Milo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zAm9IaMbMa1AuNhFOCRbq9MDlWl.jpg'),
(127300, 9120, 'Shasha e Milo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zAm9IaMbMa1AuNhFOCRbq9MDlWl.jpg'),
(127301, 9120, 'Shasha e Milo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zAm9IaMbMa1AuNhFOCRbq9MDlWl.jpg'),
(127302, 9120, 'Shasha e Milo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zAm9IaMbMa1AuNhFOCRbq9MDlWl.jpg'),
(127303, 9120, 'Shasha e Milo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zAm9IaMbMa1AuNhFOCRbq9MDlWl.jpg'),
(127304, 9120, 'Shasha e Milo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zAm9IaMbMa1AuNhFOCRbq9MDlWl.jpg'),
(127305, 9120, 'Shasha e Milo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zAm9IaMbMa1AuNhFOCRbq9MDlWl.jpg'),
(127306, 9120, 'Shasha e Milo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zAm9IaMbMa1AuNhFOCRbq9MDlWl.jpg'),
(127307, 9120, 'Shasha e Milo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zAm9IaMbMa1AuNhFOCRbq9MDlWl.jpg'),
(127308, 9120, 'Shasha e Milo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zAm9IaMbMa1AuNhFOCRbq9MDlWl.jpg'),
(127309, 9120, 'Shasha e Milo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zAm9IaMbMa1AuNhFOCRbq9MDlWl.jpg'),
(127310, 9121, '1670 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/48zAaYdSGRTtq6f7L9z6MOf1z20.jpg'),
(127311, 9121, '1670 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/maBXrHH7rlN50CgERqOoC8N71w0.jpg'),
(127312, 9121, '1670 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xdwJuu5HLKfSGPdZ4CCnyliot9I.jpg'),
(127313, 9121, '1670 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9XQOXCY4cyospUFM14llFKiSGbj.jpg'),
(127314, 9121, '1670 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uQDDUYhutkD0pIHQ3nUbrRyCIPC.jpg'),
(127315, 9121, '1670 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ykBEBf0rk9feCzD44swuVsjwuL.jpg'),
(127316, 9121, '1670 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6dn472UyvBzCx3httc1OwN5xnfl.jpg'),
(127317, 9121, '1670 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmNGnhSappaBOM7D4UiDYRCoGyB.jpg'),
(127318, 9122, 'Se eu fosse Luisa Sonza S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7udYXSNwlnQGv5jOLlvIoVwSsve.jpg'),
(127319, 9122, 'Se eu fosse Luisa Sonza S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1MHW8tf1QK3171EuW9HYqoL0ELn.jpg'),
(127320, 9122, 'Se eu fosse Luisa Sonza S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Rj9OJgxgePA3IAjoi5rgz2oonq.jpg'),
(127321, 654, 'Slasher S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8NuxzISP4wXSqaRIGwXOW7ZXgvW.jpg'),
(127322, 654, 'Slasher S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7x3vV3Wf6ZIhRZCqaFrYZLBWFF3.jpg'),
(127323, 654, 'Slasher S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zGKvIdBQsgi2hpYAFQvVBRWMPpV.jpg'),
(127324, 654, 'Slasher S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f7fkUJ964zoLIIf0Fj9vveeoKOU.jpg'),
(127325, 654, 'Slasher S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9lggjqxvDQ5MG63dM7v19hAC52D.jpg'),
(127326, 654, 'Slasher S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ivqHXwnqcVSRCKbhWW0IlSqhW5q.jpg'),
(127327, 654, 'Slasher S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mfKxcDg74CK3tR7EPdGeY1I5pOb.jpg'),
(127328, 654, 'Slasher S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jJW4IvDgsSlsGYBwr9lHtfDqkGN.jpg'),
(127329, 655, 'Slasher S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0rwYDVFnuHoWnvwa040odBQrXY.jpg'),
(127330, 655, 'Slasher S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dpkj3MrtRfwxkAUV3PNmLvCzCIe.jpg'),
(127331, 655, 'Slasher S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kqCasNc30it4vaVgSK01ETFJQ8O.jpg'),
(127332, 655, 'Slasher S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j9vGftvf4Jtipnb5NEjSOq186ST.jpg'),
(127333, 655, 'Slasher S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3sDVm65t04EjujkNDcx27wbFiXq.jpg'),
(127334, 655, 'Slasher S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/flnC7YBNcha0CG6m8IwOdtpLbgw.jpg'),
(127335, 655, 'Slasher S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Sv9aBeBmqhbxk5DeYwGMVeplTx.jpg'),
(127336, 655, 'Slasher S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7GnDB7pzovVuLAWHPS1v0kMe2j6.jpg'),
(127337, 656, 'Slasher S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sHBtzJA2Pg0LAIL5vjzhoBxSYiL.jpg'),
(127338, 656, 'Slasher S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iPHVAKWFpMOWCtdSEAsPPxmhv8b.jpg'),
(127339, 656, 'Slasher S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xdRJHqnC3gE1T7ImdUsMASIuRZZ.jpg'),
(127340, 656, 'Slasher S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xE7AcTmNTRIHsTMt1b5ktyRDheL.jpg'),
(127341, 656, 'Slasher S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yg9LgTaNylxx0m9PvSIMIwgpIxe.jpg'),
(127342, 656, 'Slasher S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9PKGVX3Iie1K5oDtCjWGTXljIIw.jpg'),
(127343, 656, 'Slasher S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zRLQHgftWplLMVqVqUKV3XnEnx4.jpg'),
(127344, 656, 'Slasher S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jjvrqBkOrCZtFnhDhpDmVT2YKZx.jpg'),
(127345, 9123, 'Tom Swift S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3RdcoHW7bUGvPmgIswSSWcDzgwm.jpg'),
(127346, 9123, 'Tom Swift S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qipLATKpZf93O71ZLc8tCcnbNGD.jpg'),
(127347, 9123, 'Tom Swift S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lDlAyCK6bsU6v5cV2zjWZvKbOlA.jpg'),
(127348, 9123, 'Tom Swift S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ofBTKoRFPFNWlFCMMmBwP3bKELz.jpg'),
(127349, 9123, 'Tom Swift S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a0T5XE9dd18R0kDabC7DhaM6ykW.jpg'),
(127350, 9123, 'Tom Swift S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cm5zYJUmIaQGXXdDzwLkzCsAeJv.jpg'),
(127351, 9123, 'Tom Swift S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/clBQ3SaKrv0k0jJtqhZrDHQKzQH.jpg'),
(127352, 9123, 'Tom Swift S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AR4HWzt95dlT0xA6KhABWoL56L.jpg'),
(127353, 9123, 'Tom Swift S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3XHlUPSceNTiWII7iWbKaqe06tM.jpg'),
(127354, 9123, 'Tom Swift S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rBcrSM76B7mfJUDRxJqCWRVC3Cm.jpg'),
(127355, 9124, 'A Influenciadora S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfMWH5Xo3oEjgoN7UQP6KzfRPoD.jpg'),
(127356, 9124, 'A Influenciadora S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfMWH5Xo3oEjgoN7UQP6KzfRPoD.jpg'),
(127357, 9124, 'A Influenciadora S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfMWH5Xo3oEjgoN7UQP6KzfRPoD.jpg'),
(127358, 9124, 'A Influenciadora S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfMWH5Xo3oEjgoN7UQP6KzfRPoD.jpg'),
(127359, 9124, 'A Influenciadora S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfMWH5Xo3oEjgoN7UQP6KzfRPoD.jpg'),
(127360, 9124, 'A Influenciadora S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfMWH5Xo3oEjgoN7UQP6KzfRPoD.jpg'),
(127361, 9124, 'A Influenciadora S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfMWH5Xo3oEjgoN7UQP6KzfRPoD.jpg'),
(127362, 9124, 'A Influenciadora S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfMWH5Xo3oEjgoN7UQP6KzfRPoD.jpg'),
(127363, 9124, 'A Influenciadora S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfMWH5Xo3oEjgoN7UQP6KzfRPoD.jpg'),
(127364, 9124, 'A Influenciadora S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfMWH5Xo3oEjgoN7UQP6KzfRPoD.jpg'),
(127365, 9124, 'A Influenciadora S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfMWH5Xo3oEjgoN7UQP6KzfRPoD.jpg'),
(127366, 9124, 'A Influenciadora S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfMWH5Xo3oEjgoN7UQP6KzfRPoD.jpg'),
(127367, 9124, 'A Influenciadora S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfMWH5Xo3oEjgoN7UQP6KzfRPoD.jpg'),
(127368, 9124, 'A Influenciadora S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/248411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfMWH5Xo3oEjgoN7UQP6KzfRPoD.jpg'),
(127369, 9124, 'A Influenciadora S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/248412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfMWH5Xo3oEjgoN7UQP6KzfRPoD.jpg'),
(127370, 9124, 'A Influenciadora S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/248413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mfMWH5Xo3oEjgoN7UQP6KzfRPoD.jpg'),
(127371, 9125, 'Sai de Baixo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iLfki4Uu39voaWiWCUNLms92UK7.jpg'),
(127372, 9125, 'Sai de Baixo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nE502HZnxdrA1sI8WJelR5EnNWc.jpg'),
(127373, 9125, 'Sai de Baixo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/htXXZHWypkjeywsHjYTKXgMcoxx.jpg'),
(127374, 9125, 'Sai de Baixo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6pCph6BxcCAErxAM8f2QldTXF0U.jpg'),
(127375, 9125, 'Sai de Baixo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7BfKL4KxuUyQQUckldyvt2zSk3R.jpg'),
(127376, 9125, 'Sai de Baixo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xaxd9cnRjUCBat3xNUNQ9T0SmPC.jpg'),
(127377, 9125, 'Sai de Baixo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c9ICFtpyZiZCYStg7GaOrEgKl9c.jpg'),
(127378, 9125, 'Sai de Baixo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sm4HkFeQOFEp7AexJQO8NfoKweS.jpg'),
(127379, 9125, 'Sai de Baixo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o9zxzHJI922tx03RnUbd3OmJnUy.jpg'),
(127380, 9125, 'Sai de Baixo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOs7ViBqGZpGGFpgd9CVZ8Gusvr.jpg'),
(127381, 9125, 'Sai de Baixo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xFoMzk5r5ksct9i7gSBsgQjNhSX.jpg'),
(127382, 9125, 'Sai de Baixo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A5Okm9IryT4LlB7h0RP8e4pnmEd.jpg'),
(127383, 9125, 'Sai de Baixo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uokz0E4iEgZLRknyhPLNGIbL9V2.jpg'),
(127384, 9125, 'Sai de Baixo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/248166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ceSBAvzKVocMDvIKwfkTjyNxGK4.jpg'),
(127385, 9125, 'Sai de Baixo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/248167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z2MRy4A6FSrhLa1nrctpidnSc2R.jpg'),
(127386, 9125, 'Sai de Baixo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/248168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yr1182q7j18Gj8RFt8ouvhFSM4B.jpg'),
(127387, 9125, 'Sai de Baixo S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/248169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vTjGrAHqVuRqNnBrt8V2RqrrRSh.jpg'),
(127388, 9125, 'Sai de Baixo S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/248170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/48uSE060eh9tyQw3I9S5xJka3Ox.jpg'),
(127389, 9125, 'Sai de Baixo S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/248171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sSnvyYWbrXwNitBm4Do3v5Y8z7K.jpg'),
(127390, 9125, 'Sai de Baixo S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/248172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vQHr36epY5kjjNRwogyyvq09JWx.jpg'),
(127391, 9125, 'Sai de Baixo S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/248173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zoNf9u2H2nAsJfGD7DWXpCPyaxb.jpg'),
(127392, 9125, 'Sai de Baixo S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/248174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dhwN4j5zIf7jJlbhU9vcTOyvT2M.jpg'),
(127393, 9125, 'Sai de Baixo S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/248175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/26QXSWn0jhQILNzWPJRpK1SUv5j.jpg'),
(127394, 9125, 'Sai de Baixo S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/248176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jcA0hwyOmR2MbcBwnYPO1lBPoBd.jpg'),
(127395, 9125, 'Sai de Baixo S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/248177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/adk6MFqHOIiHOgQ6cddhcyWbKcK.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(127396, 9125, 'Sai de Baixo S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/248178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kFwXEOguozGS2yrSIBZ73lNa1d2.jpg'),
(127397, 9125, 'Sai de Baixo S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/248179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/paBPHoSx9ri34TDMkZy0YTqodkq.jpg'),
(127398, 9125, 'Sai de Baixo S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/248180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nYqq8JywySPy04mB7ZAkw3Cosam.jpg'),
(127399, 9125, 'Sai de Baixo S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/248181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xkz0CShdtsAipxTJY4oAZEDiHPD.jpg'),
(127400, 9125, 'Sai de Baixo S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/248182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/32kfXFASZr6MU8DZCI9S6xkAJH3.jpg'),
(127401, 9125, 'Sai de Baixo S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/248183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9nKTTNgGPwf1xaH76oLKzoXHo1J.jpg'),
(127402, 9125, 'Sai de Baixo S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/248184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wrFfYxtim85J0fDhOnGB9Piqf6v.jpg'),
(127403, 9125, 'Sai de Baixo S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/248185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lSzgJcHfFKZNBFRadnRSgAsJi7D.jpg'),
(127404, 9125, 'Sai de Baixo S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/248186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/elPC3U69ePAY83DiKvoAH36a1ju.jpg'),
(127405, 9125, 'Sai de Baixo S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/248187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1zBfGwy4F4K4wIHlPd4fJOD6RQ5.jpg'),
(127406, 9125, 'Sai de Baixo S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/248188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l25CA1lNmExOmpWMs6vENAuuuHn.jpg'),
(127407, 9125, 'Sai de Baixo S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/248189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9v3rScWG2zwNtNMofQh9Ajg19fo.jpg'),
(127408, 9125, 'Sai de Baixo S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/248190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ow6578genUrv3ezSZjl0Ztnsqmj.jpg'),
(127409, 9126, 'Sai de Baixo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2pA0IRA7UItBpvqW3l6m9nWoc8e.jpg'),
(127410, 9126, 'Sai de Baixo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lx8QeO0B2DqBwWHMFqZLP4xzHUB.jpg'),
(127411, 9126, 'Sai de Baixo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xYDuCFmnnSxWIgxvNZVV6WwlPqZ.jpg'),
(127412, 9126, 'Sai de Baixo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2DzSLImWHRxaMYc2AnQz95ChgD6.jpg'),
(127413, 9126, 'Sai de Baixo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iPcMkDimPjc1p5ZEzQzgKM76vsK.jpg'),
(127414, 9126, 'Sai de Baixo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8mUpyFCK5XLGNTN2Kx44LchLVWZ.jpg'),
(127415, 9126, 'Sai de Baixo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/G9zK16eDyVzfPJDwPpK0A95Ppm.jpg'),
(127416, 9126, 'Sai de Baixo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127417, 9126, 'Sai de Baixo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127418, 9126, 'Sai de Baixo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cVkxX8dutMCqlusXhq61W8BzY7s.jpg'),
(127419, 9126, 'Sai de Baixo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lx8QeO0B2DqBwWHMFqZLP4xzHUB.jpg'),
(127420, 9126, 'Sai de Baixo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5vTPxZ57C0nBvSytCRxYjW8buLk.jpg'),
(127421, 9126, 'Sai de Baixo S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/usaJBJILJhG7zhkX9dosJWOczAS.jpg'),
(127422, 9126, 'Sai de Baixo S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/248204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sQ8gl8RJkbnAcGRQXUgCQ8IQFfY.jpg'),
(127423, 9126, 'Sai de Baixo S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/248205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1Gc6Y8be0KcZmdCgcZiwQIGYkn.jpg'),
(127424, 9126, 'Sai de Baixo S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/248206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qnkUDAdyN9G6R0CZgi1XrGgDxKo.jpg'),
(127425, 9126, 'Sai de Baixo S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/248207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127426, 9126, 'Sai de Baixo S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/248208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uGXCbCaRQ6B0VfiTAWsE7BbKjlB.jpg'),
(127427, 9126, 'Sai de Baixo S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/248209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ej7AMsPquLjkkXgSAWEKiVjA9Y6.jpg'),
(127428, 9126, 'Sai de Baixo S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/248210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oMCV7cIZbPaB5caCONh43hsjeDM.jpg'),
(127429, 9126, 'Sai de Baixo S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/248211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZEwfFhakh44KkrmrL91MlsAsRc.jpg'),
(127430, 9126, 'Sai de Baixo S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/248212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y7MKUe3rUM1uSjMaeYHSbTEOmef.jpg'),
(127431, 9126, 'Sai de Baixo S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/248213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Eq0HFAmyqjxaMIVHQOuPZgJSlL.jpg'),
(127432, 9126, 'Sai de Baixo S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/248214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWbfulTOUDXnh0Pbwr2zkPSU2D9.jpg'),
(127433, 9126, 'Sai de Baixo S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/248215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127434, 9126, 'Sai de Baixo S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/248216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127435, 9126, 'Sai de Baixo S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/248217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127436, 9126, 'Sai de Baixo S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/248218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127437, 9126, 'Sai de Baixo S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/248219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127438, 9126, 'Sai de Baixo S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/248220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127439, 9126, 'Sai de Baixo S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/248221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127440, 9126, 'Sai de Baixo S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/248222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127441, 9126, 'Sai de Baixo S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/248223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127442, 9126, 'Sai de Baixo S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/248224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127443, 9126, 'Sai de Baixo S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/248225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127444, 9126, 'Sai de Baixo S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/248226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127445, 9126, 'Sai de Baixo S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/248227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127446, 9126, 'Sai de Baixo S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/248228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127447, 9126, 'Sai de Baixo S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/248229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ekU20JPsP5bEl0HCLTJD5KmZGp5.jpg'),
(127448, 9126, 'Sai de Baixo S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/248230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127449, 9127, 'Sai de Baixo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127450, 9127, 'Sai de Baixo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127451, 9127, 'Sai de Baixo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127452, 9127, 'Sai de Baixo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127453, 9127, 'Sai de Baixo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127454, 9127, 'Sai de Baixo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127455, 9127, 'Sai de Baixo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127456, 9127, 'Sai de Baixo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127457, 9127, 'Sai de Baixo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127458, 9127, 'Sai de Baixo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127459, 9127, 'Sai de Baixo S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127460, 9127, 'Sai de Baixo S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127461, 9127, 'Sai de Baixo S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127462, 9127, 'Sai de Baixo S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/248244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127463, 9127, 'Sai de Baixo S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/248245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127464, 9127, 'Sai de Baixo S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/248246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127465, 9127, 'Sai de Baixo S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/248247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127466, 9127, 'Sai de Baixo S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/248248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127467, 9127, 'Sai de Baixo S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/248249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127468, 9127, 'Sai de Baixo S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/248250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127469, 9127, 'Sai de Baixo S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/248251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127470, 9127, 'Sai de Baixo S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/248252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127471, 9127, 'Sai de Baixo S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/248253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127472, 9127, 'Sai de Baixo S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/248254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127473, 9127, 'Sai de Baixo S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/248255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127474, 9127, 'Sai de Baixo S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/248256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127475, 9127, 'Sai de Baixo S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/248257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127476, 9127, 'Sai de Baixo S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/248258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127477, 9127, 'Sai de Baixo S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/248259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127478, 9127, 'Sai de Baixo S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/248260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127479, 9127, 'Sai de Baixo S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/248261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127480, 9127, 'Sai de Baixo S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/248262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127481, 9127, 'Sai de Baixo S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/248263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127482, 9127, 'Sai de Baixo S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/248264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127483, 9127, 'Sai de Baixo S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/248265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127484, 9127, 'Sai de Baixo S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/248266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127485, 9127, 'Sai de Baixo S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/248267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127486, 9127, 'Sai de Baixo S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/248268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127487, 9127, 'Sai de Baixo S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/248269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127488, 9127, 'Sai de Baixo S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/248270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127489, 9128, 'Sai de Baixo S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bT4BNzR8mVGh4aMQ7rXfF4GNRNT.jpg'),
(127490, 9128, 'Sai de Baixo S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hbS6kvmD0TpqtLTTEAqSGQRW3cB.jpg'),
(127491, 9128, 'Sai de Baixo S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127492, 9128, 'Sai de Baixo S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127493, 9128, 'Sai de Baixo S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bT4BNzR8mVGh4aMQ7rXfF4GNRNT.jpg'),
(127494, 9128, 'Sai de Baixo S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127495, 9128, 'Sai de Baixo S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127496, 9128, 'Sai de Baixo S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127497, 9128, 'Sai de Baixo S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127498, 9128, 'Sai de Baixo S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127499, 9128, 'Sai de Baixo S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127500, 9128, 'Sai de Baixo S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127501, 9128, 'Sai de Baixo S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127502, 9128, 'Sai de Baixo S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/248284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127503, 9128, 'Sai de Baixo S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/248285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127504, 9128, 'Sai de Baixo S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/248286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127505, 9128, 'Sai de Baixo S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/248287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127506, 9128, 'Sai de Baixo S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/248288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127507, 9128, 'Sai de Baixo S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/248289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127508, 9128, 'Sai de Baixo S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/248290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127509, 9128, 'Sai de Baixo S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/248291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127510, 9128, 'Sai de Baixo S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/248292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127511, 9128, 'Sai de Baixo S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/248293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127512, 9128, 'Sai de Baixo S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/248294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127513, 9128, 'Sai de Baixo S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/248295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127514, 9128, 'Sai de Baixo S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/248296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127515, 9128, 'Sai de Baixo S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/248297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127516, 9128, 'Sai de Baixo S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/248298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127517, 9128, 'Sai de Baixo S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/248299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127518, 9128, 'Sai de Baixo S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/248300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127519, 9128, 'Sai de Baixo S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/248301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127520, 9128, 'Sai de Baixo S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/248302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127521, 9128, 'Sai de Baixo S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/248303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127522, 9128, 'Sai de Baixo S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/248304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127523, 9128, 'Sai de Baixo S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/248305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127524, 9128, 'Sai de Baixo S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/248306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127525, 9128, 'Sai de Baixo S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/248307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127526, 9128, 'Sai de Baixo S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/248308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127527, 9128, 'Sai de Baixo S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/248309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127528, 9128, 'Sai de Baixo S04 E40', 'http://sinalprivado.info:80/series/1533784/1533784/248310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127529, 9129, 'Sai de Baixo S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127530, 9129, 'Sai de Baixo S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127531, 9129, 'Sai de Baixo S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127532, 9129, 'Sai de Baixo S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127533, 9129, 'Sai de Baixo S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127534, 9129, 'Sai de Baixo S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127535, 9129, 'Sai de Baixo S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127536, 9129, 'Sai de Baixo S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127537, 9129, 'Sai de Baixo S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127538, 9129, 'Sai de Baixo S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127539, 9129, 'Sai de Baixo S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127540, 9129, 'Sai de Baixo S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127541, 9129, 'Sai de Baixo S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127542, 9129, 'Sai de Baixo S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/248324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127543, 9129, 'Sai de Baixo S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/248325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127544, 9129, 'Sai de Baixo S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/248326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127545, 9129, 'Sai de Baixo S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/248327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127546, 9129, 'Sai de Baixo S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/248328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127547, 9129, 'Sai de Baixo S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/248329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127548, 9129, 'Sai de Baixo S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/248330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127549, 9129, 'Sai de Baixo S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/248331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127550, 9129, 'Sai de Baixo S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/248332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127551, 9129, 'Sai de Baixo S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/248333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127552, 9129, 'Sai de Baixo S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/248334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127553, 9129, 'Sai de Baixo S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/248335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127554, 9129, 'Sai de Baixo S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/248336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127555, 9129, 'Sai de Baixo S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/248337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127556, 9129, 'Sai de Baixo S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/248338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127557, 9129, 'Sai de Baixo S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/248339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127558, 9129, 'Sai de Baixo S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/248340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127559, 9129, 'Sai de Baixo S05 E31', 'http://sinalprivado.info:80/series/1533784/1533784/248341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127560, 9129, 'Sai de Baixo S05 E32', 'http://sinalprivado.info:80/series/1533784/1533784/248342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127561, 9129, 'Sai de Baixo S05 E33', 'http://sinalprivado.info:80/series/1533784/1533784/248343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127562, 9129, 'Sai de Baixo S05 E34', 'http://sinalprivado.info:80/series/1533784/1533784/248344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127563, 9129, 'Sai de Baixo S05 E35', 'http://sinalprivado.info:80/series/1533784/1533784/248345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127564, 9129, 'Sai de Baixo S05 E36', 'http://sinalprivado.info:80/series/1533784/1533784/248346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127565, 9129, 'Sai de Baixo S05 E37', 'http://sinalprivado.info:80/series/1533784/1533784/248347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127566, 9129, 'Sai de Baixo S05 E38', 'http://sinalprivado.info:80/series/1533784/1533784/248348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127567, 9129, 'Sai de Baixo S05 E39', 'http://sinalprivado.info:80/series/1533784/1533784/248349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127568, 9130, 'Sai de Baixo S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127569, 9130, 'Sai de Baixo S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127570, 9130, 'Sai de Baixo S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127571, 9130, 'Sai de Baixo S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127572, 9130, 'Sai de Baixo S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127573, 9130, 'Sai de Baixo S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127574, 9130, 'Sai de Baixo S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127575, 9130, 'Sai de Baixo S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127576, 9130, 'Sai de Baixo S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127577, 9130, 'Sai de Baixo S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127578, 9130, 'Sai de Baixo S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127579, 9130, 'Sai de Baixo S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127580, 9130, 'Sai de Baixo S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/248362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127581, 9130, 'Sai de Baixo S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/248363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127582, 9130, 'Sai de Baixo S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/248364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127583, 9130, 'Sai de Baixo S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/248365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127584, 9130, 'Sai de Baixo S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/248366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127585, 9130, 'Sai de Baixo S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/248367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127586, 9130, 'Sai de Baixo S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/248368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127587, 9130, 'Sai de Baixo S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/248369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127588, 9130, 'Sai de Baixo S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/248370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127589, 9130, 'Sai de Baixo S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/248371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127590, 9130, 'Sai de Baixo S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/248372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127591, 9130, 'Sai de Baixo S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/248373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127592, 9130, 'Sai de Baixo S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/248374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127593, 9130, 'Sai de Baixo S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/248375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127594, 9130, 'Sai de Baixo S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/248376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127595, 9130, 'Sai de Baixo S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/248377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127596, 9130, 'Sai de Baixo S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/248378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127597, 9130, 'Sai de Baixo S06 E30', 'http://sinalprivado.info:80/series/1533784/1533784/248379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127598, 9130, 'Sai de Baixo S06 E31', 'http://sinalprivado.info:80/series/1533784/1533784/248380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127599, 9130, 'Sai de Baixo S06 E32', 'http://sinalprivado.info:80/series/1533784/1533784/248381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127600, 9131, 'Sai de Baixo S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127601, 9131, 'Sai de Baixo S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127602, 9131, 'Sai de Baixo S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127603, 9131, 'Sai de Baixo S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127604, 9131, 'Sai de Baixo S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127605, 9131, 'Sai de Baixo S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/248387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127606, 9131, 'Sai de Baixo S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/248388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127607, 9131, 'Sai de Baixo S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/248389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127608, 9131, 'Sai de Baixo S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/248390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127609, 9131, 'Sai de Baixo S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/248391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127610, 9131, 'Sai de Baixo S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/248392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127611, 9131, 'Sai de Baixo S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/248393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127612, 9132, 'Sai de Baixo S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127613, 9132, 'Sai de Baixo S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127614, 9132, 'Sai de Baixo S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127615, 9132, 'Sai de Baixo S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ZehoCj2uuHGHn9Xz1lZ3KfkmZ.jpg'),
(127616, 4957, 'Yu Yu Hakusho S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/248148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zauWAQiP3rxrkNubwDY8vFAsTvx.jpg'),
(127617, 4957, 'Yu Yu Hakusho S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/248149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cwqUt9bMKWcUDvlFeDcqPom29O1.jpg'),
(127618, 4957, 'Yu Yu Hakusho S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/248150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmqYUPz0uL2S7lPjNpfALchLrYC.jpg'),
(127619, 4957, 'Yu Yu Hakusho S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/248151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a7WmQt4pMLwAR1jcOiYXskzgmso.jpg'),
(127620, 4957, 'Yu Yu Hakusho S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/248152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9UZwmD248h5yuhbAn6a6Kc2b1CF.jpg'),
(127621, 9133, 'Ben 10: Supremacia Alienígena S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xkA5U7fmhRDZ5L8kT5mZRTdHylB.jpg'),
(127622, 9133, 'Ben 10: Supremacia Alienígena S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nwuQHD4uoLj6tMO0CTzcBTNPPa8.jpg'),
(127623, 9133, 'Ben 10: Supremacia Alienígena S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSjiObFxCVS4zrPLrYxFw6AgO00.jpg'),
(127624, 9133, 'Ben 10: Supremacia Alienígena S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l1bOTYIxlCCW8JQPrZv5JQXZ7u3.jpg'),
(127625, 9133, 'Ben 10: Supremacia Alienígena S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqvzNJNboirf069c9m9N22VwtH8.jpg'),
(127626, 9133, 'Ben 10: Supremacia Alienígena S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u8r4h5BHOmY4n2CT2XZBiKHlfGA.jpg'),
(127627, 9133, 'Ben 10: Supremacia Alienígena S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/krVGW59iY7agSZQRacwqJ5nz4Gt.jpg'),
(127628, 9133, 'Ben 10: Supremacia Alienígena S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/99g4psCcH7AQEutvlOudiWpvcxK.jpg'),
(127629, 9133, 'Ben 10: Supremacia Alienígena S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uyW5YyQg829Oz3nd0sNydfIQ8ZP.jpg'),
(127630, 9133, 'Ben 10: Supremacia Alienígena S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9DW9o0KrT1OmFPy51oqvI17WYib.jpg'),
(127631, 9133, 'Ben 10: Supremacia Alienígena S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bNiblD60jztSPPXzEduFnBBXkoK.jpg'),
(127632, 9133, 'Ben 10: Supremacia Alienígena S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mBMfC4A5YLTVUggp6Z5pUlE6Dhn.jpg'),
(127633, 9133, 'Ben 10: Supremacia Alienígena S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yL4eahtOWmPnCTHZRX8V9xxC3Cc.jpg'),
(127634, 9133, 'Ben 10: Supremacia Alienígena S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/254082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kYhWvzn8wjQUhbudQGPijIc9YW7.jpg'),
(127635, 9133, 'Ben 10: Supremacia Alienígena S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/254083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dEjXpJy0eK4bbMzb1qPHG10DAcM.jpg'),
(127636, 9133, 'Ben 10: Supremacia Alienígena S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/254084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rzU4SaluuxkdDc36RPGvlrG92Q4.jpg'),
(127637, 9133, 'Ben 10: Supremacia Alienígena S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/254085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jHNJVCpe0kjwSIgDtyR3jI49EL6.jpg'),
(127638, 9133, 'Ben 10: Supremacia Alienígena S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/254086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AdxYiIhUmqVe5kqPTq9mV7C0mXT.jpg'),
(127639, 9133, 'Ben 10: Supremacia Alienígena S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/254087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hLOCir1hIwIz6hUN6hRE7oYdHbJ.jpg'),
(127640, 9133, 'Ben 10: Supremacia Alienígena S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/254088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6VzvwoUeYYtlqS6p6FlPxTviATp.jpg'),
(127641, 9134, 'Ben 10: Supremacia Alienígena S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udBU7ySpRuqRgAmVktXTe8J3Ay0.jpg'),
(127642, 9134, 'Ben 10: Supremacia Alienígena S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v6cVvfJqRomRtZv8Ju43SbVqBGU.jpg'),
(127643, 9134, 'Ben 10: Supremacia Alienígena S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OpVJN1yjEZ80u6OhL06aLxjlit.jpg'),
(127644, 9134, 'Ben 10: Supremacia Alienígena S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2g4H8nxwdqt4SoyEnBdqU2GbHgI.jpg'),
(127645, 9134, 'Ben 10: Supremacia Alienígena S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p429m686XMDVW43UeIaJqOvwKKb.jpg'),
(127646, 9134, 'Ben 10: Supremacia Alienígena S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dYs2nBlnjrwOa8hjrN3flhFDlEi.jpg'),
(127647, 9134, 'Ben 10: Supremacia Alienígena S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cJc7dqnn0eIu3yEUh3STfwRNvev.jpg'),
(127648, 9134, 'Ben 10: Supremacia Alienígena S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uwcxsRyWd9iYLDOoG9DKeKzIHuM.jpg'),
(127649, 9134, 'Ben 10: Supremacia Alienígena S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AkzS61liUzqmGSdh5jjqDIGcvNT.jpg'),
(127650, 9134, 'Ben 10: Supremacia Alienígena S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5WFd4ybLPmksFEvsAJ6Q9iLBZs2.jpg'),
(127651, 9134, 'Ben 10: Supremacia Alienígena S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m6CPxwyZnCljFOXTZ78ELzfmLhS.jpg'),
(127652, 9134, 'Ben 10: Supremacia Alienígena S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o38qVrkwIROIYOh7ZYnidHnnCKJ.jpg'),
(127653, 9135, 'Ben 10: Supremacia Alienígena S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kP5ymRF6kFvox4CFJCEBK0NnSLq.jpg'),
(127654, 9135, 'Ben 10: Supremacia Alienígena S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kP5ymRF6kFvox4CFJCEBK0NnSLq.jpg'),
(127655, 9135, 'Ben 10: Supremacia Alienígena S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kP5ymRF6kFvox4CFJCEBK0NnSLq.jpg'),
(127656, 9135, 'Ben 10: Supremacia Alienígena S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kP5ymRF6kFvox4CFJCEBK0NnSLq.jpg'),
(127657, 9135, 'Ben 10: Supremacia Alienígena S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kP5ymRF6kFvox4CFJCEBK0NnSLq.jpg'),
(127658, 9135, 'Ben 10: Supremacia Alienígena S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kP5ymRF6kFvox4CFJCEBK0NnSLq.jpg'),
(127659, 9135, 'Ben 10: Supremacia Alienígena S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kP5ymRF6kFvox4CFJCEBK0NnSLq.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(127660, 9135, 'Ben 10: Supremacia Alienígena S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kP5ymRF6kFvox4CFJCEBK0NnSLq.jpg'),
(127661, 9135, 'Ben 10: Supremacia Alienígena S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kP5ymRF6kFvox4CFJCEBK0NnSLq.jpg'),
(127662, 9135, 'Ben 10: Supremacia Alienígena S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kP5ymRF6kFvox4CFJCEBK0NnSLq.jpg'),
(127663, 9135, 'Ben 10: Supremacia Alienígena S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kP5ymRF6kFvox4CFJCEBK0NnSLq.jpg'),
(127664, 9135, 'Ben 10: Supremacia Alienígena S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kP5ymRF6kFvox4CFJCEBK0NnSLq.jpg'),
(127665, 9135, 'Ben 10: Supremacia Alienígena S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kP5ymRF6kFvox4CFJCEBK0NnSLq.jpg'),
(127666, 9135, 'Ben 10: Supremacia Alienígena S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/254114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kP5ymRF6kFvox4CFJCEBK0NnSLq.jpg'),
(127667, 9135, 'Ben 10: Supremacia Alienígena S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/254115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kP5ymRF6kFvox4CFJCEBK0NnSLq.jpg'),
(127668, 9135, 'Ben 10: Supremacia Alienígena S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/254116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kP5ymRF6kFvox4CFJCEBK0NnSLq.jpg'),
(127669, 9135, 'Ben 10: Supremacia Alienígena S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/254117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kP5ymRF6kFvox4CFJCEBK0NnSLq.jpg'),
(127670, 9135, 'Ben 10: Supremacia Alienígena S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/254118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kP5ymRF6kFvox4CFJCEBK0NnSLq.jpg'),
(127671, 9135, 'Ben 10: Supremacia Alienígena S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/254119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kP5ymRF6kFvox4CFJCEBK0NnSLq.jpg'),
(127672, 9135, 'Ben 10: Supremacia Alienígena S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/254120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kP5ymRF6kFvox4CFJCEBK0NnSLq.jpg'),
(127673, 9136, 'O11ZE S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/17uW6WyQjYeW5DNHlVHwWW07THN.jpg'),
(127674, 9136, 'O11ZE S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z3tCIZ4s0tEshrpAs5uS3fCALRp.jpg'),
(127675, 9136, 'O11ZE S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qUw3pNU5yCwtFL4p4o4hbNrFK49.jpg'),
(127676, 9136, 'O11ZE S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3nxBQ5A7SYgU1uLD1q0dXUIcA5k.jpg'),
(127677, 9136, 'O11ZE S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yhh35Xp7jTxOIdejWGGBAUd4Elp.jpg'),
(127678, 9136, 'O11ZE S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ohp3DA6UNXZjqZAn2eSdzsvOPLR.jpg'),
(127679, 9136, 'O11ZE S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8a9b2SCx3yLqaRuWdYGbM9iiQwQ.jpg'),
(127680, 9136, 'O11ZE S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hGjCU6lMVSgz7PR1bFiJQqkb6lg.jpg'),
(127681, 9136, 'O11ZE S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2gN81BlKq8Zvhkqz6nnCsDwnHjt.jpg'),
(127682, 9136, 'O11ZE S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5wgPocgSz06IUG0AsKnoxD1aNme.jpg'),
(127683, 9136, 'O11ZE S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oIVgFY3vlEU1q3eegPeBsjKOecx.jpg'),
(127684, 9136, 'O11ZE S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4mKmy2ynly603L63LT0aaV6pmi8.jpg'),
(127685, 9136, 'O11ZE S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/biBC5GhuVFWPAmtD5Bcz1D33yMq.jpg'),
(127686, 9136, 'O11ZE S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/254002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vco1mM2O6J64QLJUML7rmkSPKDK.jpg'),
(127687, 9136, 'O11ZE S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/254003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBv3WsQN7R5eKksDT5EeVdlyYYq.jpg'),
(127688, 9136, 'O11ZE S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/254004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Qxz423hzVKRu9TvbeV5kysGaAS.jpg'),
(127689, 9136, 'O11ZE S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/254005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dNbBsbt1zn7xksuGCINMFDRk2iu.jpg'),
(127690, 9136, 'O11ZE S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/254006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bQhBjYau1Wvnph9oGgAF5EdKV2o.jpg'),
(127691, 9136, 'O11ZE S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/254007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dP3CDTa07wsvETNaygFqzCZAopf.jpg'),
(127692, 9136, 'O11ZE S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/254008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xApEoQQgLB1S4cn6gmtPfhs3wDd.jpg'),
(127693, 9136, 'O11ZE S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/254009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2FQbvBN0HshLr0ftaFvkTmLfabt.jpg'),
(127694, 9136, 'O11ZE S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/254010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dwYYp9XJe7fXXsD6DJApkCrTAZm.jpg'),
(127695, 9136, 'O11ZE S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/254011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pV2oAhrIsvGSAr31vjclaQtHuS4.jpg'),
(127696, 9136, 'O11ZE S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/254012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nY8bExRu22j5yUMuQztXDeafvdu.jpg'),
(127697, 9136, 'O11ZE S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/254013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tgn0oPuBh8sByWBcwNCYaJ9C7KR.jpg'),
(127698, 9136, 'O11ZE S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/254014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vvQS79YDww2YwG5BeffonHwYFN8.jpg'),
(127699, 9136, 'O11ZE S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/254015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bYXHG2gZTkxE1VJuAnBNpPXjOW8.jpg'),
(127700, 9136, 'O11ZE S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/254016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/knKM52MPwBiDs1h2Qkf21nrRzxw.jpg'),
(127701, 9136, 'O11ZE S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/254017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eb5LTUQislLEj8EitdOo1EYLpin.jpg'),
(127702, 9136, 'O11ZE S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/254018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nUJwLZRGcfVyeWRLFqxK4FIzrAe.jpg'),
(127703, 9136, 'O11ZE S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/254019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eBNPcxkwWU0B6QdIMkmTvSwBiFY.jpg'),
(127704, 9136, 'O11ZE S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/254020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qmrv1Zz47EPbxFTTqLqKnNrAInV.jpg'),
(127705, 9136, 'O11ZE S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/254021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yyJTBxT5sAlX5wT0TwoU6A9YYkc.jpg'),
(127706, 9136, 'O11ZE S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/254022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aA6A4jtCgKj6GWjgvZYuZ7oVsOS.jpg'),
(127707, 9136, 'O11ZE S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/254023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hOnmIYzjnwVIvNrzG0VErDSyNWD.jpg'),
(127708, 9136, 'O11ZE S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/254024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yRjDfEGrfoX1X4CkCSuRrGOg115.jpg'),
(127709, 9136, 'O11ZE S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/254025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ck7ULqh7C8Zn9p5rWhoqtfpUQp5.jpg'),
(127710, 9136, 'O11ZE S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/254026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6oUBj9WvCPAwhIIhXckhWq9kC0N.jpg'),
(127711, 9136, 'O11ZE S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/254027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yYgjuyKHv3tpxNmVU83Y3G6hXSp.jpg'),
(127712, 9136, 'O11ZE S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/254028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yESg4VEdFh1iUGG79ktTZEuA21v.jpg'),
(127713, 9136, 'O11ZE S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/254029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1mylrZETxaOOvdvWjR2NMkWp88X.jpg'),
(127714, 9136, 'O11ZE S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/254030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vHMy3UMFu8dtYaOpnCrvxDR2t2X.jpg'),
(127715, 9136, 'O11ZE S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/254031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ag714thhrEC9vy63QTEgWTPl10q.jpg'),
(127716, 9136, 'O11ZE S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/254032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3MycZ5R9vCU2vvW0mhfMn9RVnV.jpg'),
(127717, 9136, 'O11ZE S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/254033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1C1gX06HJJQVXyVntJdYqPY7jAX.jpg'),
(127718, 9136, 'O11ZE S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/254034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bo7WOrFe1nMjF3apMu97mSXj4jg.jpg'),
(127719, 9136, 'O11ZE S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/254035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2NPzfX3uJqehMNZw2d7PsVTx8iE.jpg'),
(127720, 9136, 'O11ZE S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/254036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wxFdYlD2RZsQxlxHru4pcLh2H1P.jpg'),
(127721, 9136, 'O11ZE S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/254037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1MEZhpLP1pFJtj5h7ZZ017RdZdZ.jpg'),
(127722, 9136, 'O11ZE S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/254038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gjRh4KZBp251HYUtJaN8jYkPDaE.jpg'),
(127723, 9136, 'O11ZE S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/254039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/frsGhiP4YewePgW2ySEvjmmnUEf.jpg'),
(127724, 9136, 'O11ZE S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/254040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mQ7JsOB1Zttx7V2rn6LIAhZJUPH.jpg'),
(127725, 9136, 'O11ZE S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/254041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yVN5tTvHNFP8pao8atOS48XYPAA.jpg'),
(127726, 9136, 'O11ZE S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/254042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7LQqUaHzblR3gmjBe1SStzJUEqY.jpg'),
(127727, 9136, 'O11ZE S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/254043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gskThG91H1yVYx4e7gWhqS6a78w.jpg'),
(127728, 9136, 'O11ZE S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/254044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ZG77dMvcSeu1AIINl3p3KP79iZ.jpg'),
(127729, 9136, 'O11ZE S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/254045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4LV699klEDYT6mzTx7BMNev85BZ.jpg'),
(127730, 9136, 'O11ZE S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/254046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gPQB0GPpE6jgSAiY5iq2VJpn29E.jpg'),
(127731, 9136, 'O11ZE S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/254047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b3NzBm7Xgt4OrGknhpVhgEkDKPH.jpg'),
(127732, 9136, 'O11ZE S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/254048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gFFNmAvS129I3P7EfhEoMYl4379.jpg'),
(127733, 9136, 'O11ZE S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/254049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ruQPN3OMYJcooWr9vP7gKtcAb01.jpg'),
(127734, 9136, 'O11ZE S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/254050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzYfUOupElmC4kNCHAdNSsqDeZb.jpg'),
(127735, 9136, 'O11ZE S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/254051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gsKqQ1YaD7J3PsurQkOKVpVE1fi.jpg'),
(127736, 9136, 'O11ZE S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/254052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFkOySeZ92UnwrMzvPYe5vlbkyC.jpg'),
(127737, 9136, 'O11ZE S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/254053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qlReEGmnUzMEUlwoABZI15j1XCc.jpg'),
(127738, 9136, 'O11ZE S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/254054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fSdnrtDN0ZFHNtgNPYiqGS6xxup.jpg'),
(127739, 9136, 'O11ZE S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/254055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9crhM4AwmN9Am9OFAmT4ftcA4su.jpg'),
(127740, 9136, 'O11ZE S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/254056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/knBgmLjL3lAVzDS61M8CJGwBgWJ.jpg'),
(127741, 9136, 'O11ZE S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/254057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1zOTEaqVWPA244JRJhXC9jF3cz.jpg'),
(127742, 9136, 'O11ZE S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/254058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fE3kAWrklouXEGHGT6a54KkiMGd.jpg'),
(127743, 9136, 'O11ZE S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/254059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9CaI0KuQF6w1zXgBFzdAYDFHXz1.jpg'),
(127744, 9136, 'O11ZE S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/254060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zDEoYYmQGTAzi8CgjVIxQyzQC51.jpg'),
(127745, 9136, 'O11ZE S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/254061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vTi12sKxuTu5eoys9bNcveCaElv.jpg'),
(127746, 9136, 'O11ZE S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/254062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jmRucOOztBoWypeWN3sTcoGRppD.jpg'),
(127747, 9136, 'O11ZE S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/254063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kEOiYbjGwh16Q5HrvLKpJvtRAeq.jpg'),
(127748, 9136, 'O11ZE S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/254064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dHWhF99u8tegylr1jatPNgqDbKD.jpg'),
(127749, 9136, 'O11ZE S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/254065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9qryJI1bqFa2ifjrbXalq4eNN8N.jpg'),
(127750, 9136, 'O11ZE S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/254066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wPigydT5BcEwhhXn7qTEJFGMhK1.jpg'),
(127751, 9136, 'O11ZE S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/254067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cjIwQpLb3aZuQcCCryxcTZLfI8j.jpg'),
(127752, 9136, 'O11ZE S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/254068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ff216FMqomLK61yGroEy9I0OW1Z.jpg'),
(127753, 9137, 'O11ZE S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/869139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127754, 9137, 'O11ZE S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/869140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127755, 9137, 'O11ZE S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/869141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127756, 9137, 'O11ZE S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/869142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127757, 9137, 'O11ZE S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/869143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127758, 9137, 'O11ZE S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/869144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127759, 9137, 'O11ZE S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/869145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127760, 9137, 'O11ZE S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/869146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127761, 9137, 'O11ZE S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/869147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127762, 9137, 'O11ZE S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/869148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127763, 9137, 'O11ZE S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/869149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127764, 9137, 'O11ZE S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/869150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127765, 9137, 'O11ZE S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/869151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127766, 9137, 'O11ZE S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/869152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127767, 9137, 'O11ZE S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/869153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127768, 9137, 'O11ZE S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/869154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127769, 9137, 'O11ZE S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/869155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127770, 9137, 'O11ZE S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/869156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127771, 9137, 'O11ZE S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/869157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127772, 9137, 'O11ZE S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/869158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127773, 9137, 'O11ZE S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/869159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127774, 9137, 'O11ZE S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/869160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127775, 9137, 'O11ZE S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/869161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127776, 9137, 'O11ZE S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/869162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127777, 9137, 'O11ZE S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/869163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127778, 9137, 'O11ZE S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/869164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127779, 9137, 'O11ZE S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/869165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127780, 9137, 'O11ZE S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/869166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127781, 9137, 'O11ZE S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/869167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127782, 9137, 'O11ZE S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/869168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127783, 9137, 'O11ZE S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/869169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127784, 9137, 'O11ZE S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/869170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127785, 9137, 'O11ZE S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/869171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127786, 9137, 'O11ZE S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/869172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127787, 9137, 'O11ZE S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/869173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127788, 9137, 'O11ZE S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/869174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127789, 9137, 'O11ZE S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/869175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127790, 9137, 'O11ZE S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/869176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127791, 9137, 'O11ZE S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/869177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127792, 9137, 'O11ZE S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/869178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127793, 9137, 'O11ZE S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/869179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127794, 9137, 'O11ZE S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/869180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127795, 9137, 'O11ZE S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/869181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127796, 9137, 'O11ZE S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/869182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127797, 9137, 'O11ZE S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/869183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127798, 9137, 'O11ZE S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/869184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127799, 9137, 'O11ZE S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/869185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127800, 9137, 'O11ZE S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/869186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127801, 9137, 'O11ZE S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/869187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127802, 9137, 'O11ZE S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/869188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127803, 9137, 'O11ZE S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/869189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127804, 9137, 'O11ZE S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/869190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127805, 9137, 'O11ZE S02 E53', 'http://sinalprivado.info:80/series/1533784/1533784/869191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127806, 9137, 'O11ZE S02 E54', 'http://sinalprivado.info:80/series/1533784/1533784/869192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127807, 9137, 'O11ZE S02 E55', 'http://sinalprivado.info:80/series/1533784/1533784/869193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127808, 9137, 'O11ZE S02 E56', 'http://sinalprivado.info:80/series/1533784/1533784/869194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127809, 9137, 'O11ZE S02 E57', 'http://sinalprivado.info:80/series/1533784/1533784/869195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127810, 9137, 'O11ZE S02 E58', 'http://sinalprivado.info:80/series/1533784/1533784/869196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127811, 9137, 'O11ZE S02 E59', 'http://sinalprivado.info:80/series/1533784/1533784/869197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127812, 9137, 'O11ZE S02 E60', 'http://sinalprivado.info:80/series/1533784/1533784/869198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127813, 9137, 'O11ZE S02 E61', 'http://sinalprivado.info:80/series/1533784/1533784/869199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127814, 9137, 'O11ZE S02 E62', 'http://sinalprivado.info:80/series/1533784/1533784/869200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127815, 9137, 'O11ZE S02 E63', 'http://sinalprivado.info:80/series/1533784/1533784/869201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127816, 9137, 'O11ZE S02 E64', 'http://sinalprivado.info:80/series/1533784/1533784/869202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127817, 9137, 'O11ZE S02 E65', 'http://sinalprivado.info:80/series/1533784/1533784/869203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127818, 9137, 'O11ZE S02 E66', 'http://sinalprivado.info:80/series/1533784/1533784/869204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127819, 9137, 'O11ZE S02 E67', 'http://sinalprivado.info:80/series/1533784/1533784/869205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127820, 9137, 'O11ZE S02 E68', 'http://sinalprivado.info:80/series/1533784/1533784/869206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127821, 9137, 'O11ZE S02 E69', 'http://sinalprivado.info:80/series/1533784/1533784/869207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127822, 9137, 'O11ZE S02 E70', 'http://sinalprivado.info:80/series/1533784/1533784/869208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127823, 9137, 'O11ZE S02 E71', 'http://sinalprivado.info:80/series/1533784/1533784/869209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127824, 9137, 'O11ZE S02 E72', 'http://sinalprivado.info:80/series/1533784/1533784/869210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127825, 9137, 'O11ZE S02 E73', 'http://sinalprivado.info:80/series/1533784/1533784/869211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127826, 9137, 'O11ZE S02 E74', 'http://sinalprivado.info:80/series/1533784/1533784/869212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127827, 9137, 'O11ZE S02 E75', 'http://sinalprivado.info:80/series/1533784/1533784/869213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127828, 9137, 'O11ZE S02 E76', 'http://sinalprivado.info:80/series/1533784/1533784/869214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127829, 9137, 'O11ZE S02 E77', 'http://sinalprivado.info:80/series/1533784/1533784/869215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127830, 9137, 'O11ZE S02 E78', 'http://sinalprivado.info:80/series/1533784/1533784/869216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127831, 9137, 'O11ZE S02 E79', 'http://sinalprivado.info:80/series/1533784/1533784/869217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127832, 9137, 'O11ZE S02 E80', 'http://sinalprivado.info:80/series/1533784/1533784/869218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127833, 9138, 'O11ZE S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/871789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127834, 9138, 'O11ZE S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/871790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127835, 9138, 'O11ZE S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/871791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127836, 9138, 'O11ZE S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/871792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127837, 9138, 'O11ZE S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/871793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127838, 9138, 'O11ZE S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/871794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127839, 9138, 'O11ZE S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/871795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127840, 9138, 'O11ZE S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/871796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127841, 9138, 'O11ZE S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/871797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127842, 9138, 'O11ZE S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/871798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127843, 9138, 'O11ZE S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/871799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127844, 9138, 'O11ZE S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/871800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127845, 9138, 'O11ZE S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/871801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127846, 9138, 'O11ZE S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/871802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127847, 9138, 'O11ZE S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/871803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127848, 9138, 'O11ZE S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/871804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127849, 9138, 'O11ZE S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/871805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127850, 9138, 'O11ZE S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/871806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127851, 9138, 'O11ZE S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/871807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127852, 9138, 'O11ZE S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/871808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127853, 9138, 'O11ZE S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/871809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127854, 9138, 'O11ZE S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/871810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127855, 9138, 'O11ZE S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/871811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127856, 9138, 'O11ZE S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/871812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127857, 9138, 'O11ZE S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/871813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127858, 9138, 'O11ZE S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/871814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127859, 9138, 'O11ZE S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/871815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127860, 9138, 'O11ZE S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/871816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127861, 9138, 'O11ZE S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/871817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127862, 9138, 'O11ZE S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/871818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127863, 9138, 'O11ZE S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/871819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127864, 9138, 'O11ZE S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/871820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127865, 9138, 'O11ZE S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/871821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127866, 9138, 'O11ZE S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/871822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127867, 9138, 'O11ZE S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/871823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127868, 9138, 'O11ZE S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/871824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127869, 9138, 'O11ZE S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/871825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127870, 9138, 'O11ZE S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/871826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127871, 9138, 'O11ZE S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/871827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127872, 9138, 'O11ZE S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/871828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127873, 9138, 'O11ZE S03 E41', 'http://sinalprivado.info:80/series/1533784/1533784/871829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127874, 9138, 'O11ZE S03 E42', 'http://sinalprivado.info:80/series/1533784/1533784/871830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127875, 9138, 'O11ZE S03 E43', 'http://sinalprivado.info:80/series/1533784/1533784/871831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127876, 9138, 'O11ZE S03 E44', 'http://sinalprivado.info:80/series/1533784/1533784/871832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127877, 9138, 'O11ZE S03 E45', 'http://sinalprivado.info:80/series/1533784/1533784/871833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127878, 9138, 'O11ZE S03 E46', 'http://sinalprivado.info:80/series/1533784/1533784/871834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127879, 9138, 'O11ZE S03 E47', 'http://sinalprivado.info:80/series/1533784/1533784/871835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127880, 9138, 'O11ZE S03 E48', 'http://sinalprivado.info:80/series/1533784/1533784/871836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127881, 9138, 'O11ZE S03 E49', 'http://sinalprivado.info:80/series/1533784/1533784/871837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127882, 9138, 'O11ZE S03 E50', 'http://sinalprivado.info:80/series/1533784/1533784/871838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127883, 9138, 'O11ZE S03 E51', 'http://sinalprivado.info:80/series/1533784/1533784/871839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127884, 9138, 'O11ZE S03 E52', 'http://sinalprivado.info:80/series/1533784/1533784/871840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127885, 9138, 'O11ZE S03 E53', 'http://sinalprivado.info:80/series/1533784/1533784/871841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127886, 9138, 'O11ZE S03 E54', 'http://sinalprivado.info:80/series/1533784/1533784/871842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127887, 9138, 'O11ZE S03 E55', 'http://sinalprivado.info:80/series/1533784/1533784/871843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127888, 9138, 'O11ZE S03 E56', 'http://sinalprivado.info:80/series/1533784/1533784/871844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127889, 9138, 'O11ZE S03 E57', 'http://sinalprivado.info:80/series/1533784/1533784/871845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127890, 9138, 'O11ZE S03 E58', 'http://sinalprivado.info:80/series/1533784/1533784/871846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127891, 9138, 'O11ZE S03 E59', 'http://sinalprivado.info:80/series/1533784/1533784/871847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127892, 9138, 'O11ZE S03 E60', 'http://sinalprivado.info:80/series/1533784/1533784/871848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5SLwlAinusyXIr6sWYhuPpCDfq0.jpg'),
(127893, 9139, 'Ah o Natal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gVVN9y8LahNU69tNqKGJzZKMuXQ.jpg'),
(127894, 9139, 'Ah o Natal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nURDj5SdxUG3Rdcq005QZpaASTE.jpg'),
(127895, 9139, 'Ah o Natal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gxFaztJEwJd2DsxoZNOzceIjiEm.jpg'),
(127896, 9139, 'Ah o Natal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q5hteNnAk15wc3eG550yeEc9MbY.jpg'),
(127897, 9139, 'Ah o Natal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2r5rMKMQIJT8RegJGeI4HJ9BQfX.jpg'),
(127898, 9139, 'Ah o Natal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8NhU6N6ncqxnXPz2R6KHYrS2fMx.jpg'),
(127899, 9140, 'Baby Vampire Blues [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c8NohRLXdYnAC7z6XOEumTMoVSn.jpg'),
(127900, 9140, 'Baby Vampire Blues [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c8NohRLXdYnAC7z6XOEumTMoVSn.jpg'),
(127901, 9140, 'Baby Vampire Blues [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c8NohRLXdYnAC7z6XOEumTMoVSn.jpg'),
(127902, 9140, 'Baby Vampire Blues [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c8NohRLXdYnAC7z6XOEumTMoVSn.jpg'),
(127903, 9140, 'Baby Vampire Blues [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c8NohRLXdYnAC7z6XOEumTMoVSn.jpg'),
(127904, 9140, 'Baby Vampire Blues [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c8NohRLXdYnAC7z6XOEumTMoVSn.jpg'),
(127905, 9140, 'Baby Vampire Blues [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c8NohRLXdYnAC7z6XOEumTMoVSn.jpg'),
(127906, 9140, 'Baby Vampire Blues [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c8NohRLXdYnAC7z6XOEumTMoVSn.jpg'),
(127907, 9141, 'Carol e o Fim do Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkK6Pqg4bU6RcabFEtqZv5m1jsv.jpg'),
(127908, 9141, 'Carol e o Fim do Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sJkPfuVaJGhxdLhQnS0MiNzptpM.jpg'),
(127909, 9141, 'Carol e o Fim do Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3wKUfUPtF8tUppVbuGYKeiiGxWj.jpg'),
(127910, 9141, 'Carol e o Fim do Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7vYyyKyChZOFxMqBg5jqJrfaAM.jpg'),
(127911, 9141, 'Carol e o Fim do Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvTqkXKybJOSTblaU9TRuee9fnu.jpg'),
(127912, 9141, 'Carol e o Fim do Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hrGmoBduIhE3E2ji3yIN90bU71T.jpg'),
(127913, 9141, 'Carol e o Fim do Mundo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nGwUho9st78fF4m4y5QL9c9qFRx.jpg'),
(127914, 9141, 'Carol e o Fim do Mundo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpgEkMDnUPekBmETcL911YVwzQQ.jpg'),
(127915, 9141, 'Carol e o Fim do Mundo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fx3z71cGEYVjpmmLLkbtgtjNQUn.jpg'),
(127916, 9141, 'Carol e o Fim do Mundo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzDIxvMb4fpF2sW7kkE7WmPKNAA.jpg'),
(127917, 9142, 'FBI Casos Reais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5z5WUmMIYRzq3YeY8714gLKqDdX.jpg'),
(127918, 9142, 'FBI Casos Reais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xbyxjcDl4qIPVwA0PIVfhB7mSTK.jpg'),
(127919, 9142, 'FBI Casos Reais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sbMVhGnZcQZtXpWgrBl2uwkbIE3.jpg'),
(127920, 9142, 'FBI Casos Reais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2IEx7Lj2k9Rpkac0sUUOnVdqnY5.jpg'),
(127921, 9142, 'FBI Casos Reais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9jp5tdxvztqDxcDTxGInBCU07xl.jpg'),
(127922, 9142, 'FBI Casos Reais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tKrBo5kk6kkIq5UjpuqWp20BCs4.jpg'),
(127923, 9142, 'FBI Casos Reais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gUJgubdx1R2dfnaIKYp9OBGCBvH.jpg'),
(127924, 9142, 'FBI Casos Reais S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJL88Fl9dTeIywX912vejg45eD.jpg'),
(127925, 9142, 'FBI Casos Reais S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2YTLDzn8txPQUj4Jh8Ila6VSaML.jpg'),
(127926, 9142, 'FBI Casos Reais S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJA7Fl37L5NXLEJhlYEMabPa5nu.jpg'),
(127927, 9142, 'FBI Casos Reais S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vlyc2VqJTA0U4A4Sbq0juXc8Rm.jpg'),
(127928, 9142, 'FBI Casos Reais S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vlyc2VqJTA0U4A4Sbq0juXc8Rm.jpg'),
(127929, 9142, 'FBI Casos Reais S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/253919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vlyc2VqJTA0U4A4Sbq0juXc8Rm.jpg'),
(127930, 9142, 'FBI Casos Reais S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/253920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vlyc2VqJTA0U4A4Sbq0juXc8Rm.jpg'),
(127931, 9142, 'FBI Casos Reais S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/253921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vlyc2VqJTA0U4A4Sbq0juXc8Rm.jpg'),
(127932, 9142, 'FBI Casos Reais S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/253922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vlyc2VqJTA0U4A4Sbq0juXc8Rm.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(127933, 9142, 'FBI Casos Reais S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/253923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vlyc2VqJTA0U4A4Sbq0juXc8Rm.jpg'),
(127934, 9142, 'FBI Casos Reais S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/253924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vlyc2VqJTA0U4A4Sbq0juXc8Rm.jpg'),
(127935, 9142, 'FBI Casos Reais S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/253925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vlyc2VqJTA0U4A4Sbq0juXc8Rm.jpg'),
(127936, 9142, 'FBI Casos Reais S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/253926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vlyc2VqJTA0U4A4Sbq0juXc8Rm.jpg'),
(127937, 9142, 'FBI Casos Reais S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/253927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vlyc2VqJTA0U4A4Sbq0juXc8Rm.jpg'),
(127938, 9142, 'FBI Casos Reais S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/253928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vlyc2VqJTA0U4A4Sbq0juXc8Rm.jpg'),
(127939, 9142, 'FBI Casos Reais S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/253929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vlyc2VqJTA0U4A4Sbq0juXc8Rm.jpg'),
(127940, 9142, 'FBI Casos Reais S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/253930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vlyc2VqJTA0U4A4Sbq0juXc8Rm.jpg'),
(127941, 9142, 'FBI Casos Reais S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/253931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vlyc2VqJTA0U4A4Sbq0juXc8Rm.jpg'),
(127942, 9142, 'FBI Casos Reais S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/253932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vlyc2VqJTA0U4A4Sbq0juXc8Rm.jpg'),
(127943, 9142, 'FBI Casos Reais S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/253933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vlyc2VqJTA0U4A4Sbq0juXc8Rm.jpg'),
(127944, 9142, 'FBI Casos Reais S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/253934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vlyc2VqJTA0U4A4Sbq0juXc8Rm.jpg'),
(127945, 9142, 'FBI Casos Reais S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/253935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vlyc2VqJTA0U4A4Sbq0juXc8Rm.jpg'),
(127946, 9142, 'FBI Casos Reais S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/253936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vlyc2VqJTA0U4A4Sbq0juXc8Rm.jpg'),
(127947, 9143, 'Interprete do Silencio [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6cnCJrVtpxoogNJB7yPSbiIEBiz.jpg'),
(127948, 9143, 'Interprete do Silencio [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h8shihsCa5CIyJ4XeXCPUb5wXQT.jpg'),
(127949, 9143, 'Interprete do Silencio [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wmMlnriOLb2usDNq4UFOeafYdrU.jpg'),
(127950, 9143, 'Interprete do Silencio [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vcmwDghbHHhGPIwFQzhEDh1OAS2.jpg'),
(127951, 9143, 'Interprete do Silencio [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h8ic3XwrTJYZYj6cde3iypsgGez.jpg'),
(127952, 9144, 'Jeffrey Epstein Poder e Perversao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qYds0dtCYwdRDrLc6l4PcIHFDTn.jpg'),
(127953, 9144, 'Jeffrey Epstein Poder e Perversao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cIhGy6BMnw7r37tpyRlIsSRv9lf.jpg'),
(127954, 9144, 'Jeffrey Epstein Poder e Perversao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ayXDagV7ofMkCgYJZZZkFsjOrO9.jpg'),
(127955, 9144, 'Jeffrey Epstein Poder e Perversao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZ30VZq7TfefJcrbhTQJOsyvTrZ.jpg'),
(127956, 9145, 'My Dearest [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zx5V6HHniWBXktT8EWb4NbKKjca.jpg'),
(127957, 9145, 'My Dearest [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/HYRsKTzHYFAVH1viViqzfEDLE4.jpg'),
(127958, 9145, 'My Dearest [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AnkJFlpjQTkhVLvjG8pNWVQhtBy.jpg'),
(127959, 9145, 'My Dearest [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7igULaHwjgQq9j9U4hE1sYeB8CQ.jpg'),
(127960, 9145, 'My Dearest [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d2aCVxeRl5R2bAgMKz0P7pCCVd1.jpg'),
(127961, 9145, 'My Dearest [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sNDE7IYRo1tNcebRzRT1JK8AR1T.jpg'),
(127962, 9145, 'My Dearest [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/llrEmDwZVTAEJTK7mfC8lYmAhpj.jpg'),
(127963, 9145, 'My Dearest [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2tGo2U2iVbDURkG7wgWpgC94j1O.jpg'),
(127964, 9145, 'My Dearest [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eW6bskTNBOpZ6QnYr05g1jGkX8J.jpg'),
(127965, 9145, 'My Dearest [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/deQK39JEMiCn1vVtJ00AWQ9rfpX.jpg'),
(127966, 9145, 'My Dearest [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6tsaAcR9JV7D8jHjxvlbGl0b4Er.jpg'),
(127967, 9145, 'My Dearest [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oYf8wUjpHXdEyJcaHJEdGKVz2qJ.jpg'),
(127968, 9145, 'My Dearest [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/253889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4nI6gUwhw5ClwBTW4poO42LE7NV.jpg'),
(127969, 9145, 'My Dearest [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/253890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g9q0z6lhePxuhQQgqQNFStbnO1o.jpg'),
(127970, 9145, 'My Dearest [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/253891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lKTwHFHkVF1YEIrPr7YPwmJWYkF.jpg'),
(127971, 9145, 'My Dearest [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/253892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3pcGyATMina7no5a1IuRHpWSX60.jpg'),
(127972, 9145, 'My Dearest [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/253893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hNofWloaNYzjTvTmH4i0oHOuEMb.jpg'),
(127973, 9145, 'My Dearest [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/253894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j9iwGKtFS4m1kJppjRXopxnOZXq.jpg'),
(127974, 9145, 'My Dearest [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/253895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bFrt41STcWlxHq7wRmgFoP3NiRM.jpg'),
(127975, 9145, 'My Dearest [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/253896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ZyOGI5T2QbJ73g3JMdYcayjXKy.jpg'),
(127976, 9145, 'My Dearest [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/253897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/coll09Tf128fszhgfoXvY43V6FB.jpg'),
(127977, 9146, 'Shooting Stars [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sGNBJiL0ZJEJyJL8Q4u8IKPnnku.jpg'),
(127978, 9146, 'Shooting Stars [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tpMy71dGDCOGbIpsOEadO93P1oy.jpg'),
(127979, 9146, 'Shooting Stars [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pPdgkkGQaBdgXT5emWAHtRwGhlT.jpg'),
(127980, 9146, 'Shooting Stars [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/goq4HL7k15E145aiVlPW05wzFqO.jpg'),
(127981, 9146, 'Shooting Stars [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oi2T7wU4IjVF0HW6wnjStM0w5wi.jpg'),
(127982, 9146, 'Shooting Stars [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tep7eFucf4Dz4HKY3yZivHVbhSQ.jpg'),
(127983, 9146, 'Shooting Stars [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6wFOMTfcoJkUnvGhVCka6LXJnN.jpg'),
(127984, 9146, 'Shooting Stars [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qVuiA1nxl1zDELFuj7abQ0emv5I.jpg'),
(127985, 9146, 'Shooting Stars [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4EUoJpiw0bRwI2M4ecI5pr3wgFW.jpg'),
(127986, 9146, 'Shooting Stars [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zgHkisfwO4e82msxSdp5UUI9G10.jpg'),
(127987, 9146, 'Shooting Stars [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDVgOJop2bPt5DzhnYTlGe6xVxt.jpg'),
(127988, 9146, 'Shooting Stars [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVH8mGPaUnVNclVn6lUKYfzN9Xc.jpg'),
(127989, 9146, 'Shooting Stars [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/253873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aPTdMr7bFVe6sV40Tewmi5lO5jt.jpg'),
(127990, 9146, 'Shooting Stars [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/253874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3FAqSGK2Tf1yZ4hItu30HVfOEuL.jpg'),
(127991, 9146, 'Shooting Stars [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/253875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oDdlgyg8PWBANGztKGSVrdaxcpH.jpg'),
(127992, 9146, 'Shooting Stars [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/253876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qb7eKPYcKJRtH3ETvryH8soI4ql.jpg'),
(127993, 9147, 'The Matchmakers [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eVls39gFZXwDg94UzhNx6m17Ncy.jpg'),
(127994, 9147, 'The Matchmakers [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5cMxEEf4QdsGqucXg2taW39biy8.jpg'),
(127995, 9147, 'The Matchmakers [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j4xTaAjVegwgbqJ6pMQz05Utrmj.jpg'),
(127996, 9147, 'The Matchmakers [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rsr2kBFMkduASBwx2IfjoSpC9zU.jpg'),
(127997, 9147, 'The Matchmakers [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e2BhDxpPcmON8oFlOQoj99qCiGe.jpg'),
(127998, 9147, 'The Matchmakers [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9XW0mMiWB4LXFueQSbkcjBKwC6K.jpg'),
(127999, 9147, 'The Matchmakers [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/icXcQQ51CgKWNY2bBoydtKMTWKS.jpg'),
(128000, 9147, 'The Matchmakers [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/enXj6at3nuiQktD0kkrTklYcbww.jpg'),
(128001, 9147, 'The Matchmakers [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8wCm3cN5oP5zj8Bj8xoiGkzSJKJ.jpg'),
(128002, 9147, 'The Matchmakers [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nU8zyUwhlXAfwhwggJ7265Pvfks.jpg'),
(128003, 9147, 'The Matchmakers [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ew8P1gL2Mo2ZlNcgO6Kd4oT2Up7.jpg'),
(128004, 9147, 'The Matchmakers [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xLjY7qdsMjQqThAGJFWIsQfU4U9.jpg'),
(128005, 9148, 'Agatha Christies Poirot [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZJ98SW1n60mj27bx0I77zAZRxy.jpg'),
(128006, 9148, 'Agatha Christies Poirot [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rD4qBCDo72XKcGgN7wg4VQCuBcG.jpg'),
(128007, 9148, 'Agatha Christies Poirot [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/niZvzkhU08J7buqonBwpXiTNmoA.jpg'),
(128008, 9148, 'Agatha Christies Poirot [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jlxAwCDb167rQFwj9VvI02VBW45.jpg'),
(128009, 9148, 'Agatha Christies Poirot [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNBuYlD2BSSCyA0HL3M9gq7Hd2l.jpg'),
(128010, 9148, 'Agatha Christies Poirot [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zwLh1D3sQVJaZapIOiwBSzRSeBt.jpg'),
(128011, 9148, 'Agatha Christies Poirot [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/95tOwofSA6jYxYR7ZSi0PzdZ28o.jpg'),
(128012, 9148, 'Agatha Christies Poirot [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/12JLAYl9vTuD8Ziw3kvuX8Js2H1.jpg'),
(128013, 9148, 'Agatha Christies Poirot [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b2EB8ljp9xgeaByKIxlu3UYQyco.jpg'),
(128014, 9149, 'Agatha Christies Poirot [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Tz1k3GLZrAzPRvHJsZnDBTG8ZH.jpg'),
(128015, 9149, 'Agatha Christies Poirot [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4vFS2yngRR3ZLusaHj0YbqoyH6C.jpg'),
(128016, 9149, 'Agatha Christies Poirot [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qn3ojuOVHnc24puqDOX1JrnPys7.jpg'),
(128017, 9149, 'Agatha Christies Poirot [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cu1B3bNf1Ut7xkLtJTvZ4coTPIq.jpg'),
(128018, 9149, 'Agatha Christies Poirot [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/slNtA5X0W3tp7i4pmLzsfO4bows.jpg'),
(128019, 9149, 'Agatha Christies Poirot [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1j1kbJl8E0XPiYKR1LAKHccRwjF.jpg'),
(128020, 9149, 'Agatha Christies Poirot [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xASybVaSGxgjeQmzsgFG7aCYPmh.jpg'),
(128021, 9149, 'Agatha Christies Poirot [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qH1RhbvGTeBzJmopZNrt4fAa9SL.jpg'),
(128022, 9149, 'Agatha Christies Poirot [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rnn1fEJ0o9ycdXxzZt5efitOy7L.jpg'),
(128023, 9150, 'Agatha Christies Poirot [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/R3zOkNboDZziLTn83aUAba8AOg.jpg'),
(128024, 9150, 'Agatha Christies Poirot [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rmHj5maXrNmU9lQJFfDhpOOOfbb.jpg'),
(128025, 9150, 'Agatha Christies Poirot [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j58gX2OMKuGOTQrRaMr2jjghOGx.jpg'),
(128026, 9150, 'Agatha Christies Poirot [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2lxoSGaQAS1YqshqCXEW7nFTr0W.jpg'),
(128027, 9150, 'Agatha Christies Poirot [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eupUlReXpiLd4aMyCqnhMeLWhu3.jpg'),
(128028, 9150, 'Agatha Christies Poirot [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Ju8nowZlFlStvwdIlQOwNzltsO.jpg'),
(128029, 9150, 'Agatha Christies Poirot [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zY3mb0H4S7mKXsRGf1ZpPmCwKF8.jpg'),
(128030, 9150, 'Agatha Christies Poirot [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oDrCEyufGi1NDbT6F9yW8OFliHT.jpg'),
(128031, 9150, 'Agatha Christies Poirot [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b474RlQMQcDcFBnZE5seW1bFSqg.jpg'),
(128032, 9150, 'Agatha Christies Poirot [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gMmQzJfSU1samkWcgBP5jsjGcU5.jpg'),
(128033, 9150, 'Agatha Christies Poirot [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6f4IVfbn8knb7RjdZlGLuW5guDc.jpg'),
(128034, 9151, 'Agatha Christies Poirot [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5jRMxYFCY92d5I8Y8YUeZUFg7Qx.jpg'),
(128035, 9151, 'Agatha Christies Poirot [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUEMtCN1bGdoEn3T9Bdgct26hwa.jpg'),
(128036, 9151, 'Agatha Christies Poirot [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qxJc7LF2cm43ric7Li8vzNiGW63.jpg'),
(128037, 9152, 'Agatha Christies Poirot [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yicwJgFpgbLXetNVqs9Qg8Gz5vO.jpg'),
(128038, 9152, 'Agatha Christies Poirot [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63gAdMGzP5Q1IpcyyaFbW8B9eRw.jpg'),
(128039, 9152, 'Agatha Christies Poirot [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6eLxL0PXiO2l8QyJjhGilpXK7Ju.jpg'),
(128040, 9152, 'Agatha Christies Poirot [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bX7FYgVpYhZH44nxTgx47LPtNBK.jpg'),
(128041, 9152, 'Agatha Christies Poirot [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2SkoaNeLMnjEfujcgf2jHxkdtrL.jpg'),
(128042, 9152, 'Agatha Christies Poirot [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lQmzX6PPDQDCC9bQ83qHbAxOhR.jpg'),
(128043, 9152, 'Agatha Christies Poirot [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jxcv4ssjZSDe4vXlllFnPe5rYrH.jpg'),
(128044, 9152, 'Agatha Christies Poirot [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cTQEeqgo4fnThmpQ4emTRV6JjXG.jpg'),
(128045, 9153, 'Agatha Christies Poirot [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2OKvyTx1fcqrB2NAQWr5LwJmxDY.jpg'),
(128046, 9153, 'Agatha Christies Poirot [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zCrNW0Sq4BMZlgx8VokWU0K0UVU.jpg'),
(128047, 9153, 'Agatha Christies Poirot [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h8NKzsnPq5apl3upXCtzHGqFzIV.jpg'),
(128048, 9153, 'Agatha Christies Poirot [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xRntrubMAFH33AWBji0ubbKMerK.jpg'),
(128049, 9154, 'Agatha Christies Poirot [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zU8iPveSvjmVQA79Dmsd1MgUjKe.jpg'),
(128050, 9154, 'Agatha Christies Poirot [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/htckC9abadzNthi4zUW5YrbN7V6.jpg'),
(128051, 9155, 'Agatha Christies Poirot [L] S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3KtVZjkp5FGTIrbsMNQKAqkBKnG.jpg'),
(128052, 9155, 'Agatha Christies Poirot [L] S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b39xdAgLnG52ZvTUgsK8IG95yFM.jpg'),
(128053, 9156, 'Agatha Christies Poirot [L] S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXIgJIIfwJgybaWhqxKAq4nxAPj.jpg'),
(128054, 9156, 'Agatha Christies Poirot [L] S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rjfvnyZPfJQzluJkv8pB05vQ7Er.jpg'),
(128055, 9156, 'Agatha Christies Poirot [L] S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cdqfyn6WC0krgV6SH63J5BQrrII.jpg'),
(128056, 9156, 'Agatha Christies Poirot [L] S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6inCYpOMowWQ6B5CyT2AZxXMRkK.jpg'),
(128057, 9157, 'Agatha Christies Poirot [L] S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8GUanRDaoEDi89OcWK5fhUjTtRv.jpg'),
(128058, 9157, 'Agatha Christies Poirot [L] S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n7ARim6q0AYaNXv8y5xwjOLwiR2.jpg'),
(128059, 9157, 'Agatha Christies Poirot [L] S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bjBdyp28YTcOi5ckrYxc128yYLO.jpg'),
(128060, 9157, 'Agatha Christies Poirot [L] S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kKuym850zu9R83pwwSWdvrD0tka.jpg'),
(128061, 9158, 'Agatha Christies Poirot [L] S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vtvBC5DToWdQ8oevFEKYgivy2Si.jpg'),
(128062, 9158, 'Agatha Christies Poirot [L] S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i1X5oGkh4VmPrPmbCxwvLWqiiy3.jpg'),
(128063, 9158, 'Agatha Christies Poirot [L] S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uXQInHop4sgp0ChzWfxhAw8RFMd.jpg'),
(128064, 9158, 'Agatha Christies Poirot [L] S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pCffVaHpeg01QFlfWefBwPypRmS.jpg'),
(128065, 9159, 'Agatha Christies Poirot [L] S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wve1RXxZNi9IRBD70GP2U9GYk0T.jpg'),
(128066, 9159, 'Agatha Christies Poirot [L] S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cFZPFcvmxbKVzCGzVulrVoxjpr8.jpg'),
(128067, 9159, 'Agatha Christies Poirot [L] S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wQ5ounjdXmumaaDmguTufPRBkg8.jpg'),
(128068, 9159, 'Agatha Christies Poirot [L] S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6wyUYwZl7hhiugj1xfTNG1JLzz0.jpg'),
(128069, 9160, 'Agatha Christies Poirot [L] S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/940FguRXcWCSUMAM5AOul9wjLhd.jpg'),
(128070, 9160, 'Agatha Christies Poirot [L] S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/onlwR121fgVVJn4OdNJPxeygQTs.jpg'),
(128071, 9160, 'Agatha Christies Poirot [L] S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ADW3MIVfypT8eDcT7UBlLoIIF8.jpg'),
(128072, 9160, 'Agatha Christies Poirot [L] S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ISRkkw47EztezHxRKCZ2aKdtKf.jpg'),
(128073, 9160, 'Agatha Christies Poirot [L] S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ptNDuxfpm6d4tpC7riKzB6p950c.jpg'),
(128074, 9161, 'As Megamarcas que Mudaram o Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0kB5ROrmYnKWeu8M4lz8riSwDz.jpg'),
(128075, 9161, 'As Megamarcas que Mudaram o Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tUn8WP1yH0EEXkZUlpaWO1QLtR0.jpg'),
(128076, 9161, 'As Megamarcas que Mudaram o Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vYMOeTVazxhBmMDySQXtt8LO40I.jpg'),
(128077, 9161, 'As Megamarcas que Mudaram o Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/39l0NpdAy6Bp2SNqvSmRFgeDgc4.jpg'),
(128078, 9162, 'As Megamarcas que Mudaram o Mundo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/659795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zw2CjeIphPm4TZo16mL83fdEiJw.jpg'),
(128079, 9162, 'As Megamarcas que Mudaram o Mundo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/659796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zw2CjeIphPm4TZo16mL83fdEiJw.jpg'),
(128080, 9162, 'As Megamarcas que Mudaram o Mundo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/659797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zw2CjeIphPm4TZo16mL83fdEiJw.jpg'),
(128081, 9162, 'As Megamarcas que Mudaram o Mundo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/659798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zw2CjeIphPm4TZo16mL83fdEiJw.jpg'),
(128082, 9162, 'As Megamarcas que Mudaram o Mundo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/659799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zw2CjeIphPm4TZo16mL83fdEiJw.jpg'),
(128083, 9162, 'As Megamarcas que Mudaram o Mundo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/659800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zw2CjeIphPm4TZo16mL83fdEiJw.jpg'),
(128084, 9162, 'As Megamarcas que Mudaram o Mundo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/659801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zw2CjeIphPm4TZo16mL83fdEiJw.jpg'),
(128085, 9162, 'As Megamarcas que Mudaram o Mundo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/659802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zw2CjeIphPm4TZo16mL83fdEiJw.jpg'),
(128086, 9163, 'Hello Kitty Super Style S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128087, 9163, 'Hello Kitty Super Style S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128088, 9163, 'Hello Kitty Super Style S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128089, 9163, 'Hello Kitty Super Style S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128090, 9163, 'Hello Kitty Super Style S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128091, 9163, 'Hello Kitty Super Style S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128092, 9163, 'Hello Kitty Super Style S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128093, 9163, 'Hello Kitty Super Style S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128094, 9163, 'Hello Kitty Super Style S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128095, 9163, 'Hello Kitty Super Style S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128096, 9163, 'Hello Kitty Super Style S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128097, 9163, 'Hello Kitty Super Style S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128098, 9163, 'Hello Kitty Super Style S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/253765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128099, 9163, 'Hello Kitty Super Style S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/253766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128100, 9163, 'Hello Kitty Super Style S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/253767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128101, 9163, 'Hello Kitty Super Style S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/253768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128102, 9163, 'Hello Kitty Super Style S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/253769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128103, 9163, 'Hello Kitty Super Style S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/253770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128104, 9163, 'Hello Kitty Super Style S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/253771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128105, 9163, 'Hello Kitty Super Style S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/253772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128106, 9163, 'Hello Kitty Super Style S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/253773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128107, 9163, 'Hello Kitty Super Style S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/253774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128108, 9163, 'Hello Kitty Super Style S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/253775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHhvqLFmCwIAxDh7acMFInA0B2.jpg'),
(128109, 573, 'Perdidos no Espaco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128110, 573, 'Perdidos no Espaco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ntM9jLJBSgIQwOfsmGwtKaWbLpC.jpg'),
(128111, 573, 'Perdidos no Espaco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/usHJqc4RbEQEeCaurDnNjM8C0Of.jpg'),
(128112, 573, 'Perdidos no Espaco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6e7nkpIAJebMqOhvIJhETAZLNPe.jpg'),
(128113, 573, 'Perdidos no Espaco S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1vjs4XIyR3yp3y8aR9BXu3TxTwX.jpg'),
(128114, 573, 'Perdidos no Espaco S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9i64KoJFP0DaroW5tn3KTciYDcQ.jpg'),
(128115, 573, 'Perdidos no Espaco S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v7lFcWQZZToiR3fUPRjgkT83a5m.jpg'),
(128116, 573, 'Perdidos no Espaco S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lgSODYmTTg7Ni4uUjjm5Hpg4YIe.jpg'),
(128117, 573, 'Perdidos no Espaco S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5pxTvuoZmZxweagONub8GWMIZlo.jpg'),
(128118, 573, 'Perdidos no Espaco S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5LDVULk8ovX8tYN38zPWfySXHKO.jpg'),
(128119, 573, 'Perdidos no Espaco S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Xko0oTtKF9S6xqTjpiYVfBfO9K.jpg'),
(128120, 573, 'Perdidos no Espaco S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y5edi20iodWujG9ntWLwmPDKo9x.jpg'),
(128121, 573, 'Perdidos no Espaco S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gTehNgIOuEdahLqjDBOV3Sbq2ko.jpg'),
(128122, 573, 'Perdidos no Espaco S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rxsrfs3BXkku3OSmw26ZrPmbOiP.jpg'),
(128123, 573, 'Perdidos no Espaco S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7C0ghaH0HbLuP4BmIJRYokjrB53.jpg'),
(128124, 573, 'Perdidos no Espaco S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ikGutnizxrDT2J0o4bVEOzGUGL1.jpg'),
(128125, 573, 'Perdidos no Espaco S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/263289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vLrTlKNsQLZ2AHNN7E3pWW9GEMy.jpg'),
(128126, 573, 'Perdidos no Espaco S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/263290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uze4GGGMSXJYKHWJolq2YmQGwU6.jpg'),
(128127, 573, 'Perdidos no Espaco S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/263291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xtVmtsv13yWssYbb2BAH8wXxBwu.jpg'),
(128128, 573, 'Perdidos no Espaco S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/263292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aDyHBIzuc0jJf5c8WNT3TpK2Sdr.jpg'),
(128129, 573, 'Perdidos no Espaco S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/263293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sP3G3Ul9UlcTb8n8cECHIp9KUB9.jpg'),
(128130, 573, 'Perdidos no Espaco S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/263294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/heBDsXy5fxKZAs4TJalOmmLCSEV.jpg'),
(128131, 573, 'Perdidos no Espaco S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/263295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1teaDBfdv0cSkGgWZredU41VU5O.jpg'),
(128132, 573, 'Perdidos no Espaco S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/263296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8KaAB9QJEUhmEUqwAhcZMiIgj4Y.jpg'),
(128133, 573, 'Perdidos no Espaco S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/263297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7q754MmF3fDiTrkQtyitZwu9Ih.jpg'),
(128134, 573, 'Perdidos no Espaco S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/263298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/519Gyss6T7r1hWcZoxStxvstK03.jpg'),
(128135, 573, 'Perdidos no Espaco S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/263299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/srqsBAydE4LJQ2ipV8gzEKZYrMy.jpg'),
(128136, 573, 'Perdidos no Espaco S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/263300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zNLD1dKtFYQsgsS3tVBUTx1G3BX.jpg'),
(128137, 573, 'Perdidos no Espaco S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/263301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qUa1mlNOrLnN4MaABYbM739o5WH.jpg'),
(128138, 573, 'Perdidos no Espaco S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/263302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7BDVAB2Bt2hyoFKZsvKq3eqGKeq.jpg'),
(128139, 574, 'Perdidos no Espaco S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128140, 574, 'Perdidos no Espaco S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128141, 574, 'Perdidos no Espaco S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128142, 574, 'Perdidos no Espaco S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128143, 574, 'Perdidos no Espaco S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128144, 574, 'Perdidos no Espaco S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128145, 574, 'Perdidos no Espaco S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128146, 574, 'Perdidos no Espaco S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128147, 574, 'Perdidos no Espaco S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128148, 574, 'Perdidos no Espaco S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128149, 574, 'Perdidos no Espaco S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128150, 574, 'Perdidos no Espaco S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128151, 574, 'Perdidos no Espaco S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128152, 574, 'Perdidos no Espaco S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128153, 574, 'Perdidos no Espaco S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128154, 574, 'Perdidos no Espaco S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128155, 574, 'Perdidos no Espaco S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/263319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128156, 574, 'Perdidos no Espaco S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/263320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128157, 574, 'Perdidos no Espaco S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/263321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128158, 574, 'Perdidos no Espaco S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/263322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128159, 574, 'Perdidos no Espaco S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/263323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128160, 574, 'Perdidos no Espaco S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/263324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128161, 574, 'Perdidos no Espaco S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/263325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128162, 574, 'Perdidos no Espaco S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/263326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128163, 574, 'Perdidos no Espaco S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/263327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128164, 574, 'Perdidos no Espaco S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/263328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128165, 574, 'Perdidos no Espaco S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/263329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128166, 574, 'Perdidos no Espaco S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/263330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128167, 574, 'Perdidos no Espaco S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/263331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128168, 574, 'Perdidos no Espaco S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/263332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128169, 574, 'Perdidos no Espaco S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/263333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128170, 575, 'Perdidos no Espaco S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128171, 575, 'Perdidos no Espaco S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128172, 575, 'Perdidos no Espaco S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128173, 575, 'Perdidos no Espaco S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128174, 575, 'Perdidos no Espaco S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128175, 575, 'Perdidos no Espaco S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128176, 575, 'Perdidos no Espaco S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128177, 575, 'Perdidos no Espaco S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128178, 575, 'Perdidos no Espaco S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128179, 575, 'Perdidos no Espaco S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128180, 575, 'Perdidos no Espaco S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128181, 575, 'Perdidos no Espaco S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128182, 575, 'Perdidos no Espaco S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128183, 575, 'Perdidos no Espaco S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128184, 575, 'Perdidos no Espaco S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128185, 575, 'Perdidos no Espaco S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128186, 575, 'Perdidos no Espaco S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/263350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128187, 575, 'Perdidos no Espaco S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/263351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(128188, 575, 'Perdidos no Espaco S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/263352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128189, 575, 'Perdidos no Espaco S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/263353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128190, 575, 'Perdidos no Espaco S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/263354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128191, 575, 'Perdidos no Espaco S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/263355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128192, 575, 'Perdidos no Espaco S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/263356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128193, 575, 'Perdidos no Espaco S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/263357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dGhtCpYZutuso2P3GKWnQnqwhSi.jpg'),
(128194, 9164, 'Platform 7 [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/paiSHCMMZWiTLEsLDancZfycigH.jpg'),
(128195, 9165, 'Via Publica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8TiqXHlFeSKSJiM1w8fdlacL73M.jpg'),
(128196, 9165, 'Via Publica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8TiqXHlFeSKSJiM1w8fdlacL73M.jpg'),
(128197, 9165, 'Via Publica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8TiqXHlFeSKSJiM1w8fdlacL73M.jpg'),
(128198, 9165, 'Via Publica S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8TiqXHlFeSKSJiM1w8fdlacL73M.jpg'),
(128199, 9166, 'Amor de intermediario [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/awMlsdDrS1W00XJfPZ1A5PqxqBg.jpg'),
(128200, 9166, 'Amor de intermediario [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vfEO10tJO6aBLZEh4xD0BfMt9Mu.jpg'),
(128201, 9166, 'Amor de intermediario [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9YCAdFMOYgy4HtdKAfc2EnxFPcd.jpg'),
(128202, 9166, 'Amor de intermediario [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9YCAdFMOYgy4HtdKAfc2EnxFPcd.jpg'),
(128203, 9166, 'Amor de intermediario [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9YCAdFMOYgy4HtdKAfc2EnxFPcd.jpg'),
(128204, 9166, 'Amor de intermediario [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9YCAdFMOYgy4HtdKAfc2EnxFPcd.jpg'),
(128205, 9166, 'Amor de intermediario [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9YCAdFMOYgy4HtdKAfc2EnxFPcd.jpg'),
(128206, 9166, 'Amor de intermediario [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9YCAdFMOYgy4HtdKAfc2EnxFPcd.jpg'),
(128207, 9167, 'Cinderella Chef [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4UkEr0erRyvdGpPdV5qSdJx55WR.jpg'),
(128208, 9167, 'Cinderella Chef [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7mBqXZ9QZno8AqZqxWk5ZN32ok7.jpg'),
(128209, 9167, 'Cinderella Chef [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3pXRBjaAtYOYOkeBJEvMivmlJsT.jpg'),
(128210, 9167, 'Cinderella Chef [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aaxq7tKIPiShDaUQ7a12Ckg5RuN.jpg'),
(128211, 9167, 'Cinderella Chef [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l3uvR35wioRLLGtjAwCa3OX7iS5.jpg'),
(128212, 9167, 'Cinderella Chef [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z7wRlFMWS41lg7qi3fp6TBOAuY9.jpg'),
(128213, 9167, 'Cinderella Chef [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zAAvPiKswKQxA3GDrXCTmEM83rj.jpg'),
(128214, 9167, 'Cinderella Chef [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63HoIPUtFnQpsYk6DUVsdPpxYsM.jpg'),
(128215, 9167, 'Cinderella Chef [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yKnjWI2aQwcSt9Sums8BGqQr7HN.jpg'),
(128216, 9167, 'Cinderella Chef [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3vR9f1iMCuKB9NmOVJkNG0LKvrI.jpg'),
(128217, 9167, 'Cinderella Chef [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eyUTI3PnX9yAk7SOGlnqcUYFOhO.jpg'),
(128218, 9167, 'Cinderella Chef [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z8oAqjwt89YR48oTpOf4iNPCPO7.jpg'),
(128219, 9168, 'Cinderella Chef [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nVQKEFnI52T2UzCijgKPGa58hxy.jpg'),
(128220, 9168, 'Cinderella Chef [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/twCIt2fpa8LGcGqC0NZfOvEm1LN.jpg'),
(128221, 9168, 'Cinderella Chef [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pmJTbJL3qtcm3lwza2AWU1JRftq.jpg'),
(128222, 9168, 'Cinderella Chef [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/swy4N9eAqSNoHgi7HUy95xpuPqn.jpg'),
(128223, 9168, 'Cinderella Chef [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0sH97J2IKsadviQgqGhv5VIfvs.jpg'),
(128224, 9168, 'Cinderella Chef [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qNlpBEesJ6s4mf1kHmploTBZbi0.jpg'),
(128225, 9168, 'Cinderella Chef [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hiBv9NIYgK6c3jeE4hrLmTNlFea.jpg'),
(128226, 9168, 'Cinderella Chef [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZvTZOPZKf8VrwHMWjhtNTaWoJK.jpg'),
(128227, 9168, 'Cinderella Chef [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8J5axFsKBubyNA1XaHd1k2Br67l.jpg'),
(128228, 9168, 'Cinderella Chef [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/54pIOsDLmhDY4tenoIFNLn8sc7G.jpg'),
(128229, 9168, 'Cinderella Chef [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/krBKR2D1KyxkzScNsx1O21JbZTj.jpg'),
(128230, 9168, 'Cinderella Chef [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Omi8SYCmK3m5j1xPWy5VmFZL4f.jpg'),
(128231, 9169, 'Cinderella Chef [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AlVhb8ssOhMkKw35UMzhNgDAcKI.jpg'),
(128232, 9169, 'Cinderella Chef [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ed98YilSvSQiaYnnmrJz5YZ1wbb.jpg'),
(128233, 9169, 'Cinderella Chef [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dLruHlRPToUW9J7vxKNFfColBW.jpg'),
(128234, 9169, 'Cinderella Chef [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/omQrvkgIEfXkfvt8Iu53TsNi9Nh.jpg'),
(128235, 9169, 'Cinderella Chef [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iOSzJhEZNgLbdkS2lpGXM3JhQ54.jpg'),
(128236, 9169, 'Cinderella Chef [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z2cC3NXT5MAkAnct4NyNITDGPZr.jpg'),
(128237, 9169, 'Cinderella Chef [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lJxIu5vvdQLYArgzQM5baVJlJew.jpg'),
(128238, 9169, 'Cinderella Chef [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/emdId36fqo76L3Evs3BYnBXsto2.jpg'),
(128239, 9169, 'Cinderella Chef [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vuRIfp8JPrOH61CQc5pZBaqzyOh.jpg'),
(128240, 9169, 'Cinderella Chef [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3BicxROiyPGLbhxrMsTF7ojwFS1.jpg'),
(128241, 9169, 'Cinderella Chef [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g0XtXCcuCFkcPb4Cwyb8VFfALIt.jpg'),
(128242, 9169, 'Cinderella Chef [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fpUEXmKaUKhzFpQb8TUrPopw4Ic.jpg'),
(128243, 9170, 'Gaikotsu Shotenin Honda san [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7AnoopNIB9lw27U4WOnYjm3Nh8W.jpg'),
(128244, 9170, 'Gaikotsu Shotenin Honda san [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJqwTo7HSNkuvz3yMdEXpf67DyP.jpg'),
(128245, 9170, 'Gaikotsu Shotenin Honda san [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a60ix58Pkyyx8U9GZyR0KcDRJlw.jpg'),
(128246, 9170, 'Gaikotsu Shotenin Honda san [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Mi0JUxM4TrzPinFglSdTouXpru.jpg'),
(128247, 9170, 'Gaikotsu Shotenin Honda san [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nIhGQiTmiAzJm1cFtnKcOpnHy1t.jpg'),
(128248, 9170, 'Gaikotsu Shotenin Honda san [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZoGSLS0UECShQQql8hegZpPU5O.jpg'),
(128249, 9170, 'Gaikotsu Shotenin Honda san [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bGZe1nYrk0TT4CryAfgE6N2c5dD.jpg'),
(128250, 9170, 'Gaikotsu Shotenin Honda san [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11qKnRm1sM2HNs4PYYzXzT1n6I5.jpg'),
(128251, 9170, 'Gaikotsu Shotenin Honda san [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hWAfe1rwBv43xdJ8wfu5YoTKZPT.jpg'),
(128252, 9170, 'Gaikotsu Shotenin Honda san [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wad28hbhWG8q5jgJhLFRCPlj023.jpg'),
(128253, 9170, 'Gaikotsu Shotenin Honda san [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9BhmkLFD8mJVSUFgR8hxrOR0hH4.jpg'),
(128254, 9170, 'Gaikotsu Shotenin Honda san [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/puDrYF84hoVP8fpB4CFk9je8sGz.jpg'),
(128255, 9171, 'Legendary Twins [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rolmrYkUUKaqVc3RZDr8MKeeK42.jpg'),
(128256, 9171, 'Legendary Twins [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/labSfzC1n0N3qoE9pgi6ldkaNq1.jpg'),
(128257, 9171, 'Legendary Twins [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ranxih6euLoEE54IFyumxmBW1Qo.jpg'),
(128258, 9171, 'Legendary Twins [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kb6rHTHFJcvpDZSVW7ZQgFK4yf4.jpg'),
(128259, 9171, 'Legendary Twins [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7nTL5ciwEMeL9iHqOweoy9EhBv.jpg'),
(128260, 9171, 'Legendary Twins [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ucNHOxMZA7xfeH9iXaGtA2glZRy.jpg'),
(128261, 9171, 'Legendary Twins [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jCIsVn6W16dQo7Iv8Z4aClkdTul.jpg'),
(128262, 9171, 'Legendary Twins [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cWsLdJNKg5Ibg8VY3cppPt7fIOW.jpg'),
(128263, 9171, 'Legendary Twins [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8ao3m91qBJTz9iUbeIuvXxbo5e.jpg'),
(128264, 9171, 'Legendary Twins [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oopCSTuO882w9yEFl5vM9MovgKU.jpg'),
(128265, 9171, 'Legendary Twins [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6wUMz2gl9IoanGy9qY7AbYQaXtN.jpg'),
(128266, 9171, 'Legendary Twins [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yR0ODu4oCBKqZY5iFjszBpOEw8L.jpg'),
(128267, 9171, 'Legendary Twins [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/253296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/93t4U6NLHwzAbBkng38UCQOW29f.jpg'),
(128268, 9171, 'Legendary Twins [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/253297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mmEhBc0Emm0WcdmFNaagKLz7hXU.jpg'),
(128269, 9171, 'Legendary Twins [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/253298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vDmNoo6Q2b5daYNbsyS11bCwYUr.jpg'),
(128270, 9171, 'Legendary Twins [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/253299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sk5RblarLeJvxbJ4XvApuOHigtX.jpg'),
(128271, 9171, 'Legendary Twins [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/253300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/32ZGFVxzRsYAv4fDUdtTIr6lg1R.jpg'),
(128272, 9171, 'Legendary Twins [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/253301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tSwqRnROsJcMc9Mf1L2UsbcwHpc.jpg'),
(128273, 9172, 'O Lobo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128274, 9172, 'O Lobo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128275, 9172, 'O Lobo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128276, 9172, 'O Lobo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128277, 9172, 'O Lobo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128278, 9172, 'O Lobo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128279, 9172, 'O Lobo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128280, 9172, 'O Lobo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128281, 9172, 'O Lobo [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128282, 9172, 'O Lobo [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128283, 9172, 'O Lobo [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128284, 9172, 'O Lobo [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128285, 9172, 'O Lobo [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/253142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128286, 9172, 'O Lobo [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/253143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128287, 9172, 'O Lobo [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/253144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128288, 9172, 'O Lobo [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/253145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128289, 9172, 'O Lobo [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/253146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128290, 9172, 'O Lobo [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/253147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128291, 9172, 'O Lobo [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/253148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128292, 9172, 'O Lobo [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/253149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128293, 9172, 'O Lobo [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/253150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128294, 9172, 'O Lobo [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/253151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128295, 9172, 'O Lobo [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/253152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128296, 9172, 'O Lobo [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/253153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128297, 9172, 'O Lobo [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/253154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128298, 9172, 'O Lobo [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/253155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128299, 9172, 'O Lobo [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/253156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128300, 9172, 'O Lobo [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/253157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128301, 9172, 'O Lobo [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/253158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128302, 9172, 'O Lobo [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/253159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128303, 9172, 'O Lobo [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/253160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128304, 9172, 'O Lobo [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/253161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128305, 9172, 'O Lobo [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/253162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128306, 9172, 'O Lobo [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/253163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128307, 9172, 'O Lobo [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/253164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128308, 9172, 'O Lobo [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/253165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128309, 9172, 'O Lobo [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/253166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128310, 9172, 'O Lobo [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/253167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128311, 9172, 'O Lobo [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/253168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128312, 9172, 'O Lobo [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/253169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128313, 9172, 'O Lobo [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/253170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128314, 9172, 'O Lobo [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/253171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128315, 9172, 'O Lobo [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/253172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128316, 9172, 'O Lobo [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/253173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128317, 9172, 'O Lobo [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/253174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128318, 9172, 'O Lobo [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/253175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128319, 9172, 'O Lobo [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/253176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128320, 9172, 'O Lobo [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/253177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128321, 9172, 'O Lobo [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/253178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rpUtYhHleUQrbKfR0tHGPmttUgF.jpg'),
(128322, 9173, 'Shoujo Kakumei Utena [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ssiEzrkWUMq5BqtrBz99Xf75umC.jpg'),
(128323, 9173, 'Shoujo Kakumei Utena [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h7BJSwywuYHq0wRz9JB420EG81p.jpg'),
(128324, 9173, 'Shoujo Kakumei Utena [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ePIalcIVD6AoTTtTsnn8348IKj7.jpg'),
(128325, 9173, 'Shoujo Kakumei Utena [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hOruhGnWYq9X0btuoCy07S7Py6P.jpg'),
(128326, 9173, 'Shoujo Kakumei Utena [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8o4zlSDxSNG4WcD336iGDl9R65z.jpg'),
(128327, 9173, 'Shoujo Kakumei Utena [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/seqtolbLN6gZHd8Pb0A38kJhwmt.jpg'),
(128328, 9173, 'Shoujo Kakumei Utena [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zcK284o8dDAYEXj4HEXcm7iG8Ok.jpg'),
(128329, 9173, 'Shoujo Kakumei Utena [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xjAEbzHAz6tS6ta0gE8yzTJS79d.jpg'),
(128330, 9173, 'Shoujo Kakumei Utena [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yf0YLD6ngvk2wfFKcEq9TsY9Vnp.jpg'),
(128331, 9173, 'Shoujo Kakumei Utena [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lq5Dji3VovxPsuLwjWkUnnnMVsv.jpg'),
(128332, 9173, 'Shoujo Kakumei Utena [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lMBpJLp74Sc9ruB6tztGO5QPX2i.jpg'),
(128333, 9173, 'Shoujo Kakumei Utena [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/70v9ylmPDJT3FnpkPd3Qf2VwgQc.jpg'),
(128334, 9173, 'Shoujo Kakumei Utena [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/253257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pR88C6t7ysTiSbD9WoAtvYetkOk.jpg'),
(128335, 9173, 'Shoujo Kakumei Utena [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/253258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jxlUAKRgEL7x4KxYzF5XozEy3e5.jpg'),
(128336, 9173, 'Shoujo Kakumei Utena [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/253259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gRKNzyZAxx3DTzJn7jiIfSDzSO1.jpg'),
(128337, 9173, 'Shoujo Kakumei Utena [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/253260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/BWGHBf6PzOHfRBwemWLVqmQSD6.jpg'),
(128338, 9173, 'Shoujo Kakumei Utena [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/253261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/egIkZyXffy4u36tklOrhaj6hRbC.jpg'),
(128339, 9173, 'Shoujo Kakumei Utena [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/253262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/28EyLBpxRkQ8BNaO3rcsFBlAmNG.jpg'),
(128340, 9173, 'Shoujo Kakumei Utena [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/253263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/acrwgS1WemzEDXXDZDiuN7DWmJN.jpg'),
(128341, 9173, 'Shoujo Kakumei Utena [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/253264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bDkiIhHoxD3HfC3ITuWArEbnlT0.jpg'),
(128342, 9173, 'Shoujo Kakumei Utena [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/253265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1KekVTKoRueQhIBOOUZEAYUP0i.jpg'),
(128343, 9173, 'Shoujo Kakumei Utena [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/253266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y5hi1boRX9TopZqPReUFNWgHqtt.jpg'),
(128344, 9173, 'Shoujo Kakumei Utena [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/253267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nI9Ci8nFvNWRbQkmC6STyAfLcLA.jpg'),
(128345, 9173, 'Shoujo Kakumei Utena [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/253268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uAYJrHrJ9hJ1FuBZenhG3d6CHG5.jpg'),
(128346, 9173, 'Shoujo Kakumei Utena [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/253269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKRYsRcPmEwMXTE7gbCux5gHDBT.jpg'),
(128347, 9173, 'Shoujo Kakumei Utena [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/253270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kfiiHGeviVb1mxsvKD75AYlmxYt.jpg'),
(128348, 9173, 'Shoujo Kakumei Utena [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/253271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QysUPCDcLf27WwYUxO6viJzYkN.jpg'),
(128349, 9173, 'Shoujo Kakumei Utena [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/253272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u8Npi0qyKO5azhBczFk9BIIZOQA.jpg'),
(128350, 9173, 'Shoujo Kakumei Utena [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/253273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/go7ne5dnEFxRbbaFtr3jf7AsvyC.jpg'),
(128351, 9173, 'Shoujo Kakumei Utena [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/253274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ghi44ZUSBRTXSdys3ME6JRg8wd.jpg'),
(128352, 9173, 'Shoujo Kakumei Utena [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/253275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i2Z9VLgpwwkKtoNeNB5X6os2Nd0.jpg'),
(128353, 9173, 'Shoujo Kakumei Utena [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/253276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oBcbD102AFJZpe9XJMycX6EtK6m.jpg'),
(128354, 9173, 'Shoujo Kakumei Utena [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/253277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hyDThdfsrsQeLt39196FsAqGikG.jpg'),
(128355, 9173, 'Shoujo Kakumei Utena [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/253278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oTpzA3aM2j0B52m5XJPhLPVB5P0.jpg'),
(128356, 9173, 'Shoujo Kakumei Utena [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/253279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fo4XtblyIekbqdGLxZt3JfA9PlL.jpg'),
(128357, 9173, 'Shoujo Kakumei Utena [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/253280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qabmSzaGYpoETYuwn2TeZFzmsYC.jpg'),
(128358, 9173, 'Shoujo Kakumei Utena [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/253281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6WAGjcqdU5Hymupim6zfm66PcVJ.jpg'),
(128359, 9173, 'Shoujo Kakumei Utena [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/253282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ucjBrOSuSZLJln16bWGQyncM84h.jpg'),
(128360, 9173, 'Shoujo Kakumei Utena [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/253283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pOjDuclpsWGV13Nj7XtZukuZj6f.jpg'),
(128361, 9174, 'Somente VIP [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5AScMK3VVb3cIlkwlC3oGDcL6MF.jpg'),
(128362, 9174, 'Somente VIP [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xpHZof17p9JPxZ3XE85oz86hpkj.jpg'),
(128363, 9174, 'Somente VIP [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4EQ9WQnIWlD2hWSfncsWqbFeoi3.jpg'),
(128364, 9174, 'Somente VIP [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dRhYWnGnndKdpNQa83h48YudaxU.jpg'),
(128365, 9174, 'Somente VIP [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pnKy26YHBFdLqyeCi60sJucycR.jpg'),
(128366, 9174, 'Somente VIP [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pnKy26YHBFdLqyeCi60sJucycR.jpg'),
(128367, 9174, 'Somente VIP [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pnKy26YHBFdLqyeCi60sJucycR.jpg'),
(128368, 9174, 'Somente VIP [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pnKy26YHBFdLqyeCi60sJucycR.jpg'),
(128369, 9174, 'Somente VIP [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pnKy26YHBFdLqyeCi60sJucycR.jpg'),
(128370, 9174, 'Somente VIP [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1pnKy26YHBFdLqyeCi60sJucycR.jpg'),
(128371, 9175, 'Spicy Girl [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oJEVmcAKjTztwgOEAEDOVhkrWb3.jpg'),
(128372, 9175, 'Spicy Girl [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s4GWkVYqGx75SSCW9dILmkUfmLo.jpg'),
(128373, 9175, 'Spicy Girl [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nL9PEhIWSVzLnXhSW1y1WbE7u7n.jpg'),
(128374, 9175, 'Spicy Girl [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylYwbA7Ouv3hrVgA1TYZbYAsBZt.jpg'),
(128375, 9175, 'Spicy Girl [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylYwbA7Ouv3hrVgA1TYZbYAsBZt.jpg'),
(128376, 9175, 'Spicy Girl [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylYwbA7Ouv3hrVgA1TYZbYAsBZt.jpg'),
(128377, 9175, 'Spicy Girl [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylYwbA7Ouv3hrVgA1TYZbYAsBZt.jpg'),
(128378, 9175, 'Spicy Girl [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylYwbA7Ouv3hrVgA1TYZbYAsBZt.jpg'),
(128379, 9175, 'Spicy Girl [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylYwbA7Ouv3hrVgA1TYZbYAsBZt.jpg'),
(128380, 9175, 'Spicy Girl [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylYwbA7Ouv3hrVgA1TYZbYAsBZt.jpg'),
(128381, 9175, 'Spicy Girl [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylYwbA7Ouv3hrVgA1TYZbYAsBZt.jpg'),
(128382, 9175, 'Spicy Girl [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylYwbA7Ouv3hrVgA1TYZbYAsBZt.jpg'),
(128383, 9175, 'Spicy Girl [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/253233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylYwbA7Ouv3hrVgA1TYZbYAsBZt.jpg'),
(128384, 9175, 'Spicy Girl [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/253234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylYwbA7Ouv3hrVgA1TYZbYAsBZt.jpg'),
(128385, 9175, 'Spicy Girl [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/253235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylYwbA7Ouv3hrVgA1TYZbYAsBZt.jpg'),
(128386, 9175, 'Spicy Girl [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/253236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylYwbA7Ouv3hrVgA1TYZbYAsBZt.jpg'),
(128387, 9175, 'Spicy Girl [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/253237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylYwbA7Ouv3hrVgA1TYZbYAsBZt.jpg'),
(128388, 9175, 'Spicy Girl [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/253238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylYwbA7Ouv3hrVgA1TYZbYAsBZt.jpg'),
(128389, 9175, 'Spicy Girl [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/253239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylYwbA7Ouv3hrVgA1TYZbYAsBZt.jpg'),
(128390, 9175, 'Spicy Girl [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/253240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylYwbA7Ouv3hrVgA1TYZbYAsBZt.jpg'),
(128391, 9175, 'Spicy Girl [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/253241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylYwbA7Ouv3hrVgA1TYZbYAsBZt.jpg'),
(128392, 9175, 'Spicy Girl [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/253242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylYwbA7Ouv3hrVgA1TYZbYAsBZt.jpg'),
(128393, 9175, 'Spicy Girl [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/253243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylYwbA7Ouv3hrVgA1TYZbYAsBZt.jpg'),
(128394, 9175, 'Spicy Girl [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/253244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylYwbA7Ouv3hrVgA1TYZbYAsBZt.jpg'),
(128395, 9176, 'Your Pretty Face Is Going to Hell [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cXGGyBm75zoCGVwiU4rdmJ5Zqxs.jpg'),
(128396, 9176, 'Your Pretty Face Is Going to Hell [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/44kXuDLzEk7E2lxRCS1UeCoKV4e.jpg'),
(128397, 9176, 'Your Pretty Face Is Going to Hell [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8FrqnfKTYIPh1YnLkg0jnpDYAAR.jpg'),
(128398, 9176, 'Your Pretty Face Is Going to Hell [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cESIGjHpdhZBJtNHm8dkxzhD8SV.jpg'),
(128399, 9176, 'Your Pretty Face Is Going to Hell [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQE3QR6tStv9GcAWDcAKnN9uGKR.jpg'),
(128400, 9176, 'Your Pretty Face Is Going to Hell [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2XLpTrioXerI9O5ONzZG1sNVjIN.jpg'),
(128401, 9177, 'Your Pretty Face Is Going to Hell [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ovu9triUGWLnI0jkjqc3fW5jdkB.jpg'),
(128402, 9177, 'Your Pretty Face Is Going to Hell [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lcyPo1FZb80o73sklLcnSK4bi0o.jpg'),
(128403, 9177, 'Your Pretty Face Is Going to Hell [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7MVnUk8ZlKK1mXLCbi5Ot4gZ8sH.jpg'),
(128404, 9177, 'Your Pretty Face Is Going to Hell [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/omp22A9PbHDYwMR3CMY7bHydNVT.jpg'),
(128405, 9177, 'Your Pretty Face Is Going to Hell [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jL2LaIWkIxXUnPdMYOvqFIvM0x5.jpg'),
(128406, 9177, 'Your Pretty Face Is Going to Hell [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ifbQn8lBsCZqfAfIHZboKYRucTd.jpg'),
(128407, 9177, 'Your Pretty Face Is Going to Hell [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5aSJcaoUkuPexZXJeOl6j4RPnFY.jpg'),
(128408, 9177, 'Your Pretty Face Is Going to Hell [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oeu0avatjYJpdCG7RwFrZEJlWHq.jpg'),
(128409, 9177, 'Your Pretty Face Is Going to Hell [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCoRR7FPv41Px3wQNnO0rMMH54b.jpg'),
(128410, 9177, 'Your Pretty Face Is Going to Hell [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6fDfDRf6XH3Oc7t6ichFZax2d9b.jpg'),
(128411, 9177, 'Your Pretty Face Is Going to Hell [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5mzmGb6QFVTOeHNSfxhev5JAnF0.jpg'),
(128412, 9177, 'Your Pretty Face Is Going to Hell [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uV3hbCxWRMdH85e93QZv25WSpc8.jpg'),
(128413, 9178, 'Your Pretty Face Is Going to Hell [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g3pwi9aiJ5yKQDBK3GkqFHOQfQe.jpg'),
(128414, 9178, 'Your Pretty Face Is Going to Hell [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ap5BFnHFeY1QoySvsaTnh09KCa0.jpg'),
(128415, 9178, 'Your Pretty Face Is Going to Hell [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rZ0dU1GCSE0kWeXHYaZQ2atii5M.jpg'),
(128416, 9178, 'Your Pretty Face Is Going to Hell [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nT4FgPoJ1qXg2R6pe9AHc6oBe6n.jpg'),
(128417, 9178, 'Your Pretty Face Is Going to Hell [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iyzQ92OdUw5IHZyKKTPtZTlX7H.jpg'),
(128418, 9178, 'Your Pretty Face Is Going to Hell [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6e376ozQQh6o8uYp38lPQq8k09Z.jpg'),
(128419, 9178, 'Your Pretty Face Is Going to Hell [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1RdDTwzhkNc1QIvPnhlNTtbeTln.jpg'),
(128420, 9178, 'Your Pretty Face Is Going to Hell [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hqPQSP4H1ZRfsFSV93zqsYCpix7.jpg'),
(128421, 9178, 'Your Pretty Face Is Going to Hell [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MYW1Gr6igRfGKjYPvQBkulPXIZ.jpg'),
(128422, 9178, 'Your Pretty Face Is Going to Hell [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/larGbFoWelgp3aSWTP8vuu42nB1.jpg'),
(128423, 9178, 'Your Pretty Face Is Going to Hell [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ccBrnEaGhOmtSUMFm9bu0xoNRhB.jpg'),
(128424, 9178, 'Your Pretty Face Is Going to Hell [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jEqujMoAque9Tn2K5mb3K3CfGmM.jpg'),
(128425, 9179, 'Your Pretty Face Is Going to Hell [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qI84DUGJkc1wTcZqPwGF75wF6gR.jpg'),
(128426, 9179, 'Your Pretty Face Is Going to Hell [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vSxqg0yELKy2wZcqB1J6AZWfBg0.jpg'),
(128427, 9179, 'Your Pretty Face Is Going to Hell [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9rJdgmT1X6GdUKUxUXQJVydJIAs.jpg'),
(128428, 9179, 'Your Pretty Face Is Going to Hell [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzETpqcK9HTxG36fyjjugJPXXg0.jpg'),
(128429, 9179, 'Your Pretty Face Is Going to Hell [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/onQoycOJY40eBeMIlqmONh8A8ZT.jpg'),
(128430, 9179, 'Your Pretty Face Is Going to Hell [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/evJ8L2Uic19z2sUqhn0fC2czPeS.jpg'),
(128431, 9179, 'Your Pretty Face Is Going to Hell [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5KRMmpI7kj9TaLPDofjFcpcumuJ.jpg'),
(128432, 9179, 'Your Pretty Face Is Going to Hell [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jJa6yFbkoEtknZj5SpsTSg0wD1X.jpg'),
(128433, 9179, 'Your Pretty Face Is Going to Hell [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/idkahLGIqVRKRgPY8nNDJHw9f8V.jpg'),
(128434, 9179, 'Your Pretty Face Is Going to Hell [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6MnHIoJZubsv5XCAgFP1DYNdDgm.jpg'),
(128435, 9179, 'Your Pretty Face Is Going to Hell [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/253219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Jot8cKoL4j1B5s4dsDIgDCcgKc.jpg'),
(128436, 9179, 'Your Pretty Face Is Going to Hell [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/253220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lGxWGlYcSCWDmc5ydjhABSIxIZD.jpg'),
(128437, 9180, 'Jogos do Destino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tvbOKQhZArpSRDVrskp3Cl2NvvD.jpg'),
(128438, 9180, 'Jogos do Destino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uSqixRf8lyVj1Nl91YOHsWkAu2G.jpg'),
(128439, 9180, 'Jogos do Destino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vqRh3vaCwCTG2mOd34DYbsdWeXX.jpg'),
(128440, 9180, 'Jogos do Destino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7BTRh2aE9SDiqJY4zw6kLG2UTFf.jpg'),
(128441, 9180, 'Jogos do Destino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q1Chqr0VtBPVipMRcGoORzfCNWw.jpg'),
(128442, 9180, 'Jogos do Destino S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a5SyPXPJqO2t2pUHi6Js6QiRbgV.jpg'),
(128443, 9180, 'Jogos do Destino S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ySpa81AlkPfUdqkMyrl3eWYA6eE.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(128444, 9180, 'Jogos do Destino S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hcKlLG360iHv3wV7fy7GJxYpTM5.jpg'),
(128445, 9180, 'Jogos do Destino S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qC3yaSMkg8SWQyEaVnLninVlLCW.jpg'),
(128446, 9180, 'Jogos do Destino S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qnez2EzYJqXwXVaolrrgoa4cAPH.jpg'),
(128447, 9180, 'Jogos do Destino S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/261715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128448, 9180, 'Jogos do Destino S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/261716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128449, 9180, 'Jogos do Destino S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/261717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128450, 9180, 'Jogos do Destino S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/261718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128451, 9180, 'Jogos do Destino S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/261719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128452, 9180, 'Jogos do Destino S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/261720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128453, 9180, 'Jogos do Destino S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/261721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128454, 9180, 'Jogos do Destino S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/261722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128455, 9180, 'Jogos do Destino S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/261723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128456, 9180, 'Jogos do Destino S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/261724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128457, 9180, 'Jogos do Destino S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/261725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128458, 9180, 'Jogos do Destino S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/261726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128459, 9180, 'Jogos do Destino S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/261727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128460, 9180, 'Jogos do Destino S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/261728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128461, 9180, 'Jogos do Destino S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/261729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128462, 9180, 'Jogos do Destino S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/261730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128463, 9180, 'Jogos do Destino S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/261731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128464, 9180, 'Jogos do Destino S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/261732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128465, 9180, 'Jogos do Destino S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/261733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128466, 9180, 'Jogos do Destino S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/261734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128467, 9180, 'Jogos do Destino S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/261735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128468, 9180, 'Jogos do Destino S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/261736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128469, 9180, 'Jogos do Destino S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/261737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128470, 9180, 'Jogos do Destino S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/261738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128471, 9180, 'Jogos do Destino S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/261739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128472, 9180, 'Jogos do Destino S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/261740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128473, 9180, 'Jogos do Destino S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/261741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128474, 9180, 'Jogos do Destino S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/261742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128475, 9180, 'Jogos do Destino S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/261743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128476, 9180, 'Jogos do Destino S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/261744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128477, 9180, 'Jogos do Destino S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/261745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128478, 9180, 'Jogos do Destino S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/261746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128479, 9180, 'Jogos do Destino S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/261747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128480, 9180, 'Jogos do Destino S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/261748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128481, 9180, 'Jogos do Destino S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/261749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128482, 9180, 'Jogos do Destino S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/261750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128483, 9180, 'Jogos do Destino S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/261751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128484, 9180, 'Jogos do Destino S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/261752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128485, 9180, 'Jogos do Destino S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/261753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128486, 9180, 'Jogos do Destino S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/261754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128487, 9180, 'Jogos do Destino S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/261755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128488, 9180, 'Jogos do Destino S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/261756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128489, 9180, 'Jogos do Destino S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/261757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128490, 9180, 'Jogos do Destino S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/261758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128491, 9180, 'Jogos do Destino S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/261759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128492, 9180, 'Jogos do Destino S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/261760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128493, 9180, 'Jogos do Destino S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/261761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128494, 9180, 'Jogos do Destino S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/261762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmMfq72zwuhh2OsPG2o6muZ3aF7.jpg'),
(128495, 9181, '90 Dias para Casar Antes dos 90 Dias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AhJZt7vA06Ubl8U5TQLYCUwbtUl.jpg'),
(128496, 9181, '90 Dias para Casar Antes dos 90 Dias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vd2dDm81Z3DLfxt7659bk5iB8li.jpg'),
(128497, 9181, '90 Dias para Casar Antes dos 90 Dias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3fEz5mRj5zsWwMBZ3i4dTgfSn6a.jpg'),
(128498, 9181, '90 Dias para Casar Antes dos 90 Dias S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aeSKlSYULFo0XU43lvZPdn2SSBk.jpg'),
(128499, 9181, '90 Dias para Casar Antes dos 90 Dias S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2k2M0SjXMEDVXkRVym4iuRc4eb4.jpg'),
(128500, 9181, '90 Dias para Casar Antes dos 90 Dias S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fWRj1qWt2PdBxCcqPozYzHm5wAB.jpg'),
(128501, 9181, '90 Dias para Casar Antes dos 90 Dias S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ahL7UATBzuGN9BuA9Y9haS2a0jx.jpg'),
(128502, 9181, '90 Dias para Casar Antes dos 90 Dias S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/av0ASb7LedbMAxdoum2W3ebZs51.jpg'),
(128503, 9181, '90 Dias para Casar Antes dos 90 Dias S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xj3wkpDEuX5xKMsov1hEZiTk1zB.jpg'),
(128504, 9181, '90 Dias para Casar Antes dos 90 Dias S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AdfpgSEUJRhDUXXsHlIKbuz5iij.jpg'),
(128505, 9181, '90 Dias para Casar Antes dos 90 Dias S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r58CgdyFOGuvh6djB1U5pm6Cc5k.jpg'),
(128506, 9181, '90 Dias para Casar Antes dos 90 Dias S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uB0uCURfZYyvQ7vUCIk4LhjEnsN.jpg'),
(128507, 9181, '90 Dias para Casar Antes dos 90 Dias S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dAmBOVLSuC0faIfEEd43rps69w8.jpg'),
(128508, 9181, '90 Dias para Casar Antes dos 90 Dias S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iXzKZYEZoW3Pf0n8RUEGpv04wmp.jpg'),
(128509, 9182, '90 Dias para Casar Antes dos 90 Dias S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lqZzv97pACrMCDrvARi8UJLxSec.jpg'),
(128510, 9182, '90 Dias para Casar Antes dos 90 Dias S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t0ih0jNUFbhv9EgkRlAX17GoBZD.jpg'),
(128511, 9182, '90 Dias para Casar Antes dos 90 Dias S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xp1nQHQnyPeFXgvcZSiuVFflJs2.jpg'),
(128512, 9182, '90 Dias para Casar Antes dos 90 Dias S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rqZua7wu0mdtdInTL20Bz4hlDOh.jpg'),
(128513, 9182, '90 Dias para Casar Antes dos 90 Dias S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSt2SEaL08C87qsahkwgXfICG8u.jpg'),
(128514, 9182, '90 Dias para Casar Antes dos 90 Dias S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uCLEjbfOBpYULcQkNLCbMMlqYAI.jpg'),
(128515, 9182, '90 Dias para Casar Antes dos 90 Dias S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8QQoNLUkVWSKAQJRvj5Mz3y3wXw.jpg'),
(128516, 9182, '90 Dias para Casar Antes dos 90 Dias S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9UWKZdiTFbhpMa0EMKVpQuJ0dgi.jpg'),
(128517, 9182, '90 Dias para Casar Antes dos 90 Dias S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mdkMrc621JDg3yVZuyBWKcJzVFq.jpg'),
(128518, 9182, '90 Dias para Casar Antes dos 90 Dias S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/625AAekqqdgAGSfTXUf3EW9AD0B.jpg'),
(128519, 9182, '90 Dias para Casar Antes dos 90 Dias S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9DUM45p2T5fU4VMwms6ymZK2Bc.jpg'),
(128520, 9183, '90 Dias para Casar Antes dos 90 Dias S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gUpQ1kcmmCD2gufRfD3bzRncoWP.jpg'),
(128521, 9183, '90 Dias para Casar Antes dos 90 Dias S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ouWMHDXirv007AzyzuTrztRObBf.jpg'),
(128522, 9183, '90 Dias para Casar Antes dos 90 Dias S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w1yFMarRVCjbnJP7USs99Qltfq1.jpg'),
(128523, 9183, '90 Dias para Casar Antes dos 90 Dias S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4uaNBHdwKEjqnYlpTN03qCKEPQe.jpg'),
(128524, 9183, '90 Dias para Casar Antes dos 90 Dias S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eIRJe0Ti2GXjdPH8sXOjOEfRyPn.jpg'),
(128525, 9183, '90 Dias para Casar Antes dos 90 Dias S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4A9iGvSYbFcJtByUiM8NG29nhKM.jpg'),
(128526, 9183, '90 Dias para Casar Antes dos 90 Dias S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Yjuj6OKNTeSIDqiMoHVXLsFDcc.jpg'),
(128527, 9183, '90 Dias para Casar Antes dos 90 Dias S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nm4ml3g023zxe81WNSUnj9jQISt.jpg'),
(128528, 9183, '90 Dias para Casar Antes dos 90 Dias S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/niw3Eai1zPWKhvihyWRCKO88sEM.jpg'),
(128529, 9183, '90 Dias para Casar Antes dos 90 Dias S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Q21Ovr6XMMYVigDfPsa9l4LZue.jpg'),
(128530, 9183, '90 Dias para Casar Antes dos 90 Dias S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u5pxPq3nrfnyUdkOyMb6qtjb02x.jpg'),
(128531, 9183, '90 Dias para Casar Antes dos 90 Dias S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cyKlbVQY4InoWgIbt737Wb1oT6A.jpg'),
(128532, 9183, '90 Dias para Casar Antes dos 90 Dias S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bGaWK0dy7pQ0mDmeCkWp0j6hHzg.jpg'),
(128533, 9183, '90 Dias para Casar Antes dos 90 Dias S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fxj5FG10XwDo42RNAoNBoGNFi9d.jpg'),
(128534, 9183, '90 Dias para Casar Antes dos 90 Dias S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfCq35DZ7XgukA4Nmc1YWl02GrK.jpg'),
(128535, 9184, '90 Dias para Casar Antes dos 90 Dias S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oZp3UPyWa59NLqyqBV5SLyqta6N.jpg'),
(128536, 9184, '90 Dias para Casar Antes dos 90 Dias S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kN0bAlobEuvJLGxoM0uQQ0MGakP.jpg'),
(128537, 9184, '90 Dias para Casar Antes dos 90 Dias S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/68XlP9Halzg8zrHHeIhveXzNtmY.jpg'),
(128538, 9184, '90 Dias para Casar Antes dos 90 Dias S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzkF7AF6AWN0RRUpJ1XUQKr6Ezn.jpg'),
(128539, 9184, '90 Dias para Casar Antes dos 90 Dias S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bR9AgmSbnHEx73mzcXPRaJ9Jvhg.jpg'),
(128540, 9184, '90 Dias para Casar Antes dos 90 Dias S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9sAx9WIHdOIzZmUEWOWGjhh27f9.jpg'),
(128541, 9184, '90 Dias para Casar Antes dos 90 Dias S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zFBbtLuWJVQbYCeXClmp9wTzToR.jpg'),
(128542, 9184, '90 Dias para Casar Antes dos 90 Dias S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xniXd6oHruWrkMVUrrjswoG0nff.jpg'),
(128543, 9184, '90 Dias para Casar Antes dos 90 Dias S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wEsCIgL2ochzvdMFPCyYM0fTziI.jpg'),
(128544, 9184, '90 Dias para Casar Antes dos 90 Dias S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tiEcO17K5h5btr1n1KVC1khk67S.jpg'),
(128545, 9184, '90 Dias para Casar Antes dos 90 Dias S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lys8UKcC4qLusttZoWZoesabVUO.jpg'),
(128546, 9184, '90 Dias para Casar Antes dos 90 Dias S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hAyKLSyzshdzYvHoc2ty4N2T71u.jpg'),
(128547, 9184, '90 Dias para Casar Antes dos 90 Dias S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4JPVMPhh8G27Y9MwFOWwfzB9qTQ.jpg'),
(128548, 9184, '90 Dias para Casar Antes dos 90 Dias S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tBkZaCRc1l7uUtjUjq9VTc2ccME.jpg'),
(128549, 9184, '90 Dias para Casar Antes dos 90 Dias S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lD2NrndXRcc0ubNch1zRX9tau6O.jpg'),
(128550, 9184, '90 Dias para Casar Antes dos 90 Dias S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wL0IWzt6QZa4Zm7mSMTAhhT7Q5A.jpg'),
(128551, 9184, '90 Dias para Casar Antes dos 90 Dias S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sgZwqakZvoxsenckROXegmJ62jq.jpg'),
(128552, 9184, '90 Dias para Casar Antes dos 90 Dias S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/265208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128553, 9185, '90 Dias para Casar Antes dos 90 Dias S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4vyVjfqr3mLCRhDyIJrfcAxXnvR.jpg'),
(128554, 9185, '90 Dias para Casar Antes dos 90 Dias S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lv9bmNeS0nR4ENhTcsbc7XA55vI.jpg'),
(128555, 9185, '90 Dias para Casar Antes dos 90 Dias S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/heguHqmxDEmWG2QW6M4IWitOpt4.jpg'),
(128556, 9185, '90 Dias para Casar Antes dos 90 Dias S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Qde14jXsVtopolHAdV1j1GI8JB.jpg'),
(128557, 9185, '90 Dias para Casar Antes dos 90 Dias S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8c78LycEWp50hjyAi0FXXW8QHfA.jpg'),
(128558, 9185, '90 Dias para Casar Antes dos 90 Dias S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ejKaVF0Ht05OAahvvjxFFL0BK2o.jpg'),
(128559, 9185, '90 Dias para Casar Antes dos 90 Dias S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128560, 9185, '90 Dias para Casar Antes dos 90 Dias S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128561, 9185, '90 Dias para Casar Antes dos 90 Dias S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128562, 9185, '90 Dias para Casar Antes dos 90 Dias S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128563, 9185, '90 Dias para Casar Antes dos 90 Dias S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128564, 9185, '90 Dias para Casar Antes dos 90 Dias S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128565, 9185, '90 Dias para Casar Antes dos 90 Dias S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128566, 9185, '90 Dias para Casar Antes dos 90 Dias S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/273450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128567, 9185, '90 Dias para Casar Antes dos 90 Dias S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/277257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128568, 9185, '90 Dias para Casar Antes dos 90 Dias S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/279322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128569, 9185, '90 Dias para Casar Antes dos 90 Dias S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/596500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128570, 9185, '90 Dias para Casar Antes dos 90 Dias S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/296193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128571, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/806886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128572, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/810399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128573, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/810400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128574, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/822863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128575, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/834038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128576, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/842145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128577, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/849082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128578, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/860089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128579, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/862296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128580, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/868514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128581, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/872789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128582, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/878898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128583, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/879592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128584, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/880076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128585, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/881268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128586, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/881999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128587, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/882000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128588, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/883577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128589, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/884171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128590, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/885871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128591, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/886299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128592, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/887765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128593, 9186, '90 Dias para Casar Antes dos 90 Dias S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/888265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5QWCNZfcUgYlEmD7kMuyerjVFmz.jpg'),
(128594, 9187, '99 9 Advogado Criminal [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yO6acfSQKJYMaG637JZZWWhns5z.jpg'),
(128595, 9187, '99 9 Advogado Criminal [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vggoSzkHtqnCsLljIEi9TKbeWu8.jpg'),
(128596, 9187, '99 9 Advogado Criminal [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n1UOh2ETjl2DiQL3yE2mIXkNf9b.jpg'),
(128597, 9187, '99 9 Advogado Criminal [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8tDlkAF6GrvUs5VhXxBJbzs7VV2.jpg'),
(128598, 9187, '99 9 Advogado Criminal [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kAmu03DUMQiNKGxhKNLuKpLJ18e.jpg'),
(128599, 9187, '99 9 Advogado Criminal [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eTMUjfwHZe9mn4BeogE3Nh8Jibu.jpg'),
(128600, 9187, '99 9 Advogado Criminal [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v9WKo1ymEUZCIf2L2feqX00mlLK.jpg'),
(128601, 9187, '99 9 Advogado Criminal [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cfw97zB77DsmVI3RdGdZGpnZJOB.jpg'),
(128602, 9187, '99 9 Advogado Criminal [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kUaQBpT1NswHrX3LhCIXXXrFke1.jpg'),
(128603, 9187, '99 9 Advogado Criminal [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOrc6z6zxEQZeRo4sX14YvLNl5O.jpg'),
(128604, 9188, '99 9 Advogado Criminal [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rIxvmTjqwazKulnOHUz3YboggDn.jpg'),
(128605, 9188, '99 9 Advogado Criminal [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdGwuOK7EyBq9Vy2QYRv259hbUE.jpg'),
(128606, 9188, '99 9 Advogado Criminal [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xku6J4IF81A16lgaJYbOoTwhR8q.jpg'),
(128607, 9188, '99 9 Advogado Criminal [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ndYqvwg2CTjsrP99mFdL4B3pmE.jpg'),
(128608, 9188, '99 9 Advogado Criminal [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sLwvjYgwcuaAt6Tv19ziwncr3xy.jpg'),
(128609, 9188, '99 9 Advogado Criminal [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t3MIXEQBTflckBRlqwvNKN28XBB.jpg'),
(128610, 9188, '99 9 Advogado Criminal [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qrH2YJfvY5R5z4vttPdiopQr6hc.jpg'),
(128611, 9188, '99 9 Advogado Criminal [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/icwckNJgAeKzPCwOgzBRWrro9jN.jpg'),
(128612, 9188, '99 9 Advogado Criminal [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oDzwYpmKUgcIgdnE6uZz0ImJNlo.jpg'),
(128613, 9189, '99 9 Advogado Criminal [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/887042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ex8Rr04vsjp6EB55t7eCAE0tCNt.jpg'),
(128614, 9190, 'A Batalha dos Piores Cozinheiros S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128615, 9190, 'A Batalha dos Piores Cozinheiros S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128616, 9190, 'A Batalha dos Piores Cozinheiros S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128617, 9190, 'A Batalha dos Piores Cozinheiros S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128618, 9190, 'A Batalha dos Piores Cozinheiros S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128619, 9190, 'A Batalha dos Piores Cozinheiros S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128620, 9190, 'A Batalha dos Piores Cozinheiros S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128621, 9190, 'A Batalha dos Piores Cozinheiros S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128622, 9191, 'A Batalha dos Piores Cozinheiros S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128623, 9191, 'A Batalha dos Piores Cozinheiros S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128624, 9191, 'A Batalha dos Piores Cozinheiros S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128625, 9191, 'A Batalha dos Piores Cozinheiros S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128626, 9191, 'A Batalha dos Piores Cozinheiros S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128627, 9191, 'A Batalha dos Piores Cozinheiros S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128628, 9191, 'A Batalha dos Piores Cozinheiros S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128629, 9191, 'A Batalha dos Piores Cozinheiros S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128630, 9191, 'A Batalha dos Piores Cozinheiros S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128631, 9191, 'A Batalha dos Piores Cozinheiros S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128632, 9192, 'A Batalha dos Piores Cozinheiros S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128633, 9192, 'A Batalha dos Piores Cozinheiros S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128634, 9192, 'A Batalha dos Piores Cozinheiros S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128635, 9192, 'A Batalha dos Piores Cozinheiros S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128636, 9192, 'A Batalha dos Piores Cozinheiros S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128637, 9192, 'A Batalha dos Piores Cozinheiros S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128638, 9192, 'A Batalha dos Piores Cozinheiros S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128639, 9192, 'A Batalha dos Piores Cozinheiros S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128640, 9193, 'A Batalha dos Piores Cozinheiros S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128641, 9193, 'A Batalha dos Piores Cozinheiros S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128642, 9193, 'A Batalha dos Piores Cozinheiros S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128643, 9193, 'A Batalha dos Piores Cozinheiros S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128644, 9193, 'A Batalha dos Piores Cozinheiros S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128645, 9193, 'A Batalha dos Piores Cozinheiros S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128646, 9193, 'A Batalha dos Piores Cozinheiros S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128647, 9193, 'A Batalha dos Piores Cozinheiros S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128648, 9193, 'A Batalha dos Piores Cozinheiros S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128649, 9193, 'A Batalha dos Piores Cozinheiros S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128650, 9194, 'A Batalha dos Piores Cozinheiros S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128651, 9194, 'A Batalha dos Piores Cozinheiros S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128652, 9194, 'A Batalha dos Piores Cozinheiros S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128653, 9194, 'A Batalha dos Piores Cozinheiros S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128654, 9194, 'A Batalha dos Piores Cozinheiros S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128655, 9194, 'A Batalha dos Piores Cozinheiros S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128656, 9195, 'A Batalha dos Piores Cozinheiros S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128657, 9195, 'A Batalha dos Piores Cozinheiros S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128658, 9195, 'A Batalha dos Piores Cozinheiros S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128659, 9195, 'A Batalha dos Piores Cozinheiros S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128660, 9195, 'A Batalha dos Piores Cozinheiros S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128661, 9195, 'A Batalha dos Piores Cozinheiros S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128662, 9195, 'A Batalha dos Piores Cozinheiros S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128663, 9195, 'A Batalha dos Piores Cozinheiros S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128664, 9196, 'A Batalha dos Piores Cozinheiros S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128665, 9196, 'A Batalha dos Piores Cozinheiros S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128666, 9196, 'A Batalha dos Piores Cozinheiros S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128667, 9196, 'A Batalha dos Piores Cozinheiros S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/588339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128668, 9196, 'A Batalha dos Piores Cozinheiros S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128669, 9196, 'A Batalha dos Piores Cozinheiros S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128670, 9196, 'A Batalha dos Piores Cozinheiros S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128671, 9197, 'A Batalha dos Piores Cozinheiros S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128672, 9197, 'A Batalha dos Piores Cozinheiros S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128673, 9197, 'A Batalha dos Piores Cozinheiros S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128674, 9197, 'A Batalha dos Piores Cozinheiros S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128675, 9197, 'A Batalha dos Piores Cozinheiros S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128676, 9197, 'A Batalha dos Piores Cozinheiros S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128677, 9197, 'A Batalha dos Piores Cozinheiros S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128678, 9197, 'A Batalha dos Piores Cozinheiros S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128679, 9197, 'A Batalha dos Piores Cozinheiros S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128680, 9198, 'A Batalha dos Piores Cozinheiros S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128681, 9198, 'A Batalha dos Piores Cozinheiros S18 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128682, 9198, 'A Batalha dos Piores Cozinheiros S18 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128683, 9198, 'A Batalha dos Piores Cozinheiros S18 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128684, 9198, 'A Batalha dos Piores Cozinheiros S18 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128685, 9198, 'A Batalha dos Piores Cozinheiros S18 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128686, 9198, 'A Batalha dos Piores Cozinheiros S18 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128687, 9198, 'A Batalha dos Piores Cozinheiros S18 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(128688, 9198, 'A Batalha dos Piores Cozinheiros S18 E09', 'http://sinalprivado.info:80/series/1533784/1533784/253073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128689, 9198, 'A Batalha dos Piores Cozinheiros S18 E10', 'http://sinalprivado.info:80/series/1533784/1533784/253074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128690, 9199, 'A Batalha dos Piores Cozinheiros S19 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128691, 9199, 'A Batalha dos Piores Cozinheiros S19 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128692, 9199, 'A Batalha dos Piores Cozinheiros S19 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128693, 9199, 'A Batalha dos Piores Cozinheiros S19 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128694, 9199, 'A Batalha dos Piores Cozinheiros S19 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128695, 9199, 'A Batalha dos Piores Cozinheiros S19 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128696, 9200, 'A Batalha dos Piores Cozinheiros S21 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128697, 9200, 'A Batalha dos Piores Cozinheiros S21 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128698, 9200, 'A Batalha dos Piores Cozinheiros S21 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128699, 9200, 'A Batalha dos Piores Cozinheiros S21 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128700, 9200, 'A Batalha dos Piores Cozinheiros S21 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128701, 9200, 'A Batalha dos Piores Cozinheiros S21 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128702, 9200, 'A Batalha dos Piores Cozinheiros S21 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128703, 9200, 'A Batalha dos Piores Cozinheiros S21 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128704, 9201, 'A Batalha dos Piores Cozinheiros S22 E01', 'http://sinalprivado.info:80/series/1533784/1533784/588376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128705, 9201, 'A Batalha dos Piores Cozinheiros S22 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128706, 9201, 'A Batalha dos Piores Cozinheiros S22 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128707, 9201, 'A Batalha dos Piores Cozinheiros S22 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128708, 9201, 'A Batalha dos Piores Cozinheiros S22 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128709, 9201, 'A Batalha dos Piores Cozinheiros S22 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128710, 9201, 'A Batalha dos Piores Cozinheiros S22 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128711, 9202, 'A Batalha dos Piores Cozinheiros S23 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128712, 9202, 'A Batalha dos Piores Cozinheiros S23 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128713, 9202, 'A Batalha dos Piores Cozinheiros S23 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128714, 9202, 'A Batalha dos Piores Cozinheiros S23 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128715, 9202, 'A Batalha dos Piores Cozinheiros S23 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128716, 9202, 'A Batalha dos Piores Cozinheiros S23 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128717, 9202, 'A Batalha dos Piores Cozinheiros S23 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128718, 9202, 'A Batalha dos Piores Cozinheiros S23 E08', 'http://sinalprivado.info:80/series/1533784/1533784/253103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128719, 9203, 'A Batalha dos Piores Cozinheiros S24 E01', 'http://sinalprivado.info:80/series/1533784/1533784/253104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128720, 9203, 'A Batalha dos Piores Cozinheiros S24 E02', 'http://sinalprivado.info:80/series/1533784/1533784/253105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128721, 9203, 'A Batalha dos Piores Cozinheiros S24 E03', 'http://sinalprivado.info:80/series/1533784/1533784/253106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128722, 9203, 'A Batalha dos Piores Cozinheiros S24 E04', 'http://sinalprivado.info:80/series/1533784/1533784/253107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128723, 9203, 'A Batalha dos Piores Cozinheiros S24 E05', 'http://sinalprivado.info:80/series/1533784/1533784/253108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128724, 9203, 'A Batalha dos Piores Cozinheiros S24 E06', 'http://sinalprivado.info:80/series/1533784/1533784/253109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128725, 9203, 'A Batalha dos Piores Cozinheiros S24 E07', 'http://sinalprivado.info:80/series/1533784/1533784/253110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i2TfbvFNDR8wM0flD1PVv96Xn6x.jpg'),
(128726, 9204, 'A Paranormal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w27IIhZJ57hYo8HOCABUtuxFMrG.jpg'),
(128727, 9204, 'A Paranormal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jPVt77CGtUkQIjYRPg3ULmzEy9w.jpg'),
(128728, 9204, 'A Paranormal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyhHwJ9sVPfexlSXYpmObX73Mhg.jpg'),
(128729, 9204, 'A Paranormal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7TqKxx1UHVoIj9xRQ9EDHBVHJG.jpg'),
(128730, 9204, 'A Paranormal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ptmD9njClFVWPPXGTjHekeXelUH.jpg'),
(128731, 9204, 'A Paranormal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5YgMnBvvTzV6jA8OtEV5gKsruZ.jpg'),
(128732, 9204, 'A Paranormal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8W5jY39lOBOy0g3ZvMLTshpQyKJ.jpg'),
(128733, 9204, 'A Paranormal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVf9OTcCP0gqUDQhVdg1lR3dlZN.jpg'),
(128734, 9204, 'A Paranormal S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ClPc8FFTHN3M4BJSUX4k64jjlq.jpg'),
(128735, 9204, 'A Paranormal S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8DvNz5NqzBwybaQCwpE73cMqR51.jpg'),
(128736, 9204, 'A Paranormal S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pscitVCPWnPddTMboChyf7AEQf0.jpg'),
(128737, 9204, 'A Paranormal S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/54VjLMoLO44jQKgTbS5olFuYYaA.jpg'),
(128738, 9204, 'A Paranormal S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/remDWx5EXNY1QcKTtfANBtRFbTS.jpg'),
(128739, 9204, 'A Paranormal S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/252882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rKZUz35ka4YqyCZeqrlwGFzGn9t.jpg'),
(128740, 9204, 'A Paranormal S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/252883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3l6G1vwE6CL3mbznPLjD0rvGhni.jpg'),
(128741, 9204, 'A Paranormal S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/252884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eNq2H3OJNBbc6c0Nvl7UVdLt4el.jpg'),
(128742, 9205, 'A Paranormal S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yZ06dauVBGuTqPIrcE6zGmdWb9E.jpg'),
(128743, 9205, 'A Paranormal S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/grhClgGAUovD94QNa3ZwfuA8rVA.jpg'),
(128744, 9205, 'A Paranormal S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFCnofx1qTfV2V2I8eQ0x5htuiX.jpg'),
(128745, 9205, 'A Paranormal S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oB9l46PG6wxbtsUfUpGaDvd1odn.jpg'),
(128746, 9205, 'A Paranormal S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9s0TKCc2HprKtNn9PS6x1Nh2TLn.jpg'),
(128747, 9205, 'A Paranormal S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kKffjEp0IXYUkyrVEzPYT4ZBlRN.jpg'),
(128748, 9205, 'A Paranormal S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ktU3JcIdTohLMm6BOPwQUpRzB8c.jpg'),
(128749, 9205, 'A Paranormal S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6nMhjVcCA2x86WX2r3ikU12vs9o.jpg'),
(128750, 9205, 'A Paranormal S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Em0mZTi9rjyg9hqVHETUOaAxU1.jpg'),
(128751, 9205, 'A Paranormal S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c02neTOBHIOE12M4a9nuCQo6TcY.jpg'),
(128752, 9205, 'A Paranormal S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yBLQ68HmXn3vtxB9jK4MY0fardK.jpg'),
(128753, 9205, 'A Paranormal S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cO91oi06TpwkJJVSgKuYseBKR3B.jpg'),
(128754, 9205, 'A Paranormal S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xu4ukoZDiTm7J3Ho8SCQ1JdP8Im.jpg'),
(128755, 9205, 'A Paranormal S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/252898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ahdMKbjjQ9ZKTjlcxMZQ8Uyl4i.jpg'),
(128756, 9205, 'A Paranormal S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/252899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/etXHf4cRDDrSpRSOr3Xb8UBygUG.jpg'),
(128757, 9205, 'A Paranormal S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/252900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/16ogMhqp2mA5WuoTHmcdtPx0KmP.jpg'),
(128758, 9205, 'A Paranormal S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/252901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fZqBGH6skCbvu1ai4pXsDO4NOlL.jpg'),
(128759, 9205, 'A Paranormal S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/252902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eOigFz0iLpUg6UoPYuhgvI3UQmp.jpg'),
(128760, 9205, 'A Paranormal S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/252903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wLfixeurZ9SesrW6hkjvWTz46iu.jpg'),
(128761, 9205, 'A Paranormal S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/252904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AeKoa7TV1DebV6DnoEprhOEEa6u.jpg'),
(128762, 9205, 'A Paranormal S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/252905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zupMIurbXPc7FQ1nFbFVx6zFyhl.jpg'),
(128763, 9205, 'A Paranormal S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/252906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j6wjDcZmrwJPyquZs3fJlHRBZvb.jpg'),
(128764, 9206, 'A Paranormal S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l79p4nuP9r1Hkq5aOWe3aKSgbf3.jpg'),
(128765, 9206, 'A Paranormal S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o3LGFyHbpawl3EtG5mdVsKUku8Y.jpg'),
(128766, 9206, 'A Paranormal S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fElp3uZn5Oe5kFusbVnzeBwUSrG.jpg'),
(128767, 9206, 'A Paranormal S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Cfm6aLgmtUMZjGByqeHhVkDKEL.jpg'),
(128768, 9206, 'A Paranormal S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vomr8EvJvSsqb8eVVEvroK1uZHK.jpg'),
(128769, 9206, 'A Paranormal S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ECK9MB43rQqFmUEu4cIU8BuYRz.jpg'),
(128770, 9206, 'A Paranormal S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/588200.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nXBUejs8DhoYmAyWgt4QV8fpd3N.jpg'),
(128771, 9206, 'A Paranormal S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bU55jcwvNh35qL86CjqGvFTEyOl.jpg'),
(128772, 9206, 'A Paranormal S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ZxYgp3RHWAbHTcNDeWMqvwfllt.jpg'),
(128773, 9206, 'A Paranormal S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ElOkNNqh0CFlkgg5MvSJqH61eH.jpg'),
(128774, 9206, 'A Paranormal S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/588204.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gheCa7QzUfntn0hHyTnUADSF65B.jpg'),
(128775, 9206, 'A Paranormal S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7mfcPhdbiX26iidIrO1cqklRRf.jpg'),
(128776, 9206, 'A Paranormal S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/df2ZXROlAYCaWGyi7odGDGTAuSn.jpg'),
(128777, 9206, 'A Paranormal S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/252920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/36gWIqNkNV842KNxwkpZhPPcUb7.jpg'),
(128778, 9206, 'A Paranormal S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/252921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vEEVahjWFZLL5IPXeHUnhNWuCmk.jpg'),
(128779, 9206, 'A Paranormal S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/252922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2yFhWiVrud8VNeGO6OlRoqSXSh8.jpg'),
(128780, 9206, 'A Paranormal S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/252923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvd7jpdaZaZxoBDmSWxl1UejjU4.jpg'),
(128781, 9206, 'A Paranormal S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/252924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/we5NHHcUvyztUXB68wFOBBBPYyY.jpg'),
(128782, 9206, 'A Paranormal S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/252925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2s57J2NUpCFbvc6Ra4QtzMl6sKv.jpg'),
(128783, 9206, 'A Paranormal S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/252926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVDxc9BLHjBdEdc2F2GTnp26Sll.jpg'),
(128784, 9206, 'A Paranormal S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/252927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i4xBFBBPqVD7wukqEXGwEBHlemx.jpg'),
(128785, 9206, 'A Paranormal S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/252928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9cZjIqmQ9fQYSOqa9IZP6Uv0Pck.jpg'),
(128786, 9207, 'A Paranormal S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AvLBQAmIn6RA754t3kL0CjHpeFW.jpg'),
(128787, 9207, 'A Paranormal S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1cvabJifqemJcoGME6l8bqPQ3oF.jpg'),
(128788, 9207, 'A Paranormal S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ZcujCTU0vLdkG1hHtmEQuJ03Nz.jpg'),
(128789, 9207, 'A Paranormal S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Or15TLwoExo8ifVa5vUDaNglxW.jpg'),
(128790, 9207, 'A Paranormal S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/npF09YtemrFH77vXAYYK92zlj8d.jpg'),
(128791, 9207, 'A Paranormal S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kUaPTIg5IhpGVpvApcFKGLofVIr.jpg'),
(128792, 9207, 'A Paranormal S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fBakdcqY7ezey7KssxMsCuUqyDK.jpg'),
(128793, 9207, 'A Paranormal S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7nQYHQXJm3TNy2Xdvvq71toQqs0.jpg'),
(128794, 9207, 'A Paranormal S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lAQxohaq5vAEpGZVM826SUmUNIZ.jpg'),
(128795, 9207, 'A Paranormal S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v8DLZD6gzJgswNyTbTTS215MtMJ.jpg'),
(128796, 9207, 'A Paranormal S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uGfocmQapgHbJOYFXvfJwBSBz8E.jpg'),
(128797, 9207, 'A Paranormal S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cv965XRtawTOrA0H7LDLhAbjRLa.jpg'),
(128798, 9207, 'A Paranormal S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4QsrbHxJTnwdiVa8VIcV4JRJZHI.jpg'),
(128799, 9207, 'A Paranormal S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/252942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aD2hC3CSTi89pm7xYE5BOmYFFW8.jpg'),
(128800, 9207, 'A Paranormal S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/252943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2dbeOPUJIQpnpysNddos3Ot9Sr.jpg'),
(128801, 9207, 'A Paranormal S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/252944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nEljcOok23f7h9PNj9x3KVBR7ar.jpg'),
(128802, 9208, 'A Paranormal S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gez3dnOnQtxoCzeodFSNQLfq5l8.jpg'),
(128803, 9208, 'A Paranormal S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2vBFKiSSkZ2eS9tkKJ3EJHIx1d.jpg'),
(128804, 9208, 'A Paranormal S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zVeTJUvgryVl7p64ZFLmAH3DC38.jpg'),
(128805, 9208, 'A Paranormal S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mkvhbOrspQbMwClCYGOSzS1TfRy.jpg'),
(128806, 9208, 'A Paranormal S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ybtWiKkIURbXtIl2PORnclxUkw.jpg'),
(128807, 9208, 'A Paranormal S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vv1Pr3lYPy41hS3yKUxicDJlzYf.jpg'),
(128808, 9208, 'A Paranormal S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fzymkh1GE8zENbhA1bCWFaE9KAA.jpg'),
(128809, 9208, 'A Paranormal S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9igs94o8PRKmpOSgGG31WuR2Uug.jpg'),
(128810, 9208, 'A Paranormal S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vvPAGuVjvEws6v1Zd2OopD7EOGc.jpg'),
(128811, 9208, 'A Paranormal S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/54XRGS4OjRQAXW4g0wLQX7iSjz6.jpg'),
(128812, 9208, 'A Paranormal S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1SuHnnaJveP3fNoKWtlnrqgUyOc.jpg'),
(128813, 9208, 'A Paranormal S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sD0D5OPsWsPC5LbKltEtnesgHGP.jpg'),
(128814, 9208, 'A Paranormal S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w00AMTdunhJSwChhu7a0Toww2dd.jpg'),
(128815, 9208, 'A Paranormal S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/252958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vYLRdQTRWBEbbtCscB5YKi5vji2.jpg'),
(128816, 9208, 'A Paranormal S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/252959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bEj3Fd7Xdz7ksnHoGkD733p0bky.jpg'),
(128817, 9208, 'A Paranormal S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/252960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/82YTov2HjSFLc1S8N7V3ash8noU.jpg'),
(128818, 9208, 'A Paranormal S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/252961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7CgWXChXwF2BpoHr3BwM6yg7tcP.jpg'),
(128819, 9208, 'A Paranormal S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/252962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4PLgyzhaSLXQpLPTPNgi5aoCpT1.jpg'),
(128820, 9208, 'A Paranormal S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/252963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mOsu4ABp6ltWTb7iu2RFYFA6FUI.jpg'),
(128821, 9209, 'A Paranormal S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fIJJdgwokjBYslM0du5Qb7nTjan.jpg'),
(128822, 9209, 'A Paranormal S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oGcI5c2KHLvm1oJyVBONpr2lrnx.jpg'),
(128823, 9209, 'A Paranormal S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3bAAVpBrdBTPV46W0qssAkMdT35.jpg'),
(128824, 9209, 'A Paranormal S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkVEUeY4DJNjk3iYL222VI5rFSB.jpg'),
(128825, 9209, 'A Paranormal S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDx1q79hlmHtKX4gwIhBIF9XEqY.jpg'),
(128826, 9209, 'A Paranormal S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yh5tgfsvxVVOLeF3uJKtqrOjczZ.jpg'),
(128827, 9209, 'A Paranormal S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AiDafurhc2X1YZeHslSf26qTIdh.jpg'),
(128828, 9209, 'A Paranormal S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xDVodX1r9Y0XP7uoAqOIGlBfWIY.jpg'),
(128829, 9209, 'A Paranormal S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rEHRNTUwuo6TVW1xeTcxIG6yVjC.jpg'),
(128830, 9209, 'A Paranormal S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dtHRk5MlPRjhyDXtpd1oaMejkhm.jpg'),
(128831, 9209, 'A Paranormal S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/51JXFekydvKFb6OwdY9eHqxnJri.jpg'),
(128832, 9209, 'A Paranormal S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/52msRWssW8z8FYIeZgLXTv6r532.jpg'),
(128833, 9209, 'A Paranormal S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3d5YWaDNPbUq843JgikKY3PXanT.jpg'),
(128834, 9209, 'A Paranormal S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/252977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ahOmvYpQwCkORTcCBODnEOqjRz.jpg'),
(128835, 9209, 'A Paranormal S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/252978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hBxEyGBP4EmN1yYRAMzTCkt2h6A.jpg'),
(128836, 9209, 'A Paranormal S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/252979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lGX8qaP8eg7IsCvOG5HfjQtIGtQ.jpg'),
(128837, 9209, 'A Paranormal S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/252980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zOcFYmRJNekh6OzH5UO1Gn3UT2k.jpg'),
(128838, 9209, 'A Paranormal S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/252981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2FdtSuGY1x7plGHikFhro6on8b8.jpg'),
(128839, 9209, 'A Paranormal S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/252982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nQJvHTt0W5Fuo2PHumDBjireCD7.jpg'),
(128840, 9209, 'A Paranormal S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/252983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/C6LU54nTYameTDHmiiKK8c9TOc.jpg'),
(128841, 9209, 'A Paranormal S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/252984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eOQZ1BvRx8F0hpEXe26v7Ke1eQX.jpg'),
(128842, 9209, 'A Paranormal S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/252985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iRkZ1Kt41r5oQ4fmI9gcJV40S7a.jpg'),
(128843, 9210, 'A Paranormal S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cwG2eIVB3gordaGdk2HsRQlunPR.jpg'),
(128844, 9210, 'A Paranormal S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s49TCislpAkIXpE0MbNknMyPS6W.jpg'),
(128845, 9210, 'A Paranormal S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7gfv3B62HbeVhKKAY7kTxDijHB.jpg'),
(128846, 9210, 'A Paranormal S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1YFOXSpe2o8QQtYULr2hBt5xEgs.jpg'),
(128847, 9210, 'A Paranormal S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ceSXCUR9QRLCUUxaH0N0qhu8SDC.jpg'),
(128848, 9210, 'A Paranormal S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aHgnBZOOZhyKJAnDZS7BV3YGE5B.jpg'),
(128849, 9210, 'A Paranormal S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lKuMQxsYfPGPijxMnsir1n9e7hy.jpg'),
(128850, 9210, 'A Paranormal S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a2CnBwxKYmjHafMhfwfJjOUXhnJ.jpg'),
(128851, 9210, 'A Paranormal S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ygzDDE7xtWDESaJ43VD5OPflv0y.jpg'),
(128852, 9210, 'A Paranormal S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lxo8pKXVUw4qUSPbKohrRyh1MEu.jpg'),
(128853, 9210, 'A Paranormal S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Utoqu3pKteHCvQAD5LvuoHv3Fq.jpg'),
(128854, 9210, 'A Paranormal S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSYVbXDCtg72p6YwihfJG0Ch1aD.jpg'),
(128855, 9210, 'A Paranormal S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/viRBkXMCIyRJHloP6t4SW3Knspl.jpg'),
(128856, 9211, 'Archer [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l3RD3MNl8QDV2AyPF9HQ8PbHasj.jpg'),
(128857, 9211, 'Archer [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e22L3pas4D9NIGD0oOVwhEbtyD7.jpg'),
(128858, 9211, 'Archer [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/youYb3bE9CbCrmt1SDYWNTTi2Mf.jpg'),
(128859, 9211, 'Archer [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dXeFHtBk9aeQSUUrEBJ3s2mb8He.jpg'),
(128860, 9211, 'Archer [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l7ZebRcWyx9WbPEUvPip7DLPWJm.jpg'),
(128861, 9211, 'Archer [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A6A448D9nfqGguVdEMPNjeQnSXz.jpg'),
(128862, 9211, 'Archer [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pc4VjXFGeOv84ck2cikVaj1Q4jm.jpg'),
(128863, 9211, 'Archer [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8NZaGU2AzAeKmLPYKKOD0UxqBQF.jpg'),
(128864, 9211, 'Archer [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9AePazOeL2j7d6HlwcUuvHeC9WQ.jpg'),
(128865, 9211, 'Archer [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rr1gghBYFrRBBdSDXPgRYq3cNnF.jpg'),
(128866, 9212, 'Archer [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g13OaaBrRiCBDQko880yIVO7rN2.jpg'),
(128867, 9212, 'Archer [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u5uinew4KUnvrcm0ZjIyEOMJcut.jpg'),
(128868, 9212, 'Archer [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nNCcDOrrIniEtK04Ey0FsL7kui0.jpg'),
(128869, 9212, 'Archer [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5twwashrlt77vICCeja2zmf5xX7.jpg'),
(128870, 9212, 'Archer [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vNrNLrJQaNj40qECbwFwCmB67VQ.jpg'),
(128871, 9212, 'Archer [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4mr0R4wYA1Jt1gLiXWapnEcxAl1.jpg'),
(128872, 9212, 'Archer [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lA2oRtethz05SUVufNWj8VhEvPO.jpg'),
(128873, 9212, 'Archer [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Csd8bqzLezLXFb81o5eAjABPfx.jpg'),
(128874, 9212, 'Archer [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7S1KnMeoR0BFvqn9zDEbnlmeuvC.jpg'),
(128875, 9212, 'Archer [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xdLh2SyLk4VcZjq9HSkvM5V5ltZ.jpg'),
(128876, 9212, 'Archer [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/90M8B4UGQjJXffXZeqshDp2DuDz.jpg'),
(128877, 9212, 'Archer [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/82lIjldMpp6Wiwi9iaqO3XJZgNX.jpg'),
(128878, 9212, 'Archer [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udhGniCG1kvvPrdP81tTrkBAhnl.jpg'),
(128879, 9213, 'Archer [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/boKtNq57dsuJZsdQgaMAmjoDZ2Q.jpg'),
(128880, 9213, 'Archer [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lRKJgfS49TIxn9xehfMhNMjZtWM.jpg'),
(128881, 9213, 'Archer [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r53Ezns6Rk7cOObGT0DSRzQEUQx.jpg'),
(128882, 9213, 'Archer [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mamXN05uhZDAGqlHdpGQF2I7ZH.jpg'),
(128883, 9213, 'Archer [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vprVT08pyqT9p1A3lwbzt50w24H.jpg'),
(128884, 9213, 'Archer [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMkm9kA6eAPOD9ZeExbkMZdIVrW.jpg'),
(128885, 9213, 'Archer [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xUaquZB677e7UPcXhp9AZl5ECBZ.jpg'),
(128886, 9213, 'Archer [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yKHnFNewnV6bdmvSGerD5yTaIMP.jpg'),
(128887, 9213, 'Archer [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gmseMWkO6liJN0n3J9nAVciRXr4.jpg'),
(128888, 9213, 'Archer [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2IE4eyBlr84th0RubBMVq8eHkOA.jpg'),
(128889, 9213, 'Archer [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o51NY5Zjgh7ridCu93dKOdKftVy.jpg'),
(128890, 9213, 'Archer [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o51NY5Zjgh7ridCu93dKOdKftVy.jpg'),
(128891, 9213, 'Archer [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o51NY5Zjgh7ridCu93dKOdKftVy.jpg'),
(128892, 9214, 'Archer [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r0DHGPlkveqjWhKGliFiIyMHumU.jpg'),
(128893, 9214, 'Archer [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gFbEiWcze8WAMyiGy7NsGu0XmMT.jpg'),
(128894, 9214, 'Archer [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ge7hyTdAL2ki8hYfxEt9I6LxFiK.jpg'),
(128895, 9214, 'Archer [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y5hO0gA44vZMo4I0YO1U4pUPOBr.jpg'),
(128896, 9214, 'Archer [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tK1EMgEncR5HzJ3lPSbfGI2RMOI.jpg'),
(128897, 9214, 'Archer [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hskfOwQiEUDJlXISO5SV7JlG0UH.jpg'),
(128898, 9214, 'Archer [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hUmqPbz9OE20uAIwLvpQ6Hea7Ho.jpg'),
(128899, 9214, 'Archer [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z07k7iYk5eh6S9R1jbCJ4kGzgVH.jpg'),
(128900, 9214, 'Archer [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xxiIILbgyH6YfxD3hJUJYUvKEeF.jpg'),
(128901, 9214, 'Archer [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtTXB4btQtXKHKPyt7A4UKerx2E.jpg'),
(128902, 9214, 'Archer [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bA8aetWGUlxLQHw0rSGzPp7Lfhe.jpg'),
(128903, 9214, 'Archer [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9B1CdFFd6CWmG5nh8Bm9QfO98Hn.jpg'),
(128904, 9214, 'Archer [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aH2VzkpWmsqW1IJj4So3zE9FlQd.jpg'),
(128905, 9215, 'Archer [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Uw9MrNYbJzn2tHnPqatx2TRdI4.jpg'),
(128906, 9215, 'Archer [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3cifLNIIXRGpmigCg5Rwqtt6hY.jpg'),
(128907, 9215, 'Archer [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4sXpkGr5tcwa99F3H1wiiBQ97Hx.jpg'),
(128908, 9215, 'Archer [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6HNcfy9a8KLQWkRE4RdDDwwuWNp.jpg'),
(128909, 9215, 'Archer [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2DbtYbG1QYHijrjolErtW2Ufa9j.jpg'),
(128910, 9215, 'Archer [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11rGUise0OplsdzTGwLgWiuwesx.jpg'),
(128911, 9215, 'Archer [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a5f27cb7CqUPGz2cHyyoEqy8Sa6.jpg'),
(128912, 9215, 'Archer [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2CTtq5YMcoayY8M8GnbpbaNVY0f.jpg'),
(128913, 9215, 'Archer [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSTiRMAmgBAhvRiyzVN9NXe5tFy.jpg'),
(128914, 9215, 'Archer [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mulzsGSxCEGlS1YTvfX6B1XruTu.jpg'),
(128915, 9215, 'Archer [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cd6COXXA6K0j6hiIuHf18m1iv5j.jpg'),
(128916, 9215, 'Archer [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tXFb8vP6cMSW3Tr3tKHEjljuzXd.jpg'),
(128917, 9215, 'Archer [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjfvMRf26ezVbsGaWLjhUdkCd23.jpg'),
(128918, 9216, 'Archer [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mMZ6xo0XN6iBREMtsezqw8oAJRo.jpg'),
(128919, 9216, 'Archer [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSlmJ50aU545sHyHYQqFCawQlcl.jpg'),
(128920, 9216, 'Archer [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vlWQURRBi0u7VPE4A2mOQYr4Do5.jpg'),
(128921, 9216, 'Archer [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wH0YpDHYdEBajjfg3GkrSfcqgMK.jpg'),
(128922, 9216, 'Archer [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/klUCzJJXG2768QjEbaNT0HzKKlW.jpg'),
(128923, 9216, 'Archer [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdNhKZLSci0RbDGA0MQQ8coOmQa.jpg'),
(128924, 9216, 'Archer [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dHzBNQjwcX5LSSDfVrMwmWkpjY3.jpg'),
(128925, 9216, 'Archer [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nhk6JNGmjCHzVEsqXVhBxEUSkMD.jpg'),
(128926, 9216, 'Archer [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJn34PxspGcj8GLMe1b13yKNKdR.jpg'),
(128927, 9216, 'Archer [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbZCASjnlYU0JdDu0hRvQEGBbXw.jpg'),
(128928, 9216, 'Archer [L] S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sjp7s2HGBUjK2Lpb26UvtFmRiCT.jpg'),
(128929, 9216, 'Archer [L] S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4YFBwJQbGU6Z1HfQUQrGsjqyDez.jpg'),
(128930, 9216, 'Archer [L] S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u4KXkmP6artHFm2hvAEM4vF2NQN.jpg'),
(128931, 9217, 'Archer [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/evsN8UwQTQMqPkIRhKw7fBd0Qa3.jpg'),
(128932, 9217, 'Archer [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aMB0qZtjw2jMaeRnkPNK9d2vNPF.jpg'),
(128933, 9217, 'Archer [L] S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jrJIE8bir5ilaVYFFCRtOeoSPj4.jpg'),
(128934, 9217, 'Archer [L] S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bREjKYW0AUZsOrAADvE8ookzl4y.jpg'),
(128935, 9217, 'Archer [L] S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/49KK3tnMFuRw29FMzeb0bOaMVkD.jpg'),
(128936, 9217, 'Archer [L] S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7kHg3gPsKGW6WNjKHwuoMk6IeKt.jpg'),
(128937, 9217, 'Archer [L] S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zYwht3vD44MR0QehGHqXGD8R0hE.jpg'),
(128938, 9217, 'Archer [L] S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8UvCtU5BFbgOWlTBjv4y4lxGDqr.jpg'),
(128939, 9217, 'Archer [L] S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3fb46nkxqSQXGvB4PZaawjgkDRx.jpg'),
(128940, 9217, 'Archer [L] S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uGhzHtGNXNCTzDGfYNJB1Hf9BXV.jpg'),
(128941, 9218, 'Archer [L] S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fho3jT2e5loYKIYDgjC2ibEaWxN.jpg'),
(128942, 9218, 'Archer [L] S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gIYUrp6sExvhkbkhPVr4j7jVstn.jpg'),
(128943, 9218, 'Archer [L] S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7KOPrdKXdTLXIkbXDeBOFqkSm1M.jpg'),
(128944, 9218, 'Archer [L] S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yPMhsgn8tP1FWZJOb0fKENDFzmc.jpg'),
(128945, 9218, 'Archer [L] S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tH4QuphYh52adI7ugepaeImXjIv.jpg'),
(128946, 9218, 'Archer [L] S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOiADM7JtGtIDU4oWL89wFAJRnm.jpg'),
(128947, 9218, 'Archer [L] S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLSP6DWb3WJJ9DbQj8LI9UoyuSY.jpg'),
(128948, 9218, 'Archer [L] S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rYXH4PmK7Ebg7eU9ulrardjMYme.jpg'),
(128949, 9219, 'Archer [L] S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iFsEKw6RyWvoyJiSAwaOhLD34OY.jpg'),
(128950, 9219, 'Archer [L] S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9CN4rFGRqJGCimx5s19nMOkfLGH.jpg'),
(128951, 9219, 'Archer [L] S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bFRtt3GREYufwRGJQGKR2adQ0Lq.jpg'),
(128952, 9219, 'Archer [L] S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bnxi1iBhT6c5XZ7ubjChwP7TNvu.jpg'),
(128953, 9219, 'Archer [L] S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zRVWYuWZZP18aoFhAegXd7jzctI.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(128954, 9219, 'Archer [L] S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9i6B1orXD3mnxBAh8GmPRGkB9bx.jpg'),
(128955, 9219, 'Archer [L] S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9AuSeqGM4votuBnpoVCv57ffJEc.jpg'),
(128956, 9219, 'Archer [L] S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDEtlFFfE33c1F2givG2t2pGjMi.jpg'),
(128957, 9220, 'Archer [L] S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBoezlZKSOYXkuqyuNbvg4RSpdo.jpg'),
(128958, 9220, 'Archer [L] S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qaTQq0J0xifjw0XrF4iKQMj0LYZ.jpg'),
(128959, 9220, 'Archer [L] S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Z0Lp5ULpMeARJE4bJcIfhPMCy4.jpg'),
(128960, 9220, 'Archer [L] S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aWQ6UoErp6hFrLOQNzNFCk3PwHh.jpg'),
(128961, 9220, 'Archer [L] S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVxPcVxC4LM5eAeIZGwbBGxdwif.jpg'),
(128962, 9220, 'Archer [L] S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gwWGOurBLRlvJ5HHg0fmWE7Xd7d.jpg'),
(128963, 9220, 'Archer [L] S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jQX6K5PKFwj6ZNgoiHmJlZ9sHyL.jpg'),
(128964, 9220, 'Archer [L] S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eGWOfH6tmhAczc9FEzYbT6xiB04.jpg'),
(128965, 9220, 'Archer [L] S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d1HPefc07jqdVKPE2rnnhdU3P6R.jpg'),
(128966, 9221, 'Archer [L] S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1u1cy8Xo0DvAtO6QdlVhrIIpfqk.jpg'),
(128967, 9221, 'Archer [L] S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2rYlJ0QqGNy3XShhbsl20YdnJU5.jpg'),
(128968, 9221, 'Archer [L] S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sf4DqNNgQiuA3zD2fovgIDmHSmz.jpg'),
(128969, 9221, 'Archer [L] S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hZHwZ2BhUEzuymK1tIrOQXEU3wz.jpg'),
(128970, 9221, 'Archer [L] S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7cBbaSoAe3oFuS0Sj6LNBUKJDEk.jpg'),
(128971, 9221, 'Archer [L] S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dMqd2KB7rhg885e3q0pn07HziLH.jpg'),
(128972, 9221, 'Archer [L] S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ubwVXfagyjBKQH63C03bz0Pxy0c.jpg'),
(128973, 9221, 'Archer [L] S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nKG6ELaHsDwu8AVlptM29En5BEP.jpg'),
(128974, 9222, 'Archer [L] S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQRQThQcJJDNriYCAI3HTs8CBkq.jpg'),
(128975, 9222, 'Archer [L] S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXyChEbW4W5UY7npSIabbAfpQRE.jpg'),
(128976, 9222, 'Archer [L] S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lV2FGHYfXooy7MWRWEj0eNxtKPv.jpg'),
(128977, 9222, 'Archer [L] S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bfUobWdrLVJ3jHO15yPzcwYmLaV.jpg'),
(128978, 9222, 'Archer [L] S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ogSp4JUeA00neCYCCxklUV9RYpR.jpg'),
(128979, 9222, 'Archer [L] S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pMCfHWYbC8FcFqTYKNS7VGZPhRZ.jpg'),
(128980, 9222, 'Archer [L] S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QfVhZRTRGqdKsw6ewjedZeSdMj.jpg'),
(128981, 9222, 'Archer [L] S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTGcMPBdoNS3DTcQq8megzHV3ib.jpg'),
(128982, 9223, 'Archer [L] S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dBuZrsmKXV7KMfoGKFjjRKvH4Ku.jpg'),
(128983, 9223, 'Archer [L] S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ak9wz6vTZ6O0G8lCRcFfDod2cNa.jpg'),
(128984, 9223, 'Archer [L] S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s2Zhb7QtBeXK8rPKpMve7khxu9y.jpg'),
(128985, 9223, 'Archer [L] S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o8CrzGIjnb6f01LnKyI3NfqsJZA.jpg'),
(128986, 9223, 'Archer [L] S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uKr5uSCGpdeF3gAZKAmLLwzPeDL.jpg'),
(128987, 9223, 'Archer [L] S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5L03vLUYh0QawTUZ1BTed3uB5L.jpg'),
(128988, 9223, 'Archer [L] S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wAkAMvFirqfVxkLtoxnidKLDXoY.jpg'),
(128989, 9223, 'Archer [L] S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aIASFWWUOMmMpIT70wd7PKsduxG.jpg'),
(128990, 9224, 'Archer [L] S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/atijwRFQUFuzCHszgk8WBqR0egP.jpg'),
(128991, 9224, 'Archer [L] S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mwDRbYGp7ihp7ScI4Z3857bXtzi.jpg'),
(128992, 9224, 'Archer [L] S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/syH60TV2FZcpEMQepfRFY0uHDyR.jpg'),
(128993, 9224, 'Archer [L] S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9LGm5g84dw37x7Ha1Un56pT9F4o.jpg'),
(128994, 9224, 'Archer [L] S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/48ETTAU2haf8CQ6OGpEiK10xXw6.jpg'),
(128995, 9224, 'Archer [L] S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pxr2AgSJBKpN7mLecer8ONCsab9.jpg'),
(128996, 9224, 'Archer [L] S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i21kaTNcUaKU2RzKf24IimtVr5q.jpg'),
(128997, 9224, 'Archer [L] S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f59cBxBdm1XguAqNsLxJSTVhkZM.jpg'),
(128998, 9225, 'Cindy La Regia Adolescencia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iOzgAU84biRrnbWIAvn0VjR6zXZ.jpg'),
(128999, 9225, 'Cindy La Regia Adolescencia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4zR5qt6w9XPWZoGwy964OrIkYYk.jpg'),
(129000, 9225, 'Cindy La Regia Adolescencia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4lULtraZCqyEcAoDGlKgALY2O0T.jpg'),
(129001, 9225, 'Cindy La Regia Adolescencia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Xjk3S2AYOVXyz7gxLA25JhCInP.jpg'),
(129002, 9225, 'Cindy La Regia Adolescencia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yLdrPgTYVgUV6iWeI6V2sjLsxzv.jpg'),
(129003, 9225, 'Cindy La Regia Adolescencia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a7b0Wgbhhzxxjh92TTmA0ZGWbH1.jpg'),
(129004, 9225, 'Cindy La Regia Adolescencia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9vJAzwRW4Q4klZuZCZIywEyTig8.jpg'),
(129005, 9226, 'Clube do Medo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eGTdPq0St6V5pWtQ0geRpuJDrXD.jpg'),
(129006, 9226, 'Clube do Medo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eGTdPq0St6V5pWtQ0geRpuJDrXD.jpg'),
(129007, 9226, 'Clube do Medo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eGTdPq0St6V5pWtQ0geRpuJDrXD.jpg'),
(129008, 9226, 'Clube do Medo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eGTdPq0St6V5pWtQ0geRpuJDrXD.jpg'),
(129009, 9226, 'Clube do Medo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eGTdPq0St6V5pWtQ0geRpuJDrXD.jpg'),
(129010, 9226, 'Clube do Medo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eGTdPq0St6V5pWtQ0geRpuJDrXD.jpg'),
(129011, 9226, 'Clube do Medo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eGTdPq0St6V5pWtQ0geRpuJDrXD.jpg'),
(129012, 9226, 'Clube do Medo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eGTdPq0St6V5pWtQ0geRpuJDrXD.jpg'),
(129013, 9226, 'Clube do Medo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eGTdPq0St6V5pWtQ0geRpuJDrXD.jpg'),
(129014, 9226, 'Clube do Medo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eGTdPq0St6V5pWtQ0geRpuJDrXD.jpg'),
(129015, 9227, 'Clube do Medo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eGTdPq0St6V5pWtQ0geRpuJDrXD.jpg'),
(129016, 9227, 'Clube do Medo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eGTdPq0St6V5pWtQ0geRpuJDrXD.jpg'),
(129017, 9227, 'Clube do Medo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eGTdPq0St6V5pWtQ0geRpuJDrXD.jpg'),
(129018, 9227, 'Clube do Medo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eGTdPq0St6V5pWtQ0geRpuJDrXD.jpg'),
(129019, 9227, 'Clube do Medo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eGTdPq0St6V5pWtQ0geRpuJDrXD.jpg'),
(129020, 9227, 'Clube do Medo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eGTdPq0St6V5pWtQ0geRpuJDrXD.jpg'),
(129021, 9227, 'Clube do Medo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eGTdPq0St6V5pWtQ0geRpuJDrXD.jpg'),
(129022, 9227, 'Clube do Medo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eGTdPq0St6V5pWtQ0geRpuJDrXD.jpg'),
(129023, 9227, 'Clube do Medo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eGTdPq0St6V5pWtQ0geRpuJDrXD.jpg'),
(129024, 9227, 'Clube do Medo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eGTdPq0St6V5pWtQ0geRpuJDrXD.jpg'),
(129025, 9228, 'Esqueca me se Puder S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m7usUoxH6nYfM48ir21qQb3Y0Lk.jpg'),
(129026, 9228, 'Esqueca me se Puder S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xauZ9lkofWjgdA6a5mRUCqiZpjG.jpg'),
(129027, 9228, 'Esqueca me se Puder S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/keiYRVPPWfzem8vZHIzBPOEl9PQ.jpg'),
(129028, 9228, 'Esqueca me se Puder S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aer3T0rkg9cOXY0cTJfRWtWoc3O.jpg'),
(129029, 9228, 'Esqueca me se Puder S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v7xBZ5pOLQmvNSAI21DI4pvFqMn.jpg'),
(129030, 9228, 'Esqueca me se Puder S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cQIwfTxDWedCssdfSfjKeg8dBec.jpg'),
(129031, 9228, 'Esqueca me se Puder S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xA2jb6COQsgN19itAfv9Tj6byeS.jpg'),
(129032, 9228, 'Esqueca me se Puder S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2C9oMgcOmksjt57VuP8pejEKpdz.jpg'),
(129033, 9228, 'Esqueca me se Puder S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A2dTUtCDtHVqDVN2EdmWv40Zvlp.jpg'),
(129034, 9228, 'Esqueca me se Puder S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/moQzF6iGlVwYaH5RsW6DZNyrlbH.jpg'),
(129035, 9228, 'Esqueca me se Puder S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bbjvAj1S9KIuiSMVXOWb6KgUfYN.jpg'),
(129036, 9228, 'Esqueca me se Puder S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129037, 9228, 'Esqueca me se Puder S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzJmDJEwO4lgrl7CHRtLEIFZNIP.jpg'),
(129038, 9228, 'Esqueca me se Puder S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/252640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/68PcWfd6KjeqQvfs0Kq5awNsIjf.jpg'),
(129039, 9228, 'Esqueca me se Puder S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/252641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/78vWrvGCrGLw0Noib67vtlzMCFz.jpg'),
(129040, 9228, 'Esqueca me se Puder S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/252642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s3b5QB4zs3z7taXYUIpEW9ob8Om.jpg'),
(129041, 9228, 'Esqueca me se Puder S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/252643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129042, 9228, 'Esqueca me se Puder S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/252644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129043, 9228, 'Esqueca me se Puder S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/252645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129044, 9228, 'Esqueca me se Puder S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/252646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129045, 9228, 'Esqueca me se Puder S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/252647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129046, 9228, 'Esqueca me se Puder S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/252648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129047, 9228, 'Esqueca me se Puder S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/252649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129048, 9228, 'Esqueca me se Puder S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/252650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129049, 9228, 'Esqueca me se Puder S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/252651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129050, 9228, 'Esqueca me se Puder S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/252652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129051, 9228, 'Esqueca me se Puder S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/252653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129052, 9228, 'Esqueca me se Puder S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/252654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129053, 9228, 'Esqueca me se Puder S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/252655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129054, 9228, 'Esqueca me se Puder S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/252656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129055, 9228, 'Esqueca me se Puder S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/252657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129056, 9228, 'Esqueca me se Puder S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/252658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129057, 9228, 'Esqueca me se Puder S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/252659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129058, 9228, 'Esqueca me se Puder S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/252660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129059, 9228, 'Esqueca me se Puder S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/252661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129060, 9228, 'Esqueca me se Puder S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/252662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129061, 9228, 'Esqueca me se Puder S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/252663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129062, 9228, 'Esqueca me se Puder S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/252664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129063, 9228, 'Esqueca me se Puder S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/252665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129064, 9228, 'Esqueca me se Puder S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/252666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129065, 9228, 'Esqueca me se Puder S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/252667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129066, 9228, 'Esqueca me se Puder S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/252668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129067, 9228, 'Esqueca me se Puder S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/252669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129068, 9228, 'Esqueca me se Puder S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/252670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129069, 9228, 'Esqueca me se Puder S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/252671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129070, 9228, 'Esqueca me se Puder S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/252672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129071, 9228, 'Esqueca me se Puder S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/252673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129072, 9228, 'Esqueca me se Puder S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/252674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129073, 9228, 'Esqueca me se Puder S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/252675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129074, 9228, 'Esqueca me se Puder S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/252676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129075, 9228, 'Esqueca me se Puder S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/252677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129076, 9228, 'Esqueca me se Puder S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/252678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129077, 9228, 'Esqueca me se Puder S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/252679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129078, 9228, 'Esqueca me se Puder S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/252680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129079, 9228, 'Esqueca me se Puder S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/252681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129080, 9228, 'Esqueca me se Puder S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/252682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129081, 9228, 'Esqueca me se Puder S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/252683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129082, 9228, 'Esqueca me se Puder S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/252684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129083, 9228, 'Esqueca me se Puder S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/252685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129084, 9228, 'Esqueca me se Puder S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/252686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129085, 9228, 'Esqueca me se Puder S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/252687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129086, 9228, 'Esqueca me se Puder S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/252688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129087, 9228, 'Esqueca me se Puder S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/252689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129088, 9228, 'Esqueca me se Puder S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/252690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129089, 9228, 'Esqueca me se Puder S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/252691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129090, 9228, 'Esqueca me se Puder S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/252692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129091, 9228, 'Esqueca me se Puder S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/252693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129092, 9228, 'Esqueca me se Puder S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/252694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129093, 9228, 'Esqueca me se Puder S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/252695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129094, 9228, 'Esqueca me se Puder S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/252696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129095, 9228, 'Esqueca me se Puder S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/252697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129096, 9228, 'Esqueca me se Puder S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/252698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129097, 9228, 'Esqueca me se Puder S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/252699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129098, 9228, 'Esqueca me se Puder S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/329215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129099, 9228, 'Esqueca me se Puder S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/329216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129100, 9228, 'Esqueca me se Puder S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/329217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129101, 9228, 'Esqueca me se Puder S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/329218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129102, 9228, 'Esqueca me se Puder S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/329219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129103, 9228, 'Esqueca me se Puder S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/329220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129104, 9228, 'Esqueca me se Puder S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/329221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129105, 9228, 'Esqueca me se Puder S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/329222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129106, 9228, 'Esqueca me se Puder S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/329223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129107, 9228, 'Esqueca me se Puder S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/329224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129108, 9228, 'Esqueca me se Puder S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/329225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129109, 9228, 'Esqueca me se Puder S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/329226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129110, 9228, 'Esqueca me se Puder S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/329227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129111, 9228, 'Esqueca me se Puder S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/329228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129112, 9228, 'Esqueca me se Puder S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/329229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129113, 9228, 'Esqueca me se Puder S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/329230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129114, 9228, 'Esqueca me se Puder S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/329231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129115, 9228, 'Esqueca me se Puder S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/329232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129116, 9228, 'Esqueca me se Puder S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/329233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129117, 9228, 'Esqueca me se Puder S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/329234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129118, 9228, 'Esqueca me se Puder S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/329235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129119, 9228, 'Esqueca me se Puder S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/329236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129120, 9228, 'Esqueca me se Puder S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/329237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129121, 9228, 'Esqueca me se Puder S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/329238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129122, 9228, 'Esqueca me se Puder S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/329239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129123, 9228, 'Esqueca me se Puder S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/329240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129124, 9228, 'Esqueca me se Puder S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/329241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129125, 9228, 'Esqueca me se Puder S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/329242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129126, 9228, 'Esqueca me se Puder S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/329243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129127, 9228, 'Esqueca me se Puder S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/329244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129128, 9228, 'Esqueca me se Puder S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/329245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129129, 9228, 'Esqueca me se Puder S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/329246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129130, 9228, 'Esqueca me se Puder S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/329247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129131, 9228, 'Esqueca me se Puder S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/329248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2c4YMQHL36BTuaax1BMuwwwWyKm.jpg'),
(129132, 9229, 'Ghost Force S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129133, 9229, 'Ghost Force S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129134, 9229, 'Ghost Force S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129135, 9229, 'Ghost Force S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129136, 9229, 'Ghost Force S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129137, 9229, 'Ghost Force S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129138, 9229, 'Ghost Force S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129139, 9229, 'Ghost Force S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129140, 9229, 'Ghost Force S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129141, 9229, 'Ghost Force S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129142, 9229, 'Ghost Force S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129143, 9229, 'Ghost Force S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129144, 9229, 'Ghost Force S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129145, 9229, 'Ghost Force S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/252588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129146, 9229, 'Ghost Force S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/252589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129147, 9229, 'Ghost Force S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/252590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129148, 9229, 'Ghost Force S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/252591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129149, 9229, 'Ghost Force S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/252592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129150, 9229, 'Ghost Force S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/252593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129151, 9229, 'Ghost Force S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/252594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129152, 9229, 'Ghost Force S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/252595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129153, 9229, 'Ghost Force S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/252596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129154, 9229, 'Ghost Force S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/252597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129155, 9229, 'Ghost Force S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/252598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129156, 9229, 'Ghost Force S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/252599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129157, 9229, 'Ghost Force S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/252600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129158, 9229, 'Ghost Force S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/252601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129159, 9229, 'Ghost Force S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/252602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129160, 9229, 'Ghost Force S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/252603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129161, 9229, 'Ghost Force S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/252604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129162, 9229, 'Ghost Force S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/252605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129163, 9229, 'Ghost Force S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/252606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129164, 9229, 'Ghost Force S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/252607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129165, 9229, 'Ghost Force S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/252608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129166, 9229, 'Ghost Force S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/252609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129167, 9229, 'Ghost Force S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/252610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129168, 9229, 'Ghost Force S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/252611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129169, 9229, 'Ghost Force S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/252612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129170, 9229, 'Ghost Force S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/252613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129171, 9229, 'Ghost Force S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/252614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129172, 9229, 'Ghost Force S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/252615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129173, 9229, 'Ghost Force S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/252616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129174, 9229, 'Ghost Force S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/252617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129175, 9229, 'Ghost Force S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/252618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129176, 9229, 'Ghost Force S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/252619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129177, 9229, 'Ghost Force S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/252620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129178, 9229, 'Ghost Force S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/252621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129179, 9229, 'Ghost Force S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/252622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129180, 9229, 'Ghost Force S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/252623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129181, 9229, 'Ghost Force S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/252624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129182, 9229, 'Ghost Force S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/252625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129183, 9229, 'Ghost Force S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/252626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3BnMSyrjHhY8oDopPkEtFLkC22N.jpg'),
(129184, 9230, 'Legend of Nine Tails Fox [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129185, 9230, 'Legend of Nine Tails Fox [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129186, 9230, 'Legend of Nine Tails Fox [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129187, 9230, 'Legend of Nine Tails Fox [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129188, 9230, 'Legend of Nine Tails Fox [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129189, 9230, 'Legend of Nine Tails Fox [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129190, 9230, 'Legend of Nine Tails Fox [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129191, 9230, 'Legend of Nine Tails Fox [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129192, 9230, 'Legend of Nine Tails Fox [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129193, 9230, 'Legend of Nine Tails Fox [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129194, 9230, 'Legend of Nine Tails Fox [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129195, 9230, 'Legend of Nine Tails Fox [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129196, 9230, 'Legend of Nine Tails Fox [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129197, 9230, 'Legend of Nine Tails Fox [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/252551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129198, 9230, 'Legend of Nine Tails Fox [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/252552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129199, 9230, 'Legend of Nine Tails Fox [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/252553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129200, 9230, 'Legend of Nine Tails Fox [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/252554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129201, 9230, 'Legend of Nine Tails Fox [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/252555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129202, 9230, 'Legend of Nine Tails Fox [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/252556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129203, 9230, 'Legend of Nine Tails Fox [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/252557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129204, 9230, 'Legend of Nine Tails Fox [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/252558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129205, 9230, 'Legend of Nine Tails Fox [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/252559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129206, 9230, 'Legend of Nine Tails Fox [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/252560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129207, 9230, 'Legend of Nine Tails Fox [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/252561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129208, 9230, 'Legend of Nine Tails Fox [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/252562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129209, 9230, 'Legend of Nine Tails Fox [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/252563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129210, 9230, 'Legend of Nine Tails Fox [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/252564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129211, 9230, 'Legend of Nine Tails Fox [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/252565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129212, 9230, 'Legend of Nine Tails Fox [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/252566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129213, 9230, 'Legend of Nine Tails Fox [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/252567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129214, 9230, 'Legend of Nine Tails Fox [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/252568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(129215, 9230, 'Legend of Nine Tails Fox [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/252569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129216, 9230, 'Legend of Nine Tails Fox [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/252570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129217, 9230, 'Legend of Nine Tails Fox [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/252571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129218, 9230, 'Legend of Nine Tails Fox [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/252572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129219, 9230, 'Legend of Nine Tails Fox [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/252573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129220, 9230, 'Legend of Nine Tails Fox [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/252574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWG68wF3jNSCq0dX757Xm2KGELv.jpg'),
(129221, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ytrDdUSUxEVfprcHEsFRvVntIuv.jpg'),
(129222, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qAmdjh6RByzoOGCWat1V29evDvI.jpg'),
(129223, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v95CeaXbmoO1EVKduwmwbGKHUTa.jpg'),
(129224, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Nujh8Jnpr9LEi1CBWstHXeqP1y.jpg'),
(129225, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kkfVw2sllY0N98xxkHvvGr2txsl.jpg'),
(129226, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/knQm8YhQzDLYPdqMK3BIHySXzQ.jpg'),
(129227, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mVAs47TiOOJrQgtvnyf7dPTrgxd.jpg'),
(129228, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m9CJXdb2DXNRPaI4yYABiHL1qBU.jpg'),
(129229, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8iL4OTc2Vj9q3GK7SiSoPFxqkla.jpg'),
(129230, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6meNlfMQrEuR6MoqPOGxwk67IxK.jpg'),
(129231, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pN0DpqLpCOO0Rm1jGD9RPEvyFYT.jpg'),
(129232, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hRAe3I6VDFmwUzOezLj07AFNKGq.jpg'),
(129233, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oMzNmNGSVdeR46DLn0rRFWkJqKW.jpg'),
(129234, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/252520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/skRtTyqUtRtldZS7218oQJPKcL8.jpg'),
(129235, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/252521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lWKCAx7xTdi1ugFTzcWhXoELzrB.jpg'),
(129236, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/252522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iTcoIDa1eiZ6fxZFuc6YGj0Od9p.jpg'),
(129237, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/252523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8msbI4MpDjwVzWl0GD61Ue50uXy.jpg'),
(129238, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/252524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zsR7Cl3fiz7GzE22Z4h85lCzObN.jpg'),
(129239, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/252525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A6rVi4BVlZDr2fpIkM7CNckcKEP.jpg'),
(129240, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/252526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bqd0SeNFe08i5iTqQ5C6B2P82N4.jpg'),
(129241, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/252527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5nENkTefPNZvZXNAnfzcuRwQFzP.jpg'),
(129242, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/252528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5EQj5i87CtYMH09aLcocEUXpFDU.jpg'),
(129243, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/252529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aACfzLHglOfvj5Tyh8Kf4XGRA1m.jpg'),
(129244, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/252530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ieEJLXOOjvmbTFxb5wbViX1rQot.jpg'),
(129245, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/252531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gPcWJZAhXAa0UCnJzLUfUqNQPou.jpg'),
(129246, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/252532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmw4H0BiuGjM9GVQ2W2Kblfe89F.jpg'),
(129247, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/252533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kjNBRq6DjIzoJlShv4h1Zccm3v9.jpg'),
(129248, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/252534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lTjyoHzkeviKC4NULgZ3VXuqafz.jpg'),
(129249, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/252535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nUBwDlapM9mdSz9sEvjm5obiy0H.jpg'),
(129250, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/252536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/diHOXzYuCLchafYesBRc4jT8sAT.jpg'),
(129251, 9231, 'Mergulhando Em Seu Sorriso [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/252537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p29JG5VaAgPgYS4mnVdMIzBN3zx.jpg'),
(129252, 9232, 'Meu Homem e um Cupido [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zxC8XXmTKRL0wFhWs6ytYY443tJ.jpg'),
(129253, 9232, 'Meu Homem e um Cupido [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6qBNaQjvgUcFBc4aZctWAjuExkI.jpg'),
(129254, 9232, 'Meu Homem e um Cupido [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kOWBTEa2zzNjcXCly1B4LNKTPLx.jpg'),
(129255, 9232, 'Meu Homem e um Cupido [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vPnV3JTNk3ZaGtmsFOlyAqTfVy.jpg'),
(129256, 9232, 'Meu Homem e um Cupido [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sAMXIreHjNR6XIBpboCgTy5Hpu5.jpg'),
(129257, 9232, 'Meu Homem e um Cupido [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eAsPxMmbz5WPodGKxRWFzuSYQWL.jpg'),
(129258, 9232, 'Meu Homem e um Cupido [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eAsPxMmbz5WPodGKxRWFzuSYQWL.jpg'),
(129259, 9232, 'Meu Homem e um Cupido [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eAsPxMmbz5WPodGKxRWFzuSYQWL.jpg'),
(129260, 9232, 'Meu Homem e um Cupido [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eAsPxMmbz5WPodGKxRWFzuSYQWL.jpg'),
(129261, 9232, 'Meu Homem e um Cupido [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eAsPxMmbz5WPodGKxRWFzuSYQWL.jpg'),
(129262, 9232, 'Meu Homem e um Cupido [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/261341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eAsPxMmbz5WPodGKxRWFzuSYQWL.jpg'),
(129263, 9232, 'Meu Homem e um Cupido [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/261342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eAsPxMmbz5WPodGKxRWFzuSYQWL.jpg'),
(129264, 9232, 'Meu Homem e um Cupido [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/261343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eAsPxMmbz5WPodGKxRWFzuSYQWL.jpg'),
(129265, 9232, 'Meu Homem e um Cupido [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/261344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eAsPxMmbz5WPodGKxRWFzuSYQWL.jpg'),
(129266, 9232, 'Meu Homem e um Cupido [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/261345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eAsPxMmbz5WPodGKxRWFzuSYQWL.jpg'),
(129267, 9232, 'Meu Homem e um Cupido [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/261346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eAsPxMmbz5WPodGKxRWFzuSYQWL.jpg'),
(129268, 9233, 'Muv Luv Alternative Total Eclipse S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/270248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gVxp0r0AtxFXWnr5jB2PpOLJPML.jpg'),
(129269, 9233, 'Muv Luv Alternative Total Eclipse S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/270249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oo2TLDHxAiF3AZLIOkzBwYL0X7t.jpg'),
(129270, 9233, 'Muv Luv Alternative Total Eclipse S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/270250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gmQhBVGi5fc8uJvLOW6GonfZgyR.jpg'),
(129271, 9233, 'Muv Luv Alternative Total Eclipse S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/270251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7cQlxvpzIr0w7QtBc8dpSs0ycAk.jpg'),
(129272, 9233, 'Muv Luv Alternative Total Eclipse S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/270252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iU8KXigx6uBY1myCisjDccsHJxb.jpg'),
(129273, 9233, 'Muv Luv Alternative Total Eclipse S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/270253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qCcUT9hJAjQN0gRPVC8lzeXobci.jpg'),
(129274, 9233, 'Muv Luv Alternative Total Eclipse S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/270254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qCcUT9hJAjQN0gRPVC8lzeXobci.jpg'),
(129275, 9233, 'Muv Luv Alternative Total Eclipse S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/270255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qCcUT9hJAjQN0gRPVC8lzeXobci.jpg'),
(129276, 9233, 'Muv Luv Alternative Total Eclipse S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/270256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qCcUT9hJAjQN0gRPVC8lzeXobci.jpg'),
(129277, 9233, 'Muv Luv Alternative Total Eclipse S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/270257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qCcUT9hJAjQN0gRPVC8lzeXobci.jpg'),
(129278, 9233, 'Muv Luv Alternative Total Eclipse S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/270258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qCcUT9hJAjQN0gRPVC8lzeXobci.jpg'),
(129279, 9233, 'Muv Luv Alternative Total Eclipse S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/270259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qCcUT9hJAjQN0gRPVC8lzeXobci.jpg'),
(129280, 9233, 'Muv Luv Alternative Total Eclipse S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/270260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qCcUT9hJAjQN0gRPVC8lzeXobci.jpg'),
(129281, 9233, 'Muv Luv Alternative Total Eclipse S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/270261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qCcUT9hJAjQN0gRPVC8lzeXobci.jpg'),
(129282, 9233, 'Muv Luv Alternative Total Eclipse S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/270262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qCcUT9hJAjQN0gRPVC8lzeXobci.jpg'),
(129283, 9233, 'Muv Luv Alternative Total Eclipse S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/270263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qCcUT9hJAjQN0gRPVC8lzeXobci.jpg'),
(129284, 9233, 'Muv Luv Alternative Total Eclipse S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/270264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qCcUT9hJAjQN0gRPVC8lzeXobci.jpg'),
(129285, 9233, 'Muv Luv Alternative Total Eclipse S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/270265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qCcUT9hJAjQN0gRPVC8lzeXobci.jpg'),
(129286, 9233, 'Muv Luv Alternative Total Eclipse S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/271031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qCcUT9hJAjQN0gRPVC8lzeXobci.jpg'),
(129287, 9233, 'Muv Luv Alternative Total Eclipse S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/272766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qCcUT9hJAjQN0gRPVC8lzeXobci.jpg'),
(129288, 9233, 'Muv Luv Alternative Total Eclipse S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/274404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qCcUT9hJAjQN0gRPVC8lzeXobci.jpg'),
(129289, 9233, 'Muv Luv Alternative Total Eclipse S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/593636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qCcUT9hJAjQN0gRPVC8lzeXobci.jpg'),
(129290, 9233, 'Muv Luv Alternative Total Eclipse S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/280740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qCcUT9hJAjQN0gRPVC8lzeXobci.jpg'),
(129291, 9234, 'O Encontro com Dragao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129292, 9234, 'O Encontro com Dragao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129293, 9234, 'O Encontro com Dragao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129294, 9234, 'O Encontro com Dragao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129295, 9234, 'O Encontro com Dragao [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129296, 9234, 'O Encontro com Dragao [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129297, 9234, 'O Encontro com Dragao [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129298, 9234, 'O Encontro com Dragao [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129299, 9234, 'O Encontro com Dragao [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129300, 9234, 'O Encontro com Dragao [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129301, 9234, 'O Encontro com Dragao [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129302, 9234, 'O Encontro com Dragao [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129303, 9234, 'O Encontro com Dragao [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129304, 9234, 'O Encontro com Dragao [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/252484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129305, 9234, 'O Encontro com Dragao [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/252485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129306, 9234, 'O Encontro com Dragao [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/252486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129307, 9234, 'O Encontro com Dragao [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/252487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129308, 9234, 'O Encontro com Dragao [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/252488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129309, 9234, 'O Encontro com Dragao [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/252489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129310, 9234, 'O Encontro com Dragao [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/252490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129311, 9234, 'O Encontro com Dragao [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/252491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129312, 9234, 'O Encontro com Dragao [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/252492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129313, 9234, 'O Encontro com Dragao [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/252493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129314, 9234, 'O Encontro com Dragao [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/252494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129315, 9234, 'O Encontro com Dragao [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/252495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129316, 9234, 'O Encontro com Dragao [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/252496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129317, 9234, 'O Encontro com Dragao [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/252497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129318, 9234, 'O Encontro com Dragao [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/252498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129319, 9234, 'O Encontro com Dragao [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/252499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129320, 9234, 'O Encontro com Dragao [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/252500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129321, 9234, 'O Encontro com Dragao [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/252501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129322, 9234, 'O Encontro com Dragao [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/252502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129323, 9234, 'O Encontro com Dragao [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/252503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129324, 9234, 'O Encontro com Dragao [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/252504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129325, 9234, 'O Encontro com Dragao [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/252505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129326, 9234, 'O Encontro com Dragao [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/252506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imilFxJWV7JBdzT4JLnoi8mAF8c.jpg'),
(129327, 9235, 'Pecados Mortais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129328, 9235, 'Pecados Mortais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129329, 9235, 'Pecados Mortais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129330, 9235, 'Pecados Mortais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129331, 9235, 'Pecados Mortais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129332, 9235, 'Pecados Mortais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129333, 9235, 'Pecados Mortais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129334, 9236, 'Pecados Mortais S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129335, 9236, 'Pecados Mortais S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129336, 9236, 'Pecados Mortais S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129337, 9236, 'Pecados Mortais S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129338, 9236, 'Pecados Mortais S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129339, 9236, 'Pecados Mortais S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129340, 9236, 'Pecados Mortais S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129341, 9236, 'Pecados Mortais S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129342, 9236, 'Pecados Mortais S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129343, 9236, 'Pecados Mortais S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129344, 9237, 'Pecados Mortais S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129345, 9237, 'Pecados Mortais S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129346, 9237, 'Pecados Mortais S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129347, 9237, 'Pecados Mortais S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129348, 9237, 'Pecados Mortais S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129349, 9237, 'Pecados Mortais S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129350, 9237, 'Pecados Mortais S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129351, 9237, 'Pecados Mortais S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129352, 9237, 'Pecados Mortais S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129353, 9237, 'Pecados Mortais S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129354, 9238, 'Pecados Mortais S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129355, 9238, 'Pecados Mortais S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129356, 9238, 'Pecados Mortais S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129357, 9238, 'Pecados Mortais S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129358, 9238, 'Pecados Mortais S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129359, 9238, 'Pecados Mortais S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129360, 9238, 'Pecados Mortais S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129361, 9238, 'Pecados Mortais S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129362, 9238, 'Pecados Mortais S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129363, 9238, 'Pecados Mortais S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129364, 9239, 'Pecados Mortais S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129365, 9239, 'Pecados Mortais S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129366, 9239, 'Pecados Mortais S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129367, 9239, 'Pecados Mortais S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129368, 9239, 'Pecados Mortais S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129369, 9239, 'Pecados Mortais S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129370, 9239, 'Pecados Mortais S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129371, 9239, 'Pecados Mortais S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129372, 9239, 'Pecados Mortais S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129373, 9239, 'Pecados Mortais S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/26FUSKdpEYkK22rk4FqJzf9MK7t.jpg'),
(129374, 9240, 'Percy Jackson e os Olimpianos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tBlYUJrATQJIilgO0P40edoQAgE.jpg'),
(129375, 9240, 'Percy Jackson e os Olimpianos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bG1rPBVP6OIkl9fU0z5UqPmlhh1.jpg'),
(129376, 9240, 'Percy Jackson e os Olimpianos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/63zVMAA4oxz9N8EnkNdR8gpyjKf.jpg'),
(129377, 9240, 'Percy Jackson e os Olimpianos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/63zVMAA4oxz9N8EnkNdR8gpyjKf.jpg'),
(129378, 9240, 'Percy Jackson e os Olimpianos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/63zVMAA4oxz9N8EnkNdR8gpyjKf.jpg'),
(129379, 9240, 'Percy Jackson e os Olimpianos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/63zVMAA4oxz9N8EnkNdR8gpyjKf.jpg'),
(129380, 9240, 'Percy Jackson e os Olimpianos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/63zVMAA4oxz9N8EnkNdR8gpyjKf.jpg'),
(129381, 9240, 'Percy Jackson e os Olimpianos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/63zVMAA4oxz9N8EnkNdR8gpyjKf.jpg'),
(129382, 9241, 'Percy Jackson e os Olimpianos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/896391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/63zVMAA4oxz9N8EnkNdR8gpyjKf.jpg'),
(129383, 9241, 'Percy Jackson e os Olimpianos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/896392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/63zVMAA4oxz9N8EnkNdR8gpyjKf.jpg'),
(129384, 9241, 'Percy Jackson e os Olimpianos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/896393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/63zVMAA4oxz9N8EnkNdR8gpyjKf.jpg'),
(129385, 9241, 'Percy Jackson e os Olimpianos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/897410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/63zVMAA4oxz9N8EnkNdR8gpyjKf.jpg'),
(129386, 9242, 'Semideuses e Semidemonios [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Vvr6716NlO47MsFDibm0xpBMFz.jpg'),
(129387, 9242, 'Semideuses e Semidemonios [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/imtFoTz8QCTpyITGITMJJr9OIPh.jpg'),
(129388, 9242, 'Semideuses e Semidemonios [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jqTToBjnSkIruOesOrzAmvDBWmh.jpg'),
(129389, 9242, 'Semideuses e Semidemonios [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hUpGSMzOEaOfbqX0y4apwdvpoyI.jpg'),
(129390, 9242, 'Semideuses e Semidemonios [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7pVFZ0Do72780l7OTKoJQsCudGE.jpg'),
(129391, 9242, 'Semideuses e Semidemonios [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1lyJ3DD41F3RnjwjA6K0UAQyOZe.jpg'),
(129392, 9242, 'Semideuses e Semidemonios [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qhqG5vsfrdh9HX5fXvnhfbaFdkZ.jpg'),
(129393, 9242, 'Semideuses e Semidemonios [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8EJPaITcV8CGuWzXh5hVR93wfS9.jpg'),
(129394, 9242, 'Semideuses e Semidemonios [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2rIuUCwqWMOZHHLJKsNHEPQrtm.jpg'),
(129395, 9242, 'Semideuses e Semidemonios [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129396, 9242, 'Semideuses e Semidemonios [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129397, 9242, 'Semideuses e Semidemonios [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129398, 9242, 'Semideuses e Semidemonios [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129399, 9242, 'Semideuses e Semidemonios [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/252387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129400, 9242, 'Semideuses e Semidemonios [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/252388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129401, 9242, 'Semideuses e Semidemonios [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/252389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129402, 9242, 'Semideuses e Semidemonios [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/252390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129403, 9242, 'Semideuses e Semidemonios [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/252391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129404, 9242, 'Semideuses e Semidemonios [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/252392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129405, 9242, 'Semideuses e Semidemonios [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/252393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129406, 9242, 'Semideuses e Semidemonios [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/252394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129407, 9242, 'Semideuses e Semidemonios [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/252395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129408, 9242, 'Semideuses e Semidemonios [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/252396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129409, 9242, 'Semideuses e Semidemonios [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/252397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129410, 9242, 'Semideuses e Semidemonios [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/252398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129411, 9242, 'Semideuses e Semidemonios [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/252399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129412, 9242, 'Semideuses e Semidemonios [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/252400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129413, 9242, 'Semideuses e Semidemonios [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/252401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129414, 9242, 'Semideuses e Semidemonios [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/252402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129415, 9242, 'Semideuses e Semidemonios [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/252403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129416, 9242, 'Semideuses e Semidemonios [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/252404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129417, 9242, 'Semideuses e Semidemonios [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/252405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129418, 9242, 'Semideuses e Semidemonios [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/252406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129419, 9242, 'Semideuses e Semidemonios [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/252407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129420, 9242, 'Semideuses e Semidemonios [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/252408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129421, 9242, 'Semideuses e Semidemonios [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/252409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129422, 9242, 'Semideuses e Semidemonios [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/252410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129423, 9242, 'Semideuses e Semidemonios [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/252411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129424, 9242, 'Semideuses e Semidemonios [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/252412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129425, 9242, 'Semideuses e Semidemonios [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/252413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129426, 9242, 'Semideuses e Semidemonios [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/252414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129427, 9242, 'Semideuses e Semidemonios [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/252415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129428, 9242, 'Semideuses e Semidemonios [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/252416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129429, 9242, 'Semideuses e Semidemonios [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/252417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129430, 9242, 'Semideuses e Semidemonios [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/252418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129431, 9242, 'Semideuses e Semidemonios [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/252419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129432, 9242, 'Semideuses e Semidemonios [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/252420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129433, 9242, 'Semideuses e Semidemonios [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/252421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129434, 9242, 'Semideuses e Semidemonios [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/252422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129435, 9242, 'Semideuses e Semidemonios [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/252423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0gvywTPbbHLcJDedoLdciaiB2t.jpg'),
(129436, 9243, 'A Lenda de Zhuohua [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wfgTBwDefAPbnflDAUZenkKBUrX.jpg'),
(129437, 9243, 'A Lenda de Zhuohua [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nImDN5rckG66J2EX45o5o1RYUxd.jpg'),
(129438, 9243, 'A Lenda de Zhuohua [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pPObtdxG3Z68Nh6g7lGnaNGx6HY.jpg'),
(129439, 9243, 'A Lenda de Zhuohua [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5mDxsvQ8hW4EPNDHQZ7XD29MH14.jpg'),
(129440, 9243, 'A Lenda de Zhuohua [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5d7pfwanNRZ2dWdaCgWHCQ0KW24.jpg'),
(129441, 9243, 'A Lenda de Zhuohua [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/192GRK7ocv4O0SKbWSr7CE1ioI0.jpg'),
(129442, 9243, 'A Lenda de Zhuohua [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bIz2Tp5CFm2PJ97CgEXq4z0aI4F.jpg'),
(129443, 9243, 'A Lenda de Zhuohua [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ho8eV80ly3TrSASOmDDKo1smJ0Z.jpg'),
(129444, 9243, 'A Lenda de Zhuohua [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6GbFUBcsaqYQ2YLeplWg0pNE3Fr.jpg'),
(129445, 9243, 'A Lenda de Zhuohua [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gpX4QDhc4jVbLWQCuhumzuXqvnv.jpg'),
(129446, 9243, 'A Lenda de Zhuohua [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3XjQ0WwgDNEsnxR0hg8nMqVpJtk.jpg'),
(129447, 9243, 'A Lenda de Zhuohua [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hUQmRyOqiitXzQxUKexqBXyPL1h.jpg'),
(129448, 9243, 'A Lenda de Zhuohua [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jmTYkumnz3BVEVs96mOwFWQ0xoa.jpg'),
(129449, 9243, 'A Lenda de Zhuohua [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/252170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJ3F7N49fenVQPegTVyAy0VwAbb.jpg'),
(129450, 9243, 'A Lenda de Zhuohua [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/252171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzLk6kaKbq9V0Jtcf772OWax01t.jpg'),
(129451, 9243, 'A Lenda de Zhuohua [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/252172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1PqBXeQWTtl0QLU4Rxp2C2zlDwx.jpg'),
(129452, 9243, 'A Lenda de Zhuohua [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/252173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tss07013dXSFTGphZL4njKrV2B8.jpg'),
(129453, 9243, 'A Lenda de Zhuohua [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/252174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dtaPeJHqChDKyxmkYGWbnqfznEV.jpg'),
(129454, 9243, 'A Lenda de Zhuohua [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/252175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wGodWcKlSAxn9lvAvXKskr6ix4K.jpg'),
(129455, 9243, 'A Lenda de Zhuohua [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/252176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A7PHXM9Xb2dyxDhfJAUliL0GCf2.jpg'),
(129456, 9243, 'A Lenda de Zhuohua [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/252177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mGQdgSg9DGM1ihkR4TD0ndeBb62.jpg'),
(129457, 9243, 'A Lenda de Zhuohua [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/252178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/up9Hlj96UVngAAGsmnoy5ioAnx1.jpg'),
(129458, 9243, 'A Lenda de Zhuohua [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/252179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iapGibHYVV4a2LFHSlWZXbkbuLK.jpg'),
(129459, 9243, 'A Lenda de Zhuohua [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/252180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1lfOnyLDBlC4u69HRqIvjjeQCE.jpg'),
(129460, 9243, 'A Lenda de Zhuohua [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/252181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kEBYPOvHOugx86kEI86EcswuX8n.jpg'),
(129461, 9243, 'A Lenda de Zhuohua [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/252182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/huNAJrJFchtzujg7BjybkiXMbMo.jpg'),
(129462, 9243, 'A Lenda de Zhuohua [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/252183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5969EWgpfp339j2MKUa6WTZyJol.jpg'),
(129463, 9243, 'A Lenda de Zhuohua [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/252184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bR9d0smgNlxAyVsCgsb4Ys8R6s1.jpg'),
(129464, 9243, 'A Lenda de Zhuohua [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/252185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gcG4gEVsinqqLCDO5gTZNFo65oE.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(129465, 9243, 'A Lenda de Zhuohua [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/252186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iFPZ6n2VnsGszaV5n1bwLp0TbqP.jpg'),
(129466, 9243, 'A Lenda de Zhuohua [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/252187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cCXRA9tZzCKtIt8Xs0nuFq1x7K3.jpg'),
(129467, 9243, 'A Lenda de Zhuohua [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/252188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rctI9nsureCboqEWNPLHvojeZ8Y.jpg'),
(129468, 9243, 'A Lenda de Zhuohua [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/252189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lfPdPgzmrRKLGrTV8JkVGJhrrUU.jpg'),
(129469, 9243, 'A Lenda de Zhuohua [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/252190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zXCzSIbzMM8bzsPGi4ovMjDPZKo.jpg'),
(129470, 9243, 'A Lenda de Zhuohua [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/252191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3nrud2GcAQnUO6CoJjanAYMjHQV.jpg'),
(129471, 9243, 'A Lenda de Zhuohua [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/252192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gG3Y9MvHOgqXqqlifOyAMZjNYqT.jpg'),
(129472, 9243, 'A Lenda de Zhuohua [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/252193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/izi247PWho2LhJ9ixdAPhtdLq4r.jpg'),
(129473, 9243, 'A Lenda de Zhuohua [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/252194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p94SiOwTpKgAoHOjYhSDw5rNltm.jpg'),
(129474, 9243, 'A Lenda de Zhuohua [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/252195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8deRQ1IaGGXyeIC97Dc6tC3d6ys.jpg'),
(129475, 9243, 'A Lenda de Zhuohua [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/252196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qYNbltTTzEwxcEbSj33Y9Chx4u1.jpg'),
(129476, 9244, 'Agora Terminamos [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/48o4oEXbNpOKB2Hecd4icEPv7s5.jpg'),
(129477, 9244, 'Agora Terminamos [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c3bMmXGOPUPn3lBA9En7bDNwfwt.jpg'),
(129478, 9244, 'Agora Terminamos [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/siAAuVWoGEVPAxbIXppZV7qNrv6.jpg'),
(129479, 9244, 'Agora Terminamos [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f79Clr9EZLmHatZwsVAzbESASLN.jpg'),
(129480, 9244, 'Agora Terminamos [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A6pVeOateM1OSTDP7rmMjrUKmuK.jpg'),
(129481, 9244, 'Agora Terminamos [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2qrSnjiqdSGhIutArgX36pQ1FAN.jpg'),
(129482, 9244, 'Agora Terminamos [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6p2ElTEBKe01I6R47CZPyv31dr8.jpg'),
(129483, 9244, 'Agora Terminamos [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4hCyX5zuPs5cpT2Gd3Bvzwm9fPR.jpg'),
(129484, 9244, 'Agora Terminamos [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/91EVlqLH73l4dKFivruvtI6XsgW.jpg'),
(129485, 9244, 'Agora Terminamos [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/osDJE51W2nvplkCQW1IdXmm66sA.jpg'),
(129486, 9244, 'Agora Terminamos [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tUGkXCWwVXqEXzFPex7csVeOMb8.jpg'),
(129487, 9244, 'Agora Terminamos [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fakiECAR91te29r4oTXt01H8Lhb.jpg'),
(129488, 9244, 'Agora Terminamos [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/im1IX794108HZ3qAVy9QIpo0dZp.jpg'),
(129489, 9244, 'Agora Terminamos [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/252154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/usqPHTZ9iN1WQJBVa6ycEuLwyC8.jpg'),
(129490, 9244, 'Agora Terminamos [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/252155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ebfoIy3KF1X8lIYtY4usPAK4QCL.jpg'),
(129491, 9244, 'Agora Terminamos [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/252156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pz6udK8S0XQ08lMCTnfrJsSd1uN.jpg'),
(129492, 9245, 'Doctor Prisoner [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x1Kcn7rL7jcDyfbZp4CAL80XV83.jpg'),
(129493, 9245, 'Doctor Prisoner [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5KqBuTxJbR8cJVvMUnfCjbsNjNj.jpg'),
(129494, 9245, 'Doctor Prisoner [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHJ54t4A6HfVnYTYbhmCYBQz9s8.jpg'),
(129495, 9245, 'Doctor Prisoner [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o4AewluGjfncMJnvYZR7W9PuZ00.jpg'),
(129496, 9245, 'Doctor Prisoner [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uLLFYRPsrpkcY9LWDqgrbAwOwkK.jpg'),
(129497, 9245, 'Doctor Prisoner [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nYjeDqH8F3KObOPQ2cJcfMmjdbe.jpg'),
(129498, 9245, 'Doctor Prisoner [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u1WJbKPegadzJsFAHk2CLhSj6NC.jpg'),
(129499, 9245, 'Doctor Prisoner [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rW302zbM1xkiEVDmHlvpEiUP0yq.jpg'),
(129500, 9245, 'Doctor Prisoner [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sq7XemTlh9YR288gMK0PDtrkn3V.jpg'),
(129501, 9245, 'Doctor Prisoner [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBO34bi9zAMhVlgP3wEl1yTyCek.jpg'),
(129502, 9245, 'Doctor Prisoner [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o5jfrv5FNF3lgSIbA6zYN3FvzCO.jpg'),
(129503, 9245, 'Doctor Prisoner [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0XPIxqKYQTXBbGVUe6X8tZyxVX.jpg'),
(129504, 9245, 'Doctor Prisoner [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iV8ZmcPKOBopAyqF0rlniZN5BoJ.jpg'),
(129505, 9245, 'Doctor Prisoner [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/252122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2gdQtJc3iR7mVJ3ERl6GVz94SXv.jpg'),
(129506, 9245, 'Doctor Prisoner [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/252123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmxbqPcqi9rKWwTo5yq5dshFVVF.jpg'),
(129507, 9245, 'Doctor Prisoner [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/252124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gY1ffcAR1mmLacVOyfq4j1cdl1z.jpg'),
(129508, 9245, 'Doctor Prisoner [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/252125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/67FLhynveUGytuBetOQANZRmNKQ.jpg'),
(129509, 9245, 'Doctor Prisoner [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/252126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/67FLhynveUGytuBetOQANZRmNKQ.jpg'),
(129510, 9245, 'Doctor Prisoner [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/252127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/67FLhynveUGytuBetOQANZRmNKQ.jpg'),
(129511, 9245, 'Doctor Prisoner [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/252128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/67FLhynveUGytuBetOQANZRmNKQ.jpg'),
(129512, 9245, 'Doctor Prisoner [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/252129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/67FLhynveUGytuBetOQANZRmNKQ.jpg'),
(129513, 9245, 'Doctor Prisoner [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/252130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/67FLhynveUGytuBetOQANZRmNKQ.jpg'),
(129514, 9245, 'Doctor Prisoner [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/252131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/67FLhynveUGytuBetOQANZRmNKQ.jpg'),
(129515, 9245, 'Doctor Prisoner [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/252132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/67FLhynveUGytuBetOQANZRmNKQ.jpg'),
(129516, 9245, 'Doctor Prisoner [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/252133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/67FLhynveUGytuBetOQANZRmNKQ.jpg'),
(129517, 9245, 'Doctor Prisoner [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/252134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/67FLhynveUGytuBetOQANZRmNKQ.jpg'),
(129518, 9245, 'Doctor Prisoner [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/252135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/67FLhynveUGytuBetOQANZRmNKQ.jpg'),
(129519, 9245, 'Doctor Prisoner [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/252136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/67FLhynveUGytuBetOQANZRmNKQ.jpg'),
(129520, 9245, 'Doctor Prisoner [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/252137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/67FLhynveUGytuBetOQANZRmNKQ.jpg'),
(129521, 9245, 'Doctor Prisoner [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/252138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/67FLhynveUGytuBetOQANZRmNKQ.jpg'),
(129522, 9245, 'Doctor Prisoner [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/252139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/67FLhynveUGytuBetOQANZRmNKQ.jpg'),
(129523, 9245, 'Doctor Prisoner [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/252140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/67FLhynveUGytuBetOQANZRmNKQ.jpg'),
(129524, 9246, 'Flores no Deserto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zZ0uX2fAqeONypmst01L6Y3IX4o.jpg'),
(129525, 9246, 'Flores no Deserto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5KywPQdxkvl02OPmREYR8a68C0q.jpg'),
(129526, 9246, 'Flores no Deserto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g90L9ho4seAjxEHlZzRYONMgYrD.jpg'),
(129527, 9246, 'Flores no Deserto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g90L9ho4seAjxEHlZzRYONMgYrD.jpg'),
(129528, 9246, 'Flores no Deserto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g90L9ho4seAjxEHlZzRYONMgYrD.jpg'),
(129529, 9246, 'Flores no Deserto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g90L9ho4seAjxEHlZzRYONMgYrD.jpg'),
(129530, 9246, 'Flores no Deserto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g90L9ho4seAjxEHlZzRYONMgYrD.jpg'),
(129531, 9246, 'Flores no Deserto S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g90L9ho4seAjxEHlZzRYONMgYrD.jpg'),
(129532, 9246, 'Flores no Deserto S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g90L9ho4seAjxEHlZzRYONMgYrD.jpg'),
(129533, 9246, 'Flores no Deserto S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g90L9ho4seAjxEHlZzRYONMgYrD.jpg'),
(129534, 9246, 'Flores no Deserto S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g90L9ho4seAjxEHlZzRYONMgYrD.jpg'),
(129535, 9246, 'Flores no Deserto S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g90L9ho4seAjxEHlZzRYONMgYrD.jpg'),
(129536, 9247, 'Gyeongseong Creature S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6QWQ7SaGFeOnzo2HvAqljp1fTbq.jpg'),
(129537, 9247, 'Gyeongseong Creature S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6QWQ7SaGFeOnzo2HvAqljp1fTbq.jpg'),
(129538, 9247, 'Gyeongseong Creature S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6QWQ7SaGFeOnzo2HvAqljp1fTbq.jpg'),
(129539, 9247, 'Gyeongseong Creature S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6QWQ7SaGFeOnzo2HvAqljp1fTbq.jpg'),
(129540, 9247, 'Gyeongseong Creature S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6QWQ7SaGFeOnzo2HvAqljp1fTbq.jpg'),
(129541, 9247, 'Gyeongseong Creature S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6QWQ7SaGFeOnzo2HvAqljp1fTbq.jpg'),
(129542, 9247, 'Gyeongseong Creature S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6QWQ7SaGFeOnzo2HvAqljp1fTbq.jpg'),
(129543, 9247, 'Gyeongseong Creature S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6QWQ7SaGFeOnzo2HvAqljp1fTbq.jpg'),
(129544, 9247, 'Gyeongseong Creature S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6QWQ7SaGFeOnzo2HvAqljp1fTbq.jpg'),
(129545, 9247, 'Gyeongseong Creature S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6QWQ7SaGFeOnzo2HvAqljp1fTbq.jpg'),
(129546, 9248, 'Gyeongseong Creature S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/467418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6QWQ7SaGFeOnzo2HvAqljp1fTbq.jpg'),
(129547, 9248, 'Gyeongseong Creature S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/467419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6QWQ7SaGFeOnzo2HvAqljp1fTbq.jpg'),
(129548, 9248, 'Gyeongseong Creature S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/467420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6QWQ7SaGFeOnzo2HvAqljp1fTbq.jpg'),
(129549, 9248, 'Gyeongseong Creature S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/467421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6QWQ7SaGFeOnzo2HvAqljp1fTbq.jpg'),
(129550, 9248, 'Gyeongseong Creature S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/467422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6QWQ7SaGFeOnzo2HvAqljp1fTbq.jpg'),
(129551, 9248, 'Gyeongseong Creature S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/467423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6QWQ7SaGFeOnzo2HvAqljp1fTbq.jpg'),
(129552, 9248, 'Gyeongseong Creature S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/467424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6QWQ7SaGFeOnzo2HvAqljp1fTbq.jpg'),
(129553, 9249, 'Insider [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/izABLev9P8sxsTrF8jOgvMbsDj2.jpg'),
(129554, 9249, 'Insider [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bBLwXaibkeB8GNRuDdwVIZjuFFt.jpg'),
(129555, 9249, 'Insider [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tu1J6oj89nP2U9mPRWwjunkZP3l.jpg'),
(129556, 9249, 'Insider [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9r4ebTEG2M7IGyQAqFTfcHI5WlJ.jpg'),
(129557, 9249, 'Insider [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cYJFxcQU2Tr2mzy1n9MunF8aGvk.jpg'),
(129558, 9249, 'Insider [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ehgLvFhupnxNlALVEbRPb6P6VG.jpg'),
(129559, 9249, 'Insider [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e85d3oRdUpVspwp9Ax4iii0NXTH.jpg'),
(129560, 9249, 'Insider [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wLAe4NaXaUcoTEC8ee195r0uW7T.jpg'),
(129561, 9249, 'Insider [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zvSGmy3HYBUAXX9yXLRbR1g4W9h.jpg'),
(129562, 9249, 'Insider [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kqeYPWMGwLzlg0FCYuJVHLwKnwc.jpg'),
(129563, 9249, 'Insider [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uRaEIm8KzM78rUT5LqavhQNTwYm.jpg'),
(129564, 9249, 'Insider [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97Dh6YB9wuJcPJXxVJ0O0Kf9Vj8.jpg'),
(129565, 9249, 'Insider [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZDOOtREjyzmKmObPJTVLgA79WL.jpg'),
(129566, 9249, 'Insider [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/252106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xKLr3Ht9JcpLixTkyyVA1uZYJ4G.jpg'),
(129567, 9249, 'Insider [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/252107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oN3nryJpS8Ma5NCZaH8lL0vuJDo.jpg'),
(129568, 9249, 'Insider [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/252108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Ys1glIIUX1TotzfGOaASLpYTZH.jpg'),
(129569, 9250, 'Kid vs. Kat S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129570, 9250, 'Kid vs. Kat S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129571, 9250, 'Kid vs. Kat S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129572, 9250, 'Kid vs. Kat S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129573, 9250, 'Kid vs. Kat S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129574, 9250, 'Kid vs. Kat S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129575, 9250, 'Kid vs. Kat S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129576, 9250, 'Kid vs. Kat S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129577, 9250, 'Kid vs. Kat S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129578, 9250, 'Kid vs. Kat S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129579, 9250, 'Kid vs. Kat S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129580, 9250, 'Kid vs. Kat S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129581, 9250, 'Kid vs. Kat S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129582, 9250, 'Kid vs. Kat S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/252080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129583, 9250, 'Kid vs. Kat S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/252081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129584, 9250, 'Kid vs. Kat S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/252082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129585, 9250, 'Kid vs. Kat S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/252083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129586, 9250, 'Kid vs. Kat S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/252084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129587, 9250, 'Kid vs. Kat S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/252085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129588, 9250, 'Kid vs. Kat S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/252086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129589, 9250, 'Kid vs. Kat S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/252087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129590, 9250, 'Kid vs. Kat S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/252088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129591, 9250, 'Kid vs. Kat S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/252089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129592, 9250, 'Kid vs. Kat S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/252090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129593, 9250, 'Kid vs. Kat S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/252091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129594, 9250, 'Kid vs. Kat S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/252092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1f3DyCY4Xe6ZxN2blj0gNdWhS71.jpg'),
(129595, 9251, 'Namoro na Cozinha [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9UarJqn7o6bbjX3jzTkWbwmzKcR.jpg'),
(129596, 9251, 'Namoro na Cozinha [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1yjGIGsWdMvQ7qSoNP1fZtvGRpa.jpg'),
(129597, 9251, 'Namoro na Cozinha [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7J4ThGzYbCp8dSGwd4XMqpeyVbs.jpg'),
(129598, 9251, 'Namoro na Cozinha [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1y64KSY3dDF3UKoaK13vTlbP72p.jpg'),
(129599, 9251, 'Namoro na Cozinha [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yALwjPCttH6eqkxgdpNvehbIaTf.jpg'),
(129600, 9251, 'Namoro na Cozinha [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFIRsOmZnygab9CZdpgw8ZVIlRe.jpg'),
(129601, 9251, 'Namoro na Cozinha [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/obCd9T4TQXje1UyrXVqeagNElvt.jpg'),
(129602, 9251, 'Namoro na Cozinha [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1i8aDbaSVJF3tbDoXwzkLP7bJvr.jpg'),
(129603, 9251, 'Namoro na Cozinha [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fbTq6UPhFXsMwiF0056L8MZQxDV.jpg'),
(129604, 9251, 'Namoro na Cozinha [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fgLpTalOzS0Jx4eASiC10EbvePL.jpg'),
(129605, 9251, 'Namoro na Cozinha [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6yFfDFUbwkylek2tJhBXaSZGokN.jpg'),
(129606, 9251, 'Namoro na Cozinha [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7rxbuO9UW9QqyWp5Rj2aHGP8rjK.jpg'),
(129607, 9251, 'Namoro na Cozinha [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gecucOQYssgtcT0HXWwtNaalCQ6.jpg'),
(129608, 9251, 'Namoro na Cozinha [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/252056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lWq3KoTckca9a9RRWdXUCGilpkD.jpg'),
(129609, 9251, 'Namoro na Cozinha [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/252057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/akzrOCA85qzR1AUtN4Lo5TQaEzi.jpg'),
(129610, 9251, 'Namoro na Cozinha [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/252058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pxGeXAdITXF9prJ2srk3cnGKOxV.jpg'),
(129611, 9251, 'Namoro na Cozinha [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/252059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9xhhRwAORfNQtcwDuYdhTcY8zb3.jpg'),
(129612, 9251, 'Namoro na Cozinha [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/252060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ptbpzRlxA7AxfnNoGecdCNIFSKt.jpg'),
(129613, 9251, 'Namoro na Cozinha [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/252061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/anYJR6zDnJu6pJksYgUNjoQbpqs.jpg'),
(129614, 9251, 'Namoro na Cozinha [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/252062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n7imHgW5lr5DNhhvVGgAi7U6oYO.jpg'),
(129615, 9251, 'Namoro na Cozinha [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/252063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tIktcUWcBaiFNLDe2s8FwJ447FX.jpg'),
(129616, 9251, 'Namoro na Cozinha [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/252064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u5i36kteeP5TMYNfBn8c8dCxmJw.jpg'),
(129617, 9251, 'Namoro na Cozinha [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/252065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1o5lnKMe6qbf7zDxAD6Nah7eN21.jpg'),
(129618, 9251, 'Namoro na Cozinha [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/252066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/XLiEZvIabQNgePXMKO5h0fuJlv.jpg'),
(129619, 9252, 'O Outro Lado [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/252037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jKTLDd7hp2bahzxPMmVhjvgwfVg.jpg'),
(129620, 9252, 'O Outro Lado [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/252038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqWNEjCZpJMkZo2tVplxmmA2c5l.jpg'),
(129621, 9252, 'O Outro Lado [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/252039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/st2hWrlI1OmwB01LYwSdlY8ydvZ.jpg'),
(129622, 9252, 'O Outro Lado [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6Cn7BvFKWZ9kSgu7jmnVkrwLTj.jpg'),
(129623, 9252, 'O Outro Lado [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w26pLbkOdbSLHIH7uYxr1ATKqu2.jpg'),
(129624, 9252, 'O Outro Lado [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6SUfxHmrU1X4LYYhrS2PpYEyzC3.jpg'),
(129625, 9253, 'O Sacerdote Impetuoso [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ivzJTK0XkHLcIhfEu4QUtZYHYJt.jpg'),
(129626, 9253, 'O Sacerdote Impetuoso [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f28831eNvrFm7OiGkUoTU2uVoTP.jpg'),
(129627, 9253, 'O Sacerdote Impetuoso [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8UI5nYFwxwMGMhNS1YHXtWDbfA.jpg'),
(129628, 9253, 'O Sacerdote Impetuoso [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/252000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGeNKBZWTcRuM6ud9bHFzGkc2rj.jpg'),
(129629, 9253, 'O Sacerdote Impetuoso [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/252001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eXcZrgEMv8LdEcge071aBEDB2d2.jpg'),
(129630, 9253, 'O Sacerdote Impetuoso [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/252002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dwReZTMGEkHiOZPQbQgWjSkrbjx.jpg'),
(129631, 9253, 'O Sacerdote Impetuoso [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/252003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g72gd9sp5zNronZ66FREYB0wkbH.jpg'),
(129632, 9253, 'O Sacerdote Impetuoso [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/252004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyLRwcxhSfLKFVVq1U0thB0wMpL.jpg'),
(129633, 9253, 'O Sacerdote Impetuoso [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/252005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cFDLRkhzv2ih6dhUlLEDeBBZ6JS.jpg'),
(129634, 9253, 'O Sacerdote Impetuoso [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/252006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uyYk8n8617PVGpPDDeMk57zCZvZ.jpg'),
(129635, 9253, 'O Sacerdote Impetuoso [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/252007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7cJOxxh6tj2y8Aii5p28h7rcdN.jpg'),
(129636, 9253, 'O Sacerdote Impetuoso [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/252008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/djb0D9QCZF4x13u6myLYpM4LMGq.jpg'),
(129637, 9253, 'O Sacerdote Impetuoso [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/252009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Uza7DhcKtzKaxPBnm47WOu3t38.jpg'),
(129638, 9253, 'O Sacerdote Impetuoso [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/252010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qHmjWNbSO8rLW5AM8r2fdKzsvcM.jpg'),
(129639, 9253, 'O Sacerdote Impetuoso [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/252011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOPSvZWacF0DRQohY3P2aOZeRkx.jpg'),
(129640, 9253, 'O Sacerdote Impetuoso [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/252012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aa5QyAALKOXL3UJ330OeUvr3sfe.jpg'),
(129641, 9253, 'O Sacerdote Impetuoso [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/252013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7ZeYIQncXBPMCq8Hgc6WKOaKkf.jpg'),
(129642, 9253, 'O Sacerdote Impetuoso [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/252014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vDzsA9QPP8MlQO7e8vsY3HTOhSI.jpg'),
(129643, 9253, 'O Sacerdote Impetuoso [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/252015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4naAz0kImDnmoazAIPGA1K6sxPB.jpg'),
(129644, 9253, 'O Sacerdote Impetuoso [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/252016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yS9OOYsAztqDc11wurickFEfO1e.jpg'),
(129645, 9253, 'O Sacerdote Impetuoso [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/252017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vpBiWSFMpOZDuPyBrVw8qy0EzrF.jpg'),
(129646, 9253, 'O Sacerdote Impetuoso [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/252018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gKl9zdORhm2iSGnS7PkAHkT7pnV.jpg'),
(129647, 9253, 'O Sacerdote Impetuoso [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/252019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xYgfnSdyO3Qlnml1JEWoOtNX5CZ.jpg'),
(129648, 9253, 'O Sacerdote Impetuoso [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/252020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ckcBGRBHRUCdFYEHTg81J1CR3Oc.jpg'),
(129649, 9253, 'O Sacerdote Impetuoso [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/252021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gfwI6EyMEAFmtaSKjxHMTIHbNDG.jpg'),
(129650, 9253, 'O Sacerdote Impetuoso [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/252022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c5nKkgcPLF73Yym7ZBYc2mfLDmL.jpg'),
(129651, 9253, 'O Sacerdote Impetuoso [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/252023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5QTBvIpITQasdEyo9P6HnbvxS92.jpg'),
(129652, 9253, 'O Sacerdote Impetuoso [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/252024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hgPR8Q72AFlP1Qu1L0CsbK82IoQ.jpg'),
(129653, 9253, 'O Sacerdote Impetuoso [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/252025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ghGDFYwsk1GLiy5Io9CD0Zwj0Uf.jpg'),
(129654, 9253, 'O Sacerdote Impetuoso [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/252026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8IwQuTmrLrQWnpKLK8N0F9OXdhU.jpg'),
(129655, 9253, 'O Sacerdote Impetuoso [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/252027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pjMcnrv6sjmemCxpwTAu8XKzCBH.jpg'),
(129656, 9253, 'O Sacerdote Impetuoso [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/252028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wKpIBudIJXqQC4mIwkZaz6mkkCh.jpg'),
(129657, 9253, 'O Sacerdote Impetuoso [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/252029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSOOAGTbl7YPKsokxotTtYxRv35.jpg'),
(129658, 9253, 'O Sacerdote Impetuoso [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/252030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t2cuqxwuTQE9LqBzpD1gwO5QgWm.jpg'),
(129659, 9253, 'O Sacerdote Impetuoso [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/252031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m5qxCO6cc4bgieJZgx6kquZAqKI.jpg'),
(129660, 9253, 'O Sacerdote Impetuoso [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/252032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hRQUNZlZ28UucWSQOrrhPNGWJ1N.jpg'),
(129661, 9253, 'O Sacerdote Impetuoso [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/252033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/47ZWlPj70NREFSFim1NkHWPXEvE.jpg'),
(129662, 9253, 'O Sacerdote Impetuoso [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/252034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aRaEZyeHJ5ZxstZpQBSdamnHAZw.jpg'),
(129663, 9253, 'O Sacerdote Impetuoso [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/252035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tBuLnOLn6EWU5ll1ykvG3Itj5r2.jpg'),
(129664, 9253, 'O Sacerdote Impetuoso [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/252036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTiliTnkSXWci9ZXuKvdpxI3cOF.jpg'),
(129665, 9254, 'Rattan [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wh5qDjb0HGerV4YA4ZJGfXFooP1.jpg'),
(129666, 9254, 'Rattan [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4MUMp7ORJKqw6gQRNUzRvdlwvjO.jpg'),
(129667, 9254, 'Rattan [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tKbRvouH5XeUGMS4x9E4zHmBJQW.jpg'),
(129668, 9254, 'Rattan [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aftu3x5NbIhEQ97A90YgxImOyiC.jpg'),
(129669, 9254, 'Rattan [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qjWG7kPlwmTMNuU51piOZKyKmQN.jpg'),
(129670, 9254, 'Rattan [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pXxHOUw1G1T6h2pgKklrIluLaqm.jpg'),
(129671, 9254, 'Rattan [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vrQyyyfczbX9oJFTwk8aGLgBxwC.jpg'),
(129672, 9254, 'Rattan [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cwulOkT5jlJvHfcxA6Imr6ZFkWK.jpg'),
(129673, 9254, 'Rattan [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sRQulkGVYxHLs1RMmLdNkbqMQ5v.jpg'),
(129674, 9254, 'Rattan [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yorMrYtvnERMo3CFo1NgIlonsm0.jpg'),
(129675, 9254, 'Rattan [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/suO3UiCwwn16V2HIiEC5c7kTgxW.jpg'),
(129676, 9254, 'Rattan [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hRarNzBmUPPiTpf4yA1kk6mC5DU.jpg'),
(129677, 9254, 'Rattan [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xyM8JvkgGNOeojuqQh6aC0Cyye5.jpg'),
(129678, 9254, 'Rattan [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hBBZQUuGjU3HHTQyUm6JRuzPSfO.jpg'),
(129679, 9254, 'Rattan [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vbfsfLQLm0ktWl26Vy9A9iDNzyG.jpg'),
(129680, 9254, 'Rattan [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/251981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/luVjOkkYTmCRYyW4ana4jxiWFMj.jpg'),
(129681, 9254, 'Rattan [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/251982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dfxNCRz5sFc4X65bxZTX4gN5IGp.jpg'),
(129682, 9254, 'Rattan [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/251983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bj8J7D91kZvEX6OeBbdHzqOag7O.jpg'),
(129683, 9254, 'Rattan [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/251984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqfr2gihyn5sdyNevdlnVr6mIi5.jpg'),
(129684, 9254, 'Rattan [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/251985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2IIoATsu980pzlGrfNBO8DuQ3kA.jpg'),
(129685, 9254, 'Rattan [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/251986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nqUnKhEuvbDqI6cm7uEGXTWi3Hm.jpg'),
(129686, 9254, 'Rattan [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/251987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eYW96OfZZXeFSbjwtWXR4zz29e6.jpg'),
(129687, 9254, 'Rattan [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/251988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/htim5i3kY1CDSZsS17AEZtvSUM1.jpg'),
(129688, 9254, 'Rattan [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/251989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aLkhQi0brynEgzrNSC2EDQ0VZ0N.jpg'),
(129689, 9254, 'Rattan [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/251990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7xTNAEzIrlLIaG27zOhvJs5UKlL.jpg'),
(129690, 9254, 'Rattan [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/251991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tNiIgXzcV3AgyuP752HBapgm7QE.jpg'),
(129691, 9254, 'Rattan [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/251992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6nnucZw17Y2XEJplhbNrG7ensZo.jpg'),
(129692, 9254, 'Rattan [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/251993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z0zhIhKPEs3HawnPBYQE7Ber07t.jpg'),
(129693, 9254, 'Rattan [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/251994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCducil3rauSLYce36SVKxH4BYe.jpg'),
(129694, 9254, 'Rattan [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/251995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dvWVSnoSJjLxrFGTGMpSqyaZu5J.jpg'),
(129695, 9254, 'Rattan [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/251996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7iG3NZfZkyaxJSsJMerOkcZFgI8.jpg'),
(129696, 9255, 'Vivant [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6hYRXSVtRLJTYfcWeDX76zU9jkt.jpg'),
(129697, 9255, 'Vivant [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uhQ069vHbBg4Dy42KczghwtbkSC.jpg'),
(129698, 9255, 'Vivant [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ogHg9cqMAudcIUSCvfcucUkQ4qc.jpg'),
(129699, 9255, 'Vivant [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZ98UJxvCiFfH135lYB8IH5Og9O.jpg'),
(129700, 9255, 'Vivant [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hY3f31xqWGxEP5ETdy6WMasEbh3.jpg'),
(129701, 9255, 'Vivant [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8bU4BLvXVPzRMpfN6ifDy0fiz8j.jpg'),
(129702, 9255, 'Vivant [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eq9RiBDfACNVj4rXFbrarPQ933W.jpg'),
(129703, 9255, 'Vivant [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5iBDpN0wGxL37Vxg1PgcLkYZAux.jpg'),
(129704, 9255, 'Vivant [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mlhcahP4iRhy49C7pIA96sPrj2z.jpg'),
(129705, 9255, 'Vivant [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/abpXyErqMAiIj1foIi36qzdaolT.jpg'),
(129706, 9256, 'Meu Demonio Favorito S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tLSb3i9NWyFZYiSDIgJ5ldx9fza.jpg'),
(129707, 9256, 'Meu Demonio Favorito S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ytmU4X2s9Yil4S8OvpkVnSvxohd.jpg'),
(129708, 9256, 'Meu Demonio Favorito S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Roa4QPck4B5447SBzVpphsexxB.jpg'),
(129709, 9256, 'Meu Demonio Favorito S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ibBjNb4WAkpcpDhnmkoiw8cTWJh.jpg'),
(129710, 9256, 'Meu Demonio Favorito S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7BTIHhk5BTPMUBZESqHhrxoAmUa.jpg'),
(129711, 9256, 'Meu Demonio Favorito S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/otDKLlBv2KeB0wPLuDjScPgeYgz.jpg'),
(129712, 9256, 'Meu Demonio Favorito S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a3rgpcca9djljXjzmL3p9X1y0vy.jpg'),
(129713, 9256, 'Meu Demonio Favorito S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kchJoe3Gwhyd1rn6fUbEQuVhxTq.jpg'),
(129714, 9256, 'Meu Demonio Favorito S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xBnscv5BrJREKVSvh0le61y4KDk.jpg'),
(129715, 9256, 'Meu Demonio Favorito S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xBnscv5BrJREKVSvh0le61y4KDk.jpg'),
(129716, 9256, 'Meu Demonio Favorito S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xBnscv5BrJREKVSvh0le61y4KDk.jpg'),
(129717, 9256, 'Meu Demonio Favorito S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xBnscv5BrJREKVSvh0le61y4KDk.jpg'),
(129718, 9256, 'Meu Demonio Favorito S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xBnscv5BrJREKVSvh0le61y4KDk.jpg'),
(129719, 9256, 'Meu Demonio Favorito S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sP2sHjYVTSxqRtq9yW3ckHFd7Ep.jpg'),
(129720, 9256, 'Meu Demonio Favorito S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/266862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6oKhGdYY0BsHlPHk474zO7KUZZS.jpg'),
(129721, 9256, 'Meu Demonio Favorito S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/266863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g5co7fqdkmc5TAzaFOcBfxavBag.jpg'),
(129722, 9257, 'Pequeno Principe e Seus Amigos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129723, 9257, 'Pequeno Principe e Seus Amigos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129724, 9257, 'Pequeno Principe e Seus Amigos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(129725, 9257, 'Pequeno Principe e Seus Amigos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129726, 9257, 'Pequeno Principe e Seus Amigos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129727, 9257, 'Pequeno Principe e Seus Amigos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129728, 9257, 'Pequeno Principe e Seus Amigos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129729, 9257, 'Pequeno Principe e Seus Amigos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129730, 9257, 'Pequeno Principe e Seus Amigos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129731, 9257, 'Pequeno Principe e Seus Amigos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129732, 9257, 'Pequeno Principe e Seus Amigos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/251201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129733, 9257, 'Pequeno Principe e Seus Amigos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/251202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129734, 9257, 'Pequeno Principe e Seus Amigos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/251203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129735, 9257, 'Pequeno Principe e Seus Amigos S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/251204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129736, 9257, 'Pequeno Principe e Seus Amigos S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/251205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129737, 9257, 'Pequeno Principe e Seus Amigos S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/251206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129738, 9257, 'Pequeno Principe e Seus Amigos S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/251207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129739, 9257, 'Pequeno Principe e Seus Amigos S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/251208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129740, 9257, 'Pequeno Principe e Seus Amigos S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/251209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129741, 9257, 'Pequeno Principe e Seus Amigos S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/251210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129742, 9257, 'Pequeno Principe e Seus Amigos S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/251211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129743, 9257, 'Pequeno Principe e Seus Amigos S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/251212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129744, 9257, 'Pequeno Principe e Seus Amigos S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/251213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129745, 9257, 'Pequeno Principe e Seus Amigos S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/251214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129746, 9257, 'Pequeno Principe e Seus Amigos S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/251215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129747, 9257, 'Pequeno Principe e Seus Amigos S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/251216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129748, 9257, 'Pequeno Principe e Seus Amigos S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/251217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129749, 9257, 'Pequeno Principe e Seus Amigos S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/251218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129750, 9257, 'Pequeno Principe e Seus Amigos S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/251219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129751, 9257, 'Pequeno Principe e Seus Amigos S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/251220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129752, 9257, 'Pequeno Principe e Seus Amigos S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/251221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129753, 9257, 'Pequeno Principe e Seus Amigos S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/251222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129754, 9257, 'Pequeno Principe e Seus Amigos S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/251223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129755, 9257, 'Pequeno Principe e Seus Amigos S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/251224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129756, 9257, 'Pequeno Principe e Seus Amigos S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/251225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129757, 9257, 'Pequeno Principe e Seus Amigos S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/251226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129758, 9257, 'Pequeno Principe e Seus Amigos S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/251227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129759, 9257, 'Pequeno Principe e Seus Amigos S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/251228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129760, 9257, 'Pequeno Principe e Seus Amigos S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/251229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gzEPtTooxBfaABRvHptJZuibisT.jpg'),
(129761, 9258, 'Sobrevivendo as Tentacoes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9I8Wulb2B4Oq9It4TPIU8ffqHPY.jpg'),
(129762, 9258, 'Sobrevivendo as Tentacoes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hfHJNa1VY7s1WLSb2Tv7U2l6NYe.jpg'),
(129763, 9258, 'Sobrevivendo as Tentacoes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/efCcTTyuSMeAdc8ckQqaOLV035e.jpg'),
(129764, 9258, 'Sobrevivendo as Tentacoes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mS3B9yiNjXvjb88Xxcr5Uh7gaa9.jpg'),
(129765, 9258, 'Sobrevivendo as Tentacoes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQwvnvdq4voCjc3YmoL4DegkxwH.jpg'),
(129766, 9258, 'Sobrevivendo as Tentacoes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZa0kAjz36SVNiUXspqPt35hkI5.jpg'),
(129767, 9259, 'Sobrevivendo as Tentacoes S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/855687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGy4p8fy3GRAX43qOgcfJ7AspVZ.jpg'),
(129768, 9259, 'Sobrevivendo as Tentacoes S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/855688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGy4p8fy3GRAX43qOgcfJ7AspVZ.jpg'),
(129769, 9259, 'Sobrevivendo as Tentacoes S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/855689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGy4p8fy3GRAX43qOgcfJ7AspVZ.jpg'),
(129770, 9259, 'Sobrevivendo as Tentacoes S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/855690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGy4p8fy3GRAX43qOgcfJ7AspVZ.jpg'),
(129771, 9259, 'Sobrevivendo as Tentacoes S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/855691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGy4p8fy3GRAX43qOgcfJ7AspVZ.jpg'),
(129772, 9259, 'Sobrevivendo as Tentacoes S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/855692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGy4p8fy3GRAX43qOgcfJ7AspVZ.jpg'),
(129773, 9259, 'Sobrevivendo as Tentacoes S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/855693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGy4p8fy3GRAX43qOgcfJ7AspVZ.jpg'),
(129774, 9259, 'Sobrevivendo as Tentacoes S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/855694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGy4p8fy3GRAX43qOgcfJ7AspVZ.jpg'),
(129775, 9260, 'O Baba S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/251175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129776, 9260, 'O Baba S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/251176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129777, 9260, 'O Baba S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/251177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129778, 9260, 'O Baba S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/251178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129779, 9260, 'O Baba S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/251179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129780, 9260, 'O Baba S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/251180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129781, 9260, 'O Baba S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/251181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129782, 9260, 'O Baba S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/251182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129783, 9260, 'O Baba S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/251183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129784, 9260, 'O Baba S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/251184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129785, 9261, 'O Baba S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/636954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129786, 9261, 'O Baba S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/636955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129787, 9261, 'O Baba S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/636956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129788, 9261, 'O Baba S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/636957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129789, 9261, 'O Baba S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/636958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129790, 9261, 'O Baba S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/636959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129791, 9261, 'O Baba S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/636960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129792, 9261, 'O Baba S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/636961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129793, 9262, 'O Baba S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/896474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129794, 9262, 'O Baba S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/896475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129795, 9262, 'O Baba S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/896476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129796, 9262, 'O Baba S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/896477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129797, 9262, 'O Baba S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/896478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129798, 9262, 'O Baba S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/896479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129799, 9262, 'O Baba S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/896480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129800, 9262, 'O Baba S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/896481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rS0UXajeYwsiIPupylTWnElzyx.jpg'),
(129801, 9263, 'O Rei Eterno S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hkK63gSfAtNcsAbKLxuy1aT4ZFs.jpg'),
(129802, 9263, 'O Rei Eterno S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qtHe5oNk3W3wU3dYvm1XR4bOHEL.jpg'),
(129803, 9263, 'O Rei Eterno S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tO91t0ZtMgFrzTjOe39RmPyLJaI.jpg'),
(129804, 9263, 'O Rei Eterno S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QLqfXmPVY7NtOLbRS5cO8Kp3XI.jpg'),
(129805, 9263, 'O Rei Eterno S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lEqk4B01xmd2gtV3AmRrKxyD46E.jpg'),
(129806, 9263, 'O Rei Eterno S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gaUYeAplzluPcyz8CzX0FAiKJSZ.jpg'),
(129807, 9263, 'O Rei Eterno S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nkcN9Yqu9h9GJWsJWH5hO4ScyNE.jpg'),
(129808, 9263, 'O Rei Eterno S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pZIymsaRYBydjm58Niou7XF2xsb.jpg'),
(129809, 9263, 'O Rei Eterno S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cXYTDjca16xuUUswpqjBoPKHnot.jpg'),
(129810, 9263, 'O Rei Eterno S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xCBc3Nm5pbHY3TKIQmieqY79nEY.jpg'),
(129811, 9263, 'O Rei Eterno S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lV56vXy6iWSgZP4BqEoDfQMBrXn.jpg'),
(129812, 9263, 'O Rei Eterno S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1cF1zC4CzKHAwVunvEIL6v7EguQ.jpg'),
(129813, 9263, 'O Rei Eterno S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d0ZmghSvPm8djx2lXNJLbMRkrK3.jpg'),
(129814, 9263, 'O Rei Eterno S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/257185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j5q5jFiqJlfnToQ6bgSH3uUeIkN.jpg'),
(129815, 9263, 'O Rei Eterno S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/257186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eptzpg5KEliXtSm91nr7akSwhIV.jpg'),
(129816, 9263, 'O Rei Eterno S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/257187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uphhf6Oy2OW1evTZSmjOQehUdtm.jpg'),
(129817, 9264, 'Carros Irados A Disputa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zxoxpr2rUaNIrnbnBEA8szD67tH.jpg'),
(129818, 9264, 'Carros Irados A Disputa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a0fx5yqfM4cZ1K33hiGVgK4oltK.jpg'),
(129819, 9264, 'Carros Irados A Disputa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4PUi4dHvSMQg4FDqXka2yb1i9e8.jpg'),
(129820, 9264, 'Carros Irados A Disputa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3pTnK3q41wnAJ1kGamIOFsInxhj.jpg'),
(129821, 9264, 'Carros Irados A Disputa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kTJ7atVeXb2RXugnWbDStUow1wp.jpg'),
(129822, 9264, 'Carros Irados A Disputa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4yc8uJg3xxQppdX45TZFLiCGmja.jpg'),
(129823, 9264, 'Carros Irados A Disputa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/PguJ5elttG1srTnyefCSHKm7ug.jpg'),
(129824, 9264, 'Carros Irados A Disputa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3nSNJ7H2KKFj2gzwo5lWh5MjHc1.jpg'),
(129825, 9265, 'Dr. Storks [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gRIianbdE8DJkIJXwLOeONlMjRO.jpg'),
(129826, 9265, 'Dr. Storks [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3CxubDSyIdqDVhYl0aG5gzBxkBP.jpg'),
(129827, 9265, 'Dr. Storks [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgZWuJwCnQHnvFRsnBV0hsoCAIu.jpg'),
(129828, 9265, 'Dr. Storks [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bAjEO9zSXuNH64CiQO2z5ZMJ3I2.jpg'),
(129829, 9265, 'Dr. Storks [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h7siUs5EfCqNzVjiluDDMmWoqZs.jpg'),
(129830, 9265, 'Dr. Storks [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11rH8GIzeCzYrLSPdsaKwYKOsjh.jpg'),
(129831, 9265, 'Dr. Storks [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cZRG6z4c2CFpdVNLxCheRJIZK2J.jpg'),
(129832, 9265, 'Dr. Storks [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6GuVU98hd2POXEzmibOsJQU94sN.jpg'),
(129833, 9265, 'Dr. Storks [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cOERSH24yNd0ZaAaWPJwvYekIKb.jpg'),
(129834, 9265, 'Dr. Storks [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AbiM36pLaBcQM31s9kEMiWXS7Tv.jpg'),
(129835, 9266, 'Dr. Storks [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHxhGYbSVtepKlRdAXxchXpjzJ3.jpg'),
(129836, 9266, 'Dr. Storks [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A8YXG8GA5D9bSlS1iy6di7jc8N7.jpg'),
(129837, 9266, 'Dr. Storks [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OHbMOCL88pSjtfTHKFkyIkmDer.jpg'),
(129838, 9266, 'Dr. Storks [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wUsGS35PdPfCYndxYyKWOg6xksr.jpg'),
(129839, 9266, 'Dr. Storks [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iTZDHtXWUwVvgOAUWvNOTK9YLk8.jpg'),
(129840, 9266, 'Dr. Storks [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sMeMaqYrpVJ2MTkq1fX7U06iCJD.jpg'),
(129841, 9266, 'Dr. Storks [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sxIL78Kikyn7Kpx35nmfzb8xc4j.jpg'),
(129842, 9266, 'Dr. Storks [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6qdLIJbSXR2psrSbGtAay0Eb5po.jpg'),
(129843, 9266, 'Dr. Storks [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzYYEgG6zqQOrkfNLyBsLbxKkw1.jpg'),
(129844, 9266, 'Dr. Storks [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/134qCnSFvlolQmZWEukjI0d7y4d.jpg'),
(129845, 9266, 'Dr. Storks [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tyXn4ye6hrAxeqI4qpx950lCZjH.jpg'),
(129846, 9267, 'Level E S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/74hiJ07FWmOiKNGbreecTTl8kTh.jpg'),
(129847, 9267, 'Level E S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mT3jIsrDDHu9MlV6M6M1QdmmHzv.jpg'),
(129848, 9267, 'Level E S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/590360.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nvmJtIVwompvyucHX934nPhEuCJ.jpg'),
(129849, 9267, 'Level E S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tdhOYnrkZhSr6wiLDWOKIozRhEI.jpg'),
(129850, 9267, 'Level E S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tdhOYnrkZhSr6wiLDWOKIozRhEI.jpg'),
(129851, 9267, 'Level E S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tdhOYnrkZhSr6wiLDWOKIozRhEI.jpg'),
(129852, 9267, 'Level E S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tdhOYnrkZhSr6wiLDWOKIozRhEI.jpg'),
(129853, 9267, 'Level E S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tdhOYnrkZhSr6wiLDWOKIozRhEI.jpg'),
(129854, 9267, 'Level E S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tdhOYnrkZhSr6wiLDWOKIozRhEI.jpg'),
(129855, 9267, 'Level E S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tdhOYnrkZhSr6wiLDWOKIozRhEI.jpg'),
(129856, 9267, 'Level E S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tdhOYnrkZhSr6wiLDWOKIozRhEI.jpg'),
(129857, 9267, 'Level E S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tdhOYnrkZhSr6wiLDWOKIozRhEI.jpg'),
(129858, 9267, 'Level E S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/590370.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u4Bbpi1bhJvftSxniTJSx6Q9NnP.jpg'),
(129859, 9268, 'O Clube das Divorciadas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129860, 9268, 'O Clube das Divorciadas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129861, 9268, 'O Clube das Divorciadas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129862, 9268, 'O Clube das Divorciadas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129863, 9268, 'O Clube das Divorciadas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129864, 9268, 'O Clube das Divorciadas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129865, 9268, 'O Clube das Divorciadas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129866, 9268, 'O Clube das Divorciadas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129867, 9268, 'O Clube das Divorciadas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129868, 9269, 'O Clube das Divorciadas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129869, 9269, 'O Clube das Divorciadas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129870, 9269, 'O Clube das Divorciadas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129871, 9269, 'O Clube das Divorciadas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129872, 9269, 'O Clube das Divorciadas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129873, 9269, 'O Clube das Divorciadas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129874, 9269, 'O Clube das Divorciadas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129875, 9269, 'O Clube das Divorciadas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129876, 9269, 'O Clube das Divorciadas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129877, 9269, 'O Clube das Divorciadas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129878, 9270, 'O Clube das Divorciadas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129879, 9270, 'O Clube das Divorciadas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129880, 9270, 'O Clube das Divorciadas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129881, 9270, 'O Clube das Divorciadas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129882, 9270, 'O Clube das Divorciadas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129883, 9270, 'O Clube das Divorciadas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129884, 9270, 'O Clube das Divorciadas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129885, 9270, 'O Clube das Divorciadas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129886, 9270, 'O Clube das Divorciadas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129887, 9270, 'O Clube das Divorciadas S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7ppKW2N7ZCr8k1P4iHldXUUmF7H.jpg'),
(129888, 9271, 'The Serial Killers Wife [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpL6lJNmoCz6gjvZ8o3FEqlNXM6.jpg'),
(129889, 9271, 'The Serial Killers Wife [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7C7yB9pp4qEZxDudczgUd4W80f.jpg'),
(129890, 9271, 'The Serial Killers Wife [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oa2g8DTbeEakv6zy6WeBzkDCUKB.jpg'),
(129891, 9271, 'The Serial Killers Wife [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n5ipEYMyAUZsXIF0HTPduTxJDuc.jpg'),
(129892, 9272, 'Voce e Linda [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wIdQW9JrGzBLmKjat9kBjKgSZEY.jpg'),
(129893, 9272, 'Voce e Linda [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a0dcd9elboOfRIEaLrVOvFsKZXb.jpg'),
(129894, 9272, 'Voce e Linda [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lX3cHjIsyL7Dg0198aWaZlvxzMK.jpg'),
(129895, 9272, 'Voce e Linda [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oLAvsvrbRJQ5OEDMwVXnGQ49dSb.jpg'),
(129896, 9272, 'Voce e Linda [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/va3nR73sjY5bJy1GC3ny3SqNpoo.jpg'),
(129897, 9272, 'Voce e Linda [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/75hMU69a5gCjv5YxdYQcH9Fapkx.jpg'),
(129898, 9272, 'Voce e Linda [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3tUXPZUbEJIqFKAxkxkytXQ1LJQ.jpg'),
(129899, 9272, 'Voce e Linda [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l2PTWIY6DUg7Uu2bHcidtdIwLs3.jpg'),
(129900, 9272, 'Voce e Linda [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hAmoVZpH82gIQF5trDd1Jjb0BD8.jpg'),
(129901, 9272, 'Voce e Linda [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2cczhBFTKYhy5C6zboWLtTvwalR.jpg'),
(129902, 9272, 'Voce e Linda [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1EL4KkB4NFcKEFpuidBLKTFoTrL.jpg'),
(129903, 9272, 'Voce e Linda [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xUToMoQmJZXuPhYf1OnUipOut3c.jpg'),
(129904, 9272, 'Voce e Linda [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nR5q9RGuFbBHUyg4wbUGVhrj2q7.jpg'),
(129905, 9272, 'Voce e Linda [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/257107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2BUGl7qmRNbVCWZ0w8BazoCPVB.jpg'),
(129906, 9272, 'Voce e Linda [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/257108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zAX6Q6SqPm8oEiXiNVxEoqWnfTP.jpg'),
(129907, 9272, 'Voce e Linda [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/257109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c81Ae3IWZxDb4mg4UQutvL1A30P.jpg'),
(129908, 9273, 'Cookies de Natal O Desafio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129909, 9273, 'Cookies de Natal O Desafio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129910, 9273, 'Cookies de Natal O Desafio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129911, 9273, 'Cookies de Natal O Desafio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129912, 9273, 'Cookies de Natal O Desafio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129913, 9273, 'Cookies de Natal O Desafio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129914, 9273, 'Cookies de Natal O Desafio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129915, 9274, 'Cookies de Natal O Desafio S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129916, 9274, 'Cookies de Natal O Desafio S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129917, 9274, 'Cookies de Natal O Desafio S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129918, 9274, 'Cookies de Natal O Desafio S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129919, 9274, 'Cookies de Natal O Desafio S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129920, 9274, 'Cookies de Natal O Desafio S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129921, 9274, 'Cookies de Natal O Desafio S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129922, 9275, 'Cookies de Natal O Desafio S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129923, 9275, 'Cookies de Natal O Desafio S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129924, 9275, 'Cookies de Natal O Desafio S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129925, 9275, 'Cookies de Natal O Desafio S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129926, 9275, 'Cookies de Natal O Desafio S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129927, 9275, 'Cookies de Natal O Desafio S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129928, 9275, 'Cookies de Natal O Desafio S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129929, 9275, 'Cookies de Natal O Desafio S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129930, 9276, 'Cookies de Natal O Desafio S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129931, 9276, 'Cookies de Natal O Desafio S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129932, 9276, 'Cookies de Natal O Desafio S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129933, 9276, 'Cookies de Natal O Desafio S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129934, 9276, 'Cookies de Natal O Desafio S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129935, 9276, 'Cookies de Natal O Desafio S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129936, 9277, 'Cookies de Natal O Desafio S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129937, 9277, 'Cookies de Natal O Desafio S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129938, 9277, 'Cookies de Natal O Desafio S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129939, 9277, 'Cookies de Natal O Desafio S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129940, 9277, 'Cookies de Natal O Desafio S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129941, 9277, 'Cookies de Natal O Desafio S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129942, 9277, 'Cookies de Natal O Desafio S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129943, 9277, 'Cookies de Natal O Desafio S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rA5kqPR4LkqdDtzxwf2DG7ZxSHw.jpg'),
(129944, 9278, 'Ate o Fim da Lua [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q2TFGXmg7BavZK8PNhwlqeKjvs8.jpg'),
(129945, 9278, 'Ate o Fim da Lua [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oyumqGEyxDjGc0QbyLeMOA4Nnno.jpg'),
(129946, 9278, 'Ate o Fim da Lua [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rD9ePkpIQ8n9Ke6m0GLEXp6F4dB.jpg'),
(129947, 9278, 'Ate o Fim da Lua [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSIGdIP4T3sQQtYfB419RCKCUzX.jpg'),
(129948, 9278, 'Ate o Fim da Lua [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8wIqOg2m40aBANMPZeMgybP6nLP.jpg'),
(129949, 9278, 'Ate o Fim da Lua [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1c2YgKuvwdvI87V5v079epaiZQM.jpg'),
(129950, 9278, 'Ate o Fim da Lua [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xbcIYnaf0DlkhfooLcpWKEt9HWX.jpg'),
(129951, 9278, 'Ate o Fim da Lua [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jedt8VZxRgEAvl2hlzfmp5k4qQD.jpg'),
(129952, 9278, 'Ate o Fim da Lua [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o1zpDkaCxeGqD68OzqN0AIcoHtm.jpg'),
(129953, 9278, 'Ate o Fim da Lua [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a9BuY9lM5WkiEsEJJh1qOuZkuOr.jpg'),
(129954, 9278, 'Ate o Fim da Lua [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9qgzWUXCC73MJVvhSDV6Ta9N1MS.jpg'),
(129955, 9278, 'Ate o Fim da Lua [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mFN63xcPCicDplDbgNjmYedJk8z.jpg'),
(129956, 9278, 'Ate o Fim da Lua [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t0eitf3ocqJgHfSJAfxImP00fdT.jpg'),
(129957, 9278, 'Ate o Fim da Lua [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fjJ2l6ZnHhInYppVp3VkvVR3MtD.jpg'),
(129958, 9278, 'Ate o Fim da Lua [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pi7GCKlhQZRpGSzgPF0MaxlrMZ9.jpg'),
(129959, 9278, 'Ate o Fim da Lua [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tUodHesQ5mVhjbXjHT9fRf12q62.jpg'),
(129960, 9278, 'Ate o Fim da Lua [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/256755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Tov9L18PUHrlYSbordc2T6zejU.jpg'),
(129961, 9278, 'Ate o Fim da Lua [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/256756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vyIodL8qr8mTt2V7Ux6enziX0xl.jpg'),
(129962, 9278, 'Ate o Fim da Lua [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/256757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2Pp5LMTzsGQagHlPL1gVrrhV6x.jpg'),
(129963, 9278, 'Ate o Fim da Lua [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/256758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e2CgXoDfCU474JehWBxBOQEVTNC.jpg'),
(129964, 9278, 'Ate o Fim da Lua [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/256759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h80WyCfoRRnntbNLQ34RUNtk3Bz.jpg'),
(129965, 9278, 'Ate o Fim da Lua [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/256760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kKKY6Nhq9yuA8d3RuW25ZywNxxc.jpg'),
(129966, 9278, 'Ate o Fim da Lua [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/256761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rdRHQC3fwbt4ykHrqh9fMIoeRu.jpg'),
(129967, 9278, 'Ate o Fim da Lua [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/256762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9bZGtWL8S3ltSxuoLQnStWRT7Wa.jpg'),
(129968, 9278, 'Ate o Fim da Lua [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/256763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pezn1d0nZixW41zO6QbAFwZ1W4y.jpg'),
(129969, 9278, 'Ate o Fim da Lua [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/256764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gGn3ap4WK9BM5Ni7mH6MlctyH4p.jpg'),
(129970, 9278, 'Ate o Fim da Lua [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/256765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yYm03fOatOHnQ4NUg341smQ4nbs.jpg'),
(129971, 9278, 'Ate o Fim da Lua [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/256766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dZtuiMuIcBfwQne0nN3Tggx7pW.jpg'),
(129972, 9278, 'Ate o Fim da Lua [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/256767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/usk1q9HoRgxu9Fx2IL9grmSyOqw.jpg'),
(129973, 9278, 'Ate o Fim da Lua [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/256768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/501xgfjjeYuPJaYg2HmCmqbNl6F.jpg'),
(129974, 9278, 'Ate o Fim da Lua [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/256769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kTzJ9j7hrye37S0apA4WAOf8OZc.jpg'),
(129975, 9278, 'Ate o Fim da Lua [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/256770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gISF3uA7u1VzBdsLusKGH4Efecz.jpg'),
(129976, 9278, 'Ate o Fim da Lua [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/256771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e7fnErylYRwm6PtYhn9jsUuCWFB.jpg'),
(129977, 9278, 'Ate o Fim da Lua [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/256772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ujsYWI8xwEuf2azldc0UsPRwlF1.jpg'),
(129978, 9278, 'Ate o Fim da Lua [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/256773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cO8as9VK1bGit9xyZXxLwdX5RxR.jpg'),
(129979, 9278, 'Ate o Fim da Lua [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/256774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iu63GM0llYD2Uqx3mDQ2pM8vWXC.jpg'),
(129980, 9278, 'Ate o Fim da Lua [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/256775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AaORmISmUgs7qN5F4uRSjcZpDj7.jpg'),
(129981, 9278, 'Ate o Fim da Lua [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/256776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wVIc3CIz1e0X27mHkQktWKvby1g.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(129982, 9278, 'Ate o Fim da Lua [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/256777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kHEmzyBLEEj4dfOIZRtUasY38sa.jpg'),
(129983, 9278, 'Ate o Fim da Lua [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/256778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ka67KwJlW66Skbh4FaTvwEKJCiH.jpg'),
(129984, 9279, '18 Outra Vez S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8PJT1489ovBo9QQiheOwC24e4pQ.jpg'),
(129985, 9279, '18 Outra Vez S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rdqGJaqtLKXEgvyo68EDAewwgGG.jpg'),
(129986, 9279, '18 Outra Vez S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mf4qKwfqd3eLOAEinH3RZ1Pa67.jpg'),
(129987, 9279, '18 Outra Vez S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9qK5DZfSvCC6feU6rEmo1tCLkGE.jpg'),
(129988, 9279, '18 Outra Vez S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cSATaG8VZpr7hLPit0z7H1oWKnb.jpg'),
(129989, 9279, '18 Outra Vez S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aTJylscqkuDjVbQiacSQHTGpBTw.jpg'),
(129990, 9279, '18 Outra Vez S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eQLfWBRhDRd8pK2eG7bZdwenNGZ.jpg'),
(129991, 9279, '18 Outra Vez S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fgkeCoiZJBNjH2SShdXM9vR7Wx0.jpg'),
(129992, 9279, '18 Outra Vez S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mfY5QdQ1LzhmS4GbBZz6OWrRAh5.jpg'),
(129993, 9279, '18 Outra Vez S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fkDLF0DoTcx3kqCsG7j0vezYyzm.jpg'),
(129994, 9279, '18 Outra Vez S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eyqLFeOGCWeikdIpDgmiZPm8XXw.jpg'),
(129995, 9279, '18 Outra Vez S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f5eusJtBwEvahf1xsTD2Z5w5ePg.jpg'),
(129996, 9279, '18 Outra Vez S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7yuus8fEFHXYcMWZz5f0csRKspe.jpg'),
(129997, 9279, '18 Outra Vez S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xCzLlB24SA2odOaJd8MuNKHSeOR.jpg'),
(129998, 9279, '18 Outra Vez S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/low6pFPNQFYzI7q4enOKIMvdR9w.jpg'),
(129999, 9279, '18 Outra Vez S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6pEHEmGuFItfgCdHkSdo2EHhH1b.jpg'),
(130000, 9280, '90 Dias Para Ficar Milionario S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fZD62AIkJyiqm6yAdXDk8jIC6aF.jpg'),
(130001, 9280, '90 Dias Para Ficar Milionario S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aNwlA9fB7L3u0PJe37O310whAAX.jpg'),
(130002, 9280, '90 Dias Para Ficar Milionario S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d9F2aNwUtflld9wIbucqosgyc9X.jpg'),
(130003, 9280, '90 Dias Para Ficar Milionario S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uW2AB3S1uocp133xwODho6J3EGV.jpg'),
(130004, 9280, '90 Dias Para Ficar Milionario S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7xxd8MgMyk3lkiGL2FZHPxPWKeL.jpg'),
(130005, 9280, '90 Dias Para Ficar Milionario S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rZSBAnxQjp2fVirEf6kCMRvJZn6.jpg'),
(130006, 9280, '90 Dias Para Ficar Milionario S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPPJ6sibzc7eG8FtlMuh65HQayD.jpg'),
(130007, 9280, '90 Dias Para Ficar Milionario S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mNQHHGtpM4AaTVQXnsUmRYptlo8.jpg'),
(130008, 9280, '90 Dias Para Ficar Milionario S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5A3XUbCr7hcCylesLVklErVpR8m.jpg'),
(130009, 9281, '90 Dias Para Ficar Milionario S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jbVT9wKTr9Wk8IwjvQEbNinsFCJ.jpg'),
(130010, 9281, '90 Dias Para Ficar Milionario S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xAHM6DNNSgYz1CdpJSWNjjEGTTg.jpg'),
(130011, 9281, '90 Dias Para Ficar Milionario S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gbQaJaDJzwYaadsBja4aSdzX2Ia.jpg'),
(130012, 9281, '90 Dias Para Ficar Milionario S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jUcrPt8OSeOkyhqYB0K7W8lsd7o.jpg'),
(130013, 9281, '90 Dias Para Ficar Milionario S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MXJyjZsPWDOMFebGDnBvwTxmXn.jpg'),
(130014, 9281, '90 Dias Para Ficar Milionario S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3JLb6HjEiREFHmdxlEulTMWWDIi.jpg'),
(130015, 9281, '90 Dias Para Ficar Milionario S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ozQGBBnrbeSzoOgfJgwDR1rn93i.jpg'),
(130016, 9281, '90 Dias Para Ficar Milionario S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/75ojumX6x4pjcgaksdm7RzkVnCP.jpg'),
(130017, 9281, '90 Dias Para Ficar Milionario S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yuqhHPXUdJLQGe8TYIpDAn3TguZ.jpg'),
(130018, 9281, '90 Dias Para Ficar Milionario S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/llHoywZSDTDOhS6zWGS5CzkqKAl.jpg'),
(130019, 9281, '90 Dias Para Ficar Milionario S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/psS6j4J2W6UcoxJWHHx7coDhPFm.jpg'),
(130020, 9281, '90 Dias Para Ficar Milionario S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s0zBLh0KlCXCLCxXVClunYIMl57.jpg'),
(130021, 9281, '90 Dias Para Ficar Milionario S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b7a2FpOZYu0d7Es3xZ8oWZa7DyG.jpg'),
(130022, 9281, '90 Dias Para Ficar Milionario S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eHWDl213TF3qyzWjzEu9ps6pG2q.jpg'),
(130023, 9282, 'A Concierge Pokemon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pGqtuH8NmfExttjOWNBuncsgiPB.jpg'),
(130024, 9282, 'A Concierge Pokemon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqS7jOhI6t0dcFWnvBaLstjR5Xl.jpg'),
(130025, 9282, 'A Concierge Pokemon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnwGWArNtM29H0wkTpSiSgn9miX.jpg'),
(130026, 9282, 'A Concierge Pokemon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uFjRUFHSSlgQwxZB7xAU2gzguyR.jpg'),
(130027, 9282, 'A Concierge Pokemon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/882880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySSivX1z5n7ALFF0082sbsCasK2.jpg'),
(130028, 9282, 'A Concierge Pokemon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/882881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySSivX1z5n7ALFF0082sbsCasK2.jpg'),
(130029, 9282, 'A Concierge Pokemon S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/882882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySSivX1z5n7ALFF0082sbsCasK2.jpg'),
(130030, 9282, 'A Concierge Pokemon S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/882883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ySSivX1z5n7ALFF0082sbsCasK2.jpg'),
(130031, 9283, 'Do Velho Ao Novo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130032, 9283, 'Do Velho Ao Novo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130033, 9283, 'Do Velho Ao Novo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130034, 9283, 'Do Velho Ao Novo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130035, 9283, 'Do Velho Ao Novo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130036, 9283, 'Do Velho Ao Novo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130037, 9283, 'Do Velho Ao Novo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130038, 9283, 'Do Velho Ao Novo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130039, 9283, 'Do Velho Ao Novo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130040, 9283, 'Do Velho Ao Novo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130041, 9283, 'Do Velho Ao Novo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130042, 9283, 'Do Velho Ao Novo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130043, 9283, 'Do Velho Ao Novo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130044, 9284, 'Do Velho Ao Novo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130045, 9284, 'Do Velho Ao Novo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130046, 9284, 'Do Velho Ao Novo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130047, 9284, 'Do Velho Ao Novo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130048, 9284, 'Do Velho Ao Novo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130049, 9284, 'Do Velho Ao Novo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130050, 9284, 'Do Velho Ao Novo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130051, 9284, 'Do Velho Ao Novo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130052, 9284, 'Do Velho Ao Novo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130053, 9284, 'Do Velho Ao Novo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130054, 9284, 'Do Velho Ao Novo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130055, 9284, 'Do Velho Ao Novo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130056, 9284, 'Do Velho Ao Novo S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130057, 9285, 'Do Velho Ao Novo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130058, 9285, 'Do Velho Ao Novo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130059, 9285, 'Do Velho Ao Novo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130060, 9285, 'Do Velho Ao Novo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130061, 9285, 'Do Velho Ao Novo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130062, 9285, 'Do Velho Ao Novo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130063, 9285, 'Do Velho Ao Novo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130064, 9285, 'Do Velho Ao Novo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130065, 9285, 'Do Velho Ao Novo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130066, 9285, 'Do Velho Ao Novo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130067, 9285, 'Do Velho Ao Novo S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130068, 9285, 'Do Velho Ao Novo S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130069, 9285, 'Do Velho Ao Novo S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130070, 9285, 'Do Velho Ao Novo S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130071, 9285, 'Do Velho Ao Novo S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130072, 9285, 'Do Velho Ao Novo S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130073, 9285, 'Do Velho Ao Novo S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/256494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130074, 9285, 'Do Velho Ao Novo S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/256495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130075, 9286, 'Do Velho Ao Novo S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130076, 9286, 'Do Velho Ao Novo S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130077, 9286, 'Do Velho Ao Novo S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130078, 9286, 'Do Velho Ao Novo S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130079, 9286, 'Do Velho Ao Novo S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130080, 9286, 'Do Velho Ao Novo S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130081, 9286, 'Do Velho Ao Novo S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130082, 9286, 'Do Velho Ao Novo S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130083, 9286, 'Do Velho Ao Novo S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130084, 9286, 'Do Velho Ao Novo S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130085, 9286, 'Do Velho Ao Novo S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5f38ePU7QuWs57H6IdqOszsTKDq.jpg'),
(130086, 9286, 'Do Velho Ao Novo S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130087, 9286, 'Do Velho Ao Novo S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130088, 9286, 'Do Velho Ao Novo S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130089, 9286, 'Do Velho Ao Novo S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130090, 9287, 'Do Velho Ao Novo S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130091, 9287, 'Do Velho Ao Novo S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130092, 9287, 'Do Velho Ao Novo S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130093, 9287, 'Do Velho Ao Novo S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130094, 9287, 'Do Velho Ao Novo S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130095, 9287, 'Do Velho Ao Novo S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130096, 9287, 'Do Velho Ao Novo S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130097, 9287, 'Do Velho Ao Novo S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130098, 9287, 'Do Velho Ao Novo S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130099, 9287, 'Do Velho Ao Novo S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130100, 9287, 'Do Velho Ao Novo S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130101, 9287, 'Do Velho Ao Novo S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130102, 9287, 'Do Velho Ao Novo S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130103, 9287, 'Do Velho Ao Novo S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130104, 9287, 'Do Velho Ao Novo S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1O9xcX15kY0U6LMplMQvWOscnHR.jpg'),
(130105, 9288, 'Eyeshield 21 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vB3JXiMVKdUXK82LbkeFoPnPdNm.jpg'),
(130106, 9288, 'Eyeshield 21 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpFG52QRU1T32huS5YW9FCfL4R1.jpg'),
(130107, 9288, 'Eyeshield 21 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iLgy1iwiSbGmjF7ESvOcKF0Fifr.jpg'),
(130108, 9288, 'Eyeshield 21 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u3lAsF58kkTpnSulsbAQD3vYCMj.jpg'),
(130109, 9288, 'Eyeshield 21 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/opxWpR50U5AgSJAjddSwv2zM809.jpg'),
(130110, 9288, 'Eyeshield 21 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m5CEsPJfuZ0SpnLcqGWuL5F9lFa.jpg'),
(130111, 9288, 'Eyeshield 21 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8mFBkGttLY9ssHDtbPnnvBb2h70.jpg'),
(130112, 9288, 'Eyeshield 21 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130113, 9288, 'Eyeshield 21 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130114, 9288, 'Eyeshield 21 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130115, 9288, 'Eyeshield 21 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130116, 9288, 'Eyeshield 21 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130117, 9288, 'Eyeshield 21 S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/264959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130118, 9288, 'Eyeshield 21 S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/264960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130119, 9288, 'Eyeshield 21 S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/264961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130120, 9288, 'Eyeshield 21 S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/264962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130121, 9288, 'Eyeshield 21 S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/264963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130122, 9288, 'Eyeshield 21 S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/264964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130123, 9288, 'Eyeshield 21 S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/264965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130124, 9288, 'Eyeshield 21 S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/264966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130125, 9288, 'Eyeshield 21 S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/264967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130126, 9288, 'Eyeshield 21 S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/264968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130127, 9288, 'Eyeshield 21 S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/264969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130128, 9288, 'Eyeshield 21 S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/271435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130129, 9288, 'Eyeshield 21 S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/271436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130130, 9288, 'Eyeshield 21 S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/271437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130131, 9288, 'Eyeshield 21 S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/271438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130132, 9288, 'Eyeshield 21 S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/272996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130133, 9288, 'Eyeshield 21 S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/272997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130134, 9288, 'Eyeshield 21 S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/276636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130135, 9288, 'Eyeshield 21 S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/281190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130136, 9288, 'Eyeshield 21 S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/281191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130137, 9288, 'Eyeshield 21 S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/281192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130138, 9288, 'Eyeshield 21 S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/287487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130139, 9288, 'Eyeshield 21 S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/287488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130140, 9288, 'Eyeshield 21 S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/287489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130141, 9288, 'Eyeshield 21 S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/296397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130142, 9288, 'Eyeshield 21 S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/296398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130143, 9288, 'Eyeshield 21 S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/298002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130144, 9288, 'Eyeshield 21 S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/300058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130145, 9288, 'Eyeshield 21 S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/300059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130146, 9288, 'Eyeshield 21 S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/302780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130147, 9288, 'Eyeshield 21 S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/305113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130148, 9288, 'Eyeshield 21 S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/305114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130149, 9288, 'Eyeshield 21 S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/310366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130150, 9288, 'Eyeshield 21 S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/310367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130151, 9288, 'Eyeshield 21 S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/310368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130152, 9288, 'Eyeshield 21 S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/312498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130153, 9288, 'Eyeshield 21 S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/318031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130154, 9288, 'Eyeshield 21 S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/319670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130155, 9288, 'Eyeshield 21 S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/320778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130156, 9288, 'Eyeshield 21 S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/325937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130157, 9288, 'Eyeshield 21 S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/325938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130158, 9288, 'Eyeshield 21 S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/325939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130159, 9288, 'Eyeshield 21 S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/328280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130160, 9288, 'Eyeshield 21 S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/330653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130161, 9288, 'Eyeshield 21 S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/330654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130162, 9288, 'Eyeshield 21 S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/333183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130163, 9288, 'Eyeshield 21 S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/333184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130164, 9288, 'Eyeshield 21 S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/338950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130165, 9288, 'Eyeshield 21 S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/341194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130166, 9288, 'Eyeshield 21 S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/345661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130167, 9288, 'Eyeshield 21 S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/345662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130168, 9288, 'Eyeshield 21 S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/349499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130169, 9288, 'Eyeshield 21 S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/349500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130170, 9288, 'Eyeshield 21 S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/349501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130171, 9288, 'Eyeshield 21 S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/349502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130172, 9288, 'Eyeshield 21 S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/349503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130173, 9288, 'Eyeshield 21 S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/349504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130174, 9288, 'Eyeshield 21 S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/349505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130175, 9288, 'Eyeshield 21 S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/349506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130176, 9288, 'Eyeshield 21 S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/349507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130177, 9288, 'Eyeshield 21 S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/406037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130178, 9288, 'Eyeshield 21 S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/406038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130179, 9288, 'Eyeshield 21 S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/406039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130180, 9288, 'Eyeshield 21 S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/406040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130181, 9288, 'Eyeshield 21 S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/406041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130182, 9288, 'Eyeshield 21 S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/406042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130183, 9288, 'Eyeshield 21 S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/406043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130184, 9288, 'Eyeshield 21 S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/406044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130185, 9288, 'Eyeshield 21 S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/406045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130186, 9288, 'Eyeshield 21 S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/406046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130187, 9288, 'Eyeshield 21 S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/406047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130188, 9288, 'Eyeshield 21 S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/406048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130189, 9288, 'Eyeshield 21 S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/406049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130190, 9288, 'Eyeshield 21 S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/406050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130191, 9288, 'Eyeshield 21 S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/406051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130192, 9288, 'Eyeshield 21 S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/406052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130193, 9288, 'Eyeshield 21 S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/406053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130194, 9288, 'Eyeshield 21 S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/406054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130195, 9288, 'Eyeshield 21 S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/406055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130196, 9288, 'Eyeshield 21 S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/406056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130197, 9288, 'Eyeshield 21 S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/406057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130198, 9288, 'Eyeshield 21 S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/406058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130199, 9288, 'Eyeshield 21 S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/406059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130200, 9288, 'Eyeshield 21 S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/406060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130201, 9288, 'Eyeshield 21 S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/406061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130202, 9288, 'Eyeshield 21 S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/406062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130203, 9288, 'Eyeshield 21 S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/406063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130204, 9288, 'Eyeshield 21 S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/406064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130205, 9288, 'Eyeshield 21 S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/406065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130206, 9288, 'Eyeshield 21 S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/406066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130207, 9288, 'Eyeshield 21 S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/406067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130208, 9288, 'Eyeshield 21 S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/406068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130209, 9288, 'Eyeshield 21 S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/406069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130210, 9288, 'Eyeshield 21 S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/406070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130211, 9288, 'Eyeshield 21 S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/406071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130212, 9288, 'Eyeshield 21 S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/406072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130213, 9288, 'Eyeshield 21 S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/406073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130214, 9288, 'Eyeshield 21 S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/406074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130215, 9288, 'Eyeshield 21 S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/406075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130216, 9288, 'Eyeshield 21 S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/406076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130217, 9288, 'Eyeshield 21 S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/406077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130218, 9288, 'Eyeshield 21 S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/406078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130219, 9288, 'Eyeshield 21 S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/406079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130220, 9288, 'Eyeshield 21 S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/406080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130221, 9288, 'Eyeshield 21 S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/406081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130222, 9288, 'Eyeshield 21 S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/406082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130223, 9288, 'Eyeshield 21 S01 E119', 'http://sinalprivado.info:80/series/1533784/1533784/406083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130224, 9288, 'Eyeshield 21 S01 E120', 'http://sinalprivado.info:80/series/1533784/1533784/406084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130225, 9288, 'Eyeshield 21 S01 E121', 'http://sinalprivado.info:80/series/1533784/1533784/406085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130226, 9288, 'Eyeshield 21 S01 E122', 'http://sinalprivado.info:80/series/1533784/1533784/406086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130227, 9288, 'Eyeshield 21 S01 E123', 'http://sinalprivado.info:80/series/1533784/1533784/406087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130228, 9288, 'Eyeshield 21 S01 E124', 'http://sinalprivado.info:80/series/1533784/1533784/406088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130229, 9288, 'Eyeshield 21 S01 E125', 'http://sinalprivado.info:80/series/1533784/1533784/406089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130230, 9288, 'Eyeshield 21 S01 E126', 'http://sinalprivado.info:80/series/1533784/1533784/406090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130231, 9288, 'Eyeshield 21 S01 E127', 'http://sinalprivado.info:80/series/1533784/1533784/406091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130232, 9288, 'Eyeshield 21 S01 E128', 'http://sinalprivado.info:80/series/1533784/1533784/406092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130233, 9288, 'Eyeshield 21 S01 E129', 'http://sinalprivado.info:80/series/1533784/1533784/406093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130234, 9288, 'Eyeshield 21 S01 E130', 'http://sinalprivado.info:80/series/1533784/1533784/406094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130235, 9288, 'Eyeshield 21 S01 E131', 'http://sinalprivado.info:80/series/1533784/1533784/406095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130236, 9288, 'Eyeshield 21 S01 E132', 'http://sinalprivado.info:80/series/1533784/1533784/406096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130237, 9288, 'Eyeshield 21 S01 E133', 'http://sinalprivado.info:80/series/1533784/1533784/406097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130238, 9288, 'Eyeshield 21 S01 E134', 'http://sinalprivado.info:80/series/1533784/1533784/406098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130239, 9288, 'Eyeshield 21 S01 E135', 'http://sinalprivado.info:80/series/1533784/1533784/406099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130240, 9288, 'Eyeshield 21 S01 E136', 'http://sinalprivado.info:80/series/1533784/1533784/406100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130241, 9288, 'Eyeshield 21 S01 E137', 'http://sinalprivado.info:80/series/1533784/1533784/406101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130242, 9288, 'Eyeshield 21 S01 E138', 'http://sinalprivado.info:80/series/1533784/1533784/406102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130243, 9288, 'Eyeshield 21 S01 E139', 'http://sinalprivado.info:80/series/1533784/1533784/406103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130244, 9288, 'Eyeshield 21 S01 E140', 'http://sinalprivado.info:80/series/1533784/1533784/406104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(130245, 9288, 'Eyeshield 21 S01 E141', 'http://sinalprivado.info:80/series/1533784/1533784/406105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130246, 9288, 'Eyeshield 21 S01 E142', 'http://sinalprivado.info:80/series/1533784/1533784/406106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130247, 9288, 'Eyeshield 21 S01 E143', 'http://sinalprivado.info:80/series/1533784/1533784/406107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130248, 9288, 'Eyeshield 21 S01 E144', 'http://sinalprivado.info:80/series/1533784/1533784/406108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130249, 9288, 'Eyeshield 21 S01 E145', 'http://sinalprivado.info:80/series/1533784/1533784/406109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxIruB21oWKJEZgv22sn10YqXXX.jpg'),
(130250, 9289, 'Operacao Fronteira Espanha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130251, 9289, 'Operacao Fronteira Espanha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130252, 9289, 'Operacao Fronteira Espanha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130253, 9289, 'Operacao Fronteira Espanha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130254, 9289, 'Operacao Fronteira Espanha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130255, 9289, 'Operacao Fronteira Espanha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130256, 9289, 'Operacao Fronteira Espanha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130257, 9289, 'Operacao Fronteira Espanha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130258, 9289, 'Operacao Fronteira Espanha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130259, 9289, 'Operacao Fronteira Espanha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130260, 9289, 'Operacao Fronteira Espanha S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130261, 9289, 'Operacao Fronteira Espanha S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130262, 9289, 'Operacao Fronteira Espanha S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130263, 9289, 'Operacao Fronteira Espanha S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130264, 9289, 'Operacao Fronteira Espanha S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130265, 9289, 'Operacao Fronteira Espanha S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130266, 9289, 'Operacao Fronteira Espanha S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/263374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130267, 9289, 'Operacao Fronteira Espanha S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/263375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130268, 9289, 'Operacao Fronteira Espanha S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/263376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130269, 9289, 'Operacao Fronteira Espanha S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/263377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130270, 9290, 'Operacao Fronteira Espanha S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130271, 9290, 'Operacao Fronteira Espanha S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130272, 9290, 'Operacao Fronteira Espanha S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130273, 9290, 'Operacao Fronteira Espanha S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130274, 9290, 'Operacao Fronteira Espanha S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130275, 9290, 'Operacao Fronteira Espanha S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130276, 9290, 'Operacao Fronteira Espanha S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130277, 9290, 'Operacao Fronteira Espanha S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130278, 9290, 'Operacao Fronteira Espanha S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130279, 9290, 'Operacao Fronteira Espanha S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130280, 9290, 'Operacao Fronteira Espanha S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130281, 9290, 'Operacao Fronteira Espanha S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130282, 9290, 'Operacao Fronteira Espanha S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130283, 9290, 'Operacao Fronteira Espanha S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130284, 9290, 'Operacao Fronteira Espanha S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130285, 9290, 'Operacao Fronteira Espanha S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130286, 9291, 'Operacao Fronteira Espanha S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130287, 9291, 'Operacao Fronteira Espanha S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130288, 9291, 'Operacao Fronteira Espanha S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130289, 9291, 'Operacao Fronteira Espanha S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130290, 9291, 'Operacao Fronteira Espanha S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130291, 9291, 'Operacao Fronteira Espanha S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130292, 9291, 'Operacao Fronteira Espanha S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130293, 9291, 'Operacao Fronteira Espanha S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130294, 9291, 'Operacao Fronteira Espanha S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130295, 9291, 'Operacao Fronteira Espanha S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130296, 9291, 'Operacao Fronteira Espanha S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130297, 9291, 'Operacao Fronteira Espanha S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130298, 9291, 'Operacao Fronteira Espanha S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130299, 9291, 'Operacao Fronteira Espanha S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130300, 9291, 'Operacao Fronteira Espanha S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130301, 9291, 'Operacao Fronteira Espanha S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130302, 9291, 'Operacao Fronteira Espanha S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/263410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130303, 9291, 'Operacao Fronteira Espanha S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/263411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130304, 9291, 'Operacao Fronteira Espanha S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/263412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130305, 9291, 'Operacao Fronteira Espanha S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/263413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130306, 9292, 'Operacao Fronteira Espanha S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130307, 9292, 'Operacao Fronteira Espanha S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130308, 9292, 'Operacao Fronteira Espanha S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130309, 9292, 'Operacao Fronteira Espanha S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130310, 9292, 'Operacao Fronteira Espanha S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130311, 9292, 'Operacao Fronteira Espanha S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130312, 9292, 'Operacao Fronteira Espanha S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130313, 9292, 'Operacao Fronteira Espanha S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130314, 9292, 'Operacao Fronteira Espanha S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130315, 9292, 'Operacao Fronteira Espanha S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130316, 9292, 'Operacao Fronteira Espanha S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130317, 9292, 'Operacao Fronteira Espanha S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130318, 9292, 'Operacao Fronteira Espanha S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130319, 9292, 'Operacao Fronteira Espanha S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130320, 9292, 'Operacao Fronteira Espanha S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130321, 9292, 'Operacao Fronteira Espanha S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130322, 9292, 'Operacao Fronteira Espanha S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/263430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130323, 9292, 'Operacao Fronteira Espanha S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/263431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130324, 9292, 'Operacao Fronteira Espanha S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/263432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130325, 9292, 'Operacao Fronteira Espanha S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/263433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130326, 9293, 'Operacao Fronteira Espanha S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/esjmtkIrI0MtR32DWpniOtCjZIm.jpg'),
(130327, 9293, 'Operacao Fronteira Espanha S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iGB3bZIVVyFS61Diy2OS0ztishF.jpg'),
(130328, 9293, 'Operacao Fronteira Espanha S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cra9I6xOrVnCr2MJAUX1RGNYvC0.jpg'),
(130329, 9293, 'Operacao Fronteira Espanha S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63PakT97Ni1DvMX5yFuW2QSl6Wm.jpg'),
(130330, 9293, 'Operacao Fronteira Espanha S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ilM1OzGD9m5XrBygFWEp4rfwut2.jpg'),
(130331, 9293, 'Operacao Fronteira Espanha S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zf3bOHeHte0oY8lQSo8xytfT8Br.jpg'),
(130332, 9293, 'Operacao Fronteira Espanha S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cdbobALYTmGNbNNeSEl6tjBdojd.jpg'),
(130333, 9293, 'Operacao Fronteira Espanha S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yezaZXf10OA8JjJQaK8L3tEYCiT.jpg'),
(130334, 9293, 'Operacao Fronteira Espanha S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130335, 9293, 'Operacao Fronteira Espanha S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130336, 9293, 'Operacao Fronteira Espanha S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130337, 9293, 'Operacao Fronteira Espanha S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130338, 9293, 'Operacao Fronteira Espanha S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130339, 9293, 'Operacao Fronteira Espanha S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130340, 9293, 'Operacao Fronteira Espanha S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130341, 9293, 'Operacao Fronteira Espanha S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130342, 9293, 'Operacao Fronteira Espanha S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/897413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130343, 9293, 'Operacao Fronteira Espanha S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/897414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130344, 9293, 'Operacao Fronteira Espanha S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/897415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130345, 9293, 'Operacao Fronteira Espanha S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/897416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130346, 9294, 'Operacao Fronteira Espanha S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/897417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130347, 9294, 'Operacao Fronteira Espanha S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/897418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130348, 9294, 'Operacao Fronteira Espanha S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/897419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130349, 9294, 'Operacao Fronteira Espanha S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/897420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130350, 9294, 'Operacao Fronteira Espanha S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/897421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130351, 9294, 'Operacao Fronteira Espanha S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/897422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130352, 9294, 'Operacao Fronteira Espanha S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/897423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130353, 9294, 'Operacao Fronteira Espanha S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/897424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130354, 9294, 'Operacao Fronteira Espanha S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/897425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130355, 9294, 'Operacao Fronteira Espanha S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/897426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130356, 9294, 'Operacao Fronteira Espanha S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/897427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130357, 9294, 'Operacao Fronteira Espanha S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/897428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130358, 9294, 'Operacao Fronteira Espanha S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/897429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130359, 9294, 'Operacao Fronteira Espanha S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/897430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130360, 9294, 'Operacao Fronteira Espanha S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/897431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130361, 9294, 'Operacao Fronteira Espanha S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/897432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130362, 9294, 'Operacao Fronteira Espanha S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/897433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130363, 9294, 'Operacao Fronteira Espanha S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/897434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130364, 9294, 'Operacao Fronteira Espanha S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/897435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130365, 9294, 'Operacao Fronteira Espanha S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/897436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vr7d8TH5zvefGgSOMfPlbCzlbf.jpg'),
(130366, 9295, 'Garota Conhece o Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJmSggFqKXD6BN3SoMQj2w0S4mA.jpg'),
(130367, 9295, 'Garota Conhece o Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2JY5YS5DK3MHF1lVzF7BhC28Cz.jpg'),
(130368, 9295, 'Garota Conhece o Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xaCQqrLIDUws22AeyXERw4RoVzU.jpg'),
(130369, 9295, 'Garota Conhece o Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r6bkBgSplmilfyakpDJ4JRCwbY8.jpg'),
(130370, 9295, 'Garota Conhece o Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWnewo9Q886VKO2VXgJMp3K1tJ7.jpg'),
(130371, 9295, 'Garota Conhece o Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/waxLuAHm6UIOO3NlKteD3uB1Zbm.jpg'),
(130372, 9295, 'Garota Conhece o Mundo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJrizavpcZpSPS9FciaN66RWSMB.jpg'),
(130373, 9295, 'Garota Conhece o Mundo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vHcjj6pCk1oBu2gTUaM3qYGVv3u.jpg'),
(130374, 9295, 'Garota Conhece o Mundo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pme7AFURkWaxiI8V54ogIGqdsR5.jpg'),
(130375, 9295, 'Garota Conhece o Mundo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSbGSj5FcT5Wav5f8KYG1tpBzl4.jpg'),
(130376, 9295, 'Garota Conhece o Mundo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCo4NIbtTR8uqL7REN7RXr4xTIz.jpg'),
(130377, 9295, 'Garota Conhece o Mundo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13tT0LxzJJdjinxal3eUglBdJmh.jpg'),
(130378, 9295, 'Garota Conhece o Mundo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tnAx81C4o3iWz38m6xy33Fi2VfM.jpg'),
(130379, 9295, 'Garota Conhece o Mundo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3OUYTaQk3ght9TTgDYYG7xmtY2I.jpg'),
(130380, 9295, 'Garota Conhece o Mundo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bu1GGwolO32JFeZMbDAKOPmcqkt.jpg'),
(130381, 9295, 'Garota Conhece o Mundo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVKbDksBYq6UVRNiEjpylfZXN4i.jpg'),
(130382, 9295, 'Garota Conhece o Mundo S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/256396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7F98vlKfyXGvj38JiNlvhTotEJ6.jpg'),
(130383, 9295, 'Garota Conhece o Mundo S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/256397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1tzrlv6lM07jdCEwzIlMJZCR40c.jpg'),
(130384, 9295, 'Garota Conhece o Mundo S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/256398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hzQnE5DKtzOHrYPaUuKxwnEcQSN.jpg'),
(130385, 9295, 'Garota Conhece o Mundo S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/256399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gIjhZEAILohK8v4WELmzsgW9mbd.jpg'),
(130386, 9295, 'Garota Conhece o Mundo S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/256400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5rqrwyYFCcE6cv9olrBXERv8etM.jpg'),
(130387, 9296, 'Garota Conhece o Mundo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hwX6wztEi6MJIHalIVF6hczc95S.jpg'),
(130388, 9296, 'Garota Conhece o Mundo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Tml0vbLfVlycjNwQNDPiOCrnfR.jpg'),
(130389, 9296, 'Garota Conhece o Mundo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ocETScDAXmNj4DYt25jeQPC4RNQ.jpg'),
(130390, 9296, 'Garota Conhece o Mundo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qod9pZDsilKApYDL8pHzdQym5bS.jpg'),
(130391, 9296, 'Garota Conhece o Mundo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svrxhbL7ajLzCCCk3u1Kk2U2QYz.jpg'),
(130392, 9296, 'Garota Conhece o Mundo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xSkjqdtkRoVCT8hdOn9Ewbvhst1.jpg'),
(130393, 9296, 'Garota Conhece o Mundo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jeZQWTkGXavGY5pOTJbyp7yHTkM.jpg'),
(130394, 9296, 'Garota Conhece o Mundo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n84pK3CCPXxFllMg4ZCtbtZwnBE.jpg'),
(130395, 9296, 'Garota Conhece o Mundo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mKj9KnG7Hceq8U3vexKAF7BJTH4.jpg'),
(130396, 9296, 'Garota Conhece o Mundo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ySGeF8U6ieSt5kgHOX14I5tLb1o.jpg'),
(130397, 9296, 'Garota Conhece o Mundo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ohrMG74HoIO9FlTfH2mZMcYHCeb.jpg'),
(130398, 9296, 'Garota Conhece o Mundo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kIJMLNgBfQ8B1APBP9MjOlbyOMH.jpg'),
(130399, 9296, 'Garota Conhece o Mundo S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/53OmYcSnMi416IGMOBhRVTBHAx8.jpg'),
(130400, 9296, 'Garota Conhece o Mundo S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7FfTHcNbMgSSqvmSyUCQevkUcUa.jpg'),
(130401, 9296, 'Garota Conhece o Mundo S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ezeSQwwhNwPMbO9aSbOpEbItRSm.jpg'),
(130402, 9296, 'Garota Conhece o Mundo S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ucrrh1BKYztKoceJ02BSbVEx4u4.jpg'),
(130403, 9296, 'Garota Conhece o Mundo S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/256417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qfgkzwag5dhdfncOJrqe0THFicQ.jpg'),
(130404, 9296, 'Garota Conhece o Mundo S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/256418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oCeS0a4EL5VvqfjuvkdoZV8z0cE.jpg'),
(130405, 9296, 'Garota Conhece o Mundo S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/256419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/me33qLmZFdjVtkNpk4LIg64FsRA.jpg'),
(130406, 9296, 'Garota Conhece o Mundo S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/256420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNZv40VDEgpKd8eWep777UwqVq7.jpg'),
(130407, 9296, 'Garota Conhece o Mundo S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/256421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/njWj3cMlzS7AYajK6WmNfQJfj5y.jpg'),
(130408, 9296, 'Garota Conhece o Mundo S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/256422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJyy0qEQoAp3t0YsvTB9uVj3Ryq.jpg'),
(130409, 9296, 'Garota Conhece o Mundo S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/256423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fEs2euyqoo5rAmuG2E6TQ9W3nKB.jpg'),
(130410, 9296, 'Garota Conhece o Mundo S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/256424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/il1JuHMVZvixqDL3H2SS8vhc9wX.jpg'),
(130411, 9296, 'Garota Conhece o Mundo S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/256425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gK9I3me0YANLG2FxtSW7wQ7Fap7.jpg'),
(130412, 9296, 'Garota Conhece o Mundo S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/256426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aX4JlHZzVuL8kjFF09qMd24tcIc.jpg'),
(130413, 9296, 'Garota Conhece o Mundo S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/256427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8m9pfDINs42VQLzclQgPXgBjVyW.jpg'),
(130414, 9296, 'Garota Conhece o Mundo S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/256428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a5hNmOt6ZYo3csJV9X46dE0S4ji.jpg'),
(130415, 9296, 'Garota Conhece o Mundo S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/256429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/auyaH5iNAkCLpjkcWCzgD9dv7i1.jpg'),
(130416, 9296, 'Garota Conhece o Mundo S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/256430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6W3zWker5sqVI0VPwUYs9OqZlqH.jpg'),
(130417, 9297, 'Garota Conhece o Mundo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qDpkpYvleE4pd0momu1z3986Eby.jpg'),
(130418, 9297, 'Garota Conhece o Mundo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gcuIXgCu5h4fcarjZ6J6ME068sM.jpg'),
(130419, 9297, 'Garota Conhece o Mundo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jpSZAbwY0LMbPFcCKf3OoY4ZUBH.jpg'),
(130420, 9297, 'Garota Conhece o Mundo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dym0SKeapMBEnSqOcpO1xzziaRJ.jpg'),
(130421, 9297, 'Garota Conhece o Mundo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wIiztYTfF2mB9o4K97ix5x7qq0B.jpg'),
(130422, 9297, 'Garota Conhece o Mundo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/llmZLeKb0HiicEL47zAMj2Tmvxt.jpg'),
(130423, 9297, 'Garota Conhece o Mundo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g2Il5Wb4yFVJlW2cHjWIby1X1pt.jpg'),
(130424, 9297, 'Garota Conhece o Mundo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTmRr3OLjSYVKbkfgEH2adFHile.jpg'),
(130425, 9297, 'Garota Conhece o Mundo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eG9KkQ18eFcLurs11vdzf3WTLSY.jpg'),
(130426, 9297, 'Garota Conhece o Mundo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AeCkG1d4PxropHcnz4ZVg7AjKBk.jpg'),
(130427, 9297, 'Garota Conhece o Mundo S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSqObFLbGgPsHhFwmMqEkMunQOE.jpg'),
(130428, 9297, 'Garota Conhece o Mundo S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nCXLZvRNJmoy8td95fMaIisZbwJ.jpg'),
(130429, 9297, 'Garota Conhece o Mundo S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9h9uaJbYBFjdtdvLR8Kz98lENyT.jpg'),
(130430, 9297, 'Garota Conhece o Mundo S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2kREUqTVHAqGy3tpQSeaqwSLTBj.jpg'),
(130431, 9297, 'Garota Conhece o Mundo S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lGYVmF3IrcjUZA0ug30V7MLyIWF.jpg'),
(130432, 9297, 'Garota Conhece o Mundo S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8LDsoB2eMvavwjQO0teYquDXTfB.jpg'),
(130433, 9297, 'Garota Conhece o Mundo S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/256447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sv2XDCUqVqtg7Z2EGPrIE91AAJr.jpg'),
(130434, 9297, 'Garota Conhece o Mundo S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/256448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qetLw6Wyc0zrLPqBJZjc0PE8sRW.jpg'),
(130435, 9297, 'Garota Conhece o Mundo S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/256449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9dwbxjPmXnipv8WxRscRnoz0eOp.jpg'),
(130436, 9297, 'Garota Conhece o Mundo S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/256450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/777NF7Yh49K7JrAlwYdQ1p0DOmi.jpg'),
(130437, 9297, 'Garota Conhece o Mundo S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/256451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eCGIq8FtTqHeJ0Hzvoxqum4bFZo.jpg'),
(130438, 9298, 'Homens da Montanha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wm67AbtPJbUzhGslwLtsYv0zfna.jpg'),
(130439, 9298, 'Homens da Montanha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wm67AbtPJbUzhGslwLtsYv0zfna.jpg'),
(130440, 9298, 'Homens da Montanha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wm67AbtPJbUzhGslwLtsYv0zfna.jpg'),
(130441, 9298, 'Homens da Montanha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wm67AbtPJbUzhGslwLtsYv0zfna.jpg'),
(130442, 9298, 'Homens da Montanha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wm67AbtPJbUzhGslwLtsYv0zfna.jpg'),
(130443, 9298, 'Homens da Montanha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wm67AbtPJbUzhGslwLtsYv0zfna.jpg'),
(130444, 9298, 'Homens da Montanha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wm67AbtPJbUzhGslwLtsYv0zfna.jpg'),
(130445, 9298, 'Homens da Montanha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wm67AbtPJbUzhGslwLtsYv0zfna.jpg'),
(130446, 9299, 'Confissoes do Assassino da Times Square S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ntYmz1x1AMDvhtbSEJJfFTeWBqQ.jpg'),
(130447, 9299, 'Confissoes do Assassino da Times Square S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rWmUOVAAaoPD9GwacgMj6sXvzpI.jpg'),
(130448, 9300, 'La Casa de Papel Berlim S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yjrdB9cf9Hyuvn9Aih7U1GkgSiE.jpg'),
(130449, 9300, 'La Casa de Papel Berlim S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yjrdB9cf9Hyuvn9Aih7U1GkgSiE.jpg'),
(130450, 9300, 'La Casa de Papel Berlim S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yjrdB9cf9Hyuvn9Aih7U1GkgSiE.jpg'),
(130451, 9300, 'La Casa de Papel Berlim S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yjrdB9cf9Hyuvn9Aih7U1GkgSiE.jpg'),
(130452, 9300, 'La Casa de Papel Berlim S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yjrdB9cf9Hyuvn9Aih7U1GkgSiE.jpg'),
(130453, 9300, 'La Casa de Papel Berlim S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yjrdB9cf9Hyuvn9Aih7U1GkgSiE.jpg'),
(130454, 9300, 'La Casa de Papel Berlim S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yjrdB9cf9Hyuvn9Aih7U1GkgSiE.jpg'),
(130455, 9300, 'La Casa de Papel Berlim S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yjrdB9cf9Hyuvn9Aih7U1GkgSiE.jpg'),
(130456, 9301, 'Sala de Emergencia Casos Bizarros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6vlVhij74ViIykfH6VWqOu9Kyy3.jpg'),
(130457, 9301, 'Sala de Emergencia Casos Bizarros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBlOpqOltysJJ3HeGSAL1xsXBj0.jpg'),
(130458, 9301, 'Sala de Emergencia Casos Bizarros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6J2iDV8KYDKrUn9PlpalyPW2E5N.jpg'),
(130459, 9302, 'O Rei do Bairro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hF7776l40BHnWVKzvVmalRKcGxn.jpg'),
(130460, 9302, 'O Rei do Bairro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yF5IUjwedzaoECgj4qUhIKpBjY6.jpg'),
(130461, 9302, 'O Rei do Bairro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSAardUlK7MWhkYpju4IjJuihEA.jpg'),
(130462, 9302, 'O Rei do Bairro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9115npf9coP1kPldkpO952fCAKQ.jpg'),
(130463, 9302, 'O Rei do Bairro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lpdYR0HacuykPCPCnbOcRvNFOdN.jpg'),
(130464, 9302, 'O Rei do Bairro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jmdH1AJE0kfEb0TFf7w5tUlxSmK.jpg'),
(130465, 9302, 'O Rei do Bairro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/30O60uqxawD8R2XWpxrs6A0hDXx.jpg'),
(130466, 9302, 'O Rei do Bairro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/srYCPUyEj4ffh7eaho9d7KsFJpJ.jpg'),
(130467, 9302, 'O Rei do Bairro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1MjFWk4TWgQtV59LvNA284uF8Ty.jpg'),
(130468, 9302, 'O Rei do Bairro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vHdZ1tXkhNnVqzQIp6jEozCusgw.jpg'),
(130469, 9302, 'O Rei do Bairro S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZqWKPxpFa5fFB6YhVlaHwH4Ljs.jpg'),
(130470, 9302, 'O Rei do Bairro S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kIhiGEVnXQxdLR1owZohxHBTbi.jpg'),
(130471, 9302, 'O Rei do Bairro S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bKhlA4ECZciZUfFxGN6u4wIY7Pu.jpg'),
(130472, 9302, 'O Rei do Bairro S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lLXVp1p5mjSDzqLxDHOP9y7eljS.jpg'),
(130473, 9302, 'O Rei do Bairro S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xaSAQ5Xdmh3LMI7rPP0hJ0jKkzW.jpg'),
(130474, 9302, 'O Rei do Bairro S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8GWgyFlWUlkNLpDzNMCDQ0fuonB.jpg'),
(130475, 9302, 'O Rei do Bairro S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/256144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yaowG8WZiRKPqii6rxM5QVRlFqy.jpg'),
(130476, 9302, 'O Rei do Bairro S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/256145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nBRJi7fuc2YZTdGRAhuQNemAUFU.jpg'),
(130477, 9302, 'O Rei do Bairro S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/256146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svZZpTPDpeSHNPiidN3sfPJLKHf.jpg'),
(130478, 9302, 'O Rei do Bairro S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/256147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ldqCtpMpRUqN7cppSVvkYN3RSez.jpg'),
(130479, 9302, 'O Rei do Bairro S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/256148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8cg0WX2FQl8tk6ZvgoFfQ9EOg5d.jpg'),
(130480, 9302, 'O Rei do Bairro S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/256149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZ8mSampLgM9jd2oMv1JUWIuDWM.jpg'),
(130481, 9302, 'O Rei do Bairro S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/256150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/89YbgfFjYpKV7jrah0NFyxJ0B12.jpg'),
(130482, 9302, 'O Rei do Bairro S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/256151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBqNcpSFJ0cMcH6v23maxRYvJsj.jpg'),
(130483, 9302, 'O Rei do Bairro S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/256152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fq0XFJK5gR2zAgAbON7JndiCXVq.jpg'),
(130484, 9303, 'O Rei do Bairro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vIpayr3msUgBEEHCYfv48PKoVY6.jpg'),
(130485, 9303, 'O Rei do Bairro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bbPwJJbyemKKsbYI39IyI3mCTj5.jpg'),
(130486, 9303, 'O Rei do Bairro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z9akYXYi7aS309YdM1xT5MUPw0o.jpg'),
(130487, 9303, 'O Rei do Bairro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/42eTArZJcjCHFnzJAG8myBiq5Vz.jpg'),
(130488, 9303, 'O Rei do Bairro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lmRg0OvJWvW4JwLG5NkuVAO9VtX.jpg'),
(130489, 9303, 'O Rei do Bairro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3d2XXkd6vQD2XpOV3j3hlCKBsZ8.jpg'),
(130490, 9303, 'O Rei do Bairro S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ZJbiu8jjLCyJcc2I3LKmLqvtHI.jpg'),
(130491, 9303, 'O Rei do Bairro S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qt2ch8XjvKr9GpXjK9tXQPFsXN2.jpg'),
(130492, 9303, 'O Rei do Bairro S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dMtrWa6TsYh5B9frqIyLWpYvV2C.jpg'),
(130493, 9303, 'O Rei do Bairro S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jRDa65ukmto95EQW5epnWTi0EIq.jpg'),
(130494, 9303, 'O Rei do Bairro S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y0De229L2CmCq1GNCxYNIHs3FgB.jpg'),
(130495, 9303, 'O Rei do Bairro S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5VW6p5E5P3Tz5vwAy5Z2MijH6QN.jpg'),
(130496, 9303, 'O Rei do Bairro S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZMFzL9Lc2kYTsD05yWcd6yuAfu.jpg'),
(130497, 9303, 'O Rei do Bairro S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ggB8cSYpO37wUWMUNP2uwUiay5y.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(130498, 9303, 'O Rei do Bairro S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z2YylEaqgb1sXbHlHPBzcUfuSJT.jpg'),
(130499, 9303, 'O Rei do Bairro S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDBeQYy94SkLiV9t0pxr4cJSYXm.jpg'),
(130500, 9303, 'O Rei do Bairro S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/256169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AfKog0rFbWiEPHiXlyBly8M2Gsl.jpg'),
(130501, 9303, 'O Rei do Bairro S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/256170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jKdGh5C8R5YDMdH5ixc9SEmlLkf.jpg'),
(130502, 9303, 'O Rei do Bairro S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/256171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zbgjcYJQOAb1mQFADtjRIAxrdJp.jpg'),
(130503, 9303, 'O Rei do Bairro S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/256172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rQupep7vjtdhCHEPeMlzXcIcqGQ.jpg'),
(130504, 9303, 'O Rei do Bairro S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/256173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sw0Ey9K5ZR1yh2788UMAtRoiIFC.jpg'),
(130505, 9303, 'O Rei do Bairro S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/256174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t0PZoxYuWHuDYULzC5meKX1k8mK.jpg'),
(130506, 9303, 'O Rei do Bairro S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/256175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eZr6VZ3bpnzjFaYjJUXt0ZDAMrm.jpg'),
(130507, 9303, 'O Rei do Bairro S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/256176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5J8zxAFvblVyFNb9K26ooQGRyMr.jpg'),
(130508, 9303, 'O Rei do Bairro S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/256177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kJgSwS6QHLWIHH1E8lQcYD3M0Js.jpg'),
(130509, 9304, 'O Rei do Bairro S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rdOUxPeGWpHggQuqUI6MPsJwGv4.jpg'),
(130510, 9304, 'O Rei do Bairro S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vfO3QqDm15Fqhk4eMqscuxUuiIM.jpg'),
(130511, 9304, 'O Rei do Bairro S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d8pBOvRt0bZoQJBCSTI279GiC6p.jpg'),
(130512, 9304, 'O Rei do Bairro S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AfgKK72A9SSnvja4Eb5sVn0VCkO.jpg'),
(130513, 9304, 'O Rei do Bairro S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7hKEORQUHl8d61UvqLc24slx0wG.jpg'),
(130514, 9304, 'O Rei do Bairro S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nIJdLU9KDw51cx3aiFHOxJpbar2.jpg'),
(130515, 9304, 'O Rei do Bairro S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uNq98h02KOtLykx0PgQQxLB0cLJ.jpg'),
(130516, 9304, 'O Rei do Bairro S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hpZPsa8EtzNBWrgr0LWmUmywKQq.jpg'),
(130517, 9304, 'O Rei do Bairro S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5wvVElSA9neXuoB9tcDFIUh9W6r.jpg'),
(130518, 9304, 'O Rei do Bairro S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jazxOV8kJAfXoF1sXnDGJFvkgAS.jpg'),
(130519, 9304, 'O Rei do Bairro S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r9ACstBCcIprxIAhgwCEWMdtedH.jpg'),
(130520, 9304, 'O Rei do Bairro S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xqoV8F956MFGzEcwYMvGWntLaxL.jpg'),
(130521, 9304, 'O Rei do Bairro S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHXXRYhKCDms74xSmBikswAqkMb.jpg'),
(130522, 9304, 'O Rei do Bairro S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7DOLXr94pQGtz1GBgSDD3OiSbDf.jpg'),
(130523, 9304, 'O Rei do Bairro S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qjdf0rVfQ5kwdhGzHhMcjhEgFeE.jpg'),
(130524, 9304, 'O Rei do Bairro S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f6thyJatUJvQI1mLeRg2Y2lzMgj.jpg'),
(130525, 9304, 'O Rei do Bairro S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/256194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aI4vCVsuwdHp26UJsjYRJvz60TM.jpg'),
(130526, 9304, 'O Rei do Bairro S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/256195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kbCvTYe1v1T245VQHfmwNtNTO4b.jpg'),
(130527, 9304, 'O Rei do Bairro S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/256196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9nQUhq8ghKqah0jOuVE9VBTnqg6.jpg'),
(130528, 9304, 'O Rei do Bairro S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/256197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QKr11l7AyRgy2ReVl0uFxpUcMR.jpg'),
(130529, 9304, 'O Rei do Bairro S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/256198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kA4CEH6DlIUrzJGS1zZ6BASNm7e.jpg'),
(130530, 9304, 'O Rei do Bairro S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/256199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ry5E5bvdnHbPnpqFdKUOwLWPm7I.jpg'),
(130531, 9304, 'O Rei do Bairro S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/256200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rcGio4jZ0XKshgiVCWjAh6Y8UTd.jpg'),
(130532, 9304, 'O Rei do Bairro S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/256201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g5MHUJIQOQTtpjM8BkHBTMKIpOW.jpg'),
(130533, 9304, 'O Rei do Bairro S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/256202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AnjHC20s8HlFLhMXTla4ivGeU80.jpg'),
(130534, 9305, 'O Rei do Bairro S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oUyWAcenqsRtRCez6Ma4pfTODpl.jpg'),
(130535, 9305, 'O Rei do Bairro S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3uTZaKWy6TD8V2modn2KzP5rxSf.jpg'),
(130536, 9305, 'O Rei do Bairro S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/poQPegkKfHRpf6jWxIBB1Sf1Tgm.jpg'),
(130537, 9305, 'O Rei do Bairro S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2L84TQJDPCd9gaMJrc46l6zjXEO.jpg'),
(130538, 9305, 'O Rei do Bairro S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fglj0eRIPiq4lWjLgWU762u4Uyw.jpg'),
(130539, 9305, 'O Rei do Bairro S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z0zF5rj2Myeu1R2QUXM89vhoFfw.jpg'),
(130540, 9305, 'O Rei do Bairro S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97muffCeZLNOReCmXGBLnQLo097.jpg'),
(130541, 9305, 'O Rei do Bairro S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/czf2EzCVX1HoaqGH1y4AtOm3odr.jpg'),
(130542, 9305, 'O Rei do Bairro S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ufXxitDlYmA828SQyLXb4cJkZWj.jpg'),
(130543, 9305, 'O Rei do Bairro S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ljrJVsL6YAJ3c41MuDdoSH6ASa.jpg'),
(130544, 9305, 'O Rei do Bairro S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qi69EHjTuNGnngnfz7vnUQgdODv.jpg'),
(130545, 9305, 'O Rei do Bairro S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/78vWdbIk5YcLAgkgZkKi8zHJgYt.jpg'),
(130546, 9305, 'O Rei do Bairro S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0bPw4ttIzPMqGtgtW3tnINVTpf.jpg'),
(130547, 9305, 'O Rei do Bairro S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/spUhpIc0opjTyQ1L2PMZADlsjsR.jpg'),
(130548, 9305, 'O Rei do Bairro S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jPdZYlIkN3zohUeTeoebL7Rx2xy.jpg'),
(130549, 9305, 'O Rei do Bairro S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z2UCWrG4KioxJjqSTP6Xx2Fv8nL.jpg'),
(130550, 9305, 'O Rei do Bairro S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/256219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Xr9kHaPJtVArCpur92XvU6fCY7.jpg'),
(130551, 9305, 'O Rei do Bairro S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/256220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bnxtyTzy6y6lrxEnmyOrKeD57cQ.jpg'),
(130552, 9305, 'O Rei do Bairro S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/256221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zefcZirEDeit564URvwObUhH7X8.jpg'),
(130553, 9305, 'O Rei do Bairro S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/256222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tPdl1WrVzUChSQB0XgaLXVjzaNl.jpg'),
(130554, 9305, 'O Rei do Bairro S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/256223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oFR9DzbLPGDOeNI8qB61Wda0K6m.jpg'),
(130555, 9305, 'O Rei do Bairro S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/256224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f7T8lCLrWYPDfndDfi7U89K3HlH.jpg'),
(130556, 9305, 'O Rei do Bairro S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/256225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZxz90gu7wx4t9vtQMPanMefmD9.jpg'),
(130557, 9305, 'O Rei do Bairro S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/256226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uQ17R1lVPfSMZrxPqVTOdqL8xII.jpg'),
(130558, 9305, 'O Rei do Bairro S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/256227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nbk6dg4EbWzKLadxb69YWU0feur.jpg'),
(130559, 9306, 'O Rei do Bairro S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xGAnPa0lKDxI0KAyxSRBppJywNH.jpg'),
(130560, 9306, 'O Rei do Bairro S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oC1xAoXYtqjadhzJA4szAs5ePh5.jpg'),
(130561, 9306, 'O Rei do Bairro S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLeByWzh700ajvXr539dnP5gM43.jpg'),
(130562, 9306, 'O Rei do Bairro S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hTsjdc9TBlNktPb71aUZjXyolD.jpg'),
(130563, 9306, 'O Rei do Bairro S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ds7GjQcoaZxl8QFO84rkRNdwNhQ.jpg'),
(130564, 9306, 'O Rei do Bairro S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bf3PCqGGXssHhTfzHYBqZsquPhN.jpg'),
(130565, 9306, 'O Rei do Bairro S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/miw72K1ko7e0f8hOZjixyXbDtiX.jpg'),
(130566, 9306, 'O Rei do Bairro S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oxWcVofqLUCodShgalkDPeCd0Ig.jpg'),
(130567, 9306, 'O Rei do Bairro S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AduNgzG9irc6T7iC9Ln8akiLAIe.jpg'),
(130568, 9306, 'O Rei do Bairro S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1b03ZkZAZ0TvFsT5477gKhJk0e.jpg'),
(130569, 9306, 'O Rei do Bairro S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oWYMKSxEgQVHZnlE5pHMN0sgwvo.jpg'),
(130570, 9306, 'O Rei do Bairro S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZbqk34Rj0SoBhJ4cHpfZ6GuSTJ.jpg'),
(130571, 9306, 'O Rei do Bairro S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kOk7j3siSJmVPHDbKiymMBH6WC.jpg'),
(130572, 9306, 'O Rei do Bairro S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8eDFHron3LZU4XfDZTrzhIvDigb.jpg'),
(130573, 9306, 'O Rei do Bairro S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pcPgL54ZW1P9NnMyOy3exH4kxl9.jpg'),
(130574, 9306, 'O Rei do Bairro S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bz62NRxIF2X95xDoGCJPVoi9sW5.jpg'),
(130575, 9306, 'O Rei do Bairro S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/256244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tW7FJffjPF9h2ozP4BHQJXg1L5H.jpg'),
(130576, 9306, 'O Rei do Bairro S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/256245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/siFLwP8u0uQrhzn5iTYa1OCDyIo.jpg'),
(130577, 9306, 'O Rei do Bairro S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/256246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/orYj2Rti1ODTPs2Yh6blbNix8Qo.jpg'),
(130578, 9306, 'O Rei do Bairro S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/256247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ubGuUkyKDEIFIHY1oqOKsB5Ax89.jpg'),
(130579, 9306, 'O Rei do Bairro S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/256248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r5P4VYBeC0O60VEIodllLExMd9h.jpg'),
(130580, 9306, 'O Rei do Bairro S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/256249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vdQ9cflGHKq6ok2eJTDGQ66DoWf.jpg'),
(130581, 9306, 'O Rei do Bairro S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/256250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l2ahuIrrTLzdoLtG1udTaOiOjCN.jpg'),
(130582, 9306, 'O Rei do Bairro S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/256251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xjGhCY7OKcwGcVGGJrwi8kijc2s.jpg'),
(130583, 9306, 'O Rei do Bairro S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/256252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0Aq8Dab3RIBpkAmFMiRyLuejAo.jpg'),
(130584, 9307, 'O Rei do Bairro S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jHhYDD17U5OOKHoAJgwIIuSrGvL.jpg'),
(130585, 9307, 'O Rei do Bairro S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/abU7t5rFFqc7pHmNd5wejO9mLEe.jpg'),
(130586, 9307, 'O Rei do Bairro S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tUQF0h2UCNnVuBNZLKeYruh7kvZ.jpg'),
(130587, 9307, 'O Rei do Bairro S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pGK6X1tZaw5z68LFYVa6yHDbGUR.jpg'),
(130588, 9307, 'O Rei do Bairro S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1oDFCs8mmDD8TxGHRFucLZHQJVn.jpg'),
(130589, 9307, 'O Rei do Bairro S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/59pr8IQuvOxkqFJr3qkMid5q91P.jpg'),
(130590, 9307, 'O Rei do Bairro S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0UPnteUVrVfdtYZXiQgov6TJMb.jpg'),
(130591, 9307, 'O Rei do Bairro S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hHCIohG5CIi3uTLaIpFDNzP0WS4.jpg'),
(130592, 9307, 'O Rei do Bairro S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oTIXXsvwy2k9q5VCZRnSpdX9Vsr.jpg'),
(130593, 9307, 'O Rei do Bairro S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2SdXbCRXnzATP5lWKxLCugVqQ6.jpg'),
(130594, 9307, 'O Rei do Bairro S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r74cVQpXnqh5XFtb3AF9nt4hNTW.jpg'),
(130595, 9307, 'O Rei do Bairro S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k113L5Tfs0qDrHvKnbe4yYUyTNf.jpg'),
(130596, 9307, 'O Rei do Bairro S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pPDnX6GC077XvZsO8ws7ieuaKSS.jpg'),
(130597, 9307, 'O Rei do Bairro S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tqZ0qRFiSWoK328yNT34cvUTsCm.jpg'),
(130598, 9307, 'O Rei do Bairro S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iQ79PZNhaHWe7VMPDZwxUZjrm4C.jpg'),
(130599, 9307, 'O Rei do Bairro S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zm7hZul33V5AzGzn4q8xN7y2y3x.jpg'),
(130600, 9307, 'O Rei do Bairro S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/256269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7pZD14wE9DLWU6iDCPIe1GDLBNU.jpg'),
(130601, 9307, 'O Rei do Bairro S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/256270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bmz79mkhU5o5kxIMfIaSn0jzEw0.jpg'),
(130602, 9307, 'O Rei do Bairro S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/256271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/635Vks7txw9Nw6sSLHIgiVaWjvC.jpg'),
(130603, 9307, 'O Rei do Bairro S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/256272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o5X8xv3Ka9KhALHQ8QUpiQ9Kofk.jpg'),
(130604, 9307, 'O Rei do Bairro S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/256273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ojyQbp0O6kGwHksnoW16yX7IUKZ.jpg'),
(130605, 9307, 'O Rei do Bairro S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/256274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wu9SUOBPl6CfASvnlMZXDgZicQW.jpg'),
(130606, 9307, 'O Rei do Bairro S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/256275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qLwXcUOvneJ2UwMgiSlJ4843NOS.jpg'),
(130607, 9307, 'O Rei do Bairro S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/256276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sj9uKMhES3wKN0YO7SJLMMAEjMY.jpg'),
(130608, 9308, 'O Rei do Bairro S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xBPxF4TkNlnmLBbG1U1dKkNzaTg.jpg'),
(130609, 9308, 'O Rei do Bairro S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vBPPf2DvS2ikoEcjBYn5dTZqHOT.jpg'),
(130610, 9308, 'O Rei do Bairro S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m6DnaNo52x4DOzXNeuKTSZz0m0x.jpg'),
(130611, 9308, 'O Rei do Bairro S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t6fhxOVip5lCm4edGS4DA1Z8uAO.jpg'),
(130612, 9308, 'O Rei do Bairro S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5tQq5lNQc5qbWWmLHDbxplYtQ94.jpg'),
(130613, 9308, 'O Rei do Bairro S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xVwHR6lhK3pmzQkRklsWE44FTs.jpg'),
(130614, 9308, 'O Rei do Bairro S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6mgC6hPGBekS3XmGKft3LTrTEda.jpg'),
(130615, 9308, 'O Rei do Bairro S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lG7HNogkl7mWa1wTZMihfSg8636.jpg'),
(130616, 9308, 'O Rei do Bairro S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d5DnwiHhhVnt1kiZLY5Rupx9YWh.jpg'),
(130617, 9308, 'O Rei do Bairro S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zuMIHSXHtQGKcCYd0XyfCxvTP6N.jpg'),
(130618, 9308, 'O Rei do Bairro S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ebLDc2Udt1HBaQ48A6IlPw9rffT.jpg'),
(130619, 9308, 'O Rei do Bairro S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/80YB0FjbyXdIlTgxO71zoWu7NiR.jpg'),
(130620, 9308, 'O Rei do Bairro S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fzwiOzrwgLTKgESbCpUdDPyaAlw.jpg'),
(130621, 9308, 'O Rei do Bairro S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tQKZwA1UHVjpHLEznWo8p2klynH.jpg'),
(130622, 9308, 'O Rei do Bairro S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zVmMwAcrxWUUHkJUg0JVKCPNQQa.jpg'),
(130623, 9308, 'O Rei do Bairro S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jCdMwxvoy9ixf1FTny4trpX9Oz2.jpg'),
(130624, 9308, 'O Rei do Bairro S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/256293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6wHPAHcXTS7yxIqsGvWIzCxwDMM.jpg'),
(130625, 9308, 'O Rei do Bairro S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/256294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gEuQtKpCMTrIgGB6GXEKzxaF3vT.jpg'),
(130626, 9308, 'O Rei do Bairro S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/256295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aOd5Ltl0svrjKFSqoFCvWZ0gInM.jpg'),
(130627, 9308, 'O Rei do Bairro S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/256296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xzuvpQ8B3qPukIZAKkYfnMM1cOJ.jpg'),
(130628, 9308, 'O Rei do Bairro S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/256297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eRfJU0At9IkSlzPPE60R32Auloq.jpg'),
(130629, 9308, 'O Rei do Bairro S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/256298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AhdaluNXJ9kLpVSP2rKeWKYrtb5.jpg'),
(130630, 9309, 'O Rei do Bairro S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cCxQbP8Y4mIWTJK96EAJDu4aUeV.jpg'),
(130631, 9309, 'O Rei do Bairro S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/76uOCj06hKTgct9UYh5q16680dF.jpg'),
(130632, 9309, 'O Rei do Bairro S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jhg9y7KPYD8T2aQphr924lxg9o5.jpg'),
(130633, 9309, 'O Rei do Bairro S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7zRSOWc2LWKT71kWDQnQRcOpIYJ.jpg'),
(130634, 9309, 'O Rei do Bairro S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hWwwO8oBksChrxEjC0vB7Kg1y86.jpg'),
(130635, 9309, 'O Rei do Bairro S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6eXFxZ0TrgZuyWgMPHGMZxs52NY.jpg'),
(130636, 9309, 'O Rei do Bairro S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gFNgv8zWhwjyQC8gcT1w2y2NsvJ.jpg'),
(130637, 9309, 'O Rei do Bairro S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vVwJebloFMq5BycuBmNelh8v5Gg.jpg'),
(130638, 9309, 'O Rei do Bairro S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2uDF6kASig5MrpIxiwLAoCbghfc.jpg'),
(130639, 9309, 'O Rei do Bairro S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sMJbX2ZQkIIvN8NBH0FumAuorFO.jpg'),
(130640, 9309, 'O Rei do Bairro S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8XpIKIChQogScWEiLBwiGQWvALd.jpg'),
(130641, 9309, 'O Rei do Bairro S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eeaRglJ48DeLb12TgCj1os0XDpq.jpg'),
(130642, 9309, 'O Rei do Bairro S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9GBs0ouhPhcm3F7O2hNZWvxXKea.jpg'),
(130643, 9309, 'O Rei do Bairro S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qmxQtBa6MzhPWzWQdbyqIEdrr6e.jpg'),
(130644, 9309, 'O Rei do Bairro S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7OPHHa2M03UP00vjeiSCsLmcqYR.jpg'),
(130645, 9309, 'O Rei do Bairro S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3PzwzCrP7aYL9UY4TYeUQf9Po6e.jpg'),
(130646, 9309, 'O Rei do Bairro S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/256315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kJaxoWdpAZn3wrmfAKWHORJciCR.jpg'),
(130647, 9309, 'O Rei do Bairro S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/256316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wjBENtNQHVHEBNZEmDMPqQdUFvF.jpg'),
(130648, 9309, 'O Rei do Bairro S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/256317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cTjqouGPzIxyTWhA4wID7BqMsmw.jpg'),
(130649, 9309, 'O Rei do Bairro S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/256318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6356eTMgSJTL3LiGsHDfGlRQ5f.jpg'),
(130650, 9309, 'O Rei do Bairro S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/256319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9vD1WfQ31Oi5Y6ht4e1cS3XAePj.jpg'),
(130651, 9309, 'O Rei do Bairro S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/256320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lujr2zsdLixl9jtG0l4FFSzAWcx.jpg'),
(130652, 9309, 'O Rei do Bairro S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/256321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qswICjw1PuKVEdEahmY5YVR44iM.jpg'),
(130653, 9310, 'O Rei do Bairro S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3NXmvB6GoiQ9cnyOXBmWwpoMWt8.jpg'),
(130654, 9310, 'O Rei do Bairro S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jr9w5Bn0jL5QHNizG7ciPmuVHRY.jpg'),
(130655, 9310, 'O Rei do Bairro S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qR1L9yIWHYAQFGBMPTbSeeIG3u.jpg'),
(130656, 9310, 'O Rei do Bairro S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i8svqp7Pbwab1gt8pnezsNriKcv.jpg'),
(130657, 9310, 'O Rei do Bairro S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cH8p1HcJQAfU3WlGwySk9nAX4EO.jpg'),
(130658, 9310, 'O Rei do Bairro S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ckpRxnlvyGV2Nv0b59R1MEnKVhy.jpg'),
(130659, 9310, 'O Rei do Bairro S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ueyGSK5EpzrWqz73IYKcQfT391u.jpg'),
(130660, 9310, 'O Rei do Bairro S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/muhKXid0nGyIEfa3E7nSeNTrY0B.jpg'),
(130661, 9310, 'O Rei do Bairro S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gpuTGYsP0r0aCpRlnYA6iI9MXl8.jpg'),
(130662, 9310, 'O Rei do Bairro S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfTqRdjNEzNCjb7sIxJfkSOZonG.jpg'),
(130663, 9310, 'O Rei do Bairro S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yBLbRr7H2giP7t1DlT7Z3enruDS.jpg'),
(130664, 9310, 'O Rei do Bairro S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5mQuDjf94JZ4eA4IV78TNNew3HB.jpg'),
(130665, 9310, 'O Rei do Bairro S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/haqoX8KOaqIR4Uh0aopYv41TBVf.jpg'),
(130666, 9311, 'Flashpoint [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hyNL6RY8xsHe5RnnR4XVyXNvtST.jpg'),
(130667, 9311, 'Flashpoint [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pnUPnuOYcgSZZxpsJVqsxaoFVft.jpg'),
(130668, 9311, 'Flashpoint [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qXdCcMh7Rg0nqFlK2nMtuVbBTa.jpg'),
(130669, 9311, 'Flashpoint [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mSDgI9k7f4HIvOLGW8kHikg2XNb.jpg'),
(130670, 9311, 'Flashpoint [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7UMgSwAqdizPGlVSNZ7X6iXL7r2.jpg'),
(130671, 9311, 'Flashpoint [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5cKqtLqfrsi9cTZ0Pulr7rzvBqw.jpg'),
(130672, 9311, 'Flashpoint [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Tafcslw32akemmIagddng4I5uF.jpg'),
(130673, 9311, 'Flashpoint [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ejPAnYnzJHaQ0gZ5hJoejHTqGF0.jpg'),
(130674, 9311, 'Flashpoint [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1GfN5jjRAPKiJ24lr6mb09bmf2.jpg'),
(130675, 9312, 'Flashpoint [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lnMWDpgDsONPL1SolZ404jyyWXg.jpg'),
(130676, 9312, 'Flashpoint [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aU5CNzQZzH1gTRtMv75Fq4EDg2G.jpg'),
(130677, 9312, 'Flashpoint [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zMkiXjJ9zGHhpjkIeAAuNasvIFi.jpg'),
(130678, 9312, 'Flashpoint [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uf5PjkQQ0j79ugNtWOC9fA1DHb5.jpg'),
(130679, 9312, 'Flashpoint [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qciIxSvljzP33GvSvbD8dF3PbyR.jpg'),
(130680, 9312, 'Flashpoint [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfZ16kKmuravAzVxdyjG45k1LwC.jpg'),
(130681, 9312, 'Flashpoint [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ySVpxuxlTr63f4uG31244udwvFb.jpg'),
(130682, 9312, 'Flashpoint [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCXFEYwz8Lglvi20CtWOC7ODSlV.jpg'),
(130683, 9312, 'Flashpoint [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vcX2slv44tWjClTeR0rwX9Llv0p.jpg'),
(130684, 9312, 'Flashpoint [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uRa3g09YLwHRP3LJT9Rmyu8iCS4.jpg'),
(130685, 9312, 'Flashpoint [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7PImjwkcpfkqbmLKrnEG5lmYRvW.jpg'),
(130686, 9312, 'Flashpoint [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r4cSUvDp3JekTHEobTUovsO260w.jpg'),
(130687, 9312, 'Flashpoint [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/njuEiLf4e5q19WnJh0ss4PXf6xg.jpg'),
(130688, 9313, 'Flashpoint [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ii2Ywo78yzOScFKalANd2cbS4bH.jpg'),
(130689, 9313, 'Flashpoint [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yeGN29pbEi3McJRjkr6QUF2lMKV.jpg'),
(130690, 9313, 'Flashpoint [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ml20nZhYWDR7dKfo5XXm00FHUJl.jpg'),
(130691, 9313, 'Flashpoint [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ogXT2QOLuyGqOi0zW4g7jBdXD6D.jpg'),
(130692, 9313, 'Flashpoint [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oRXs3XfBF6ckV15CiKqIqkbtffp.jpg'),
(130693, 9313, 'Flashpoint [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5KRRqWQIBdsajDVf9qFYb0Br9cP.jpg'),
(130694, 9313, 'Flashpoint [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJW75RTTmLK8Wdc4D4E1Pz4XWIE.jpg'),
(130695, 9313, 'Flashpoint [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1xvjEJtbv7HmPr1Az4R5UBry0D5.jpg'),
(130696, 9313, 'Flashpoint [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bJPfVK6VIrTuemb0OVceJ3ExVx1.jpg'),
(130697, 9313, 'Flashpoint [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6HHQLaM9erU9ImKavEWxBpmUJXr.jpg'),
(130698, 9313, 'Flashpoint [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/einxnB0nTGQgtOtEm2tIIKvPIjA.jpg'),
(130699, 9313, 'Flashpoint [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/msvLF8BxCb4Zri9WNnD5k6WXvEy.jpg'),
(130700, 9313, 'Flashpoint [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/giuNJGbLea9lrN9VRZ7pJrStGJJ.jpg'),
(130701, 9313, 'Flashpoint [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Bp3vJrPxnrN8iRDaclsVUPwgWa.jpg'),
(130702, 9313, 'Flashpoint [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Bp3vJrPxnrN8iRDaclsVUPwgWa.jpg'),
(130703, 9313, 'Flashpoint [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Bp3vJrPxnrN8iRDaclsVUPwgWa.jpg'),
(130704, 9313, 'Flashpoint [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/256091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Bp3vJrPxnrN8iRDaclsVUPwgWa.jpg'),
(130705, 9313, 'Flashpoint [L] S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/256092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Bp3vJrPxnrN8iRDaclsVUPwgWa.jpg'),
(130706, 9313, 'Flashpoint [L] S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/256093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Bp3vJrPxnrN8iRDaclsVUPwgWa.jpg'),
(130707, 9313, 'Flashpoint [L] S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/256094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Bp3vJrPxnrN8iRDaclsVUPwgWa.jpg'),
(130708, 9313, 'Flashpoint [L] S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/256095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Bp3vJrPxnrN8iRDaclsVUPwgWa.jpg'),
(130709, 9313, 'Flashpoint [L] S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/256096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3Bp3vJrPxnrN8iRDaclsVUPwgWa.jpg'),
(130710, 9314, 'Flashpoint [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0LRWGucOM2AMBEkWGIzfLTvPsv.jpg'),
(130711, 9314, 'Flashpoint [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gYHvZuc6PfJYNEM580gIEEf7lUR.jpg'),
(130712, 9314, 'Flashpoint [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/txIZ7t7bHRVkPv4l9RImyg3Z9pM.jpg'),
(130713, 9314, 'Flashpoint [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7p6FjQJKzQDx6UahZG2rVj8XN14.jpg'),
(130714, 9314, 'Flashpoint [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2AvNbRYhZcnOkjFjJT7xwGmwEFr.jpg'),
(130715, 9314, 'Flashpoint [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qmLLCWhtpRIp48zuDb3wRMZNafX.jpg'),
(130716, 9314, 'Flashpoint [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Tayr26zPcnl5rmNQnqcYyYMktF.jpg'),
(130717, 9314, 'Flashpoint [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8N1QnQSeAqQbOd2rky3QAQkCr3T.jpg'),
(130718, 9314, 'Flashpoint [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x2WF0lSAwLr5Nh7O9EI1wd0BMO3.jpg'),
(130719, 9314, 'Flashpoint [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rv5O1USXdAYb4EYyBUHWugSJgAp.jpg'),
(130720, 9314, 'Flashpoint [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOHtMbeLdmA9pccVyfrO0Bn8gJV.jpg'),
(130721, 9314, 'Flashpoint [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PL3GezEwjPatrzs50F4KXQyY1H.jpg'),
(130722, 9314, 'Flashpoint [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iFrY8oIznilyfVeFMPeLUxg25la.jpg'),
(130723, 9314, 'Flashpoint [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/256110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ln2RoOoNUmgVMznuDgogPxQk26.jpg'),
(130724, 9314, 'Flashpoint [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/256111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/47yS9SoKH9i6XuL1ja4u7YAhE53.jpg'),
(130725, 9314, 'Flashpoint [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/256112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3kz4a81M5kDc3qiFTP77drRI7RP.jpg'),
(130726, 9314, 'Flashpoint [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/256113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nWR9Do6ZsSYxPDz0ghs5Cl2qOPB.jpg'),
(130727, 9314, 'Flashpoint [L] S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/256114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zyG9qjG38dRcJGcVyYxufhouL7V.jpg'),
(130728, 9315, 'Flashpoint [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zztMRB0zSYdbSmMC1o4OlKz8VIv.jpg'),
(130729, 9315, 'Flashpoint [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/giQcK1ISszn1BaCTBGhyHAMOtjB.jpg'),
(130730, 9315, 'Flashpoint [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9eS7QMhZRN2OuovZo7dHTxhMDnn.jpg'),
(130731, 9315, 'Flashpoint [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ZBI9FdSijMx416UqAKpAsUEtpf.jpg'),
(130732, 9315, 'Flashpoint [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wN2utuHZH0DwAaHMSfSjmTPPWTI.jpg'),
(130733, 9315, 'Flashpoint [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ao7Bd9TsiqzHThOfFGY7sc3TRVz.jpg'),
(130734, 9315, 'Flashpoint [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lFNHFU2tzwMSQ3JXXEDd6mgcclV.jpg'),
(130735, 9315, 'Flashpoint [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6INZab8wMWTDz3Y5Hsgtq3mYY4G.jpg'),
(130736, 9315, 'Flashpoint [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hl4RXooPCnPx1CRK1sG9t1ADWNt.jpg'),
(130737, 9315, 'Flashpoint [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5LuLtOlOwbOsSL9V1NC0yBAK4oU.jpg'),
(130738, 9315, 'Flashpoint [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJtJXXg0LZHaKh04eUFuPMKBYpn.jpg'),
(130739, 9315, 'Flashpoint [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/le7fq4NUgQ81mAaJpOafSNtXAkN.jpg'),
(130740, 9315, 'Flashpoint [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6unNimvla7VDWjRBg8fbh7KXrWi.jpg'),
(130741, 9316, 'Dragons of Wonderhatch [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/setNSgjzVP3JWP7PS5eyfgKYR6G.jpg'),
(130742, 9316, 'Dragons of Wonderhatch [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gVBFUoLMtymyyNLH3cnC9GjqJKg.jpg'),
(130743, 9316, 'Dragons of Wonderhatch [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aEji6V6VDDfOICLGiyWRyhjsSWE.jpg'),
(130744, 9316, 'Dragons of Wonderhatch [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g12YZHrFHBhBKxJ2VHsKDav7KsM.jpg'),
(130745, 9316, 'Dragons of Wonderhatch [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6IcKlEy3q257ks03DBKn7C5AGYG.jpg'),
(130746, 9316, 'Dragons of Wonderhatch [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6IcKlEy3q257ks03DBKn7C5AGYG.jpg'),
(130747, 9316, 'Dragons of Wonderhatch [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6IcKlEy3q257ks03DBKn7C5AGYG.jpg'),
(130748, 9316, 'Dragons of Wonderhatch [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6IcKlEy3q257ks03DBKn7C5AGYG.jpg'),
(130749, 9317, 'Kunoichi Tsubaki no Mune no Uchi [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lgTd3CoX3f23RwpLoX5JKGplkIR.jpg'),
(130750, 9317, 'Kunoichi Tsubaki no Mune no Uchi [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kfbzanBNRNzzOKWpFwBfUXHi9zV.jpg'),
(130751, 9317, 'Kunoichi Tsubaki no Mune no Uchi [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o6STiAqcp95fLv7YCrgmoszP8Y5.jpg'),
(130752, 9317, 'Kunoichi Tsubaki no Mune no Uchi [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9MBPXIksoj3ejtV3G1EDCMRImMT.jpg'),
(130753, 9317, 'Kunoichi Tsubaki no Mune no Uchi [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fLakS9F91XXzndumO5suuSbQePf.jpg'),
(130754, 9317, 'Kunoichi Tsubaki no Mune no Uchi [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nqloZVsylxQm5G3jlr7v4c6LI0Z.jpg'),
(130755, 9317, 'Kunoichi Tsubaki no Mune no Uchi [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aezDmwB9wPpwsQesaIZ2sQxnX4y.jpg'),
(130756, 9317, 'Kunoichi Tsubaki no Mune no Uchi [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m5Gvd0E1Oy2qKh67y8VYeq5CQ2Y.jpg'),
(130757, 9317, 'Kunoichi Tsubaki no Mune no Uchi [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/21iDRKPlUjjUf530zof5AQeRUqj.jpg'),
(130758, 9317, 'Kunoichi Tsubaki no Mune no Uchi [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xnqWKw6fRd2emhkQd7sbMVppPqk.jpg'),
(130759, 9317, 'Kunoichi Tsubaki no Mune no Uchi [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l8sACJJlt8hYYTYhjKBGpqyNXFJ.jpg'),
(130760, 9317, 'Kunoichi Tsubaki no Mune no Uchi [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iRGJnOQ6QBFUd3ccxVLRpt7NOhD.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(130761, 9317, 'Kunoichi Tsubaki no Mune no Uchi [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/256034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqhWSGtlj7H37Cq6N2wLpu6GbkF.jpg'),
(130762, 9318, 'Meninos de Aluguel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4oQ2L5axJY4Z5ChzY0H1v6zKKe9.jpg'),
(130763, 9318, 'Meninos de Aluguel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vvSLkU6Fh7i19LBSw7G0EwkikB4.jpg'),
(130764, 9318, 'Meninos de Aluguel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A9FqB96b4DMNfURW1hJIEDQ53BA.jpg'),
(130765, 9318, 'Meninos de Aluguel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dSzyyVPpvxi5CjzOgcz5XFx9LUp.jpg'),
(130766, 9318, 'Meninos de Aluguel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5VuAUx75DodszKMNK3ZAXHk2fdT.jpg'),
(130767, 9318, 'Meninos de Aluguel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u2Nfhw9JLOHEnTzeyFXzgLrTJSX.jpg'),
(130768, 9319, 'My New Boss is Goofy [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/256004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kuLZi7apS2bvDZ49na5qAXVajHi.jpg'),
(130769, 9319, 'My New Boss is Goofy [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/256005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4cXX0gEyqK7L2OHmJHuHl7GXYbV.jpg'),
(130770, 9319, 'My New Boss is Goofy [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vddajWF6ym8VUSYrkfhzwScoF6z.jpg'),
(130771, 9319, 'My New Boss is Goofy [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUx5sp4y180wLNEj2nDuwxhuian.jpg'),
(130772, 9319, 'My New Boss is Goofy [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hAhpvWEfOu0y30NQE95yg9yBVeq.jpg'),
(130773, 9319, 'My New Boss is Goofy [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rMq4bgJC3mnqqVoKRk6eDcYEVHK.jpg'),
(130774, 9319, 'My New Boss is Goofy [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/256010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qTcMuH4ybQQ3TrEISmqzwdWMTzF.jpg'),
(130775, 9319, 'My New Boss is Goofy [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/256011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqjgCy7qhGphiSq3KL3OjYCgZrS.jpg'),
(130776, 9319, 'My New Boss is Goofy [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/256012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k2hkVun8P90HuqZonOv2vk1ESk.jpg'),
(130777, 9319, 'My New Boss is Goofy [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/256013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pewEqBjkdtoRc8PEDB1OqrboNnf.jpg'),
(130778, 9319, 'My New Boss is Goofy [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/256014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7GErcTzvsGxqLNWQK8hqhvN9VP2.jpg'),
(130779, 9319, 'My New Boss is Goofy [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/256015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1R3DvkrYPfiPTowH1w3JeHHVeQH.jpg'),
(130780, 9320, 'O Que Estou Comendo Com Zooey Deschanel [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rv4rQcG3wnRO9wVHlnATu1EHvJC.jpg'),
(130781, 9320, 'O Que Estou Comendo Com Zooey Deschanel [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gmuTBOt12pNSLjpRK7VpR02chRT.jpg'),
(130782, 9320, 'O Que Estou Comendo Com Zooey Deschanel [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/256000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JydcEwsDBSywqfwuK0QAgcJzhg.jpg'),
(130783, 9320, 'O Que Estou Comendo Com Zooey Deschanel [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/256001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9R2C7ePxJ1aqymcn4d86ixEgR1C.jpg'),
(130784, 9320, 'O Que Estou Comendo Com Zooey Deschanel [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/256002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hwAatDCLl9Ih83nT5iRXe79bHaH.jpg'),
(130785, 9320, 'O Que Estou Comendo Com Zooey Deschanel [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/256003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fMMGIu0lAoXM7Zj1j41pyyhEgq2.jpg'),
(130786, 9321, 'Paradox Live THE ANIMATION [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ekJbp3mhsdCVwwj91rqxvLxRAdy.jpg'),
(130787, 9321, 'Paradox Live THE ANIMATION [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7l0MEO1jMS5wpplalHMiBPZ8kMW.jpg'),
(130788, 9321, 'Paradox Live THE ANIMATION [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y2rL3mvtnskikb7XlSfDYfMt7jK.jpg'),
(130789, 9321, 'Paradox Live THE ANIMATION [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6PlDpONR0cjSRZ0JcfafikCSX5n.jpg'),
(130790, 9321, 'Paradox Live THE ANIMATION [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vfdH2Pc3YVlFDAk8SBMNB0oEFq4.jpg'),
(130791, 9321, 'Paradox Live THE ANIMATION [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/V0mwIEOMCXqLZo7iQbJV1DftU4.jpg'),
(130792, 9321, 'Paradox Live THE ANIMATION [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ciWNyA6vp95Qscjr1R1CyHMGAhc.jpg'),
(130793, 9321, 'Paradox Live THE ANIMATION [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AgFSNv8s9dduw5VhwfFPrb6zSDx.jpg'),
(130794, 9321, 'Paradox Live THE ANIMATION [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5v1USewzgglji0uXq0kLRUbDvLk.jpg'),
(130795, 9321, 'Paradox Live THE ANIMATION [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4L1O0f1khJZO52T752bGsYZnvTG.jpg'),
(130796, 9321, 'Paradox Live THE ANIMATION [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7h3GlD3risRNe4QpydkFrG9xQqm.jpg'),
(130797, 9321, 'Paradox Live THE ANIMATION [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qQsnispQj5L71u3YUWiVKxJp48D.jpg'),
(130798, 9322, 'Retrospectiva 2023 Edicao Globoplay S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yRDILzJBbOoiLfwHrvo5heAuMl4.jpg'),
(130799, 9322, 'Retrospectiva 2023 Edicao Globoplay S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yRDILzJBbOoiLfwHrvo5heAuMl4.jpg'),
(130800, 9322, 'Retrospectiva 2023 Edicao Globoplay S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yRDILzJBbOoiLfwHrvo5heAuMl4.jpg'),
(130801, 9322, 'Retrospectiva 2023 Edicao Globoplay S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yRDILzJBbOoiLfwHrvo5heAuMl4.jpg'),
(130802, 9323, 'Tearmoon Empire [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/27KYG61osVKDUxM5YwPh9F70Tiz.jpg'),
(130803, 9323, 'Tearmoon Empire [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVW3bWxEfWbB8Jh2KGVLv8M9Fsb.jpg'),
(130804, 9323, 'Tearmoon Empire [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6AjPmek6f6GR6TuBZGHBNWl1rRb.jpg'),
(130805, 9323, 'Tearmoon Empire [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qIdAeQteDK1p81E64Q73D6x7C4k.jpg'),
(130806, 9323, 'Tearmoon Empire [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xwCcXJ6eb8CXSFMCEUkznLFyvLQ.jpg'),
(130807, 9323, 'Tearmoon Empire [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pmvyGC56Jt3yzlRfZI3UA3brYv2.jpg'),
(130808, 9323, 'Tearmoon Empire [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7gFxSplCANIG0ZeKCWkOCM9sqqq.jpg'),
(130809, 9323, 'Tearmoon Empire [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cA5EfM3XSMDhA16EgUdKTrGrkx0.jpg'),
(130810, 9323, 'Tearmoon Empire [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b72K2tVHkyKBeVwGwiVwW7DJNBV.jpg'),
(130811, 9323, 'Tearmoon Empire [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4QVb9s4udAvtLbh3DeCwogBYd0X.jpg'),
(130812, 9323, 'Tearmoon Empire [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4VrxLeODVtKQ94CLAEqC16HReHl.jpg'),
(130813, 9323, 'Tearmoon Empire [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kMrScPiMlcy75FAIyyMW36G0AVt.jpg'),
(130814, 9324, 'The Idolmaster Million Live [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4GyppcFtn3z366uGU9MVxbNMaaO.jpg'),
(130815, 9324, 'The Idolmaster Million Live [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iL2d7F10g2FbyghQRLTEFt8OMy1.jpg'),
(130816, 9324, 'The Idolmaster Million Live [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfbkbHd4fTJReaKGoJbQHziy9CX.jpg'),
(130817, 9324, 'The Idolmaster Million Live [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wrVbKIyfuO354LnnsZwcVRNKQGO.jpg'),
(130818, 9324, 'The Idolmaster Million Live [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZc6RQzUfCXzGJskjwuxsReQIz7.jpg'),
(130819, 9324, 'The Idolmaster Million Live [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jHarW8nf3JCGgHX26bDPFBeH5my.jpg'),
(130820, 9324, 'The Idolmaster Million Live [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ffdfs3oxisZydW6WadmZFwMmQs.jpg'),
(130821, 9324, 'The Idolmaster Million Live [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5FmHDq35WwntByFqaMBolFkFCfG.jpg'),
(130822, 9324, 'The Idolmaster Million Live [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zYBxUs4dAPMOw8R9kwCZpBcocGr.jpg'),
(130823, 9324, 'The Idolmaster Million Live [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eduKCIM0Du2IcF3d7WzJyU3Dq9n.jpg'),
(130824, 9324, 'The Idolmaster Million Live [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wczACx74Rihg6Dcyx4gPHRmrub8.jpg'),
(130825, 9324, 'The Idolmaster Million Live [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7AXT1yp1pkuFuxn6CcgdAto6CCJ.jpg'),
(130826, 9325, 'Um Novo Corpo Uma Nova Vida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8aTFpHNJc9yZIRIPDOI0UVyXlfW.jpg'),
(130827, 9325, 'Um Novo Corpo Uma Nova Vida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aXt4gz4jyaTfZ4h8QbY7hBBpj5l.jpg'),
(130828, 9325, 'Um Novo Corpo Uma Nova Vida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qHuNRcu1DWHdcRHfZRmmaOlbEVQ.jpg'),
(130829, 9326, 'A Cozinha de Eduardo Garcia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hOn2IFm7o7Nd7Srorkguv2rtzPG.jpg'),
(130830, 9326, 'A Cozinha de Eduardo Garcia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ynwyBhlOY49ieYoDKmwcpTBNdf.jpg'),
(130831, 9326, 'A Cozinha de Eduardo Garcia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vYKIDzt7Qab9tfAM0Q4VcGIbEN6.jpg'),
(130832, 9326, 'A Cozinha de Eduardo Garcia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9LwsjUfPQgbmYhcsDRCKSdP45SZ.jpg'),
(130833, 9326, 'A Cozinha de Eduardo Garcia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6TwkXWjGHbXUiZJXSAwerPvtFmj.jpg'),
(130834, 9326, 'A Cozinha de Eduardo Garcia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pPGTY1u3oHdbeHPteZaNUbJFgv9.jpg'),
(130835, 9327, 'A Grande Ilusao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tIofhILukFRSFbW6Y4oJ7gkgd7p.jpg'),
(130836, 9327, 'A Grande Ilusao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/momRTddzHwEddYdXtKwWlsIzD9g.jpg'),
(130837, 9327, 'A Grande Ilusao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g3Zy3HNsOlvJXkZb3PP53vlBenM.jpg'),
(130838, 9327, 'A Grande Ilusao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o43ZhmQhv6KB9BjhkrjZoXTTqwp.jpg'),
(130839, 9327, 'A Grande Ilusao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSDnjnmSmLAF0ozgIFUDkS24D5s.jpg'),
(130840, 9327, 'A Grande Ilusao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zN7pjQhaWXDwHYnelttSX3ecjAp.jpg'),
(130841, 9327, 'A Grande Ilusao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8oLJIgnwG1n7iaAvYahbeeXoD4M.jpg'),
(130842, 9327, 'A Grande Ilusao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/agIq7jiHQVIAHCVPuotff1Aybe2.jpg'),
(130843, 9328, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/DB94GtK6xp7zicyjoYiu0JODSD.jpg'),
(130844, 9328, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kYN1K9d5Hy4xQgtFVkMS8KQr59t.jpg'),
(130845, 9328, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9yBonr7S4tMRhjRH5Q8cpM4Zo9d.jpg'),
(130846, 9328, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z76A4yW79GF1z5YrH2W3k173jMk.jpg'),
(130847, 9328, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9rVlBLJPGgNoY0PTYXG6rrDcXXz.jpg'),
(130848, 9328, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tEjZNsOuVyovwEzdVeoLMHZfxOA.jpg'),
(130849, 9328, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qAs4Bu0jYdcc45m8D1oSqoQTrJ7.jpg'),
(130850, 9328, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/weFue0EZ9Ih6Ty5s2o9uoKWpbgV.jpg'),
(130851, 9328, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yr5wUqpjoDopcVFkzlB3c0otyWi.jpg'),
(130852, 9328, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6taDPMMcG08nhtGGAA56cJB4zPm.jpg'),
(130853, 9328, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dYTsxWXzEz0E6qTg95Ze5HEDLZc.jpg'),
(130854, 9328, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zAGZG0qX7TL2dySQFnSYRzg56jy.jpg'),
(130855, 9329, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dr8AtU8Z7kTOUUhY3qhzPgpAnVA.jpg'),
(130856, 9329, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/YUO0Vy0mwy4CWScgHZFEfZh6P8.jpg'),
(130857, 9329, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/apZDKZjEzgwnmWh9vRhPNi397Yc.jpg'),
(130858, 9329, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63eZniakSHk6JaHebnnlzVjtbp3.jpg'),
(130859, 9329, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cFKRvBStKylGqnvzMUpkkEbSykr.jpg'),
(130860, 9329, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6gm13e94MvqvkPhNwRNfEi58x8i.jpg'),
(130861, 9329, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5pWX8IF6ubt7Ot6JIsdPmnHZc93.jpg'),
(130862, 9329, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jlyLQyVKia0TRtHCIMPsYBlNNWZ.jpg'),
(130863, 9329, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j22XBZAhOrBgKWPKGDHFRgYgjkJ.jpg'),
(130864, 9329, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gpl3gdlWIIFFOHEKBmJuUeG6R3C.jpg'),
(130865, 9329, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ooj0ghrpBrMpRHt8sPIcw7AIWkd.jpg'),
(130866, 9329, 'BOFURI I Dont Want to Get Hurt so Ill Max Out My Defense [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vCDkgSXbz58vfTGhJHZUxg2zzJa.jpg'),
(130867, 9330, 'Beautiful Mind [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUAinTIokPJE4bBIoZFPFQStOff.jpg'),
(130868, 9330, 'Beautiful Mind [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jyluAalyqntjlfBhOyGjvd7lHNS.jpg'),
(130869, 9330, 'Beautiful Mind [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cD7u0w9ydeQ2apn0ChetC3bylJe.jpg'),
(130870, 9330, 'Beautiful Mind [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bWDz2dhxuvWY3h0zV7GEWLKSObb.jpg'),
(130871, 9330, 'Beautiful Mind [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dV96mO7k6RUIcTnTbzVltAfQl8D.jpg'),
(130872, 9330, 'Beautiful Mind [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j2M2wIFPuxBWp9vyARslXIMiLJx.jpg'),
(130873, 9330, 'Beautiful Mind [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rqOBquhN4jYWNvqOWQy0hlYSCfO.jpg'),
(130874, 9330, 'Beautiful Mind [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LFghX5e83IRxmF8jXtOZNKDNIW.jpg'),
(130875, 9330, 'Beautiful Mind [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ivztjUqGYdPSoqExy5AW2EP7SEW.jpg'),
(130876, 9330, 'Beautiful Mind [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oRCYzaN1jN3bzhDPJIrugVkoHJU.jpg'),
(130877, 9330, 'Beautiful Mind [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dsOmZFsWiQgZJNnLK7IR1kQQnH5.jpg'),
(130878, 9330, 'Beautiful Mind [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nNhNh5Gx3H9CUBJMmNgmjno7kQm.jpg'),
(130879, 9330, 'Beautiful Mind [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5jh8g4nf039tpv4Wk9zwswNKt4g.jpg'),
(130880, 9330, 'Beautiful Mind [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bhycJvtxGGhf94psjN0mK4qNvn9.jpg'),
(130881, 9331, 'Capitaes do Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xEs4P46uMzUZF0hYdpQ9Kws4cTx.jpg'),
(130882, 9331, 'Capitaes do Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tST9MBjYWRZ3YRuUzgcXiPCvhuz.jpg'),
(130883, 9331, 'Capitaes do Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3A11ySyoUthaBK8AYVvgmqOx8zQ.jpg'),
(130884, 9331, 'Capitaes do Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oLZzvsoDxyhisxi6cyIW245Rdkx.jpg'),
(130885, 9331, 'Capitaes do Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ltG1nDuMrTrpDhg3LROWWh4iKm.jpg'),
(130886, 9331, 'Capitaes do Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t3v3FLCKMhcmiiJFIyAH37bT2ch.jpg'),
(130887, 9332, 'Contatos Imediatos Oceania S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6HUmUuRnFiEBPVNZtvTJDOLyir1.jpg'),
(130888, 9332, 'Contatos Imediatos Oceania S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6HUmUuRnFiEBPVNZtvTJDOLyir1.jpg'),
(130889, 9332, 'Contatos Imediatos Oceania S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6HUmUuRnFiEBPVNZtvTJDOLyir1.jpg'),
(130890, 9332, 'Contatos Imediatos Oceania S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6HUmUuRnFiEBPVNZtvTJDOLyir1.jpg'),
(130891, 9332, 'Contatos Imediatos Oceania S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6HUmUuRnFiEBPVNZtvTJDOLyir1.jpg'),
(130892, 9332, 'Contatos Imediatos Oceania S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6HUmUuRnFiEBPVNZtvTJDOLyir1.jpg'),
(130893, 9333, 'Dark Hole [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtF5gUgueK60u97q28mgnaiLgzs.jpg'),
(130894, 9333, 'Dark Hole [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5bLo0lItG5UVgv4s2Ys9lNwCOsb.jpg'),
(130895, 9333, 'Dark Hole [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bNOEoaz31xxO5zqoTvOBYx1lXMS.jpg'),
(130896, 9333, 'Dark Hole [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/da3vAO0NBpnBoVp1a1QLbfzja7e.jpg'),
(130897, 9333, 'Dark Hole [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iwa92JnTspP1cHpGTY5KgLmV2O0.jpg'),
(130898, 9333, 'Dark Hole [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fA7w67Z5CQNDskKqHbSLsu4SO8s.jpg'),
(130899, 9333, 'Dark Hole [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wcgxnkpc2JAC1CXBVN2iq3jySXT.jpg'),
(130900, 9333, 'Dark Hole [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sKfuDiZQMGJCiG3L4eWY8naYwUs.jpg'),
(130901, 9333, 'Dark Hole [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kb9FJz2vdtYUZsMk1Lh0o72x9hS.jpg'),
(130902, 9333, 'Dark Hole [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9uChMuMA5F0G6GkrxPw286jc04Q.jpg'),
(130903, 9333, 'Dark Hole [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jK5VEmEkLjxHzpG0MsKVU3xDjub.jpg'),
(130904, 9333, 'Dark Hole [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iahYTEma9ex28AOHze9kp5ah3uU.jpg'),
(130905, 9334, 'De Volta as Raizes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gw7kNz95AQyYaB6bSiTfwn3kKIY.jpg'),
(130906, 9334, 'De Volta as Raizes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q5TKHDCTYTeTzj0Ea5vqQGVadrz.jpg'),
(130907, 9334, 'De Volta as Raizes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tv13kY7rC1Afn9BdjJ0l7VqADeJ.jpg'),
(130908, 9334, 'De Volta as Raizes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wP0tKhLeNPpAeabeLVjVMZV8Ul4.jpg'),
(130909, 9334, 'De Volta as Raizes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5axZllylBVeKv9cduhCisOYUqIp.jpg'),
(130910, 9334, 'De Volta as Raizes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5axZllylBVeKv9cduhCisOYUqIp.jpg'),
(130911, 9334, 'De Volta as Raizes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5axZllylBVeKv9cduhCisOYUqIp.jpg'),
(130912, 9334, 'De Volta as Raizes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5axZllylBVeKv9cduhCisOYUqIp.jpg'),
(130913, 9334, 'De Volta as Raizes S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5axZllylBVeKv9cduhCisOYUqIp.jpg'),
(130914, 9334, 'De Volta as Raizes S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5axZllylBVeKv9cduhCisOYUqIp.jpg'),
(130915, 9334, 'De Volta as Raizes S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5axZllylBVeKv9cduhCisOYUqIp.jpg'),
(130916, 9334, 'De Volta as Raizes S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5axZllylBVeKv9cduhCisOYUqIp.jpg'),
(130917, 9334, 'De Volta as Raizes S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5axZllylBVeKv9cduhCisOYUqIp.jpg'),
(130918, 9334, 'De Volta as Raizes S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5axZllylBVeKv9cduhCisOYUqIp.jpg'),
(130919, 9334, 'De Volta as Raizes S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/271581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5axZllylBVeKv9cduhCisOYUqIp.jpg'),
(130920, 9334, 'De Volta as Raizes S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/271582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5axZllylBVeKv9cduhCisOYUqIp.jpg'),
(130921, 9335, 'Fargo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2aoYgtJE8VRp3gixQMHprWIsLJs.jpg'),
(130922, 9335, 'Fargo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVq4CeIwvlulOBTDELk4VVlEvD5.jpg'),
(130923, 9335, 'Fargo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/269IUdtuzqCfRWOHxgkPX24Oj6h.jpg'),
(130924, 9335, 'Fargo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/medpgSsX9bc0aeW8ujDbWTPC25x.jpg'),
(130925, 9335, 'Fargo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/thwaGJ8kAkEWa5lrvmHPnQKMpwQ.jpg'),
(130926, 9335, 'Fargo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/H3JU0CreR995r2gQkOv5OP49H0.jpg'),
(130927, 9335, 'Fargo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6QQQwwNpEHR8xrCX4T59oKMXrZA.jpg'),
(130928, 9335, 'Fargo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z0dQrylb9iFxu0ImB4ibCtIjcW7.jpg'),
(130929, 9335, 'Fargo [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xIAN4BBuBGcATok05XGKIdsAUpR.jpg'),
(130930, 9335, 'Fargo [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iFqazjg50D0LnLI7IyplXLFiAN4.jpg'),
(130931, 9336, 'Fargo [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f5GAKBnvFOYs1kpPm12GX67dlmN.jpg'),
(130932, 9336, 'Fargo [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wMBUPjvbMGpmLkFyQOCLztIcrke.jpg'),
(130933, 9336, 'Fargo [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tA6urSiXcUyw6PVRtbKAakJbzJE.jpg'),
(130934, 9336, 'Fargo [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xyEqq8EPRxi0Otv9DWwdrqdEjNh.jpg'),
(130935, 9336, 'Fargo [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dTDcch1UsYDcwTeNkrmpXrIRw8n.jpg'),
(130936, 9336, 'Fargo [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dYLvgimJh2UgA2bGx6ffBUeOsau.jpg'),
(130937, 9336, 'Fargo [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oYrYIFHidpFOpPdncwfZBhZrBfL.jpg'),
(130938, 9336, 'Fargo [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wuZqErsa5pS5oSP1guS3nlqqbfl.jpg'),
(130939, 9336, 'Fargo [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/834y7bDx7JHGEKoUJ1G9cvxFWVF.jpg'),
(130940, 9336, 'Fargo [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h6sSCMixDZh4lBLxR9zZCmgE1JH.jpg'),
(130941, 9337, 'Fargo [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/phouc6q1IZTxUlClr7CNnxaF9Xw.jpg'),
(130942, 9337, 'Fargo [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1NqbChQ7sSXQvo0WKHS7bHKwv2o.jpg'),
(130943, 9337, 'Fargo [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q38okovZVSEsabPddeH2dFplpJE.jpg'),
(130944, 9337, 'Fargo [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mckpwFFSIHqL9kD1pUYBdci7W9k.jpg'),
(130945, 9337, 'Fargo [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1KGKMJXfIlwkVjBV3TBrPkRuuqy.jpg'),
(130946, 9337, 'Fargo [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ZfK6DrqbZ4B98zBEGbY4M0C0lK.jpg'),
(130947, 9337, 'Fargo [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yaf1iDx4AW0CDx9RnjD8E6mvw71.jpg'),
(130948, 9337, 'Fargo [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AmXD9mAHJpX8NQK6u446FLjrOp8.jpg'),
(130949, 9337, 'Fargo [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rMIja7QyZQVzy6AtdSz1EEiWf5F.jpg'),
(130950, 9337, 'Fargo [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aLGpSW9RfbWEOvXCN8W61LiKC2h.jpg'),
(130951, 9338, 'Fargo [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r8uWDma9ewCfxmdrjOMaXlj0PgI.jpg'),
(130952, 9338, 'Fargo [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t2lbYZMFFI21aub0wpAnKf6b6BB.jpg'),
(130953, 9338, 'Fargo [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iF0W1r5JF8yJ4CjNxc6YfIjXWSH.jpg'),
(130954, 9338, 'Fargo [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y619kj6sRWiai4ZPffUI5UVWHed.jpg'),
(130955, 9338, 'Fargo [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1CcPbyrtn9nqOaZqlC3UbZGXoP.jpg'),
(130956, 9338, 'Fargo [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8fGw0TfgZx62wSu7k4pqOsXJX5l.jpg'),
(130957, 9338, 'Fargo [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mjDkMqcfDsYyDgbYKmZ15xM9PPL.jpg'),
(130958, 9338, 'Fargo [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xnGU0KnEzzSazhib0Dnnl7rNAxk.jpg'),
(130959, 9338, 'Fargo [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mRWvGbDL4IwniAdX19jKmVN3MM5.jpg'),
(130960, 9338, 'Fargo [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xybYWE5yWpODggthaJQ2WaLIZFY.jpg'),
(130961, 9338, 'Fargo [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/261522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/irzANwBef1h7L6lpJT3SOvmuV07.jpg'),
(130962, 9339, 'Fargo [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yt9VPxlZLvyNTjMWtzhdqeXwPsH.jpg'),
(130963, 9339, 'Fargo [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sjBOWb7hWC34hvwgz2c3wcpFBO2.jpg'),
(130964, 9339, 'Fargo [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bqU69n8bJVzX0GMcVNhqsQ5AN8K.jpg'),
(130965, 9339, 'Fargo [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fLBHoSzmqv4k4QTXHk74TLcZXCp.jpg'),
(130966, 9339, 'Fargo [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7UgJ8TpVQArpUJgdqH9IrKKTBLZ.jpg'),
(130967, 9339, 'Fargo [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/stEwG8xjK9LfrwQK8zSwv97xiVG.jpg'),
(130968, 9339, 'Fargo [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o9eKNJimo65sMiRJjw9T6VaGKTb.jpg'),
(130969, 9339, 'Fargo [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zu3rkBP4uxmfyOHstfr6KbEGUdz.jpg'),
(130970, 9339, 'Fargo [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zu3rkBP4uxmfyOHstfr6KbEGUdz.jpg'),
(130971, 9339, 'Fargo [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zu3rkBP4uxmfyOHstfr6KbEGUdz.jpg'),
(130972, 9340, 'Fated to Love You [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/skGzNTnWv7hQdSp42Nx7wtr3ZwD.jpg'),
(130973, 9340, 'Fated to Love You [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/skGzNTnWv7hQdSp42Nx7wtr3ZwD.jpg'),
(130974, 9340, 'Fated to Love You [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/skGzNTnWv7hQdSp42Nx7wtr3ZwD.jpg'),
(130975, 9340, 'Fated to Love You [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/skGzNTnWv7hQdSp42Nx7wtr3ZwD.jpg'),
(130976, 9340, 'Fated to Love You [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/skGzNTnWv7hQdSp42Nx7wtr3ZwD.jpg'),
(130977, 9340, 'Fated to Love You [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/skGzNTnWv7hQdSp42Nx7wtr3ZwD.jpg'),
(130978, 9340, 'Fated to Love You [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/skGzNTnWv7hQdSp42Nx7wtr3ZwD.jpg'),
(130979, 9340, 'Fated to Love You [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/skGzNTnWv7hQdSp42Nx7wtr3ZwD.jpg'),
(130980, 9340, 'Fated to Love You [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/skGzNTnWv7hQdSp42Nx7wtr3ZwD.jpg'),
(130981, 9340, 'Fated to Love You [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/skGzNTnWv7hQdSp42Nx7wtr3ZwD.jpg'),
(130982, 9340, 'Fated to Love You [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/skGzNTnWv7hQdSp42Nx7wtr3ZwD.jpg'),
(130983, 9340, 'Fated to Love You [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/skGzNTnWv7hQdSp42Nx7wtr3ZwD.jpg'),
(130984, 9340, 'Fated to Love You [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/skGzNTnWv7hQdSp42Nx7wtr3ZwD.jpg'),
(130985, 9340, 'Fated to Love You [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/skGzNTnWv7hQdSp42Nx7wtr3ZwD.jpg'),
(130986, 9340, 'Fated to Love You [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/skGzNTnWv7hQdSp42Nx7wtr3ZwD.jpg'),
(130987, 9340, 'Fated to Love You [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/skGzNTnWv7hQdSp42Nx7wtr3ZwD.jpg'),
(130988, 9340, 'Fated to Love You [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/skGzNTnWv7hQdSp42Nx7wtr3ZwD.jpg'),
(130989, 9340, 'Fated to Love You [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/skGzNTnWv7hQdSp42Nx7wtr3ZwD.jpg'),
(130990, 9340, 'Fated to Love You [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/skGzNTnWv7hQdSp42Nx7wtr3ZwD.jpg'),
(130991, 9340, 'Fated to Love You [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/skGzNTnWv7hQdSp42Nx7wtr3ZwD.jpg'),
(130992, 9341, 'Fix You [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Gxzy3Ryz1ZFDU9EsYHfYzmha3X.jpg'),
(130993, 9341, 'Fix You [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9rCavCUANaGeAiBSkgp453zD7bB.jpg'),
(130994, 9341, 'Fix You [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wRhgrjescj3dDiwox09GaPqyFvJ.jpg'),
(130995, 9341, 'Fix You [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ubYZAMb51pq55SKiSez6WyVVRjh.jpg'),
(130996, 9341, 'Fix You [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zwvYDsBBWveyQwVAAc51v8Jq0xM.jpg'),
(130997, 9341, 'Fix You [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/455zdEbzvke60RTrMAfSRJ96caO.jpg'),
(130998, 9341, 'Fix You [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7LnoJnH35kH26JJcSXSBwDEYVjG.jpg'),
(130999, 9341, 'Fix You [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBGB1mO1ukh3TZbJza9AuMeFhM3.jpg'),
(131000, 9341, 'Fix You [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aGku4o3ng9vUa9n3UlxB9o4SgVC.jpg'),
(131001, 9341, 'Fix You [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hyJdb6okn7aa06TlUCCupBubor6.jpg'),
(131002, 9341, 'Fix You [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jNE7GQPE0y1AJOXuLQ4vg2rxjUn.jpg'),
(131003, 9341, 'Fix You [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1blQfNS3TIXeD8Dd2s5pKGklByw.jpg'),
(131004, 9341, 'Fix You [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vsyAKJwIJeDUx79iVVddpzk0pyv.jpg'),
(131005, 9341, 'Fix You [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2uKs07RAo7N45T3NMfvxp1MVEe.jpg'),
(131006, 9341, 'Fix You [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Ip3GP6mD6GcjrAeSqlFSfZDoqS.jpg'),
(131007, 9341, 'Fix You [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHAO9PW3ZupkPQpa9klrFNqcFVD.jpg'),
(131008, 9341, 'Fix You [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHAO9PW3ZupkPQpa9klrFNqcFVD.jpg'),
(131009, 9341, 'Fix You [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHAO9PW3ZupkPQpa9klrFNqcFVD.jpg'),
(131010, 9341, 'Fix You [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHAO9PW3ZupkPQpa9klrFNqcFVD.jpg'),
(131011, 9341, 'Fix You [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHAO9PW3ZupkPQpa9klrFNqcFVD.jpg'),
(131012, 9341, 'Fix You [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/255227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHAO9PW3ZupkPQpa9klrFNqcFVD.jpg'),
(131013, 9341, 'Fix You [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/255228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHAO9PW3ZupkPQpa9klrFNqcFVD.jpg'),
(131014, 9341, 'Fix You [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/255229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHAO9PW3ZupkPQpa9klrFNqcFVD.jpg'),
(131015, 9341, 'Fix You [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/255230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHAO9PW3ZupkPQpa9klrFNqcFVD.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(131016, 9341, 'Fix You [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/255231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHAO9PW3ZupkPQpa9klrFNqcFVD.jpg'),
(131017, 9341, 'Fix You [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/255232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHAO9PW3ZupkPQpa9klrFNqcFVD.jpg'),
(131018, 9341, 'Fix You [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/255233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHAO9PW3ZupkPQpa9klrFNqcFVD.jpg'),
(131019, 9341, 'Fix You [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/255234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHAO9PW3ZupkPQpa9klrFNqcFVD.jpg'),
(131020, 9341, 'Fix You [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/255235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHAO9PW3ZupkPQpa9klrFNqcFVD.jpg'),
(131021, 9341, 'Fix You [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/255236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHAO9PW3ZupkPQpa9klrFNqcFVD.jpg'),
(131022, 9341, 'Fix You [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/255237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHAO9PW3ZupkPQpa9klrFNqcFVD.jpg'),
(131023, 9341, 'Fix You [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/255238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHAO9PW3ZupkPQpa9klrFNqcFVD.jpg'),
(131024, 9342, 'Hannah Montana S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/khRPSUBRPI1kGJyPZTpZYWy1M0M.jpg'),
(131025, 9342, 'Hannah Montana S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hvC0QSnIZMUoJritTdxoKjMQpaf.jpg'),
(131026, 9342, 'Hannah Montana S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3xJclQzyYNh6exHTEWM5KnvtM1.jpg'),
(131027, 9342, 'Hannah Montana S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ayk2LR4IVS9RU37CwnIfcv014J.jpg'),
(131028, 9342, 'Hannah Montana S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ncAjzXbscn9ng9Zm5L9zIP0Mxw0.jpg'),
(131029, 9342, 'Hannah Montana S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/881TSMWioUoCLxAp2YeFat7Kj86.jpg'),
(131030, 9342, 'Hannah Montana S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nOSJLAgk0NxYtevh7pcj6RSo0xa.jpg'),
(131031, 9342, 'Hannah Montana S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lRNA4pc93CwC1ni1D9SYHdobfZR.jpg'),
(131032, 9342, 'Hannah Montana S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xlWcPtGH6CoG2Ir8wpDqnucFiKc.jpg'),
(131033, 9342, 'Hannah Montana S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u0njPzNnWzIIHIIk2ukUS05OBIs.jpg'),
(131034, 9342, 'Hannah Montana S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2eWAEgEkuApQraU7uA7j0ryKU5E.jpg'),
(131035, 9342, 'Hannah Montana S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJ7LW5h4fFPDVolsaUHeLoLFIji.jpg'),
(131036, 9342, 'Hannah Montana S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fadjIbOftAKRzt5HKkDmpkkMwS.jpg'),
(131037, 9342, 'Hannah Montana S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6JbGDMjcsU79YxF1mMDickgMsy9.jpg'),
(131038, 9342, 'Hannah Montana S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n9GNcf2vR0bvDbMRoC8Fv0IwNDQ.jpg'),
(131039, 9342, 'Hannah Montana S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/73mYX5dwEOeTW9eV5p3XbTERrd3.jpg'),
(131040, 9342, 'Hannah Montana S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lEgQh8Nz8hXzHjuKRxInzem2by7.jpg'),
(131041, 9342, 'Hannah Montana S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9oKCP1dYkthkLYTI5m9SopJTWYo.jpg'),
(131042, 9342, 'Hannah Montana S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qAIlB7kmRWEaqjlYoXYGwhBhQE5.jpg'),
(131043, 9342, 'Hannah Montana S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfp3995J863Vjogz3pJdCGQmm6B.jpg'),
(131044, 9342, 'Hannah Montana S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/255171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uytQGFMReZlq5FxCPVVKp5kgjqj.jpg'),
(131045, 9342, 'Hannah Montana S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/255172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jLioXZjuRHSUgwJ1U4zhJgq1HZV.jpg'),
(131046, 9342, 'Hannah Montana S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/255173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iI2hpvl194uRRgLcmwzoCebXeXc.jpg'),
(131047, 9342, 'Hannah Montana S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/255174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3HpI8IpE1WS6nuH4eyJCpVTOgbJ.jpg'),
(131048, 9342, 'Hannah Montana S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/255175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1iVM6Y2NwZoUojS7IIW6xAJi6J6.jpg'),
(131049, 9342, 'Hannah Montana S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/255176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1kP1JRVaJBtM6FJw4nxXnSNNyzT.jpg'),
(131050, 9343, 'Hannah Montana S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sP0CIRkcTYb1a1ETYRs2Ozfqs4U.jpg'),
(131051, 9343, 'Hannah Montana S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AtzyXmvuHxNw2JiSEj7diI17PXE.jpg'),
(131052, 9343, 'Hannah Montana S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEAaDUwK1Lr4thF0tghW2B1BK0s.jpg'),
(131053, 9343, 'Hannah Montana S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/puoXOqOlgCUJ9FFtDTwrBA1gllr.jpg'),
(131054, 9343, 'Hannah Montana S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8jPQ1YdNjQIHKbn1QHXgXnDJYr7.jpg'),
(131055, 9343, 'Hannah Montana S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/FSeZQwYN3uLvIUNAhppfkPVC8b.jpg'),
(131056, 9343, 'Hannah Montana S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A81bSS1afIqiGPnpc0TNNfiagPL.jpg'),
(131057, 9343, 'Hannah Montana S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hs2G0WypFeA897DMLm7fXfvcmyx.jpg'),
(131058, 9343, 'Hannah Montana S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7BgO5iQQItiU1meXuJoTi59nWmA.jpg'),
(131059, 9343, 'Hannah Montana S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3RIkk7iXLFPaw99TQwKc3MIzXNJ.jpg'),
(131060, 9343, 'Hannah Montana S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r13Dv2MeiVtYSkPhxnu1QSXFi4O.jpg'),
(131061, 9343, 'Hannah Montana S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6b5QpMBxgk6R7tvwh6HsOCogCDN.jpg'),
(131062, 9343, 'Hannah Montana S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9uMwZQxeLXNtIHY9IrPAgKwunBl.jpg'),
(131063, 9343, 'Hannah Montana S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eB1uS5nh217xD8DKqAynYA25ejS.jpg'),
(131064, 9343, 'Hannah Montana S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ygqw1zdTcShkJ3HNgjf6Cu0mNx.jpg'),
(131065, 9343, 'Hannah Montana S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qA7ivoJy2YBnCCAfYiUssEkoot4.jpg'),
(131066, 9343, 'Hannah Montana S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/813tSY7dzGWfCfsE8y5XhklMlGx.jpg'),
(131067, 9343, 'Hannah Montana S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8h0UNGRm6v2pTu3ZtU9ewvMqrYs.jpg'),
(131068, 9343, 'Hannah Montana S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5rCz7K0koX7cnp3KQrUUc4YSjUt.jpg'),
(131069, 9343, 'Hannah Montana S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l4o1mkyOEDWjgRJ61Z1lEmdNVgN.jpg'),
(131070, 9343, 'Hannah Montana S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/255197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mc5ef2i92qSwByiujS4WmU32HjS.jpg'),
(131071, 9343, 'Hannah Montana S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/255198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6SsmWhIESx65gSbuIN4YZYtUIxp.jpg'),
(131072, 9343, 'Hannah Montana S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/255199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAEvCpuXHsgRd6UQUuFGRgwCfOp.jpg'),
(131073, 9343, 'Hannah Montana S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/255200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vNyIiYZjDoXNkwMQjn7cBLoKXyR.jpg'),
(131074, 9343, 'Hannah Montana S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/255201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sVOxOUqPgE2hm9H7w1xbKgIWa3u.jpg'),
(131075, 9343, 'Hannah Montana S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/255202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/amRP4Gl3lgYemOi6tlzgKPjJNNA.jpg'),
(131076, 9343, 'Hannah Montana S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/255203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rWcCN7IFWubUGLYnrp0tatDOqqS.jpg'),
(131077, 9343, 'Hannah Montana S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/255204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zs9d5n9VWXlK4JxGPtFOrRxohJd.jpg'),
(131078, 9343, 'Hannah Montana S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/255205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wEX5UnQ8qETQtmSqAS7p9AoZ0e9.jpg'),
(131079, 9343, 'Hannah Montana S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/255206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131080, 9344, 'Hannah Montana S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/398645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131081, 9344, 'Hannah Montana S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/398646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131082, 9344, 'Hannah Montana S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/398647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131083, 9344, 'Hannah Montana S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/398648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131084, 9344, 'Hannah Montana S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/398649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131085, 9344, 'Hannah Montana S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/398650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131086, 9344, 'Hannah Montana S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/398651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131087, 9344, 'Hannah Montana S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/398652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131088, 9344, 'Hannah Montana S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/398653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131089, 9344, 'Hannah Montana S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/398654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131090, 9344, 'Hannah Montana S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/398655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131091, 9344, 'Hannah Montana S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/398656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131092, 9344, 'Hannah Montana S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/398657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131093, 9344, 'Hannah Montana S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/398658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131094, 9344, 'Hannah Montana S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/398659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131095, 9344, 'Hannah Montana S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/398660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131096, 9344, 'Hannah Montana S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/398661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131097, 9344, 'Hannah Montana S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/398662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131098, 9344, 'Hannah Montana S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/398663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131099, 9344, 'Hannah Montana S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/398664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131100, 9344, 'Hannah Montana S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/398665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131101, 9344, 'Hannah Montana S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/398666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131102, 9344, 'Hannah Montana S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/398667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131103, 9344, 'Hannah Montana S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/398668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131104, 9344, 'Hannah Montana S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/398669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131105, 9344, 'Hannah Montana S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/398670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131106, 9344, 'Hannah Montana S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/398671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131107, 9344, 'Hannah Montana S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/398672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131108, 9344, 'Hannah Montana S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/398673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131109, 9344, 'Hannah Montana S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/398674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131110, 9345, 'Hannah Montana S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/403118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131111, 9345, 'Hannah Montana S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/403119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131112, 9345, 'Hannah Montana S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/403120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131113, 9345, 'Hannah Montana S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/403121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131114, 9345, 'Hannah Montana S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/403122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131115, 9345, 'Hannah Montana S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/403123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131116, 9345, 'Hannah Montana S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/403124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131117, 9345, 'Hannah Montana S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/403125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131118, 9345, 'Hannah Montana S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/403126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131119, 9345, 'Hannah Montana S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/403127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131120, 9345, 'Hannah Montana S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/403128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131121, 9345, 'Hannah Montana S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/403129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131122, 9345, 'Hannah Montana S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/403130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131123, 9345, 'Hannah Montana S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/403131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131124, 9345, 'Hannah Montana S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/403132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRqLl0SHA4diTL8zvUTgBw6DQeM.jpg'),
(131125, 9346, 'If You Wish Upon Me [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mayE4yYLMlfdcZeVvqqHAvlKjXK.jpg'),
(131126, 9346, 'If You Wish Upon Me [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s0WN2oRwRv9BvtzVwO205g0BUGT.jpg'),
(131127, 9346, 'If You Wish Upon Me [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ug3ybGGjPDfmtfdEBK4pwntUfDr.jpg'),
(131128, 9346, 'If You Wish Upon Me [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s7t5UYbt4CUEVqKw3M6X8lTyp5g.jpg'),
(131129, 9346, 'If You Wish Upon Me [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xIMKMZomvfc7gulRxYv04PX18UG.jpg'),
(131130, 9346, 'If You Wish Upon Me [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sOS4X0tTreIRjAUJiVImYUaO6sk.jpg'),
(131131, 9346, 'If You Wish Upon Me [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uJxUIpQXcNfmOEIVB65hey0ImGh.jpg'),
(131132, 9346, 'If You Wish Upon Me [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AldUisR7Pp5FeZmlQsUmwf0k26K.jpg'),
(131133, 9346, 'If You Wish Upon Me [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sJbfL5sm0iCfOlVb83NLieouxBW.jpg'),
(131134, 9346, 'If You Wish Upon Me [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rEz9buEKtUCu793unNa2orSGMgn.jpg'),
(131135, 9346, 'If You Wish Upon Me [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AtnVax8tizATrFVcCuqjtVZHZot.jpg'),
(131136, 9346, 'If You Wish Upon Me [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nq5w6lw2R46jLFIl0Xscj8vFMxT.jpg'),
(131137, 9346, 'If You Wish Upon Me [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pZ0DXPsX9hw0F8ZaWXqWK8IXnRt.jpg'),
(131138, 9346, 'If You Wish Upon Me [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2wcAHdNlZ2ZC1akjfLKIFObitMG.jpg'),
(131139, 9346, 'If You Wish Upon Me [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJumn3tHoIYqYvgLzmkDz1T2LrU.jpg'),
(131140, 9346, 'If You Wish Upon Me [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aOzPxVGVgHjhAYibV7kCuzJciMx.jpg'),
(131141, 9347, 'Kimi wa Houkago Insomnia [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8zGhtTrtMIvRDfeKHP33KCTlopd.jpg'),
(131142, 9347, 'Kimi wa Houkago Insomnia [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bNI6XywQ7BYkgdno8680uaNxyJI.jpg'),
(131143, 9347, 'Kimi wa Houkago Insomnia [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zP9QVsYXM89gs4KElF59B00LZwt.jpg'),
(131144, 9347, 'Kimi wa Houkago Insomnia [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cjjoURuDqXsGfvPOZuqeTMg2RHz.jpg'),
(131145, 9347, 'Kimi wa Houkago Insomnia [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nmQMgbiC88WyTxD4RI5KiHMwflf.jpg'),
(131146, 9347, 'Kimi wa Houkago Insomnia [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/puW1RCSW81zhqJfQ5mW2U68vxuu.jpg'),
(131147, 9347, 'Kimi wa Houkago Insomnia [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/leJEC6tORpACQXtW4HvSuRJBTsu.jpg'),
(131148, 9347, 'Kimi wa Houkago Insomnia [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1bJiPtUVNwEurJTicBZeoQojqN4.jpg'),
(131149, 9347, 'Kimi wa Houkago Insomnia [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wCVvpuwxOTdYLx5k6EzgNzTXkmo.jpg'),
(131150, 9347, 'Kimi wa Houkago Insomnia [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/avQzfpLgk4Z02D1uTHMXyW378xO.jpg'),
(131151, 9347, 'Kimi wa Houkago Insomnia [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w1Rz5YWNJXWlE4R8B5VXuoWlykq.jpg'),
(131152, 9347, 'Kimi wa Houkago Insomnia [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iD3FIFCLkpPAwDmWy6GyrZjiRuH.jpg'),
(131153, 9347, 'Kimi wa Houkago Insomnia [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1JXb7UuHixADjUKx4tMdHgcCnEm.jpg'),
(131154, 9348, 'Noble My Love [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lV39ysihO5sjcV4BezOzCJQYvDK.jpg'),
(131155, 9348, 'Noble My Love [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lV39ysihO5sjcV4BezOzCJQYvDK.jpg'),
(131156, 9348, 'Noble My Love [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lV39ysihO5sjcV4BezOzCJQYvDK.jpg'),
(131157, 9348, 'Noble My Love [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lV39ysihO5sjcV4BezOzCJQYvDK.jpg'),
(131158, 9348, 'Noble My Love [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lV39ysihO5sjcV4BezOzCJQYvDK.jpg'),
(131159, 9348, 'Noble My Love [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lV39ysihO5sjcV4BezOzCJQYvDK.jpg'),
(131160, 9348, 'Noble My Love [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lV39ysihO5sjcV4BezOzCJQYvDK.jpg'),
(131161, 9349, 'Reu [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kPOLexEaq2PhEAtxy5p1SjIDN1G.jpg'),
(131162, 9349, 'Reu [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lnfOis0UDcDcRZOU3vZ7dIPzMDb.jpg'),
(131163, 9349, 'Reu [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lnfOis0UDcDcRZOU3vZ7dIPzMDb.jpg'),
(131164, 9349, 'Reu [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lnfOis0UDcDcRZOU3vZ7dIPzMDb.jpg'),
(131165, 9349, 'Reu [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lnfOis0UDcDcRZOU3vZ7dIPzMDb.jpg'),
(131166, 9349, 'Reu [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lnfOis0UDcDcRZOU3vZ7dIPzMDb.jpg'),
(131167, 9349, 'Reu [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lnfOis0UDcDcRZOU3vZ7dIPzMDb.jpg'),
(131168, 9349, 'Reu [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lnfOis0UDcDcRZOU3vZ7dIPzMDb.jpg'),
(131169, 9349, 'Reu [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lnfOis0UDcDcRZOU3vZ7dIPzMDb.jpg'),
(131170, 9349, 'Reu [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lnfOis0UDcDcRZOU3vZ7dIPzMDb.jpg'),
(131171, 9349, 'Reu [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lnfOis0UDcDcRZOU3vZ7dIPzMDb.jpg'),
(131172, 9349, 'Reu [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lnfOis0UDcDcRZOU3vZ7dIPzMDb.jpg'),
(131173, 9349, 'Reu [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lnfOis0UDcDcRZOU3vZ7dIPzMDb.jpg'),
(131174, 9349, 'Reu [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lnfOis0UDcDcRZOU3vZ7dIPzMDb.jpg'),
(131175, 9349, 'Reu [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lnfOis0UDcDcRZOU3vZ7dIPzMDb.jpg'),
(131176, 9349, 'Reu [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lnfOis0UDcDcRZOU3vZ7dIPzMDb.jpg'),
(131177, 9349, 'Reu [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lnfOis0UDcDcRZOU3vZ7dIPzMDb.jpg'),
(131178, 9349, 'Reu [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lnfOis0UDcDcRZOU3vZ7dIPzMDb.jpg'),
(131179, 9350, 'Seiken Gakuin no Makentsukai [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rKd3NJblRLfrLb7I0VV2TkK640f.jpg'),
(131180, 9350, 'Seiken Gakuin no Makentsukai [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gcW7pCHa56hKXQTdq4pIHCbEjL3.jpg'),
(131181, 9350, 'Seiken Gakuin no Makentsukai [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tDprIn6g5YJxnaiJ3FHmxtxnyI8.jpg'),
(131182, 9350, 'Seiken Gakuin no Makentsukai [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rcDF5aBr9kBj1Hf2IScxOn8mUPc.jpg'),
(131183, 9350, 'Seiken Gakuin no Makentsukai [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1at7bB1NWwG7yHwUrPkLbDHEcIr.jpg'),
(131184, 9350, 'Seiken Gakuin no Makentsukai [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mRzOS4qikE72QIpo0OPIpzc99Vd.jpg'),
(131185, 9350, 'Seiken Gakuin no Makentsukai [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i3Tw6mw6y85wnf8ToKerfcXnaa1.jpg'),
(131186, 9350, 'Seiken Gakuin no Makentsukai [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zPCzTBrmnlfpwbmorDzFqRDSnPN.jpg'),
(131187, 9350, 'Seiken Gakuin no Makentsukai [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mPDLNAzc3RBRD7Xe4tHoFGnKuZR.jpg'),
(131188, 9351, 'Sonata de Inverno [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ex2HXbNRyOlhV3DxrSXR5FCOoA.jpg'),
(131189, 9351, 'Sonata de Inverno [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w6eFh8Lq2kZGW8uBoNDaEP6GVdn.jpg'),
(131190, 9351, 'Sonata de Inverno [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aR3wV3f3Nu9FfiY4Z6lCX0IS2ua.jpg'),
(131191, 9351, 'Sonata de Inverno [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cuwiIx7dY4KTHOx60EQjFGwdxbK.jpg'),
(131192, 9351, 'Sonata de Inverno [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hcqXqAd0TyG5M1DggXADzDxLRQm.jpg'),
(131193, 9351, 'Sonata de Inverno [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gp2UoZpcD8s1D2P1LufnKKEztOv.jpg'),
(131194, 9351, 'Sonata de Inverno [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTNwtKbgbpNqkk0AcRxXvfxOYLz.jpg'),
(131195, 9351, 'Sonata de Inverno [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c9bdAd8yH9BCvLuZt314rn0aIJC.jpg'),
(131196, 9351, 'Sonata de Inverno [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3L0P7GFHrBdektWuJAuh3dnHx8K.jpg'),
(131197, 9351, 'Sonata de Inverno [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yq6TdNDOiJdjQBlvnFRpDeupzYK.jpg'),
(131198, 9351, 'Sonata de Inverno [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnhNOEYhEOLFxyUOmrNRQKdtQKx.jpg'),
(131199, 9351, 'Sonata de Inverno [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnhNOEYhEOLFxyUOmrNRQKdtQKx.jpg'),
(131200, 9351, 'Sonata de Inverno [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hjvV1OOZ3sD9S0JLoyuqRzjaRV.jpg'),
(131201, 9351, 'Sonata de Inverno [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rl6q7otdKHSdGwtWQh07m6ha5E.jpg'),
(131202, 9351, 'Sonata de Inverno [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/efPbmaUUHKWASY7VFXDGdOWsmMK.jpg'),
(131203, 9351, 'Sonata de Inverno [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z5lyTVdpt3PzcN489yt7ChOQkj2.jpg'),
(131204, 9351, 'Sonata de Inverno [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n20c7ilfOuIYzev5ZpFqdHVTlNl.jpg'),
(131205, 9351, 'Sonata de Inverno [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gYGhpN9x32hJNeENDm1S1BAws0x.jpg'),
(131206, 9351, 'Sonata de Inverno [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f8TQSwu5UO1a4LRoBpwjxYrqXwT.jpg'),
(131207, 9351, 'Sonata de Inverno [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jErdaWzweAey17mYErCDLX01gz6.jpg'),
(131208, 9352, 'TSUKIMICHI Moonlit Fantasy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zw21ulawI2xjBbyUrsTbEU9bKDD.jpg'),
(131209, 9352, 'TSUKIMICHI Moonlit Fantasy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZmhrXhl2LNZmns1fXG3aao6FCR.jpg'),
(131210, 9352, 'TSUKIMICHI Moonlit Fantasy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jNTQHpQrZSKSxESMAuAQZ4U5uav.jpg'),
(131211, 9352, 'TSUKIMICHI Moonlit Fantasy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6cGpr8NWl0oBXJjuhdFTddbmv6a.jpg'),
(131212, 9352, 'TSUKIMICHI Moonlit Fantasy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kojoqUmD4NDzhuXaUEUz8UhgeK3.jpg'),
(131213, 9352, 'TSUKIMICHI Moonlit Fantasy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9OkSps4eGuntx1e6GZtQ0vF5whM.jpg'),
(131214, 9352, 'TSUKIMICHI Moonlit Fantasy S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/acQhdkyDknwHmP6OzfvN14kPucD.jpg'),
(131215, 9352, 'TSUKIMICHI Moonlit Fantasy S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jJIygE3kYQmE50UEgBu2IFcsdtd.jpg'),
(131216, 9352, 'TSUKIMICHI Moonlit Fantasy S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1GXgJpLvpWwidVFAjXJdMKG3WMh.jpg'),
(131217, 9352, 'TSUKIMICHI Moonlit Fantasy S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tddj0cjLtCY3YQSrtf36SwxheX3.jpg'),
(131218, 9352, 'TSUKIMICHI Moonlit Fantasy S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyQMXauyiF767uWHG0K2gH5ccrq.jpg'),
(131219, 9352, 'TSUKIMICHI Moonlit Fantasy S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/labur9NDw5fUgsnFkEOhX1MNbZP.jpg'),
(131220, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131221, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/270810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131222, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/272529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131223, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/277552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131224, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/293973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131225, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/293974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131226, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/299058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131227, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/303906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131228, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/309601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131229, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/317137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131230, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/323498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131231, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/327520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131232, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/335812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131233, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/339970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131234, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/351288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131235, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/351289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131236, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/358624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131237, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/611901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131238, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/372938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131239, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/383998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131240, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/388495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131241, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/394133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131242, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/400264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131243, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/404121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131244, 9353, 'TSUKIMICHI Moonlit Fantasy S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/411321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(131245, 9354, 'Voce e o que Voce Come As Dietas dos Gemeos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4kzMTHYaZTmjU3rkkUK7A5oFJ0F.jpg'),
(131246, 9354, 'Voce e o que Voce Come As Dietas dos Gemeos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/95fO1tqyEuWedMS1LB0wjZIO4Da.jpg'),
(131247, 9354, 'Voce e o que Voce Come As Dietas dos Gemeos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hnT5znHQVIQCPoREhyUbGkearSK.jpg'),
(131248, 9354, 'Voce e o que Voce Come As Dietas dos Gemeos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9hfQGfHxsrrYxC4jRkkLKjRmPCH.jpg'),
(131249, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qEclvbcqLvlyngRplBY4rRMdawh.jpg'),
(131250, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2UfqgNL6IMv47bNd1ox2jUPCw0o.jpg'),
(131251, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/unF67oWaxWfmY0miyZIpYtsKyrS.jpg'),
(131252, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1GQeJjI5vWtt1EdGrstKYJhNYi2.jpg'),
(131253, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gOQSqvda0nZlhgdv8qN0E4tHHk.jpg'),
(131254, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCQIRa1N4yxniRHZlQhBQ8pOxFL.jpg'),
(131255, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cvAuaGFkLmk2IUjxA2irqnzKk9p.jpg'),
(131256, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ONm6dyY2A82zxT6JEpaOUE0W9J.jpg'),
(131257, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9GfPDqetDhS8DU3naXk9L7bAFlF.jpg'),
(131258, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9g4HmRwU9i10Ud2PtpUsY50ITp0.jpg'),
(131259, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1kDeqPVoknTTZndHJM4fcY6yEap.jpg'),
(131260, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZRYmac0yMGq5Sge70m2qw4NavV.jpg'),
(131261, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6sSE2tK6XoUcTxAok7F5mGsXvOP.jpg'),
(131262, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/254985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jczZNxQIGmHEZKGjCYOYHBXGwDH.jpg'),
(131263, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/254986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z8KYotN8tqsLnsmS0zxOKG8ZEFj.jpg'),
(131264, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/254987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4kgTzqNRVzA67BQO3Zm8AVQmpT0.jpg'),
(131265, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/254988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/umzSEbxf0gTgkIWmaztYdApbaHD.jpg'),
(131266, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/254989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t9SgjKdJ0nuHSf8sJ2sFFQZW5MH.jpg'),
(131267, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/254990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yCY9rvyk5QNDxYAx4zGcNPcxxxd.jpg'),
(131268, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/254991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iNCq64ISH5SYN2F1rIQMNBjQi4K.jpg'),
(131269, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/254992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/usZFr7jok06JVnmkQsA8tJaCQyJ.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(131270, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/254993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vlIR3dJgXQr9SsQkZfR0QclexqH.jpg'),
(131271, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/254994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/15MOFVUIBN8skxvrU97lZqPqXqR.jpg'),
(131272, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/254995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rrIxg609V2SAL6OuwS8D0PBxwG.jpg'),
(131273, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/254996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c75XHOp36NJ6TxZlIpzkkgzWRuj.jpg'),
(131274, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/254997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/psIVtLlVnY7AYgIsq8wGz3PZNZs.jpg'),
(131275, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/254998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OhNTZyytd35KtcLehUPFX1UjXw.jpg'),
(131276, 9355, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/254999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u1NyBHUbFx6dZtHtBx4RGYj50KP.jpg'),
(131277, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/255000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xiCuwcHweRoXzN6r4VgkLCGT7vM.jpg'),
(131278, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/255001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHTqD8NH2hY4UDpznW97c1na0ZK.jpg'),
(131279, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/255002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nIyAsatzf8bZfOVajQdyf7AuutB.jpg'),
(131280, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/255003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4dnAqs6X2w6egzdciLePDNhxpbj.jpg'),
(131281, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/255004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2cJKwSRfyc54tzMifmrWOKJuc5p.jpg'),
(131282, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/255005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9yDERYWWeUayiCXDi5jjm1FqboY.jpg'),
(131283, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/255006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNiDuYWsbemqU1N9IRd3U8A4Sld.jpg'),
(131284, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/255007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1Sh28IgeRNdWnfEfu8XdVHH7GH.jpg'),
(131285, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/255008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hlJp3WVJeF4vzfpnrAoEK7ww0Pm.jpg'),
(131286, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/255009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTzfEsXHxehFPWlaOpphP5ByEoq.jpg'),
(131287, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/255010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pPo0sTC9ZGBUtKPykuXPXxNL3oo.jpg'),
(131288, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/255011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yk6Z4S6PeDYURZKiT3TBaZsanxb.jpg'),
(131289, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/255012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vX3jZespnFfhfhJixjhaiR9kgdO.jpg'),
(131290, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/255013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9eJhZIWqZT6233VAO9AKiiwCzd0.jpg'),
(131291, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/255014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pHypYRgEZQJ7oUHlmLNxoH7Wptw.jpg'),
(131292, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/255015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cq7heB0wgJCwu5Hz1bFTIcKJq5X.jpg'),
(131293, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/255016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v3kgkC2InRY1RWPfL5fK8IskA8i.jpg'),
(131294, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/255017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1GtQ6WP8uGy2E2hYEtImHHms9Yz.jpg'),
(131295, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/255018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h4CxsgfEqtSlH4gaiMRzFUpUnJV.jpg'),
(131296, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/255019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bjTNj3fY0TWjEt970pmKeTTIlXB.jpg'),
(131297, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/255020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pSC0QuziItqfBUgA21GrtnZjQ4J.jpg'),
(131298, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/255021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9CUC50UPjxA5UnIILsQmupyidy.jpg'),
(131299, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/255022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yrtB9eSz2JBbZbR5dm22jWAy44U.jpg'),
(131300, 9356, '8 Regrinhas Basicas... para Namorar Minhas Filhas Adolescentes S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/255023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rImCIyPTiHvTwsG3dSHG7eqIk26.jpg'),
(131301, 9357, 'Amnesia [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tuIlkOoNXBNHXp7leLmgxopgYIb.jpg'),
(131302, 9357, 'Amnesia [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/faINFsQspHsnF7nQg7nrQymbBtq.jpg'),
(131303, 9357, 'Amnesia [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Ge8LRDmMX8Jhojwwq9Z7mD1KuS.jpg'),
(131304, 9357, 'Amnesia [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vlZdhuBwwuiytOnq051PSo3XLSY.jpg'),
(131305, 9357, 'Amnesia [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A0yfhJdaFOcfW4BHIDnM13aRXj6.jpg'),
(131306, 9357, 'Amnesia [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cV4eDYyUfb9l39OvrJ9qn4B9vpk.jpg'),
(131307, 9357, 'Amnesia [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/69qFOz1LAQxaQPAEJgEZWuGUG1Z.jpg'),
(131308, 9357, 'Amnesia [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9C7k7vNWG9Dua2TXOOwHDGU6eRe.jpg'),
(131309, 9357, 'Amnesia [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4n5UwSjpASYDg2c6eq3vwlQTsSP.jpg'),
(131310, 9357, 'Amnesia [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hiBDmKPC0vXxYCcpc12bAw4Chwc.jpg'),
(131311, 9357, 'Amnesia [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kgS6hdcjNhkKnBXDbxf55TQAHcY.jpg'),
(131312, 9357, 'Amnesia [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cnKKOwM4KVfIZIkPTcecQlrXGTk.jpg'),
(131313, 9358, 'Btooom [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOoET4slVVKa8F90LTjgopzkItL.jpg'),
(131314, 9358, 'Btooom [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vk9gn3zGsh5wBnbPYCofv9esrCT.jpg'),
(131315, 9358, 'Btooom [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pbi0bpG0N792RdmSf9lttvX5hM7.jpg'),
(131316, 9358, 'Btooom [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/stsIGOSu9hoDziXtxqiTu9WT8Iq.jpg'),
(131317, 9358, 'Btooom [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bKgPR5Beo84ay4GtOIdo1aQFsTD.jpg'),
(131318, 9358, 'Btooom [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nylAqky3CbPxIs8m0KCwA7YU2Kr.jpg'),
(131319, 9358, 'Btooom [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/532txgDRP5eDG5P8xxcXK7Fb49X.jpg'),
(131320, 9358, 'Btooom [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tmJPQcIhC1aMMutXO0v0CmGvyGa.jpg'),
(131321, 9358, 'Btooom [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uAo74aiMNnTQJUfYOjCvhN6nLOm.jpg'),
(131322, 9358, 'Btooom [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k7etUJDSmR1cPnIoDbrFbZobxls.jpg'),
(131323, 9358, 'Btooom [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d4np13l7nJ18Rxe4gctqLRqYu5P.jpg'),
(131324, 9358, 'Btooom [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/80TAhVhGO8i7zPnq30HTidAThRT.jpg'),
(131325, 9359, 'Entre Ele e Ela [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Ajedqd1o9ZGx0GYTkx4rn3TtE3.jpg'),
(131326, 9359, 'Entre Ele e Ela [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wWR34nUZ7QxwlAQf06k9Wc7X0yg.jpg'),
(131327, 9359, 'Entre Ele e Ela [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z3aeuHaa97FBTy2BKY242Dfrgy6.jpg'),
(131328, 9359, 'Entre Ele e Ela [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z3aeuHaa97FBTy2BKY242Dfrgy6.jpg'),
(131329, 9359, 'Entre Ele e Ela [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z3aeuHaa97FBTy2BKY242Dfrgy6.jpg'),
(131330, 9359, 'Entre Ele e Ela [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z3aeuHaa97FBTy2BKY242Dfrgy6.jpg'),
(131331, 9359, 'Entre Ele e Ela [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z3aeuHaa97FBTy2BKY242Dfrgy6.jpg'),
(131332, 9359, 'Entre Ele e Ela [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/276649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z3aeuHaa97FBTy2BKY242Dfrgy6.jpg'),
(131333, 9359, 'Entre Ele e Ela [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/281207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z3aeuHaa97FBTy2BKY242Dfrgy6.jpg'),
(131334, 9359, 'Entre Ele e Ela [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/287505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z3aeuHaa97FBTy2BKY242Dfrgy6.jpg'),
(131335, 9359, 'Entre Ele e Ela [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/295566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z3aeuHaa97FBTy2BKY242Dfrgy6.jpg'),
(131336, 9359, 'Entre Ele e Ela [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/302792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z3aeuHaa97FBTy2BKY242Dfrgy6.jpg'),
(131337, 9360, 'George O Curioso S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7XB9wteRi9XEqROISQAp887tmr9.jpg'),
(131338, 9360, 'George O Curioso S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yKocBKotWvEvqFddnzNaMlqNGEf.jpg'),
(131339, 9360, 'George O Curioso S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shJvYuAOv3l9rlpQ0ik5dFKUlyv.jpg'),
(131340, 9360, 'George O Curioso S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mMPvH6suNjAVFWqx7BOwEyodNEO.jpg'),
(131341, 9360, 'George O Curioso S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nae04FDAAz2Cgg2g5JczcE57tJ.jpg'),
(131342, 9360, 'George O Curioso S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ue99cx9lkAo6jvXg8mvLdsM9Urx.jpg'),
(131343, 9361, 'George O Curioso S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131344, 9361, 'George O Curioso S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131345, 9361, 'George O Curioso S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131346, 9361, 'George O Curioso S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131347, 9361, 'George O Curioso S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131348, 9361, 'George O Curioso S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131349, 9362, 'George O Curioso S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3cLhD6EClyQ5rWmlctSmPJYaqR.jpg'),
(131350, 9362, 'George O Curioso S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4zeL6CP8Xj8XFyjvCV5xuyME8RN.jpg'),
(131351, 9362, 'George O Curioso S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/esBAmYAd5xyXgJ4VgLsdEyeNeOJ.jpg'),
(131352, 9362, 'George O Curioso S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hAiZZqSAlgr5uBBOrpim61e1TR6.jpg'),
(131353, 9362, 'George O Curioso S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131354, 9362, 'George O Curioso S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131355, 9363, 'George O Curioso S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131356, 9363, 'George O Curioso S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131357, 9363, 'George O Curioso S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131358, 9363, 'George O Curioso S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131359, 9363, 'George O Curioso S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131360, 9363, 'George O Curioso S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131361, 9363, 'George O Curioso S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131362, 9363, 'George O Curioso S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131363, 9363, 'George O Curioso S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131364, 9363, 'George O Curioso S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131365, 9363, 'George O Curioso S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131366, 9363, 'George O Curioso S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131367, 9363, 'George O Curioso S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131368, 9363, 'George O Curioso S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/254916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131369, 9363, 'George O Curioso S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/254917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131370, 9364, 'George O Curioso S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131371, 9364, 'George O Curioso S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131372, 9364, 'George O Curioso S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131373, 9364, 'George O Curioso S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131374, 9364, 'George O Curioso S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131375, 9364, 'George O Curioso S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131376, 9364, 'George O Curioso S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131377, 9364, 'George O Curioso S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131378, 9364, 'George O Curioso S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131379, 9364, 'George O Curioso S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131380, 9364, 'George O Curioso S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131381, 9364, 'George O Curioso S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131382, 9364, 'George O Curioso S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131383, 9364, 'George O Curioso S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/254931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131384, 9364, 'George O Curioso S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/254932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131385, 9365, 'George O Curioso S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131386, 9365, 'George O Curioso S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131387, 9365, 'George O Curioso S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131388, 9365, 'George O Curioso S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131389, 9365, 'George O Curioso S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131390, 9365, 'George O Curioso S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131391, 9365, 'George O Curioso S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131392, 9365, 'George O Curioso S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131393, 9365, 'George O Curioso S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131394, 9365, 'George O Curioso S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131395, 9365, 'George O Curioso S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131396, 9365, 'George O Curioso S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131397, 9365, 'George O Curioso S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131398, 9365, 'George O Curioso S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/254946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131399, 9365, 'George O Curioso S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/254947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AWQF9ZP7X5GqGUoXnyj1NSQjKo.jpg'),
(131400, 9366, 'Intimidade Fatal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eJ19kVd5qZXaGq3f255EisnXXyc.jpg'),
(131401, 9366, 'Intimidade Fatal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eJ19kVd5qZXaGq3f255EisnXXyc.jpg'),
(131402, 9366, 'Intimidade Fatal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eJ19kVd5qZXaGq3f255EisnXXyc.jpg'),
(131403, 9366, 'Intimidade Fatal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eJ19kVd5qZXaGq3f255EisnXXyc.jpg'),
(131404, 9366, 'Intimidade Fatal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eJ19kVd5qZXaGq3f255EisnXXyc.jpg'),
(131405, 9366, 'Intimidade Fatal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eJ19kVd5qZXaGq3f255EisnXXyc.jpg'),
(131406, 9367, 'O Preco do Silencio [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBTVv3Qx7MjSZB78KPBsavPMMHs.jpg'),
(131407, 9368, 'Shaking the Bar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nF11piY4ViIC1rY1GCkvnDvq8bh.jpg'),
(131408, 9368, 'Shaking the Bar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nF11piY4ViIC1rY1GCkvnDvq8bh.jpg'),
(131409, 9368, 'Shaking the Bar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nF11piY4ViIC1rY1GCkvnDvq8bh.jpg'),
(131410, 9368, 'Shaking the Bar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nF11piY4ViIC1rY1GCkvnDvq8bh.jpg'),
(131411, 9368, 'Shaking the Bar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nF11piY4ViIC1rY1GCkvnDvq8bh.jpg'),
(131412, 9368, 'Shaking the Bar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nF11piY4ViIC1rY1GCkvnDvq8bh.jpg'),
(131413, 9368, 'Shaking the Bar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nF11piY4ViIC1rY1GCkvnDvq8bh.jpg'),
(131414, 9368, 'Shaking the Bar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nF11piY4ViIC1rY1GCkvnDvq8bh.jpg'),
(131415, 9368, 'Shaking the Bar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nF11piY4ViIC1rY1GCkvnDvq8bh.jpg'),
(131416, 9368, 'Shaking the Bar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nF11piY4ViIC1rY1GCkvnDvq8bh.jpg'),
(131417, 9369, 'Yamishibai Japanese Ghost Stories S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yCvGoIZThtlzvDbPpogLAIb8DU7.jpg'),
(131418, 9369, 'Yamishibai Japanese Ghost Stories S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ju2zjTjD4FrSX7WtNUJD18J80mL.jpg'),
(131419, 9369, 'Yamishibai Japanese Ghost Stories S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aNlNIhgdvwjlQeW04ntZKO650eW.jpg'),
(131420, 9369, 'Yamishibai Japanese Ghost Stories S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b2WNhBohPY1jpU5ILeHSNc3Mx4O.jpg'),
(131421, 9369, 'Yamishibai Japanese Ghost Stories S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m0zd7oeIBntXAPs9O3BmJT3sxYJ.jpg'),
(131422, 9369, 'Yamishibai Japanese Ghost Stories S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dwEMxUVI0lA8vGMUQgl8zZBP7ev.jpg'),
(131423, 9369, 'Yamishibai Japanese Ghost Stories S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qB3Pj3v9UCiDpFZa9F7VY7SshvI.jpg'),
(131424, 9369, 'Yamishibai Japanese Ghost Stories S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uxeD1n9G9aP1evw4TnlhIY5bDT7.jpg'),
(131425, 9369, 'Yamishibai Japanese Ghost Stories S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t3KhdJKWjdrefF0p6IRojHcWff7.jpg'),
(131426, 9369, 'Yamishibai Japanese Ghost Stories S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uMuopu4DNF8MHVU6kCFzyuOZ1qC.jpg'),
(131427, 9369, 'Yamishibai Japanese Ghost Stories S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cCDZhCTJgU64zx1xGAckVF3uG3R.jpg'),
(131428, 9369, 'Yamishibai Japanese Ghost Stories S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kTfIXYarAXz8tMVBzfGOIgem6VV.jpg'),
(131429, 9369, 'Yamishibai Japanese Ghost Stories S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1tjmqaa7IdDeBureqUqZOD8OoR5.jpg'),
(131430, 9370, 'Yamishibai Japanese Ghost Stories S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wi6NLEneJNsFKkeiarn20O3eZ6z.jpg'),
(131431, 9370, 'Yamishibai Japanese Ghost Stories S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AlW8LzMp87PrWFRzTze1yk5TT2b.jpg'),
(131432, 9370, 'Yamishibai Japanese Ghost Stories S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Q3vKVTTZ7HPdTuIHRqheI4kIos.jpg'),
(131433, 9370, 'Yamishibai Japanese Ghost Stories S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/IqjwW2ahTMparsjWuUADQfbuY9.jpg'),
(131434, 9370, 'Yamishibai Japanese Ghost Stories S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tD5gYnttH2EXoHsU5XVYbuparjQ.jpg'),
(131435, 9370, 'Yamishibai Japanese Ghost Stories S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Uyr9vZLxj66dJmk3gFci4mE3wA.jpg'),
(131436, 9370, 'Yamishibai Japanese Ghost Stories S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uotBuM1uWeElHgbcti3ci9N1VLQ.jpg'),
(131437, 9370, 'Yamishibai Japanese Ghost Stories S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7dlKMPwBtpZB83BED9fBk4FXmIm.jpg'),
(131438, 9370, 'Yamishibai Japanese Ghost Stories S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nOMe47mveB9ioc1DLCsLLIDgJFk.jpg'),
(131439, 9370, 'Yamishibai Japanese Ghost Stories S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ag4JxNxdhANTAuB0lfrdFIjR6Ai.jpg'),
(131440, 9370, 'Yamishibai Japanese Ghost Stories S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hWuURDWyF3OAWxb0RnXFbWV49Mh.jpg'),
(131441, 9370, 'Yamishibai Japanese Ghost Stories S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r0sgMhApsshRg1PkU0PUi3Z9ZPd.jpg'),
(131442, 9370, 'Yamishibai Japanese Ghost Stories S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i2Xt4jpPgq8jEps2TO0DhjTay2c.jpg'),
(131443, 9371, 'Yamishibai Japanese Ghost Stories S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vuYkpKhAcp94wgAlrUbxVaxESqG.jpg'),
(131444, 9371, 'Yamishibai Japanese Ghost Stories S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/EtJS2V0wv3X9ys8n2XNMqIVxEZ.jpg'),
(131445, 9371, 'Yamishibai Japanese Ghost Stories S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iwIClAb3vqk3g8Rl1M8s6ytBblX.jpg'),
(131446, 9371, 'Yamishibai Japanese Ghost Stories S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2EhHg9Lx19MS2HVayi4agdVrj8p.jpg'),
(131447, 9371, 'Yamishibai Japanese Ghost Stories S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ulUxJJdbYL9xsVyiA0Z3QuUJdGb.jpg'),
(131448, 9371, 'Yamishibai Japanese Ghost Stories S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gHojZFldBi2LlUG1BTtXA8WzXWh.jpg'),
(131449, 9371, 'Yamishibai Japanese Ghost Stories S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4xVdw1PLLfemOQrOAJdqKptHabc.jpg'),
(131450, 9371, 'Yamishibai Japanese Ghost Stories S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uYTbCIL90ngUojFvAZSywe1JU5j.jpg'),
(131451, 9371, 'Yamishibai Japanese Ghost Stories S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zFyQ8QdF9CWQp7TzK4s788nFbUD.jpg'),
(131452, 9371, 'Yamishibai Japanese Ghost Stories S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d6Wj7tAHbFQPHTtxsI70ISkz4cl.jpg'),
(131453, 9371, 'Yamishibai Japanese Ghost Stories S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6GjEcfEkmXZSyon6iuxGYpCzpE3.jpg'),
(131454, 9371, 'Yamishibai Japanese Ghost Stories S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jO2nu7MIDCvF6yMnNa39gQSFmwe.jpg'),
(131455, 9371, 'Yamishibai Japanese Ghost Stories S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ewReMd45SDt0tnjYWAaX9CI0DsP.jpg'),
(131456, 9372, 'Yamishibai Japanese Ghost Stories S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4OksoH7yuURoYho5FxvwmMWyvX4.jpg'),
(131457, 9372, 'Yamishibai Japanese Ghost Stories S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2xqdc1EKa5PMxCAmUOUxoV9ihQH.jpg'),
(131458, 9372, 'Yamishibai Japanese Ghost Stories S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zNVyUCd2D2SOvAeDCS578L7hazw.jpg'),
(131459, 9372, 'Yamishibai Japanese Ghost Stories S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ex3iISo8Jl2wb0JO1c20m955UbM.jpg'),
(131460, 9372, 'Yamishibai Japanese Ghost Stories S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qKJZPa538d7TXR0er3yC9t3Y9si.jpg'),
(131461, 9372, 'Yamishibai Japanese Ghost Stories S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v48ftdjkVvNs42QdYOv8iOIqyAh.jpg'),
(131462, 9372, 'Yamishibai Japanese Ghost Stories S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ysgnpDiSPWK6ODr6hKQKyzCBUan.jpg'),
(131463, 9372, 'Yamishibai Japanese Ghost Stories S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jHvxcx13vkzIsMSDmdQfhme8zQe.jpg'),
(131464, 9372, 'Yamishibai Japanese Ghost Stories S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/MxCf2sjGsIMKA87V7feJVgfuRf.jpg'),
(131465, 9372, 'Yamishibai Japanese Ghost Stories S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l7lmSLhc0o7q98TEmONTdXIeaGx.jpg'),
(131466, 9372, 'Yamishibai Japanese Ghost Stories S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/savHr4oImOReOcUpD1xuXCsUpCO.jpg'),
(131467, 9372, 'Yamishibai Japanese Ghost Stories S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ZQRP51lJpY6pn3vKsSb9UbPy50.jpg'),
(131468, 9372, 'Yamishibai Japanese Ghost Stories S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wcj9xMaMolstdrrb9TT0G7wUE2e.jpg'),
(131469, 9373, 'Yamishibai Japanese Ghost Stories S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zQ2obiZNThPyUz0c3fXzOfsy5aA.jpg'),
(131470, 9373, 'Yamishibai Japanese Ghost Stories S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ht5oO9b0m3QXtKuRrd641bijpEi.jpg'),
(131471, 9373, 'Yamishibai Japanese Ghost Stories S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zgHupbSc7WuBMWJk7mraHOOzya6.jpg'),
(131472, 9373, 'Yamishibai Japanese Ghost Stories S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/KxBprMsLdF7yxaoE4xdc8jeO6s.jpg'),
(131473, 9373, 'Yamishibai Japanese Ghost Stories S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1i6389EanTcz2s7rv0NIUyd6xa2.jpg'),
(131474, 9373, 'Yamishibai Japanese Ghost Stories S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2WDifSPW81yqZfYA26Do9rBBl3R.jpg'),
(131475, 9373, 'Yamishibai Japanese Ghost Stories S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bZ359R7HQIsqv4bSW8Xpckxtobw.jpg'),
(131476, 9373, 'Yamishibai Japanese Ghost Stories S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wSgtPbNL3Ncil3ZhpddYKyOI6zi.jpg'),
(131477, 9373, 'Yamishibai Japanese Ghost Stories S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3PC51v4ZNZ8uNkBu47GT7TKbKvG.jpg'),
(131478, 9373, 'Yamishibai Japanese Ghost Stories S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k6e4jqB1eXEPjqpSZTs0aAbHy8j.jpg'),
(131479, 9373, 'Yamishibai Japanese Ghost Stories S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6uMv1DL39HSzgxUixQQaFUBiBGM.jpg'),
(131480, 9373, 'Yamishibai Japanese Ghost Stories S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7JdaFbCgUU20sWfCdXj5lVtn2wI.jpg'),
(131481, 9373, 'Yamishibai Japanese Ghost Stories S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qnmvjOdM3sZ1ibgHnSBCWDV4JyF.jpg'),
(131482, 9374, 'Yamishibai Japanese Ghost Stories S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aTROD6keKCr4i76lDzE4Ivgi9Vr.jpg'),
(131483, 9374, 'Yamishibai Japanese Ghost Stories S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3YTYGahZNHMv0r484lNUXWO2h0a.jpg'),
(131484, 9374, 'Yamishibai Japanese Ghost Stories S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m52YTWZfokyGIs41hN1T4p5pjz2.jpg'),
(131485, 9374, 'Yamishibai Japanese Ghost Stories S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cu8KB8vtiBg7K1WLkApFsTtFPEK.jpg'),
(131486, 9374, 'Yamishibai Japanese Ghost Stories S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cg0iPEvsriDQkLqWKDAlH5hCAKS.jpg'),
(131487, 9374, 'Yamishibai Japanese Ghost Stories S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9kkSseimtBdvZWMRQKPbtLdO81E.jpg'),
(131488, 9374, 'Yamishibai Japanese Ghost Stories S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jUBruKljxirQQgEQK3TtM7bPaH2.jpg'),
(131489, 9374, 'Yamishibai Japanese Ghost Stories S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/55Y1HOhhcgJajjX1T98dZmofAVG.jpg'),
(131490, 9374, 'Yamishibai Japanese Ghost Stories S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mp5wu4AhbStOoHTQrysUsBT6qHF.jpg'),
(131491, 9374, 'Yamishibai Japanese Ghost Stories S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cQWaEes3aSD32kFIMwT8NxCiC79.jpg'),
(131492, 9374, 'Yamishibai Japanese Ghost Stories S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h4CsYjvX25vjdzZSMomNS7V4Dqj.jpg'),
(131493, 9374, 'Yamishibai Japanese Ghost Stories S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uhgQmzeN0ZpBVjyBZ0p1U8WfgUl.jpg'),
(131494, 9374, 'Yamishibai Japanese Ghost Stories S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aVsC8kewOHKtRfwtxyWzM2pqIFl.jpg'),
(131495, 9375, 'Yamishibai Japanese Ghost Stories S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dI0ZmPnq8nMHtfLJH4ADHDq8sqL.jpg'),
(131496, 9375, 'Yamishibai Japanese Ghost Stories S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/M72JuaYeKOwrKm75WyJpa8tVb1.jpg'),
(131497, 9375, 'Yamishibai Japanese Ghost Stories S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uSEtU94C8pqBirh5M4SqNT54y8T.jpg'),
(131498, 9375, 'Yamishibai Japanese Ghost Stories S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5zQPATdqMWyVj0tP0YONCqZIlpz.jpg'),
(131499, 9375, 'Yamishibai Japanese Ghost Stories S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJL3eMEEUvshTsyBmQsIHRLZqnz.jpg'),
(131500, 9375, 'Yamishibai Japanese Ghost Stories S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kii1gQRLDhefI3LkGbmQZhaLVK6.jpg'),
(131501, 9375, 'Yamishibai Japanese Ghost Stories S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3N2LeNDeGA3zcgTJ70y7NzIyjPi.jpg'),
(131502, 9375, 'Yamishibai Japanese Ghost Stories S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Y976TEd02UhlOznBPJhDzD5yr8.jpg'),
(131503, 9375, 'Yamishibai Japanese Ghost Stories S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y0vkLYr6ovTckChnnQfwELJeSsU.jpg'),
(131504, 9375, 'Yamishibai Japanese Ghost Stories S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gvYZZ4GkDCvRpjAXg2mg8sypQyT.jpg'),
(131505, 9375, 'Yamishibai Japanese Ghost Stories S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lXjFPeM1NMhA2MzRe1YnMZj984l.jpg'),
(131506, 9375, 'Yamishibai Japanese Ghost Stories S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sy5Q6KxccRPZYu8Rv4jXOOQFA4u.jpg'),
(131507, 9375, 'Yamishibai Japanese Ghost Stories S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h6icfYIfWIQK08vGM5RJoLVYSiD.jpg'),
(131508, 9376, 'Yamishibai Japanese Ghost Stories S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1NPxD2BuQ59YfGpISUWPuh2TAsJ.jpg'),
(131509, 9376, 'Yamishibai Japanese Ghost Stories S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cSk5OKOUp0tSsgMKzYfNnCofVfN.jpg'),
(131510, 9376, 'Yamishibai Japanese Ghost Stories S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7xQzaws9nncdBPJ7ROIxlVAxeb.jpg'),
(131511, 9376, 'Yamishibai Japanese Ghost Stories S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ziWoboMCY54HzshYyctVRjN2zYU.jpg'),
(131512, 9376, 'Yamishibai Japanese Ghost Stories S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1UBFLTSuetdEnbdS1UHlUQJQbtX.jpg'),
(131513, 9376, 'Yamishibai Japanese Ghost Stories S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nPrBtVD5OHFANS9UANg6ooSqzha.jpg'),
(131514, 9376, 'Yamishibai Japanese Ghost Stories S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ZXdjs3lgEaWiRfyfkhm7OW3u8p.jpg'),
(131515, 9376, 'Yamishibai Japanese Ghost Stories S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bu06a0UsRfbJLyQtKWiyVZUTkAv.jpg'),
(131516, 9376, 'Yamishibai Japanese Ghost Stories S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/R43U4B0w9oNIErelQtEyX7FMID.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(131517, 9376, 'Yamishibai Japanese Ghost Stories S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pPyBSEbLnUX7FpxePuHfDukfqcC.jpg'),
(131518, 9376, 'Yamishibai Japanese Ghost Stories S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w5ZPJ0ToZomK4Im7e4pEaPbaULb.jpg'),
(131519, 9376, 'Yamishibai Japanese Ghost Stories S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d5ozS27BeJDapXkwceu77xsAjdn.jpg'),
(131520, 9376, 'Yamishibai Japanese Ghost Stories S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/poHD793plNLLvwfkwqaSvYImxZC.jpg'),
(131521, 9377, 'Yamishibai Japanese Ghost Stories S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s2XsskJ36MCSxO1Q4XnDEW6UVWi.jpg'),
(131522, 9377, 'Yamishibai Japanese Ghost Stories S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wV3OgEsLZgwNTgJO7nvkuvJzDDZ.jpg'),
(131523, 9377, 'Yamishibai Japanese Ghost Stories S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l7YZxQCzm5LyEDMRjKjkfNJA2Ih.jpg'),
(131524, 9377, 'Yamishibai Japanese Ghost Stories S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9aCnEnDZRNghIkgEo9ae2UaIDPR.jpg'),
(131525, 9377, 'Yamishibai Japanese Ghost Stories S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1gSz8PfdEma7KjqToT2wA38Tb2d.jpg'),
(131526, 9377, 'Yamishibai Japanese Ghost Stories S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7mjljsfF1cmX9BQldApNMYRn2Na.jpg'),
(131527, 9377, 'Yamishibai Japanese Ghost Stories S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJ7eOJQeDKsQzuoeChrtxsomqVE.jpg'),
(131528, 9377, 'Yamishibai Japanese Ghost Stories S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gKvfV7iIc8PM8BdHFJZPVlZWzRx.jpg'),
(131529, 9377, 'Yamishibai Japanese Ghost Stories S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y8BfKdWJl2yrneJcPG5NOjmMRPa.jpg'),
(131530, 9377, 'Yamishibai Japanese Ghost Stories S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4QWFnJ0fkV2umoaq1RhNFogV4Z1.jpg'),
(131531, 9377, 'Yamishibai Japanese Ghost Stories S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uT4WAPC7c8W5r9oPtHo0bC0dFxA.jpg'),
(131532, 9377, 'Yamishibai Japanese Ghost Stories S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3XAdosVLvnqBbxkRI9NIS4FoiY4.jpg'),
(131533, 9377, 'Yamishibai Japanese Ghost Stories S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/LZSmGfSmXFmDP5ieTrPWiAc4YU.jpg'),
(131534, 9378, 'Buscando a Lua Cheia [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fEd6iSTWbPXWFpsRPhTlW1FuXhA.jpg'),
(131535, 9378, 'Buscando a Lua Cheia [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4XaPpHLAFAXw9T5et01T0cFsMWZ.jpg'),
(131536, 9378, 'Buscando a Lua Cheia [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nPqtWguQMy9WRauZe4PoRPvc3HZ.jpg'),
(131537, 9378, 'Buscando a Lua Cheia [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ttxzQdLGbv0nkU3s3MRIeR2aIU4.jpg'),
(131538, 9378, 'Buscando a Lua Cheia [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2aw7y9m3pdnBEArA6cjd0HL532y.jpg'),
(131539, 9378, 'Buscando a Lua Cheia [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/LODdU5ISUahzqfdHKpJuyKmyfB.jpg'),
(131540, 9378, 'Buscando a Lua Cheia [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vqT5gewHvK6kHBb5LLCOnokbrVx.jpg'),
(131541, 9378, 'Buscando a Lua Cheia [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tdGFGV3UWBQqLMP9jf1qIgXygTL.jpg'),
(131542, 9378, 'Buscando a Lua Cheia [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zmarKme7uB8VMBQyAyOIuTqxE8E.jpg'),
(131543, 9378, 'Buscando a Lua Cheia [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qNWRYziLDox1UfJGlxM5FfdQPxM.jpg'),
(131544, 9378, 'Buscando a Lua Cheia [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131545, 9378, 'Buscando a Lua Cheia [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131546, 9378, 'Buscando a Lua Cheia [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131547, 9378, 'Buscando a Lua Cheia [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/254631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131548, 9378, 'Buscando a Lua Cheia [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/254632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131549, 9378, 'Buscando a Lua Cheia [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/254633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131550, 9378, 'Buscando a Lua Cheia [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/254634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131551, 9378, 'Buscando a Lua Cheia [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/254635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131552, 9378, 'Buscando a Lua Cheia [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/254636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131553, 9378, 'Buscando a Lua Cheia [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/254637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131554, 9378, 'Buscando a Lua Cheia [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/254638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131555, 9378, 'Buscando a Lua Cheia [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/254639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131556, 9378, 'Buscando a Lua Cheia [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/254640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131557, 9378, 'Buscando a Lua Cheia [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/254641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131558, 9378, 'Buscando a Lua Cheia [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/254642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131559, 9378, 'Buscando a Lua Cheia [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/254643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131560, 9378, 'Buscando a Lua Cheia [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/254644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131561, 9378, 'Buscando a Lua Cheia [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/254645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131562, 9378, 'Buscando a Lua Cheia [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/254646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131563, 9378, 'Buscando a Lua Cheia [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/254647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131564, 9378, 'Buscando a Lua Cheia [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/254648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131565, 9378, 'Buscando a Lua Cheia [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/254649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131566, 9378, 'Buscando a Lua Cheia [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/254650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131567, 9378, 'Buscando a Lua Cheia [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/254651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131568, 9378, 'Buscando a Lua Cheia [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/254652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131569, 9378, 'Buscando a Lua Cheia [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/254653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131570, 9378, 'Buscando a Lua Cheia [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/254654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131571, 9378, 'Buscando a Lua Cheia [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/254655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131572, 9378, 'Buscando a Lua Cheia [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/254656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131573, 9378, 'Buscando a Lua Cheia [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/254657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131574, 9378, 'Buscando a Lua Cheia [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/254658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131575, 9378, 'Buscando a Lua Cheia [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/254659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131576, 9378, 'Buscando a Lua Cheia [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/254660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131577, 9378, 'Buscando a Lua Cheia [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/254661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131578, 9378, 'Buscando a Lua Cheia [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/254662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131579, 9378, 'Buscando a Lua Cheia [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/254663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131580, 9378, 'Buscando a Lua Cheia [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/254664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131581, 9378, 'Buscando a Lua Cheia [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/254665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131582, 9378, 'Buscando a Lua Cheia [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/254666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131583, 9378, 'Buscando a Lua Cheia [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/254667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131584, 9378, 'Buscando a Lua Cheia [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/254668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131585, 9378, 'Buscando a Lua Cheia [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/254669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131586, 9379, 'A Esposa do Meu Marido [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nVRML7uH6G8lFGfSGle83tj7h58.jpg'),
(131587, 9379, 'A Esposa do Meu Marido [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sdE9Hy22F65glApLVzjhLW6L20q.jpg'),
(131588, 9379, 'A Esposa do Meu Marido [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/21UVSO3lmwyiw1iXdMkFmfQ7Qob.jpg'),
(131589, 9379, 'A Esposa do Meu Marido [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/21UVSO3lmwyiw1iXdMkFmfQ7Qob.jpg'),
(131590, 9379, 'A Esposa do Meu Marido [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/21UVSO3lmwyiw1iXdMkFmfQ7Qob.jpg'),
(131591, 9379, 'A Esposa do Meu Marido [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/21UVSO3lmwyiw1iXdMkFmfQ7Qob.jpg'),
(131592, 9379, 'A Esposa do Meu Marido [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/21UVSO3lmwyiw1iXdMkFmfQ7Qob.jpg'),
(131593, 9379, 'A Esposa do Meu Marido [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/21UVSO3lmwyiw1iXdMkFmfQ7Qob.jpg'),
(131594, 9379, 'A Esposa do Meu Marido [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/21UVSO3lmwyiw1iXdMkFmfQ7Qob.jpg'),
(131595, 9379, 'A Esposa do Meu Marido [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/21UVSO3lmwyiw1iXdMkFmfQ7Qob.jpg'),
(131596, 9379, 'A Esposa do Meu Marido [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/273375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/21UVSO3lmwyiw1iXdMkFmfQ7Qob.jpg'),
(131597, 9379, 'A Esposa do Meu Marido [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/273376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/21UVSO3lmwyiw1iXdMkFmfQ7Qob.jpg'),
(131598, 9379, 'A Esposa do Meu Marido [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/273377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/21UVSO3lmwyiw1iXdMkFmfQ7Qob.jpg'),
(131599, 9379, 'A Esposa do Meu Marido [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/273378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/21UVSO3lmwyiw1iXdMkFmfQ7Qob.jpg'),
(131600, 9379, 'A Esposa do Meu Marido [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/274871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/21UVSO3lmwyiw1iXdMkFmfQ7Qob.jpg'),
(131601, 9379, 'A Esposa do Meu Marido [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/21UVSO3lmwyiw1iXdMkFmfQ7Qob.jpg'),
(131602, 9378, 'Buscando a Lua Cheia [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fEd6iSTWbPXWFpsRPhTlW1FuXhA.jpg'),
(131603, 9378, 'Buscando a Lua Cheia [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4XaPpHLAFAXw9T5et01T0cFsMWZ.jpg'),
(131604, 9378, 'Buscando a Lua Cheia [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nPqtWguQMy9WRauZe4PoRPvc3HZ.jpg'),
(131605, 9378, 'Buscando a Lua Cheia [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ttxzQdLGbv0nkU3s3MRIeR2aIU4.jpg'),
(131606, 9378, 'Buscando a Lua Cheia [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2aw7y9m3pdnBEArA6cjd0HL532y.jpg'),
(131607, 9378, 'Buscando a Lua Cheia [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/LODdU5ISUahzqfdHKpJuyKmyfB.jpg'),
(131608, 9378, 'Buscando a Lua Cheia [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vqT5gewHvK6kHBb5LLCOnokbrVx.jpg'),
(131609, 9378, 'Buscando a Lua Cheia [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tdGFGV3UWBQqLMP9jf1qIgXygTL.jpg'),
(131610, 9378, 'Buscando a Lua Cheia [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zmarKme7uB8VMBQyAyOIuTqxE8E.jpg'),
(131611, 9378, 'Buscando a Lua Cheia [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qNWRYziLDox1UfJGlxM5FfdQPxM.jpg'),
(131612, 9378, 'Buscando a Lua Cheia [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131613, 9378, 'Buscando a Lua Cheia [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131614, 9378, 'Buscando a Lua Cheia [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131615, 9378, 'Buscando a Lua Cheia [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/254579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131616, 9378, 'Buscando a Lua Cheia [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/254580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131617, 9378, 'Buscando a Lua Cheia [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/254581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131618, 9378, 'Buscando a Lua Cheia [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/254582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131619, 9378, 'Buscando a Lua Cheia [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/254583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131620, 9378, 'Buscando a Lua Cheia [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/254584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131621, 9378, 'Buscando a Lua Cheia [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/254585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131622, 9378, 'Buscando a Lua Cheia [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/254586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131623, 9378, 'Buscando a Lua Cheia [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/254587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131624, 9378, 'Buscando a Lua Cheia [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/254588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131625, 9378, 'Buscando a Lua Cheia [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/254589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131626, 9378, 'Buscando a Lua Cheia [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/254590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131627, 9378, 'Buscando a Lua Cheia [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/254591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131628, 9378, 'Buscando a Lua Cheia [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/254592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131629, 9378, 'Buscando a Lua Cheia [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/254593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131630, 9378, 'Buscando a Lua Cheia [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/254594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131631, 9378, 'Buscando a Lua Cheia [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/254595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131632, 9378, 'Buscando a Lua Cheia [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/254596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131633, 9378, 'Buscando a Lua Cheia [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/254597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131634, 9378, 'Buscando a Lua Cheia [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/254598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131635, 9378, 'Buscando a Lua Cheia [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/254599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131636, 9378, 'Buscando a Lua Cheia [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/254600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131637, 9378, 'Buscando a Lua Cheia [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/254601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131638, 9378, 'Buscando a Lua Cheia [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/254602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131639, 9378, 'Buscando a Lua Cheia [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/254603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131640, 9378, 'Buscando a Lua Cheia [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/254604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131641, 9378, 'Buscando a Lua Cheia [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/254605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131642, 9378, 'Buscando a Lua Cheia [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/254606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131643, 9378, 'Buscando a Lua Cheia [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/254607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131644, 9378, 'Buscando a Lua Cheia [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/254608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131645, 9378, 'Buscando a Lua Cheia [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/254609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131646, 9378, 'Buscando a Lua Cheia [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/254610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131647, 9378, 'Buscando a Lua Cheia [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/254611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131648, 9378, 'Buscando a Lua Cheia [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/254612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131649, 9378, 'Buscando a Lua Cheia [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/254613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131650, 9378, 'Buscando a Lua Cheia [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/254614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131651, 9378, 'Buscando a Lua Cheia [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/254615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131652, 9378, 'Buscando a Lua Cheia [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/254616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131653, 9378, 'Buscando a Lua Cheia [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/254617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AecYTAKiDXj8z2Sa1ccD5LDtzGm.jpg'),
(131654, 9380, 'Dr. Death [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rBi9d8BJdt6UdDyJ0MgnIYBoxTY.jpg'),
(131655, 9380, 'Dr. Death [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y0H5UtWqUtHbXiASmWEWoPQrmCa.jpg'),
(131656, 9380, 'Dr. Death [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/woCQD7xrMzbwT9JXOjPrnb0Ru9n.jpg'),
(131657, 9380, 'Dr. Death [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nVomvwPJdaA7yCH9LEt117wn16r.jpg'),
(131658, 9380, 'Dr. Death [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/10Ubvso4y1SPwCeeJvM55rNDBuE.jpg'),
(131659, 9380, 'Dr. Death [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bzg4p7jvbJElXfxzoI575PNmy3J.jpg'),
(131660, 9380, 'Dr. Death [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8anFWPJbe8ZuYREhunAa2VfeJg.jpg'),
(131661, 9380, 'Dr. Death [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sBvrxXY4jvTznrixP57EbcLCXP3.jpg'),
(131662, 9381, 'Dr. Death [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kyh0HuLux0VFCPGbPTwjT8ARQKG.jpg'),
(131663, 9381, 'Dr. Death [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d4xDAH4LpfdAEwHF1kAgO2FyZBB.jpg'),
(131664, 9381, 'Dr. Death [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8SPwXglQHRgf33gN1COFzQuLZAZ.jpg'),
(131665, 9381, 'Dr. Death [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vyHRAjgagfzwpaQ5zUU30feTSBH.jpg'),
(131666, 9381, 'Dr. Death [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qmY1fT7bDkbACVrUzjLhRV2eTNM.jpg'),
(131667, 9381, 'Dr. Death [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6F2JjQn5gXOiKTw3JeVWsU6U5yo.jpg'),
(131668, 9381, 'Dr. Death [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fxypFI7LJpJMtActg9PiEtr4RCl.jpg'),
(131669, 9381, 'Dr. Death [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tIi7Kmwg1sW5cLhUaX8jRdAh2k5.jpg'),
(131670, 9382, 'Money Flower [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131671, 9382, 'Money Flower [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131672, 9382, 'Money Flower [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131673, 9382, 'Money Flower [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131674, 9382, 'Money Flower [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131675, 9382, 'Money Flower [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131676, 9382, 'Money Flower [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131677, 9382, 'Money Flower [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131678, 9382, 'Money Flower [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131679, 9382, 'Money Flower [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131680, 9382, 'Money Flower [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131681, 9382, 'Money Flower [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131682, 9382, 'Money Flower [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131683, 9382, 'Money Flower [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131684, 9382, 'Money Flower [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131685, 9382, 'Money Flower [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131686, 9382, 'Money Flower [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131687, 9382, 'Money Flower [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131688, 9382, 'Money Flower [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131689, 9382, 'Money Flower [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131690, 9382, 'Money Flower [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131691, 9382, 'Money Flower [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131692, 9382, 'Money Flower [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/260387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131693, 9382, 'Money Flower [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/260388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8uVAyYAg5g6y1jhchT94hjI8EBz.jpg'),
(131694, 9383, 'My Happy End [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj2HjjwjnrkVH3xgehUF9VRsVv.jpg'),
(131695, 9383, 'My Happy End [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj2HjjwjnrkVH3xgehUF9VRsVv.jpg'),
(131696, 9384, 'ONIMAI Im Now Your Sister [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eGyqRy1cNAupsNZy87jdRniRaVz.jpg'),
(131697, 9384, 'ONIMAI Im Now Your Sister [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v2qTCMpnJicxtrD7XBTdi8WBldI.jpg'),
(131698, 9384, 'ONIMAI Im Now Your Sister [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/idcqxlP3RNGreQwrqCV8Kn9YZj5.jpg'),
(131699, 9384, 'ONIMAI Im Now Your Sister [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEQ3ench9CVdsSspbEemQTvxKfW.jpg'),
(131700, 9384, 'ONIMAI Im Now Your Sister [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nOkXezkBOtBSkKx6VPcdQKGrNoj.jpg'),
(131701, 9384, 'ONIMAI Im Now Your Sister [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cb3IC00w7i0veIJ9QOwV5xPyHzG.jpg'),
(131702, 9384, 'ONIMAI Im Now Your Sister [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/21oMlBNdxuoRs9ScrjkELi1OIZi.jpg'),
(131703, 9384, 'ONIMAI Im Now Your Sister [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/djvzQp3p1aZ6ZuzW5tlwql7ZmMl.jpg'),
(131704, 9384, 'ONIMAI Im Now Your Sister [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jRLv1zbezULAuCOf7AdZ0TsHnp7.jpg'),
(131705, 9384, 'ONIMAI Im Now Your Sister [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTGOcMfN5rSrTqSOPKgBz9u7xRz.jpg'),
(131706, 9384, 'ONIMAI Im Now Your Sister [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2M3jpJoMy64BJP1QQmJp72LawmN.jpg'),
(131707, 9384, 'ONIMAI Im Now Your Sister [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/plMG1RHV6GgsHC513Uqmgv32H7o.jpg'),
(131708, 9385, 'Orange Days [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/syvmXcDghCI3uezMDtOyP5b7vqz.jpg'),
(131709, 9385, 'Orange Days [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3hmoU1GD1bXRYMSYuWbtOR2TA7.jpg'),
(131710, 9385, 'Orange Days [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fVpN6uhLLgMclQEskuyGlmIcUIp.jpg'),
(131711, 9385, 'Orange Days [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDMZDLEY0nJ10y3NBhTOZ5e56E2.jpg'),
(131712, 9385, 'Orange Days [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3l8NqFXUNv3wG2VjhzRLiPGRGdp.jpg'),
(131713, 9385, 'Orange Days [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/envRbwoLcNNQVtKIsv9OQ1TokwB.jpg'),
(131714, 9385, 'Orange Days [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHU7rihf3d5SUr4szRjvssWRmUN.jpg'),
(131715, 9385, 'Orange Days [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gnV7hTwna3JqD9avUoGi8lf0L4s.jpg'),
(131716, 9385, 'Orange Days [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6b8y000MeR9hGFMGy7D24VW0Iai.jpg'),
(131717, 9385, 'Orange Days [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o1l1LzsiZNJHrEWteFOhT0OAE4h.jpg'),
(131718, 9385, 'Orange Days [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5VIZaai53DWBG6RYAIcUhoXk1TC.jpg'),
(131719, 9386, 'Oshi no Ko [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/588795.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rvy4W28wYkct3IFxU0RGF2uHppG.jpg'),
(131720, 9386, 'Oshi no Ko [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/588797.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/klFBxM7QHRtYvuqBcHGSoJaY5ES.jpg'),
(131721, 9386, 'Oshi no Ko [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/588799.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gRmEOAKLkF2qWUT0GB4QQcI2X1q.jpg'),
(131722, 9386, 'Oshi no Ko [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/588801.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h44DwOqXqq44KzNHOzkNpcTRVRR.jpg'),
(131723, 9386, 'Oshi no Ko [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/588803.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bmIyVqU5c5iw1g1S8ENY5bKpf4P.jpg'),
(131724, 9386, 'Oshi no Ko [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/588805.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dTnNfowpkkjSG8fxDprhHxJD465.jpg'),
(131725, 9386, 'Oshi no Ko [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/588807.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/culBlCRSAeAbCmOqw6QnCo0z7td.jpg'),
(131726, 9386, 'Oshi no Ko [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/588809.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7tOzcBf8qjQcnocGGadFAXAJOdq.jpg'),
(131727, 9386, 'Oshi no Ko [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/588811.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hGvzVPKuNBUThYsBlpxGMFkuueU.jpg'),
(131728, 9386, 'Oshi no Ko [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/588813.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aNYlFnW3TsubWgi3GphiBdI0WgZ.jpg'),
(131729, 9386, 'Oshi no Ko [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/588815.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rPjI9wOlKxzbfjiBjFDdjuKmkwt.jpg'),
(131730, 9386, 'Oshi no Ko [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ozJvrtYnLDz0wpOTx61Qs5t3ZEJ.jpg'),
(131731, 9386, 'Oshi no Ko [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ozJvrtYnLDz0wpOTx61Qs5t3ZEJ.jpg'),
(131732, 9386, 'Oshi no Ko [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/254538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ozJvrtYnLDz0wpOTx61Qs5t3ZEJ.jpg'),
(131733, 9386, 'Oshi no Ko [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/254539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ozJvrtYnLDz0wpOTx61Qs5t3ZEJ.jpg'),
(131734, 9386, 'Oshi no Ko [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/254540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ozJvrtYnLDz0wpOTx61Qs5t3ZEJ.jpg'),
(131735, 9387, 'Oshi no Ko [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/667898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ozJvrtYnLDz0wpOTx61Qs5t3ZEJ.jpg'),
(131736, 9387, 'Oshi no Ko [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/667899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ozJvrtYnLDz0wpOTx61Qs5t3ZEJ.jpg'),
(131737, 9387, 'Oshi no Ko [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/667900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ozJvrtYnLDz0wpOTx61Qs5t3ZEJ.jpg'),
(131738, 9387, 'Oshi no Ko [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/667901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ozJvrtYnLDz0wpOTx61Qs5t3ZEJ.jpg'),
(131739, 9387, 'Oshi no Ko [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/667902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ozJvrtYnLDz0wpOTx61Qs5t3ZEJ.jpg'),
(131740, 9387, 'Oshi no Ko [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/667903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ozJvrtYnLDz0wpOTx61Qs5t3ZEJ.jpg'),
(131741, 9387, 'Oshi no Ko [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/667904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ozJvrtYnLDz0wpOTx61Qs5t3ZEJ.jpg'),
(131742, 9387, 'Oshi no Ko [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/667905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ozJvrtYnLDz0wpOTx61Qs5t3ZEJ.jpg'),
(131743, 9387, 'Oshi no Ko [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/667906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ozJvrtYnLDz0wpOTx61Qs5t3ZEJ.jpg'),
(131744, 9387, 'Oshi no Ko [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/667907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ozJvrtYnLDz0wpOTx61Qs5t3ZEJ.jpg'),
(131745, 9387, 'Oshi no Ko [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/667908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ozJvrtYnLDz0wpOTx61Qs5t3ZEJ.jpg'),
(131746, 9387, 'Oshi no Ko [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/667909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ozJvrtYnLDz0wpOTx61Qs5t3ZEJ.jpg'),
(131747, 9387, 'Oshi no Ko [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/667910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ozJvrtYnLDz0wpOTx61Qs5t3ZEJ.jpg'),
(131748, 9388, 'Signal [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mIekNn9F8pBek9vy6rvIoiLih8r.jpg'),
(131749, 9388, 'Signal [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wXJXCx2HT4TnTrx38FKYTMVAFkP.jpg'),
(131750, 9388, 'Signal [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kNYRtAGuN8YDNNKSE8DZBWidJ2F.jpg'),
(131751, 9388, 'Signal [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2XSWGg1zox1aaFJE1gvJqaQZHdE.jpg'),
(131752, 9388, 'Signal [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oBf62LEucicmvt8VHrkqcDTI3c0.jpg'),
(131753, 9388, 'Signal [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pee18qWsHF1gMtfN4FcwLCdDogO.jpg'),
(131754, 9388, 'Signal [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9TRv5FQXLvOs9enASkvlmpyORrJ.jpg'),
(131755, 9388, 'Signal [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rbzomdKBSLWidF8hR4NsZc9LiXi.jpg'),
(131756, 9388, 'Signal [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r6FmMLjExX5nXVWtaKeWmAfvxgR.jpg'),
(131757, 9388, 'Signal [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ti4bxcoLrdcc57CfVbgHRwQfQQy.jpg'),
(131758, 9388, 'Signal [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zHIj9kTRxZxYeZllWo7OCCJvro0.jpg'),
(131759, 9388, 'Signal [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/av4LNpnWqDpHFI4BOPjY3PgwJdL.jpg'),
(131760, 9388, 'Signal [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uuVR6RalWrVFx2GcqsP6WPnM99x.jpg'),
(131761, 9388, 'Signal [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/254463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3uhS8lXJWvUKkO8xkIyocj6ENZq.jpg'),
(131762, 9388, 'Signal [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/254464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yKw6o57FgpaKJwSyfGVnKkeBbE9.jpg'),
(131763, 9388, 'Signal [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/254465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rdNICbxGftTShJJMEKwvg5HhgDh.jpg'),
(131764, 9389, 'Tokyo Revengers [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131765, 9389, 'Tokyo Revengers [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131766, 9389, 'Tokyo Revengers [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131767, 9389, 'Tokyo Revengers [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131768, 9389, 'Tokyo Revengers [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131769, 9389, 'Tokyo Revengers [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131770, 9389, 'Tokyo Revengers [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131771, 9389, 'Tokyo Revengers [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(131772, 9389, 'Tokyo Revengers [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131773, 9389, 'Tokyo Revengers [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131774, 9389, 'Tokyo Revengers [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131775, 9389, 'Tokyo Revengers [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131776, 9389, 'Tokyo Revengers [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131777, 9390, 'Tokyo Revengers [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131778, 9390, 'Tokyo Revengers [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131779, 9390, 'Tokyo Revengers [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131780, 9390, 'Tokyo Revengers [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131781, 9390, 'Tokyo Revengers [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131782, 9390, 'Tokyo Revengers [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131783, 9390, 'Tokyo Revengers [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131784, 9390, 'Tokyo Revengers [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131785, 9390, 'Tokyo Revengers [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131786, 9390, 'Tokyo Revengers [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131787, 9390, 'Tokyo Revengers [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131788, 9390, 'Tokyo Revengers [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131789, 9390, 'Tokyo Revengers [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XbjlgUJknGCv7cNuinxdaFUFNt.jpg'),
(131790, 9391, 'Unidentified with Demi Lovato [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o5SaprZ86N6pzbstVPcpWxwplEu.jpg'),
(131791, 9391, 'Unidentified with Demi Lovato [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/68DzT11nbwqV1rrqKGqcLccphUO.jpg'),
(131792, 9391, 'Unidentified with Demi Lovato [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b9UkbJ6znX1HFQKjPotMWctZyHi.jpg'),
(131793, 9391, 'Unidentified with Demi Lovato [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xwMeUhCLu5BFLZTgfLFvVh7AQWO.jpg'),
(131794, 9392, 'Volume [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7D6Cu8vETQwlhubGnNZoLxk39p8.jpg'),
(131795, 9392, 'Volume [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7D6Cu8vETQwlhubGnNZoLxk39p8.jpg'),
(131796, 9392, 'Volume [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7D6Cu8vETQwlhubGnNZoLxk39p8.jpg'),
(131797, 9392, 'Volume [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7D6Cu8vETQwlhubGnNZoLxk39p8.jpg'),
(131798, 9392, 'Volume [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7D6Cu8vETQwlhubGnNZoLxk39p8.jpg'),
(131799, 9392, 'Volume [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7D6Cu8vETQwlhubGnNZoLxk39p8.jpg'),
(131800, 9393, 'Yuusha ni Narenakatta Ore wa Shibushibu Shuushoku wo Ketsui Shimashita [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vaOLIBlPY39WIFgVynq85yzCP8P.jpg'),
(131801, 9393, 'Yuusha ni Narenakatta Ore wa Shibushibu Shuushoku wo Ketsui Shimashita [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3mJCKPAyBefHrZFlkHKddQUpaFV.jpg'),
(131802, 9393, 'Yuusha ni Narenakatta Ore wa Shibushibu Shuushoku wo Ketsui Shimashita [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wc2ti5xuHqMEXYTUZvMcpKIiVuO.jpg'),
(131803, 9393, 'Yuusha ni Narenakatta Ore wa Shibushibu Shuushoku wo Ketsui Shimashita [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/86RmtoEjetvcqkhMRkDS3zVChgl.jpg'),
(131804, 9393, 'Yuusha ni Narenakatta Ore wa Shibushibu Shuushoku wo Ketsui Shimashita [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyK6mYkMpvVp0ESl0pAjbz1Wz51.jpg'),
(131805, 9393, 'Yuusha ni Narenakatta Ore wa Shibushibu Shuushoku wo Ketsui Shimashita [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cIZthWo5MTFnLPsYETeCEoHg6O0.jpg'),
(131806, 9393, 'Yuusha ni Narenakatta Ore wa Shibushibu Shuushoku wo Ketsui Shimashita [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/seim5W29VrSVxLHufrwOkIHxJuC.jpg'),
(131807, 9393, 'Yuusha ni Narenakatta Ore wa Shibushibu Shuushoku wo Ketsui Shimashita [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gisicpjgrAHvndE1oIjpNmFpKYv.jpg'),
(131808, 9393, 'Yuusha ni Narenakatta Ore wa Shibushibu Shuushoku wo Ketsui Shimashita [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hG5NNQemdk8A09CzNorc1hSrGJX.jpg'),
(131809, 9393, 'Yuusha ni Narenakatta Ore wa Shibushibu Shuushoku wo Ketsui Shimashita [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8wiDB9Bbxj49F0iklevghUqWEwf.jpg'),
(131810, 9393, 'Yuusha ni Narenakatta Ore wa Shibushibu Shuushoku wo Ketsui Shimashita [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9tApt9qkLvSt9Ujh1Mh6k6jsKFU.jpg'),
(131811, 9393, 'Yuusha ni Narenakatta Ore wa Shibushibu Shuushoku wo Ketsui Shimashita [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tnlfxizYvMR2umxNAdYjMrdvjSU.jpg'),
(131812, 9394, 'Classroom of the Elite S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8A2eGfqyomNgxqcyfIexSmYF43C.jpg'),
(131813, 9394, 'Classroom of the Elite S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xFwvFgtr9k9Y8C13CGuJ0BvNaCL.jpg'),
(131814, 9394, 'Classroom of the Elite S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2kaeokG53dUQDqOdEXDP2JkUuAj.jpg'),
(131815, 9394, 'Classroom of the Elite S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7oaikTMJo2VTDhktCvBUCnftjce.jpg'),
(131816, 9394, 'Classroom of the Elite S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hLIwcF7aWjFrVrpqMkdXfJYmDbu.jpg'),
(131817, 9394, 'Classroom of the Elite S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7eb7cSn5gSzljHwcVN9b5W63DGi.jpg'),
(131818, 9394, 'Classroom of the Elite S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lDtIIAiih1d81MhoNRdmRwZCBa4.jpg'),
(131819, 9394, 'Classroom of the Elite S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tcqWleFpviDiHhLp48zPkFXgxYD.jpg'),
(131820, 9394, 'Classroom of the Elite S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/giRYMa11C7tSxNwCQK3yznnLo8A.jpg'),
(131821, 9394, 'Classroom of the Elite S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pcbRim2OfErsqUD4vrpyeTYrH9m.jpg'),
(131822, 9394, 'Classroom of the Elite S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qrRwKfCbdysBKxf9ApEHtjAys5U.jpg'),
(131823, 9394, 'Classroom of the Elite S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aOdRq37dWJQcQge1qelkFfdgK6Q.jpg'),
(131824, 9395, 'Classroom of the Elite S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qUMhwS1QbTY6wuAv7CemW1AGVZA.jpg'),
(131825, 9395, 'Classroom of the Elite S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3BE7fmLK5J1nijfY52S2nvx08tU.jpg'),
(131826, 9395, 'Classroom of the Elite S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xleOVHWBY4b3yGlgMG1iXfQvtYg.jpg'),
(131827, 9395, 'Classroom of the Elite S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oF6UbzQQce0xri9vHL7cCaN9N3J.jpg'),
(131828, 9395, 'Classroom of the Elite S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hyRKf7wM0cWuXpMnMHjCDoWeNoW.jpg'),
(131829, 9395, 'Classroom of the Elite S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qoIHpSIN1XketcShpULWMmPPDyT.jpg'),
(131830, 9395, 'Classroom of the Elite S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l6bI7i1sKKCa94bLZ7R5WM0qRVN.jpg'),
(131831, 9395, 'Classroom of the Elite S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qYp9tCdw4ICEQxexR4MTL6eAGw3.jpg'),
(131832, 9395, 'Classroom of the Elite S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ToxZSq75pkFGvk45SHoywc2CJN.jpg'),
(131833, 9395, 'Classroom of the Elite S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iuH1dtZ3neoXw5Dp35cMDwxEBHt.jpg'),
(131834, 9395, 'Classroom of the Elite S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AfdWfIjGUOc1Oxtg73Oe7ElaNHa.jpg'),
(131835, 9395, 'Classroom of the Elite S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6E0DJbQwTgHe1ousRpRHaP0Zx9O.jpg'),
(131836, 9395, 'Classroom of the Elite S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d3ML6HoEhX8n1BZWXs4TxdQ6gVj.jpg'),
(131837, 9396, 'Classroom of the Elite S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131838, 9396, 'Classroom of the Elite S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131839, 9396, 'Classroom of the Elite S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/271644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131840, 9396, 'Classroom of the Elite S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131841, 9396, 'Classroom of the Elite S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/279064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131842, 9396, 'Classroom of the Elite S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/288313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131843, 9396, 'Classroom of the Elite S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/296863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131844, 9396, 'Classroom of the Elite S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/300253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131845, 9396, 'Classroom of the Elite S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/305318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131846, 9396, 'Classroom of the Elite S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/318250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131847, 9396, 'Classroom of the Elite S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/319887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131848, 9396, 'Classroom of the Elite S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/326218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131849, 9396, 'Classroom of the Elite S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/331504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131850, 9397, 'Classroom of the Elite [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8A2eGfqyomNgxqcyfIexSmYF43C.jpg'),
(131851, 9397, 'Classroom of the Elite [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xFwvFgtr9k9Y8C13CGuJ0BvNaCL.jpg'),
(131852, 9397, 'Classroom of the Elite [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2kaeokG53dUQDqOdEXDP2JkUuAj.jpg'),
(131853, 9397, 'Classroom of the Elite [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7oaikTMJo2VTDhktCvBUCnftjce.jpg'),
(131854, 9397, 'Classroom of the Elite [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hLIwcF7aWjFrVrpqMkdXfJYmDbu.jpg'),
(131855, 9397, 'Classroom of the Elite [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7eb7cSn5gSzljHwcVN9b5W63DGi.jpg'),
(131856, 9397, 'Classroom of the Elite [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lDtIIAiih1d81MhoNRdmRwZCBa4.jpg'),
(131857, 9397, 'Classroom of the Elite [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tcqWleFpviDiHhLp48zPkFXgxYD.jpg'),
(131858, 9397, 'Classroom of the Elite [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/giRYMa11C7tSxNwCQK3yznnLo8A.jpg'),
(131859, 9397, 'Classroom of the Elite [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pcbRim2OfErsqUD4vrpyeTYrH9m.jpg'),
(131860, 9397, 'Classroom of the Elite [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qrRwKfCbdysBKxf9ApEHtjAys5U.jpg'),
(131861, 9397, 'Classroom of the Elite [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aOdRq37dWJQcQge1qelkFfdgK6Q.jpg'),
(131862, 9398, 'Classroom of the Elite [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qUMhwS1QbTY6wuAv7CemW1AGVZA.jpg'),
(131863, 9398, 'Classroom of the Elite [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3BE7fmLK5J1nijfY52S2nvx08tU.jpg'),
(131864, 9398, 'Classroom of the Elite [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xleOVHWBY4b3yGlgMG1iXfQvtYg.jpg'),
(131865, 9398, 'Classroom of the Elite [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oF6UbzQQce0xri9vHL7cCaN9N3J.jpg'),
(131866, 9398, 'Classroom of the Elite [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hyRKf7wM0cWuXpMnMHjCDoWeNoW.jpg'),
(131867, 9398, 'Classroom of the Elite [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qoIHpSIN1XketcShpULWMmPPDyT.jpg'),
(131868, 9398, 'Classroom of the Elite [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l6bI7i1sKKCa94bLZ7R5WM0qRVN.jpg'),
(131869, 9398, 'Classroom of the Elite [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qYp9tCdw4ICEQxexR4MTL6eAGw3.jpg'),
(131870, 9398, 'Classroom of the Elite [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ToxZSq75pkFGvk45SHoywc2CJN.jpg'),
(131871, 9398, 'Classroom of the Elite [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iuH1dtZ3neoXw5Dp35cMDwxEBHt.jpg'),
(131872, 9398, 'Classroom of the Elite [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AfdWfIjGUOc1Oxtg73Oe7ElaNHa.jpg'),
(131873, 9398, 'Classroom of the Elite [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6E0DJbQwTgHe1ousRpRHaP0Zx9O.jpg'),
(131874, 9398, 'Classroom of the Elite [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d3ML6HoEhX8n1BZWXs4TxdQ6gVj.jpg'),
(131875, 9399, 'Classroom of the Elite [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131876, 9399, 'Classroom of the Elite [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131877, 9399, 'Classroom of the Elite [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131878, 9399, 'Classroom of the Elite [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/597611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131879, 9399, 'Classroom of the Elite [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/276713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131880, 9399, 'Classroom of the Elite [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/276714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131881, 9399, 'Classroom of the Elite [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/279096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131882, 9399, 'Classroom of the Elite [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/288346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131883, 9399, 'Classroom of the Elite [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/296897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131884, 9399, 'Classroom of the Elite [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/300288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131885, 9399, 'Classroom of the Elite [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/305354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131886, 9399, 'Classroom of the Elite [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/313368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mmhx3dImdsfYpcFm3J1tlQt5IRN.jpg'),
(131887, 9400, 'Ishura [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eTiiL4NrH3dH5oi6mY5kQQSsLOa.jpg'),
(131888, 9400, 'Ishura [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131889, 9400, 'Ishura [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131890, 9400, 'Ishura [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/595385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131891, 9400, 'Ishura [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/272855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131892, 9400, 'Ishura [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/272856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131893, 9400, 'Ishura [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131894, 9400, 'Ishura [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/288260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131895, 9400, 'Ishura [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/296791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131896, 9400, 'Ishura [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/299926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131897, 9400, 'Ishura [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/304575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131898, 9401, 'Ishura [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/662254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131899, 9401, 'Ishura [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/668702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131900, 9401, 'Ishura [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/673608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131901, 9401, 'Ishura [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/679426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131902, 9401, 'Ishura [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/684648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131903, 9401, 'Ishura [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/695875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131904, 9401, 'Ishura [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/701654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131905, 9401, 'Ishura [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/709063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131906, 9401, 'Ishura [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/718055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131907, 9401, 'Ishura [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/725511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131908, 9401, 'Ishura [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/731207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131909, 9401, 'Ishura [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/739921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0nbxeYiFQJxzJ8nTTOwWNij2z.jpg'),
(131910, 9402, 'Jaku Chara Tomozaki kun [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x48hxQ3TACAwUh6B7x7DAGMGlDZ.jpg'),
(131911, 9402, 'Jaku Chara Tomozaki kun [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AdSMneRrb1LfbdTUdrgdauXRKbc.jpg'),
(131912, 9402, 'Jaku Chara Tomozaki kun [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Fh5h8Ryis6ZQvYG51KpY2yBPz5.jpg'),
(131913, 9402, 'Jaku Chara Tomozaki kun [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGSzyhjj3VxoqKZ563K7pBh5U4h.jpg'),
(131914, 9402, 'Jaku Chara Tomozaki kun [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b7RG9xa8H0HpAxoeAoeSgU1JQfx.jpg'),
(131915, 9402, 'Jaku Chara Tomozaki kun [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jpcp0MwukfKcQnwS0ykmo30trdi.jpg'),
(131916, 9402, 'Jaku Chara Tomozaki kun [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZnHjloivTo9Xxo9V5DIf5c7ezY.jpg'),
(131917, 9402, 'Jaku Chara Tomozaki kun [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4PgelxEl2qf4zC3JgyLizITlGe.jpg'),
(131918, 9402, 'Jaku Chara Tomozaki kun [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4qBbtHAs0Jr4YzcrwvhIFmrFYFh.jpg'),
(131919, 9402, 'Jaku Chara Tomozaki kun [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/deg18mXPM5GnV38hSqr6RMPa7T4.jpg'),
(131920, 9402, 'Jaku Chara Tomozaki kun [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/neYPkM2qYOSUSLDXqsJspc2EWes.jpg'),
(131921, 9402, 'Jaku Chara Tomozaki kun [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fIgmK2AXcfppydEXlV55lQQawUe.jpg'),
(131922, 9402, 'Jaku Chara Tomozaki kun [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/99lvxrZP8c7r57ShlM51TQTJ3cc.jpg'),
(131923, 9402, 'Jaku Chara Tomozaki kun [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/99lvxrZP8c7r57ShlM51TQTJ3cc.jpg'),
(131924, 9403, 'Jaku Chara Tomozaki kun [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/imV686LPmVHwnz4N1R6P0vNUTBL.jpg'),
(131925, 9403, 'Jaku Chara Tomozaki kun [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/99lvxrZP8c7r57ShlM51TQTJ3cc.jpg'),
(131926, 9403, 'Jaku Chara Tomozaki kun [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/99lvxrZP8c7r57ShlM51TQTJ3cc.jpg'),
(131927, 9403, 'Jaku Chara Tomozaki kun [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/99lvxrZP8c7r57ShlM51TQTJ3cc.jpg'),
(131928, 9403, 'Jaku Chara Tomozaki kun [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/99lvxrZP8c7r57ShlM51TQTJ3cc.jpg'),
(131929, 9403, 'Jaku Chara Tomozaki kun [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/272849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/99lvxrZP8c7r57ShlM51TQTJ3cc.jpg'),
(131930, 9403, 'Jaku Chara Tomozaki kun [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/272850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/99lvxrZP8c7r57ShlM51TQTJ3cc.jpg'),
(131931, 9403, 'Jaku Chara Tomozaki kun [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/288251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/99lvxrZP8c7r57ShlM51TQTJ3cc.jpg'),
(131932, 9403, 'Jaku Chara Tomozaki kun [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/288252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/99lvxrZP8c7r57ShlM51TQTJ3cc.jpg'),
(131933, 9403, 'Jaku Chara Tomozaki kun [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/296782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/99lvxrZP8c7r57ShlM51TQTJ3cc.jpg'),
(131934, 9403, 'Jaku Chara Tomozaki kun [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/299916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/99lvxrZP8c7r57ShlM51TQTJ3cc.jpg'),
(131935, 9403, 'Jaku Chara Tomozaki kun [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/304564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/99lvxrZP8c7r57ShlM51TQTJ3cc.jpg'),
(131936, 9403, 'Jaku Chara Tomozaki kun [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/313272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/99lvxrZP8c7r57ShlM51TQTJ3cc.jpg'),
(131937, 9404, 'Jared Fogle O Monstro do Subway S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QA8JVpG5wNHN9NZxV1ljyUP9sF.jpg'),
(131938, 9404, 'Jared Fogle O Monstro do Subway S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/an1hUwgSIs1CHi8kpxyZZ5wB7DW.jpg'),
(131939, 9404, 'Jared Fogle O Monstro do Subway S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tyMXoTZnn32LnlvAlhnQYmYDofB.jpg'),
(131940, 9405, 'Tari Tari [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iYkCF9h0vApdEYiaUWGyvBb8o8m.jpg'),
(131941, 9405, 'Tari Tari [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x8JNexHXqzRnSmBKWj2ky4LK67g.jpg'),
(131942, 9405, 'Tari Tari [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vtWHOU7bE1yAxDgnRWMoH8ae319.jpg'),
(131943, 9405, 'Tari Tari [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/254440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZOy7MsYD4lEUwxzkLqLoftGAKZ.jpg'),
(131944, 9405, 'Tari Tari [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/254441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nfsAJKS3Y685hy4WOz7C5Jf13Sk.jpg'),
(131945, 9405, 'Tari Tari [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/254442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gIXXhc69kzUGbepTDiZfFDplQCT.jpg'),
(131946, 9405, 'Tari Tari [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/254443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJpKTOrLN1ht4f3ohJPn7H9b0Zp.jpg'),
(131947, 9405, 'Tari Tari [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/254444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xqS9RBrvY73eCYVkQyjeBGweYRG.jpg'),
(131948, 9405, 'Tari Tari [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/254445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oAAhPQLRu930ephZaDYBLVv3yTp.jpg'),
(131949, 9405, 'Tari Tari [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/254446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qE7pNjSaAOgSyUrAm6gTjoT8Mzh.jpg'),
(131950, 9405, 'Tari Tari [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/254447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ywUf7YfzkXiu0tN6LKLoVvY1TGS.jpg'),
(131951, 9405, 'Tari Tari [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/254448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2VKWA8QAuQMKRYjgkhpjVoPWrbh.jpg'),
(131952, 9405, 'Tari Tari [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/254449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4rhzaCsga9nBiqK1zPrNAszmgQY.jpg'),
(131953, 9406, '3x Artico O Alerta do Gelo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/254431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x1v9qGzQASjwNHieRcUAHApraRn.jpg'),
(131954, 9406, '3x Artico O Alerta do Gelo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/254432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MIqLUAIqNVDWKWRTD6Qylwlmbb.jpg'),
(131955, 9406, '3x Artico O Alerta do Gelo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/254433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/70062RzvpY5ArWEgBcQm5yotTbW.jpg'),
(131956, 9407, 'Irmaos Sun S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xLODtsBxL1OANSS9RFgRVBTDKYo.jpg'),
(131957, 9407, 'Irmaos Sun S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r6CsYn4Vy8opWRCVdvfvUoSksjG.jpg'),
(131958, 9407, 'Irmaos Sun S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/318KI9vsFWe0YCm85G0jSoAJRME.jpg'),
(131959, 9407, 'Irmaos Sun S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gLOkvwSmdcosm0k6tw5ZpTQ5m0C.jpg'),
(131960, 9407, 'Irmaos Sun S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5kbcyc9svIvxlWGrc8wsx5CZesq.jpg'),
(131961, 9407, 'Irmaos Sun S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Yc2xFq5OiMlhwvnCppRb5k1N2E.jpg'),
(131962, 9407, 'Irmaos Sun S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/doQU4mJA2nfd2ZeKtY3JR7dYVyb.jpg'),
(131963, 9407, 'Irmaos Sun S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/etPLMarfj7Y462IZADeABXdwJYa.jpg'),
(131964, 9408, 'As Meninas Superpoderosas (2016) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8xOVyJENTLVFZfLUFIMhFKIJK1v.jpg'),
(131965, 9408, 'As Meninas Superpoderosas (2016) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cOzQrcerxXJAdfhg5ar5HkbWadq.jpg'),
(131966, 9408, 'As Meninas Superpoderosas (2016) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDPAt7HvWQljWALsBCNLV4W7KtV.jpg'),
(131967, 9408, 'As Meninas Superpoderosas (2016) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zpJ2DTPh7p8ICIG9osb8ZeEctbs.jpg'),
(131968, 9408, 'As Meninas Superpoderosas (2016) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0zUtBgLbnKwITmkWvCwIHa3XVh.jpg'),
(131969, 9408, 'As Meninas Superpoderosas (2016) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xwEgtT2sM9JoMqGVLk6TISfxHvZ.jpg'),
(131970, 9408, 'As Meninas Superpoderosas (2016) S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBXZwSwkLO7s2k0doPIAf8Jqt2w.jpg'),
(131971, 9408, 'As Meninas Superpoderosas (2016) S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rAXcHsRX9tz8aCbQg1KNHYR80ca.jpg'),
(131972, 9408, 'As Meninas Superpoderosas (2016) S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zxf3PIFWZ3EfCumhxgcskVHH1B8.jpg'),
(131973, 9408, 'As Meninas Superpoderosas (2016) S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6r4kSLvjnMdyUu2rrpwSq7W3QPS.jpg'),
(131974, 9408, 'As Meninas Superpoderosas (2016) S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvwtJvHmwVPCzipCrXYsmVMvMEC.jpg'),
(131975, 9408, 'As Meninas Superpoderosas (2016) S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lr9WiQRurOB59O3hgdn40O4gsSZ.jpg'),
(131976, 9408, 'As Meninas Superpoderosas (2016) S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aKT8LLuR3UZMnzGe3InH7h3LMu8.jpg'),
(131977, 9408, 'As Meninas Superpoderosas (2016) S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mNd80QiwdjaQKqgKPDjzuB2rEw0.jpg'),
(131978, 9408, 'As Meninas Superpoderosas (2016) S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c6F3ajnoSgejaNkQsjIU9tF3xbH.jpg'),
(131979, 9408, 'As Meninas Superpoderosas (2016) S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vpsxzbLx0lFwUNptHe1kxkIJwvG.jpg'),
(131980, 9408, 'As Meninas Superpoderosas (2016) S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pZJkuqa6QMePFJvPG8FNLjy03Zx.jpg'),
(131981, 9408, 'As Meninas Superpoderosas (2016) S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lpV8P2vf4mAM1osZRrayuAQSEoj.jpg'),
(131982, 9408, 'As Meninas Superpoderosas (2016) S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJwEVwDyrjdacwwe4J9WJ3kJQ0J.jpg'),
(131983, 9408, 'As Meninas Superpoderosas (2016) S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1X2qMhR6aH1rBQ2HUwm7MU04TOq.jpg'),
(131984, 9408, 'As Meninas Superpoderosas (2016) S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wbzMAcF5KeGq7d1tOgJW7euwxNN.jpg'),
(131985, 9408, 'As Meninas Superpoderosas (2016) S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cXSaLkzV7XVVw4lSfikVR0Svh1L.jpg'),
(131986, 9408, 'As Meninas Superpoderosas (2016) S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/260235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9hQ0VPBpKL5CQCX9WLm8ryBu9xc.jpg'),
(131987, 9408, 'As Meninas Superpoderosas (2016) S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/260236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/akaIupYv7cYFC452JZ0dzABJqYW.jpg'),
(131988, 9408, 'As Meninas Superpoderosas (2016) S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/260237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zpfHjhGnv7reDsoM1h600sVu6Mj.jpg'),
(131989, 9408, 'As Meninas Superpoderosas (2016) S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/260238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cQPnVeWvdFXKblDe5KrSLsYZwVm.jpg'),
(131990, 9408, 'As Meninas Superpoderosas (2016) S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/260239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9yeNJtGnrWK26TvTZmLgS5L2g4z.jpg'),
(131991, 9408, 'As Meninas Superpoderosas (2016) S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/260240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xmDYGQue4LuzspN4gQpZTIhEKD5.jpg'),
(131992, 9408, 'As Meninas Superpoderosas (2016) S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/260241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5XCNgrJCuoosTYe9nf0g6CFXiqi.jpg'),
(131993, 9408, 'As Meninas Superpoderosas (2016) S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/260242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rP4MgBggj6bqYNSi6viiUWC2ZBN.jpg'),
(131994, 9408, 'As Meninas Superpoderosas (2016) S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/260243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/khiWVbKv8hyLKUux2ZTifB1Ye3I.jpg'),
(131995, 9408, 'As Meninas Superpoderosas (2016) S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/260244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hUiitetZe6tT1ne5gTrcHd9KhFB.jpg'),
(131996, 9408, 'As Meninas Superpoderosas (2016) S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/260245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ea8Enty1VBsQNS6wObrr4b1FEiQ.jpg'),
(131997, 9408, 'As Meninas Superpoderosas (2016) S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/260246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4IAu6GGMxg4HLU8RBmALZ8knDIn.jpg'),
(131998, 9408, 'As Meninas Superpoderosas (2016) S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/260247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xLupOHN0oVbZuQSPyPUvudVFwJM.jpg'),
(131999, 9408, 'As Meninas Superpoderosas (2016) S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/260248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n9ZL7CXxpaQRkapTDhSKjttmYTx.jpg'),
(132000, 9408, 'As Meninas Superpoderosas (2016) S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/260249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4IkDCYRiZUtU0HtTye4prUFguwX.jpg'),
(132001, 9408, 'As Meninas Superpoderosas (2016) S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/260250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v0R8cy0fXnnHxvGFJZ6gQAXMWz9.jpg'),
(132002, 9409, 'As Meninas Superpoderosas (2016) S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqpGUlj0KSIReHs6f1D7knDxKsJ.jpg'),
(132003, 9409, 'As Meninas Superpoderosas (2016) S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eouflLWppIf8OPgkkGLaniJNFVd.jpg'),
(132004, 9409, 'As Meninas Superpoderosas (2016) S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nKpGW1Vv4pVC2qUd52xIl48P47P.jpg'),
(132005, 9409, 'As Meninas Superpoderosas (2016) S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1oZqKffGrmdkHnj2pE8dIJFGnGa.jpg'),
(132006, 9409, 'As Meninas Superpoderosas (2016) S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Ua4JRJiCOh789KxuQwtFLkgWtf.jpg'),
(132007, 9409, 'As Meninas Superpoderosas (2016) S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ezpwld7sQUehzzpZb9klaNxyW7R.jpg'),
(132008, 9409, 'As Meninas Superpoderosas (2016) S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7z97sUi8OPpHaA2jog6K8tAyTAC.jpg'),
(132009, 9409, 'As Meninas Superpoderosas (2016) S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/frk1vY7tHGHmYFb8wbX3A7Rl419.jpg'),
(132010, 9409, 'As Meninas Superpoderosas (2016) S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p0Nh0rFjMWPEfqL4LzscXmjxLL7.jpg'),
(132011, 9409, 'As Meninas Superpoderosas (2016) S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xlrcth1UeH0EwdNhSJnfk0DxH4M.jpg'),
(132012, 9409, 'As Meninas Superpoderosas (2016) S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7EssQarGJUwvEvbYykhB0wgLiwX.jpg'),
(132013, 9409, 'As Meninas Superpoderosas (2016) S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4yKjA1OCMnccZJjCj6PfFI4qVOv.jpg'),
(132014, 9409, 'As Meninas Superpoderosas (2016) S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jpOEjepX8bUiJT8nhkpveaqu9QG.jpg'),
(132015, 9409, 'As Meninas Superpoderosas (2016) S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cNi6E1YD28xY9Xx5EjhG49Q3OUF.jpg'),
(132016, 9409, 'As Meninas Superpoderosas (2016) S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o55PndP9pMG23nPdAFti5SEyGL7.jpg'),
(132017, 9409, 'As Meninas Superpoderosas (2016) S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lmZzdL35KjkAYp9epCOYakpwD5Q.jpg'),
(132018, 9409, 'As Meninas Superpoderosas (2016) S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/M2lCQdny5Ui1EAGDN1mRx7UV15.jpg'),
(132019, 9409, 'As Meninas Superpoderosas (2016) S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t2fwuhREQbjqFJGwjcDKnLHy7rw.jpg'),
(132020, 9409, 'As Meninas Superpoderosas (2016) S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uW19X9JYRdsQKsWVtfzle7qhoU1.jpg'),
(132021, 9409, 'As Meninas Superpoderosas (2016) S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ztQMZ2cvnS1lM1fnB7gCdkdM5h.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(132022, 9409, 'As Meninas Superpoderosas (2016) S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t0kmNXyZ2LrET2JxJ83zkxcwEwc.jpg'),
(132023, 9409, 'As Meninas Superpoderosas (2016) S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ixWZ9nORdKx0LgYYpXrw07iLOp2.jpg'),
(132024, 9409, 'As Meninas Superpoderosas (2016) S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/260273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7ZXHu7ssl5pZDWzHzkEbEbR6jM.jpg'),
(132025, 9409, 'As Meninas Superpoderosas (2016) S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/260274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fbPUPMwlJowKJgZgWEVxDwZihMA.jpg'),
(132026, 9409, 'As Meninas Superpoderosas (2016) S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/260275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vHBhE49pogyCj3Uzyms1p1zRk7z.jpg'),
(132027, 9409, 'As Meninas Superpoderosas (2016) S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/260276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2tLTjkN0RvqXac5BOfSIyKsYmjf.jpg'),
(132028, 9409, 'As Meninas Superpoderosas (2016) S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/260277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/egkufcvnhREFFEL2494rJ8f6oU3.jpg'),
(132029, 9409, 'As Meninas Superpoderosas (2016) S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/260278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q8KKWUwOJcy0XE6j3sPKNeo36Yo.jpg'),
(132030, 9409, 'As Meninas Superpoderosas (2016) S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/260279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ykTT9KjsDV9sMpTsl2wMI2FO44.jpg'),
(132031, 9409, 'As Meninas Superpoderosas (2016) S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/260280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n6vfcCMvcvo1xPi14Uu37CVQNk4.jpg'),
(132032, 9409, 'As Meninas Superpoderosas (2016) S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/260281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mWwRqYf2x2J216CGvI4VCAU4IMb.jpg'),
(132033, 9409, 'As Meninas Superpoderosas (2016) S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/260282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZ8s86QqEp9eSX99HdlAKBdzSLM.jpg'),
(132034, 9409, 'As Meninas Superpoderosas (2016) S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/260283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xA7VCU61nM8AW53RGczwgsX90hx.jpg'),
(132035, 9409, 'As Meninas Superpoderosas (2016) S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/260284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fBlzgy3uiT6TUU9FhaZz9tc24R5.jpg'),
(132036, 9409, 'As Meninas Superpoderosas (2016) S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/260285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lK0pP5QwM1e0ZBWshyuhSUV5RRs.jpg'),
(132037, 9409, 'As Meninas Superpoderosas (2016) S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/260286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hgCgJY4pQh2cUwSyD4gL8cBZghP.jpg'),
(132038, 9409, 'As Meninas Superpoderosas (2016) S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/260287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hWta408Wv5OD125HOr1wxdF7IyO.jpg'),
(132039, 9409, 'As Meninas Superpoderosas (2016) S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/260288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wjo3WN4XmJh45KTJuZfn4QNwpc9.jpg'),
(132040, 9409, 'As Meninas Superpoderosas (2016) S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/260289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/btO7hY0g5SuUnasX1LGayH6nUcJ.jpg'),
(132041, 9409, 'As Meninas Superpoderosas (2016) S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/260290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7atqZfQn9giulvhUVKD9ZmE7J8C.jpg'),
(132042, 9409, 'As Meninas Superpoderosas (2016) S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/260291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hYNqzwNemBRr2N1BTKlS5ohEnbB.jpg'),
(132043, 9410, 'As Meninas Superpoderosas (2016) S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pZpf9aHyX8MdbIoJro6r28fneDq.jpg'),
(132044, 9410, 'As Meninas Superpoderosas (2016) S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mTHB6d2UzdGhnZf3p2ySg44HaCd.jpg'),
(132045, 9410, 'As Meninas Superpoderosas (2016) S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eovuzHadR3SUWqYG96Ey18tfhRp.jpg'),
(132046, 9410, 'As Meninas Superpoderosas (2016) S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u1gAbaLhStoAY0ezW9JoesnA2yj.jpg'),
(132047, 9410, 'As Meninas Superpoderosas (2016) S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUpGyBsUX9OJoUNvJTHz0nrqizE.jpg'),
(132048, 9410, 'As Meninas Superpoderosas (2016) S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/soxtQP13Dol6KH2PjZjcBx7wKqO.jpg'),
(132049, 9410, 'As Meninas Superpoderosas (2016) S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPiqkzoXMSQ2VJdcmNsXo5LQeIk.jpg'),
(132050, 9410, 'As Meninas Superpoderosas (2016) S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s1CJooFCgUknDXBjTBmIRbPu56y.jpg'),
(132051, 9410, 'As Meninas Superpoderosas (2016) S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8VP2oczTuGuX9TntWkOmHl6gsVE.jpg'),
(132052, 9410, 'As Meninas Superpoderosas (2016) S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5EapKVjHqHwjw4BOlDUoqKCYNJ.jpg'),
(132053, 9410, 'As Meninas Superpoderosas (2016) S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5hCTYUSILvdzdG3HMR1DlgmuSmU.jpg'),
(132054, 9410, 'As Meninas Superpoderosas (2016) S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zT8pX6v4TZU9Z5xdHWBuSKvOJbg.jpg'),
(132055, 9410, 'As Meninas Superpoderosas (2016) S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z9MCdAkfcUzHe9cggWF0CGvm8kE.jpg'),
(132056, 9410, 'As Meninas Superpoderosas (2016) S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8hRDJELscysroJ3vQxlnkh5W2tl.jpg'),
(132057, 9410, 'As Meninas Superpoderosas (2016) S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDtMo4R65bDyeHjqWfN5yIbuMSR.jpg'),
(132058, 9410, 'As Meninas Superpoderosas (2016) S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/50eHP1ZbVUbw9HSgPkySQATvDrZ.jpg'),
(132059, 9410, 'As Meninas Superpoderosas (2016) S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aVhCscPWvezcGVER5dv3WI3bwe.jpg'),
(132060, 9410, 'As Meninas Superpoderosas (2016) S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aVhCscPWvezcGVER5dv3WI3bwe.jpg'),
(132061, 9410, 'As Meninas Superpoderosas (2016) S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aVhCscPWvezcGVER5dv3WI3bwe.jpg'),
(132062, 9410, 'As Meninas Superpoderosas (2016) S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0SqYRk2QhFGGEb800Z798GOBHL.jpg'),
(132063, 9410, 'As Meninas Superpoderosas (2016) S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJR8fQft3K3HM8EZUt1Knuyg0yd.jpg'),
(132064, 9410, 'As Meninas Superpoderosas (2016) S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3IRx6fDuZ2kib4LNVgJJfUnLQQm.jpg'),
(132065, 9410, 'As Meninas Superpoderosas (2016) S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/260314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h7guIsfs9U6hpg4UbXyHVd4kpS5.jpg'),
(132066, 9410, 'As Meninas Superpoderosas (2016) S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/260315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/chBVsXdTAu6RPKJa5EvNCe4eb02.jpg'),
(132067, 9410, 'As Meninas Superpoderosas (2016) S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/260316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rSW5YzzYAoe3PgveT0YzcxtRjoP.jpg'),
(132068, 9410, 'As Meninas Superpoderosas (2016) S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/260317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fK3GjnbIzVGtqwMPs0juxfLagOY.jpg'),
(132069, 9410, 'As Meninas Superpoderosas (2016) S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/260318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8BTU6uAwFbQZTLi7ueAOYFQ1P4w.jpg'),
(132070, 9410, 'As Meninas Superpoderosas (2016) S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/260319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13Zjrfwo5Vt7mW2LDqcs1KQQ56S.jpg'),
(132071, 9410, 'As Meninas Superpoderosas (2016) S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/260320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7HYfnvp9YAYvUHYJ97rYk2eSp6c.jpg'),
(132072, 9410, 'As Meninas Superpoderosas (2016) S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/260321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8w8TKvRV5zEe1DXI60GsYlXYbnh.jpg'),
(132073, 9410, 'As Meninas Superpoderosas (2016) S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/260322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5P5dUFcTyODfsmMUyGGRlEEP50t.jpg'),
(132074, 9410, 'As Meninas Superpoderosas (2016) S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/260323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nOymLQ3idz4VHaW2o2hUSgJBeFf.jpg'),
(132075, 9410, 'As Meninas Superpoderosas (2016) S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/260324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1iqnPI56eTo2fHtWRra2jKqY30X.jpg'),
(132076, 9410, 'As Meninas Superpoderosas (2016) S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/260325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vQiZCTRPMJaSVfnTOpaM41B4O7k.jpg'),
(132077, 9410, 'As Meninas Superpoderosas (2016) S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/260326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nBDu0wPd7o1EIVjUApL2YhAs15x.jpg'),
(132078, 9410, 'As Meninas Superpoderosas (2016) S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/260327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sjcf9qlMxihVGFEIVbpOHiGywo7.jpg'),
(132079, 9410, 'As Meninas Superpoderosas (2016) S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/260328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nH5WrQo72MZdJvzHfHYjPYlmNWh.jpg'),
(132080, 9410, 'As Meninas Superpoderosas (2016) S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/260329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qm4UIsWKGjh2U0Z5MdYabxRNyok.jpg'),
(132081, 9410, 'As Meninas Superpoderosas (2016) S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/260330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jEPmrN2kXpLoqD1ZqJqb26Au3Vr.jpg'),
(132082, 9411, 'Dungeon Meshi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/taXqIOzkit6zap6aCTqtavog4ty.jpg'),
(132083, 9411, 'Dungeon Meshi S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132084, 9411, 'Dungeon Meshi S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132085, 9411, 'Dungeon Meshi S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132086, 9411, 'Dungeon Meshi S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132087, 9411, 'Dungeon Meshi S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/271566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132088, 9411, 'Dungeon Meshi S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132089, 9411, 'Dungeon Meshi S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/281345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132090, 9411, 'Dungeon Meshi S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/287650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132091, 9411, 'Dungeon Meshi S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/296408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132092, 9411, 'Dungeon Meshi S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/302826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132093, 9411, 'Dungeon Meshi S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/306206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132094, 9411, 'Dungeon Meshi S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/316113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132095, 9411, 'Dungeon Meshi S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/319846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132096, 9411, 'Dungeon Meshi S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/326124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132097, 9411, 'Dungeon Meshi S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/331441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132098, 9411, 'Dungeon Meshi S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/333201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132099, 9411, 'Dungeon Meshi S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/345680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132100, 9411, 'Dungeon Meshi S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/352590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132101, 9411, 'Dungeon Meshi S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/352591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132102, 9411, 'Dungeon Meshi S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/363571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132103, 9411, 'Dungeon Meshi S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/369004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132104, 9411, 'Dungeon Meshi S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/374537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132105, 9411, 'Dungeon Meshi S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/383141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8gN7dsgBVxYtX3fGqTTogckVnD.jpg'),
(132106, 9412, 'Haiyore Nyaruko san [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7OeUykouD4vX3Wxv7ReFCARusqA.jpg'),
(132107, 9412, 'Haiyore Nyaruko san [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vbbfUbjvkXn9KwsamsISAKmvHH3.jpg'),
(132108, 9412, 'Haiyore Nyaruko san [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVhhiYcMfvC751y2hPMPQgXxWpR.jpg'),
(132109, 9412, 'Haiyore Nyaruko san [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5IeCdzbnwBv061zZduHHhN0YgWh.jpg'),
(132110, 9412, 'Haiyore Nyaruko san [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7s1and3IyVGR8L46ngyjR4dSRMx.jpg'),
(132111, 9412, 'Haiyore Nyaruko san [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mA4OJUphXJuREHhyPHy53WRQNTe.jpg'),
(132112, 9412, 'Haiyore Nyaruko san [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jWVdDwLnjJPlEPDorqw1fBHWIMx.jpg'),
(132113, 9412, 'Haiyore Nyaruko san [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lkufID5bzBo7TPrABlRIvsjoWmw.jpg'),
(132114, 9412, 'Haiyore Nyaruko san [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3KkmFE60PRCFA2KYRqOOQEtKD9R.jpg'),
(132115, 9412, 'Haiyore Nyaruko san [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/loe8JpRyQZJZlX4ipW1n47rICl9.jpg'),
(132116, 9412, 'Haiyore Nyaruko san [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5NHr3zyVtobQ1WMTEWnDCbAcQNY.jpg'),
(132117, 9412, 'Haiyore Nyaruko san [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sjt5uIEf0eMxvDREHLLmZaoygBS.jpg'),
(132118, 9413, 'Mahou Shoujo ni Akogarete [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8rDaEiAApIT8Erv9geKTsLBZQ0N.jpg'),
(132119, 9413, 'Mahou Shoujo ni Akogarete [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hGzIjy1iYwhmY2LweJSuUYkhg42.jpg'),
(132120, 9413, 'Mahou Shoujo ni Akogarete [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hGzIjy1iYwhmY2LweJSuUYkhg42.jpg'),
(132121, 9413, 'Mahou Shoujo ni Akogarete [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hGzIjy1iYwhmY2LweJSuUYkhg42.jpg'),
(132122, 9413, 'Mahou Shoujo ni Akogarete [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hGzIjy1iYwhmY2LweJSuUYkhg42.jpg'),
(132123, 9413, 'Mahou Shoujo ni Akogarete [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/272795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hGzIjy1iYwhmY2LweJSuUYkhg42.jpg'),
(132124, 9413, 'Mahou Shoujo ni Akogarete [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/276412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hGzIjy1iYwhmY2LweJSuUYkhg42.jpg'),
(132125, 9413, 'Mahou Shoujo ni Akogarete [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/280768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hGzIjy1iYwhmY2LweJSuUYkhg42.jpg'),
(132126, 9413, 'Mahou Shoujo ni Akogarete [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/287059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hGzIjy1iYwhmY2LweJSuUYkhg42.jpg'),
(132127, 9413, 'Mahou Shoujo ni Akogarete [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/295513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hGzIjy1iYwhmY2LweJSuUYkhg42.jpg'),
(132128, 9413, 'Mahou Shoujo ni Akogarete [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/302583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hGzIjy1iYwhmY2LweJSuUYkhg42.jpg'),
(132129, 9413, 'Mahou Shoujo ni Akogarete [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/308616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hGzIjy1iYwhmY2LweJSuUYkhg42.jpg'),
(132130, 9413, 'Mahou Shoujo ni Akogarete [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/317572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hGzIjy1iYwhmY2LweJSuUYkhg42.jpg'),
(132131, 9414, 'Mato Seihei no Slave [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11dlpT8xwrPfmxwChQQIxXYGLkt.jpg'),
(132132, 9414, 'Mato Seihei no Slave [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ieI3bn3oBKkqbJtYEPiaCV22Gps.jpg'),
(132133, 9414, 'Mato Seihei no Slave [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ieI3bn3oBKkqbJtYEPiaCV22Gps.jpg'),
(132134, 9414, 'Mato Seihei no Slave [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ieI3bn3oBKkqbJtYEPiaCV22Gps.jpg'),
(132135, 9414, 'Mato Seihei no Slave [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/272788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ieI3bn3oBKkqbJtYEPiaCV22Gps.jpg'),
(132136, 9414, 'Mato Seihei no Slave [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/272789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ieI3bn3oBKkqbJtYEPiaCV22Gps.jpg'),
(132137, 9414, 'Mato Seihei no Slave [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/276377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ieI3bn3oBKkqbJtYEPiaCV22Gps.jpg'),
(132138, 9414, 'Mato Seihei no Slave [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/292002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ieI3bn3oBKkqbJtYEPiaCV22Gps.jpg'),
(132139, 9414, 'Mato Seihei no Slave [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/292003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ieI3bn3oBKkqbJtYEPiaCV22Gps.jpg'),
(132140, 9414, 'Mato Seihei no Slave [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/297505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ieI3bn3oBKkqbJtYEPiaCV22Gps.jpg'),
(132141, 9414, 'Mato Seihei no Slave [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/302511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ieI3bn3oBKkqbJtYEPiaCV22Gps.jpg'),
(132142, 9414, 'Mato Seihei no Slave [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/306010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ieI3bn3oBKkqbJtYEPiaCV22Gps.jpg'),
(132143, 9415, 'Mazinkaiser [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJWKn1tiW3fDSYUYPm6SvVJwzFa.jpg'),
(132144, 9415, 'Mazinkaiser [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9AjqxFE5r6NzwGoQAzF9keC7y68.jpg'),
(132145, 9415, 'Mazinkaiser [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sgTPtTRde0I84zsaHHQdotmXIrP.jpg'),
(132146, 9415, 'Mazinkaiser [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AbJm7YyDE9bPOHRaiGTqm4j8xq4.jpg'),
(132147, 9415, 'Mazinkaiser [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hivc7WSLVfr1uU4gnDONbMEgNYz.jpg'),
(132148, 9415, 'Mazinkaiser [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zmemVf7FKSpBd349LcBUydNu47h.jpg'),
(132149, 9415, 'Mazinkaiser [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nftWD4QPTvUMtFP9vEohEUXHDsi.jpg'),
(132150, 9416, 'O Jogo da Morte [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xBQHNp0GeFVo7AkMPqW4pgIPfNT.jpg'),
(132151, 9416, 'O Jogo da Morte [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNX1ciVORz3XoX33VGh9oFZQiXy.jpg'),
(132152, 9416, 'O Jogo da Morte [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PMtPqi76pds24v7MTU1uHjIFzj.jpg'),
(132153, 9416, 'O Jogo da Morte [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qfFgizHPVUlPSFapUCzYZ6sjkQ2.jpg'),
(132154, 9416, 'O Jogo da Morte [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7y1PxmDZUCqFkKeo9lFTxVRkKU.jpg'),
(132155, 9416, 'O Jogo da Morte [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tN5lUukhXBqRIf7UEE15BDYufhA.jpg'),
(132156, 9416, 'O Jogo da Morte [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kfTURRWFBhbucWLQP4N3K3T3U1X.jpg'),
(132157, 9416, 'O Jogo da Morte [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/89VeSJn2KwaFD6nfwGVMfFCX25N.jpg'),
(132158, 9417, 'O Turista [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261319.mp4', 'http://timg.bdta.pro/images/d14aa7f125f6d2614abb3409913acae1.jpg'),
(132159, 9417, 'O Turista [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261320.mp4', 'http://timg.bdta.pro/images/5e8900925f3daf1df31b2ad6c769d4fd.jpg'),
(132160, 9417, 'O Turista [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261321.mp4', 'http://timg.bdta.pro/images/0ecf2aff4fcff5ab3354357e21102b2f.jpg'),
(132161, 9417, 'O Turista [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261322.mp4', 'http://timg.bdta.pro/images/a1c9b008b2ef6ab38b5c145a1e121d7a.jpg'),
(132162, 9417, 'O Turista [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261323.mp4', 'http://timg.bdta.pro/images/a624ae2689b5d7d68c5a932c49a6ea3b.jpg'),
(132163, 9417, 'O Turista [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261324.mp4', 'http://timg.bdta.pro/images/b7ca9269f862310cb2afeb8f9b6c853c.jpg'),
(132164, 9418, 'O Turista [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261325.mp4', 'http://gstaticontent.com/images/0dc3efbeac3ff0f415eca03151697aa5.jpg'),
(132165, 9418, 'O Turista [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261326.mp4', 'http://gstaticontent.com/images/0dc3efbeac3ff0f415eca03151697aa5.jpg'),
(132166, 9418, 'O Turista [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261327.mp4', 'http://gstaticontent.com/images/0dc3efbeac3ff0f415eca03151697aa5.jpg'),
(132167, 9418, 'O Turista [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261328.mp4', 'http://gstaticontent.com/images/0dc3efbeac3ff0f415eca03151697aa5.jpg'),
(132168, 9418, 'O Turista [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261329.mp4', 'http://gstaticontent.com/images/0dc3efbeac3ff0f415eca03151697aa5.jpg'),
(132169, 9418, 'O Turista [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261330.mp4', 'http://gstaticontent.com/images/0dc3efbeac3ff0f415eca03151697aa5.jpg'),
(132170, 9419, 'Power of Hope Precure Full Bloom [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9FQSTIg1lrFpSK7WFUN9SYh426v.jpg'),
(132171, 9419, 'Power of Hope Precure Full Bloom [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dRrTeOaU7jGjbZwXlHe6tul3Bpo.jpg'),
(132172, 9419, 'Power of Hope Precure Full Bloom [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iagoqu4zwfjkAcleEQOxQ3exeHe.jpg'),
(132173, 9419, 'Power of Hope Precure Full Bloom [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qwmphHcywjwaapSz6X2huF0Zq4l.jpg'),
(132174, 9419, 'Power of Hope Precure Full Bloom [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2VtjGXczcFkjIXmOR6Ay4hqk9q.jpg'),
(132175, 9419, 'Power of Hope Precure Full Bloom [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tO59rXm8GMSFJrOZyUQ6tWd70HD.jpg'),
(132176, 9419, 'Power of Hope Precure Full Bloom [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shneLiWk9siokvWm2q17My7G3GK.jpg'),
(132177, 9419, 'Power of Hope Precure Full Bloom [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cU7xzjdh3rvSeHn2Ab0JYeHvDG1.jpg'),
(132178, 9419, 'Power of Hope Precure Full Bloom [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wjoXOejy2pskaALrrPdbJc72UKA.jpg'),
(132179, 9419, 'Power of Hope Precure Full Bloom [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kicrdik1qDo0j52nvn0i1su9M3S.jpg'),
(132180, 9419, 'Power of Hope Precure Full Bloom [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zXJpIdWqsmju8GKBLQQPPigYFsM.jpg'),
(132181, 9419, 'Power of Hope Precure Full Bloom [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wu4qNChKCwKkUsa8yWQcObEXENt.jpg'),
(132182, 9420, 'Rakshasa Street [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fFyWGqPf9OZeEDWdocKsdzl6L6Y.jpg'),
(132183, 9420, 'Rakshasa Street [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5JR62MDHCtG6LcgTISSMt1UShkx.jpg'),
(132184, 9420, 'Rakshasa Street [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ejQi8j3Ysh1edwpJRaZHMMHNdbF.jpg'),
(132185, 9420, 'Rakshasa Street [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bo3qXWBQFot5uMuXxsf0P4Gbrr8.jpg'),
(132186, 9420, 'Rakshasa Street [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8NTKKncrakuTreJvBYSpTadbTHy.jpg'),
(132187, 9420, 'Rakshasa Street [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sktHMLh2hVHCO0WJT2V6V6aWJzH.jpg'),
(132188, 9420, 'Rakshasa Street [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fxyNv3Av0wtEKEwQy1jwbyUsabm.jpg'),
(132189, 9420, 'Rakshasa Street [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d5irxxVZPe15sFXZb7jj5M2AUXo.jpg'),
(132190, 9420, 'Rakshasa Street [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cWZUnvDWQMrYo8LG9bnoxPl5Utw.jpg'),
(132191, 9420, 'Rakshasa Street [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rSM5lhy8btA3gSDrwzA25Pu3qmI.jpg'),
(132192, 9420, 'Rakshasa Street [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfqMlVJviysN8yjzed6uUF2kZVW.jpg'),
(132193, 9420, 'Rakshasa Street [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dOrKrDG6G7KAq4vGl1Dx5s91Qgn.jpg'),
(132194, 9420, 'Rakshasa Street [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uQ7Azyx5uSYE7nCzOfrtib4xM5E.jpg'),
(132195, 9420, 'Rakshasa Street [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rf3PYFYNlaPek5SXKb4i6bok2zQ.jpg'),
(132196, 9420, 'Rakshasa Street [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqBIrDPPhHukfXCqlaknsXIEO0U.jpg'),
(132197, 9420, 'Rakshasa Street [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9cj0xYT1JECUolXvIxxUPZrP9E2.jpg'),
(132198, 9420, 'Rakshasa Street [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wDEpGfDxtegsZS3gEWO79h1fdex.jpg'),
(132199, 9420, 'Rakshasa Street [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rlS6VCLCSNyitfa7UiWoaEVkgEi.jpg'),
(132200, 9420, 'Rakshasa Street [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3SFo20Dvk3Ij0PMsN4ZoQM4SwnJ.jpg'),
(132201, 9420, 'Rakshasa Street [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tsafZxewX45tHvtDNDnLT7DDOSr.jpg'),
(132202, 9420, 'Rakshasa Street [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/khO2KFzlom6kkHzSGz1xJxUVSEX.jpg'),
(132203, 9420, 'Rakshasa Street [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/az1DgBbLnuxLtz5w7oxL3pCwR0x.jpg'),
(132204, 9420, 'Rakshasa Street [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/260162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oT5ajbG2gEijkpw8LgZ1q2VuRin.jpg'),
(132205, 9420, 'Rakshasa Street [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/260163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b6VVUszO2N4L6z8o3M8VSOVvc6R.jpg'),
(132206, 9421, 'Rakshasa Street [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/angCF3tK88s8nxbO8Ngt1k6W6m5.jpg'),
(132207, 9421, 'Rakshasa Street [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o12WFrrogsZIIs9KgcQfF75wkno.jpg'),
(132208, 9421, 'Rakshasa Street [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cCXNwG4ZP7DynZgNPylnbrNHOX9.jpg'),
(132209, 9421, 'Rakshasa Street [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/clUTs018wjY6PrIfq0tM2BgC2cZ.jpg'),
(132210, 9421, 'Rakshasa Street [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2dCti8g1H6PxYuWfTeoOREHkl1v.jpg'),
(132211, 9421, 'Rakshasa Street [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uQ9zplgjBV4UAfeHBLoy0x787zy.jpg'),
(132212, 9421, 'Rakshasa Street [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tlytWGCYZ9KtTjGG3YhG9h0lJ53.jpg'),
(132213, 9421, 'Rakshasa Street [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8HnlFwO65AIjI3d2gzh1zz3kRJs.jpg'),
(132214, 9421, 'Rakshasa Street [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3mxlX10hIBSvyuj8yv0WJpZ6gGB.jpg'),
(132215, 9421, 'Rakshasa Street [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/miN5H3cRtowWadhITzqpzW1bLc.jpg'),
(132216, 9422, 'Rakshasa Street [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/463797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h52JLVCrMofAV6tKjVHhK3uhrAN.jpg'),
(132217, 9422, 'Rakshasa Street [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/463798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h52JLVCrMofAV6tKjVHhK3uhrAN.jpg'),
(132218, 9422, 'Rakshasa Street [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/463799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h52JLVCrMofAV6tKjVHhK3uhrAN.jpg'),
(132219, 9422, 'Rakshasa Street [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/463800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h52JLVCrMofAV6tKjVHhK3uhrAN.jpg'),
(132220, 9422, 'Rakshasa Street [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/463801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h52JLVCrMofAV6tKjVHhK3uhrAN.jpg'),
(132221, 9422, 'Rakshasa Street [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/463802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h52JLVCrMofAV6tKjVHhK3uhrAN.jpg'),
(132222, 9422, 'Rakshasa Street [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/463803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h52JLVCrMofAV6tKjVHhK3uhrAN.jpg'),
(132223, 9422, 'Rakshasa Street [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/463804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h52JLVCrMofAV6tKjVHhK3uhrAN.jpg'),
(132224, 9422, 'Rakshasa Street [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/463805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h52JLVCrMofAV6tKjVHhK3uhrAN.jpg'),
(132225, 9422, 'Rakshasa Street [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/463806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h52JLVCrMofAV6tKjVHhK3uhrAN.jpg'),
(132226, 9422, 'Rakshasa Street [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/463807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h52JLVCrMofAV6tKjVHhK3uhrAN.jpg'),
(132227, 9422, 'Rakshasa Street [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/463808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h52JLVCrMofAV6tKjVHhK3uhrAN.jpg'),
(132228, 9422, 'Rakshasa Street [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/463809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h52JLVCrMofAV6tKjVHhK3uhrAN.jpg'),
(132229, 9422, 'Rakshasa Street [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/463810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h52JLVCrMofAV6tKjVHhK3uhrAN.jpg'),
(132230, 9422, 'Rakshasa Street [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/463811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h52JLVCrMofAV6tKjVHhK3uhrAN.jpg'),
(132231, 9422, 'Rakshasa Street [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/463812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h52JLVCrMofAV6tKjVHhK3uhrAN.jpg'),
(132232, 9423, 'Sobrevivi por Sorte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b70RBjvzxfKZXmjAFxYdR2bJiNK.jpg'),
(132233, 9423, 'Sobrevivi por Sorte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b70RBjvzxfKZXmjAFxYdR2bJiNK.jpg'),
(132234, 9423, 'Sobrevivi por Sorte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b70RBjvzxfKZXmjAFxYdR2bJiNK.jpg'),
(132235, 9423, 'Sobrevivi por Sorte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b70RBjvzxfKZXmjAFxYdR2bJiNK.jpg'),
(132236, 9423, 'Sobrevivi por Sorte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b70RBjvzxfKZXmjAFxYdR2bJiNK.jpg'),
(132237, 9423, 'Sobrevivi por Sorte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b70RBjvzxfKZXmjAFxYdR2bJiNK.jpg'),
(132238, 9423, 'Sobrevivi por Sorte S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b70RBjvzxfKZXmjAFxYdR2bJiNK.jpg'),
(132239, 9423, 'Sobrevivi por Sorte S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b70RBjvzxfKZXmjAFxYdR2bJiNK.jpg'),
(132240, 9423, 'Sobrevivi por Sorte S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b70RBjvzxfKZXmjAFxYdR2bJiNK.jpg'),
(132241, 9423, 'Sobrevivi por Sorte S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b70RBjvzxfKZXmjAFxYdR2bJiNK.jpg'),
(132242, 9423, 'Sobrevivi por Sorte S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b70RBjvzxfKZXmjAFxYdR2bJiNK.jpg'),
(132243, 9423, 'Sobrevivi por Sorte S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b70RBjvzxfKZXmjAFxYdR2bJiNK.jpg'),
(132244, 9423, 'Sobrevivi por Sorte S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b70RBjvzxfKZXmjAFxYdR2bJiNK.jpg'),
(132245, 9423, 'Sobrevivi por Sorte S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b70RBjvzxfKZXmjAFxYdR2bJiNK.jpg'),
(132246, 9424, 'The Demon Prince of Momochi House [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/js5VSmUkBDReyHcgOOBHYxXbWvb.jpg'),
(132247, 9424, 'The Demon Prince of Momochi House [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6CHvOjWVxWQkcRKc4iijHIReACY.jpg'),
(132248, 9424, 'The Demon Prince of Momochi House [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6CHvOjWVxWQkcRKc4iijHIReACY.jpg'),
(132249, 9424, 'The Demon Prince of Momochi House [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6CHvOjWVxWQkcRKc4iijHIReACY.jpg'),
(132250, 9424, 'The Demon Prince of Momochi House [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6CHvOjWVxWQkcRKc4iijHIReACY.jpg'),
(132251, 9424, 'The Demon Prince of Momochi House [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/272509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6CHvOjWVxWQkcRKc4iijHIReACY.jpg'),
(132252, 9424, 'The Demon Prince of Momochi House [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/275031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6CHvOjWVxWQkcRKc4iijHIReACY.jpg'),
(132253, 9424, 'The Demon Prince of Momochi House [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/307149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6CHvOjWVxWQkcRKc4iijHIReACY.jpg'),
(132254, 9424, 'The Demon Prince of Momochi House [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/307150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6CHvOjWVxWQkcRKc4iijHIReACY.jpg'),
(132255, 9424, 'The Demon Prince of Momochi House [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/307151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6CHvOjWVxWQkcRKc4iijHIReACY.jpg'),
(132256, 9424, 'The Demon Prince of Momochi House [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/307152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6CHvOjWVxWQkcRKc4iijHIReACY.jpg'),
(132257, 9424, 'The Demon Prince of Momochi House [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/307153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6CHvOjWVxWQkcRKc4iijHIReACY.jpg'),
(132258, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGqgOMCuYJEcPbHhZDGX2vMiAoG.jpg'),
(132259, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m6aT4dDkd5fI4X2nVb055T5ymJh.jpg'),
(132260, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m18g4vMG7Uda3ROv7FP4KuAMpMx.jpg'),
(132261, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shsZqSkqo5CWN6ecZstG7dOgYGb.jpg'),
(132262, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rInUnnK8aK0QZH4o7Gn3QSO06iM.jpg'),
(132263, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i51iCGOyMb4VscpDOvUqbVXntqi.jpg'),
(132264, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iyF9cEjbvpu20cx0IpPrAXzpay3.jpg'),
(132265, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/caX5CUxE7sm13wGdR4O5AqpCVej.jpg'),
(132266, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tLPtYiIli8oppPG8NzFqXbR3NQc.jpg'),
(132267, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4YB32KAKSAZWgpSvm1HS9btavlS.jpg'),
(132268, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jRIiZwB8sS44GJ7yzrPMIHtOdrr.jpg'),
(132269, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132270, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132271, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(132272, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/268960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132273, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/295185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132274, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/295186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132275, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/295187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132276, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/295188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132277, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/295189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132278, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/299754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132279, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/313107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132280, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/313108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132281, 9425, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/319254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132282, 9426, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/513927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132283, 9426, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/513928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132284, 9426, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/513929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132285, 9426, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/513930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132286, 9426, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/513931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132287, 9426, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/513932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132288, 9426, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/635956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132289, 9426, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/635957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132290, 9426, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/639915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132291, 9426, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/657408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132292, 9426, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/657409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132293, 9426, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/657410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/knOEGRfSV8RTrBFbdd2eXF0w10q.jpg'),
(132294, 9427, 'Treinador Prime [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/beOJvzmJ30HYYbkz3DIwokjotAh.jpg'),
(132295, 9427, 'Treinador Prime [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vq5gmoif3U3KTEm0oS6ZxHA17To.jpg'),
(132296, 9427, 'Treinador Prime [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o8TA8WRjoVwjkShm9GrbO8ODxM8.jpg'),
(132297, 9427, 'Treinador Prime [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfbs7yVFOZirUl7ZwtwjkAEg1MH.jpg'),
(132298, 9428, 'Treinador Prime [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJcGSeKlhrl3KBAbwAWkkLsiyBp.jpg'),
(132299, 9428, 'Treinador Prime [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rufWcJti7VxPdXsRq0QrbpIK9sg.jpg'),
(132300, 9428, 'Treinador Prime [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/er4wM1Ixo9QCXBR7QYjSVatsVZu.jpg'),
(132301, 9428, 'Treinador Prime [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o5IR5sGSzdwg6tnlo2VoM1vbdZR.jpg'),
(132302, 9428, 'Treinador Prime [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Gk3MQXcueJJYiIFNnzLPCjrQmO.jpg'),
(132303, 9428, 'Treinador Prime [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dcuhfvOiNEJFE7KS4AMKKJnZOsr.jpg'),
(132304, 9429, 'Zombie Loan [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/51JT43chGaLlkARKuLmsHLZOQXO.jpg'),
(132305, 9429, 'Zombie Loan [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6GAUZMMX9DVMdE415Y9qmBfofgt.jpg'),
(132306, 9429, 'Zombie Loan [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z4sq23YeztKVBvaYzghxzxk1vMO.jpg'),
(132307, 9429, 'Zombie Loan [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qtrFljBMX2JmjOZuGDbncRrrOoW.jpg'),
(132308, 9429, 'Zombie Loan [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2nE95rzEGlXOP89mRKnvvfd2Xp8.jpg'),
(132309, 9429, 'Zombie Loan [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lyB3ZxVRgfWlHEgegH1JTnw6Jsk.jpg'),
(132310, 9429, 'Zombie Loan [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gprjdEKsaCcHLLDTRSQX4wjVH5u.jpg'),
(132311, 9429, 'Zombie Loan [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zSJITV1CyB86CeTNDRqAhzeZczq.jpg'),
(132312, 9429, 'Zombie Loan [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3UySXlqdfGG9RyIkVYTtZGRbNoq.jpg'),
(132313, 9429, 'Zombie Loan [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/81yBn6T0NFbzZ1rHmgQNkyDcv2o.jpg'),
(132314, 9429, 'Zombie Loan [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/evKx5JX6C4DzgvKtvGeg80B3LfO.jpg'),
(132315, 9429, 'Zombie Loan [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lcfubN14JxIFpUjtG03xdhp4GTQ.jpg'),
(132316, 9429, 'Zombie Loan [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lcfubN14JxIFpUjtG03xdhp4GTQ.jpg'),
(132317, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6apLvqM2XxGOSDc3iiZavSpA7g1.jpg'),
(132318, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j1N6wAfJn81OJ6rEZOFrVDVvWC4.jpg'),
(132319, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j42M4lpK69NpF4gU4Lw0o7FqV3o.jpg'),
(132320, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kmRcGjDMpaRG1z797XQ9PauQ84.jpg'),
(132321, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTVhfhZ6CzO12hfry5Hz0wwBzHF.jpg'),
(132322, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AhWiEA9V1tmB3Mzsp46CGkXAHpq.jpg'),
(132323, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a1JL4ma0itOLJ0e9d8PgYODwm2z.jpg'),
(132324, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/598301.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vve1ihB5QjjJ0k83wkduVYs6EHQ.jpg'),
(132325, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/frw2rWChuvvkZqxT7kwJ1RpmmRj.jpg'),
(132326, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svxi7Q1N9vsDKMk5pUuo0niK6gM.jpg'),
(132327, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bxzuA2JXNZKGgjfRPnNLZ0aYoVH.jpg'),
(132328, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kCkCq22yOwHbjdoutVUZyYvaSYe.jpg'),
(132329, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/264920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iCLITSmiqOUpS7bU5NxNkUkP8Dz.jpg'),
(132330, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/264921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nP8D7JZPuqyBHSyYGE9EkSQ6tRS.jpg'),
(132331, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/264922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nP8D7JZPuqyBHSyYGE9EkSQ6tRS.jpg'),
(132332, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/264923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nP8D7JZPuqyBHSyYGE9EkSQ6tRS.jpg'),
(132333, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/264924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nP8D7JZPuqyBHSyYGE9EkSQ6tRS.jpg'),
(132334, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/292796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nP8D7JZPuqyBHSyYGE9EkSQ6tRS.jpg'),
(132335, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/292797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nP8D7JZPuqyBHSyYGE9EkSQ6tRS.jpg'),
(132336, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/292798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nP8D7JZPuqyBHSyYGE9EkSQ6tRS.jpg'),
(132337, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/297941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nP8D7JZPuqyBHSyYGE9EkSQ6tRS.jpg'),
(132338, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/304702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nP8D7JZPuqyBHSyYGE9EkSQ6tRS.jpg'),
(132339, 9430, 'Firefighter Daigo Rescuer in Orange [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/308916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nP8D7JZPuqyBHSyYGE9EkSQ6tRS.jpg'),
(132340, 9412, 'Haiyore Nyaruko san [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7OeUykouD4vX3Wxv7ReFCARusqA.jpg'),
(132341, 9412, 'Haiyore Nyaruko san [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vbbfUbjvkXn9KwsamsISAKmvHH3.jpg'),
(132342, 9412, 'Haiyore Nyaruko san [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVhhiYcMfvC751y2hPMPQgXxWpR.jpg'),
(132343, 9412, 'Haiyore Nyaruko san [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5IeCdzbnwBv061zZduHHhN0YgWh.jpg'),
(132344, 9412, 'Haiyore Nyaruko san [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7s1and3IyVGR8L46ngyjR4dSRMx.jpg'),
(132345, 9412, 'Haiyore Nyaruko san [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mA4OJUphXJuREHhyPHy53WRQNTe.jpg'),
(132346, 9412, 'Haiyore Nyaruko san [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jWVdDwLnjJPlEPDorqw1fBHWIMx.jpg'),
(132347, 9412, 'Haiyore Nyaruko san [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lkufID5bzBo7TPrABlRIvsjoWmw.jpg'),
(132348, 9412, 'Haiyore Nyaruko san [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3KkmFE60PRCFA2KYRqOOQEtKD9R.jpg'),
(132349, 9412, 'Haiyore Nyaruko san [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/loe8JpRyQZJZlX4ipW1n47rICl9.jpg'),
(132350, 9412, 'Haiyore Nyaruko san [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5NHr3zyVtobQ1WMTEWnDCbAcQNY.jpg'),
(132351, 9412, 'Haiyore Nyaruko san [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sjt5uIEf0eMxvDREHLLmZaoygBS.jpg'),
(132352, 9431, 'The Ancient Magus Bride [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvIikSYZE8BFH1gWWAWgyWuwEZ6.jpg'),
(132353, 9431, 'The Ancient Magus Bride [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ecygMmcHvJ2zrSsmnxFqYQxFQol.jpg'),
(132354, 9431, 'The Ancient Magus Bride [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/osd97AEyVlupNrTU4LDQ3sZLFBL.jpg'),
(132355, 9431, 'The Ancient Magus Bride [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/unp6Qfhl0XIY38sjaKrNb7uAf2n.jpg'),
(132356, 9431, 'The Ancient Magus Bride [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gwvoeZGfqylYjRce0gedBZEZZkm.jpg'),
(132357, 9431, 'The Ancient Magus Bride [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ko7FqD2KoYx9QOS06kbqMxDYWDX.jpg'),
(132358, 9431, 'The Ancient Magus Bride [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uWM90RulIWtIpWlWY3OWwHvMLx4.jpg'),
(132359, 9431, 'The Ancient Magus Bride [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o492t7rCXRG9rbDFYzWEe8abUiT.jpg'),
(132360, 9431, 'The Ancient Magus Bride [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eYEeZxyrwykLNPsY9JSoM6kOlHY.jpg'),
(132361, 9431, 'The Ancient Magus Bride [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oWtyFEYDN1YH6OKnvClsOdZ1NdQ.jpg'),
(132362, 9431, 'The Ancient Magus Bride [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k3WSOsxQJqxnD1VZXYLdHtY1R7f.jpg'),
(132363, 9431, 'The Ancient Magus Bride [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/apquDLY1SWqGVw28VDicdgk51ot.jpg'),
(132364, 9431, 'The Ancient Magus Bride [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjM1tEOhg3BIpjztmXvhmSDJQXY.jpg'),
(132365, 9431, 'The Ancient Magus Bride [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9j0jkGLf5u58ugzbPDUN0abc6P4.jpg'),
(132366, 9431, 'The Ancient Magus Bride [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ycAOo3rBdAt5lZXnzDhC2Gs0Mo.jpg'),
(132367, 9431, 'The Ancient Magus Bride [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ehEI7CfDcWhLyGkJA5iS4Bia7eG.jpg'),
(132368, 9431, 'The Ancient Magus Bride [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/coIHUREy4HkQr7SBFrwtCN78c7I.jpg'),
(132369, 9431, 'The Ancient Magus Bride [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xMJTBESZhJ87ZbSnBAhKFmTtofU.jpg'),
(132370, 9431, 'The Ancient Magus Bride [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8i2P61pmEAn23PCqJCHnqMWr0Sf.jpg'),
(132371, 9431, 'The Ancient Magus Bride [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3LlzQKtGVTVhrm1m5Z96h3EBhQM.jpg'),
(132372, 9431, 'The Ancient Magus Bride [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2qJra4mJHkoFgM4YIC8QtKaKazf.jpg'),
(132373, 9431, 'The Ancient Magus Bride [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6BJucnqvhrgPHgfApZOIisvrzo.jpg'),
(132374, 9431, 'The Ancient Magus Bride [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/260065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eSXYmB8rxGB1nZkvVIeHSdfUHDq.jpg'),
(132375, 9431, 'The Ancient Magus Bride [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/260066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uTQ82zIGuvgSBAmD0JiHcAgZHma.jpg'),
(132376, 9432, 'The Ancient Magus Bride [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6dEQjN5auGtnP3SrhzVOwLxBUX8.jpg'),
(132377, 9432, 'The Ancient Magus Bride [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/83dYre3iSOvPf3EvUmnVqgGMjIw.jpg'),
(132378, 9432, 'The Ancient Magus Bride [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kFau4Dymgpc4miHnPC32oiMm3fe.jpg'),
(132379, 9432, 'The Ancient Magus Bride [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eJFng4qIdNuqrJXg0tOoW5gshxx.jpg'),
(132380, 9432, 'The Ancient Magus Bride [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mSVcNhpjgc7BEhL8sWSXrnytuy1.jpg'),
(132381, 9432, 'The Ancient Magus Bride [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gxu99Uk0vq1jpxUUUFpPxZQZERv.jpg'),
(132382, 9432, 'The Ancient Magus Bride [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zRuFc1VZpez7u9ox0N7D5c7IORq.jpg'),
(132383, 9432, 'The Ancient Magus Bride [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/frovyQS7l07oJGqCfqsVgWB1Ezt.jpg'),
(132384, 9432, 'The Ancient Magus Bride [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kRa6nKK49MDcjtCTcwfM2Jq4EdW.jpg'),
(132385, 9432, 'The Ancient Magus Bride [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cAgbDhhSzkA569Gz6fkKcjvJLSW.jpg'),
(132386, 9432, 'The Ancient Magus Bride [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hTx9WpjETmq9aS0fqHMJXn0qsJv.jpg'),
(132387, 9432, 'The Ancient Magus Bride [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Q0EWy0prsJF2scE4fe2EeZTT7f.jpg'),
(132388, 9432, 'The Ancient Magus Bride [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/260079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ojwipHmjabXGg7ZsNrcklchtcUz.jpg'),
(132389, 9432, 'The Ancient Magus Bride [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/260080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rKwcBGJkw7vPtUdnc2paBaNiOVk.jpg'),
(132390, 9432, 'The Ancient Magus Bride [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/260081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dEyxkBpq7yT8rLKnHTj7sYKXzrZ.jpg'),
(132391, 9432, 'The Ancient Magus Bride [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/260082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4HYFoOr0sZ5v3WAOwcT59CA7m2j.jpg'),
(132392, 9432, 'The Ancient Magus Bride [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/260083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fjYsARisjooQfxahVrr1XBlpcbB.jpg'),
(132393, 9432, 'The Ancient Magus Bride [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/260084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/liiCzhhDoCFSfG8gqlajih8Qwiz.jpg'),
(132394, 9432, 'The Ancient Magus Bride [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/260085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wJjcEinBzxe6EdO5pSJSbnK9LuC.jpg'),
(132395, 9432, 'The Ancient Magus Bride [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/260086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d2gck6rRjqPbpSR3WWSYbC7FdH9.jpg'),
(132396, 9432, 'The Ancient Magus Bride [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/260087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8UZ6nokZkSGWp2ttLgBUpp2Z3sz.jpg'),
(132397, 9432, 'The Ancient Magus Bride [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/260088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9kvpYB2IW17uKinW5gY1HzvB9d7.jpg'),
(132398, 9432, 'The Ancient Magus Bride [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/260089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mKHCw6MNMlruAAOxChKNDQGWpb3.jpg'),
(132399, 9432, 'The Ancient Magus Bride [L] S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/260090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s6Y3bGAbC5waaRQVImbXDvuJBp3.jpg'),
(132400, 9433, 'A Sign of Affection [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7W3H0bfSiZrd1ymSMJqQCnigPg3.jpg'),
(132401, 9433, 'A Sign of Affection [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WJZiR1lRoa80tkWrR2U2IQm9rO.jpg'),
(132402, 9433, 'A Sign of Affection [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WJZiR1lRoa80tkWrR2U2IQm9rO.jpg'),
(132403, 9433, 'A Sign of Affection [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/598431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WJZiR1lRoa80tkWrR2U2IQm9rO.jpg'),
(132404, 9433, 'A Sign of Affection [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/276962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WJZiR1lRoa80tkWrR2U2IQm9rO.jpg'),
(132405, 9433, 'A Sign of Affection [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/276963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WJZiR1lRoa80tkWrR2U2IQm9rO.jpg'),
(132406, 9433, 'A Sign of Affection [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WJZiR1lRoa80tkWrR2U2IQm9rO.jpg'),
(132407, 9433, 'A Sign of Affection [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WJZiR1lRoa80tkWrR2U2IQm9rO.jpg'),
(132408, 9433, 'A Sign of Affection [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/298544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WJZiR1lRoa80tkWrR2U2IQm9rO.jpg'),
(132409, 9433, 'A Sign of Affection [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/303127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WJZiR1lRoa80tkWrR2U2IQm9rO.jpg'),
(132410, 9433, 'A Sign of Affection [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/309416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WJZiR1lRoa80tkWrR2U2IQm9rO.jpg'),
(132411, 9434, 'A Vida Secreta da Minha Secretaria [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8N6kEKxuUJctsttVgXzzcX2ZDV4.jpg'),
(132412, 9434, 'A Vida Secreta da Minha Secretaria [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A9kgopNiBirP1ZuefGy2uNh6Vy2.jpg'),
(132413, 9434, 'A Vida Secreta da Minha Secretaria [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b9d1nR8tCE2jsjPU07czZbM3Fbm.jpg'),
(132414, 9434, 'A Vida Secreta da Minha Secretaria [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qg4KgGbKi9PpbI0EA0mubmc4svj.jpg'),
(132415, 9434, 'A Vida Secreta da Minha Secretaria [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zgmGImiXyLNqrxcJfqwB2TKU75M.jpg'),
(132416, 9434, 'A Vida Secreta da Minha Secretaria [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oBYgnISwZwlMdWxSuymRDlZMeMJ.jpg'),
(132417, 9434, 'A Vida Secreta da Minha Secretaria [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bIuIztnwKBhAoCpVGcYa9J4WY9r.jpg'),
(132418, 9434, 'A Vida Secreta da Minha Secretaria [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOfsPQ1S0GM8fqnheliWXpdPNoH.jpg'),
(132419, 9434, 'A Vida Secreta da Minha Secretaria [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLAGO7mQfGJoaGjF09HY61tNqLy.jpg'),
(132420, 9434, 'A Vida Secreta da Minha Secretaria [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkZs5CLF3chrlVL6VdRvACCFAdH.jpg'),
(132421, 9434, 'A Vida Secreta da Minha Secretaria [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHDb2DA5KC3uv1QopXItoNYhQTJ.jpg'),
(132422, 9434, 'A Vida Secreta da Minha Secretaria [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mu2pClTHSzmJ4jrj5ufgsSHuzed.jpg'),
(132423, 9434, 'A Vida Secreta da Minha Secretaria [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nvcRW0dhgHxTKqi8fg3vpkrcugy.jpg'),
(132424, 9434, 'A Vida Secreta da Minha Secretaria [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/259969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4kZfBp5lywz2GyFm87ylmpBUaTv.jpg'),
(132425, 9434, 'A Vida Secreta da Minha Secretaria [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/259970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yVju91y5pWKJDwIXashzDsHvjVr.jpg'),
(132426, 9434, 'A Vida Secreta da Minha Secretaria [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/259971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bkgog0I1xmJd5AULA1l9HO1SHGA.jpg'),
(132427, 9435, 'Almas Perdidas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hlxeK4x1WM1EQrXdwNneMpvmKno.jpg'),
(132428, 9435, 'Almas Perdidas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Cxi9VxecbgfC2EiLWaYMUlTD5M.jpg'),
(132429, 9435, 'Almas Perdidas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132430, 9435, 'Almas Perdidas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132431, 9435, 'Almas Perdidas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132432, 9435, 'Almas Perdidas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132433, 9435, 'Almas Perdidas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132434, 9435, 'Almas Perdidas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132435, 9436, 'Almas Perdidas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132436, 9436, 'Almas Perdidas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132437, 9436, 'Almas Perdidas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132438, 9436, 'Almas Perdidas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132439, 9436, 'Almas Perdidas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132440, 9436, 'Almas Perdidas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132441, 9436, 'Almas Perdidas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132442, 9436, 'Almas Perdidas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132443, 9436, 'Almas Perdidas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132444, 9436, 'Almas Perdidas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132445, 9437, 'Almas Perdidas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132446, 9437, 'Almas Perdidas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132447, 9437, 'Almas Perdidas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132448, 9437, 'Almas Perdidas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132449, 9437, 'Almas Perdidas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132450, 9437, 'Almas Perdidas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132451, 9437, 'Almas Perdidas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132452, 9437, 'Almas Perdidas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132453, 9437, 'Almas Perdidas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132454, 9438, 'Almas Perdidas S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132455, 9438, 'Almas Perdidas S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132456, 9438, 'Almas Perdidas S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132457, 9438, 'Almas Perdidas S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132458, 9438, 'Almas Perdidas S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132459, 9438, 'Almas Perdidas S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132460, 9438, 'Almas Perdidas S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132461, 9438, 'Almas Perdidas S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132462, 9438, 'Almas Perdidas S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132463, 9438, 'Almas Perdidas S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132464, 9439, 'Almas Perdidas S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132465, 9439, 'Almas Perdidas S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132466, 9439, 'Almas Perdidas S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132467, 9439, 'Almas Perdidas S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132468, 9439, 'Almas Perdidas S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132469, 9439, 'Almas Perdidas S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132470, 9439, 'Almas Perdidas S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132471, 9439, 'Almas Perdidas S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/508046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132472, 9439, 'Almas Perdidas S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/508047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132473, 9439, 'Almas Perdidas S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/508048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132474, 9440, 'Almas Perdidas S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132475, 9440, 'Almas Perdidas S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/628858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132476, 9440, 'Almas Perdidas S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132477, 9440, 'Almas Perdidas S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/628860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132478, 9440, 'Almas Perdidas S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/659854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132479, 9440, 'Almas Perdidas S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/659855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132480, 9440, 'Almas Perdidas S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/659856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132481, 9440, 'Almas Perdidas S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/659857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132482, 9440, 'Almas Perdidas S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/659858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132483, 9440, 'Almas Perdidas S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/659859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ9kL02N7zHqA8o6pBvLWKPJ4AS.jpg'),
(132484, 9441, 'As Meninas Superpoderosas (1998) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xEkS0FLyWa6iIds5VQbBjQ1Tw4x.jpg'),
(132485, 9441, 'As Meninas Superpoderosas (1998) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vRmTRxfIPNcos3pZQFBziLysKHQ.jpg'),
(132486, 9441, 'As Meninas Superpoderosas (1998) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dnWscQu74kyC3nvL7Z30rGals0Y.jpg'),
(132487, 9441, 'As Meninas Superpoderosas (1998) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hAwrB8ixwjfkln5oPdnlbguui91.jpg'),
(132488, 9441, 'As Meninas Superpoderosas (1998) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dedrMGzls5N9Ltj6BrHrE30AbhA.jpg'),
(132489, 9441, 'As Meninas Superpoderosas (1998) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ghbfjjAJlkYPwHV1I4nwfDUfDHG.jpg'),
(132490, 9441, 'As Meninas Superpoderosas (1998) S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5xU0Yobu4gqOwxuKmadbXvJtM2U.jpg'),
(132491, 9441, 'As Meninas Superpoderosas (1998) S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cCCIn0TJiUlQcLShjyDwi11bUOz.jpg'),
(132492, 9441, 'As Meninas Superpoderosas (1998) S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8YnOtWkYq6kbAp7I73VKbtK1GSS.jpg'),
(132493, 9441, 'As Meninas Superpoderosas (1998) S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/owggmfaklGtmwZxHATm4w39DwBF.jpg'),
(132494, 9441, 'As Meninas Superpoderosas (1998) S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e5eLNZLGtFVEBGDe9WUwGSKvTSt.jpg'),
(132495, 9441, 'As Meninas Superpoderosas (1998) S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dAFKB5uPv7raUQCBTKSoQpW7iTs.jpg'),
(132496, 9441, 'As Meninas Superpoderosas (1998) S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/S89XtEEU7cDHYT3T8gz8Jus1L7.jpg'),
(132497, 9442, 'As Meninas Superpoderosas (1998) S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s8se93NhL5TQdrYePBzyRo32Cns.jpg'),
(132498, 9442, 'As Meninas Superpoderosas (1998) S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fY1KRU6TSi7n3sN10muJdHflP4E.jpg'),
(132499, 9442, 'As Meninas Superpoderosas (1998) S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aTE0g71iAUg8K7rO9cuSCI2J6Ta.jpg'),
(132500, 9442, 'As Meninas Superpoderosas (1998) S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vWAXloCrR6Cp6z0h4yTKOQkskLN.jpg'),
(132501, 9442, 'As Meninas Superpoderosas (1998) S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tnxlLUZkCiHlwW7TNuJO9RKZRo6.jpg'),
(132502, 9442, 'As Meninas Superpoderosas (1998) S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bbMLj3zZNkLlj37phnhajXwHfzr.jpg'),
(132503, 9442, 'As Meninas Superpoderosas (1998) S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fTy5vILPEfjI7BZTQNIxsH7ZiZP.jpg'),
(132504, 9442, 'As Meninas Superpoderosas (1998) S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/GkSfbscVztW2FEB8dAGd9L5xw8.jpg'),
(132505, 9442, 'As Meninas Superpoderosas (1998) S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hrIRT3mh2KOwXgX8vP234vOHrDv.jpg'),
(132506, 9442, 'As Meninas Superpoderosas (1998) S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yRiCUQlX8uQj6LezmwPZGSIeOn6.jpg'),
(132507, 9442, 'As Meninas Superpoderosas (1998) S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2obqIi4KjG9oxAMKhfXuRG4AUOV.jpg'),
(132508, 9442, 'As Meninas Superpoderosas (1998) S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/goljcuzxvIzmjcZ2xWbmPkOeCXA.jpg'),
(132509, 9442, 'As Meninas Superpoderosas (1998) S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ay6uOe6M1V2kuVvFmRXxeZZt6Wm.jpg'),
(132510, 9443, 'As Meninas Superpoderosas (1998) S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dvqORTqEsPJ8MtIdwzNPS89UVhp.jpg'),
(132511, 9443, 'As Meninas Superpoderosas (1998) S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8PFfdKGEm6OK3c8taG7edwScjFG.jpg'),
(132512, 9443, 'As Meninas Superpoderosas (1998) S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k3kUEsXGnNEt6oRWjhBpsg4vybO.jpg'),
(132513, 9443, 'As Meninas Superpoderosas (1998) S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aXXFpOzEIGKZFR6dOmI1Vhb8wPt.jpg'),
(132514, 9443, 'As Meninas Superpoderosas (1998) S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aeGHVCwoJx294GnaxRcWjHP77rl.jpg'),
(132515, 9443, 'As Meninas Superpoderosas (1998) S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yj107lsfI8EmfuGfZ2skWkh8Gcf.jpg'),
(132516, 9443, 'As Meninas Superpoderosas (1998) S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lnUzH5IaDVQJ3FY4FUbQfXzWiEo.jpg'),
(132517, 9443, 'As Meninas Superpoderosas (1998) S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sWWj2FE2qkovNLjdMYdHUAoQSAh.jpg'),
(132518, 9443, 'As Meninas Superpoderosas (1998) S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ms4eCcx1vYod0bgoKQGDIBrFs0A.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(132519, 9443, 'As Meninas Superpoderosas (1998) S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nqQhMb4PPuLpCoiwNBjPyihMrts.jpg'),
(132520, 9443, 'As Meninas Superpoderosas (1998) S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tfuceWZEVJkmclluw4sjQoAYiiw.jpg'),
(132521, 9443, 'As Meninas Superpoderosas (1998) S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/68nAGSUyfGSUp3Pyzfa4sWVpexW.jpg'),
(132522, 9443, 'As Meninas Superpoderosas (1998) S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jQgRbeZNcVGLmxX81lG1HAgOhpj.jpg'),
(132523, 9444, 'As Meninas Superpoderosas (1998) S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gckq7n6kM5xnQDzixNdnk05bQg0.jpg'),
(132524, 9444, 'As Meninas Superpoderosas (1998) S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7puFBsMlj6FMOpkjKeK3kk1dgIn.jpg'),
(132525, 9444, 'As Meninas Superpoderosas (1998) S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2A4jMFkQHUkDh0L6gFmy6pzSgob.jpg'),
(132526, 9444, 'As Meninas Superpoderosas (1998) S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w6BSEXLzt4Q3tyw808lYNV5wyx6.jpg'),
(132527, 9444, 'As Meninas Superpoderosas (1998) S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8OniejRhQmU92rx5BbspXmYGbDt.jpg'),
(132528, 9444, 'As Meninas Superpoderosas (1998) S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7eTkpDHCLQBpkFuqwlf18f71NpW.jpg'),
(132529, 9444, 'As Meninas Superpoderosas (1998) S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Wa02YUd1tD39zp7gt8sxgAC3HL.jpg'),
(132530, 9444, 'As Meninas Superpoderosas (1998) S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4GZsitx1EOr72H554XQvf45ethI.jpg'),
(132531, 9444, 'As Meninas Superpoderosas (1998) S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3clOZWEIIykFAKcdEF3g8Uut1xa.jpg'),
(132532, 9444, 'As Meninas Superpoderosas (1998) S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l9zPR6Ylld9xm4ceeSuaCxjQjds.jpg'),
(132533, 9444, 'As Meninas Superpoderosas (1998) S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ftFTY3EZTTAP5RKfRijD8Q8PNQX.jpg'),
(132534, 9444, 'As Meninas Superpoderosas (1998) S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ftFTY3EZTTAP5RKfRijD8Q8PNQX.jpg'),
(132535, 9445, 'As Meninas Superpoderosas (1998) S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o3zcZktgbFwf05cu79gAgQ1NRez.jpg'),
(132536, 9445, 'As Meninas Superpoderosas (1998) S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rsWCAyQj2DOqLcE7CxQE9XSVSHX.jpg'),
(132537, 9445, 'As Meninas Superpoderosas (1998) S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/htUBn2yaHHt1tvRN45etTshsdkD.jpg'),
(132538, 9445, 'As Meninas Superpoderosas (1998) S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ys3xYaqcaZPMGp10MknhW5O3AW5.jpg'),
(132539, 9445, 'As Meninas Superpoderosas (1998) S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7fhNc0ujyYfqgwv1ej1FP4E5LiO.jpg'),
(132540, 9445, 'As Meninas Superpoderosas (1998) S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kynf4rdCyBOLk6our05nlkAC3ct.jpg'),
(132541, 9445, 'As Meninas Superpoderosas (1998) S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dq17DP4KFc6UzqgB0tgqGhkjn56.jpg'),
(132542, 9445, 'As Meninas Superpoderosas (1998) S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8hlUxNq1XhkPrwU2350JjoayJAm.jpg'),
(132543, 9445, 'As Meninas Superpoderosas (1998) S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bheFGjnX3KHVV66dZiOOqXy4AXX.jpg'),
(132544, 9445, 'As Meninas Superpoderosas (1998) S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/61aLlDGnpiS6dsHdtQMSOCFjxq2.jpg'),
(132545, 9445, 'As Meninas Superpoderosas (1998) S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/efPGCr5mHGDz6D7oSRQf6HqNNGe.jpg'),
(132546, 9446, 'As Meninas Superpoderosas (1998) S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9OmArYchwmTmePWaVzGfzYRYPy6.jpg'),
(132547, 9446, 'As Meninas Superpoderosas (1998) S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oxfM3xKS3Q88s2mSKFlnpFa4o7v.jpg'),
(132548, 9446, 'As Meninas Superpoderosas (1998) S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vDzjEhTttHhwelJdsxA6nJyPq4q.jpg'),
(132549, 9446, 'As Meninas Superpoderosas (1998) S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x7iuJqX4J5C1HaxqmjuhyjT27HM.jpg'),
(132550, 9446, 'As Meninas Superpoderosas (1998) S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/goILGSKI7lJNplU6sjX6UgjpXCx.jpg'),
(132551, 9446, 'As Meninas Superpoderosas (1998) S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kNkq68TsV3mNUaDLFgP6u8XTAFS.jpg'),
(132552, 9446, 'As Meninas Superpoderosas (1998) S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mYI8gWjEhOZZnXmMYyN9uWyBdvr.jpg'),
(132553, 9446, 'As Meninas Superpoderosas (1998) S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tfBQc4amAIGn8PPoXJz8sX7waiW.jpg'),
(132554, 9446, 'As Meninas Superpoderosas (1998) S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jxdjcuoMEBqW6gQONZ1dyDPnfQK.jpg'),
(132555, 9446, 'As Meninas Superpoderosas (1998) S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jW5nV5HGac2SoZP3Rz9IGV6tHN0.jpg'),
(132556, 9446, 'As Meninas Superpoderosas (1998) S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ftFTY3EZTTAP5RKfRijD8Q8PNQX.jpg'),
(132557, 9446, 'As Meninas Superpoderosas (1998) S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ftFTY3EZTTAP5RKfRijD8Q8PNQX.jpg'),
(132558, 9446, 'As Meninas Superpoderosas (1998) S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ftFTY3EZTTAP5RKfRijD8Q8PNQX.jpg'),
(132559, 9446, 'As Meninas Superpoderosas (1998) S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/259911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ftFTY3EZTTAP5RKfRijD8Q8PNQX.jpg'),
(132560, 9446, 'As Meninas Superpoderosas (1998) S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/259912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ftFTY3EZTTAP5RKfRijD8Q8PNQX.jpg'),
(132561, 9447, 'Assassinato de uma Sexta a Noite S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x3pPf6lm7IgdPPldcAvlPExcnUx.jpg'),
(132562, 9447, 'Assassinato de uma Sexta a Noite S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lOPNcRdLzTYHzJgtwOB8bUDZE5L.jpg'),
(132563, 9447, 'Assassinato de uma Sexta a Noite S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cVCU6KyIGlRL0TMYyBLXTsGLFAJ.jpg'),
(132564, 9447, 'Assassinato de uma Sexta a Noite S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3GPC4BwBnxQbYVwLDLAgxejASU6.jpg'),
(132565, 9447, 'Assassinato de uma Sexta a Noite S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pbUoweMHUjhYu6EOe0nF4xc3vcg.jpg'),
(132566, 9447, 'Assassinato de uma Sexta a Noite S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7cI4RVfoXaDl3s96zWYm2IFDALs.jpg'),
(132567, 9448, 'Assassinato de uma Sexta a Noite S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wARHaZaItHMUynkQmsKHpxSHcu8.jpg'),
(132568, 9448, 'Assassinato de uma Sexta a Noite S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/TNST3md0Nr7JDX0AjjVs8ZSOi7.jpg'),
(132569, 9448, 'Assassinato de uma Sexta a Noite S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6osx2B38Gia6Tu5PUDsHqLfrR51.jpg'),
(132570, 9448, 'Assassinato de uma Sexta a Noite S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qSGyyDXAWoy83RVKCXJcLJi0WuN.jpg'),
(132571, 9448, 'Assassinato de uma Sexta a Noite S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4A07JhBlUJmOdEcAqbmvZbzc4cZ.jpg'),
(132572, 9448, 'Assassinato de uma Sexta a Noite S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uk7E8AMjBVXo7KvX8oJtmHuo0o5.jpg'),
(132573, 9448, 'Assassinato de uma Sexta a Noite S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tAeMQEo3A33jPnb5JnVK35pDbiD.jpg'),
(132574, 9448, 'Assassinato de uma Sexta a Noite S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4c5QGMndtd61EkeNd8NUrPh9P5D.jpg'),
(132575, 9449, 'Assassinato de uma Sexta a Noite S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch5uWUXHIAmWEtJ048opEBpo7Tx.jpg'),
(132576, 9449, 'Assassinato de uma Sexta a Noite S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch5uWUXHIAmWEtJ048opEBpo7Tx.jpg'),
(132577, 9449, 'Assassinato de uma Sexta a Noite S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch5uWUXHIAmWEtJ048opEBpo7Tx.jpg'),
(132578, 9449, 'Assassinato de uma Sexta a Noite S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch5uWUXHIAmWEtJ048opEBpo7Tx.jpg'),
(132579, 9449, 'Assassinato de uma Sexta a Noite S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch5uWUXHIAmWEtJ048opEBpo7Tx.jpg'),
(132580, 9449, 'Assassinato de uma Sexta a Noite S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch5uWUXHIAmWEtJ048opEBpo7Tx.jpg'),
(132581, 9449, 'Assassinato de uma Sexta a Noite S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/435269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch5uWUXHIAmWEtJ048opEBpo7Tx.jpg'),
(132582, 9449, 'Assassinato de uma Sexta a Noite S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/435270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch5uWUXHIAmWEtJ048opEBpo7Tx.jpg'),
(132583, 9450, 'Bright Girls Success [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8u3STG6CHNGRC21B9iBwsMpM1ZH.jpg'),
(132584, 9450, 'Bright Girls Success [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8u3STG6CHNGRC21B9iBwsMpM1ZH.jpg'),
(132585, 9450, 'Bright Girls Success [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8u3STG6CHNGRC21B9iBwsMpM1ZH.jpg'),
(132586, 9450, 'Bright Girls Success [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8u3STG6CHNGRC21B9iBwsMpM1ZH.jpg'),
(132587, 9450, 'Bright Girls Success [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8u3STG6CHNGRC21B9iBwsMpM1ZH.jpg'),
(132588, 9450, 'Bright Girls Success [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8u3STG6CHNGRC21B9iBwsMpM1ZH.jpg'),
(132589, 9450, 'Bright Girls Success [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8u3STG6CHNGRC21B9iBwsMpM1ZH.jpg'),
(132590, 9450, 'Bright Girls Success [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8u3STG6CHNGRC21B9iBwsMpM1ZH.jpg'),
(132591, 9450, 'Bright Girls Success [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8u3STG6CHNGRC21B9iBwsMpM1ZH.jpg'),
(132592, 9450, 'Bright Girls Success [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8u3STG6CHNGRC21B9iBwsMpM1ZH.jpg'),
(132593, 9450, 'Bright Girls Success [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8u3STG6CHNGRC21B9iBwsMpM1ZH.jpg'),
(132594, 9450, 'Bright Girls Success [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8u3STG6CHNGRC21B9iBwsMpM1ZH.jpg'),
(132595, 9450, 'Bright Girls Success [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8u3STG6CHNGRC21B9iBwsMpM1ZH.jpg'),
(132596, 9450, 'Bright Girls Success [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/259819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8u3STG6CHNGRC21B9iBwsMpM1ZH.jpg'),
(132597, 9450, 'Bright Girls Success [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/259820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8u3STG6CHNGRC21B9iBwsMpM1ZH.jpg'),
(132598, 9450, 'Bright Girls Success [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/259821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8u3STG6CHNGRC21B9iBwsMpM1ZH.jpg'),
(132599, 9451, 'Corre Compra e Cozinha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xKbD8wU269ijXFMSKDUyZYinU3H.jpg'),
(132600, 9451, 'Corre Compra e Cozinha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xKbD8wU269ijXFMSKDUyZYinU3H.jpg'),
(132601, 9451, 'Corre Compra e Cozinha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xKbD8wU269ijXFMSKDUyZYinU3H.jpg'),
(132602, 9451, 'Corre Compra e Cozinha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xKbD8wU269ijXFMSKDUyZYinU3H.jpg'),
(132603, 9451, 'Corre Compra e Cozinha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xKbD8wU269ijXFMSKDUyZYinU3H.jpg'),
(132604, 9451, 'Corre Compra e Cozinha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xKbD8wU269ijXFMSKDUyZYinU3H.jpg'),
(132605, 9452, 'Corre Compra e Cozinha S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xKbD8wU269ijXFMSKDUyZYinU3H.jpg'),
(132606, 9452, 'Corre Compra e Cozinha S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xKbD8wU269ijXFMSKDUyZYinU3H.jpg'),
(132607, 9452, 'Corre Compra e Cozinha S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xKbD8wU269ijXFMSKDUyZYinU3H.jpg'),
(132608, 9452, 'Corre Compra e Cozinha S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xKbD8wU269ijXFMSKDUyZYinU3H.jpg'),
(132609, 9452, 'Corre Compra e Cozinha S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xKbD8wU269ijXFMSKDUyZYinU3H.jpg'),
(132610, 9452, 'Corre Compra e Cozinha S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xKbD8wU269ijXFMSKDUyZYinU3H.jpg'),
(132611, 9452, 'Corre Compra e Cozinha S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xKbD8wU269ijXFMSKDUyZYinU3H.jpg'),
(132612, 9452, 'Corre Compra e Cozinha S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xKbD8wU269ijXFMSKDUyZYinU3H.jpg'),
(132613, 9452, 'Corre Compra e Cozinha S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1jdpm1Qla6zrs2okqxMwaYzeyYs.jpg'),
(132614, 9452, 'Corre Compra e Cozinha S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qfppqe7upYjwaEygImKWqhV6tOb.jpg'),
(132615, 9452, 'Corre Compra e Cozinha S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3D9cwpMUyOxxq8KhEygy33yi0vh.jpg'),
(132616, 9452, 'Corre Compra e Cozinha S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v9YGs7lUkcNkwzJNx8qGre1OF6B.jpg'),
(132617, 9452, 'Corre Compra e Cozinha S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pHJFgUx23LJDtIAIo4bXOaeYmIp.jpg'),
(132618, 9453, 'Corre Compra e Cozinha S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/flP9XiW6MX5LhmWq95nT09VgEpy.jpg'),
(132619, 9453, 'Corre Compra e Cozinha S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vAXVLRJs2umLzG9IqMeV9102oz0.jpg'),
(132620, 9453, 'Corre Compra e Cozinha S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iaBn5mEmPN1km6zjR53ibWkmPsI.jpg'),
(132621, 9453, 'Corre Compra e Cozinha S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ja0MiNMUeDf2WzTm0kHuaf0fth.jpg'),
(132622, 9453, 'Corre Compra e Cozinha S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n6ydKbrQRhmUqrA362gBnI9AH6M.jpg'),
(132623, 9453, 'Corre Compra e Cozinha S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bccC8B9hXIeiZBRF6oDDGvIwID7.jpg'),
(132624, 9453, 'Corre Compra e Cozinha S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fyvaq3JPLBTv2D8w95h6mr4nzWY.jpg'),
(132625, 9453, 'Corre Compra e Cozinha S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xKbD8wU269ijXFMSKDUyZYinU3H.jpg'),
(132626, 9453, 'Corre Compra e Cozinha S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4CaNZeX7GINwGiNkQ1wIpOJO9O4.jpg'),
(132627, 9453, 'Corre Compra e Cozinha S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9WYRv6JSiq9Q6mqdMScILHmLKIL.jpg'),
(132628, 9453, 'Corre Compra e Cozinha S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/klRkjGn7v6Sutieu04PeorixEs7.jpg'),
(132629, 9453, 'Corre Compra e Cozinha S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ziDIaQGfqvchKveujOUqYn6bUOU.jpg'),
(132630, 9453, 'Corre Compra e Cozinha S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rqWPOHsho0BW40SWAGnk92qSheb.jpg'),
(132631, 9453, 'Corre Compra e Cozinha S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/259799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uWalToUvQNO7Oo6ElhPt2cpf73X.jpg'),
(132632, 9453, 'Corre Compra e Cozinha S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/259800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ccKYKe0KKTp2JXndQ6tiGe42Ee.jpg'),
(132633, 9453, 'Corre Compra e Cozinha S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/259801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xKbD8wU269ijXFMSKDUyZYinU3H.jpg'),
(132634, 9453, 'Corre Compra e Cozinha S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/259802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xd8F8sHxyiJFD4tLuBR4pntXMB5.jpg'),
(132635, 9453, 'Corre Compra e Cozinha S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/259803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHeVgTMS7gXytzvNRvWNyWC98R2.jpg'),
(132636, 9453, 'Corre Compra e Cozinha S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/259804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wQmtC7HiTmQGzl8VNHsImJiqMhf.jpg'),
(132637, 9453, 'Corre Compra e Cozinha S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/259805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xKbD8wU269ijXFMSKDUyZYinU3H.jpg'),
(132638, 9454, 'Diarios de uma Apotecaria [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ggj0UKd4j5uwYPEuuS9KmO76Lcn.jpg'),
(132639, 9454, 'Diarios de uma Apotecaria [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pYC0kEvnKtVm50uD2rBmtrZZnix.jpg'),
(132640, 9454, 'Diarios de uma Apotecaria [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nfrCtoX4yRh7WyF9unECvML4dyG.jpg'),
(132641, 9454, 'Diarios de uma Apotecaria [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/56uZXOtpTuUvyuYGEpSLNJtJOBO.jpg'),
(132642, 9454, 'Diarios de uma Apotecaria [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/45h60UAouIJHiKRCI8zx6Vb38Nh.jpg'),
(132643, 9454, 'Diarios de uma Apotecaria [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lk1dC3AFErQwPjaKlHHc6f7g7rz.jpg'),
(132644, 9454, 'Diarios de uma Apotecaria [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5wBAUmOAlu9z2chOoqke2wwI6G9.jpg'),
(132645, 9454, 'Diarios de uma Apotecaria [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j9m1E9HOJVl4pjnJRhjH445EYmx.jpg'),
(132646, 9454, 'Diarios de uma Apotecaria [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/85di7jtFru5hlHMF5kytkhC9epK.jpg'),
(132647, 9454, 'Diarios de uma Apotecaria [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kXyc6WziVrsnFZ0Z37xjTZegcY.jpg'),
(132648, 9454, 'Diarios de uma Apotecaria [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9K1ZNqTYK8ty1Olj2jGJAZ3l4y3.jpg'),
(132649, 9454, 'Diarios de uma Apotecaria [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xa9CovqvQIgYENhpHdqun3JTn4A.jpg'),
(132650, 9454, 'Diarios de uma Apotecaria [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/264990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wIIuz0ZkiKKdBSUyZfAIH25uPNF.jpg'),
(132651, 9454, 'Diarios de uma Apotecaria [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/264991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l3lUDpsjugdQFEn5X44CrLgisx.jpg'),
(132652, 9454, 'Diarios de uma Apotecaria [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/264992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132653, 9454, 'Diarios de uma Apotecaria [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/264993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132654, 9454, 'Diarios de uma Apotecaria [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/264994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132655, 9454, 'Diarios de uma Apotecaria [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/273035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132656, 9454, 'Diarios de uma Apotecaria [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/276683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132657, 9454, 'Diarios de uma Apotecaria [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/281430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132658, 9454, 'Diarios de uma Apotecaria [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/287738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132659, 9454, 'Diarios de uma Apotecaria [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/298024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132660, 9454, 'Diarios de uma Apotecaria [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/302907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132661, 9454, 'Diarios de uma Apotecaria [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/309089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132662, 9455, 'Diarios de uma Apotecaria [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/660489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132663, 9455, 'Diarios de uma Apotecaria [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/665237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132664, 9455, 'Diarios de uma Apotecaria [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/675852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132665, 9455, 'Diarios de uma Apotecaria [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/683770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132666, 9455, 'Diarios de uma Apotecaria [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/686806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132667, 9455, 'Diarios de uma Apotecaria [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/698314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132668, 9455, 'Diarios de uma Apotecaria [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/706417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132669, 9455, 'Diarios de uma Apotecaria [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/712855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132670, 9455, 'Diarios de uma Apotecaria [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/718723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132671, 9455, 'Diarios de uma Apotecaria [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/724212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132672, 9455, 'Diarios de uma Apotecaria [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/730675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132673, 9455, 'Diarios de uma Apotecaria [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/752350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132674, 9455, 'Diarios de uma Apotecaria [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/760937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132675, 9455, 'Diarios de uma Apotecaria [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/767657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132676, 9455, 'Diarios de uma Apotecaria [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/776865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132677, 9455, 'Diarios de uma Apotecaria [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/778260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132678, 9455, 'Diarios de uma Apotecaria [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/793045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132679, 9455, 'Diarios de uma Apotecaria [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/796705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132680, 9455, 'Diarios de uma Apotecaria [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/808496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132681, 9455, 'Diarios de uma Apotecaria [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/820004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132682, 9455, 'Diarios de uma Apotecaria [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/826702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132683, 9455, 'Diarios de uma Apotecaria [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/834428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132684, 9455, 'Diarios de uma Apotecaria [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/852717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132685, 9455, 'Diarios de uma Apotecaria [L] S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/855598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(132686, 9456, 'Guerra as Drogas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o1QindHHWxIkJEz2sgHoAx1xLNm.jpg'),
(132687, 9456, 'Guerra as Drogas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wl7rD6vCKIN7jTxw4jg4Og7bGQc.jpg'),
(132688, 9456, 'Guerra as Drogas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wxetbPnAQI1hmKGicYONFLG0ZSa.jpg'),
(132689, 9456, 'Guerra as Drogas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4SR0fEdsBGicO8nFfuOvRsk5maO.jpg'),
(132690, 9456, 'Guerra as Drogas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4FRiouUhr0leB8M0IjtdeB9LOZ0.jpg'),
(132691, 9456, 'Guerra as Drogas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ygqCjLEpBqZRhwDufJEYo0UW1p5.jpg'),
(132692, 9456, 'Guerra as Drogas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/artBUApF98o0QIVDy6lZBEPfzrv.jpg'),
(132693, 9456, 'Guerra as Drogas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ahx5KZShcMOqfDcYgZ6OyPp917u.jpg'),
(132694, 9456, 'Guerra as Drogas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1IZiIWF9RJ2yoiYNubNWbF6Wjey.jpg'),
(132695, 9456, 'Guerra as Drogas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bSLIKnyPJ2O4gAkj0coCVU3sd70.jpg'),
(132696, 9457, 'Guerra as Drogas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bSLIKnyPJ2O4gAkj0coCVU3sd70.jpg'),
(132697, 9457, 'Guerra as Drogas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bSLIKnyPJ2O4gAkj0coCVU3sd70.jpg'),
(132698, 9457, 'Guerra as Drogas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bSLIKnyPJ2O4gAkj0coCVU3sd70.jpg'),
(132699, 9457, 'Guerra as Drogas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bSLIKnyPJ2O4gAkj0coCVU3sd70.jpg'),
(132700, 9457, 'Guerra as Drogas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bSLIKnyPJ2O4gAkj0coCVU3sd70.jpg'),
(132701, 9457, 'Guerra as Drogas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bSLIKnyPJ2O4gAkj0coCVU3sd70.jpg'),
(132702, 9458, 'Guerra as Drogas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bSLIKnyPJ2O4gAkj0coCVU3sd70.jpg'),
(132703, 9458, 'Guerra as Drogas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bSLIKnyPJ2O4gAkj0coCVU3sd70.jpg'),
(132704, 9458, 'Guerra as Drogas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bSLIKnyPJ2O4gAkj0coCVU3sd70.jpg'),
(132705, 9458, 'Guerra as Drogas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bSLIKnyPJ2O4gAkj0coCVU3sd70.jpg'),
(132706, 9458, 'Guerra as Drogas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bSLIKnyPJ2O4gAkj0coCVU3sd70.jpg'),
(132707, 9458, 'Guerra as Drogas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bSLIKnyPJ2O4gAkj0coCVU3sd70.jpg'),
(132708, 9459, 'Here We Meet Again [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/25CvTwrRNZoPHXOPn3SrUwPLH7H.jpg'),
(132709, 9459, 'Here We Meet Again [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/veJdQxPWRgxBDKOGnENoPUK26vf.jpg'),
(132710, 9459, 'Here We Meet Again [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3lHvTQX93nbGWgCepOxqevV3FLi.jpg'),
(132711, 9459, 'Here We Meet Again [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xaMGeA3Lf5MxmmFI65dRI2ZucCq.jpg'),
(132712, 9459, 'Here We Meet Again [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zIU7wexPL4o3pHtcmfHC0zuQ5n1.jpg'),
(132713, 9459, 'Here We Meet Again [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5mKBjtlCv2Sha3aYAi6njhTKtJX.jpg'),
(132714, 9459, 'Here We Meet Again [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bAX3gL4WdWNAG2jEPObGWlCRTo4.jpg'),
(132715, 9459, 'Here We Meet Again [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4lOqNGTrUO5z7dRtad83Tza396f.jpg'),
(132716, 9459, 'Here We Meet Again [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tKri8kQFmqKlh1pdaXaBO0137LN.jpg'),
(132717, 9459, 'Here We Meet Again [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kAniHBlSftixv2J1TDYRrmHufyk.jpg'),
(132718, 9459, 'Here We Meet Again [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wReF0R1KcJCmvHBIznCVa68ToWz.jpg'),
(132719, 9459, 'Here We Meet Again [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7IvTMdYMRvWaTk1Y22BarVYL2mN.jpg'),
(132720, 9459, 'Here We Meet Again [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3EDjHTkJRMOF7coMfCt8wLi6DKW.jpg'),
(132721, 9459, 'Here We Meet Again [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/259748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n6N0ZXExic3ypi69G15QJk9sXAs.jpg'),
(132722, 9459, 'Here We Meet Again [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/259749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m9818Q8IiKfHRIniNgdVb4YOTVr.jpg'),
(132723, 9459, 'Here We Meet Again [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/259750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7jBK5ZJCqOHLhWQ2kdv3XFtlU1D.jpg'),
(132724, 9459, 'Here We Meet Again [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/259751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hX7nYZIfvoosx7GYEFMd3qj1a6J.jpg'),
(132725, 9459, 'Here We Meet Again [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/259752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/soHyFDPVAdzwQUrHEFfL9SjAGnk.jpg'),
(132726, 9459, 'Here We Meet Again [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/259753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nP40Z6cnSUXtsZDdigVpCYHWAdK.jpg'),
(132727, 9459, 'Here We Meet Again [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/259754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qAsjAn1gFXbsqsVWkalO4OzVz3o.jpg'),
(132728, 9459, 'Here We Meet Again [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/259755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Ovd7IyEbgjuxYOzOBGyOZgDxTT.jpg'),
(132729, 9459, 'Here We Meet Again [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/259756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/njzSxfCNO8XICOkBolw2MPLMQgC.jpg'),
(132730, 9459, 'Here We Meet Again [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/259757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/doP6v3u4EEop1gVvboVwCs9zpjq.jpg'),
(132731, 9459, 'Here We Meet Again [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/259758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5LaBcQdKEXb0Us1GboAaCoEMt4y.jpg'),
(132732, 9459, 'Here We Meet Again [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/259759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v00YrR4F3b6GxsbpJZVRHlXLcHI.jpg'),
(132733, 9459, 'Here We Meet Again [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/259760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zK9qfAVQlwQebUVDrCv9qb6y3CT.jpg'),
(132734, 9459, 'Here We Meet Again [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/259761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lK944uGY2l5A8AOCFKfpc5yYbS5.jpg'),
(132735, 9459, 'Here We Meet Again [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/259762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4fjoTcYDh0LdxHOmtVqo4c4HW3x.jpg'),
(132736, 9459, 'Here We Meet Again [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/259763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJrGeyxSs3QCMrQSEqIXwX2CNhr.jpg'),
(132737, 9459, 'Here We Meet Again [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/259764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lR70StownZ8ZzNZL6DSXAcUJ79q.jpg'),
(132738, 9459, 'Here We Meet Again [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/259765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ikFm3EUq8u8g1wtQvs7jepRVxJH.jpg'),
(132739, 9459, 'Here We Meet Again [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/259766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7B2gKwG7CGiYKhzsBgwUAMpho5N.jpg'),
(132740, 9460, 'Individual Circumstances [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rAgIV0TD16VVAG433YJuBM8sb2c.jpg'),
(132741, 9460, 'Individual Circumstances [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1rKdrDJ3mWJ7jc8th7hhVA7cALX.jpg'),
(132742, 9460, 'Individual Circumstances [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZogyHFlvGIj3YmXJoSQ2BGz064.jpg'),
(132743, 9460, 'Individual Circumstances [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Q7sEOp9zPfyKHkKwdCnx2BYfBo.jpg'),
(132744, 9460, 'Individual Circumstances [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wynOVIv3PGsZokgt0EBP6oJO9sP.jpg'),
(132745, 9460, 'Individual Circumstances [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1mZPALZBanKmbJRMBv8dsxYeK8x.jpg'),
(132746, 9460, 'Individual Circumstances [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rTQ3MGCBRvP1Y62fBwsLbJnQRv1.jpg'),
(132747, 9460, 'Individual Circumstances [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rcQhyoVzMd0asj8pc069EC1r9Rf.jpg'),
(132748, 9461, 'John Wayne Gacy Palhaco Assassino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fgfG19OZoYCtQL918WPivetnFvi.jpg'),
(132749, 9461, 'John Wayne Gacy Palhaco Assassino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xrqrpo85IOmcWx2CdfVYFScWVPw.jpg'),
(132750, 9461, 'John Wayne Gacy Palhaco Assassino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yBh6WDfFtwWbzqLAp1xix5IhKYl.jpg'),
(132751, 9461, 'John Wayne Gacy Palhaco Assassino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l9sGG50i2OEvEmvEPLsnBUA1fAG.jpg'),
(132752, 9461, 'John Wayne Gacy Palhaco Assassino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lqfV0LumCJ6R96GTptmg6rRM1cB.jpg'),
(132753, 9461, 'John Wayne Gacy Palhaco Assassino S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aAr82FbAvaQERlMrNQy2piGmWAu.jpg'),
(132754, 9462, 'Lobo em Pele de Cordeiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fTl0C3IBg0E930HOGfQ7fgtjPWG.jpg'),
(132755, 9462, 'Lobo em Pele de Cordeiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o3WOPeRS4xegKfPdlGW4nJY46u9.jpg'),
(132756, 9462, 'Lobo em Pele de Cordeiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4DzHW3tDfTc0xCEjbiJuZoHQzEl.jpg'),
(132757, 9462, 'Lobo em Pele de Cordeiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j1vwmM1sP3k3EjJ09kiuDslpOhH.jpg'),
(132758, 9462, 'Lobo em Pele de Cordeiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u5hcXN0BpyZUyFIeCim2OuL7Vnt.jpg'),
(132759, 9462, 'Lobo em Pele de Cordeiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/65oLRwSYdUco5Wec1K1snjJHCis.jpg'),
(132760, 9463, 'Lobo em Pele de Cordeiro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qSeHS8whLgouo0uOYBPFeXrIzCA.jpg'),
(132761, 9463, 'Lobo em Pele de Cordeiro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/clp8ktRtj31uuaiBOyc8g1vg6cT.jpg'),
(132762, 9463, 'Lobo em Pele de Cordeiro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kMyZg0KbSEW3n67VZddJzJfS3Yz.jpg'),
(132763, 9463, 'Lobo em Pele de Cordeiro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m1loi5KKtbklLk7QhnS2I1tdDb3.jpg'),
(132764, 9463, 'Lobo em Pele de Cordeiro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8udgWnvQAuMhhwTqfozlLsmXu0w.jpg'),
(132765, 9463, 'Lobo em Pele de Cordeiro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ivInFGkI1HPHNRhOrFebzhopv3.jpg'),
(132766, 9463, 'Lobo em Pele de Cordeiro S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHUQzpJA6fUPbWrQp35rE8bLipO.jpg'),
(132767, 9463, 'Lobo em Pele de Cordeiro S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ko8T26Cm9xLUVgjR8JAq1J8KRa0.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(132768, 9463, 'Lobo em Pele de Cordeiro S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cS4PWG8O1fUya4R7Yzz6050ogdt.jpg'),
(132769, 9463, 'Lobo em Pele de Cordeiro S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4drbeGz1J0tMrdTpghth9O3XQt3.jpg'),
(132770, 9464, 'Lobo em Pele de Cordeiro S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dRaUwIbhrz8ollRiGvtV1H5Yc4h.jpg'),
(132771, 9464, 'Lobo em Pele de Cordeiro S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pXDnUpQ1KlzBnJn3INNJm7JbFTt.jpg'),
(132772, 9464, 'Lobo em Pele de Cordeiro S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d7GPmRA0I8W3LpkNZzKYYB2HC3h.jpg'),
(132773, 9464, 'Lobo em Pele de Cordeiro S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ecRKuWX1QiXxduaeDb6gN5b4E3M.jpg'),
(132774, 9464, 'Lobo em Pele de Cordeiro S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mva4K9Jeb0mU3hZisHRiW1uIbUi.jpg'),
(132775, 9464, 'Lobo em Pele de Cordeiro S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bmugPNbbdzDJkTvQ9cnNs20RZvo.jpg'),
(132776, 9464, 'Lobo em Pele de Cordeiro S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iiMFPbdNsoopRzXtDNa7GlzYG0.jpg'),
(132777, 9464, 'Lobo em Pele de Cordeiro S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtWZ1GsfVc0bz7vX3LPR95cB08b.jpg'),
(132778, 9464, 'Lobo em Pele de Cordeiro S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gS4sU0ZN3mvcyQAe9mlHXdjH1q5.jpg'),
(132779, 9464, 'Lobo em Pele de Cordeiro S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9ZWjVrCSTu2x09fXypGVdZmRoe.jpg'),
(132780, 9464, 'Lobo em Pele de Cordeiro S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jlCVrCqAW6xTvdKqeKKEiRIC6NE.jpg'),
(132781, 9464, 'Lobo em Pele de Cordeiro S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtoNueDTVpdw00CqHfON45NSdMX.jpg'),
(132782, 9465, 'Lobo em Pele de Cordeiro S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/51yEsl9Bcapl6U7F661I0DhS7gG.jpg'),
(132783, 9465, 'Lobo em Pele de Cordeiro S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1N9NV4MaXRyuXbNF03HmBAsvTYf.jpg'),
(132784, 9465, 'Lobo em Pele de Cordeiro S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2nAVMIRMxUtLkELWX2Bpqsh8FOk.jpg'),
(132785, 9465, 'Lobo em Pele de Cordeiro S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rkcFpWcmRsuIBvlruuUI89ikApN.jpg'),
(132786, 9465, 'Lobo em Pele de Cordeiro S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jnRr3g2Eeknfan3p9ed6aKZlxoW.jpg'),
(132787, 9465, 'Lobo em Pele de Cordeiro S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b9jKba61YCaf799iflIfGlW2xY.jpg'),
(132788, 9465, 'Lobo em Pele de Cordeiro S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oktpAzqxQB8DYYPbfwHsRfc7Mym.jpg'),
(132789, 9465, 'Lobo em Pele de Cordeiro S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ntTXwXYaXX6tZi7v4JRmu76UnKN.jpg'),
(132790, 9465, 'Lobo em Pele de Cordeiro S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/26sAJixAsofRbsENf9cTX4DCuSZ.jpg'),
(132791, 9465, 'Lobo em Pele de Cordeiro S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yzOsf6nsEhgHQ9jaIU3UYGRBI5Y.jpg'),
(132792, 9465, 'Lobo em Pele de Cordeiro S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWYfa21fkOP1K31Jdw5ok0dSGLG.jpg'),
(132793, 9465, 'Lobo em Pele de Cordeiro S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z27HmL1G69pXIvsy1OFullGl5bS.jpg'),
(132794, 9465, 'Lobo em Pele de Cordeiro S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ZDdbOkmTkNk6IWPw4epfF4thaS.jpg'),
(132795, 9466, 'Lobo em Pele de Cordeiro S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xAJYKDLxD2ChTPXgZVB2Nx1dypF.jpg'),
(132796, 9466, 'Lobo em Pele de Cordeiro S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9azgOIlHw1hKkwHmpIROHoQiZKV.jpg'),
(132797, 9466, 'Lobo em Pele de Cordeiro S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vxNfojbCpDZHqp7SgjeNciU0u6l.jpg'),
(132798, 9466, 'Lobo em Pele de Cordeiro S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3KTGPTnvgKsDMrg6uEscK2qSpve.jpg'),
(132799, 9466, 'Lobo em Pele de Cordeiro S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4MoNKiqSO8OFLJDdaX9HNqVDU9T.jpg'),
(132800, 9466, 'Lobo em Pele de Cordeiro S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/apxIa3j2hBlRbuAWtNZasnRZKuk.jpg'),
(132801, 9466, 'Lobo em Pele de Cordeiro S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5eMKKpNAmkwafIZYzU4UKdL4y6Z.jpg'),
(132802, 9466, 'Lobo em Pele de Cordeiro S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eLTYmarzBsKfSYtt85V6qBOG2Kb.jpg'),
(132803, 9466, 'Lobo em Pele de Cordeiro S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jL2DWiHsj74egECuPGiWJFZ9Rc2.jpg'),
(132804, 9466, 'Lobo em Pele de Cordeiro S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dzlRb5f9ro90ddXEACl2ToW8Hni.jpg'),
(132805, 9467, 'Lobo em Pele de Cordeiro S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iUnRE8XcBhQYeNxt4QDpR8nYMAI.jpg'),
(132806, 9467, 'Lobo em Pele de Cordeiro S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r06O6kq9n3dr78OjmF9cx04wY63.jpg'),
(132807, 9467, 'Lobo em Pele de Cordeiro S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wHwkwMt9XEkqWjXZMHhnU4xJITH.jpg'),
(132808, 9467, 'Lobo em Pele de Cordeiro S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6f5RlZjnA3qe19T5pCls2AHqxQg.jpg'),
(132809, 9467, 'Lobo em Pele de Cordeiro S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/40V39x2zPmO4LxhErU5HxBRJS6A.jpg'),
(132810, 9467, 'Lobo em Pele de Cordeiro S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x7w3vvqegnnP7nm9TIt1h6hbiBa.jpg'),
(132811, 9467, 'Lobo em Pele de Cordeiro S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oiMTBRc7hxXa5DVoodEYPF1I2ct.jpg'),
(132812, 9467, 'Lobo em Pele de Cordeiro S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fahG5XPgoBYnqtg0vYYZtzv7f03.jpg'),
(132813, 9467, 'Lobo em Pele de Cordeiro S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/px1ZOwfseqsavPfeeTYInp26QVx.jpg'),
(132814, 9467, 'Lobo em Pele de Cordeiro S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hNXDBxRV8fI2upA1ZYdzLstOvrZ.jpg'),
(132815, 9468, 'Lobo em Pele de Cordeiro S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFDUIM46CUiVcmPhcPnRvBPVStk.jpg'),
(132816, 9468, 'Lobo em Pele de Cordeiro S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hbfCxQ6JyJOVT1CdxrwdadLTuKf.jpg'),
(132817, 9468, 'Lobo em Pele de Cordeiro S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/70M1pxFDuPE9Bx5rTeS9m1FgFDP.jpg'),
(132818, 9468, 'Lobo em Pele de Cordeiro S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1qpqfbYcv7EhKYVC5L1r78NH8q.jpg'),
(132819, 9468, 'Lobo em Pele de Cordeiro S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZ3eCL6moSsjWtFwSsWODBI0q0P.jpg'),
(132820, 9468, 'Lobo em Pele de Cordeiro S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uB4gGoqGTnoNMIv75ajo3xFJRVO.jpg'),
(132821, 9468, 'Lobo em Pele de Cordeiro S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ebbWNvRGnJbAhpBSJxGTWCWCY4q.jpg'),
(132822, 9468, 'Lobo em Pele de Cordeiro S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5xYjvTq2TWUivqtJftuaJ9B1W07.jpg'),
(132823, 9468, 'Lobo em Pele de Cordeiro S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fSXHlcHFhsLibe1FWEzkKyHHcYH.jpg'),
(132824, 9468, 'Lobo em Pele de Cordeiro S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/46FYAEqKh8kGYUXA842jvH4zxpt.jpg'),
(132825, 9469, 'Lobo em Pele de Cordeiro S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2BaQbIBkzxL7Fgdu63YxqOk29eK.jpg'),
(132826, 9469, 'Lobo em Pele de Cordeiro S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l64Gop9XfGZJsMA3pmF3OjwfYe2.jpg'),
(132827, 9469, 'Lobo em Pele de Cordeiro S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eVpPINiYcbiIx2wD7lQxPup5JRu.jpg'),
(132828, 9469, 'Lobo em Pele de Cordeiro S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1leDDoWkKbXQjCV5oKsqzoEO5I0.jpg'),
(132829, 9469, 'Lobo em Pele de Cordeiro S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKCR3oGhvDbNF07FeJ2S395Pxc3.jpg'),
(132830, 9469, 'Lobo em Pele de Cordeiro S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lVKCFO7oR6LjlcDSseruRLhmc4e.jpg'),
(132831, 9469, 'Lobo em Pele de Cordeiro S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mWXWBpJrD9P6Rd8NqgrrPO3kOgk.jpg'),
(132832, 9469, 'Lobo em Pele de Cordeiro S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/duTSnayyxlZxkKQlBJ8Gpaxl0sE.jpg'),
(132833, 9469, 'Lobo em Pele de Cordeiro S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bY082DpJtxQycfrHItLNGpsPc5K.jpg'),
(132834, 9469, 'Lobo em Pele de Cordeiro S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cdm6mdYVXCPGWOnvMSBRFyG2gaM.jpg'),
(132835, 9470, 'Lobo em Pele de Cordeiro S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ld52cgGPyaNycBXsonHm9nIjP2.jpg'),
(132836, 9470, 'Lobo em Pele de Cordeiro S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fcRAexJB0plqRzxqzQfr67OL0hl.jpg'),
(132837, 9470, 'Lobo em Pele de Cordeiro S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vI1FqCGMhGH6WJlFL8AwJTq3NyM.jpg'),
(132838, 9470, 'Lobo em Pele de Cordeiro S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zexDXm2hlh9eiECyznqRoNcxkvl.jpg'),
(132839, 9470, 'Lobo em Pele de Cordeiro S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2BIO8JnKRV9CJ0avhkHiNsbyr9g.jpg'),
(132840, 9470, 'Lobo em Pele de Cordeiro S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/juQVh2M3zF7aUGW6NAIQYEpsshH.jpg'),
(132841, 9470, 'Lobo em Pele de Cordeiro S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7S2hHQglZxufOIwCxtCA0Zaqsrb.jpg'),
(132842, 9470, 'Lobo em Pele de Cordeiro S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iYXvzEY6jnuILvOPvO70oh5gjQe.jpg'),
(132843, 9470, 'Lobo em Pele de Cordeiro S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/81gyF85M9tmNAyZJwbD0wk18lLO.jpg'),
(132844, 9470, 'Lobo em Pele de Cordeiro S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AcqTuf5HsjDEkPy2I5eslX58AEJ.jpg'),
(132845, 9471, 'Lobo em Pele de Cordeiro S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wNh05PHUAKHkkb9hyxbd3D1aKAZ.jpg'),
(132846, 9471, 'Lobo em Pele de Cordeiro S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y4d3jFydzycpfs4oyMuVMC8ZMrI.jpg'),
(132847, 9471, 'Lobo em Pele de Cordeiro S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q9dErzox64Q9lS2kLeK3FHLK7KW.jpg'),
(132848, 9471, 'Lobo em Pele de Cordeiro S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lhnzsXkts7Gnk81SOcpLHeIekDF.jpg'),
(132849, 9471, 'Lobo em Pele de Cordeiro S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gtUWeQh6wGTmRZscMsCaniWhMjb.jpg'),
(132850, 9471, 'Lobo em Pele de Cordeiro S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1t4ZwI0olzca23pual9rFW5nkpb.jpg'),
(132851, 9471, 'Lobo em Pele de Cordeiro S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7z8nNpQrN4ZfQjLjTF2pMU0TOl8.jpg'),
(132852, 9471, 'Lobo em Pele de Cordeiro S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rT8c1Ub1cmuKy1ZS1PO5b0mYrGf.jpg'),
(132853, 9471, 'Lobo em Pele de Cordeiro S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hiYCDc3vZ2CeBVH7q5kHtnRxr7u.jpg'),
(132854, 9471, 'Lobo em Pele de Cordeiro S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFtNoJfdxfIN00L4iS6kOL8pc9R.jpg'),
(132855, 9472, 'Lobo em Pele de Cordeiro S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/313245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ZDdbOkmTkNk6IWPw4epfF4thaS.jpg'),
(132856, 9472, 'Lobo em Pele de Cordeiro S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/319566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ZDdbOkmTkNk6IWPw4epfF4thaS.jpg'),
(132857, 9472, 'Lobo em Pele de Cordeiro S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/338643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ZDdbOkmTkNk6IWPw4epfF4thaS.jpg'),
(132858, 9472, 'Lobo em Pele de Cordeiro S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/338644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ZDdbOkmTkNk6IWPw4epfF4thaS.jpg'),
(132859, 9472, 'Lobo em Pele de Cordeiro S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/338645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ZDdbOkmTkNk6IWPw4epfF4thaS.jpg'),
(132860, 9472, 'Lobo em Pele de Cordeiro S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/345235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ZDdbOkmTkNk6IWPw4epfF4thaS.jpg'),
(132861, 9472, 'Lobo em Pele de Cordeiro S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/360725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ZDdbOkmTkNk6IWPw4epfF4thaS.jpg'),
(132862, 9472, 'Lobo em Pele de Cordeiro S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/360726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ZDdbOkmTkNk6IWPw4epfF4thaS.jpg'),
(132863, 9472, 'Lobo em Pele de Cordeiro S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/360727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ZDdbOkmTkNk6IWPw4epfF4thaS.jpg'),
(132864, 9472, 'Lobo em Pele de Cordeiro S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/368147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ZDdbOkmTkNk6IWPw4epfF4thaS.jpg'),
(132865, 9473, 'Maes do Funk S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v7H8FteWAXSx4uuncpQjYMbCbsB.jpg'),
(132866, 9473, 'Maes do Funk S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gUj84DYJN9lZq8MTh2oDzpswwmw.jpg'),
(132867, 9473, 'Maes do Funk S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzQUEZIOx5vbEADqRSaBgBU7VCV.jpg'),
(132868, 9473, 'Maes do Funk S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ni7uf06tGknibwkWsb1Fu5OxBjF.jpg'),
(132869, 9473, 'Maes do Funk S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r51zPILbpikBGhQLKJPnAZYoJFX.jpg'),
(132870, 9474, 'Meet Yourself [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUF6n6RovQnwD5RbWbEGFnD07eI.jpg'),
(132871, 9474, 'Meet Yourself [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9zGtGtZJ3DZIKExvJMycaApfrby.jpg'),
(132872, 9474, 'Meet Yourself [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ykC8QbStWgVymuYEtF1YNLIRCp8.jpg'),
(132873, 9474, 'Meet Yourself [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gC5MNLEhyv8t7N69e2oWirnnppU.jpg'),
(132874, 9474, 'Meet Yourself [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lkeU7AbtdesmjyDqqPYLwB4jNW1.jpg'),
(132875, 9474, 'Meet Yourself [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHcAb59W86F6T2Im7TLheDvlDyf.jpg'),
(132876, 9474, 'Meet Yourself [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k1dFwyMqhkX9aPxv4lEiERXK9aa.jpg'),
(132877, 9474, 'Meet Yourself [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h0cOneYPCF8TQfL0QrAXzgKNrGM.jpg'),
(132878, 9474, 'Meet Yourself [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h3zMThsgRSXFUtr7nzkcvU13pl7.jpg'),
(132879, 9474, 'Meet Yourself [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gBZ5CiKtgItdeqA3nBOovp1GzZn.jpg'),
(132880, 9474, 'Meet Yourself [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/amv2HieBWe4GmFNQ7hYXdvxoSgK.jpg'),
(132881, 9474, 'Meet Yourself [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aotKUrWD6KObsRMu1meIfrEdbgj.jpg'),
(132882, 9474, 'Meet Yourself [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5DQZYhBPnZDYciqysOOUQAAHb5I.jpg'),
(132883, 9474, 'Meet Yourself [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/259588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7aFO4YDONlQih78tqUCVN2FS015.jpg'),
(132884, 9474, 'Meet Yourself [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/259589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i2xegtbwJhcfFo6iU6Ztvac7iO2.jpg'),
(132885, 9474, 'Meet Yourself [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/259590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jRQ06PHZORwzSUONPxb36PcDo1N.jpg'),
(132886, 9474, 'Meet Yourself [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/259591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pMmJfDZzW1Xfxlj7MHVk0ttOf8g.jpg'),
(132887, 9474, 'Meet Yourself [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/259592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ELMvPTt7hixKkMBURVLXg1GCwB.jpg'),
(132888, 9474, 'Meet Yourself [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/259593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1NsVcM4WAUpctrT1cNM2NJWgKRk.jpg'),
(132889, 9474, 'Meet Yourself [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/259594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nTCJ0ZPQ09owek4joXJOtrxsdlM.jpg'),
(132890, 9474, 'Meet Yourself [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/259595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tVvKn3fZ7Hu4l2yk2DBpycGyEre.jpg'),
(132891, 9474, 'Meet Yourself [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/259596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iig5HSHWyccjqucNndrQBQY3b6v.jpg'),
(132892, 9474, 'Meet Yourself [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/259597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bP5LepmFEwDM67W40qEa2Wl5mo0.jpg'),
(132893, 9474, 'Meet Yourself [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/259598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eWjeaUuKlkMv6QjNYf28Y18MPOt.jpg'),
(132894, 9474, 'Meet Yourself [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/259599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jjnaM3DKKiHXwYi2pWgUYvic1ko.jpg'),
(132895, 9474, 'Meet Yourself [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/259600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hDYyr5OX7X21GotB73cAZUc6O2p.jpg'),
(132896, 9474, 'Meet Yourself [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/259601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqdcNraPgzoqZS37qFUnezmCY44.jpg'),
(132897, 9474, 'Meet Yourself [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/259602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zXIsj8FKIRl8sHeF7FXe8MqwKC7.jpg'),
(132898, 9474, 'Meet Yourself [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/259603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wDzJdGeeC1MWVb100vjy4BZx0Kx.jpg'),
(132899, 9474, 'Meet Yourself [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/259604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k3uvPiruGu7vYvBIi9IgxsT36Zo.jpg'),
(132900, 9474, 'Meet Yourself [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/259605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tInvJJsmY4YlBDV6ms4mpekfsxg.jpg'),
(132901, 9474, 'Meet Yourself [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/259606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kIxjdAenVotQx9xbUjMgHUIQh1v.jpg'),
(132902, 9474, 'Meet Yourself [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/259607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8mrLGtnIaVYdgrjLEPIxwTPuESn.jpg'),
(132903, 9474, 'Meet Yourself [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/259608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/R2oCmerSRqu796mr9mMbdvjCOv.jpg'),
(132904, 9474, 'Meet Yourself [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/259609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fSipRgEI4kjsyuJcibsbZVvoLxI.jpg'),
(132905, 9474, 'Meet Yourself [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/259610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6l4OoA0KezTLj8rVCzv2r5KDyvW.jpg'),
(132906, 9474, 'Meet Yourself [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/259611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/km5mt4MM9DorkQwVNFDEBLB0hX9.jpg'),
(132907, 9474, 'Meet Yourself [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/259612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1srOzKWtoiP58oUZeqxUQjIBfKi.jpg'),
(132908, 9474, 'Meet Yourself [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/259613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/QHOT16ekehraKjF4fHrB3BSeil.jpg'),
(132909, 9474, 'Meet Yourself [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/259614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3atoSWalXtUoVg7DPX9wdceOKWw.jpg'),
(132910, 9383, 'My Happy End [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tuTxOoGqIC11gOX94ZpBYQsgzxS.jpg'),
(132911, 9383, 'My Happy End [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/losSpGi8VaBwcCGBuoE2DGMwCOC.jpg'),
(132912, 9383, 'My Happy End [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4a4G5yfGOJTPmISfBYEPIk1WYiV.jpg'),
(132913, 9383, 'My Happy End [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hgjqhnzm1kjwtdOiVGjl1SSIJ7b.jpg'),
(132914, 9383, 'My Happy End [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj2HjjwjnrkVH3xgehUF9VRsVv.jpg'),
(132915, 9383, 'My Happy End [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj2HjjwjnrkVH3xgehUF9VRsVv.jpg'),
(132916, 9383, 'My Happy End [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj2HjjwjnrkVH3xgehUF9VRsVv.jpg'),
(132917, 9383, 'My Happy End [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj2HjjwjnrkVH3xgehUF9VRsVv.jpg'),
(132918, 9383, 'My Happy End [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj2HjjwjnrkVH3xgehUF9VRsVv.jpg'),
(132919, 9383, 'My Happy End [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj2HjjwjnrkVH3xgehUF9VRsVv.jpg'),
(132920, 9383, 'My Happy End [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj2HjjwjnrkVH3xgehUF9VRsVv.jpg'),
(132921, 9383, 'My Happy End [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj2HjjwjnrkVH3xgehUF9VRsVv.jpg'),
(132922, 9383, 'My Happy End [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/276348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj2HjjwjnrkVH3xgehUF9VRsVv.jpg'),
(132923, 9383, 'My Happy End [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/276349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj2HjjwjnrkVH3xgehUF9VRsVv.jpg'),
(132924, 9383, 'My Happy End [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/280716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj2HjjwjnrkVH3xgehUF9VRsVv.jpg'),
(132925, 9383, 'My Happy End [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/282623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nj2HjjwjnrkVH3xgehUF9VRsVv.jpg'),
(132926, 9475, 'O Amor Que Me Da [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zXFijFz4aQTeuRIn4aRwQLLI5ur.jpg'),
(132927, 9475, 'O Amor Que Me Da [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hC3V219b43zKaMo5REvSQaNKIcL.jpg'),
(132928, 9475, 'O Amor Que Me Da [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wAdDWkE1YgbWGwkay4MiPcXZTnX.jpg'),
(132929, 9475, 'O Amor Que Me Da [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2wBmlsoxrdwwTua7xWzZTZhrryU.jpg'),
(132930, 9475, 'O Amor Que Me Da [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aGRYsILhjzfXKQFPTyOIDChLrTP.jpg'),
(132931, 9475, 'O Amor Que Me Da [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/knbzwlTd8a8iQgumtuUKW7Sf38R.jpg'),
(132932, 9475, 'O Amor Que Me Da [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s2ZrkRFpXOAiNPviBOQ2i0GovqI.jpg'),
(132933, 9475, 'O Amor Que Me Da [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zsbongXV1nQwfMSj4KTTsjSWOLn.jpg'),
(132934, 9475, 'O Amor Que Me Da [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lGEwVVXhISSQAb7Opf5bYDR7M1Q.jpg'),
(132935, 9475, 'O Amor Que Me Da [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hTyrRhdQCFE91PRW0c2RStkb1iW.jpg'),
(132936, 9475, 'O Amor Que Me Da [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/RVJm2PknP9UwBRH6cRidB6ejUA.jpg'),
(132937, 9475, 'O Amor Que Me Da [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9678TopTRDtCCbUzM5pe3dYkfIJ.jpg'),
(132938, 9475, 'O Amor Que Me Da [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2sWcAKY84fNwU8goFf86KnuBaUn.jpg'),
(132939, 9475, 'O Amor Que Me Da [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/259297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Kg8qv5EfijY8RFeSpsgcC7sue2.jpg'),
(132940, 9475, 'O Amor Que Me Da [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/259298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2YwkWEkR08GtJCmW0cKYJqEDDLO.jpg'),
(132941, 9475, 'O Amor Que Me Da [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/259299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/57wS6c9gLQW26ASF5UU6c3839zz.jpg'),
(132942, 9475, 'O Amor Que Me Da [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/259300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pCSW3y8Xrv62AlDwj9tllOuS0xC.jpg'),
(132943, 9475, 'O Amor Que Me Da [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/259301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2aXIZ3XXKdQlp7YsaRfagJxNbFo.jpg'),
(132944, 9475, 'O Amor Que Me Da [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/259302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/llGfrjy39vyfG0mSyc33iJ0I8dm.jpg'),
(132945, 9475, 'O Amor Que Me Da [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/259303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nomCAAHTpZXU0I7ueF1RYHsqBWl.jpg'),
(132946, 9475, 'O Amor Que Me Da [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/259304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w4BKiQQGxez8IAqD4pWWDkDLtT9.jpg'),
(132947, 9475, 'O Amor Que Me Da [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/259305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8QE2iTUt69ZsVJUV1w4SHMkQKKz.jpg'),
(132948, 9475, 'O Amor Que Me Da [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/259306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7vVANKrJhihENnnjmgKU0oDy7V.jpg'),
(132949, 9475, 'O Amor Que Me Da [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/259307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gDku5DWCWdGzqoZbPK3tdzxMD7L.jpg'),
(132950, 9475, 'O Amor Que Me Da [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/259308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iesxyLL63hhW2YbziRksxhikQam.jpg'),
(132951, 9475, 'O Amor Que Me Da [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/259309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3GTBoD8i9rN26oo9WroOFfc0ztx.jpg'),
(132952, 9475, 'O Amor Que Me Da [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/259310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nysM4xSdeXv0rzLPtTmsih6HLq3.jpg'),
(132953, 9475, 'O Amor Que Me Da [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/259311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kIjpUKQQxP1cnkRQ8QTQ5rL7aQA.jpg'),
(132954, 9476, 'O Bom Doutor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtFhU1PXSdDryZDH009dBkILJhI.jpg'),
(132955, 9476, 'O Bom Doutor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtFhU1PXSdDryZDH009dBkILJhI.jpg'),
(132956, 9476, 'O Bom Doutor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtFhU1PXSdDryZDH009dBkILJhI.jpg'),
(132957, 9476, 'O Bom Doutor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtFhU1PXSdDryZDH009dBkILJhI.jpg'),
(132958, 9476, 'O Bom Doutor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtFhU1PXSdDryZDH009dBkILJhI.jpg'),
(132959, 9476, 'O Bom Doutor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtFhU1PXSdDryZDH009dBkILJhI.jpg'),
(132960, 9476, 'O Bom Doutor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtFhU1PXSdDryZDH009dBkILJhI.jpg'),
(132961, 9476, 'O Bom Doutor [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtFhU1PXSdDryZDH009dBkILJhI.jpg'),
(132962, 9476, 'O Bom Doutor [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtFhU1PXSdDryZDH009dBkILJhI.jpg'),
(132963, 9476, 'O Bom Doutor [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtFhU1PXSdDryZDH009dBkILJhI.jpg'),
(132964, 9476, 'O Bom Doutor [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtFhU1PXSdDryZDH009dBkILJhI.jpg'),
(132965, 9476, 'O Bom Doutor [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtFhU1PXSdDryZDH009dBkILJhI.jpg'),
(132966, 9476, 'O Bom Doutor [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtFhU1PXSdDryZDH009dBkILJhI.jpg'),
(132967, 9476, 'O Bom Doutor [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/259568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtFhU1PXSdDryZDH009dBkILJhI.jpg'),
(132968, 9476, 'O Bom Doutor [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/259569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtFhU1PXSdDryZDH009dBkILJhI.jpg'),
(132969, 9476, 'O Bom Doutor [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/259570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtFhU1PXSdDryZDH009dBkILJhI.jpg'),
(132970, 9476, 'O Bom Doutor [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/259571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtFhU1PXSdDryZDH009dBkILJhI.jpg'),
(132971, 9476, 'O Bom Doutor [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/259572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtFhU1PXSdDryZDH009dBkILJhI.jpg'),
(132972, 9476, 'O Bom Doutor [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/259573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtFhU1PXSdDryZDH009dBkILJhI.jpg'),
(132973, 9476, 'O Bom Doutor [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/259574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtFhU1PXSdDryZDH009dBkILJhI.jpg'),
(132974, 4116, 'Os Padrinhos Magicos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfkzr2nKel9cgVWwcWcN9IWMKTK.jpg'),
(132975, 4116, 'Os Padrinhos Magicos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7VcL37W3bPrJWeW1HP9XUgPbHnz.jpg'),
(132976, 4116, 'Os Padrinhos Magicos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6snalsyC9ghZoMzK5FEE4OqpiFq.jpg'),
(132977, 4116, 'Os Padrinhos Magicos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvRwyzoyV53YgXSmVzNvIudypXT.jpg'),
(132978, 4116, 'Os Padrinhos Magicos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lWlsHsauwdx0OadMsHUDvaRRhJP.jpg'),
(132979, 4116, 'Os Padrinhos Magicos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8XvflF2r1uCr0v4DUzYG1Vj3jdy.jpg'),
(132980, 4116, 'Os Padrinhos Magicos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6czheSFF8ZzGKISncdTYarIdtfr.jpg'),
(132981, 4116, 'Os Padrinhos Magicos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zlo9AScTckB9BZzl1szuWiM3pk3.jpg'),
(132982, 4116, 'Os Padrinhos Magicos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i40xDzrAxHSUM8Au0fA0hVcWs3o.jpg'),
(132983, 4116, 'Os Padrinhos Magicos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6jgdOKVZUGF418W6uhpjkuiMceg.jpg'),
(132984, 4116, 'Os Padrinhos Magicos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j9CtyVFsQHJ6SWaLWDXap6KYt23.jpg'),
(132985, 4116, 'Os Padrinhos Magicos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pPhX3KMYRJBR2RE85HdsTRpQyT0.jpg'),
(132986, 9477, 'Queridos Amigos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(132987, 9477, 'Queridos Amigos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(132988, 9477, 'Queridos Amigos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(132989, 9477, 'Queridos Amigos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(132990, 9477, 'Queridos Amigos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(132991, 9477, 'Queridos Amigos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(132992, 9477, 'Queridos Amigos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(132993, 9477, 'Queridos Amigos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(132994, 9477, 'Queridos Amigos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(132995, 9477, 'Queridos Amigos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(132996, 9477, 'Queridos Amigos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(132997, 9477, 'Queridos Amigos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(132998, 9477, 'Queridos Amigos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(132999, 9477, 'Queridos Amigos S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/259531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(133000, 9477, 'Queridos Amigos S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/259532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(133001, 9477, 'Queridos Amigos S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/259533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(133002, 9477, 'Queridos Amigos S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/259534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(133003, 9477, 'Queridos Amigos S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/259535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(133004, 9477, 'Queridos Amigos S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/259536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(133005, 9477, 'Queridos Amigos S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/259537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(133006, 9477, 'Queridos Amigos S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/259538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(133007, 9477, 'Queridos Amigos S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/259539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(133008, 9477, 'Queridos Amigos S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/259540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(133009, 9477, 'Queridos Amigos S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/259541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(133010, 9477, 'Queridos Amigos S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/259542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qst5eurNkm3jnJAqEEWZcKKjr6Q.jpg'),
(133011, 9478, 'Road Home [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzCOHLGfS7b60gFLsIJ4axqdeWY.jpg'),
(133012, 9478, 'Road Home [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4SuVKzjaqNEBkrIKVi1bmXwzvtS.jpg'),
(133013, 9478, 'Road Home [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/55Jo0dkdh2CzB0kokfHmWUrtFhI.jpg'),
(133014, 9478, 'Road Home [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1oTQ1PEulclMiB8IoNZcTOQvakM.jpg'),
(133015, 9478, 'Road Home [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rjoi3v3ivEtktd7p72UxyrqxduY.jpg'),
(133016, 9478, 'Road Home [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cCd5U4OZCZ32K7FvyFOSR07QoPM.jpg'),
(133017, 9478, 'Road Home [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/irlveo0Tx3sRI6bjVklaHE0IrcL.jpg'),
(133018, 9478, 'Road Home [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pB3ODGxRiRcQECwiEZ6GFob9qws.jpg'),
(133019, 9478, 'Road Home [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3UsGPykCCnIgTVzHvBbNyzcbA7C.jpg'),
(133020, 9478, 'Road Home [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/34h488h0s4MT0fg3KaSZG4W6Kvd.jpg'),
(133021, 9478, 'Road Home [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8pYFI1C3ERonyevqdGV5Bziy8Ab.jpg'),
(133022, 9478, 'Road Home [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gL5t9A3UHMeWqbUz5qB4zEs72E2.jpg'),
(133023, 9478, 'Road Home [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2UvrDBsxdlepgXd0DW5puqTr0FO.jpg'),
(133024, 9478, 'Road Home [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/259501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3yESEPhKH7VfA3VY7fv6ez5XBzo.jpg'),
(133025, 9478, 'Road Home [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/259502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hqOVNbG2eTlUQGfxzjlWvluUmOd.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(133026, 9478, 'Road Home [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/259503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fKaKkRHP5eiNgzF05YTl3Gs7uKN.jpg'),
(133027, 9478, 'Road Home [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/259504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dtKpsJIoDAYTf2e4DKddUAP29FQ.jpg'),
(133028, 9478, 'Road Home [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/259505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/54dr6Oh7PQ2eSVEI9bnTzU5RiEp.jpg'),
(133029, 9478, 'Road Home [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/259506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q5dPUChsHjDJMKitUIEEiAjpkHt.jpg'),
(133030, 9478, 'Road Home [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/259507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lImXQPtDh6hLAOCHrzHgqUgO2SN.jpg'),
(133031, 9478, 'Road Home [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/259508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ADmAhDx0UUHwtbLjI8Kaaf38Av.jpg'),
(133032, 9478, 'Road Home [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/259509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4HKifEO27cOmTpatUA8q5IBVg4c.jpg'),
(133033, 9478, 'Road Home [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/259510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aLdg3NdWMExIT7xIPX8vs6d2gYR.jpg'),
(133034, 9478, 'Road Home [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/259511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wy6PahqsSywwp2yiznI3Nm5fdDR.jpg'),
(133035, 9478, 'Road Home [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/259512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7sat2hOHcAZ88Su5V82kpO2IQIg.jpg'),
(133036, 9478, 'Road Home [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/259513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p4zYfopTEpIFpx2e6sNlyM3thJi.jpg'),
(133037, 9478, 'Road Home [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/259514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6SUM6MOV9sk0TfofuMK7jzebl2.jpg'),
(133038, 9478, 'Road Home [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/259515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zSNxxz04gTRDxp6urZvX6GHY9m1.jpg'),
(133039, 9478, 'Road Home [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/259516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uFGqhgASR9VLTSBmkFcpu6JQaVE.jpg'),
(133040, 9478, 'Road Home [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/259517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eN6tJEVjwujoXjTi79zuXHtLd53.jpg'),
(133041, 9479, 'Sanctuary A Witchs Tale [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r6vRvgKVLZlZFrQtMdvis1RSqGk.jpg'),
(133042, 9479, 'Sanctuary A Witchs Tale [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/YTEYvTGQXX1QBvr5vr5Lvv9GgY.jpg'),
(133043, 9479, 'Sanctuary A Witchs Tale [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iZllgPmOXS5PadAs4mDp6JhQJod.jpg'),
(133044, 9479, 'Sanctuary A Witchs Tale [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iZllgPmOXS5PadAs4mDp6JhQJod.jpg'),
(133045, 9479, 'Sanctuary A Witchs Tale [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iZllgPmOXS5PadAs4mDp6JhQJod.jpg'),
(133046, 9479, 'Sanctuary A Witchs Tale [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/272631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iZllgPmOXS5PadAs4mDp6JhQJod.jpg'),
(133047, 9479, 'Sanctuary A Witchs Tale [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/272632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iZllgPmOXS5PadAs4mDp6JhQJod.jpg'),
(133048, 9480, 'Shine or Go Crazy [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3C9geb7lSLJgI0VZv8LtGVDfXHK.jpg'),
(133049, 9480, 'Shine or Go Crazy [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cqGXU4XB9r4OBK2DBlAbrAoZSiG.jpg'),
(133050, 9480, 'Shine or Go Crazy [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gSw5JokIHIgR6FF9VLp5oHYiG0W.jpg'),
(133051, 9480, 'Shine or Go Crazy [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kPsZJeAhnAmsvqndaXqF4BRsSG2.jpg'),
(133052, 9480, 'Shine or Go Crazy [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/skTdicDdUxZzO5gEvLI0j0CGD8Y.jpg'),
(133053, 9480, 'Shine or Go Crazy [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oh19oRIrGTxNX2YAKDc5BDviARs.jpg'),
(133054, 9480, 'Shine or Go Crazy [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v5RXYupxGzfcMtXHu1ZQSgKgsq0.jpg'),
(133055, 9480, 'Shine or Go Crazy [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cn2hc1QMQzZogSomSIXhO419us9.jpg'),
(133056, 9480, 'Shine or Go Crazy [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ZTIA2xB0WLD6EHWOPRWYQdtrkh.jpg'),
(133057, 9480, 'Shine or Go Crazy [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g41l3bKsV50Phh36gp5UzFSvy11.jpg'),
(133058, 9480, 'Shine or Go Crazy [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c2i27oHX2K72KU1mc1HITvElHn2.jpg'),
(133059, 9480, 'Shine or Go Crazy [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tfqjhxn5cn50pOyxHnnkKh4J1Og.jpg'),
(133060, 9480, 'Shine or Go Crazy [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2bwPymfKzmkZDaGbAExLVZ7Kkbf.jpg'),
(133061, 9480, 'Shine or Go Crazy [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/259477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4sZL7JucfSujwXDD4Hl0Co0dGUO.jpg'),
(133062, 9480, 'Shine or Go Crazy [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/259478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uIqOIyAq8VSkS4Rj29z6W97p5rA.jpg'),
(133063, 9480, 'Shine or Go Crazy [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/259479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ypeljLSoDLS4ppX6xYJog29rlyb.jpg'),
(133064, 9480, 'Shine or Go Crazy [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/259480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cMmPIKn1sHraF2tG3kOxFj89JPq.jpg'),
(133065, 9480, 'Shine or Go Crazy [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/259481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8mwkT36dNvdcXgapX7R4vu5KRxF.jpg'),
(133066, 9480, 'Shine or Go Crazy [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/259482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/luDllnTauCYDBYRrJVzBvtSgHg9.jpg'),
(133067, 9480, 'Shine or Go Crazy [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/259483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kALIeNtqdNDoR6nbgcCTN07wRXq.jpg'),
(133068, 9480, 'Shine or Go Crazy [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/259484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hqUFxOnnzXVrtuz68XJMIJU15hN.jpg'),
(133069, 9480, 'Shine or Go Crazy [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/259485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5YYTdw0v8Hu1yI7dycvU7S0vUd1.jpg'),
(133070, 9480, 'Shine or Go Crazy [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/259486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ccz4Ah7KSMljNjGqPsftxT6NONF.jpg'),
(133071, 9480, 'Shine or Go Crazy [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/259487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n24q3fLSZDccNipgyp8IzF2Gocd.jpg'),
(133072, 9481, 'Solo Leveling [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyjphDUt1vrlckpvfPd0TekuqMm.jpg'),
(133073, 9481, 'Solo Leveling [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133074, 9481, 'Solo Leveling [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133075, 9481, 'Solo Leveling [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133076, 9481, 'Solo Leveling [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133077, 9481, 'Solo Leveling [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/272570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133078, 9481, 'Solo Leveling [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/313546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133079, 9481, 'Solo Leveling [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/313547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133080, 9481, 'Solo Leveling [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/313548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133081, 9481, 'Solo Leveling [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/313549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133082, 9481, 'Solo Leveling [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/313550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133083, 9481, 'Solo Leveling [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/313551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133084, 9481, 'Solo Leveling [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/313552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133085, 9482, 'Solo Leveling [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/660155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133086, 9482, 'Solo Leveling [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/660156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133087, 9482, 'Solo Leveling [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/667371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133088, 9482, 'Solo Leveling [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/674716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133089, 9482, 'Solo Leveling [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/692798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133090, 9482, 'Solo Leveling [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/688307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133091, 9482, 'Solo Leveling [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/697420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133092, 9482, 'Solo Leveling [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/704002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133093, 9482, 'Solo Leveling [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/715929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133094, 9482, 'Solo Leveling [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/720903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133095, 9482, 'Solo Leveling [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/728470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133096, 9482, 'Solo Leveling [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/737234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133097, 9482, 'Solo Leveling [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/750206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zn7hOslLYG1U2m06jGJJln8Ry7t.jpg'),
(133098, 3082, 'Steven Universo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133099, 3082, 'Steven Universo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133100, 3082, 'Steven Universo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133101, 3082, 'Steven Universo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133102, 3082, 'Steven Universo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133103, 3082, 'Steven Universo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133104, 3082, 'Steven Universo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133105, 3082, 'Steven Universo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133106, 3082, 'Steven Universo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133107, 3082, 'Steven Universo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133108, 3082, 'Steven Universo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133109, 3082, 'Steven Universo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133110, 3082, 'Steven Universo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133111, 3082, 'Steven Universo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/259325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133112, 3082, 'Steven Universo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/259326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133113, 3082, 'Steven Universo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/259327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133114, 3082, 'Steven Universo S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/259328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133115, 3082, 'Steven Universo S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/259329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133116, 3082, 'Steven Universo S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/259330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133117, 3082, 'Steven Universo S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/259331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133118, 3082, 'Steven Universo S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/259332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133119, 3082, 'Steven Universo S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/259333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133120, 3082, 'Steven Universo S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/259334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133121, 3082, 'Steven Universo S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/259335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133122, 3082, 'Steven Universo S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/259336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133123, 3082, 'Steven Universo S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/259337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133124, 3082, 'Steven Universo S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/259338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133125, 3082, 'Steven Universo S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/259339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133126, 3082, 'Steven Universo S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/259340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133127, 3082, 'Steven Universo S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/259341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133128, 3082, 'Steven Universo S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/259342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133129, 3082, 'Steven Universo S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/259343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133130, 3082, 'Steven Universo S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/259344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133131, 3082, 'Steven Universo S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/259345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133132, 3082, 'Steven Universo S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/259346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133133, 3082, 'Steven Universo S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/259347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133134, 3082, 'Steven Universo S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/259348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133135, 3082, 'Steven Universo S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/259349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133136, 3082, 'Steven Universo S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/259350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133137, 3082, 'Steven Universo S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/259351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133138, 3082, 'Steven Universo S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/259352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133139, 3082, 'Steven Universo S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/259353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133140, 3082, 'Steven Universo S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/259354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133141, 3082, 'Steven Universo S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/259355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133142, 3082, 'Steven Universo S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/259356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133143, 3082, 'Steven Universo S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/259357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133144, 3082, 'Steven Universo S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/259358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133145, 3082, 'Steven Universo S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/259359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133146, 3082, 'Steven Universo S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/259360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133147, 3082, 'Steven Universo S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/259361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133148, 3082, 'Steven Universo S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/259362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133149, 3082, 'Steven Universo S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/259363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133150, 3083, 'Steven Universo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133151, 3083, 'Steven Universo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133152, 3083, 'Steven Universo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133153, 3083, 'Steven Universo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133154, 3083, 'Steven Universo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133155, 3083, 'Steven Universo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133156, 3083, 'Steven Universo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133157, 3083, 'Steven Universo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133158, 3083, 'Steven Universo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133159, 3083, 'Steven Universo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133160, 3083, 'Steven Universo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133161, 3083, 'Steven Universo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133162, 3083, 'Steven Universo S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133163, 3083, 'Steven Universo S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/259377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133164, 3083, 'Steven Universo S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/259378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133165, 3083, 'Steven Universo S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/259379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133166, 3083, 'Steven Universo S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/259380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133167, 3083, 'Steven Universo S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/259381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133168, 3083, 'Steven Universo S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/259382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133169, 3083, 'Steven Universo S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/259383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133170, 3083, 'Steven Universo S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/259384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133171, 3083, 'Steven Universo S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/259385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133172, 3084, 'Steven Universo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133173, 3084, 'Steven Universo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133174, 3084, 'Steven Universo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133175, 3084, 'Steven Universo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133176, 3084, 'Steven Universo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133177, 3084, 'Steven Universo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133178, 3084, 'Steven Universo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133179, 3084, 'Steven Universo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133180, 3084, 'Steven Universo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133181, 3084, 'Steven Universo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133182, 3084, 'Steven Universo S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133183, 3084, 'Steven Universo S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133184, 3084, 'Steven Universo S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133185, 3084, 'Steven Universo S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/259399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133186, 3084, 'Steven Universo S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/259400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133187, 3084, 'Steven Universo S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/259401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133188, 3084, 'Steven Universo S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/259402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133189, 3084, 'Steven Universo S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/259403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133190, 3084, 'Steven Universo S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/259404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133191, 3084, 'Steven Universo S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/259405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133192, 3084, 'Steven Universo S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/259406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133193, 3084, 'Steven Universo S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/259407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133194, 3084, 'Steven Universo S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/259408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133195, 3084, 'Steven Universo S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/259409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133196, 3084, 'Steven Universo S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/259410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133197, 3084, 'Steven Universo S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/259411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133198, 3084, 'Steven Universo S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/259412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133199, 3084, 'Steven Universo S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/259413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133200, 3085, 'Steven Universo S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133201, 3085, 'Steven Universo S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133202, 3085, 'Steven Universo S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133203, 3085, 'Steven Universo S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133204, 3085, 'Steven Universo S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133205, 3085, 'Steven Universo S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133206, 3085, 'Steven Universo S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133207, 3085, 'Steven Universo S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133208, 3085, 'Steven Universo S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133209, 3085, 'Steven Universo S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133210, 3085, 'Steven Universo S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133211, 3085, 'Steven Universo S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133212, 3085, 'Steven Universo S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133213, 3085, 'Steven Universo S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/259427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133214, 3085, 'Steven Universo S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/259428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133215, 3085, 'Steven Universo S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/259429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133216, 3085, 'Steven Universo S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/259430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133217, 3085, 'Steven Universo S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/259431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133218, 3085, 'Steven Universo S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/259432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133219, 3085, 'Steven Universo S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/259433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133220, 3085, 'Steven Universo S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/259434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133221, 3085, 'Steven Universo S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/259435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133222, 3085, 'Steven Universo S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/259436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133223, 3085, 'Steven Universo S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/259437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133224, 3086, 'Steven Universo S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133225, 3086, 'Steven Universo S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133226, 3086, 'Steven Universo S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133227, 3086, 'Steven Universo S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133228, 3086, 'Steven Universo S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133229, 3086, 'Steven Universo S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133230, 3086, 'Steven Universo S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133231, 3086, 'Steven Universo S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133232, 3086, 'Steven Universo S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133233, 3086, 'Steven Universo S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133234, 3086, 'Steven Universo S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133235, 3086, 'Steven Universo S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133236, 3086, 'Steven Universo S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/259450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133237, 3086, 'Steven Universo S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/259451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133238, 3086, 'Steven Universo S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/259452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133239, 3086, 'Steven Universo S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/259453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133240, 3086, 'Steven Universo S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/259454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133241, 3086, 'Steven Universo S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/259455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133242, 3086, 'Steven Universo S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/259456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133243, 3086, 'Steven Universo S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/259457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133244, 3086, 'Steven Universo S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/259458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133245, 3086, 'Steven Universo S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/259459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133246, 3086, 'Steven Universo S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/259460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133247, 3086, 'Steven Universo S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/259461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133248, 3086, 'Steven Universo S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/259462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133249, 3086, 'Steven Universo S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/259463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6weCsVhZid47PQfMcnLtwIUayZ.jpg'),
(133250, 9483, 'The Foolish Angel Dances with the Devil [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tA3Gj13FIn2U8v5BtSJczCsNXIk.jpg'),
(133251, 9483, 'The Foolish Angel Dances with the Devil [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4X2yAU6CtHwjiVlO07WxssRwKPu.jpg'),
(133252, 9483, 'The Foolish Angel Dances with the Devil [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4X2yAU6CtHwjiVlO07WxssRwKPu.jpg'),
(133253, 9483, 'The Foolish Angel Dances with the Devil [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4X2yAU6CtHwjiVlO07WxssRwKPu.jpg'),
(133254, 9483, 'The Foolish Angel Dances with the Devil [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/272502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4X2yAU6CtHwjiVlO07WxssRwKPu.jpg'),
(133255, 9483, 'The Foolish Angel Dances with the Devil [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/272503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4X2yAU6CtHwjiVlO07WxssRwKPu.jpg'),
(133256, 9483, 'The Foolish Angel Dances with the Devil [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/277489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4X2yAU6CtHwjiVlO07WxssRwKPu.jpg'),
(133257, 9483, 'The Foolish Angel Dances with the Devil [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/288454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4X2yAU6CtHwjiVlO07WxssRwKPu.jpg'),
(133258, 9483, 'The Foolish Angel Dances with the Devil [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/293956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4X2yAU6CtHwjiVlO07WxssRwKPu.jpg'),
(133259, 9483, 'The Foolish Angel Dances with the Devil [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/299039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4X2yAU6CtHwjiVlO07WxssRwKPu.jpg'),
(133260, 9483, 'The Foolish Angel Dances with the Devil [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/303886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4X2yAU6CtHwjiVlO07WxssRwKPu.jpg'),
(133261, 9483, 'The Foolish Angel Dances with the Devil [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/309580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4X2yAU6CtHwjiVlO07WxssRwKPu.jpg'),
(133262, 9484, 'Vinganca Dinheiro e Poder [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jwwFKYK0M0sQO38pfuX1rRGrugA.jpg'),
(133263, 9484, 'Vinganca Dinheiro e Poder [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yKkb1ZzKNNrDrUyJlQWUSP2inhO.jpg'),
(133264, 9484, 'Vinganca Dinheiro e Poder [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hK0JrGeqkbxfZ2oGGDDR1ykt6ZF.jpg'),
(133265, 9484, 'Vinganca Dinheiro e Poder [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yfrqk7zkLtCKp4jtxkg3dLKe6sl.jpg'),
(133266, 9484, 'Vinganca Dinheiro e Poder [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oYtAsu3lpKwK3KHMImQeZK2tjPH.jpg'),
(133267, 9484, 'Vinganca Dinheiro e Poder [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kJ3ZTCBF94yR1HDq8y40qMIg1hH.jpg'),
(133268, 9484, 'Vinganca Dinheiro e Poder [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jiaODhe9G9WnkjyL182tKWOKmfV.jpg'),
(133269, 9484, 'Vinganca Dinheiro e Poder [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7DiM0kwKMOLcmIB6C6zjsPFEiB4.jpg'),
(133270, 9484, 'Vinganca Dinheiro e Poder [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zN3XAMUa9x3UzNPzc3nTKb7TlRB.jpg'),
(133271, 9484, 'Vinganca Dinheiro e Poder [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f7WgMjS5jbcfYb6xSZ99iCxv0Uk.jpg'),
(133272, 9484, 'Vinganca Dinheiro e Poder [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hv2NL5detnLVULnV0Pejc3XVXQf.jpg'),
(133273, 9484, 'Vinganca Dinheiro e Poder [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qVN3U5xrAfDdk03ogSQBmQihaEM.jpg'),
(133274, 9485, 'World on a Wire [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4mjzFozVRsOaPjL3MOTxRYVU1OJ.jpg'),
(133275, 9485, 'World on a Wire [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4mjzFozVRsOaPjL3MOTxRYVU1OJ.jpg'),
(133276, 9486, 'Abraham Lincoln S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tOpof4g0dAHe60bm7cKncIbAOdh.jpg'),
(133277, 9486, 'Abraham Lincoln S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tM23iqEPAJUAIAryD294BZo93UY.jpg'),
(133278, 9486, 'Abraham Lincoln S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iQq1nPQsmFJXNQbZ4xLwlPSrWbD.jpg'),
(133279, 9487, 'James May Nosso Homem no Japao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QEqUFiWk1JCFqQJJ2HKKqofyBC.jpg'),
(133280, 9487, 'James May Nosso Homem no Japao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mcais7QZcmqXTSKZkoTnFUGFxIl.jpg'),
(133281, 9487, 'James May Nosso Homem no Japao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kXE1mpMNUIoYTQ9gPgne60VYKY6.jpg'),
(133282, 9487, 'James May Nosso Homem no Japao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/atkEaSa92vFMSAemR42NwtcTzzi.jpg'),
(133283, 9487, 'James May Nosso Homem no Japao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTMkxfKw71N3DBMjPA3DakBfUFw.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(133284, 9487, 'James May Nosso Homem no Japao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qKHLDXvzLgqj8uBPh46AeE5bGQT.jpg'),
(133285, 9488, 'James May Nosso Homem no Japao S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8tVJjWwpfJTCAzte6MvqQq26u9t.jpg'),
(133286, 9488, 'James May Nosso Homem no Japao S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o3WQtn2jarNOLTTc2TIOVX8nHF8.jpg'),
(133287, 9488, 'James May Nosso Homem no Japao S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mmLRoZ4NY3k6i0Apc8KkLTLOeFy.jpg'),
(133288, 9488, 'James May Nosso Homem no Japao S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qzOLkJrNjxDlfv4G1dozxGuwIcp.jpg'),
(133289, 9488, 'James May Nosso Homem no Japao S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ideJnld1Kb2po5lhWoksBIOMgps.jpg'),
(133290, 9488, 'James May Nosso Homem no Japao S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8LkZzakPCyGdMZIH3AeVd6tAgW8.jpg'),
(133291, 9489, 'James May Nosso Homem no Japao S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iI5nO1SORWieLqN6zVmcX5dhhmv.jpg'),
(133292, 9489, 'James May Nosso Homem no Japao S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kthOf7XACAadwxK1kntkXKHbWi9.jpg'),
(133293, 9489, 'James May Nosso Homem no Japao S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dQtjyeCKoSGsdfuBJa0M8f6ofyW.jpg'),
(133294, 9490, 'SHY S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ruHXBXSb93K1erMaae8ba7F0vsP.jpg'),
(133295, 9490, 'SHY S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iobXFRFROTPgTbP43lbPStWmcGB.jpg'),
(133296, 9490, 'SHY S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9mJ2L1SQwMWTzQaip0kWSz070u2.jpg'),
(133297, 9490, 'SHY S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mu9io9oX4KlyRp2twY8jjZzcozu.jpg'),
(133298, 9490, 'SHY S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tCdQcexnhOhMonoVKYvzSkMpLIw.jpg'),
(133299, 9490, 'SHY S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4aq43aUWeibLGktcw8gQV6C92gm.jpg'),
(133300, 9490, 'SHY S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24dgKSWxJoFi59A25Qjm20IQRDM.jpg'),
(133301, 9490, 'SHY S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s2kFJWh4N3aMn4xvdICwEKXjt28.jpg'),
(133302, 9490, 'SHY S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8qCLxkmLtHMpDuCDqpWM0OYZjn.jpg'),
(133303, 9490, 'SHY S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/259249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oL8qPKCYEAUdoSahJoTRtcU6Ho4.jpg'),
(133304, 9490, 'SHY S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/259250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f8r5dvWaACJvv69w3qEzjKHrn6I.jpg'),
(133305, 9490, 'SHY S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/259251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pwkbOFZCtqs9IWFbgrgfl34pKca.jpg'),
(133306, 9491, 'Undead Unluck S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1bN6fZY8szmpwaBY9qE0zxV1Rax.jpg'),
(133307, 9491, 'Undead Unluck S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/woQd6Nq9AX3hu2xhciqYm6cNgbW.jpg'),
(133308, 9491, 'Undead Unluck S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wRMaGj8hMjsM0a8AoiNqhgBYBaP.jpg'),
(133309, 9491, 'Undead Unluck S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62LKH8aho4EeZmcpYks9DvxyHxB.jpg'),
(133310, 9491, 'Undead Unluck S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62LKH8aho4EeZmcpYks9DvxyHxB.jpg'),
(133311, 9491, 'Undead Unluck S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/323444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62LKH8aho4EeZmcpYks9DvxyHxB.jpg'),
(133312, 9491, 'Undead Unluck S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/323445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62LKH8aho4EeZmcpYks9DvxyHxB.jpg'),
(133313, 9491, 'Undead Unluck S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/323446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62LKH8aho4EeZmcpYks9DvxyHxB.jpg'),
(133314, 9491, 'Undead Unluck S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/323447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62LKH8aho4EeZmcpYks9DvxyHxB.jpg'),
(133315, 9491, 'Undead Unluck S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/323448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62LKH8aho4EeZmcpYks9DvxyHxB.jpg'),
(133316, 9491, 'Undead Unluck S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/323449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62LKH8aho4EeZmcpYks9DvxyHxB.jpg'),
(133317, 9491, 'Undead Unluck S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/323450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62LKH8aho4EeZmcpYks9DvxyHxB.jpg'),
(133318, 9491, 'Undead Unluck S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/323451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62LKH8aho4EeZmcpYks9DvxyHxB.jpg'),
(133319, 9491, 'Undead Unluck S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/323452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62LKH8aho4EeZmcpYks9DvxyHxB.jpg'),
(133320, 9491, 'Undead Unluck S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/327354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62LKH8aho4EeZmcpYks9DvxyHxB.jpg'),
(133321, 9491, 'Undead Unluck S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/358210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62LKH8aho4EeZmcpYks9DvxyHxB.jpg'),
(133322, 9491, 'Undead Unluck S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/358211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62LKH8aho4EeZmcpYks9DvxyHxB.jpg'),
(133323, 9491, 'Undead Unluck S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/358212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62LKH8aho4EeZmcpYks9DvxyHxB.jpg'),
(133324, 9491, 'Undead Unluck S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/358213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62LKH8aho4EeZmcpYks9DvxyHxB.jpg'),
(133325, 9491, 'Undead Unluck S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/358214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62LKH8aho4EeZmcpYks9DvxyHxB.jpg'),
(133326, 9491, 'Undead Unluck S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/414291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62LKH8aho4EeZmcpYks9DvxyHxB.jpg'),
(133327, 9491, 'Undead Unluck S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/414292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62LKH8aho4EeZmcpYks9DvxyHxB.jpg'),
(133328, 9491, 'Undead Unluck S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/414293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62LKH8aho4EeZmcpYks9DvxyHxB.jpg'),
(133329, 9491, 'Undead Unluck S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/414294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/62LKH8aho4EeZmcpYks9DvxyHxB.jpg'),
(133330, 9492, 'Minha Nada Mole Vida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133331, 9492, 'Minha Nada Mole Vida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133332, 9492, 'Minha Nada Mole Vida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133333, 9492, 'Minha Nada Mole Vida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133334, 9492, 'Minha Nada Mole Vida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133335, 9492, 'Minha Nada Mole Vida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133336, 9492, 'Minha Nada Mole Vida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133337, 9492, 'Minha Nada Mole Vida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133338, 9493, 'Minha Nada Mole Vida S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133339, 9493, 'Minha Nada Mole Vida S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133340, 9493, 'Minha Nada Mole Vida S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133341, 9493, 'Minha Nada Mole Vida S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133342, 9493, 'Minha Nada Mole Vida S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133343, 9493, 'Minha Nada Mole Vida S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133344, 9494, 'Minha Nada Mole Vida S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133345, 9494, 'Minha Nada Mole Vida S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133346, 9494, 'Minha Nada Mole Vida S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133347, 9494, 'Minha Nada Mole Vida S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133348, 9494, 'Minha Nada Mole Vida S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133349, 9494, 'Minha Nada Mole Vida S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133350, 9494, 'Minha Nada Mole Vida S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133351, 9494, 'Minha Nada Mole Vida S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133352, 9494, 'Minha Nada Mole Vida S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/259239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mshWGBZN7ejXcnRfJvZlX1NpKKy.jpg'),
(133353, 9495, 'Eco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9kOfCl1W78enM9dPl7daYx5BWWd.jpg'),
(133354, 9495, 'Eco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j33mLOqagobNEl3pe1OPvwuwV76.jpg'),
(133355, 9495, 'Eco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Vhmfgbbvb4B9Op6G219phQ9l71.jpg'),
(133356, 9495, 'Eco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jdj8YQPlEeOcWKsLiKsLsFPrbk8.jpg'),
(133357, 9495, 'Eco S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/45VvSf6PVxvLeVaJM2fwbW4yfAb.jpg'),
(133358, 9496, 'Historico Criminal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m1tGXHoCzcT4h1KGTGXpMSMoyAl.jpg'),
(133359, 9496, 'Historico Criminal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ucydLAGm0skxVmmmz5EYtgQImKN.jpg'),
(133360, 9496, 'Historico Criminal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fY6yBzy4ea7yCWW57G5q1EKxnU4.jpg'),
(133361, 9496, 'Historico Criminal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fY6yBzy4ea7yCWW57G5q1EKxnU4.jpg'),
(133362, 9496, 'Historico Criminal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/271166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fY6yBzy4ea7yCWW57G5q1EKxnU4.jpg'),
(133363, 9496, 'Historico Criminal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/271167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fY6yBzy4ea7yCWW57G5q1EKxnU4.jpg'),
(133364, 9496, 'Historico Criminal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/272869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fY6yBzy4ea7yCWW57G5q1EKxnU4.jpg'),
(133365, 9496, 'Historico Criminal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/277713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fY6yBzy4ea7yCWW57G5q1EKxnU4.jpg'),
(133366, 9497, 'Investidos o Jogo da Desconfianca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q8Tb8JKVaXYILlZRbSd6gYz5nMJ.jpg'),
(133367, 9497, 'Investidos o Jogo da Desconfianca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A9zyYydcMZMzVkujepWxVjACgfH.jpg'),
(133368, 9497, 'Investidos o Jogo da Desconfianca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8oGN1ega7YkOjYi6rebtyt0uHNB.jpg'),
(133369, 9497, 'Investidos o Jogo da Desconfianca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lVnkUNr3uH1NGhuE0otcMT3Yh0y.jpg'),
(133370, 9497, 'Investidos o Jogo da Desconfianca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qjZC5hVRMpOHgiQjlgGk6GL0tdQ.jpg'),
(133371, 9497, 'Investidos o Jogo da Desconfianca S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qjZC5hVRMpOHgiQjlgGk6GL0tdQ.jpg'),
(133372, 9497, 'Investidos o Jogo da Desconfianca S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qjZC5hVRMpOHgiQjlgGk6GL0tdQ.jpg'),
(133373, 9497, 'Investidos o Jogo da Desconfianca S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qjZC5hVRMpOHgiQjlgGk6GL0tdQ.jpg'),
(133374, 9498, 'Maravilhas Sombrias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/53SmWibCYQ57yFXMkXtvXIP3eWc.jpg'),
(133375, 9498, 'Maravilhas Sombrias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/br94x3uElGpXlX1sNzmFWe7RPs1.jpg'),
(133376, 9498, 'Maravilhas Sombrias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/br94x3uElGpXlX1sNzmFWe7RPs1.jpg'),
(133377, 9498, 'Maravilhas Sombrias S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/br94x3uElGpXlX1sNzmFWe7RPs1.jpg'),
(133378, 9498, 'Maravilhas Sombrias S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/br94x3uElGpXlX1sNzmFWe7RPs1.jpg'),
(133379, 9498, 'Maravilhas Sombrias S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/277674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/br94x3uElGpXlX1sNzmFWe7RPs1.jpg'),
(133380, 9498, 'Maravilhas Sombrias S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/br94x3uElGpXlX1sNzmFWe7RPs1.jpg'),
(133381, 9498, 'Maravilhas Sombrias S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/292047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/br94x3uElGpXlX1sNzmFWe7RPs1.jpg'),
(133382, 9499, 'Mesacast BBB S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g4LwGOOwpEUK45ncxa48F2BdyjF.jpg'),
(133383, 9499, 'Mesacast BBB S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g4LwGOOwpEUK45ncxa48F2BdyjF.jpg'),
(133384, 9499, 'Mesacast BBB S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g4LwGOOwpEUK45ncxa48F2BdyjF.jpg'),
(133385, 9499, 'Mesacast BBB S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g4LwGOOwpEUK45ncxa48F2BdyjF.jpg'),
(133386, 9499, 'Mesacast BBB S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g4LwGOOwpEUK45ncxa48F2BdyjF.jpg'),
(133387, 9499, 'Mesacast BBB S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g4LwGOOwpEUK45ncxa48F2BdyjF.jpg'),
(133388, 9499, 'Mesacast BBB S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g4LwGOOwpEUK45ncxa48F2BdyjF.jpg'),
(133389, 9499, 'Mesacast BBB S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g4LwGOOwpEUK45ncxa48F2BdyjF.jpg'),
(133390, 9499, 'Mesacast BBB S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/589965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g4LwGOOwpEUK45ncxa48F2BdyjF.jpg'),
(133391, 9500, 'Champion S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2OV8yBC2IBXbhFc9Sq3v0aAJmuJ.jpg'),
(133392, 9500, 'Champion S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dDfBvfUPXKWUNPdHOF8hIqkJLE.jpg'),
(133393, 9500, 'Champion S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/61JIv2NdfmnSysdqW6t0UPNmBz8.jpg'),
(133394, 9500, 'Champion S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AuTlPHKNId33sL423hQmy7XcJWU.jpg'),
(133395, 9500, 'Champion S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zddqDPi30y9mxn2evEkeblASnPL.jpg'),
(133396, 9500, 'Champion S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iqeAlLnzWndhvIjDlITAVLrlC1y.jpg'),
(133397, 9500, 'Champion S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8YS6BQXoaLjoEZMCYNAPtj28j9D.jpg'),
(133398, 9500, 'Champion S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/259211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fY1OHY9avqKB907UQucwQj0rIxc.jpg'),
(133399, 9501, 'Detective Forst S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xOYU8U5WobOvjexS9S2HO6cGT6O.jpg'),
(133400, 9501, 'Detective Forst S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xOYU8U5WobOvjexS9S2HO6cGT6O.jpg'),
(133401, 9501, 'Detective Forst S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xOYU8U5WobOvjexS9S2HO6cGT6O.jpg'),
(133402, 9501, 'Detective Forst S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xOYU8U5WobOvjexS9S2HO6cGT6O.jpg'),
(133403, 9501, 'Detective Forst S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xOYU8U5WobOvjexS9S2HO6cGT6O.jpg'),
(133404, 9501, 'Detective Forst S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xOYU8U5WobOvjexS9S2HO6cGT6O.jpg'),
(133405, 9502, 'Garoto Devora Universo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/259191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xjgdzdlyMPR519MW9YRkQXyNMvX.jpg'),
(133406, 9502, 'Garoto Devora Universo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/259192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xjgdzdlyMPR519MW9YRkQXyNMvX.jpg'),
(133407, 9502, 'Garoto Devora Universo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/259193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xjgdzdlyMPR519MW9YRkQXyNMvX.jpg'),
(133408, 9502, 'Garoto Devora Universo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/259194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xjgdzdlyMPR519MW9YRkQXyNMvX.jpg'),
(133409, 9502, 'Garoto Devora Universo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/259195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xjgdzdlyMPR519MW9YRkQXyNMvX.jpg'),
(133410, 9502, 'Garoto Devora Universo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/259196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xjgdzdlyMPR519MW9YRkQXyNMvX.jpg'),
(133411, 9502, 'Garoto Devora Universo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/259197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xjgdzdlyMPR519MW9YRkQXyNMvX.jpg'),
(133412, 9503, 'B Daman Crossfire S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133413, 9503, 'B Daman Crossfire S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133414, 9503, 'B Daman Crossfire S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133415, 9503, 'B Daman Crossfire S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133416, 9503, 'B Daman Crossfire S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133417, 9503, 'B Daman Crossfire S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133418, 9503, 'B Daman Crossfire S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133419, 9503, 'B Daman Crossfire S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133420, 9503, 'B Daman Crossfire S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133421, 9503, 'B Daman Crossfire S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133422, 9503, 'B Daman Crossfire S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/258926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133423, 9503, 'B Daman Crossfire S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/258927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133424, 9503, 'B Daman Crossfire S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/258928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133425, 9503, 'B Daman Crossfire S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/258929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133426, 9503, 'B Daman Crossfire S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/258930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133427, 9503, 'B Daman Crossfire S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/258931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133428, 9503, 'B Daman Crossfire S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/258932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133429, 9503, 'B Daman Crossfire S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/258933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133430, 9503, 'B Daman Crossfire S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/258934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133431, 9503, 'B Daman Crossfire S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/258935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133432, 9503, 'B Daman Crossfire S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/258936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133433, 9503, 'B Daman Crossfire S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/258937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133434, 9503, 'B Daman Crossfire S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/258938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133435, 9503, 'B Daman Crossfire S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/258939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133436, 9503, 'B Daman Crossfire S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/258940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133437, 9503, 'B Daman Crossfire S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/258941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VxTQ12nPsjQUezedSUjd4yn71D.jpg'),
(133438, 9504, 'Batalha do Churrasco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z5H0AFYkea80S5QFo6HQ3q5hPs.jpg'),
(133439, 9504, 'Batalha do Churrasco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z5H0AFYkea80S5QFo6HQ3q5hPs.jpg'),
(133440, 9504, 'Batalha do Churrasco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z5H0AFYkea80S5QFo6HQ3q5hPs.jpg'),
(133441, 9504, 'Batalha do Churrasco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z5H0AFYkea80S5QFo6HQ3q5hPs.jpg'),
(133442, 9505, 'Batalha do Churrasco S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z5H0AFYkea80S5QFo6HQ3q5hPs.jpg'),
(133443, 9505, 'Batalha do Churrasco S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z5H0AFYkea80S5QFo6HQ3q5hPs.jpg'),
(133444, 9505, 'Batalha do Churrasco S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z5H0AFYkea80S5QFo6HQ3q5hPs.jpg'),
(133445, 9505, 'Batalha do Churrasco S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z5H0AFYkea80S5QFo6HQ3q5hPs.jpg'),
(133446, 9505, 'Batalha do Churrasco S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z5H0AFYkea80S5QFo6HQ3q5hPs.jpg'),
(133447, 9505, 'Batalha do Churrasco S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z5H0AFYkea80S5QFo6HQ3q5hPs.jpg'),
(133448, 9505, 'Batalha do Churrasco S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z5H0AFYkea80S5QFo6HQ3q5hPs.jpg'),
(133449, 9505, 'Batalha do Churrasco S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z5H0AFYkea80S5QFo6HQ3q5hPs.jpg'),
(133450, 9505, 'Batalha do Churrasco S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z5H0AFYkea80S5QFo6HQ3q5hPs.jpg'),
(133451, 9505, 'Batalha do Churrasco S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z5H0AFYkea80S5QFo6HQ3q5hPs.jpg'),
(133452, 9506, 'Casamento as Cegas Suecia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A7cw0zIkqqeUUpR63bstOEDJv5d.jpg'),
(133453, 9506, 'Casamento as Cegas Suecia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e9G85xZxs0L3hCPxmq2wQjL4YNs.jpg'),
(133454, 9506, 'Casamento as Cegas Suecia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vcuiL9khiA6v5WC805GQN7irnOd.jpg'),
(133455, 9506, 'Casamento as Cegas Suecia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/siRTXFBGOtwLHeTiRWBPHn51Huq.jpg'),
(133456, 9506, 'Casamento as Cegas Suecia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uCEyz2dz6vZoZIpjwkjaBGcMA49.jpg'),
(133457, 9506, 'Casamento as Cegas Suecia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uCEyz2dz6vZoZIpjwkjaBGcMA49.jpg'),
(133458, 9506, 'Casamento as Cegas Suecia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uCEyz2dz6vZoZIpjwkjaBGcMA49.jpg'),
(133459, 9506, 'Casamento as Cegas Suecia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uCEyz2dz6vZoZIpjwkjaBGcMA49.jpg'),
(133460, 9506, 'Casamento as Cegas Suecia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/296417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uCEyz2dz6vZoZIpjwkjaBGcMA49.jpg'),
(133461, 9506, 'Casamento as Cegas Suecia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/296418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uCEyz2dz6vZoZIpjwkjaBGcMA49.jpg'),
(133462, 9507, 'Casamento as Cegas Suecia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/760966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uCEyz2dz6vZoZIpjwkjaBGcMA49.jpg'),
(133463, 9507, 'Casamento as Cegas Suecia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/760967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uCEyz2dz6vZoZIpjwkjaBGcMA49.jpg'),
(133464, 9507, 'Casamento as Cegas Suecia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/760968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uCEyz2dz6vZoZIpjwkjaBGcMA49.jpg'),
(133465, 9507, 'Casamento as Cegas Suecia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/760969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uCEyz2dz6vZoZIpjwkjaBGcMA49.jpg'),
(133466, 9507, 'Casamento as Cegas Suecia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/760970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uCEyz2dz6vZoZIpjwkjaBGcMA49.jpg'),
(133467, 9507, 'Casamento as Cegas Suecia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/760971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uCEyz2dz6vZoZIpjwkjaBGcMA49.jpg'),
(133468, 9507, 'Casamento as Cegas Suecia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/760972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uCEyz2dz6vZoZIpjwkjaBGcMA49.jpg'),
(133469, 9507, 'Casamento as Cegas Suecia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/760973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uCEyz2dz6vZoZIpjwkjaBGcMA49.jpg'),
(133470, 9507, 'Casamento as Cegas Suecia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/760974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uCEyz2dz6vZoZIpjwkjaBGcMA49.jpg'),
(133471, 9507, 'Casamento as Cegas Suecia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/768494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uCEyz2dz6vZoZIpjwkjaBGcMA49.jpg'),
(133472, 9508, 'Crimes que Abalaram o Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmzZgWd6hUu5VzvPSrlkJii1HG6.jpg'),
(133473, 9508, 'Crimes que Abalaram o Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umkIyMu4Z6g7kxFkMm1ZmvfZRkN.jpg'),
(133474, 9508, 'Crimes que Abalaram o Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1sBafv0BcIJksczb3XVZ8OgxqjB.jpg'),
(133475, 9508, 'Crimes que Abalaram o Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umkIyMu4Z6g7kxFkMm1ZmvfZRkN.jpg'),
(133476, 9508, 'Crimes que Abalaram o Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhyyDOHRw9UG3p1MpcH1icppjlO.jpg'),
(133477, 9508, 'Crimes que Abalaram o Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OJPqkq7nEOnnmQPe0e9jwPz5un.jpg'),
(133478, 9508, 'Crimes que Abalaram o Mundo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umkIyMu4Z6g7kxFkMm1ZmvfZRkN.jpg'),
(133479, 9508, 'Crimes que Abalaram o Mundo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umkIyMu4Z6g7kxFkMm1ZmvfZRkN.jpg'),
(133480, 9509, 'Delusional Monthly Magazine [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zYN81uJfI8eDNDcaDvs7gn5wM9t.jpg'),
(133481, 9509, 'Delusional Monthly Magazine [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Ei5yD3veVdp2UXylL1xgZvjKR4.jpg'),
(133482, 9509, 'Delusional Monthly Magazine [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Ei5yD3veVdp2UXylL1xgZvjKR4.jpg'),
(133483, 9509, 'Delusional Monthly Magazine [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Ei5yD3veVdp2UXylL1xgZvjKR4.jpg'),
(133484, 9509, 'Delusional Monthly Magazine [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Ei5yD3veVdp2UXylL1xgZvjKR4.jpg'),
(133485, 9509, 'Delusional Monthly Magazine [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Ei5yD3veVdp2UXylL1xgZvjKR4.jpg'),
(133486, 9509, 'Delusional Monthly Magazine [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Ei5yD3veVdp2UXylL1xgZvjKR4.jpg'),
(133487, 9509, 'Delusional Monthly Magazine [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Ei5yD3veVdp2UXylL1xgZvjKR4.jpg'),
(133488, 9509, 'Delusional Monthly Magazine [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/306215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Ei5yD3veVdp2UXylL1xgZvjKR4.jpg'),
(133489, 9509, 'Delusional Monthly Magazine [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/306216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Ei5yD3veVdp2UXylL1xgZvjKR4.jpg'),
(133490, 9509, 'Delusional Monthly Magazine [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/313330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Ei5yD3veVdp2UXylL1xgZvjKR4.jpg'),
(133491, 9509, 'Delusional Monthly Magazine [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/313331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Ei5yD3veVdp2UXylL1xgZvjKR4.jpg'),
(133492, 9510, 'Doctor Elise The Royal Lady with the Lamp [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sOZ5ES6YDIX01BxEJrHuTNsvbaQ.jpg'),
(133493, 9510, 'Doctor Elise The Royal Lady with the Lamp [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WfU7lHVTS5kEPTZrglfChlkOBs.jpg'),
(133494, 9510, 'Doctor Elise The Royal Lady with the Lamp [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WfU7lHVTS5kEPTZrglfChlkOBs.jpg'),
(133495, 9510, 'Doctor Elise The Royal Lady with the Lamp [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WfU7lHVTS5kEPTZrglfChlkOBs.jpg'),
(133496, 9510, 'Doctor Elise The Royal Lady with the Lamp [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WfU7lHVTS5kEPTZrglfChlkOBs.jpg'),
(133497, 9510, 'Doctor Elise The Royal Lady with the Lamp [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WfU7lHVTS5kEPTZrglfChlkOBs.jpg'),
(133498, 9510, 'Doctor Elise The Royal Lady with the Lamp [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/288281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WfU7lHVTS5kEPTZrglfChlkOBs.jpg'),
(133499, 9510, 'Doctor Elise The Royal Lady with the Lamp [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/288282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WfU7lHVTS5kEPTZrglfChlkOBs.jpg'),
(133500, 9510, 'Doctor Elise The Royal Lady with the Lamp [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/296831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WfU7lHVTS5kEPTZrglfChlkOBs.jpg'),
(133501, 9510, 'Doctor Elise The Royal Lady with the Lamp [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/300214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WfU7lHVTS5kEPTZrglfChlkOBs.jpg'),
(133502, 9510, 'Doctor Elise The Royal Lady with the Lamp [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/305277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WfU7lHVTS5kEPTZrglfChlkOBs.jpg'),
(133503, 9510, 'Doctor Elise The Royal Lady with the Lamp [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/313319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WfU7lHVTS5kEPTZrglfChlkOBs.jpg'),
(133504, 9511, 'Fluffy Paradise [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wVGSejuJ1GYpIxXTAeAqdYL4Qmx.jpg'),
(133505, 9511, 'Fluffy Paradise [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4OxJy4WUlSRfGw1AFTdsPc4YwPO.jpg'),
(133506, 9511, 'Fluffy Paradise [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tDvb4SRltQLs1hkKe5WYQmpi6gJ.jpg'),
(133507, 9511, 'Fluffy Paradise [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tDvb4SRltQLs1hkKe5WYQmpi6gJ.jpg'),
(133508, 9511, 'Fluffy Paradise [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tDvb4SRltQLs1hkKe5WYQmpi6gJ.jpg'),
(133509, 9511, 'Fluffy Paradise [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/272938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tDvb4SRltQLs1hkKe5WYQmpi6gJ.jpg'),
(133510, 9511, 'Fluffy Paradise [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/272939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tDvb4SRltQLs1hkKe5WYQmpi6gJ.jpg'),
(133511, 9511, 'Fluffy Paradise [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/297916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tDvb4SRltQLs1hkKe5WYQmpi6gJ.jpg'),
(133512, 9511, 'Fluffy Paradise [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/297917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tDvb4SRltQLs1hkKe5WYQmpi6gJ.jpg'),
(133513, 9511, 'Fluffy Paradise [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/297918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tDvb4SRltQLs1hkKe5WYQmpi6gJ.jpg'),
(133514, 9511, 'Fluffy Paradise [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/297919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tDvb4SRltQLs1hkKe5WYQmpi6gJ.jpg'),
(133515, 9511, 'Fluffy Paradise [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/304679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tDvb4SRltQLs1hkKe5WYQmpi6gJ.jpg'),
(133516, 9512, 'Gigi e a Fonte da Juventude [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/veJGtyJRHxwZoJu2ZnNaYoc39g8.jpg'),
(133517, 9512, 'Gigi e a Fonte da Juventude [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/10Aj8ShsciSkn2qbFgavs7beFLh.jpg'),
(133518, 9512, 'Gigi e a Fonte da Juventude [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yzTJ8X3hzQsQ4eFikTNWnNPja0C.jpg'),
(133519, 9512, 'Gigi e a Fonte da Juventude [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7DLl4lvD332zqGsxzuOqWUE4OGt.jpg'),
(133520, 9512, 'Gigi e a Fonte da Juventude [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sAI1lqhvT1e9I594vPyS1nFJaeY.jpg'),
(133521, 9512, 'Gigi e a Fonte da Juventude [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jq8QA6PRuofWSO4Os7U4AydB247.jpg'),
(133522, 9512, 'Gigi e a Fonte da Juventude [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ag0XaysmS5eRhi8U4PQzu5PmEpn.jpg'),
(133523, 9512, 'Gigi e a Fonte da Juventude [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g3tkRKzkYCiBI2Z3yHbklLgb40x.jpg'),
(133524, 9512, 'Gigi e a Fonte da Juventude [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qpTEY8bsFeoN9hkJPjavTd6orjC.jpg'),
(133525, 9512, 'Gigi e a Fonte da Juventude [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWBHDmMYkDqe6BxxZNeRw5g4Za1.jpg'),
(133526, 9512, 'Gigi e a Fonte da Juventude [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/258889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hC8wJcbALeIUSza2uxKbCyn9qdn.jpg'),
(133527, 9512, 'Gigi e a Fonte da Juventude [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/258890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5X4co14DjYN9wfUBhYmiZcqvvDf.jpg'),
(133528, 9512, 'Gigi e a Fonte da Juventude [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/258891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ThUVmdG0jdaqnFIyZUCD6cE7hK.jpg'),
(133529, 9512, 'Gigi e a Fonte da Juventude [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/258892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zsR1XciTEbf70GcRZljcce6BiyE.jpg'),
(133530, 9512, 'Gigi e a Fonte da Juventude [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/258893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gdzLUcNkJjHhCBptdJEnc491cPS.jpg'),
(133531, 9513, 'HIGH CARD [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oClXjpylSGaWSJ9B5D6dl4U94d1.jpg'),
(133532, 9513, 'HIGH CARD [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6omk95WMsNqxlcR3PRXifD8kIro.jpg'),
(133533, 9513, 'HIGH CARD [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gNcF1KH5349Dj5CFBmx3UqL2A7M.jpg'),
(133534, 9513, 'HIGH CARD [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ik78LtwQnqpSlt40kwd7LBZq0q.jpg'),
(133535, 9513, 'HIGH CARD [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mJt3UKKCAG45kOJLGzr7b9zCT1v.jpg'),
(133536, 9513, 'HIGH CARD [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odrJbm1LWgEYwIUe3rAnpOwx2eA.jpg'),
(133537, 9513, 'HIGH CARD [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/88N7TgUka4fn7ql8UYokxetY4dp.jpg'),
(133538, 9513, 'HIGH CARD [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/18Xw8GhxWA3vMJdtZaFgsM7DndO.jpg'),
(133539, 9513, 'HIGH CARD [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nlbWaKgcGarX2gITAFC4KVOq060.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(133540, 9513, 'HIGH CARD [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eLxoDG4CH5etGiTeBmkmW3VCmEn.jpg'),
(133541, 9513, 'HIGH CARD [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cBMTi3oG9xxmTA15WI0eid0xhwm.jpg'),
(133542, 9513, 'HIGH CARD [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4b9eho2Fpb3JxpSP4Is4P6gE9x0.jpg'),
(133543, 9514, 'HIGH CARD [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aH6IlfOyY7yuM350BtQsRszh7H4.jpg'),
(133544, 9514, 'HIGH CARD [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133545, 9514, 'HIGH CARD [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133546, 9514, 'HIGH CARD [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133547, 9514, 'HIGH CARD [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/272898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133548, 9514, 'HIGH CARD [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/272899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133549, 9514, 'HIGH CARD [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133550, 9514, 'HIGH CARD [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/288702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133551, 9514, 'HIGH CARD [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/290051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133552, 9514, 'HIGH CARD [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/299197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133553, 9514, 'HIGH CARD [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/304657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133554, 9514, 'HIGH CARD [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/308845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133555, 9514, 'HIGH CARD [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/500148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133556, 9514, 'HIGH CARD [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/500149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133557, 9514, 'HIGH CARD [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/500150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133558, 9514, 'HIGH CARD [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/500151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133559, 9514, 'HIGH CARD [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/500152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133560, 9514, 'HIGH CARD [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/500153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133561, 9514, 'HIGH CARD [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/500154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133562, 9514, 'HIGH CARD [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/500155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133563, 9514, 'HIGH CARD [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/500156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133564, 9514, 'HIGH CARD [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/500157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133565, 9514, 'HIGH CARD [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/500158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133566, 9514, 'HIGH CARD [L] S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/500159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133567, 9514, 'HIGH CARD [L] S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/500160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uhXTMvLPKnhNLpLDSktrs3S6mVb.jpg'),
(133568, 9515, 'Masterchef EUA S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/270336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mop4J7SpbBkfDiqMiWtO46TQQm6.jpg'),
(133569, 9515, 'Masterchef EUA S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/270337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4c6W9Piqa1o1hZJuLNOO8O4GnR6.jpg'),
(133570, 9515, 'Masterchef EUA S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/270338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133571, 9515, 'Masterchef EUA S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/270339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133572, 9515, 'Masterchef EUA S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/270340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133573, 9515, 'Masterchef EUA S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/270341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133574, 9515, 'Masterchef EUA S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/270342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133575, 9515, 'Masterchef EUA S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/270343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133576, 9515, 'Masterchef EUA S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/271049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133577, 9515, 'Masterchef EUA S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/271050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133578, 9515, 'Masterchef EUA S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/276388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133579, 9515, 'Masterchef EUA S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/276389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133580, 9515, 'Masterchef EUA S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/280759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133581, 9515, 'Masterchef EUA S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/280760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133582, 9515, 'Masterchef EUA S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/287049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133583, 9515, 'Masterchef EUA S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/287050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133584, 9515, 'Masterchef EUA S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/295502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133585, 9515, 'Masterchef EUA S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/295503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133586, 9515, 'Masterchef EUA S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/302530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133587, 9515, 'Masterchef EUA S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/302531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133588, 9516, 'Masterchef EUA S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/765691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133589, 9516, 'Masterchef EUA S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/765692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133590, 9516, 'Masterchef EUA S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/765693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133591, 9516, 'Masterchef EUA S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/765694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133592, 9516, 'Masterchef EUA S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/765695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133593, 9516, 'Masterchef EUA S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/765696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133594, 9516, 'Masterchef EUA S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/765697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133595, 9516, 'Masterchef EUA S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/765698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133596, 9516, 'Masterchef EUA S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/765699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133597, 9516, 'Masterchef EUA S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/765700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133598, 9516, 'Masterchef EUA S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/765701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133599, 9516, 'Masterchef EUA S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/765702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133600, 9516, 'Masterchef EUA S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/765703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133601, 9516, 'Masterchef EUA S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/765704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133602, 9516, 'Masterchef EUA S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/765705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133603, 9516, 'Masterchef EUA S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/765706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133604, 9516, 'Masterchef EUA S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/765707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133605, 9516, 'Masterchef EUA S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/765708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133606, 9516, 'Masterchef EUA S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/765709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tyqJFv8DZ7TzqMG28ZIKVdigQyQ.jpg'),
(133607, 9517, 'Metallic Rouge S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/270329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tTLMvQa2TorY3Gm6U3Unxw0vrqn.jpg'),
(133608, 9517, 'Metallic Rouge S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/270330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oLMLxZBmIFE6tWg5s8UwuYOWTVI.jpg'),
(133609, 9517, 'Metallic Rouge S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/270331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oLMLxZBmIFE6tWg5s8UwuYOWTVI.jpg'),
(133610, 9517, 'Metallic Rouge S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/270332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oLMLxZBmIFE6tWg5s8UwuYOWTVI.jpg'),
(133611, 9517, 'Metallic Rouge S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/271036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oLMLxZBmIFE6tWg5s8UwuYOWTVI.jpg'),
(133612, 9517, 'Metallic Rouge S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/272778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oLMLxZBmIFE6tWg5s8UwuYOWTVI.jpg'),
(133613, 9517, 'Metallic Rouge S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oLMLxZBmIFE6tWg5s8UwuYOWTVI.jpg'),
(133614, 9517, 'Metallic Rouge S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/288229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oLMLxZBmIFE6tWg5s8UwuYOWTVI.jpg'),
(133615, 9517, 'Metallic Rouge S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/296739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oLMLxZBmIFE6tWg5s8UwuYOWTVI.jpg'),
(133616, 9517, 'Metallic Rouge S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/299871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oLMLxZBmIFE6tWg5s8UwuYOWTVI.jpg'),
(133617, 9517, 'Metallic Rouge S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/317554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oLMLxZBmIFE6tWg5s8UwuYOWTVI.jpg'),
(133618, 9517, 'Metallic Rouge S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/319462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oLMLxZBmIFE6tWg5s8UwuYOWTVI.jpg'),
(133619, 9517, 'Metallic Rouge S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/596623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oLMLxZBmIFE6tWg5s8UwuYOWTVI.jpg'),
(133620, 9518, 'Mr Villains Day Off [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vB6DCj59E4Qu48zJ2GI0BtHtTya.jpg'),
(133621, 9518, 'Mr Villains Day Off [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/thKhPuHjsd6DEC4eiDnlIU0Tt22.jpg'),
(133622, 9518, 'Mr Villains Day Off [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/thKhPuHjsd6DEC4eiDnlIU0Tt22.jpg'),
(133623, 9518, 'Mr Villains Day Off [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/thKhPuHjsd6DEC4eiDnlIU0Tt22.jpg'),
(133624, 9518, 'Mr Villains Day Off [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/272772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/thKhPuHjsd6DEC4eiDnlIU0Tt22.jpg'),
(133625, 9518, 'Mr Villains Day Off [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/276355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/thKhPuHjsd6DEC4eiDnlIU0Tt22.jpg'),
(133626, 9518, 'Mr Villains Day Off [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/291982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/thKhPuHjsd6DEC4eiDnlIU0Tt22.jpg'),
(133627, 9518, 'Mr Villains Day Off [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/291983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/thKhPuHjsd6DEC4eiDnlIU0Tt22.jpg'),
(133628, 9518, 'Mr Villains Day Off [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/302477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/thKhPuHjsd6DEC4eiDnlIU0Tt22.jpg'),
(133629, 9518, 'Mr Villains Day Off [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/302478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/thKhPuHjsd6DEC4eiDnlIU0Tt22.jpg'),
(133630, 9518, 'Mr Villains Day Off [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/308551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/thKhPuHjsd6DEC4eiDnlIU0Tt22.jpg'),
(133631, 9518, 'Mr Villains Day Off [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/313143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/thKhPuHjsd6DEC4eiDnlIU0Tt22.jpg'),
(133632, 9519, 'Receita do Caos [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rD52bMsbvH7nQ0QWFFU7V3R6OCR.jpg'),
(133633, 9519, 'Receita do Caos [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7mgHL0AYOmlADjqH6IYJIuuh3Xi.jpg'),
(133634, 9519, 'Receita do Caos [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b2xjxt1vordXJwXvsseI3lwJznx.jpg'),
(133635, 9519, 'Receita do Caos [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTl0e9crZzzwyGv57n7xkvw6yE9.jpg'),
(133636, 9519, 'Receita do Caos [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r1DuTgbQEyWkwdZVmtF531P2bbV.jpg'),
(133637, 9519, 'Receita do Caos [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8yXpijXLSfSYOaN1F3f8pdARtkL.jpg'),
(133638, 9519, 'Receita do Caos [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVsr0XCUAdDOeYbenHEzMc7qRhW.jpg'),
(133639, 9519, 'Receita do Caos [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ihmaTSCM3lqR7OMQkugQMfs4xZI.jpg'),
(133640, 9520, 'Sasaki and Peeps [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wieOzsGCLDaxZLJ3sIx1uLsmjj9.jpg'),
(133641, 9520, 'Sasaki and Peeps [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m3D7giT0fyJJ5ssjOEhYgUXN7Sg.jpg'),
(133642, 9520, 'Sasaki and Peeps [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m3D7giT0fyJJ5ssjOEhYgUXN7Sg.jpg'),
(133643, 9520, 'Sasaki and Peeps [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m3D7giT0fyJJ5ssjOEhYgUXN7Sg.jpg'),
(133644, 9520, 'Sasaki and Peeps [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/272624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m3D7giT0fyJJ5ssjOEhYgUXN7Sg.jpg'),
(133645, 9520, 'Sasaki and Peeps [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/272625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m3D7giT0fyJJ5ssjOEhYgUXN7Sg.jpg'),
(133646, 9520, 'Sasaki and Peeps [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/275090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m3D7giT0fyJJ5ssjOEhYgUXN7Sg.jpg'),
(133647, 9520, 'Sasaki and Peeps [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/279478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m3D7giT0fyJJ5ssjOEhYgUXN7Sg.jpg'),
(133648, 9520, 'Sasaki and Peeps [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/285769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m3D7giT0fyJJ5ssjOEhYgUXN7Sg.jpg'),
(133649, 9520, 'Sasaki and Peeps [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/295199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m3D7giT0fyJJ5ssjOEhYgUXN7Sg.jpg'),
(133650, 9520, 'Sasaki and Peeps [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/301043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m3D7giT0fyJJ5ssjOEhYgUXN7Sg.jpg'),
(133651, 9520, 'Sasaki and Peeps [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/305858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m3D7giT0fyJJ5ssjOEhYgUXN7Sg.jpg'),
(133652, 9521, 'Sengoku Youko [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8mCJqfcD0hABpZu6DJB5I5yv5fN.jpg'),
(133653, 9521, 'Sengoku Youko [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133654, 9521, 'Sengoku Youko [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133655, 9521, 'Sengoku Youko [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133656, 9521, 'Sengoku Youko [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/272618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133657, 9521, 'Sengoku Youko [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/272619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133658, 9521, 'Sengoku Youko [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133659, 9521, 'Sengoku Youko [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/288221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133660, 9521, 'Sengoku Youko [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/296703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133661, 9521, 'Sengoku Youko [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/299810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133662, 9521, 'Sengoku Youko [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/304033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133663, 9521, 'Sengoku Youko [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/317238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133664, 9521, 'Sengoku Youko [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/319372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133665, 9521, 'Sengoku Youko [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/414372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133666, 9521, 'Sengoku Youko [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/414373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133667, 9521, 'Sengoku Youko [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/420743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133668, 9521, 'Sengoku Youko [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/426395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133669, 9521, 'Sengoku Youko [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/428668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133670, 9521, 'Sengoku Youko [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/438784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133671, 9521, 'Sengoku Youko [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/440838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133672, 9521, 'Sengoku Youko [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/450033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133673, 9521, 'Sengoku Youko [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/451980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133674, 9521, 'Sengoku Youko [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/458991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133675, 9521, 'Sengoku Youko [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/481067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133676, 9521, 'Sengoku Youko [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/481068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133677, 9521, 'Sengoku Youko [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/490211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133678, 9521, 'Sengoku Youko [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/497903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133679, 9521, 'Sengoku Youko [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/499640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133680, 9521, 'Sengoku Youko [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/504901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133681, 9521, 'Sengoku Youko [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/509285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133682, 9521, 'Sengoku Youko [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/515108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133683, 9521, 'Sengoku Youko [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/517201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133684, 9521, 'Sengoku Youko [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/521923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133685, 9521, 'Sengoku Youko [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/638985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133686, 9521, 'Sengoku Youko [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/643658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oBEAvOas18mlFbafLkh0ullEDtv.jpg'),
(133687, 9522, 'Super Onze Ares No Tenbin S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t9g7qTt9ONECoXCWGLdau6Zyedw.jpg'),
(133688, 9522, 'Super Onze Ares No Tenbin S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oYoOsIuTv3NPQ92cvsLRjEPslTR.jpg'),
(133689, 9522, 'Super Onze Ares No Tenbin S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3FiOONkMqnOkdRnbDDLPkf44Uzk.jpg'),
(133690, 9522, 'Super Onze Ares No Tenbin S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5v2mmQMmO2e1ukbN4cDq3MU15HJ.jpg'),
(133691, 9522, 'Super Onze Ares No Tenbin S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vcKTgDNeJx6sjBgjpcipreQ8S2m.jpg'),
(133692, 9522, 'Super Onze Ares No Tenbin S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gA0pXx1QZ1ow4QfCschoWO76ppy.jpg'),
(133693, 9522, 'Super Onze Ares No Tenbin S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5LTw7JSLFLybrQszPuDUST38gDI.jpg'),
(133694, 9522, 'Super Onze Ares No Tenbin S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/78cclE096QBVDfTj4QLPwCxDqwc.jpg'),
(133695, 9522, 'Super Onze Ares No Tenbin S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ad73YbqRKtOl0nRR38UUMbVxxN9.jpg'),
(133696, 9522, 'Super Onze Ares No Tenbin S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ad73YbqRKtOl0nRR38UUMbVxxN9.jpg'),
(133697, 9522, 'Super Onze Ares No Tenbin S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/258855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bYycGW0zsRZ557T2ESYdnQjNcgt.jpg'),
(133698, 9522, 'Super Onze Ares No Tenbin S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/258856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fefKvkJhzpcc6KgSIMo0mf8qoQq.jpg'),
(133699, 9522, 'Super Onze Ares No Tenbin S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/258857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hWnZ3KC8SczhqJyWuIDYOs9ed61.jpg'),
(133700, 9522, 'Super Onze Ares No Tenbin S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/258858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/86qM23sDrXCH5oPhaodVDlaEzvp.jpg'),
(133701, 9522, 'Super Onze Ares No Tenbin S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/258859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gsbIF9hIgbM6z6bNhoZIkWgr6ds.jpg'),
(133702, 9522, 'Super Onze Ares No Tenbin S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/258860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rXmIcXe8PPIaa0bpgj3K9KbmiUP.jpg'),
(133703, 9522, 'Super Onze Ares No Tenbin S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/258861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJDGkrxVkGRNKGUkwbD7pEbjHY7.jpg'),
(133704, 9522, 'Super Onze Ares No Tenbin S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/258862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ev62ld8drzYArczgyeda3CzzEMr.jpg'),
(133705, 9522, 'Super Onze Ares No Tenbin S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/258863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6jDk4wSkNQrZHvtPnStAQ5mgkRW.jpg'),
(133706, 9522, 'Super Onze Ares No Tenbin S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/258864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hYcrBgE0TjnGeIkbvTNLmf2ZUrC.jpg'),
(133707, 9522, 'Super Onze Ares No Tenbin S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/258865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tDMlOAIxIGwE9JP5ckylJtj16NS.jpg'),
(133708, 9522, 'Super Onze Ares No Tenbin S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/258866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aeZYxnyOimYe351SxVgHvdvlJ27.jpg'),
(133709, 9522, 'Super Onze Ares No Tenbin S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/258867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ySH80v7vAsrlIM6ZWCzcL8jgSHY.jpg'),
(133710, 9522, 'Super Onze Ares No Tenbin S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/258868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mB0TFeH8bkUo85mDtPb84cEc5FG.jpg'),
(133711, 9522, 'Super Onze Ares No Tenbin S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/258869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lkBJKghM2qSUCkUEuCfF18xIr4E.jpg'),
(133712, 9522, 'Super Onze Ares No Tenbin S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/258870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uH1ntaB0qOZfOt8fAlhxGi6Y39c.jpg'),
(133713, 9523, 'The Wrong Way to Use Healing Magic [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tbJPb2oQIw7gFozF2BKdPyXppKD.jpg'),
(133714, 9523, 'The Wrong Way to Use Healing Magic [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/277413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmnScbX505dKwpRGKoGhCsVBUw.jpg'),
(133715, 9523, 'The Wrong Way to Use Healing Magic [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/277414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmnScbX505dKwpRGKoGhCsVBUw.jpg'),
(133716, 9523, 'The Wrong Way to Use Healing Magic [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/277415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmnScbX505dKwpRGKoGhCsVBUw.jpg'),
(133717, 9523, 'The Wrong Way to Use Healing Magic [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/277416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmnScbX505dKwpRGKoGhCsVBUw.jpg'),
(133718, 9523, 'The Wrong Way to Use Healing Magic [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/277417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmnScbX505dKwpRGKoGhCsVBUw.jpg'),
(133719, 9523, 'The Wrong Way to Use Healing Magic [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/277418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmnScbX505dKwpRGKoGhCsVBUw.jpg'),
(133720, 9523, 'The Wrong Way to Use Healing Magic [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/279382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmnScbX505dKwpRGKoGhCsVBUw.jpg'),
(133721, 9523, 'The Wrong Way to Use Healing Magic [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/285670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmnScbX505dKwpRGKoGhCsVBUw.jpg'),
(133722, 9523, 'The Wrong Way to Use Healing Magic [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/295150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmnScbX505dKwpRGKoGhCsVBUw.jpg'),
(133723, 9523, 'The Wrong Way to Use Healing Magic [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/300941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmnScbX505dKwpRGKoGhCsVBUw.jpg'),
(133724, 9523, 'The Wrong Way to Use Healing Magic [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/305737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmnScbX505dKwpRGKoGhCsVBUw.jpg'),
(133725, 9523, 'The Wrong Way to Use Healing Magic [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/316964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmnScbX505dKwpRGKoGhCsVBUw.jpg'),
(133726, 9524, '7th Time Loop The Villainess Enjoys a Carefree Life Married to Her Worst Enemy [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ubA97cIHMtbxOMs4l3H2OTJKvwW.jpg'),
(133727, 9524, '7th Time Loop The Villainess Enjoys a Carefree Life Married to Her Worst Enemy [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ttxQPgX6HJqUsXuC2HgnQRv7wZ.jpg'),
(133728, 9524, '7th Time Loop The Villainess Enjoys a Carefree Life Married to Her Worst Enemy [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ttxQPgX6HJqUsXuC2HgnQRv7wZ.jpg'),
(133729, 9524, '7th Time Loop The Villainess Enjoys a Carefree Life Married to Her Worst Enemy [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ttxQPgX6HJqUsXuC2HgnQRv7wZ.jpg'),
(133730, 9524, '7th Time Loop The Villainess Enjoys a Carefree Life Married to Her Worst Enemy [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ttxQPgX6HJqUsXuC2HgnQRv7wZ.jpg'),
(133731, 9524, '7th Time Loop The Villainess Enjoys a Carefree Life Married to Her Worst Enemy [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ttxQPgX6HJqUsXuC2HgnQRv7wZ.jpg'),
(133732, 9524, '7th Time Loop The Villainess Enjoys a Carefree Life Married to Her Worst Enemy [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/277264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ttxQPgX6HJqUsXuC2HgnQRv7wZ.jpg'),
(133733, 9524, '7th Time Loop The Villainess Enjoys a Carefree Life Married to Her Worst Enemy [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/283182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ttxQPgX6HJqUsXuC2HgnQRv7wZ.jpg'),
(133734, 9524, '7th Time Loop The Villainess Enjoys a Carefree Life Married to Her Worst Enemy [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/285628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ttxQPgX6HJqUsXuC2HgnQRv7wZ.jpg'),
(133735, 9524, '7th Time Loop The Villainess Enjoys a Carefree Life Married to Her Worst Enemy [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/298793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ttxQPgX6HJqUsXuC2HgnQRv7wZ.jpg'),
(133736, 9524, '7th Time Loop The Villainess Enjoys a Carefree Life Married to Her Worst Enemy [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/300695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ttxQPgX6HJqUsXuC2HgnQRv7wZ.jpg'),
(133737, 9524, '7th Time Loop The Villainess Enjoys a Carefree Life Married to Her Worst Enemy [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/309428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ttxQPgX6HJqUsXuC2HgnQRv7wZ.jpg'),
(133738, 9525, 'A Cozinha de Fermat [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aziMbACsXwJx8NK8JmZdoGFSykw.jpg'),
(133739, 9525, 'A Cozinha de Fermat [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hjJYrWgJcBsMwIG6IVBfIUUjEtD.jpg'),
(133740, 9525, 'A Cozinha de Fermat [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/31JZ2uIMmEW4gOfUP96bttpkZwm.jpg'),
(133741, 9525, 'A Cozinha de Fermat [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6bvKNFEgDCPhIrxdhvcKKCAvX0D.jpg'),
(133742, 9525, 'A Cozinha de Fermat [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ksfH3TUEz0tMZeZGrKzLBPr5KSP.jpg'),
(133743, 9525, 'A Cozinha de Fermat [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/or9Z2uzW3RGi4pRGi8QaZDbUirE.jpg'),
(133744, 9525, 'A Cozinha de Fermat [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kIifNjMgon6P3ckVAXBnVoWjT0k.jpg'),
(133745, 9525, 'A Cozinha de Fermat [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hYirH1DdO78rDknA6uBfFsys1Gz.jpg'),
(133746, 9525, 'A Cozinha de Fermat [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mm4f22mOXmyvAMxPztTCFFZVaV4.jpg'),
(133747, 9525, 'A Cozinha de Fermat [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2FdimUoIMTHyF6555wyjA8xk9TB.jpg'),
(133748, 9526, 'A Etica do Silencio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6VLGyGVX1BYr7mrL1gECMFHAxL.jpg'),
(133749, 9526, 'A Etica do Silencio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6VLGyGVX1BYr7mrL1gECMFHAxL.jpg'),
(133750, 9526, 'A Etica do Silencio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6VLGyGVX1BYr7mrL1gECMFHAxL.jpg'),
(133751, 9526, 'A Etica do Silencio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6VLGyGVX1BYr7mrL1gECMFHAxL.jpg'),
(133752, 9526, 'A Etica do Silencio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y6VLGyGVX1BYr7mrL1gECMFHAxL.jpg'),
(133753, 9527, 'A Jornada Heroica do Principe Ivandoe S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3o2isf6sJVoMIQeAcyT9oJGRK2X.jpg'),
(133754, 9527, 'A Jornada Heroica do Principe Ivandoe S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sTpMWNyovqkQN93mKAWJafsnwZv.jpg'),
(133755, 9527, 'A Jornada Heroica do Principe Ivandoe S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fW8PplFnaQ172GfOE3g3hSAFsg0.jpg'),
(133756, 9527, 'A Jornada Heroica do Principe Ivandoe S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgY6lDCKtYxjpqsM5JVI726lMBy.jpg'),
(133757, 9527, 'A Jornada Heroica do Principe Ivandoe S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w6JPXrB4dWnM7YJSiFaeiD4VIID.jpg'),
(133758, 9527, 'A Jornada Heroica do Principe Ivandoe S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bAiLuisxXJiGCHc5YvrAR16rphS.jpg'),
(133759, 9527, 'A Jornada Heroica do Principe Ivandoe S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oxMbxE7QKsbrfXbhLIvxZTB3yL9.jpg'),
(133760, 9528, 'A Jornada Heroica do Principe Ivandoe S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133761, 9528, 'A Jornada Heroica do Principe Ivandoe S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133762, 9528, 'A Jornada Heroica do Principe Ivandoe S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133763, 9528, 'A Jornada Heroica do Principe Ivandoe S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133764, 9528, 'A Jornada Heroica do Principe Ivandoe S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/684838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133765, 9528, 'A Jornada Heroica do Principe Ivandoe S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/684839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133766, 9528, 'A Jornada Heroica do Principe Ivandoe S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/684840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133767, 9529, 'A Jornada Heroica do Principe Ivandoe S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/684841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133768, 9529, 'A Jornada Heroica do Principe Ivandoe S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/684842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133769, 9529, 'A Jornada Heroica do Principe Ivandoe S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/684843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133770, 9529, 'A Jornada Heroica do Principe Ivandoe S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/684844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133771, 9529, 'A Jornada Heroica do Principe Ivandoe S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/684845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133772, 9529, 'A Jornada Heroica do Principe Ivandoe S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/684846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133773, 9529, 'A Jornada Heroica do Principe Ivandoe S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/684847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133774, 9529, 'A Jornada Heroica do Principe Ivandoe S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/684848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133775, 9530, 'A Jornada Heroica do Principe Ivandoe S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/684849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133776, 9530, 'A Jornada Heroica do Principe Ivandoe S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/684850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133777, 9530, 'A Jornada Heroica do Principe Ivandoe S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/684851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133778, 9530, 'A Jornada Heroica do Principe Ivandoe S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/684852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133779, 9530, 'A Jornada Heroica do Principe Ivandoe S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/684853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133780, 9530, 'A Jornada Heroica do Principe Ivandoe S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/684854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133781, 9530, 'A Jornada Heroica do Principe Ivandoe S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/684855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133782, 9531, 'A Jornada Heroica do Principe Ivandoe S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/708096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133783, 9531, 'A Jornada Heroica do Principe Ivandoe S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/708097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133784, 9531, 'A Jornada Heroica do Principe Ivandoe S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/708098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133785, 9531, 'A Jornada Heroica do Principe Ivandoe S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/708099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133786, 9531, 'A Jornada Heroica do Principe Ivandoe S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/708100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133787, 9531, 'A Jornada Heroica do Principe Ivandoe S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/708101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133788, 9531, 'A Jornada Heroica do Principe Ivandoe S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/708102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg'),
(133789, 9531, 'A Jornada Heroica do Principe Ivandoe S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/708103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zOhdHLaTpRWI4RCFaX52P3IueIK.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(133790, 9532, 'A Sacerdotisa de Outubro [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqszJjKYrU5vP1Gi7wLItzXpz5U.jpg'),
(133791, 9532, 'A Sacerdotisa de Outubro [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qaC5b87QekTTVtsl6CxhesfucGV.jpg'),
(133792, 9532, 'A Sacerdotisa de Outubro [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1isCfEAJamNXljbOXNAycv9cVp0.jpg'),
(133793, 9532, 'A Sacerdotisa de Outubro [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/psfY3IVSNF2g20NRPftkGiU3Eti.jpg'),
(133794, 9532, 'A Sacerdotisa de Outubro [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1LMIdPZJIFZ265ioybzgclrzC0Q.jpg'),
(133795, 9532, 'A Sacerdotisa de Outubro [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9FPdbnbkeepVqz7nvpiDYp1tw5V.jpg'),
(133796, 9532, 'A Sacerdotisa de Outubro [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmVd16ihsheVFyhjTIRgEkkOPsf.jpg'),
(133797, 9532, 'A Sacerdotisa de Outubro [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eFvTOfmjOqHaAPUnUx0fOUmOeX1.jpg'),
(133798, 9532, 'A Sacerdotisa de Outubro [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/noa9GeZbLLd4qdgieABTW08BFfU.jpg'),
(133799, 9532, 'A Sacerdotisa de Outubro [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/al3ebBZkwrHIFQJlXfllLIBDJ66.jpg'),
(133800, 9532, 'A Sacerdotisa de Outubro [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/258827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c4qB17YtJ4zCTFUiVOdMe5Ix7KH.jpg'),
(133801, 9532, 'A Sacerdotisa de Outubro [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/258828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rqA2LuZoTr39MwtOViPOtEDWWJq.jpg'),
(133802, 7969, 'Abominavel e a Cidade Escondida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6nbWxjFYUtgcHTONJxOdifREupk.jpg'),
(133803, 7969, 'Abominavel e a Cidade Escondida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jSflAscdYKCjJgKtNxvk1vHNJjL.jpg'),
(133804, 7969, 'Abominavel e a Cidade Escondida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ltqf9fDRdSg9Cc6D3LPDXlupuiC.jpg'),
(133805, 7969, 'Abominavel e a Cidade Escondida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jRHjPptIAFiMNUwV7INzGtmxqWl.jpg'),
(133806, 7969, 'Abominavel e a Cidade Escondida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9vJ8azPod6xLWrVL5W3ahJa8Lr0.jpg'),
(133807, 7969, 'Abominavel e a Cidade Escondida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5upkU8zdmBlbg22ElEq6eo4Vtq6.jpg'),
(133808, 7969, 'Abominavel e a Cidade Escondida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ldChuh8KerkNqLhDgcgPn2dmaSb.jpg'),
(133809, 7969, 'Abominavel e a Cidade Escondida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJ6qMgWAVgdNh0ye3I8airKXPfq.jpg'),
(133810, 7969, 'Abominavel e a Cidade Escondida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1mxxEfhfHbRkd7c9S7ouB16fO1S.jpg'),
(133811, 7969, 'Abominavel e a Cidade Escondida S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8BgyL708WvrheSMHsm8RENP5pid.jpg'),
(133812, 9533, 'Abominavel e a Cidade Escondida S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7TnLlBxW9xJllAPBXZs9xxNXwz.jpg'),
(133813, 9533, 'Abominavel e a Cidade Escondida S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dd3FJK36aNZByYr9WjGI95rInIy.jpg'),
(133814, 9533, 'Abominavel e a Cidade Escondida S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7omgvqnEGS6yEs9x1MzpqHk0N6Q.jpg'),
(133815, 9533, 'Abominavel e a Cidade Escondida S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24EYgBdRYfhA1iOREVxUGHNnFpw.jpg'),
(133816, 9533, 'Abominavel e a Cidade Escondida S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eY4KWaXhgkIT7wShFaZhYgeVxIb.jpg'),
(133817, 9533, 'Abominavel e a Cidade Escondida S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/51VZmYiZSkZMXrU7NonXIrI9KTx.jpg'),
(133818, 9533, 'Abominavel e a Cidade Escondida S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pelgJap85OGSi9Tek3phuikS5gq.jpg'),
(133819, 9533, 'Abominavel e a Cidade Escondida S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vavilMwgp0exfPpgzGitGc04y0Z.jpg'),
(133820, 9533, 'Abominavel e a Cidade Escondida S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jqtQGKcrbV1zzkvBPfSyLkHA8tv.jpg'),
(133821, 9533, 'Abominavel e a Cidade Escondida S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCUSGyR2zdMWzEio82rt0kxouiE.jpg'),
(133822, 9534, 'Ars no Kyojuu [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k7ANTRUoHnTGLg6vwBgIaQ6oEZV.jpg'),
(133823, 9534, 'Ars no Kyojuu [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i9eegBLqUdgmr1MDp2oBQ6QlM57.jpg'),
(133824, 9534, 'Ars no Kyojuu [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7GYf4MEEL9nsROgwYPEY2Q9tL9e.jpg'),
(133825, 9534, 'Ars no Kyojuu [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkuG4LbjyKBPxgQCpcz9DBM156Y.jpg'),
(133826, 9534, 'Ars no Kyojuu [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bflkDNTaR3TUe9CiYJeMlNVaTlS.jpg'),
(133827, 9534, 'Ars no Kyojuu [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCeMXI70fFHsgC8BId1eGA4NyZL.jpg'),
(133828, 9534, 'Ars no Kyojuu [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wHX8Yld58avrzbG4MAfAdEk6d5Z.jpg'),
(133829, 9534, 'Ars no Kyojuu [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e6o7MEE4tXoXe1x5Mz0CyxKWqoP.jpg'),
(133830, 9534, 'Ars no Kyojuu [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aSkOWVnmn6djfeDk0VwCNMYUpN.jpg'),
(133831, 9534, 'Ars no Kyojuu [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNHtWvgT5IkNO2WTa4XunAMToyo.jpg'),
(133832, 9534, 'Ars no Kyojuu [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/258795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vK8758X4X6vcIcHz0rAiE043rG4.jpg'),
(133833, 9534, 'Ars no Kyojuu [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/258796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13pdXOrPOpl2yWia6VQUTTojRjr.jpg'),
(133834, 9535, 'Churrasqueiros do Texas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aR34P8M3VRwDE9Hfv4reqAUUrau.jpg'),
(133835, 9535, 'Churrasqueiros do Texas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aR34P8M3VRwDE9Hfv4reqAUUrau.jpg'),
(133836, 9535, 'Churrasqueiros do Texas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aR34P8M3VRwDE9Hfv4reqAUUrau.jpg'),
(133837, 9535, 'Churrasqueiros do Texas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aR34P8M3VRwDE9Hfv4reqAUUrau.jpg'),
(133838, 9535, 'Churrasqueiros do Texas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aR34P8M3VRwDE9Hfv4reqAUUrau.jpg'),
(133839, 9535, 'Churrasqueiros do Texas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aR34P8M3VRwDE9Hfv4reqAUUrau.jpg'),
(133840, 9535, 'Churrasqueiros do Texas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aR34P8M3VRwDE9Hfv4reqAUUrau.jpg'),
(133841, 9535, 'Churrasqueiros do Texas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aR34P8M3VRwDE9Hfv4reqAUUrau.jpg'),
(133842, 9536, 'DH Divisao de Homicidios S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wlfWpKXCiW1BkgfOUai8oxKPqEH.jpg'),
(133843, 9536, 'DH Divisao de Homicidios S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wlfWpKXCiW1BkgfOUai8oxKPqEH.jpg'),
(133844, 9536, 'DH Divisao de Homicidios S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wlfWpKXCiW1BkgfOUai8oxKPqEH.jpg'),
(133845, 9536, 'DH Divisao de Homicidios S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wlfWpKXCiW1BkgfOUai8oxKPqEH.jpg'),
(133846, 9536, 'DH Divisao de Homicidios S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wlfWpKXCiW1BkgfOUai8oxKPqEH.jpg'),
(133847, 9536, 'DH Divisao de Homicidios S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wlfWpKXCiW1BkgfOUai8oxKPqEH.jpg'),
(133848, 9536, 'DH Divisao de Homicidios S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wlfWpKXCiW1BkgfOUai8oxKPqEH.jpg'),
(133849, 9536, 'DH Divisao de Homicidios S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wlfWpKXCiW1BkgfOUai8oxKPqEH.jpg'),
(133850, 9537, 'DH Divisao de Homicidios S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/EFVTNp3M7F7PX44fDHSY5Sotlf.jpg'),
(133851, 9537, 'DH Divisao de Homicidios S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/EFVTNp3M7F7PX44fDHSY5Sotlf.jpg'),
(133852, 9537, 'DH Divisao de Homicidios S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/EFVTNp3M7F7PX44fDHSY5Sotlf.jpg'),
(133853, 9537, 'DH Divisao de Homicidios S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/EFVTNp3M7F7PX44fDHSY5Sotlf.jpg'),
(133854, 9537, 'DH Divisao de Homicidios S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/EFVTNp3M7F7PX44fDHSY5Sotlf.jpg'),
(133855, 9537, 'DH Divisao de Homicidios S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/EFVTNp3M7F7PX44fDHSY5Sotlf.jpg'),
(133856, 9537, 'DH Divisao de Homicidios S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/EFVTNp3M7F7PX44fDHSY5Sotlf.jpg'),
(133857, 9537, 'DH Divisao de Homicidios S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/EFVTNp3M7F7PX44fDHSY5Sotlf.jpg'),
(133858, 9538, 'DH Divisao de Homicidios S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oFbMlQSDKvxoR0tffJM0UAekSej.jpg'),
(133859, 9538, 'DH Divisao de Homicidios S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oFbMlQSDKvxoR0tffJM0UAekSej.jpg'),
(133860, 9538, 'DH Divisao de Homicidios S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oFbMlQSDKvxoR0tffJM0UAekSej.jpg'),
(133861, 9538, 'DH Divisao de Homicidios S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oFbMlQSDKvxoR0tffJM0UAekSej.jpg'),
(133862, 9538, 'DH Divisao de Homicidios S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oFbMlQSDKvxoR0tffJM0UAekSej.jpg'),
(133863, 9538, 'DH Divisao de Homicidios S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oFbMlQSDKvxoR0tffJM0UAekSej.jpg'),
(133864, 9538, 'DH Divisao de Homicidios S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oFbMlQSDKvxoR0tffJM0UAekSej.jpg'),
(133865, 9539, 'Extinto ou Nao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/O24K9twd0pfaBoBbVIbKyRJLhg.jpg'),
(133866, 9539, 'Extinto ou Nao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c33bWlw7BbwzQK02paLnZfgsHLI.jpg'),
(133867, 9539, 'Extinto ou Nao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Isx24BL8BkqNpHakC5DYdif2k0.jpg'),
(133868, 9539, 'Extinto ou Nao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oxEiCWvRHweYnGX8WA0XZyJL71B.jpg'),
(133869, 9539, 'Extinto ou Nao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zPnif2ENUxcAzpwnGRGRKVBDxXs.jpg'),
(133870, 9539, 'Extinto ou Nao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4E3SN8wiJY3bqLxlNq7wRu09PjL.jpg'),
(133871, 9539, 'Extinto ou Nao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wqdYyJQzKZfBx4ioz0A6DFezZEt.jpg'),
(133872, 9539, 'Extinto ou Nao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qIjnBby15iQ5Txl5fycn6FMnn0A.jpg'),
(133873, 9540, 'Hyakusho Kizoku Aristocracia Rural [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7BIeBKQti26ek567NqKisEXuEl.jpg'),
(133874, 9540, 'Hyakusho Kizoku Aristocracia Rural [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7sM8d4HXZJ40BAbjWxqrKymNnyP.jpg'),
(133875, 9540, 'Hyakusho Kizoku Aristocracia Rural [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fCWNL42WBBE8BOZYlyXDoxHhWKh.jpg'),
(133876, 9540, 'Hyakusho Kizoku Aristocracia Rural [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hHWRgG8wMZd1n8OYo2w44qSJiOZ.jpg'),
(133877, 9540, 'Hyakusho Kizoku Aristocracia Rural [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2JqHpseINrmqypxJq3eNFs4r4GQ.jpg'),
(133878, 9540, 'Hyakusho Kizoku Aristocracia Rural [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lKLbdEbFZFrBQqJ3p48nF88JDuX.jpg'),
(133879, 9540, 'Hyakusho Kizoku Aristocracia Rural [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yJgL3O0376Yjry30hcS0cLHtxeM.jpg'),
(133880, 9540, 'Hyakusho Kizoku Aristocracia Rural [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zUiR5XdQBu5QGVEtyAujzuWeGq9.jpg'),
(133881, 9540, 'Hyakusho Kizoku Aristocracia Rural [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kB37CC2ONBHI5MuL5Zt9THytpJ4.jpg'),
(133882, 9540, 'Hyakusho Kizoku Aristocracia Rural [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/icOgaibCroD16fk2DnAccMCQ0IS.jpg'),
(133883, 9540, 'Hyakusho Kizoku Aristocracia Rural [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/258744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zVB0ywcCOhqsZiLiQvLSDcQEWPH.jpg'),
(133884, 9540, 'Hyakusho Kizoku Aristocracia Rural [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/258745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hokTo4Jn3jp1TWcwPYI6NVTuGsh.jpg'),
(133885, 9541, 'Love Song for Illusion [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/39FGK6AiXiMQKMOIESTvId6RwDX.jpg'),
(133886, 9541, 'Love Song for Illusion [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7TWlkyk1w3KlXYiLLxykwrslOva.jpg'),
(133887, 9541, 'Love Song for Illusion [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oAU2hDPFHfGxwC6lZXSMnJP3RJ6.jpg'),
(133888, 9541, 'Love Song for Illusion [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3MjKnz8p0qf178v8kPGSnyOCl9k.jpg'),
(133889, 9541, 'Love Song for Illusion [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3MjKnz8p0qf178v8kPGSnyOCl9k.jpg'),
(133890, 9541, 'Love Song for Illusion [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3MjKnz8p0qf178v8kPGSnyOCl9k.jpg'),
(133891, 9541, 'Love Song for Illusion [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3MjKnz8p0qf178v8kPGSnyOCl9k.jpg'),
(133892, 9541, 'Love Song for Illusion [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3MjKnz8p0qf178v8kPGSnyOCl9k.jpg'),
(133893, 9541, 'Love Song for Illusion [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3MjKnz8p0qf178v8kPGSnyOCl9k.jpg'),
(133894, 9541, 'Love Song for Illusion [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/272805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3MjKnz8p0qf178v8kPGSnyOCl9k.jpg'),
(133895, 9541, 'Love Song for Illusion [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/272806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3MjKnz8p0qf178v8kPGSnyOCl9k.jpg'),
(133896, 9541, 'Love Song for Illusion [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/272807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3MjKnz8p0qf178v8kPGSnyOCl9k.jpg'),
(133897, 9541, 'Love Song for Illusion [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/274418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3MjKnz8p0qf178v8kPGSnyOCl9k.jpg'),
(133898, 9541, 'Love Song for Illusion [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/277688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3MjKnz8p0qf178v8kPGSnyOCl9k.jpg'),
(133899, 9541, 'Love Song for Illusion [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/288673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3MjKnz8p0qf178v8kPGSnyOCl9k.jpg'),
(133900, 9541, 'Love Song for Illusion [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/288674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3MjKnz8p0qf178v8kPGSnyOCl9k.jpg'),
(133901, 9542, 'Nathan For You [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/JWtOO0YpKJyqIVFKCffnNs27Pe.jpg'),
(133902, 9542, 'Nathan For You [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mNMVNPYel6whkB4WYDaNlDRWaNn.jpg'),
(133903, 9542, 'Nathan For You [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2OP3h0rfs9I9wE0lgmxe5A1cqHt.jpg'),
(133904, 9542, 'Nathan For You [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i4586AwJKiVKDzdbZjR6xAuLUL3.jpg'),
(133905, 9542, 'Nathan For You [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6c4bn76FqMIhhnSVhzku346tCyZ.jpg'),
(133906, 9542, 'Nathan For You [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wEbGaDTiMWJRSq1AnDljMRsiY8N.jpg'),
(133907, 9542, 'Nathan For You [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glI5V9icFFSDPsC0pqBavZ4us2u.jpg'),
(133908, 9542, 'Nathan For You [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AvS0P2S9FIJDQlrFi8Db7b8qvAB.jpg'),
(133909, 9543, 'Nathan For You [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/367328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133910, 9543, 'Nathan For You [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/367329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133911, 9543, 'Nathan For You [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/367330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133912, 9543, 'Nathan For You [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/367331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133913, 9543, 'Nathan For You [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/367332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133914, 9543, 'Nathan For You [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/367333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133915, 9543, 'Nathan For You [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/367334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133916, 9544, 'Nathan For You [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/367335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133917, 9544, 'Nathan For You [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/367336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133918, 9544, 'Nathan For You [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/367337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133919, 9544, 'Nathan For You [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/367338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133920, 9544, 'Nathan For You [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/367339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133921, 9544, 'Nathan For You [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/367340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133922, 9544, 'Nathan For You [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/367341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133923, 9545, 'Nathan For You [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/367342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133924, 9545, 'Nathan For You [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/367343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133925, 9545, 'Nathan For You [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/367344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133926, 9545, 'Nathan For You [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/367345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133927, 9545, 'Nathan For You [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/367346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133928, 9545, 'Nathan For You [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/367347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133929, 9545, 'Nathan For You [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/367348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133930, 9545, 'Nathan For You [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/367349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6tGXlz61c44onUg6EdRkbhjcaPA.jpg'),
(133931, 9546, 'Poker Face S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3B5vFXtreORyBjsxIzF9vpoUFeZ.jpg'),
(133932, 9546, 'Poker Face S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/46hEeYrDAP5XmavCEN05ag61Q0P.jpg'),
(133933, 9546, 'Poker Face S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pWEBGzwtNqhRYWNnIwV8XwI7qrO.jpg'),
(133934, 9546, 'Poker Face S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q1WRpFT1OGd2EXXA0RPa4laeQta.jpg'),
(133935, 9546, 'Poker Face S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/299137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Xm5dyMQC9whMJKnGdFugUAW73C.jpg'),
(133936, 9546, 'Poker Face S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/299138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Xm5dyMQC9whMJKnGdFugUAW73C.jpg'),
(133937, 9546, 'Poker Face S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/299139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Xm5dyMQC9whMJKnGdFugUAW73C.jpg'),
(133938, 9546, 'Poker Face S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/299140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Xm5dyMQC9whMJKnGdFugUAW73C.jpg'),
(133939, 9546, 'Poker Face S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/299141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Xm5dyMQC9whMJKnGdFugUAW73C.jpg'),
(133940, 9546, 'Poker Face S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/299142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Xm5dyMQC9whMJKnGdFugUAW73C.jpg'),
(133941, 9547, 'Poker Face S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/820446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Xm5dyMQC9whMJKnGdFugUAW73C.jpg'),
(133942, 9547, 'Poker Face S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/820447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Xm5dyMQC9whMJKnGdFugUAW73C.jpg'),
(133943, 9547, 'Poker Face S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/820448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Xm5dyMQC9whMJKnGdFugUAW73C.jpg'),
(133944, 9547, 'Poker Face S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/820449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Xm5dyMQC9whMJKnGdFugUAW73C.jpg'),
(133945, 9547, 'Poker Face S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/820450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Xm5dyMQC9whMJKnGdFugUAW73C.jpg'),
(133946, 9547, 'Poker Face S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/820451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Xm5dyMQC9whMJKnGdFugUAW73C.jpg'),
(133947, 9547, 'Poker Face S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/827133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Xm5dyMQC9whMJKnGdFugUAW73C.jpg'),
(133948, 9547, 'Poker Face S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/841360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Xm5dyMQC9whMJKnGdFugUAW73C.jpg'),
(133949, 9547, 'Poker Face S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/847261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Xm5dyMQC9whMJKnGdFugUAW73C.jpg'),
(133950, 9547, 'Poker Face S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/853208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Xm5dyMQC9whMJKnGdFugUAW73C.jpg'),
(133951, 9547, 'Poker Face S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/855715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Xm5dyMQC9whMJKnGdFugUAW73C.jpg'),
(133952, 9547, 'Poker Face S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/865027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Xm5dyMQC9whMJKnGdFugUAW73C.jpg'),
(133953, 9548, 'Samurai Warriors [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qSSxc8ic63b3MRXvvEsdeKcrXLg.jpg'),
(133954, 9548, 'Samurai Warriors [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9T0Jenla1yTuXieELRb0fHCKH2p.jpg'),
(133955, 9548, 'Samurai Warriors [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/258712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHg9NHWbwI4vdNnM0wljcZSjPf4.jpg'),
(133956, 9548, 'Samurai Warriors [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/258713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qQRplhIfD1JZKFgjq30WE4IPkM9.jpg'),
(133957, 9548, 'Samurai Warriors [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/258714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qj5pGRq7zqFZLARAg1UYOeOXCfJ.jpg'),
(133958, 9548, 'Samurai Warriors [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/258715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n9NnTCGKm4eBfrYPoswNcgUg0y4.jpg'),
(133959, 9548, 'Samurai Warriors [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/258716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hmuPBHEHRloJjWb3zNRGo00MT7m.jpg'),
(133960, 9548, 'Samurai Warriors [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/258717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9mBMIiNRAtIHE6lJzQxAI6Umwwn.jpg'),
(133961, 9548, 'Samurai Warriors [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/258718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/IOAIyqpA6emy6dEGp5e4N5po79.jpg'),
(133962, 9548, 'Samurai Warriors [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/258719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tXsvs6IPe4jyY74MyqTCbOzSxTL.jpg'),
(133963, 9548, 'Samurai Warriors [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/258720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tXXwOigKren2r3xoajf1U0SiN47.jpg'),
(133964, 9548, 'Samurai Warriors [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/258721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kydI5pSOaP4Sa8JCukFiSarh0w4.jpg'),
(133965, 9549, 'Snack Basue [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xMAEjnN9vc9svJIbPTBKUl0D4zz.jpg'),
(133966, 9549, 'Snack Basue [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ofcGZLM6vH8ISBB6T8OPkjlDmjy.jpg'),
(133967, 9549, 'Snack Basue [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ofcGZLM6vH8ISBB6T8OPkjlDmjy.jpg'),
(133968, 9549, 'Snack Basue [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ofcGZLM6vH8ISBB6T8OPkjlDmjy.jpg'),
(133969, 9549, 'Snack Basue [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/272575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ofcGZLM6vH8ISBB6T8OPkjlDmjy.jpg'),
(133970, 9549, 'Snack Basue [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/275049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ofcGZLM6vH8ISBB6T8OPkjlDmjy.jpg'),
(133971, 9549, 'Snack Basue [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ofcGZLM6vH8ISBB6T8OPkjlDmjy.jpg'),
(133972, 9549, 'Snack Basue [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/290572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ofcGZLM6vH8ISBB6T8OPkjlDmjy.jpg'),
(133973, 9549, 'Snack Basue [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/297104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ofcGZLM6vH8ISBB6T8OPkjlDmjy.jpg'),
(133974, 9549, 'Snack Basue [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/304002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ofcGZLM6vH8ISBB6T8OPkjlDmjy.jpg'),
(133975, 9549, 'Snack Basue [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/307185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ofcGZLM6vH8ISBB6T8OPkjlDmjy.jpg'),
(133976, 9549, 'Snack Basue [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/313564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ofcGZLM6vH8ISBB6T8OPkjlDmjy.jpg'),
(133977, 9549, 'Snack Basue [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/321144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ofcGZLM6vH8ISBB6T8OPkjlDmjy.jpg'),
(133978, 9550, 'Tales of Wedding Rings [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ljt5Z5BrcWQ7199EdRJYeXFIgEG.jpg'),
(133979, 9550, 'Tales of Wedding Rings [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/272511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(133980, 9550, 'Tales of Wedding Rings [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/272512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(133981, 9550, 'Tales of Wedding Rings [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/272513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(133982, 9550, 'Tales of Wedding Rings [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/272514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(133983, 9550, 'Tales of Wedding Rings [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/285710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(133984, 9550, 'Tales of Wedding Rings [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/598272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(133985, 9550, 'Tales of Wedding Rings [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/279426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(133986, 9550, 'Tales of Wedding Rings [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/285713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(133987, 9550, 'Tales of Wedding Rings [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/297073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(133988, 9550, 'Tales of Wedding Rings [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/300994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(133989, 9550, 'Tales of Wedding Rings [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/307165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(133990, 9551, 'Tales of Wedding Rings [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/888086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(133991, 9551, 'Tales of Wedding Rings [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/888087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(133992, 9551, 'Tales of Wedding Rings [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/889660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(133993, 9551, 'Tales of Wedding Rings [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/889979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(133994, 9551, 'Tales of Wedding Rings [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/890955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(133995, 9551, 'Tales of Wedding Rings [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/892163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(133996, 9551, 'Tales of Wedding Rings [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/892568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(133997, 9551, 'Tales of Wedding Rings [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/893292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(133998, 9551, 'Tales of Wedding Rings [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/894798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(133999, 9551, 'Tales of Wedding Rings [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/896191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(134000, 9551, 'Tales of Wedding Rings [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/896889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(134001, 9551, 'Tales of Wedding Rings [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/897360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wHBTJRKaGJzBcmghaouepA8L4tt.jpg'),
(134002, 9552, 'The Calling S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aA3VOqnQU78LGBrfhOvCl2lvdfu.jpg'),
(134003, 9552, 'The Calling S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/258708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7UQkdxz3tvc1KgRdvSeng0H4TCZ.jpg'),
(134004, 9552, 'The Calling S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/336954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yjc3yqr4zj228aWdgQa5wZqTPam.jpg'),
(134005, 9552, 'The Calling S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/336955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yjc3yqr4zj228aWdgQa5wZqTPam.jpg'),
(134006, 9552, 'The Calling S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/342971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yjc3yqr4zj228aWdgQa5wZqTPam.jpg'),
(134007, 9552, 'The Calling S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/354024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yjc3yqr4zj228aWdgQa5wZqTPam.jpg'),
(134008, 9552, 'The Calling S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/354025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yjc3yqr4zj228aWdgQa5wZqTPam.jpg'),
(134009, 9552, 'The Calling S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/358583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yjc3yqr4zj228aWdgQa5wZqTPam.jpg'),
(134010, 9553, 'The Unwanted Undead Adventurer [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aXIv3ekx1QBUT03tkSzXDhv0evh.jpg'),
(134011, 9553, 'The Unwanted Undead Adventurer [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/277420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/krnR0ANlwtlNEX7jgO8NJtj7QiB.jpg'),
(134012, 9553, 'The Unwanted Undead Adventurer [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/277421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/krnR0ANlwtlNEX7jgO8NJtj7QiB.jpg'),
(134013, 9553, 'The Unwanted Undead Adventurer [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/277422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/krnR0ANlwtlNEX7jgO8NJtj7QiB.jpg'),
(134014, 9553, 'The Unwanted Undead Adventurer [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/277423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/krnR0ANlwtlNEX7jgO8NJtj7QiB.jpg'),
(134015, 9553, 'The Unwanted Undead Adventurer [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/277424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/krnR0ANlwtlNEX7jgO8NJtj7QiB.jpg'),
(134016, 9553, 'The Unwanted Undead Adventurer [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/277425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/krnR0ANlwtlNEX7jgO8NJtj7QiB.jpg'),
(134017, 9553, 'The Unwanted Undead Adventurer [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/279395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/krnR0ANlwtlNEX7jgO8NJtj7QiB.jpg'),
(134018, 9553, 'The Unwanted Undead Adventurer [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/285684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/krnR0ANlwtlNEX7jgO8NJtj7QiB.jpg'),
(134019, 9553, 'The Unwanted Undead Adventurer [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/295169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/krnR0ANlwtlNEX7jgO8NJtj7QiB.jpg'),
(134020, 9553, 'The Unwanted Undead Adventurer [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/300972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/krnR0ANlwtlNEX7jgO8NJtj7QiB.jpg'),
(134021, 9553, 'The Unwanted Undead Adventurer [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/305770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/krnR0ANlwtlNEX7jgO8NJtj7QiB.jpg'),
(134022, 9554, 'The Witch and the Beast [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pQh6SFzDALzA00QESRQ8412QA0P.jpg'),
(134023, 9554, 'The Witch and the Beast [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/272485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cnvGV9vmIJVXh5YRjMbMtxpdsVg.jpg'),
(134024, 9554, 'The Witch and the Beast [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/272486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cnvGV9vmIJVXh5YRjMbMtxpdsVg.jpg'),
(134025, 9554, 'The Witch and the Beast [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/272487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cnvGV9vmIJVXh5YRjMbMtxpdsVg.jpg'),
(134026, 9554, 'The Witch and the Beast [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/272488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cnvGV9vmIJVXh5YRjMbMtxpdsVg.jpg'),
(134027, 9554, 'The Witch and the Beast [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/305743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cnvGV9vmIJVXh5YRjMbMtxpdsVg.jpg'),
(134028, 9554, 'The Witch and the Beast [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/305744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cnvGV9vmIJVXh5YRjMbMtxpdsVg.jpg'),
(134029, 9554, 'The Witch and the Beast [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/299733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cnvGV9vmIJVXh5YRjMbMtxpdsVg.jpg'),
(134030, 9554, 'The Witch and the Beast [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/305746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cnvGV9vmIJVXh5YRjMbMtxpdsVg.jpg'),
(134031, 9554, 'The Witch and the Beast [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/305747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cnvGV9vmIJVXh5YRjMbMtxpdsVg.jpg'),
(134032, 9554, 'The Witch and the Beast [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/311963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cnvGV9vmIJVXh5YRjMbMtxpdsVg.jpg'),
(134033, 9554, 'The Witch and the Beast [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/320978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cnvGV9vmIJVXh5YRjMbMtxpdsVg.jpg'),
(134034, 9555, 'Time The Series [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nNVCZpQHv0HihQ3aDCtFyGwUbQ2.jpg'),
(134035, 9555, 'Time The Series [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b0bLyPJ0ffmWYowP3iRafaPlp0W.jpg'),
(134036, 9556, 'Tis Time for Torture Princess [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/258704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/juV3wCzm1vDgk1N4UgvR0OWfbXN.jpg'),
(134037, 9556, 'Tis Time for Torture Princess [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/277407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7vPpzw4goRUojCVFIsU3drIhu3B.jpg'),
(134038, 9556, 'Tis Time for Torture Princess [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/277408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7vPpzw4goRUojCVFIsU3drIhu3B.jpg'),
(134039, 9556, 'Tis Time for Torture Princess [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/277409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7vPpzw4goRUojCVFIsU3drIhu3B.jpg'),
(134040, 9556, 'Tis Time for Torture Princess [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/277410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7vPpzw4goRUojCVFIsU3drIhu3B.jpg'),
(134041, 9556, 'Tis Time for Torture Princess [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/277411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7vPpzw4goRUojCVFIsU3drIhu3B.jpg'),
(134042, 9556, 'Tis Time for Torture Princess [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7vPpzw4goRUojCVFIsU3drIhu3B.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(134043, 9556, 'Tis Time for Torture Princess [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/296966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7vPpzw4goRUojCVFIsU3drIhu3B.jpg'),
(134044, 9556, 'Tis Time for Torture Princess [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/296967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7vPpzw4goRUojCVFIsU3drIhu3B.jpg'),
(134045, 9556, 'Tis Time for Torture Princess [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/306996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7vPpzw4goRUojCVFIsU3drIhu3B.jpg'),
(134046, 9556, 'Tis Time for Torture Princess [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/306997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7vPpzw4goRUojCVFIsU3drIhu3B.jpg'),
(134047, 9556, 'Tis Time for Torture Princess [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/316939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7vPpzw4goRUojCVFIsU3drIhu3B.jpg'),
(134048, 9557, 'Blue Exorcist [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xLY4vKOUTU1m3ptaVUzzL9nEYjm.jpg'),
(134049, 9557, 'Blue Exorcist [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bNyYgsuk9bjyudLPY3e3PL8MB1U.jpg'),
(134050, 9557, 'Blue Exorcist [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oI2IEi1qRHNPqWnkfNPmHKVgszR.jpg'),
(134051, 9557, 'Blue Exorcist [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4JfMjqfZCnbFFvixrrKVh09Ii0d.jpg'),
(134052, 9557, 'Blue Exorcist [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yg5zy6lLDB6KcVrSNfoS8fpDnwo.jpg'),
(134053, 9557, 'Blue Exorcist [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lIzYur25nKjRxFCsOOsX0nLlBJa.jpg'),
(134054, 9557, 'Blue Exorcist [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sWP4focFHxiv7JYj85ZUbcplg0m.jpg'),
(134055, 9557, 'Blue Exorcist [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/81uPwpQJrwLI7phuO152rGHDwbY.jpg'),
(134056, 9557, 'Blue Exorcist [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqdF7skj0QZvOQbXjQkzHzvZwUw.jpg'),
(134057, 9557, 'Blue Exorcist [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nNdoKY1wxret7965DbofelmDHrV.jpg'),
(134058, 9557, 'Blue Exorcist [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5nblWvu3T3myk2eXRgiwfS2khaR.jpg'),
(134059, 9557, 'Blue Exorcist [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4zvtPhTVflJd7jIGIKR6x0SiKfr.jpg'),
(134060, 9557, 'Blue Exorcist [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOfi6jwgPrQ3xRYGRUd9gHk1em3.jpg'),
(134061, 9557, 'Blue Exorcist [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fogc2wL4hRDWKUnWSK5WEtLr9d1.jpg'),
(134062, 9557, 'Blue Exorcist [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iRGJFWqK4c4fP85y8Qj4RuwM48u.jpg'),
(134063, 9557, 'Blue Exorcist [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p8OeN3EjxfFswcHSaoQgZMC7Mss.jpg'),
(134064, 9557, 'Blue Exorcist [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vB5ggQuGXYdn2hViu7o3sOaUsMc.jpg'),
(134065, 9557, 'Blue Exorcist [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/265123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1PcTHENbSpaogzmwjLlFhXD6ne4.jpg'),
(134066, 9557, 'Blue Exorcist [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/265124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rKAVARBYlIHLyeU6lrn1Lz2sgTV.jpg'),
(134067, 9557, 'Blue Exorcist [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/265125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tnxBtFSQurbIkeNa0I1ZuuhoIiu.jpg'),
(134068, 9557, 'Blue Exorcist [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/265126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wubQ0MKQx33jrCiC99QUyZ6ZwPJ.jpg'),
(134069, 9557, 'Blue Exorcist [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/265127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9xJWB1xEi9CLInGubAarXDM0464.jpg'),
(134070, 9557, 'Blue Exorcist [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/265128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w9lyLjhjT5nI0XJ72D51oyyt1k6.jpg'),
(134071, 9557, 'Blue Exorcist [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/265129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d8kDKXliOptum0ha97gcgwfH4JM.jpg'),
(134072, 9557, 'Blue Exorcist [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/265130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pvX4jAnO20in0JPnhhxi3yLqOTp.jpg'),
(134073, 9558, 'Blue Exorcist [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7vqw6IsEm4mSxJvF4nN59eKg3o1.jpg'),
(134074, 9558, 'Blue Exorcist [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cwbA6Dzp5G1e0fgmRVzFHyQGTg1.jpg'),
(134075, 9558, 'Blue Exorcist [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qbWhbcvUejV8dz04wEP2n9LQ0gs.jpg'),
(134076, 9558, 'Blue Exorcist [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lo1zKrgEFHlfdJMm7gm1Fsbl7j.jpg'),
(134077, 9558, 'Blue Exorcist [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/700noPCcxyTBSjC6HEW3HM9dhCA.jpg'),
(134078, 9558, 'Blue Exorcist [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uK2gRr5SAn6OYyHVIElZSFfrc7B.jpg'),
(134079, 9558, 'Blue Exorcist [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ByK9qJ0diBtaIxvJluYkFnV2m5.jpg'),
(134080, 9558, 'Blue Exorcist [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cIGBxXhNEsEgD8UocxuRGEw6Tev.jpg'),
(134081, 9558, 'Blue Exorcist [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5hJXpnW4h2zPdJCOoWII5KhO6HA.jpg'),
(134082, 9558, 'Blue Exorcist [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6JFYbmX9ajwBuS1X7KdrlmbGqgA.jpg'),
(134083, 9558, 'Blue Exorcist [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vtrQDP6DZX0wkSH2ZI0LqTVJyOI.jpg'),
(134084, 9558, 'Blue Exorcist [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ZiegNWpdlnLTtPbYntTwBCf4B9.jpg'),
(134085, 9559, 'Blue Exorcist [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mFlRp3yOaR8bZVb2p10C7vREsu1.jpg'),
(134086, 9559, 'Blue Exorcist [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134087, 9559, 'Blue Exorcist [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134088, 9559, 'Blue Exorcist [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134089, 9559, 'Blue Exorcist [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134090, 9559, 'Blue Exorcist [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134091, 9559, 'Blue Exorcist [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/276937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134092, 9559, 'Blue Exorcist [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/281499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134093, 9559, 'Blue Exorcist [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/287805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134094, 9559, 'Blue Exorcist [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/298480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134095, 9559, 'Blue Exorcist [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/303066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134096, 9559, 'Blue Exorcist [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/309361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134097, 9560, 'Blue Exorcist [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/485862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134098, 9560, 'Blue Exorcist [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/485863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134099, 9560, 'Blue Exorcist [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/485864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134100, 9560, 'Blue Exorcist [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/493947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134101, 9560, 'Blue Exorcist [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/497090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134102, 9560, 'Blue Exorcist [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/503349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134103, 9560, 'Blue Exorcist [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/507985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134104, 9560, 'Blue Exorcist [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/512538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134105, 9560, 'Blue Exorcist [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/514619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134106, 9560, 'Blue Exorcist [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/518874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134107, 9560, 'Blue Exorcist [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/638648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134108, 9560, 'Blue Exorcist [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/638649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134109, 9561, 'Blue Exorcist [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/659742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134110, 9561, 'Blue Exorcist [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/660843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134111, 9561, 'Blue Exorcist [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/665747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134112, 9561, 'Blue Exorcist [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/675940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134113, 9561, 'Blue Exorcist [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/683983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134114, 9561, 'Blue Exorcist [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/691824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134115, 9561, 'Blue Exorcist [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/698644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134116, 9561, 'Blue Exorcist [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/707470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134117, 9561, 'Blue Exorcist [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/711660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134118, 9561, 'Blue Exorcist [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/722263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134119, 9561, 'Blue Exorcist [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/729259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134120, 9561, 'Blue Exorcist [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/739163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jtOvJjdZCCHxsUuTSNikvPjKB4P.jpg'),
(134121, 9562, 'Investigacao Criminal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFh1X6z5DQxxRzmVx44qDpOp20f.jpg'),
(134122, 9562, 'Investigacao Criminal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7TstK3DTe9mo4B92KeGJLL1FHHo.jpg'),
(134123, 9562, 'Investigacao Criminal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AqBYC7fmgW7qC9NUNyG8XLiR1OR.jpg'),
(134124, 9562, 'Investigacao Criminal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wTJT3oCDH6zcRQCniJ2zeGuLn9m.jpg'),
(134125, 9562, 'Investigacao Criminal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mDuX1H8WihZb8Segeg5NcCGOCjX.jpg'),
(134126, 9562, 'Investigacao Criminal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AevEFU1fB98Xts7BJjQkNfjyFiJ.jpg'),
(134127, 9562, 'Investigacao Criminal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bTTfbR1sMybA5bE5s1soW3MlKKu.jpg'),
(134128, 9562, 'Investigacao Criminal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6LRaypYcaFvlghpWHEapkSThGA5.jpg'),
(134129, 9563, 'Investigacao Criminal S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7UQ0Z9SOJyycH5WkDRF96m9452.jpg'),
(134130, 9563, 'Investigacao Criminal S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9KAHZWOnlkmotUD8WNKKig1ZrwP.jpg'),
(134131, 9563, 'Investigacao Criminal S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a5Sv5vE3nIS7lTZSfkLS0WF61rN.jpg'),
(134132, 9563, 'Investigacao Criminal S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6LcGX8louwuICLMQMCRVvtW5hxy.jpg'),
(134133, 9563, 'Investigacao Criminal S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tWf4xnm3yOoDE9RHhXnfuduVYCd.jpg'),
(134134, 9563, 'Investigacao Criminal S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vdG2Ti7eCagg5UTy4HPWVU6BGXo.jpg'),
(134135, 9563, 'Investigacao Criminal S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aYRTA743VghVtHilWsq4ES58Sa3.jpg'),
(134136, 9563, 'Investigacao Criminal S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqzxfh6aIMAzl2rYwiuNllHLp87.jpg'),
(134137, 9564, 'Investigacao Criminal S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mL84K7zwu8QLM2YuWCykyLmrZtP.jpg'),
(134138, 9564, 'Investigacao Criminal S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7jrp1BK4XcCQ595G9HET3edz8ZL.jpg'),
(134139, 9564, 'Investigacao Criminal S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uvGJI7myvXFL9RiPRLdEH07XP2g.jpg'),
(134140, 9564, 'Investigacao Criminal S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jGIod6qb35MIAqz53RdXNzPv3XU.jpg'),
(134141, 9564, 'Investigacao Criminal S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n1u3K60DFBbV7KffaaOrGZDJT6l.jpg'),
(134142, 9564, 'Investigacao Criminal S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vvVmkRBzkBD6sqr9h4yd4fqJP8R.jpg'),
(134143, 9564, 'Investigacao Criminal S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fyAKxzJ2IkL7trCsQVg6BszNcV4.jpg'),
(134144, 9564, 'Investigacao Criminal S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Z9uWHEHMsqa63HSojxcgEvXSMV.jpg'),
(134145, 9565, 'Investigacao Criminal S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6MFVSn1DPLaLVBrbKUFkLGGn8oh.jpg'),
(134146, 9565, 'Investigacao Criminal S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9xjQscbB0SPeqv71kj3EtUx8IWN.jpg'),
(134147, 9565, 'Investigacao Criminal S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ycOQz9xrppHVyReivPmH3cklHSw.jpg'),
(134148, 9565, 'Investigacao Criminal S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wKJUcw3yKEPyLMg1vZ0sIDA6vjD.jpg'),
(134149, 9565, 'Investigacao Criminal S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fMmX7GAGb0wPAnwyzbrit2fBu6z.jpg'),
(134150, 9565, 'Investigacao Criminal S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hfMWKQftiyUSkULX9zkJ6A5pYHe.jpg'),
(134151, 9565, 'Investigacao Criminal S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oGMpTf67PcccXPr15iojA7xZyMX.jpg'),
(134152, 9565, 'Investigacao Criminal S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nYjPQDCvwSAoF8yNHnLgB2prSZS.jpg'),
(134153, 9566, 'Investigacao Criminal S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ZDgMKstUJvgiqXALwidHvZEa84.jpg'),
(134154, 9566, 'Investigacao Criminal S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ylHgljbpcKIGyHy1euQvJECT1ag.jpg'),
(134155, 9566, 'Investigacao Criminal S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/imMrcyI59hKLGpAEQGjGwucdNoK.jpg'),
(134156, 9566, 'Investigacao Criminal S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/710CRRr5Ay0opp3oMiyBkfaCT06.jpg'),
(134157, 9566, 'Investigacao Criminal S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yoI8mkjaJHN4tGUtSuduD16uc64.jpg'),
(134158, 9566, 'Investigacao Criminal S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhgVfEXkyuRkJrMelmNj62vP2Dr.jpg'),
(134159, 9566, 'Investigacao Criminal S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nh5sI9ZByOMAWZV6JyAtkRL3aZM.jpg'),
(134160, 9566, 'Investigacao Criminal S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKsEt27aG56JQsraWXGESsMsjwu.jpg'),
(134161, 9567, 'Investigacao Criminal S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wQz1E2tkZcq8bacwxG96USeF9B2.jpg'),
(134162, 9567, 'Investigacao Criminal S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tHvqBhxDXeAnku9zBfTMrYcCUQs.jpg'),
(134163, 9567, 'Investigacao Criminal S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kdyYOrLQaGRLnqoRfXP4zDdzYKM.jpg'),
(134164, 9567, 'Investigacao Criminal S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kdyYOrLQaGRLnqoRfXP4zDdzYKM.jpg'),
(134165, 9567, 'Investigacao Criminal S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5JHvYigG6apy9zvF0jMFV7TUm6.jpg'),
(134166, 9567, 'Investigacao Criminal S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1DrAZoWT1lMCE96fP4WqX1qiGYA.jpg'),
(134167, 9567, 'Investigacao Criminal S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oV9DGqwlTa4JCsLRSc7oqXvripW.jpg'),
(134168, 9567, 'Investigacao Criminal S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Rny5s6rMEcPQXxg3LS53bHhNFl.jpg'),
(134169, 9568, 'Investigacao Criminal S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2R8yNYO05GvvjJrYQ4SsWvp1x4u.jpg'),
(134170, 9568, 'Investigacao Criminal S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2R8yNYO05GvvjJrYQ4SsWvp1x4u.jpg'),
(134171, 9568, 'Investigacao Criminal S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2R8yNYO05GvvjJrYQ4SsWvp1x4u.jpg'),
(134172, 9568, 'Investigacao Criminal S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2R8yNYO05GvvjJrYQ4SsWvp1x4u.jpg'),
(134173, 9568, 'Investigacao Criminal S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/865514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2R8yNYO05GvvjJrYQ4SsWvp1x4u.jpg'),
(134174, 9568, 'Investigacao Criminal S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/865515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2R8yNYO05GvvjJrYQ4SsWvp1x4u.jpg'),
(134175, 9568, 'Investigacao Criminal S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/865516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2R8yNYO05GvvjJrYQ4SsWvp1x4u.jpg'),
(134176, 9568, 'Investigacao Criminal S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/865517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2R8yNYO05GvvjJrYQ4SsWvp1x4u.jpg'),
(134177, 9568, 'Investigacao Criminal S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/865518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2R8yNYO05GvvjJrYQ4SsWvp1x4u.jpg'),
(134178, 9568, 'Investigacao Criminal S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/865519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2R8yNYO05GvvjJrYQ4SsWvp1x4u.jpg'),
(134179, 9569, 'Love O2O [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMql5rkn92KHiWNygktqI5A38Ez.jpg'),
(134180, 9569, 'Love O2O [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgty7LCTxGgRaiU12CpymLjsIqt.jpg'),
(134181, 9569, 'Love O2O [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jNttkBLTWnp3Fw3ngMOYVOi9O3n.jpg'),
(134182, 9569, 'Love O2O [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iwmq0iBBkR7ExFc7evHLnlVFQRR.jpg'),
(134183, 9569, 'Love O2O [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/192RlO3HaeAm6dtUPWfkEkKEqsQ.jpg'),
(134184, 9569, 'Love O2O [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iwZyMQE4IMfQQIhdRNlIBI3oLde.jpg'),
(134185, 9569, 'Love O2O [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pwG0grvtuTdBdA7Drssj09Bd9r3.jpg'),
(134186, 9569, 'Love O2O [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kX0JH6oMELyzoMxjObbEkyns8n1.jpg'),
(134187, 9569, 'Love O2O [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xRGXGYGBT9WcI4aRUvc35mWFYt6.jpg'),
(134188, 9569, 'Love O2O [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w4MUBG289BQesyfrMfpipjlZaRB.jpg'),
(134189, 9569, 'Love O2O [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uVqIAUfIIMLyiNGHzHxDDX0Uivo.jpg'),
(134190, 9569, 'Love O2O [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ygw06dRkJhhCIvQ7QDGct2KzYOU.jpg'),
(134191, 9569, 'Love O2O [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLUCZ4R9IC1cfYw4U3KjL8RcDSs.jpg'),
(134192, 9569, 'Love O2O [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/257680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/DzSn8EpbGZGV2a380HO9KQeSny.jpg'),
(134193, 9569, 'Love O2O [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/257681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vMtWe9lUdL36YfBdeP5UqcsUiBK.jpg'),
(134194, 9569, 'Love O2O [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/257682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6izjpyOQOEPvar5QtlTDOjiXhh8.jpg'),
(134195, 9569, 'Love O2O [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/257683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zGup77pGo94P1UTTahLX1QlyDgo.jpg'),
(134196, 9569, 'Love O2O [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/257684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wQVvb6StqVpU1RR9lI3leN3OjlO.jpg'),
(134197, 9569, 'Love O2O [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/257685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8jKSHggzxLsuSuCBOnzcwerJ2HA.jpg'),
(134198, 9569, 'Love O2O [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/257686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bqcJCi7piKTvo1t9BTzkSEJy2t5.jpg'),
(134199, 9569, 'Love O2O [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/257687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1c7Vtf1pR58VxyHigTKHWkifAPn.jpg'),
(134200, 9569, 'Love O2O [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/257688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kYS9KXC8yNzN54hyU6tdzAGkOm1.jpg'),
(134201, 9569, 'Love O2O [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/257689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pm459zmIv9MSJs8zxDiQYuiiyrq.jpg'),
(134202, 9569, 'Love O2O [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/257690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4742K1iwRCRICupO5bvzQ06A4Xw.jpg'),
(134203, 9569, 'Love O2O [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/257691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3caxpO50qO3gmRckXBs8d26zXjq.jpg'),
(134204, 9569, 'Love O2O [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/257692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sbqAaW03dtW9sA6Elo5s3eQOoYf.jpg'),
(134205, 9569, 'Love O2O [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/257693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v1OMYv5Lcgc9t3eptBsmVfmhFwY.jpg'),
(134206, 9569, 'Love O2O [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/257694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzFFI91YcYRD32iauWyccUGW2L6.jpg'),
(134207, 9569, 'Love O2O [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/257695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jSdsFHX0POIVUBFGXMvug00n9jd.jpg'),
(134208, 9569, 'Love O2O [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/257696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i5fcwF7u3cC23GoLht3X95aKwYd.jpg'),
(134209, 9570, 'A Morte Entre Outros Misterios S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJCwgLONIpZryHV2MeqPUamGdUh.jpg'),
(134210, 9570, 'A Morte Entre Outros Misterios S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybtVZRnCqWexlMGAi6SgLXEdd0R.jpg'),
(134211, 9570, 'A Morte Entre Outros Misterios S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2DEa0Bz3j9ZhPRdBmNyco38OR6p.jpg'),
(134212, 9570, 'A Morte Entre Outros Misterios S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2DEa0Bz3j9ZhPRdBmNyco38OR6p.jpg'),
(134213, 9570, 'A Morte Entre Outros Misterios S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/271785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2DEa0Bz3j9ZhPRdBmNyco38OR6p.jpg'),
(134214, 9570, 'A Morte Entre Outros Misterios S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2DEa0Bz3j9ZhPRdBmNyco38OR6p.jpg'),
(134215, 9570, 'A Morte Entre Outros Misterios S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2DEa0Bz3j9ZhPRdBmNyco38OR6p.jpg'),
(134216, 9570, 'A Morte Entre Outros Misterios S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/288796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2DEa0Bz3j9ZhPRdBmNyco38OR6p.jpg'),
(134217, 9570, 'A Morte Entre Outros Misterios S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/499358.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iL58hJdBKQTsnNsDYhdpgRUDwrg.jpg'),
(134218, 9570, 'A Morte Entre Outros Misterios S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/499359.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mWUG2c6Z4N85RcQ4ulkkUpDWlwt.jpg'),
(134219, 9571, 'Alienigenas do Passado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/281796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134220, 9571, 'Alienigenas do Passado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/281797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134221, 9571, 'Alienigenas do Passado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/281798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134222, 9571, 'Alienigenas do Passado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/281799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134223, 9571, 'Alienigenas do Passado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/281800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134224, 9571, 'Alienigenas do Passado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/281801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134225, 9572, 'Alienigenas do Passado S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/281802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134226, 9572, 'Alienigenas do Passado S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/281803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134227, 9572, 'Alienigenas do Passado S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/281804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134228, 9572, 'Alienigenas do Passado S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/281805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134229, 9572, 'Alienigenas do Passado S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/281806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134230, 9572, 'Alienigenas do Passado S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/281807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134231, 9572, 'Alienigenas do Passado S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/281808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134232, 9572, 'Alienigenas do Passado S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/281809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134233, 9572, 'Alienigenas do Passado S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/281810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134234, 9572, 'Alienigenas do Passado S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/281811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134235, 9573, 'Alienigenas do Passado S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/281812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134236, 9573, 'Alienigenas do Passado S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/281813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134237, 9573, 'Alienigenas do Passado S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/281814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134238, 9573, 'Alienigenas do Passado S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/281815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134239, 9573, 'Alienigenas do Passado S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/281816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134240, 9573, 'Alienigenas do Passado S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/281817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134241, 9573, 'Alienigenas do Passado S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/281818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134242, 9573, 'Alienigenas do Passado S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/281819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134243, 9573, 'Alienigenas do Passado S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/281820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134244, 9573, 'Alienigenas do Passado S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/281821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134245, 9573, 'Alienigenas do Passado S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/281822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134246, 9573, 'Alienigenas do Passado S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/281823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134247, 9573, 'Alienigenas do Passado S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/281824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134248, 9573, 'Alienigenas do Passado S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/281825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134249, 9573, 'Alienigenas do Passado S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/281826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134250, 9573, 'Alienigenas do Passado S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/281827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134251, 9574, 'Alienigenas do Passado S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/281828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134252, 9574, 'Alienigenas do Passado S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/281829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134253, 9574, 'Alienigenas do Passado S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/281830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134254, 9574, 'Alienigenas do Passado S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/281831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134255, 9574, 'Alienigenas do Passado S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/281832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134256, 9574, 'Alienigenas do Passado S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/281833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134257, 9574, 'Alienigenas do Passado S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/281834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134258, 9574, 'Alienigenas do Passado S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/281835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134259, 9574, 'Alienigenas do Passado S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/281836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134260, 9574, 'Alienigenas do Passado S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/281837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134261, 9575, 'Alienigenas do Passado S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/281838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134262, 9575, 'Alienigenas do Passado S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/281839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134263, 9575, 'Alienigenas do Passado S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/281840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134264, 9575, 'Alienigenas do Passado S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/281841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134265, 9575, 'Alienigenas do Passado S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/281842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134266, 9575, 'Alienigenas do Passado S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/281843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134267, 9575, 'Alienigenas do Passado S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/281844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134268, 9575, 'Alienigenas do Passado S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/281845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134269, 9575, 'Alienigenas do Passado S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/281846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134270, 9575, 'Alienigenas do Passado S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/281847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134271, 9575, 'Alienigenas do Passado S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/281848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134272, 9575, 'Alienigenas do Passado S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/281849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134273, 9576, 'Alienigenas do Passado S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/281850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134274, 9576, 'Alienigenas do Passado S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/281851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134275, 9576, 'Alienigenas do Passado S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/281852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134276, 9576, 'Alienigenas do Passado S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/281853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134277, 9576, 'Alienigenas do Passado S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/281854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134278, 9576, 'Alienigenas do Passado S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/281855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134279, 9576, 'Alienigenas do Passado S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/281856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134280, 9576, 'Alienigenas do Passado S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/281857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134281, 9576, 'Alienigenas do Passado S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/281858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134282, 9576, 'Alienigenas do Passado S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/281859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134283, 9576, 'Alienigenas do Passado S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/281860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134284, 9576, 'Alienigenas do Passado S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/281861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134285, 9576, 'Alienigenas do Passado S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/281862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134286, 9576, 'Alienigenas do Passado S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/281863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134287, 9576, 'Alienigenas do Passado S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/281864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134288, 9576, 'Alienigenas do Passado S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/281865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134289, 9576, 'Alienigenas do Passado S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/281866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134290, 9577, 'Alienigenas do Passado S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/281867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134291, 9577, 'Alienigenas do Passado S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/281868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134292, 9577, 'Alienigenas do Passado S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/281869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134293, 9577, 'Alienigenas do Passado S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/281870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134294, 9577, 'Alienigenas do Passado S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/281871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134295, 9577, 'Alienigenas do Passado S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/281872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134296, 9577, 'Alienigenas do Passado S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/281873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134297, 9577, 'Alienigenas do Passado S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/281874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134298, 9577, 'Alienigenas do Passado S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/281875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134299, 9577, 'Alienigenas do Passado S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/281876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(134300, 9577, 'Alienigenas do Passado S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/281877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134301, 9577, 'Alienigenas do Passado S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/281878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134302, 9577, 'Alienigenas do Passado S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/281879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134303, 9577, 'Alienigenas do Passado S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/281880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134304, 9577, 'Alienigenas do Passado S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/281881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134305, 9577, 'Alienigenas do Passado S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/281882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134306, 9577, 'Alienigenas do Passado S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/281883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134307, 9578, 'Alienigenas do Passado S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/281884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134308, 9578, 'Alienigenas do Passado S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/281885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134309, 9578, 'Alienigenas do Passado S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/281886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134310, 9578, 'Alienigenas do Passado S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/281887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134311, 9578, 'Alienigenas do Passado S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/281888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134312, 9578, 'Alienigenas do Passado S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/281889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134313, 9578, 'Alienigenas do Passado S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/281890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134314, 9578, 'Alienigenas do Passado S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/281891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134315, 9578, 'Alienigenas do Passado S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/281892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134316, 9578, 'Alienigenas do Passado S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/281893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134317, 9579, 'Alienigenas do Passado S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/281894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134318, 9579, 'Alienigenas do Passado S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/281895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134319, 9579, 'Alienigenas do Passado S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/281896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134320, 9579, 'Alienigenas do Passado S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/281897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134321, 9579, 'Alienigenas do Passado S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/281898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134322, 9579, 'Alienigenas do Passado S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/281899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134323, 9579, 'Alienigenas do Passado S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/281900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134324, 9579, 'Alienigenas do Passado S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/281901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134325, 9579, 'Alienigenas do Passado S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/281902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134326, 9579, 'Alienigenas do Passado S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/281903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134327, 9579, 'Alienigenas do Passado S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/281904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134328, 9579, 'Alienigenas do Passado S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/281905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134329, 9580, 'Alienigenas do Passado S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/281906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134330, 9580, 'Alienigenas do Passado S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/281907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134331, 9580, 'Alienigenas do Passado S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/281908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134332, 9580, 'Alienigenas do Passado S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/281909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134333, 9580, 'Alienigenas do Passado S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/281910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134334, 9580, 'Alienigenas do Passado S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/281911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134335, 9580, 'Alienigenas do Passado S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/281912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134336, 9580, 'Alienigenas do Passado S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/281913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134337, 9580, 'Alienigenas do Passado S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/281914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134338, 9580, 'Alienigenas do Passado S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/281915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134339, 9581, 'Alienigenas do Passado S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/281916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134340, 9581, 'Alienigenas do Passado S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/281917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134341, 9581, 'Alienigenas do Passado S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/281918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134342, 9581, 'Alienigenas do Passado S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/281919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134343, 9581, 'Alienigenas do Passado S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/281920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134344, 9581, 'Alienigenas do Passado S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/281921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134345, 9581, 'Alienigenas do Passado S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/281922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134346, 9581, 'Alienigenas do Passado S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/281923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134347, 9581, 'Alienigenas do Passado S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/281924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134348, 9581, 'Alienigenas do Passado S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/281925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134349, 9581, 'Alienigenas do Passado S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/281926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134350, 9581, 'Alienigenas do Passado S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/281927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134351, 9581, 'Alienigenas do Passado S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/281928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134352, 9581, 'Alienigenas do Passado S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/281929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134353, 9581, 'Alienigenas do Passado S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/281930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134354, 9582, 'Alienigenas do Passado S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/281931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134355, 9582, 'Alienigenas do Passado S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/281932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134356, 9582, 'Alienigenas do Passado S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/281933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134357, 9582, 'Alienigenas do Passado S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/281934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134358, 9582, 'Alienigenas do Passado S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/281935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134359, 9582, 'Alienigenas do Passado S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/281936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134360, 9582, 'Alienigenas do Passado S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/281937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134361, 9582, 'Alienigenas do Passado S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/281938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134362, 9582, 'Alienigenas do Passado S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/281939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134363, 9582, 'Alienigenas do Passado S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/281940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134364, 9582, 'Alienigenas do Passado S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/281941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134365, 9582, 'Alienigenas do Passado S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/281942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134366, 9582, 'Alienigenas do Passado S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/281943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134367, 9582, 'Alienigenas do Passado S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/281944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134368, 9582, 'Alienigenas do Passado S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/281945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134369, 9582, 'Alienigenas do Passado S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/281946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134370, 9583, 'Alienigenas do Passado S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/281947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134371, 9583, 'Alienigenas do Passado S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/281948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134372, 9583, 'Alienigenas do Passado S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/281949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134373, 9583, 'Alienigenas do Passado S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/281950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134374, 9583, 'Alienigenas do Passado S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/281951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134375, 9583, 'Alienigenas do Passado S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/281952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134376, 9583, 'Alienigenas do Passado S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/281953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134377, 9583, 'Alienigenas do Passado S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/281954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134378, 9583, 'Alienigenas do Passado S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/281955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134379, 9583, 'Alienigenas do Passado S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/281956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134380, 9583, 'Alienigenas do Passado S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/281957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134381, 9583, 'Alienigenas do Passado S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/281958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134382, 9583, 'Alienigenas do Passado S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/281959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134383, 9583, 'Alienigenas do Passado S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/281960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134384, 9583, 'Alienigenas do Passado S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/281961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134385, 9584, 'Alienigenas do Passado S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/281962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134386, 9584, 'Alienigenas do Passado S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/281963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134387, 9584, 'Alienigenas do Passado S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/281964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134388, 9584, 'Alienigenas do Passado S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/281965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134389, 9584, 'Alienigenas do Passado S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/281966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134390, 9584, 'Alienigenas do Passado S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/281967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134391, 9584, 'Alienigenas do Passado S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/281968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134392, 9584, 'Alienigenas do Passado S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/281969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134393, 9584, 'Alienigenas do Passado S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/281970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134394, 9584, 'Alienigenas do Passado S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/281971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134395, 9584, 'Alienigenas do Passado S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/281972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134396, 9584, 'Alienigenas do Passado S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/281973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134397, 9584, 'Alienigenas do Passado S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/281974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134398, 9584, 'Alienigenas do Passado S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/281975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134399, 9584, 'Alienigenas do Passado S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/281976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134400, 9584, 'Alienigenas do Passado S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/281977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134401, 9584, 'Alienigenas do Passado S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/281978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134402, 9584, 'Alienigenas do Passado S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/281979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134403, 9584, 'Alienigenas do Passado S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/281980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134404, 9584, 'Alienigenas do Passado S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/281981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134405, 9584, 'Alienigenas do Passado S14 E21', 'http://sinalprivado.info:80/series/1533784/1533784/281982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134406, 9584, 'Alienigenas do Passado S14 E22', 'http://sinalprivado.info:80/series/1533784/1533784/281983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134407, 9585, 'Alienigenas do Passado S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/281984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134408, 9585, 'Alienigenas do Passado S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/281985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134409, 9585, 'Alienigenas do Passado S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/281986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134410, 9585, 'Alienigenas do Passado S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/281987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134411, 9585, 'Alienigenas do Passado S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/281988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134412, 9585, 'Alienigenas do Passado S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/281989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134413, 9585, 'Alienigenas do Passado S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/281990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134414, 9585, 'Alienigenas do Passado S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/281991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134415, 9585, 'Alienigenas do Passado S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/281992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134416, 9585, 'Alienigenas do Passado S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/281993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134417, 9585, 'Alienigenas do Passado S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/281994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134418, 9585, 'Alienigenas do Passado S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/281995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134419, 9586, 'Alienigenas do Passado S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/281996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134420, 9586, 'Alienigenas do Passado S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/281997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134421, 9586, 'Alienigenas do Passado S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/281998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134422, 9586, 'Alienigenas do Passado S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/281999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134423, 9586, 'Alienigenas do Passado S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134424, 9586, 'Alienigenas do Passado S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/282001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134425, 9586, 'Alienigenas do Passado S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134426, 9586, 'Alienigenas do Passado S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/282003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134427, 9586, 'Alienigenas do Passado S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/282004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134428, 9587, 'Alienigenas do Passado S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134429, 9587, 'Alienigenas do Passado S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134430, 9587, 'Alienigenas do Passado S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/282007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134431, 9587, 'Alienigenas do Passado S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/282008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134432, 9587, 'Alienigenas do Passado S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134433, 9587, 'Alienigenas do Passado S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/282010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134434, 9587, 'Alienigenas do Passado S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134435, 9588, 'Alienigenas do Passado S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134436, 9589, 'Alienigenas do Passado S19 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tRFNSLQaYAcI1R8VU42cvIjl1lW.jpg'),
(134437, 9589, 'Alienigenas do Passado S19 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vWTdiYIF5PNINw8ijcHMPFte8Tj.jpg'),
(134438, 9589, 'Alienigenas do Passado S19 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8U5wpwvNWCs7BoQLpjTeBloCI0F.jpg'),
(134439, 9589, 'Alienigenas do Passado S19 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134440, 9589, 'Alienigenas do Passado S19 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134441, 9589, 'Alienigenas do Passado S19 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134442, 9589, 'Alienigenas do Passado S19 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134443, 9589, 'Alienigenas do Passado S19 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134444, 9589, 'Alienigenas do Passado S19 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134445, 9589, 'Alienigenas do Passado S19 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134446, 9589, 'Alienigenas do Passado S19 E11', 'http://sinalprivado.info:80/series/1533784/1533784/281566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134447, 9589, 'Alienigenas do Passado S19 E12', 'http://sinalprivado.info:80/series/1533784/1533784/281567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134448, 9589, 'Alienigenas do Passado S19 E13', 'http://sinalprivado.info:80/series/1533784/1533784/298526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134449, 9589, 'Alienigenas do Passado S19 E14', 'http://sinalprivado.info:80/series/1533784/1533784/739373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134450, 9589, 'Alienigenas do Passado S19 E15', 'http://sinalprivado.info:80/series/1533784/1533784/739374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134451, 9589, 'Alienigenas do Passado S19 E16', 'http://sinalprivado.info:80/series/1533784/1533784/739375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134452, 9589, 'Alienigenas do Passado S19 E17', 'http://sinalprivado.info:80/series/1533784/1533784/739376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134453, 9589, 'Alienigenas do Passado S19 E18', 'http://sinalprivado.info:80/series/1533784/1533784/739377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134454, 9589, 'Alienigenas do Passado S19 E19', 'http://sinalprivado.info:80/series/1533784/1533784/739378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134455, 9589, 'Alienigenas do Passado S19 E20', 'http://sinalprivado.info:80/series/1533784/1533784/739379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dlFaRJ3LwVBrZ3KV4OK4QRScY7p.jpg'),
(134456, 9590, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268659.mp4', 'http://timg.bdta.pro/images/c0be39ed0d2dae522a3ee4ae215550bb.jpg'),
(134457, 9590, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268660.mp4', 'http://timg.bdta.pro/images/3d2120805dc013e4803eddb37bad7af6.jpg'),
(134458, 9590, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268661.mp4', 'http://timg.bdta.pro/images/463e4117d64b852a6ef3c7c0e7eb31cc.jpg'),
(134459, 9590, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268662.mp4', 'http://timg.bdta.pro/images/3bdf6fbb3ec86e39202e072510a37e1c.jpg'),
(134460, 9590, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nIEstdg7X1JDzryM2tVQjpYMx1X.jpg'),
(134461, 9590, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268664.mp4', 'http://timg.bdta.pro/images/73a3482496dc2461e86aa66a881523a9.jpg'),
(134462, 9590, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6xwBrfib4jtnLH8T7NUy8NDrrKF.jpg'),
(134463, 9590, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268666.mp4', 'http://timg.bdta.pro/images/d51894bab571a1c4596d6ff0e414c44d.jpg'),
(134464, 9590, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nn0OhNw49ENSTFdF77p0GPBwoT7.jpg'),
(134465, 9590, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268668.mp4', 'http://timg.bdta.pro/images/babd10723f93c2b14b11a15a30d93b39.jpg'),
(134466, 9590, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/80QgQPtufA63Nbx2exRZg5gYt1Z.jpg'),
(134467, 9590, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ckSIT7WwTvtIvqcmd4NSiAgcZX1.jpg'),
(134468, 9590, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ouyzTu834aPl0yQm89c1gKtnEfS.jpg'),
(134469, 9591, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lPuP4djjZf7L7NtNGM3taLyAR44.jpg'),
(134470, 9591, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1TV9MQ2j3XQiw8Oad51mWh3vWGT.jpg'),
(134471, 9591, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgYMsOsFrQ9Q5NjlQwKRWu0K3uM.jpg'),
(134472, 9591, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgYMsOsFrQ9Q5NjlQwKRWu0K3uM.jpg'),
(134473, 9591, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgYMsOsFrQ9Q5NjlQwKRWu0K3uM.jpg'),
(134474, 9591, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgYMsOsFrQ9Q5NjlQwKRWu0K3uM.jpg'),
(134475, 9591, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/276957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgYMsOsFrQ9Q5NjlQwKRWu0K3uM.jpg'),
(134476, 9591, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/283174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgYMsOsFrQ9Q5NjlQwKRWu0K3uM.jpg'),
(134477, 9591, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/285619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgYMsOsFrQ9Q5NjlQwKRWu0K3uM.jpg'),
(134478, 9591, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/298503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgYMsOsFrQ9Q5NjlQwKRWu0K3uM.jpg'),
(134479, 9591, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/300680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgYMsOsFrQ9Q5NjlQwKRWu0K3uM.jpg'),
(134480, 9591, 'Banished from the Heros Party I Decided to Live a Quiet Life in the Countryside [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/309386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgYMsOsFrQ9Q5NjlQwKRWu0K3uM.jpg'),
(134481, 9592, 'Bate Papo BBB S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oAlHa5DxuVdKecGk2vOa6ogn5ph.jpg'),
(134482, 9592, 'Bate Papo BBB S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oAlHa5DxuVdKecGk2vOa6ogn5ph.jpg'),
(134483, 9593, 'Big Brother Brasil S24 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134484, 9593, 'Big Brother Brasil S24 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134485, 9593, 'Big Brother Brasil S24 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134486, 9593, 'Big Brother Brasil S24 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134487, 9593, 'Big Brother Brasil S24 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134488, 9593, 'Big Brother Brasil S24 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134489, 9593, 'Big Brother Brasil S24 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134490, 9593, 'Big Brother Brasil S24 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134491, 9593, 'Big Brother Brasil S24 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134492, 9593, 'Big Brother Brasil S24 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134493, 9593, 'Big Brother Brasil S24 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134494, 9593, 'Big Brother Brasil S24 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134495, 9593, 'Big Brother Brasil S24 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134496, 9593, 'Big Brother Brasil S24 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134497, 9593, 'Big Brother Brasil S24 E15', 'http://sinalprivado.info:80/series/1533784/1533784/268645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134498, 9593, 'Big Brother Brasil S24 E16', 'http://sinalprivado.info:80/series/1533784/1533784/268646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134499, 9593, 'Big Brother Brasil S24 E17', 'http://sinalprivado.info:80/series/1533784/1533784/268647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134500, 9593, 'Big Brother Brasil S24 E18', 'http://sinalprivado.info:80/series/1533784/1533784/268648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134501, 9593, 'Big Brother Brasil S24 E19', 'http://sinalprivado.info:80/series/1533784/1533784/268649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134502, 9593, 'Big Brother Brasil S24 E20', 'http://sinalprivado.info:80/series/1533784/1533784/268650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134503, 9593, 'Big Brother Brasil S24 E21', 'http://sinalprivado.info:80/series/1533784/1533784/268651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134504, 9593, 'Big Brother Brasil S24 E22', 'http://sinalprivado.info:80/series/1533784/1533784/268652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134505, 9593, 'Big Brother Brasil S24 E23', 'http://sinalprivado.info:80/series/1533784/1533784/268653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134506, 9593, 'Big Brother Brasil S24 E24', 'http://sinalprivado.info:80/series/1533784/1533784/268654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134507, 9593, 'Big Brother Brasil S24 E25', 'http://sinalprivado.info:80/series/1533784/1533784/268655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134508, 9593, 'Big Brother Brasil S24 E26', 'http://sinalprivado.info:80/series/1533784/1533784/268656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134509, 9593, 'Big Brother Brasil S24 E27', 'http://sinalprivado.info:80/series/1533784/1533784/268657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134510, 9593, 'Big Brother Brasil S24 E28', 'http://sinalprivado.info:80/series/1533784/1533784/268658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134511, 9593, 'Big Brother Brasil S24 E29', 'http://sinalprivado.info:80/series/1533784/1533784/271704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134512, 9593, 'Big Brother Brasil S24 E30', 'http://sinalprivado.info:80/series/1533784/1533784/271705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134513, 9593, 'Big Brother Brasil S24 E31', 'http://sinalprivado.info:80/series/1533784/1533784/271706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134514, 9593, 'Big Brother Brasil S24 E32', 'http://sinalprivado.info:80/series/1533784/1533784/271707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134515, 9593, 'Big Brother Brasil S24 E33', 'http://sinalprivado.info:80/series/1533784/1533784/271708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134516, 9593, 'Big Brother Brasil S24 E34', 'http://sinalprivado.info:80/series/1533784/1533784/271709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134517, 9593, 'Big Brother Brasil S24 E35', 'http://sinalprivado.info:80/series/1533784/1533784/271710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134518, 9593, 'Big Brother Brasil S24 E36', 'http://sinalprivado.info:80/series/1533784/1533784/273321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134519, 9593, 'Big Brother Brasil S24 E37', 'http://sinalprivado.info:80/series/1533784/1533784/273322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134520, 9593, 'Big Brother Brasil S24 E38', 'http://sinalprivado.info:80/series/1533784/1533784/273323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134521, 9593, 'Big Brother Brasil S24 E39', 'http://sinalprivado.info:80/series/1533784/1533784/274845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134522, 9593, 'Big Brother Brasil S24 E40', 'http://sinalprivado.info:80/series/1533784/1533784/274846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134523, 9593, 'Big Brother Brasil S24 E41', 'http://sinalprivado.info:80/series/1533784/1533784/274847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134524, 9593, 'Big Brother Brasil S24 E42', 'http://sinalprivado.info:80/series/1533784/1533784/274848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134525, 9593, 'Big Brother Brasil S24 E43', 'http://sinalprivado.info:80/series/1533784/1533784/274849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134526, 9593, 'Big Brother Brasil S24 E44', 'http://sinalprivado.info:80/series/1533784/1533784/278057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134527, 9593, 'Big Brother Brasil S24 E45', 'http://sinalprivado.info:80/series/1533784/1533784/279169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134528, 9593, 'Big Brother Brasil S24 E46', 'http://sinalprivado.info:80/series/1533784/1533784/281545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134529, 9593, 'Big Brother Brasil S24 E47', 'http://sinalprivado.info:80/series/1533784/1533784/281546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134530, 9593, 'Big Brother Brasil S24 E48', 'http://sinalprivado.info:80/series/1533784/1533784/281547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134531, 9593, 'Big Brother Brasil S24 E49', 'http://sinalprivado.info:80/series/1533784/1533784/283153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134532, 9593, 'Big Brother Brasil S24 E50', 'http://sinalprivado.info:80/series/1533784/1533784/290151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134533, 9593, 'Big Brother Brasil S24 E51', 'http://sinalprivado.info:80/series/1533784/1533784/290152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134534, 9593, 'Big Brother Brasil S24 E52', 'http://sinalprivado.info:80/series/1533784/1533784/290153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134535, 9593, 'Big Brother Brasil S24 E53', 'http://sinalprivado.info:80/series/1533784/1533784/290154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134536, 9593, 'Big Brother Brasil S24 E54', 'http://sinalprivado.info:80/series/1533784/1533784/290155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134537, 9593, 'Big Brother Brasil S24 E55', 'http://sinalprivado.info:80/series/1533784/1533784/290156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134538, 9593, 'Big Brother Brasil S24 E56', 'http://sinalprivado.info:80/series/1533784/1533784/290157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134539, 9593, 'Big Brother Brasil S24 E57', 'http://sinalprivado.info:80/series/1533784/1533784/294531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134540, 9593, 'Big Brother Brasil S24 E58', 'http://sinalprivado.info:80/series/1533784/1533784/295885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134541, 9593, 'Big Brother Brasil S24 E59', 'http://sinalprivado.info:80/series/1533784/1533784/295886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134542, 9593, 'Big Brother Brasil S24 E60', 'http://sinalprivado.info:80/series/1533784/1533784/295887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134543, 9593, 'Big Brother Brasil S24 E61', 'http://sinalprivado.info:80/series/1533784/1533784/299467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134544, 9593, 'Big Brother Brasil S24 E62', 'http://sinalprivado.info:80/series/1533784/1533784/299468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134545, 9593, 'Big Brother Brasil S24 E63', 'http://sinalprivado.info:80/series/1533784/1533784/299469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134546, 9593, 'Big Brother Brasil S24 E64', 'http://sinalprivado.info:80/series/1533784/1533784/300382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(134547, 9593, 'Big Brother Brasil S24 E65', 'http://sinalprivado.info:80/series/1533784/1533784/300383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134548, 9593, 'Big Brother Brasil S24 E66', 'http://sinalprivado.info:80/series/1533784/1533784/300653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134549, 9593, 'Big Brother Brasil S24 E67', 'http://sinalprivado.info:80/series/1533784/1533784/300654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134550, 9593, 'Big Brother Brasil S24 E68', 'http://sinalprivado.info:80/series/1533784/1533784/300655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134551, 9593, 'Big Brother Brasil S24 E69', 'http://sinalprivado.info:80/series/1533784/1533784/300656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134552, 9593, 'Big Brother Brasil S24 E70', 'http://sinalprivado.info:80/series/1533784/1533784/305525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134553, 9593, 'Big Brother Brasil S24 E71', 'http://sinalprivado.info:80/series/1533784/1533784/305526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134554, 9593, 'Big Brother Brasil S24 E72', 'http://sinalprivado.info:80/series/1533784/1533784/305527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134555, 9593, 'Big Brother Brasil S24 E73', 'http://sinalprivado.info:80/series/1533784/1533784/306300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134556, 9593, 'Big Brother Brasil S24 E74', 'http://sinalprivado.info:80/series/1533784/1533784/310716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134557, 9593, 'Big Brother Brasil S24 E75', 'http://sinalprivado.info:80/series/1533784/1533784/310717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134558, 9593, 'Big Brother Brasil S24 E76', 'http://sinalprivado.info:80/series/1533784/1533784/310718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134559, 9593, 'Big Brother Brasil S24 E77', 'http://sinalprivado.info:80/series/1533784/1533784/310719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134560, 9593, 'Big Brother Brasil S24 E78', 'http://sinalprivado.info:80/series/1533784/1533784/310720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134561, 9593, 'Big Brother Brasil S24 E79', 'http://sinalprivado.info:80/series/1533784/1533784/310721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134562, 9593, 'Big Brother Brasil S24 E80', 'http://sinalprivado.info:80/series/1533784/1533784/316292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134563, 9593, 'Big Brother Brasil S24 E81', 'http://sinalprivado.info:80/series/1533784/1533784/316293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134564, 9593, 'Big Brother Brasil S24 E82', 'http://sinalprivado.info:80/series/1533784/1533784/316294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134565, 9593, 'Big Brother Brasil S24 E83', 'http://sinalprivado.info:80/series/1533784/1533784/316295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134566, 9593, 'Big Brother Brasil S24 E84', 'http://sinalprivado.info:80/series/1533784/1533784/318976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134567, 9593, 'Big Brother Brasil S24 E85', 'http://sinalprivado.info:80/series/1533784/1533784/318977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134568, 9593, 'Big Brother Brasil S24 E86', 'http://sinalprivado.info:80/series/1533784/1533784/319984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134569, 9593, 'Big Brother Brasil S24 E87', 'http://sinalprivado.info:80/series/1533784/1533784/320865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134570, 9593, 'Big Brother Brasil S24 E88', 'http://sinalprivado.info:80/series/1533784/1533784/320866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134571, 9593, 'Big Brother Brasil S24 E89', 'http://sinalprivado.info:80/series/1533784/1533784/320867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134572, 9593, 'Big Brother Brasil S24 E90', 'http://sinalprivado.info:80/series/1533784/1533784/320868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134573, 9593, 'Big Brother Brasil S24 E91', 'http://sinalprivado.info:80/series/1533784/1533784/325144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134574, 9593, 'Big Brother Brasil S24 E92', 'http://sinalprivado.info:80/series/1533784/1533784/325145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134575, 9593, 'Big Brother Brasil S24 E93', 'http://sinalprivado.info:80/series/1533784/1533784/326975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134576, 9593, 'Big Brother Brasil S24 E94', 'http://sinalprivado.info:80/series/1533784/1533784/326976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134577, 9593, 'Big Brother Brasil S24 E95', 'http://sinalprivado.info:80/series/1533784/1533784/326977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134578, 9593, 'Big Brother Brasil S24 E96', 'http://sinalprivado.info:80/series/1533784/1533784/326978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134579, 9593, 'Big Brother Brasil S24 E97', 'http://sinalprivado.info:80/series/1533784/1533784/326979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134580, 9593, 'Big Brother Brasil S24 E98', 'http://sinalprivado.info:80/series/1533784/1533784/328999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134581, 9593, 'Big Brother Brasil S24 E99', 'http://sinalprivado.info:80/series/1533784/1533784/329000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134582, 9594, 'Big Brother Brasil S25 E01', 'http://sinalprivado.info:80/series/1533784/1533784/665869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134583, 9594, 'Big Brother Brasil S25 E02', 'http://sinalprivado.info:80/series/1533784/1533784/665870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134584, 9594, 'Big Brother Brasil S25 E03', 'http://sinalprivado.info:80/series/1533784/1533784/665871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134585, 9594, 'Big Brother Brasil S25 E04', 'http://sinalprivado.info:80/series/1533784/1533784/665872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134586, 9594, 'Big Brother Brasil S25 E05', 'http://sinalprivado.info:80/series/1533784/1533784/665873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134587, 9594, 'Big Brother Brasil S25 E06', 'http://sinalprivado.info:80/series/1533784/1533784/670013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134588, 9594, 'Big Brother Brasil S25 E07', 'http://sinalprivado.info:80/series/1533784/1533784/671056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134589, 9594, 'Big Brother Brasil S25 E08', 'http://sinalprivado.info:80/series/1533784/1533784/671057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134590, 9594, 'Big Brother Brasil S25 E09', 'http://sinalprivado.info:80/series/1533784/1533784/672610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134591, 9594, 'Big Brother Brasil S25 E10', 'http://sinalprivado.info:80/series/1533784/1533784/676066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134592, 9594, 'Big Brother Brasil S25 E11', 'http://sinalprivado.info:80/series/1533784/1533784/676067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134593, 9594, 'Big Brother Brasil S25 E12', 'http://sinalprivado.info:80/series/1533784/1533784/676068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134594, 9594, 'Big Brother Brasil S25 E13', 'http://sinalprivado.info:80/series/1533784/1533784/676069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134595, 9594, 'Big Brother Brasil S25 E14', 'http://sinalprivado.info:80/series/1533784/1533784/680968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134596, 9594, 'Big Brother Brasil S25 E15', 'http://sinalprivado.info:80/series/1533784/1533784/680969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134597, 9594, 'Big Brother Brasil S25 E16', 'http://sinalprivado.info:80/series/1533784/1533784/680970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134598, 9594, 'Big Brother Brasil S25 E17', 'http://sinalprivado.info:80/series/1533784/1533784/684117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134599, 9594, 'Big Brother Brasil S25 E18', 'http://sinalprivado.info:80/series/1533784/1533784/684118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134600, 9594, 'Big Brother Brasil S25 E19', 'http://sinalprivado.info:80/series/1533784/1533784/684119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134601, 9594, 'Big Brother Brasil S25 E20', 'http://sinalprivado.info:80/series/1533784/1533784/684120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134602, 9594, 'Big Brother Brasil S25 E21', 'http://sinalprivado.info:80/series/1533784/1533784/684811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134603, 9594, 'Big Brother Brasil S25 E22', 'http://sinalprivado.info:80/series/1533784/1533784/684812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134604, 9594, 'Big Brother Brasil S25 E23', 'http://sinalprivado.info:80/series/1533784/1533784/684813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134605, 9594, 'Big Brother Brasil S25 E24', 'http://sinalprivado.info:80/series/1533784/1533784/686957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134606, 9594, 'Big Brother Brasil S25 E25', 'http://sinalprivado.info:80/series/1533784/1533784/686958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134607, 9594, 'Big Brother Brasil S25 E26', 'http://sinalprivado.info:80/series/1533784/1533784/691958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134608, 9594, 'Big Brother Brasil S25 E27', 'http://sinalprivado.info:80/series/1533784/1533784/691959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134609, 9594, 'Big Brother Brasil S25 E28', 'http://sinalprivado.info:80/series/1533784/1533784/692573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134610, 9594, 'Big Brother Brasil S25 E29', 'http://sinalprivado.info:80/series/1533784/1533784/692574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134611, 9594, 'Big Brother Brasil S25 E30', 'http://sinalprivado.info:80/series/1533784/1533784/698802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134612, 9594, 'Big Brother Brasil S25 E31', 'http://sinalprivado.info:80/series/1533784/1533784/698803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134613, 9594, 'Big Brother Brasil S25 E32', 'http://sinalprivado.info:80/series/1533784/1533784/698804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134614, 9594, 'Big Brother Brasil S25 E33', 'http://sinalprivado.info:80/series/1533784/1533784/698805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134615, 9594, 'Big Brother Brasil S25 E34', 'http://sinalprivado.info:80/series/1533784/1533784/703126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134616, 9594, 'Big Brother Brasil S25 E35', 'http://sinalprivado.info:80/series/1533784/1533784/703127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134617, 9594, 'Big Brother Brasil S25 E36', 'http://sinalprivado.info:80/series/1533784/1533784/703128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134618, 9594, 'Big Brother Brasil S25 E37', 'http://sinalprivado.info:80/series/1533784/1533784/707615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134619, 9594, 'Big Brother Brasil S25 E38', 'http://sinalprivado.info:80/series/1533784/1533784/707616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134620, 9594, 'Big Brother Brasil S25 E39', 'http://sinalprivado.info:80/series/1533784/1533784/707617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134621, 9594, 'Big Brother Brasil S25 E40', 'http://sinalprivado.info:80/series/1533784/1533784/707618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134622, 9594, 'Big Brother Brasil S25 E41', 'http://sinalprivado.info:80/series/1533784/1533784/707619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134623, 9594, 'Big Brother Brasil S25 E42', 'http://sinalprivado.info:80/series/1533784/1533784/710131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134624, 9594, 'Big Brother Brasil S25 E43', 'http://sinalprivado.info:80/series/1533784/1533784/710132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134625, 9594, 'Big Brother Brasil S25 E44', 'http://sinalprivado.info:80/series/1533784/1533784/713028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134626, 9594, 'Big Brother Brasil S25 E45', 'http://sinalprivado.info:80/series/1533784/1533784/713029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134627, 9594, 'Big Brother Brasil S25 E46', 'http://sinalprivado.info:80/series/1533784/1533784/713030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134628, 9594, 'Big Brother Brasil S25 E47', 'http://sinalprivado.info:80/series/1533784/1533784/719104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134629, 9594, 'Big Brother Brasil S25 E48', 'http://sinalprivado.info:80/series/1533784/1533784/719105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134630, 9594, 'Big Brother Brasil S25 E49', 'http://sinalprivado.info:80/series/1533784/1533784/719106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134631, 9594, 'Big Brother Brasil S25 E50', 'http://sinalprivado.info:80/series/1533784/1533784/719107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134632, 9594, 'Big Brother Brasil S25 E51', 'http://sinalprivado.info:80/series/1533784/1533784/719108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134633, 9594, 'Big Brother Brasil S25 E52', 'http://sinalprivado.info:80/series/1533784/1533784/719109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134634, 9594, 'Big Brother Brasil S25 E53', 'http://sinalprivado.info:80/series/1533784/1533784/719110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134635, 9594, 'Big Brother Brasil S25 E54', 'http://sinalprivado.info:80/series/1533784/1533784/722425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134636, 9594, 'Big Brother Brasil S25 E55', 'http://sinalprivado.info:80/series/1533784/1533784/725288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134637, 9594, 'Big Brother Brasil S25 E56', 'http://sinalprivado.info:80/series/1533784/1533784/725289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134638, 9594, 'Big Brother Brasil S25 E57', 'http://sinalprivado.info:80/series/1533784/1533784/725290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134639, 9594, 'Big Brother Brasil S25 E58', 'http://sinalprivado.info:80/series/1533784/1533784/725291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134640, 9594, 'Big Brother Brasil S25 E59', 'http://sinalprivado.info:80/series/1533784/1533784/729426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134641, 9594, 'Big Brother Brasil S25 E60', 'http://sinalprivado.info:80/series/1533784/1533784/729427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134642, 9594, 'Big Brother Brasil S25 E61', 'http://sinalprivado.info:80/series/1533784/1533784/729428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134643, 9594, 'Big Brother Brasil S25 E62', 'http://sinalprivado.info:80/series/1533784/1533784/729429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134644, 9594, 'Big Brother Brasil S25 E63', 'http://sinalprivado.info:80/series/1533784/1533784/730846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134645, 9594, 'Big Brother Brasil S25 E64', 'http://sinalprivado.info:80/series/1533784/1533784/730847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134646, 9594, 'Big Brother Brasil S25 E65', 'http://sinalprivado.info:80/series/1533784/1533784/730848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134647, 9594, 'Big Brother Brasil S25 E66', 'http://sinalprivado.info:80/series/1533784/1533784/730849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134648, 9594, 'Big Brother Brasil S25 E67', 'http://sinalprivado.info:80/series/1533784/1533784/735889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134649, 9594, 'Big Brother Brasil S25 E68', 'http://sinalprivado.info:80/series/1533784/1533784/739339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134650, 9594, 'Big Brother Brasil S25 E69', 'http://sinalprivado.info:80/series/1533784/1533784/739340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134651, 9594, 'Big Brother Brasil S25 E70', 'http://sinalprivado.info:80/series/1533784/1533784/740817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134652, 9594, 'Big Brother Brasil S25 E71', 'http://sinalprivado.info:80/series/1533784/1533784/740818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134653, 9594, 'Big Brother Brasil S25 E72', 'http://sinalprivado.info:80/series/1533784/1533784/743066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134654, 9594, 'Big Brother Brasil S25 E73', 'http://sinalprivado.info:80/series/1533784/1533784/743346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134655, 9594, 'Big Brother Brasil S25 E74', 'http://sinalprivado.info:80/series/1533784/1533784/743347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134656, 9594, 'Big Brother Brasil S25 E75', 'http://sinalprivado.info:80/series/1533784/1533784/743348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134657, 9594, 'Big Brother Brasil S25 E76', 'http://sinalprivado.info:80/series/1533784/1533784/743349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134658, 9594, 'Big Brother Brasil S25 E77', 'http://sinalprivado.info:80/series/1533784/1533784/756010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134659, 9594, 'Big Brother Brasil S25 E78', 'http://sinalprivado.info:80/series/1533784/1533784/756011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134660, 9594, 'Big Brother Brasil S25 E79', 'http://sinalprivado.info:80/series/1533784/1533784/756012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134661, 9594, 'Big Brother Brasil S25 E80', 'http://sinalprivado.info:80/series/1533784/1533784/761363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134662, 9594, 'Big Brother Brasil S25 E81', 'http://sinalprivado.info:80/series/1533784/1533784/761364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134663, 9594, 'Big Brother Brasil S25 E82', 'http://sinalprivado.info:80/series/1533784/1533784/761365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134664, 9594, 'Big Brother Brasil S25 E83', 'http://sinalprivado.info:80/series/1533784/1533784/761366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134665, 9594, 'Big Brother Brasil S25 E84', 'http://sinalprivado.info:80/series/1533784/1533784/768763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134666, 9594, 'Big Brother Brasil S25 E85', 'http://sinalprivado.info:80/series/1533784/1533784/768764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134667, 9594, 'Big Brother Brasil S25 E86', 'http://sinalprivado.info:80/series/1533784/1533784/768765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134668, 9594, 'Big Brother Brasil S25 E87', 'http://sinalprivado.info:80/series/1533784/1533784/768766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134669, 9594, 'Big Brother Brasil S25 E88', 'http://sinalprivado.info:80/series/1533784/1533784/768767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134670, 9594, 'Big Brother Brasil S25 E89', 'http://sinalprivado.info:80/series/1533784/1533784/768768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134671, 9594, 'Big Brother Brasil S25 E90', 'http://sinalprivado.info:80/series/1533784/1533784/768769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134672, 9594, 'Big Brother Brasil S25 E91', 'http://sinalprivado.info:80/series/1533784/1533784/770902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134673, 9594, 'Big Brother Brasil S25 E92', 'http://sinalprivado.info:80/series/1533784/1533784/770903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134674, 9594, 'Big Brother Brasil S25 E93', 'http://sinalprivado.info:80/series/1533784/1533784/770904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134675, 9594, 'Big Brother Brasil S25 E94', 'http://sinalprivado.info:80/series/1533784/1533784/770905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134676, 9594, 'Big Brother Brasil S25 E95', 'http://sinalprivado.info:80/series/1533784/1533784/770906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134677, 9594, 'Big Brother Brasil S25 E96', 'http://sinalprivado.info:80/series/1533784/1533784/770907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134678, 9594, 'Big Brother Brasil S25 E97', 'http://sinalprivado.info:80/series/1533784/1533784/770908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134679, 9594, 'Big Brother Brasil S25 E98', 'http://sinalprivado.info:80/series/1533784/1533784/781661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134680, 9594, 'Big Brother Brasil S25 E99', 'http://sinalprivado.info:80/series/1533784/1533784/781662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134681, 9594, 'Big Brother Brasil S25 E100', 'http://sinalprivado.info:80/series/1533784/1533784/781663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ky0CxomLrqZ2cOh92agjAKECEKM.jpg'),
(134682, 9595, 'Caminhos dos Orixas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bOYFrQHhbhsC5qHj5nd1C7xsc94.jpg'),
(134683, 9595, 'Caminhos dos Orixas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bOYFrQHhbhsC5qHj5nd1C7xsc94.jpg'),
(134684, 9595, 'Caminhos dos Orixas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/257651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bOYFrQHhbhsC5qHj5nd1C7xsc94.jpg'),
(134685, 9595, 'Caminhos dos Orixas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/257652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bOYFrQHhbhsC5qHj5nd1C7xsc94.jpg'),
(134686, 9595, 'Caminhos dos Orixas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/257653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bOYFrQHhbhsC5qHj5nd1C7xsc94.jpg'),
(134687, 9595, 'Caminhos dos Orixas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/257654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bOYFrQHhbhsC5qHj5nd1C7xsc94.jpg'),
(134688, 9595, 'Caminhos dos Orixas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/257655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bOYFrQHhbhsC5qHj5nd1C7xsc94.jpg'),
(134689, 9595, 'Caminhos dos Orixas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/257656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bOYFrQHhbhsC5qHj5nd1C7xsc94.jpg'),
(134690, 9595, 'Caminhos dos Orixas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/257657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bOYFrQHhbhsC5qHj5nd1C7xsc94.jpg'),
(134691, 9595, 'Caminhos dos Orixas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/257658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bOYFrQHhbhsC5qHj5nd1C7xsc94.jpg'),
(134692, 9595, 'Caminhos dos Orixas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/257659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bOYFrQHhbhsC5qHj5nd1C7xsc94.jpg'),
(134693, 9595, 'Caminhos dos Orixas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/257660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bOYFrQHhbhsC5qHj5nd1C7xsc94.jpg'),
(134694, 9595, 'Caminhos dos Orixas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/257661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bOYFrQHhbhsC5qHj5nd1C7xsc94.jpg'),
(134695, 9595, 'Caminhos dos Orixas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/257662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bOYFrQHhbhsC5qHj5nd1C7xsc94.jpg'),
(134696, 9595, 'Caminhos dos Orixas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/257663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bOYFrQHhbhsC5qHj5nd1C7xsc94.jpg'),
(134697, 9595, 'Caminhos dos Orixas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/257664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bOYFrQHhbhsC5qHj5nd1C7xsc94.jpg'),
(134698, 9596, 'Dinheiro Sujo Por Dentro da Economia Nazista [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/257647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hqZZnhPn6mhHrI2fIvUimC61Dcq.jpg'),
(134699, 9596, 'Dinheiro Sujo Por Dentro da Economia Nazista [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/257648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hqZZnhPn6mhHrI2fIvUimC61Dcq.jpg'),
(134700, 9597, 'Frieren e a Jornada para o Alem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zVobco2BeS830uaUYOhtMnod9WX.jpg'),
(134701, 9597, 'Frieren e a Jornada para o Alem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJGUPHFJFmoHsmv0N6JI3ZJeZBG.jpg'),
(134702, 9597, 'Frieren e a Jornada para o Alem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gq0TjdNgQALpD4D8zczXATBH29Y.jpg'),
(134703, 9597, 'Frieren e a Jornada para o Alem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4kzc4beMDCjuwtBgbDRW9YlcLpB.jpg'),
(134704, 9597, 'Frieren e a Jornada para o Alem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/72wASkm3E3JoJ7O0vFcaXQ0BeCA.jpg'),
(134705, 9597, 'Frieren e a Jornada para o Alem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ec0jlVcmqK5ADkk5mNUCiW9cRzJ.jpg'),
(134706, 9597, 'Frieren e a Jornada para o Alem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/60LCMgI9HBCwoOe2nSx98W7OJvG.jpg'),
(134707, 9597, 'Frieren e a Jornada para o Alem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6cTOIPmU3KEUU68KosHHnWarx3E.jpg'),
(134708, 9597, 'Frieren e a Jornada para o Alem S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/262643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9CaxBHDfy6FeHI7bFGMCCIvcuXl.jpg'),
(134709, 9597, 'Frieren e a Jornada para o Alem S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/262644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3wgOqbGtjNmejkqsXHg2mwpoI6a.jpg'),
(134710, 9597, 'Frieren e a Jornada para o Alem S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/262645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ApKDj77DQi0sTS50StuHt9mErK5.jpg'),
(134711, 9597, 'Frieren e a Jornada para o Alem S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/262646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gSALjGge72BtvjJBrwrCKR3gfc0.jpg'),
(134712, 9597, 'Frieren e a Jornada para o Alem S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/262647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dyyGfEmF1BpZvG6p79sPg5HkBAL.jpg'),
(134713, 9597, 'Frieren e a Jornada para o Alem S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/262648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhnJr6JVHmoXfLZCwJdKvJNAxJ9.jpg'),
(134714, 9597, 'Frieren e a Jornada para o Alem S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/262649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134715, 9597, 'Frieren e a Jornada para o Alem S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/262650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134716, 9597, 'Frieren e a Jornada para o Alem S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/262651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134717, 9597, 'Frieren e a Jornada para o Alem S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/271383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134718, 9597, 'Frieren e a Jornada para o Alem S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/271384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134719, 9597, 'Frieren e a Jornada para o Alem S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/276558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134720, 9597, 'Frieren e a Jornada para o Alem S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/281096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134721, 9597, 'Frieren e a Jornada para o Alem S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/287395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134722, 9597, 'Frieren e a Jornada para o Alem S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/295540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134723, 9597, 'Frieren e a Jornada para o Alem S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/302711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134724, 9597, 'Frieren e a Jornada para o Alem S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/308881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134725, 9597, 'Frieren e a Jornada para o Alem S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/317713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134726, 9597, 'Frieren e a Jornada para o Alem S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/322699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134727, 9597, 'Frieren e a Jornada para o Alem S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/325744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134728, 9598, 'Frieren e a Jornada para o Alem [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zVobco2BeS830uaUYOhtMnod9WX.jpg'),
(134729, 9598, 'Frieren e a Jornada para o Alem [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJGUPHFJFmoHsmv0N6JI3ZJeZBG.jpg'),
(134730, 9598, 'Frieren e a Jornada para o Alem [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gq0TjdNgQALpD4D8zczXATBH29Y.jpg'),
(134731, 9598, 'Frieren e a Jornada para o Alem [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4kzc4beMDCjuwtBgbDRW9YlcLpB.jpg'),
(134732, 9598, 'Frieren e a Jornada para o Alem [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/72wASkm3E3JoJ7O0vFcaXQ0BeCA.jpg'),
(134733, 9598, 'Frieren e a Jornada para o Alem [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ec0jlVcmqK5ADkk5mNUCiW9cRzJ.jpg'),
(134734, 9598, 'Frieren e a Jornada para o Alem [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/60LCMgI9HBCwoOe2nSx98W7OJvG.jpg'),
(134735, 9598, 'Frieren e a Jornada para o Alem [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6cTOIPmU3KEUU68KosHHnWarx3E.jpg'),
(134736, 9598, 'Frieren e a Jornada para o Alem [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9CaxBHDfy6FeHI7bFGMCCIvcuXl.jpg'),
(134737, 9598, 'Frieren e a Jornada para o Alem [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3wgOqbGtjNmejkqsXHg2mwpoI6a.jpg'),
(134738, 9598, 'Frieren e a Jornada para o Alem [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ApKDj77DQi0sTS50StuHt9mErK5.jpg'),
(134739, 9598, 'Frieren e a Jornada para o Alem [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gSALjGge72BtvjJBrwrCKR3gfc0.jpg'),
(134740, 9598, 'Frieren e a Jornada para o Alem [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dyyGfEmF1BpZvG6p79sPg5HkBAL.jpg'),
(134741, 9598, 'Frieren e a Jornada para o Alem [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhnJr6JVHmoXfLZCwJdKvJNAxJ9.jpg'),
(134742, 9598, 'Frieren e a Jornada para o Alem [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/266918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/65KUShpBJQHaIUM0Bzaixn2cbn2.jpg'),
(134743, 9598, 'Frieren e a Jornada para o Alem [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/266919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ncMujhZQYcLXJA0Knr1DoAPuBHT.jpg'),
(134744, 9598, 'Frieren e a Jornada para o Alem [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/266920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f53eF4YhEOcWTKYNKE4SlCnfqV.jpg'),
(134745, 9598, 'Frieren e a Jornada para o Alem [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/266921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5iLxOsM3EakE6wYRQIJE2KfXU6.jpg'),
(134746, 9598, 'Frieren e a Jornada para o Alem [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/266922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134747, 9598, 'Frieren e a Jornada para o Alem [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/266923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134748, 9598, 'Frieren e a Jornada para o Alem [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/272927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134749, 9598, 'Frieren e a Jornada para o Alem [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/272928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134750, 9598, 'Frieren e a Jornada para o Alem [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/276581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134751, 9598, 'Frieren e a Jornada para o Alem [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/292769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134752, 9598, 'Frieren e a Jornada para o Alem [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/292770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134753, 9598, 'Frieren e a Jornada para o Alem [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/297908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134754, 9598, 'Frieren e a Jornada para o Alem [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/302738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134755, 9598, 'Frieren e a Jornada para o Alem [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/306146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qykTIEJQF8cunKD0CKOqab15wns.jpg'),
(134756, 9599, 'Hokkaido Gals Are Super Adorable [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yab8WrkxvmJwfz8Ely9UzGadisA.jpg'),
(134757, 9599, 'Hokkaido Gals Are Super Adorable [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kg4cnBiliNK6TNUjcWB0UOoj5qb.jpg'),
(134758, 9599, 'Hokkaido Gals Are Super Adorable [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wttuiqXv3lmLJLaa74SoKSXEPU.jpg'),
(134759, 9599, 'Hokkaido Gals Are Super Adorable [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wttuiqXv3lmLJLaa74SoKSXEPU.jpg'),
(134760, 9599, 'Hokkaido Gals Are Super Adorable [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/272861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wttuiqXv3lmLJLaa74SoKSXEPU.jpg'),
(134761, 9599, 'Hokkaido Gals Are Super Adorable [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/272862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wttuiqXv3lmLJLaa74SoKSXEPU.jpg'),
(134762, 9599, 'Hokkaido Gals Are Super Adorable [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/277705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wttuiqXv3lmLJLaa74SoKSXEPU.jpg'),
(134763, 9599, 'Hokkaido Gals Are Super Adorable [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/288682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wttuiqXv3lmLJLaa74SoKSXEPU.jpg'),
(134764, 9599, 'Hokkaido Gals Are Super Adorable [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/294126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wttuiqXv3lmLJLaa74SoKSXEPU.jpg'),
(134765, 9599, 'Hokkaido Gals Are Super Adorable [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/299175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wttuiqXv3lmLJLaa74SoKSXEPU.jpg'),
(134766, 9599, 'Hokkaido Gals Are Super Adorable [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/304607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wttuiqXv3lmLJLaa74SoKSXEPU.jpg'),
(134767, 9599, 'Hokkaido Gals Are Super Adorable [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/310059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wttuiqXv3lmLJLaa74SoKSXEPU.jpg'),
(134768, 9600, 'Mashle Magia e Musculos [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sNuDaeRpJeAN68nkicHXhUspgyn.jpg'),
(134769, 9600, 'Mashle Magia e Musculos [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wRhVcJOzPORex4f5MleMiBE0a8N.jpg'),
(134770, 9600, 'Mashle Magia e Musculos [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nUWfraG7hbtVIZ2VaZv2QNqMgsZ.jpg'),
(134771, 9600, 'Mashle Magia e Musculos [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yCkSMesQxSlUSl0bAwEA2QbShpk.jpg'),
(134772, 9600, 'Mashle Magia e Musculos [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kGWzULYc0GgdQaKFIMFNmM7COFq.jpg'),
(134773, 9600, 'Mashle Magia e Musculos [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AiSJOokpu1cBDUlMtth7SLj10iu.jpg'),
(134774, 9600, 'Mashle Magia e Musculos [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFu8YYzAFayt6rkv73fOeRUEwAR.jpg'),
(134775, 9600, 'Mashle Magia e Musculos [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/94Jx029j907EIqxZXbslIDcW07X.jpg'),
(134776, 9600, 'Mashle Magia e Musculos [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cWu9sSqfrd3YoSOzOHuk6F5qYbl.jpg'),
(134777, 9600, 'Mashle Magia e Musculos [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8kxD7JcC2Re1u4TNQ67s9IjGHLg.jpg'),
(134778, 9600, 'Mashle Magia e Musculos [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6bL1AUjhnUJjLhAoWkJ4SksPW3L.jpg'),
(134779, 9600, 'Mashle Magia e Musculos [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/71iETgbXw6FragBF5GoNyRqQWkN.jpg'),
(134780, 9601, 'Mashle Magia e Musculos [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/48dNOsGBOxQwZp04kcLdebFdPBU.jpg'),
(134781, 9601, 'Mashle Magia e Musculos [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/48dNOsGBOxQwZp04kcLdebFdPBU.jpg'),
(134782, 9601, 'Mashle Magia e Musculos [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/48dNOsGBOxQwZp04kcLdebFdPBU.jpg'),
(134783, 9601, 'Mashle Magia e Musculos [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/48dNOsGBOxQwZp04kcLdebFdPBU.jpg'),
(134784, 9601, 'Mashle Magia e Musculos [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/48dNOsGBOxQwZp04kcLdebFdPBU.jpg'),
(134785, 9601, 'Mashle Magia e Musculos [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/292037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/48dNOsGBOxQwZp04kcLdebFdPBU.jpg'),
(134786, 9601, 'Mashle Magia e Musculos [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/292038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/48dNOsGBOxQwZp04kcLdebFdPBU.jpg'),
(134787, 9601, 'Mashle Magia e Musculos [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/292039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/48dNOsGBOxQwZp04kcLdebFdPBU.jpg'),
(134788, 9601, 'Mashle Magia e Musculos [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/297544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/48dNOsGBOxQwZp04kcLdebFdPBU.jpg'),
(134789, 9601, 'Mashle Magia e Musculos [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/302572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/48dNOsGBOxQwZp04kcLdebFdPBU.jpg'),
(134790, 9601, 'Mashle Magia e Musculos [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/308604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/48dNOsGBOxQwZp04kcLdebFdPBU.jpg'),
(134791, 9601, 'Mashle Magia e Musculos [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/315645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/48dNOsGBOxQwZp04kcLdebFdPBU.jpg'),
(134792, 9602, 'Mussolini o Primeiro Facista [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f7HQjbWkzIHdIcBRS7MUiurx7Dj.jpg'),
(134793, 9602, 'Mussolini o Primeiro Facista [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9csegWHooW1Ariz3bl2HfaG5uOH.jpg'),
(134794, 9603, 'Na Piscina Com Fe Paes Leme S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/270234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lmxgtgllnqOwN5nFXF8XOSnLa0Q.jpg'),
(134795, 9603, 'Na Piscina Com Fe Paes Leme S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/270235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lmxgtgllnqOwN5nFXF8XOSnLa0Q.jpg'),
(134796, 9603, 'Na Piscina Com Fe Paes Leme S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/270236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lmxgtgllnqOwN5nFXF8XOSnLa0Q.jpg'),
(134797, 9603, 'Na Piscina Com Fe Paes Leme S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/270237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lmxgtgllnqOwN5nFXF8XOSnLa0Q.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(134798, 9603, 'Na Piscina Com Fe Paes Leme S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/270238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lmxgtgllnqOwN5nFXF8XOSnLa0Q.jpg'),
(134799, 9603, 'Na Piscina Com Fe Paes Leme S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/270239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lmxgtgllnqOwN5nFXF8XOSnLa0Q.jpg'),
(134800, 9603, 'Na Piscina Com Fe Paes Leme S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/270240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lmxgtgllnqOwN5nFXF8XOSnLa0Q.jpg'),
(134801, 9603, 'Na Piscina Com Fe Paes Leme S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/270241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lmxgtgllnqOwN5nFXF8XOSnLa0Q.jpg'),
(134802, 9603, 'Na Piscina Com Fe Paes Leme S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/270242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lmxgtgllnqOwN5nFXF8XOSnLa0Q.jpg'),
(134803, 9603, 'Na Piscina Com Fe Paes Leme S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/270243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lmxgtgllnqOwN5nFXF8XOSnLa0Q.jpg'),
(134804, 9603, 'Na Piscina Com Fe Paes Leme S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/270244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lmxgtgllnqOwN5nFXF8XOSnLa0Q.jpg'),
(134805, 9603, 'Na Piscina Com Fe Paes Leme S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/270245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lmxgtgllnqOwN5nFXF8XOSnLa0Q.jpg'),
(134806, 9603, 'Na Piscina Com Fe Paes Leme S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/270246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lmxgtgllnqOwN5nFXF8XOSnLa0Q.jpg'),
(134807, 9603, 'Na Piscina Com Fe Paes Leme S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/590222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lmxgtgllnqOwN5nFXF8XOSnLa0Q.jpg'),
(134808, 9603, 'Na Piscina Com Fe Paes Leme S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/271008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lmxgtgllnqOwN5nFXF8XOSnLa0Q.jpg'),
(134809, 9603, 'Na Piscina Com Fe Paes Leme S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/271009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lmxgtgllnqOwN5nFXF8XOSnLa0Q.jpg'),
(134810, 9603, 'Na Piscina Com Fe Paes Leme S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/271010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lmxgtgllnqOwN5nFXF8XOSnLa0Q.jpg'),
(134811, 9603, 'Na Piscina Com Fe Paes Leme S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/271011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lmxgtgllnqOwN5nFXF8XOSnLa0Q.jpg'),
(134812, 9603, 'Na Piscina Com Fe Paes Leme S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/271012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lmxgtgllnqOwN5nFXF8XOSnLa0Q.jpg'),
(134813, 9604, 'Spy x Family [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134814, 9604, 'Spy x Family [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134815, 9604, 'Spy x Family [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134816, 9604, 'Spy x Family [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134817, 9604, 'Spy x Family [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134818, 9604, 'Spy x Family [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134819, 9604, 'Spy x Family [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134820, 9604, 'Spy x Family [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134821, 9604, 'Spy x Family [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134822, 9604, 'Spy x Family [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134823, 9604, 'Spy x Family [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/261779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134824, 9604, 'Spy x Family [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/261780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134825, 9604, 'Spy x Family [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/261781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134826, 9604, 'Spy x Family [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/261782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134827, 9604, 'Spy x Family [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/261783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134828, 9604, 'Spy x Family [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/261784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134829, 9604, 'Spy x Family [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/261785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134830, 9604, 'Spy x Family [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/261786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134831, 9604, 'Spy x Family [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/261787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134832, 9604, 'Spy x Family [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/261788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134833, 9604, 'Spy x Family [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/261789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134834, 9604, 'Spy x Family [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/261790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134835, 9604, 'Spy x Family [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/261791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134836, 9604, 'Spy x Family [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/261792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134837, 9604, 'Spy x Family [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/261793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134838, 9605, 'Spy x Family [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134839, 9605, 'Spy x Family [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134840, 9605, 'Spy x Family [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134841, 9605, 'Spy x Family [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134842, 9605, 'Spy x Family [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134843, 9605, 'Spy x Family [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134844, 9605, 'Spy x Family [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134845, 9605, 'Spy x Family [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134846, 9605, 'Spy x Family [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134847, 9605, 'Spy x Family [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134848, 9605, 'Spy x Family [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/261804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134849, 9605, 'Spy x Family [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/261805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIREdPGZOnW9Jrs86mheVVlIQQ.jpg'),
(134850, 9606, 'TSUKIMICHI Moonlit Fantasy [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zw21ulawI2xjBbyUrsTbEU9bKDD.jpg'),
(134851, 9606, 'TSUKIMICHI Moonlit Fantasy [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZmhrXhl2LNZmns1fXG3aao6FCR.jpg'),
(134852, 9606, 'TSUKIMICHI Moonlit Fantasy [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jNTQHpQrZSKSxESMAuAQZ4U5uav.jpg'),
(134853, 9606, 'TSUKIMICHI Moonlit Fantasy [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6cGpr8NWl0oBXJjuhdFTddbmv6a.jpg'),
(134854, 9606, 'TSUKIMICHI Moonlit Fantasy [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kojoqUmD4NDzhuXaUEUz8UhgeK3.jpg'),
(134855, 9606, 'TSUKIMICHI Moonlit Fantasy [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9OkSps4eGuntx1e6GZtQ0vF5whM.jpg'),
(134856, 9606, 'TSUKIMICHI Moonlit Fantasy [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/acQhdkyDknwHmP6OzfvN14kPucD.jpg'),
(134857, 9606, 'TSUKIMICHI Moonlit Fantasy [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jJIygE3kYQmE50UEgBu2IFcsdtd.jpg'),
(134858, 9606, 'TSUKIMICHI Moonlit Fantasy [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1GXgJpLvpWwidVFAjXJdMKG3WMh.jpg'),
(134859, 9606, 'TSUKIMICHI Moonlit Fantasy [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tddj0cjLtCY3YQSrtf36SwxheX3.jpg'),
(134860, 9606, 'TSUKIMICHI Moonlit Fantasy [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyQMXauyiF767uWHG0K2gH5ccrq.jpg'),
(134861, 9606, 'TSUKIMICHI Moonlit Fantasy [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/labur9NDw5fUgsnFkEOhX1MNbZP.jpg'),
(134862, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/byLHF6qG4BbVNv4job0OU0jlCvX.jpg'),
(134863, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3VRY4CvDx4dpD5QcJ9uKNPt3K2C.jpg'),
(134864, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134865, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134866, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/272546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134867, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134868, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134869, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/288522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134870, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/293995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134871, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/299080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134872, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/303929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134873, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/309625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134874, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/317162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134875, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/323524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134876, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/327547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134877, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/335840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134878, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/339999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134879, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/351319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134880, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/351320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134881, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/358656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134882, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/609138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134883, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/372972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134884, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/384033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134885, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/388531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134886, 9607, 'TSUKIMICHI Moonlit Fantasy [L] S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/394170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/exhONC020D4DGvt7XB4nq9AOMDU.jpg'),
(134887, 9608, 'A Garota de Oslo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rwEax33EIvVqHKOrTOnd3LVyJhb.jpg'),
(134888, 9608, 'A Garota de Oslo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lv0G6poKO2IX6tJA9IzyQfj1ocU.jpg'),
(134889, 9608, 'A Garota de Oslo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3r7yAgyvAbhzyFi6axAz8D7qAB.jpg'),
(134890, 9608, 'A Garota de Oslo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hA9Q6WrJlZQuczLiG3dVInWLq04.jpg'),
(134891, 9608, 'A Garota de Oslo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iZX8snHUXPyl5ZFJX2Dwy3j7d8A.jpg'),
(134892, 9608, 'A Garota de Oslo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Zib8jITbmZ0vwSqmzORx9y2iiI.jpg'),
(134893, 9608, 'A Garota de Oslo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/awMANc78ZhSudfw9Hb2qcN4fCpo.jpg'),
(134894, 9608, 'A Garota de Oslo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qrnmXANO10aPKsIDksN2JTU8AER.jpg'),
(134895, 9608, 'A Garota de Oslo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kiuXp0zWvZxYwE47RU6HxaPQInj.jpg'),
(134896, 9608, 'A Garota de Oslo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t3ynbrp5D2vitDiLIuK1hBNh6AD.jpg'),
(134897, 9609, 'Doctor John [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(134898, 9609, 'Doctor John [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(134899, 9609, 'Doctor John [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(134900, 9609, 'Doctor John [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(134901, 9609, 'Doctor John [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(134902, 9609, 'Doctor John [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(134903, 9609, 'Doctor John [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(134904, 9609, 'Doctor John [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(134905, 9609, 'Doctor John [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(134906, 9609, 'Doctor John [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(134907, 9609, 'Doctor John [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/261652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(134908, 9609, 'Doctor John [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/261653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(134909, 9609, 'Doctor John [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/261654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(134910, 9609, 'Doctor John [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/261655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(134911, 9609, 'Doctor John [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/261656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(134912, 9609, 'Doctor John [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/261657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(134913, 9610, 'A Friend of the Family S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5wBo5iuWSbfGWzRfxrzWYKNjaKU.jpg'),
(134914, 9610, 'A Friend of the Family S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qaT9BmbW0GT7mSnVsBTxqE2hGLI.jpg'),
(134915, 9610, 'A Friend of the Family S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/443004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bmJkzDE6s0QYBGtpA4i2JLBco0j.jpg'),
(134916, 9610, 'A Friend of the Family S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bmJkzDE6s0QYBGtpA4i2JLBco0j.jpg'),
(134917, 9610, 'A Friend of the Family S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/448958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bmJkzDE6s0QYBGtpA4i2JLBco0j.jpg'),
(134918, 9610, 'A Friend of the Family S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/456780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bmJkzDE6s0QYBGtpA4i2JLBco0j.jpg'),
(134919, 9610, 'A Friend of the Family S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bmJkzDE6s0QYBGtpA4i2JLBco0j.jpg'),
(134920, 9610, 'A Friend of the Family S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/468347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bmJkzDE6s0QYBGtpA4i2JLBco0j.jpg'),
(134921, 9610, 'A Friend of the Family S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/475381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bmJkzDE6s0QYBGtpA4i2JLBco0j.jpg'),
(134922, 9611, 'O Proximo Grande Chef S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pk1LzdeUCEyWyo0UVQg6vDr1xRQ.jpg'),
(134923, 9611, 'O Proximo Grande Chef S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pk1LzdeUCEyWyo0UVQg6vDr1xRQ.jpg'),
(134924, 9611, 'O Proximo Grande Chef S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pk1LzdeUCEyWyo0UVQg6vDr1xRQ.jpg'),
(134925, 9611, 'O Proximo Grande Chef S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pk1LzdeUCEyWyo0UVQg6vDr1xRQ.jpg'),
(134926, 9611, 'O Proximo Grande Chef S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pk1LzdeUCEyWyo0UVQg6vDr1xRQ.jpg'),
(134927, 9611, 'O Proximo Grande Chef S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pk1LzdeUCEyWyo0UVQg6vDr1xRQ.jpg'),
(134928, 9612, 'Ponto Final S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nAMdrwyLKB85THepyCVTPeEwLSQ.jpg'),
(134929, 9612, 'Ponto Final S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q6RGzf8ZnnkoeSe9DdsdhbV7jEn.jpg'),
(134930, 9612, 'Ponto Final S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bUDltYd6PjsSLbkS3sw7JS4wCvc.jpg'),
(134931, 9612, 'Ponto Final S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Jgzf42YFHgip9oEzGhecDZAtp1.jpg'),
(134932, 9612, 'Ponto Final S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ex3bNAA5ga2ch27XFCrBN1IhWgu.jpg'),
(134933, 9612, 'Ponto Final S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9hcZpCeHh7YKVnEMClEAfCg89zp.jpg'),
(134934, 9612, 'Ponto Final S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/frC9e00DyJyXZh3vWLe84txWDru.jpg'),
(134935, 5955, 'Sempre Fui Eu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261609.mp4', 'http://timg.bdta.pro/images/d8c09210db0bbbde4886137c45d49e7e.jpg'),
(134936, 5955, 'Sempre Fui Eu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261610.mp4', 'http://timg.bdta.pro/images/1cb44103c0f357317f62bab98e5f2dc4.jpg'),
(134937, 5955, 'Sempre Fui Eu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261611.mp4', 'http://timg.bdta.pro/images/7947eb1bdcc45d9a046960bcbd14f75f.jpg'),
(134938, 5955, 'Sempre Fui Eu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261612.mp4', 'http://timg.bdta.pro/images/51555c3c3c4652934b1cfd73bd0d6598.jpg'),
(134939, 5955, 'Sempre Fui Eu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261613.mp4', 'http://timg.bdta.pro/images/204757a0e3299dc4d3304c39e1861375.jpg'),
(134940, 5955, 'Sempre Fui Eu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261614.mp4', 'http://timg.bdta.pro/images/a1e130da16383cce78e528744f775692.jpg'),
(134941, 5955, 'Sempre Fui Eu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261615.mp4', 'http://timg.bdta.pro/images/2345ded61627341ee43bb59943eece66.jpg'),
(134942, 5955, 'Sempre Fui Eu S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261616.mp4', 'http://timg.bdta.pro/images/917e71af264c8762bab6c4e6bd895d6f.jpg'),
(134943, 5955, 'Sempre Fui Eu S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261617.mp4', 'http://timg.bdta.pro/images/2d342206518c6c8d8215ea846979c4de.jpg'),
(134944, 5955, 'Sempre Fui Eu S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261618.mp4', 'http://timg.bdta.pro/images/d09d4dd16240a04ceae6859d57ed73e0.jpg'),
(134945, 9613, 'Sempre Fui Eu S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nkZOD72oJfUiUuQZ4d4ZB9wyzK7.jpg'),
(134946, 9613, 'Sempre Fui Eu S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pFccjv0YSJEKpkDhi1lziSNuvwm.jpg'),
(134947, 9613, 'Sempre Fui Eu S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7MNDuIIdNZeMuN76poeiITEE0qc.jpg'),
(134948, 9613, 'Sempre Fui Eu S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m1kJoh2vOdNTQOxm6MDirlZxmVX.jpg'),
(134949, 9613, 'Sempre Fui Eu S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1iKn07q7rMr4B6CjykdjNOHGptM.jpg'),
(134950, 9613, 'Sempre Fui Eu S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/94u0h5n3wJ1Y54vKeIzNFuUnJrA.jpg'),
(134951, 9613, 'Sempre Fui Eu S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lqxGforowRFWBA6x8vCvssVBAVA.jpg'),
(134952, 9613, 'Sempre Fui Eu S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tbbRamZ9x2JukfkDab4rLSKmn5E.jpg'),
(134953, 9614, 'Tribunal Noturno [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9J1itO4KCysRVAXxuyq61mDJEOT.jpg'),
(134954, 9614, 'Tribunal Noturno [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5iqFDcFh8w4A8oSUAmEmhml7Rvs.jpg'),
(134955, 9614, 'Tribunal Noturno [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MJYZgJAJIfcij9mlixo16rzcb5.jpg'),
(134956, 9614, 'Tribunal Noturno [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJFLoLi0TrUO1ZMnHOKNIvd1WJH.jpg'),
(134957, 9614, 'Tribunal Noturno [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5UJQaecsvDyqimP0F6vnmQ2ryia.jpg'),
(134958, 9614, 'Tribunal Noturno [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hYbThMUyqvVnGkiu1SUSxizgKRV.jpg'),
(134959, 9614, 'Tribunal Noturno [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ehrQ2CKjGhKGDHTa3hHKW8MtmS.jpg'),
(134960, 9614, 'Tribunal Noturno [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zMsyL0NiAC1wZ4tv1k5G2bQWZQS.jpg'),
(134961, 9614, 'Tribunal Noturno [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2p73JNnx43abcTM2KksgF45CcOH.jpg'),
(134962, 9614, 'Tribunal Noturno [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nWBovD2nwOoNzJMqymljPn52kyy.jpg'),
(134963, 9614, 'Tribunal Noturno [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lotkR0dxHRCLraMjmq8D0YpplsJ.jpg'),
(134964, 9614, 'Tribunal Noturno [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2DnWzjufeXqv22nRkrdxf8iqlqb.jpg'),
(134965, 9614, 'Tribunal Noturno [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2JQgfej9yQRlLLVdmVm6J4EA1Mh.jpg'),
(134966, 9614, 'Tribunal Noturno [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5T2cfpiyM1xDwXdIfhx6d2pdnSo.jpg'),
(134967, 9614, 'Tribunal Noturno [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/268933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fHB2h9PfkJ4rWH7yi1BemaXhBy8.jpg'),
(134968, 9614, 'Tribunal Noturno [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/268934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1uXDAt5MCQPcnhtDLo8M8fzZMaH.jpg'),
(134969, 9615, 'Tribunal Noturno [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4u73zN3nbUnY9vAvcjUyw0G1KTo.jpg'),
(134970, 9615, 'Tribunal Noturno [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z2WUUaRoEd6RAWu51IePzXRtJQO.jpg'),
(134971, 9615, 'Tribunal Noturno [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0roEpy1cdlDxXHtrSZaz0F1X0z.jpg'),
(134972, 9615, 'Tribunal Noturno [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134973, 9615, 'Tribunal Noturno [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134974, 9615, 'Tribunal Noturno [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134975, 9615, 'Tribunal Noturno [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/272471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134976, 9615, 'Tribunal Noturno [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/272472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134977, 9615, 'Tribunal Noturno [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/279374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134978, 9615, 'Tribunal Noturno [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/295131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134979, 9615, 'Tribunal Noturno [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/299710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134980, 9615, 'Tribunal Noturno [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/303767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134981, 9615, 'Tribunal Noturno [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/311952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134982, 9616, 'Tribunal Noturno [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/521810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134983, 9616, 'Tribunal Noturno [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/521811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134984, 9616, 'Tribunal Noturno [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/635925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134985, 9616, 'Tribunal Noturno [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134986, 9616, 'Tribunal Noturno [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/674637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134987, 9616, 'Tribunal Noturno [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/674638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134988, 9616, 'Tribunal Noturno [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/694777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134989, 9616, 'Tribunal Noturno [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/701126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134990, 9616, 'Tribunal Noturno [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/810788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134991, 9616, 'Tribunal Noturno [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/810789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134992, 9616, 'Tribunal Noturno [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/810790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134993, 9616, 'Tribunal Noturno [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/810791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134994, 9616, 'Tribunal Noturno [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/810792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134995, 9616, 'Tribunal Noturno [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/810793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134996, 9616, 'Tribunal Noturno [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/810794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134997, 9616, 'Tribunal Noturno [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/816194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134998, 9616, 'Tribunal Noturno [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/816195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7GD0UPNEitKd0OuUWugA0YV8w7m.jpg'),
(134999, 9617, 'Um Pesadelo Americano S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cybJ5NPkL6qoQhs4fZJyu7AGtlQ.jpg'),
(135000, 9617, 'Um Pesadelo Americano S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7DRHQIYER4NW7xtVMbyxsx3bRE8.jpg'),
(135001, 9617, 'Um Pesadelo Americano S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6wtx5towYADXbdEC5MbEkDIvM9N.jpg'),
(135002, 4808, 'Zorro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cn63H7mAOx0un5ReIRCo6o7JBlf.jpg'),
(135003, 4808, 'Zorro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iwJtWEWD6NZVL31jAdOBQaLC06B.jpg'),
(135004, 4808, 'Zorro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2gGphCnVRqwB2vVsG8f3e3kwYIS.jpg'),
(135005, 4808, 'Zorro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jMlP56wtA1u0RErQTsCqOSzf8Wz.jpg'),
(135006, 4808, 'Zorro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pz1UUZP7tv8Ys0tr34hGBClfjY0.jpg'),
(135007, 4808, 'Zorro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AtoDFYcQriqpn6xYDTuGXwt10Zp.jpg'),
(135008, 4808, 'Zorro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cB1QzxJHhViF0xC1sYNeFxuhVCn.jpg'),
(135009, 4808, 'Zorro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qPYVzKcW1aMZ2Olao2Rnt3rveUV.jpg'),
(135010, 4808, 'Zorro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jycgzuz8sC7qgPBDveBhiddne1R.jpg'),
(135011, 4808, 'Zorro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iz4qEV76h6FtDURTIkB5xdYqniC.jpg'),
(135012, 9618, '90 Dias Para Casar A Ultima Chance S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6CZ4Qzcxa3bUFvQjw64G4sralE.jpg'),
(135013, 9618, '90 Dias Para Casar A Ultima Chance S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135014, 9618, '90 Dias Para Casar A Ultima Chance S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135015, 9618, '90 Dias Para Casar A Ultima Chance S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135016, 9618, '90 Dias Para Casar A Ultima Chance S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135017, 9618, '90 Dias Para Casar A Ultima Chance S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135018, 9618, '90 Dias Para Casar A Ultima Chance S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135019, 9618, '90 Dias Para Casar A Ultima Chance S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/274879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135020, 9618, '90 Dias Para Casar A Ultima Chance S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/274880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135021, 9618, '90 Dias Para Casar A Ultima Chance S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/274881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135022, 9618, '90 Dias Para Casar A Ultima Chance S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/274882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135023, 9618, '90 Dias Para Casar A Ultima Chance S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/288808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135024, 9619, '90 Dias Para Casar A Ultima Chance S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/806808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135025, 9619, '90 Dias Para Casar A Ultima Chance S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/810414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135026, 9619, '90 Dias Para Casar A Ultima Chance S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/810415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135027, 9619, '90 Dias Para Casar A Ultima Chance S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/822879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135028, 9619, '90 Dias Para Casar A Ultima Chance S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/834055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135029, 9619, '90 Dias Para Casar A Ultima Chance S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/842163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135030, 9619, '90 Dias Para Casar A Ultima Chance S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/849119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135031, 9619, '90 Dias Para Casar A Ultima Chance S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/860109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135032, 9619, '90 Dias Para Casar A Ultima Chance S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/862317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135033, 9619, '90 Dias Para Casar A Ultima Chance S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/868536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135034, 9619, '90 Dias Para Casar A Ultima Chance S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/872812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135035, 9619, '90 Dias Para Casar A Ultima Chance S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/878899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135036, 9619, '90 Dias Para Casar A Ultima Chance S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/879593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135037, 9619, '90 Dias Para Casar A Ultima Chance S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/880077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135038, 9619, '90 Dias Para Casar A Ultima Chance S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/881269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135039, 9619, '90 Dias Para Casar A Ultima Chance S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/882001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135040, 9619, '90 Dias Para Casar A Ultima Chance S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/882002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135041, 9619, '90 Dias Para Casar A Ultima Chance S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/883578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135042, 9619, '90 Dias Para Casar A Ultima Chance S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/884172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vDbN6rxAx85IiDAOieJmIMtQw8V.jpg'),
(135043, 9620, 'A Herdeira S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mEGQvlJtXBcDFp53uCD0xiWTIjh.jpg'),
(135044, 9620, 'A Herdeira S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/riMeWPyPEO4C0Wq4K0tYmxvfLbK.jpg'),
(135045, 9620, 'A Herdeira S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nEtIatMRy3uzghO1TRLBrdcLrxE.jpg'),
(135046, 9620, 'A Herdeira S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yAGMPFvG1ECMQYzkaKN5ilnInle.jpg'),
(135047, 9620, 'A Herdeira S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fEckNopJwNPG1wh0iYVt0dB6Hsn.jpg'),
(135048, 9620, 'A Herdeira S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jaKJP2v3JezEy2JfP7S6ouGHNIO.jpg'),
(135049, 9621, 'Big Nate S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261554.mp4', 'http://timg.bdta.pro/images/28386788cdefca767505b4f99ea25846.jpg'),
(135050, 9621, 'Big Nate S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261555.mp4', 'http://timg.bdta.pro/images/b12f5ed0d07a291411496f49f29b6c4e.jpg'),
(135051, 9621, 'Big Nate S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261556.mp4', 'http://timg.bdta.pro/images/52324c036c4bdb300c58170f29e205eb.jpg'),
(135052, 9621, 'Big Nate S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261557.mp4', 'http://timg.bdta.pro/images/5d4d1d7d00ea27c762c5d30124796219.jpg'),
(135053, 9621, 'Big Nate S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261558.mp4', 'http://timg.bdta.pro/images/745eba014093f17fa15c441e25f33665.jpg'),
(135054, 9621, 'Big Nate S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261559.mp4', 'http://timg.bdta.pro/images/4c9fe521019a2506908939a74cb0556f.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(135055, 9621, 'Big Nate S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261560.mp4', 'http://timg.bdta.pro/images/af78aaca9aa6587f6c33615d33185eab.jpg'),
(135056, 9621, 'Big Nate S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261561.mp4', 'http://timg.bdta.pro/images/61eb8673a25694638a4cb309d850ffd4.jpg'),
(135057, 9621, 'Big Nate S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dN40whgC5iurvheKYW78cetyMRY.jpg'),
(135058, 9621, 'Big Nate S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q4xd1ITyM9kPJH8zglsItQ3rrTO.jpg'),
(135059, 9621, 'Big Nate S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/261564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oR3yE9yqnQNUKjm3HjPR9bpciL1.jpg'),
(135060, 9621, 'Big Nate S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/261565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jmARzJWA3QWrgYeLd723XzRjG19.jpg'),
(135061, 9621, 'Big Nate S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/261566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dT7ZzX2nZ31fhScjziNPeoSBmRx.jpg'),
(135062, 9621, 'Big Nate S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/261567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iwh7s8wV1cur0kJPFIaMBOsMMA.jpg'),
(135063, 9621, 'Big Nate S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/261568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j4GSQtvvXyNIV9wnIMpR590ux9L.jpg'),
(135064, 9621, 'Big Nate S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/261569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hariYhfE3Kvrc1mqDXrQPqzCkVO.jpg'),
(135065, 9621, 'Big Nate S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/261570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b2KQbjq6bhactyAm0Vkh4H3ihrr.jpg'),
(135066, 9621, 'Big Nate S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/261571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lrqUJAwHdM1Vb005OsUuyvosGW7.jpg'),
(135067, 9621, 'Big Nate S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/261572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oQfpz0pWCPrc0ShVcH9RjW6FaOu.jpg'),
(135068, 9621, 'Big Nate S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/261573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dSSnsLZtDjOdtWXknqOmVtpgE5w.jpg'),
(135069, 9621, 'Big Nate S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/261574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q1LQoSptXmyNKXUMLKkKOZ0w8xT.jpg'),
(135070, 9621, 'Big Nate S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/261575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6RweDWHBlvtGqKut67d90eGYWWW.jpg'),
(135071, 9621, 'Big Nate S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/261576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gUxCzj1U4bCZKO9YhILDAeyFPf0.jpg'),
(135072, 9621, 'Big Nate S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/261577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/37pHZkpxZJ5NpQSyi2r5uo38pzP.jpg'),
(135073, 9621, 'Big Nate S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/261578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iMQpJlb2ct2f6SB0mR0gi0Pdfpy.jpg'),
(135074, 9621, 'Big Nate S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/261579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uyt3N1j49aHKscylzeEtpbrXD88.jpg'),
(135075, 9622, 'Big Nate S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mfSANf0HyxpKaA6inxBL3PDghyI.jpg'),
(135076, 9622, 'Big Nate S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vMsvXEn78nNlBYHBBB9XVjRWaMs.jpg'),
(135077, 9622, 'Big Nate S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMjeuyO3UD8iswM6zgD6ZBDCIT7.jpg'),
(135078, 9622, 'Big Nate S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kW3vUqVUpozLwpgScLaoYCmkfkg.jpg'),
(135079, 9622, 'Big Nate S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kPweAUITlJtB54YrIkmORIq28oS.jpg'),
(135080, 9622, 'Big Nate S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vEj0KbATrbVrjeR6uw6YtJvmWCW.jpg'),
(135081, 9622, 'Big Nate S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x7rAmfBXYKRNkZeGd63bkAHDSdC.jpg'),
(135082, 9622, 'Big Nate S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFbHgkOIl9YEKaekdm2U1JCEaCe.jpg'),
(135083, 9622, 'Big Nate S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/261588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4TM142j6Xd3vzbjelvzpANailfO.jpg'),
(135084, 9622, 'Big Nate S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/261589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qofEsE2DsyuCwHcNKoQQdgvfQzk.jpg'),
(135085, 9623, 'Hotel Hazbin S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AjOX7VPEsUYPqEdhBnlYG8g0OI3.jpg'),
(135086, 9623, 'Hotel Hazbin S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/leSQuB2SEr9Lnd0LpFV1kxzK8He.jpg'),
(135087, 9623, 'Hotel Hazbin S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9xdoUagj3AnplIS8VmlHzRmsQoU.jpg'),
(135088, 9623, 'Hotel Hazbin S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2voEbz6aZvWgTo8NTQSfqfZVBs4.jpg'),
(135089, 9623, 'Hotel Hazbin S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bddmwtwuluURlhDaSLqHU849F8I.jpg'),
(135090, 9623, 'Hotel Hazbin S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bddmwtwuluURlhDaSLqHU849F8I.jpg'),
(135091, 9623, 'Hotel Hazbin S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/271160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bddmwtwuluURlhDaSLqHU849F8I.jpg'),
(135092, 9623, 'Hotel Hazbin S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/271161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bddmwtwuluURlhDaSLqHU849F8I.jpg'),
(135093, 9624, 'Hotel Hazbin S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/890686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bddmwtwuluURlhDaSLqHU849F8I.jpg'),
(135094, 9624, 'Hotel Hazbin S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/890687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bddmwtwuluURlhDaSLqHU849F8I.jpg'),
(135095, 9624, 'Hotel Hazbin S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/891859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bddmwtwuluURlhDaSLqHU849F8I.jpg'),
(135096, 9624, 'Hotel Hazbin S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/891860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bddmwtwuluURlhDaSLqHU849F8I.jpg'),
(135097, 9624, 'Hotel Hazbin S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/892442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bddmwtwuluURlhDaSLqHU849F8I.jpg'),
(135098, 9624, 'Hotel Hazbin S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/892443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bddmwtwuluURlhDaSLqHU849F8I.jpg'),
(135099, 9624, 'Hotel Hazbin S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/893353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bddmwtwuluURlhDaSLqHU849F8I.jpg'),
(135100, 9624, 'Hotel Hazbin S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/893354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bddmwtwuluURlhDaSLqHU849F8I.jpg'),
(135101, 9625, 'Kubra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/261546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Q13zr6aa9uFVYtGyXSzpP3kwx4.jpg'),
(135102, 9625, 'Kubra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/261547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sGFBPqe8kpqGsjhOv5m7tsl3LAL.jpg'),
(135103, 9625, 'Kubra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/261548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKPJ19CJgTBTZu26xsw8ryf4t39.jpg'),
(135104, 9625, 'Kubra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/261549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QwH5I7A1zvB2atCtIfhJHm6Ohy.jpg'),
(135105, 9625, 'Kubra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/261550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/59oihlCm7YaoPxm5rhCuGuqVRdz.jpg'),
(135106, 9625, 'Kubra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/261551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gK8k9GD2GKMAxF80EXDxQsOYhb2.jpg'),
(135107, 9625, 'Kubra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/261552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eSdqxJre3TsyPCeSRSX2WOMnxP.jpg'),
(135108, 9625, 'Kubra S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/261553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/EfpiJC5rcawkf8RfQJl8DUOpC0.jpg'),
(135109, 9626, 'Kubra S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/373957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amlpVWYgv1KXiFfZKvY2t0fqvMf.jpg'),
(135110, 9626, 'Kubra S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/373958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amlpVWYgv1KXiFfZKvY2t0fqvMf.jpg'),
(135111, 9626, 'Kubra S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/373959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amlpVWYgv1KXiFfZKvY2t0fqvMf.jpg'),
(135112, 9626, 'Kubra S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/373960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amlpVWYgv1KXiFfZKvY2t0fqvMf.jpg'),
(135113, 9626, 'Kubra S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/373961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amlpVWYgv1KXiFfZKvY2t0fqvMf.jpg'),
(135114, 9626, 'Kubra S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/373962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amlpVWYgv1KXiFfZKvY2t0fqvMf.jpg'),
(135115, 9626, 'Kubra S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/373963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amlpVWYgv1KXiFfZKvY2t0fqvMf.jpg'),
(135116, 9626, 'Kubra S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/373964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/amlpVWYgv1KXiFfZKvY2t0fqvMf.jpg'),
(135117, 9627, 'Perseguicoes em Alta Velocidade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iUgSvnsNOjkjcGKfzO2iSKrwRQF.jpg'),
(135118, 9627, 'Perseguicoes em Alta Velocidade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iUgSvnsNOjkjcGKfzO2iSKrwRQF.jpg'),
(135119, 9627, 'Perseguicoes em Alta Velocidade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iUgSvnsNOjkjcGKfzO2iSKrwRQF.jpg'),
(135120, 9627, 'Perseguicoes em Alta Velocidade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/270907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iUgSvnsNOjkjcGKfzO2iSKrwRQF.jpg'),
(135121, 9627, 'Perseguicoes em Alta Velocidade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/272693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iUgSvnsNOjkjcGKfzO2iSKrwRQF.jpg'),
(135122, 9627, 'Perseguicoes em Alta Velocidade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/277619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iUgSvnsNOjkjcGKfzO2iSKrwRQF.jpg'),
(135123, 9628, 'Perseguicoes em Alta Velocidade S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/741365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iUgSvnsNOjkjcGKfzO2iSKrwRQF.jpg'),
(135124, 9628, 'Perseguicoes em Alta Velocidade S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/741366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iUgSvnsNOjkjcGKfzO2iSKrwRQF.jpg'),
(135125, 9628, 'Perseguicoes em Alta Velocidade S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/741367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iUgSvnsNOjkjcGKfzO2iSKrwRQF.jpg'),
(135126, 9628, 'Perseguicoes em Alta Velocidade S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/741368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iUgSvnsNOjkjcGKfzO2iSKrwRQF.jpg'),
(135127, 9628, 'Perseguicoes em Alta Velocidade S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/741369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iUgSvnsNOjkjcGKfzO2iSKrwRQF.jpg'),
(135128, 9628, 'Perseguicoes em Alta Velocidade S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/741370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iUgSvnsNOjkjcGKfzO2iSKrwRQF.jpg'),
(135129, 9628, 'Perseguicoes em Alta Velocidade S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/741371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iUgSvnsNOjkjcGKfzO2iSKrwRQF.jpg'),
(135130, 9628, 'Perseguicoes em Alta Velocidade S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/741372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iUgSvnsNOjkjcGKfzO2iSKrwRQF.jpg'),
(135131, 9629, 'A Mulher na Parede S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hv1GFxc6gFItFbmWrsJB7BCoat7.jpg'),
(135132, 9629, 'A Mulher na Parede S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z6rvcCVKM6ho5u7Dk68qeYh9zlp.jpg'),
(135133, 9629, 'A Mulher na Parede S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z6rvcCVKM6ho5u7Dk68qeYh9zlp.jpg'),
(135134, 9629, 'A Mulher na Parede S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/271780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z6rvcCVKM6ho5u7Dk68qeYh9zlp.jpg'),
(135135, 9629, 'A Mulher na Parede S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/276968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z6rvcCVKM6ho5u7Dk68qeYh9zlp.jpg'),
(135136, 9629, 'A Mulher na Parede S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/281573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z6rvcCVKM6ho5u7Dk68qeYh9zlp.jpg'),
(135137, 9630, 'Forca Policial Indiana S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9hzvQFES7IKFavvQ4HPO590y6vX.jpg'),
(135138, 9630, 'Forca Policial Indiana S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t4bhPpW17VtwffGahatgp4qWtVN.jpg'),
(135139, 9630, 'Forca Policial Indiana S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7N4BbjPP2kiZFBE22tS7hSxEFXu.jpg'),
(135140, 9630, 'Forca Policial Indiana S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xzrpeSRkDZ5OoMbGosFUKW9opTk.jpg'),
(135141, 9630, 'Forca Policial Indiana S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e9JcRjzs6qiMyGQgtzHxUrEVKWJ.jpg'),
(135142, 9630, 'Forca Policial Indiana S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13IcHNiQTZBf7O6FqTBME5ADJVC.jpg'),
(135143, 9630, 'Forca Policial Indiana S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lRth1NtQP8pWNgj1EHcndm98waA.jpg'),
(135144, 9631, '90 Dias Para Casar Reino Unido S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3kafymNOnZne8oUlTNGv8LSG1RK.jpg'),
(135145, 9631, '90 Dias Para Casar Reino Unido S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vwcjXGJ2UaK2A5pc1rzJI2bqYLl.jpg'),
(135146, 9631, '90 Dias Para Casar Reino Unido S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ey4c1JzWjHwzw0NVqWtZGiXGf5o.jpg'),
(135147, 9631, '90 Dias Para Casar Reino Unido S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aHvUO9wn6WTqM0Gl5DCQ7w29rzu.jpg'),
(135148, 9631, '90 Dias Para Casar Reino Unido S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/605IBhOyYGRIfp4v74XEg0eap0U.jpg'),
(135149, 9631, '90 Dias Para Casar Reino Unido S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhcOvB46WhQf1vmD13FZACfQ5Ks.jpg'),
(135150, 9631, '90 Dias Para Casar Reino Unido S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bjXDfpsaTweVucl5CD4eXcASN5J.jpg'),
(135151, 9631, '90 Dias Para Casar Reino Unido S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c3vqINAuIuxFNd0zyFATmmqXKBQ.jpg'),
(135152, 9631, '90 Dias Para Casar Reino Unido S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eLQhgv4aBZ5PmVOCEkDjBydQaTf.jpg'),
(135153, 9631, '90 Dias Para Casar Reino Unido S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kWtwbBmXKS7o8Wka2cbD7au9FL6.jpg'),
(135154, 9631, '90 Dias Para Casar Reino Unido S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mmAEdTbtwwYXHv7UPRXMNFzHlTf.jpg'),
(135155, 9631, '90 Dias Para Casar Reino Unido S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7AU0FklgOIiozWPuWwvGCVorYi.jpg'),
(135156, 9632, '90 Dias Para Casar Reino Unido S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mdtd5zdNQx4eUIxRyGFi6YUZtFv.jpg'),
(135157, 9632, '90 Dias Para Casar Reino Unido S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ccykpDFG5C2TC0j3Xa6gWMSHtq.jpg'),
(135158, 9632, '90 Dias Para Casar Reino Unido S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/to6OFDp4duKmXSDWDKa3pCgy2dr.jpg'),
(135159, 9632, '90 Dias Para Casar Reino Unido S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cymvqR3IhfEU7ajylcTjgQBrnbu.jpg'),
(135160, 9632, '90 Dias Para Casar Reino Unido S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l0QOesiQcpuAvvZ8nOkTRmi365o.jpg'),
(135161, 9632, '90 Dias Para Casar Reino Unido S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/955nupwhVMfxJ1DnBDDFfFZJcqC.jpg'),
(135162, 9632, '90 Dias Para Casar Reino Unido S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/260722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fXt8NSI8MekhBDBqIP5OhaIKeN4.jpg'),
(135163, 9632, '90 Dias Para Casar Reino Unido S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/260723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gcHSu0LHXxN4emuhZueR7iZRwnq.jpg'),
(135164, 9632, '90 Dias Para Casar Reino Unido S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/260724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXyqYsLISO26hZDIJPttINKlFXS.jpg'),
(135165, 9632, '90 Dias Para Casar Reino Unido S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/260725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yPhubJWP4bKPgGhpKoHtxV8ARA3.jpg'),
(135166, 9632, '90 Dias Para Casar Reino Unido S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/260726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rhHGUfN7j2hQgrzPhTF0lTBp5z1.jpg'),
(135167, 9632, '90 Dias Para Casar Reino Unido S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/260727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3luXhHplmHuhFGQWI9WSExQT4pU.jpg'),
(135168, 9633, '90 Dias Para Casar Reino Unido S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/632607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135169, 9633, '90 Dias Para Casar Reino Unido S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/468522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135170, 9633, '90 Dias Para Casar Reino Unido S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/468523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135171, 9633, '90 Dias Para Casar Reino Unido S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/468524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135172, 9633, '90 Dias Para Casar Reino Unido S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/468525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135173, 9633, '90 Dias Para Casar Reino Unido S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/475516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135174, 9633, '90 Dias Para Casar Reino Unido S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/632614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135175, 9633, '90 Dias Para Casar Reino Unido S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135176, 9633, '90 Dias Para Casar Reino Unido S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/494290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135177, 9633, '90 Dias Para Casar Reino Unido S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/497542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135178, 9633, '90 Dias Para Casar Reino Unido S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/632619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135179, 9633, '90 Dias Para Casar Reino Unido S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/632620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135180, 9633, '90 Dias Para Casar Reino Unido S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/516531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135181, 9634, '90 Dias Para Casar Reino Unido S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/887649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135182, 9634, '90 Dias Para Casar Reino Unido S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/887764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135183, 9634, '90 Dias Para Casar Reino Unido S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/888264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135184, 9634, '90 Dias Para Casar Reino Unido S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/889126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135185, 9634, '90 Dias Para Casar Reino Unido S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/890164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135186, 9634, '90 Dias Para Casar Reino Unido S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/891084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135187, 9634, '90 Dias Para Casar Reino Unido S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/892245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135188, 9634, '90 Dias Para Casar Reino Unido S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/892683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135189, 9634, '90 Dias Para Casar Reino Unido S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/893408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135190, 9634, '90 Dias Para Casar Reino Unido S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/893616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135191, 9634, '90 Dias Para Casar Reino Unido S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/894947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135192, 9634, '90 Dias Para Casar Reino Unido S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/894948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135193, 9634, '90 Dias Para Casar Reino Unido S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/894949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iqGIgL0k4GdwqXY9KyQJZ79uMxf.jpg'),
(135194, 9635, 'Goulag Uma Historia dos Campos de Concentracao Sovieticos [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hu6LMAmLdcGb5Gr0sSoUWX8oZj1.jpg'),
(135195, 9635, 'Goulag Uma Historia dos Campos de Concentracao Sovieticos [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Enehkh7ipPBVoSrT05K7Vm1GH2.jpg'),
(135196, 9636, 'Pesadelo na Cozinha com Gordon Ramsey S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10XpD4aEOExWcOg9bxCA28NNsMQ.jpg'),
(135197, 9636, 'Pesadelo na Cozinha com Gordon Ramsey S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10XpD4aEOExWcOg9bxCA28NNsMQ.jpg'),
(135198, 9636, 'Pesadelo na Cozinha com Gordon Ramsey S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10XpD4aEOExWcOg9bxCA28NNsMQ.jpg'),
(135199, 9636, 'Pesadelo na Cozinha com Gordon Ramsey S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10XpD4aEOExWcOg9bxCA28NNsMQ.jpg'),
(135200, 9636, 'Pesadelo na Cozinha com Gordon Ramsey S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10XpD4aEOExWcOg9bxCA28NNsMQ.jpg'),
(135201, 9636, 'Pesadelo na Cozinha com Gordon Ramsey S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/270993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10XpD4aEOExWcOg9bxCA28NNsMQ.jpg'),
(135202, 9636, 'Pesadelo na Cozinha com Gordon Ramsey S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10XpD4aEOExWcOg9bxCA28NNsMQ.jpg'),
(135203, 9636, 'Pesadelo na Cozinha com Gordon Ramsey S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/279606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10XpD4aEOExWcOg9bxCA28NNsMQ.jpg'),
(135204, 9636, 'Pesadelo na Cozinha com Gordon Ramsey S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/285907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10XpD4aEOExWcOg9bxCA28NNsMQ.jpg'),
(135205, 9636, 'Pesadelo na Cozinha com Gordon Ramsey S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/299152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10XpD4aEOExWcOg9bxCA28NNsMQ.jpg'),
(135206, 9637, 'Pesadelo na Cozinha com Gordon Ramsey S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/886065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10XpD4aEOExWcOg9bxCA28NNsMQ.jpg'),
(135207, 9637, 'Pesadelo na Cozinha com Gordon Ramsey S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/886066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10XpD4aEOExWcOg9bxCA28NNsMQ.jpg'),
(135208, 9637, 'Pesadelo na Cozinha com Gordon Ramsey S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/886067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10XpD4aEOExWcOg9bxCA28NNsMQ.jpg'),
(135209, 9637, 'Pesadelo na Cozinha com Gordon Ramsey S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/886068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10XpD4aEOExWcOg9bxCA28NNsMQ.jpg'),
(135210, 9637, 'Pesadelo na Cozinha com Gordon Ramsey S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/886069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10XpD4aEOExWcOg9bxCA28NNsMQ.jpg'),
(135211, 9637, 'Pesadelo na Cozinha com Gordon Ramsey S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/886070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/10XpD4aEOExWcOg9bxCA28NNsMQ.jpg'),
(135212, 9638, 'Quilos Mortais Italia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/11oNGnLEy5blDNXJjFmKsmNI8o9.jpg'),
(135213, 9638, 'Quilos Mortais Italia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/11oNGnLEy5blDNXJjFmKsmNI8o9.jpg'),
(135214, 9638, 'Quilos Mortais Italia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/11oNGnLEy5blDNXJjFmKsmNI8o9.jpg'),
(135215, 9638, 'Quilos Mortais Italia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/11oNGnLEy5blDNXJjFmKsmNI8o9.jpg'),
(135216, 9638, 'Quilos Mortais Italia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/11oNGnLEy5blDNXJjFmKsmNI8o9.jpg'),
(135217, 9638, 'Quilos Mortais Italia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/11oNGnLEy5blDNXJjFmKsmNI8o9.jpg'),
(135218, 9639, 'Quilos Mortais Italia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/509292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/11oNGnLEy5blDNXJjFmKsmNI8o9.jpg'),
(135219, 9639, 'Quilos Mortais Italia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/509293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/11oNGnLEy5blDNXJjFmKsmNI8o9.jpg'),
(135220, 9639, 'Quilos Mortais Italia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/509294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/11oNGnLEy5blDNXJjFmKsmNI8o9.jpg'),
(135221, 9639, 'Quilos Mortais Italia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/509295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/11oNGnLEy5blDNXJjFmKsmNI8o9.jpg'),
(135222, 9639, 'Quilos Mortais Italia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/509296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/11oNGnLEy5blDNXJjFmKsmNI8o9.jpg'),
(135223, 9639, 'Quilos Mortais Italia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/509297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/11oNGnLEy5blDNXJjFmKsmNI8o9.jpg'),
(135224, 9639, 'Quilos Mortais Italia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/509298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/11oNGnLEy5blDNXJjFmKsmNI8o9.jpg'),
(135225, 9639, 'Quilos Mortais Italia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/509299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/11oNGnLEy5blDNXJjFmKsmNI8o9.jpg'),
(135226, 9639, 'Quilos Mortais Italia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/509300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/11oNGnLEy5blDNXJjFmKsmNI8o9.jpg'),
(135227, 9640, 'Quilos Mortais Italia S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/509302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/11oNGnLEy5blDNXJjFmKsmNI8o9.jpg'),
(135228, 9640, 'Quilos Mortais Italia S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/509303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/11oNGnLEy5blDNXJjFmKsmNI8o9.jpg'),
(135229, 9640, 'Quilos Mortais Italia S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/509304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/11oNGnLEy5blDNXJjFmKsmNI8o9.jpg'),
(135230, 9640, 'Quilos Mortais Italia S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/509305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/11oNGnLEy5blDNXJjFmKsmNI8o9.jpg'),
(135231, 9640, 'Quilos Mortais Italia S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/509306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/11oNGnLEy5blDNXJjFmKsmNI8o9.jpg'),
(135232, 9641, 'Sobre Viver S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6TOcbePt7D4QQsDU2eW3saCgpfn.jpg'),
(135233, 9641, 'Sobre Viver S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/260691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6TOcbePt7D4QQsDU2eW3saCgpfn.jpg'),
(135234, 9641, 'Sobre Viver S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/260692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6TOcbePt7D4QQsDU2eW3saCgpfn.jpg'),
(135235, 9641, 'Sobre Viver S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/260693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6TOcbePt7D4QQsDU2eW3saCgpfn.jpg'),
(135236, 9641, 'Sobre Viver S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/260694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6TOcbePt7D4QQsDU2eW3saCgpfn.jpg'),
(135237, 9641, 'Sobre Viver S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/260695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6TOcbePt7D4QQsDU2eW3saCgpfn.jpg'),
(135238, 9642, 'Uma Loja Para Assassinos [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1hk530lm0hGK2Rcq5byyhcYpneH.jpg'),
(135239, 9642, 'Uma Loja Para Assassinos [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mHAgYtfgpIhleENgK8rmLVqYf78.jpg'),
(135240, 9642, 'Uma Loja Para Assassinos [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dS35iIwx5wQlCpX5KxY9tuNd6nW.jpg'),
(135241, 9642, 'Uma Loja Para Assassinos [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dS35iIwx5wQlCpX5KxY9tuNd6nW.jpg'),
(135242, 9642, 'Uma Loja Para Assassinos [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dS35iIwx5wQlCpX5KxY9tuNd6nW.jpg'),
(135243, 9642, 'Uma Loja Para Assassinos [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dS35iIwx5wQlCpX5KxY9tuNd6nW.jpg'),
(135244, 9642, 'Uma Loja Para Assassinos [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/272434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dS35iIwx5wQlCpX5KxY9tuNd6nW.jpg'),
(135245, 9642, 'Uma Loja Para Assassinos [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/272435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dS35iIwx5wQlCpX5KxY9tuNd6nW.jpg'),
(135246, 9643, 'Villainess Level 99 I May Be the Hidden Boss But Im Not the Demon Lord [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5sedICx0GSGU9ZlpcOfSy8tRMhj.jpg'),
(135247, 9643, 'Villainess Level 99 I May Be the Hidden Boss But Im Not the Demon Lord [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y5WoU4nt84Zeo1imiD8EQHA5Sie.jpg'),
(135248, 9643, 'Villainess Level 99 I May Be the Hidden Boss But Im Not the Demon Lord [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t9IZtBFBGT9ldmvBlhXJZMjPejH.jpg'),
(135249, 9643, 'Villainess Level 99 I May Be the Hidden Boss But Im Not the Demon Lord [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t9IZtBFBGT9ldmvBlhXJZMjPejH.jpg'),
(135250, 9643, 'Villainess Level 99 I May Be the Hidden Boss But Im Not the Demon Lord [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/272426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t9IZtBFBGT9ldmvBlhXJZMjPejH.jpg'),
(135251, 9643, 'Villainess Level 99 I May Be the Hidden Boss But Im Not the Demon Lord [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/272427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t9IZtBFBGT9ldmvBlhXJZMjPejH.jpg'),
(135252, 9643, 'Villainess Level 99 I May Be the Hidden Boss But Im Not the Demon Lord [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/277405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t9IZtBFBGT9ldmvBlhXJZMjPejH.jpg'),
(135253, 9643, 'Villainess Level 99 I May Be the Hidden Boss But Im Not the Demon Lord [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/288134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t9IZtBFBGT9ldmvBlhXJZMjPejH.jpg'),
(135254, 9643, 'Villainess Level 99 I May Be the Hidden Boss But Im Not the Demon Lord [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/293935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t9IZtBFBGT9ldmvBlhXJZMjPejH.jpg'),
(135255, 9643, 'Villainess Level 99 I May Be the Hidden Boss But Im Not the Demon Lord [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/299683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t9IZtBFBGT9ldmvBlhXJZMjPejH.jpg'),
(135256, 9643, 'Villainess Level 99 I May Be the Hidden Boss But Im Not the Demon Lord [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/303739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t9IZtBFBGT9ldmvBlhXJZMjPejH.jpg'),
(135257, 9643, 'Villainess Level 99 I May Be the Hidden Boss But Im Not the Demon Lord [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/309516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t9IZtBFBGT9ldmvBlhXJZMjPejH.jpg'),
(135258, 9644, 'Solo Leveling S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/260689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyjphDUt1vrlckpvfPd0TekuqMm.jpg'),
(135259, 9644, 'Solo Leveling S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/270812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135260, 9644, 'Solo Leveling S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/270813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135261, 9644, 'Solo Leveling S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/270814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135262, 9644, 'Solo Leveling S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/275043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135263, 9644, 'Solo Leveling S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/279465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135264, 9644, 'Solo Leveling S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/285753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135265, 9644, 'Solo Leveling S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/301002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135266, 9644, 'Solo Leveling S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/307174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135267, 9644, 'Solo Leveling S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/313539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135268, 9644, 'Solo Leveling S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/327201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135269, 9644, 'Solo Leveling S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/332146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135270, 9645, 'Solo Leveling S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/674699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135271, 9645, 'Solo Leveling S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/694683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135272, 9645, 'Solo Leveling S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/688289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135273, 9645, 'Solo Leveling S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/697400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135274, 9645, 'Solo Leveling S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/703981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135275, 9645, 'Solo Leveling S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/715907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135276, 9645, 'Solo Leveling S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/728446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135277, 9645, 'Solo Leveling S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/737209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135278, 9645, 'Solo Leveling S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/750180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135279, 9645, 'Solo Leveling S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/757942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135280, 9645, 'Solo Leveling S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/763327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135281, 9645, 'Solo Leveling S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/771718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135282, 9645, 'Solo Leveling S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/783878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/451lpwzbSKClDUHmKxOcBboBf7E.jpg'),
(135283, 9646, 'A Friend of the Family [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5wBo5iuWSbfGWzRfxrzWYKNjaKU.jpg'),
(135284, 9646, 'A Friend of the Family [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qaT9BmbW0GT7mSnVsBTxqE2hGLI.jpg'),
(135285, 9646, 'A Friend of the Family [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7aHokVfSQQeW9Ce3Q9aaWSDPGoV.jpg'),
(135286, 9646, 'A Friend of the Family [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/thLlPYY2CLW5ZLT5syt9iCFe9fB.jpg'),
(135287, 9646, 'A Friend of the Family [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dvfy3DAMopnDnkRCZX8S3p3k82O.jpg'),
(135288, 9646, 'A Friend of the Family [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jkdlNlqMfopnelQXqHybNGUFcNz.jpg'),
(135289, 9646, 'A Friend of the Family [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ctN6bOzTlX0M2mCLtHh0Xco7hQJ.jpg'),
(135290, 9646, 'A Friend of the Family [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9cF3Uzcnn4s5OGEBsuc2hTH1p9Y.jpg'),
(135291, 9646, 'A Friend of the Family [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Jtw10S8AGkiCn7ZGItOQEf57z9.jpg'),
(135292, 9647, 'A Tormenta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dlFLBEQoV0ptRkKOSmB9yRvnvh4.jpg'),
(135293, 9647, 'A Tormenta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qhjMVgI85h5195YCHhHoffH8r2X.jpg'),
(135294, 9647, 'A Tormenta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e5wPZE8JklDw88I30L9alIOw2LC.jpg'),
(135295, 9647, 'A Tormenta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e5wPZE8JklDw88I30L9alIOw2LC.jpg'),
(135296, 9647, 'A Tormenta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e5wPZE8JklDw88I30L9alIOw2LC.jpg'),
(135297, 9647, 'A Tormenta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e5wPZE8JklDw88I30L9alIOw2LC.jpg'),
(135298, 9648, 'Anjos da Guarda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5UKzJwxE07mCKq04pO8SSEvFvy.jpg'),
(135299, 9648, 'Anjos da Guarda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5UKzJwxE07mCKq04pO8SSEvFvy.jpg'),
(135300, 9648, 'Anjos da Guarda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5UKzJwxE07mCKq04pO8SSEvFvy.jpg'),
(135301, 9648, 'Anjos da Guarda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5UKzJwxE07mCKq04pO8SSEvFvy.jpg'),
(135302, 9648, 'Anjos da Guarda S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5UKzJwxE07mCKq04pO8SSEvFvy.jpg'),
(135303, 9648, 'Anjos da Guarda S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5UKzJwxE07mCKq04pO8SSEvFvy.jpg'),
(135304, 9648, 'Anjos da Guarda S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5UKzJwxE07mCKq04pO8SSEvFvy.jpg'),
(135305, 9648, 'Anjos da Guarda S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5UKzJwxE07mCKq04pO8SSEvFvy.jpg'),
(135306, 9648, 'Anjos da Guarda S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5UKzJwxE07mCKq04pO8SSEvFvy.jpg'),
(135307, 9648, 'Anjos da Guarda S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5UKzJwxE07mCKq04pO8SSEvFvy.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(135308, 9648, 'Anjos da Guarda S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5UKzJwxE07mCKq04pO8SSEvFvy.jpg'),
(135309, 9648, 'Anjos da Guarda S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5UKzJwxE07mCKq04pO8SSEvFvy.jpg'),
(135310, 9648, 'Anjos da Guarda S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/264573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5UKzJwxE07mCKq04pO8SSEvFvy.jpg'),
(135311, 9648, 'Anjos da Guarda S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/264574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5UKzJwxE07mCKq04pO8SSEvFvy.jpg'),
(135312, 9648, 'Anjos da Guarda S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/264575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5UKzJwxE07mCKq04pO8SSEvFvy.jpg'),
(135313, 9648, 'Anjos da Guarda S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/264576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5UKzJwxE07mCKq04pO8SSEvFvy.jpg'),
(135314, 9649, 'Big Brother Brasil A Eliminacao S24 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zaMh2Pfnzwx20QBwrBP2LKIjTvM.jpg'),
(135315, 9649, 'Big Brother Brasil A Eliminacao S24 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zaMh2Pfnzwx20QBwrBP2LKIjTvM.jpg'),
(135316, 9649, 'Big Brother Brasil A Eliminacao S24 E03', 'http://sinalprivado.info:80/series/1533784/1533784/281551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zaMh2Pfnzwx20QBwrBP2LKIjTvM.jpg'),
(135317, 9649, 'Big Brother Brasil A Eliminacao S24 E04', 'http://sinalprivado.info:80/series/1533784/1533784/281552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zaMh2Pfnzwx20QBwrBP2LKIjTvM.jpg'),
(135318, 9649, 'Big Brother Brasil A Eliminacao S24 E05', 'http://sinalprivado.info:80/series/1533784/1533784/281553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zaMh2Pfnzwx20QBwrBP2LKIjTvM.jpg'),
(135319, 9649, 'Big Brother Brasil A Eliminacao S24 E06', 'http://sinalprivado.info:80/series/1533784/1533784/281554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zaMh2Pfnzwx20QBwrBP2LKIjTvM.jpg'),
(135320, 9649, 'Big Brother Brasil A Eliminacao S24 E07', 'http://sinalprivado.info:80/series/1533784/1533784/281555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zaMh2Pfnzwx20QBwrBP2LKIjTvM.jpg'),
(135321, 9649, 'Big Brother Brasil A Eliminacao S24 E08', 'http://sinalprivado.info:80/series/1533784/1533784/330800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zaMh2Pfnzwx20QBwrBP2LKIjTvM.jpg'),
(135322, 9649, 'Big Brother Brasil A Eliminacao S24 E09', 'http://sinalprivado.info:80/series/1533784/1533784/330801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zaMh2Pfnzwx20QBwrBP2LKIjTvM.jpg'),
(135323, 9649, 'Big Brother Brasil A Eliminacao S24 E10', 'http://sinalprivado.info:80/series/1533784/1533784/330802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zaMh2Pfnzwx20QBwrBP2LKIjTvM.jpg'),
(135324, 9649, 'Big Brother Brasil A Eliminacao S24 E11', 'http://sinalprivado.info:80/series/1533784/1533784/330803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zaMh2Pfnzwx20QBwrBP2LKIjTvM.jpg'),
(135325, 9649, 'Big Brother Brasil A Eliminacao S24 E12', 'http://sinalprivado.info:80/series/1533784/1533784/330804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zaMh2Pfnzwx20QBwrBP2LKIjTvM.jpg'),
(135326, 9649, 'Big Brother Brasil A Eliminacao S24 E13', 'http://sinalprivado.info:80/series/1533784/1533784/330805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zaMh2Pfnzwx20QBwrBP2LKIjTvM.jpg'),
(135327, 9649, 'Big Brother Brasil A Eliminacao S24 E14', 'http://sinalprivado.info:80/series/1533784/1533784/330806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zaMh2Pfnzwx20QBwrBP2LKIjTvM.jpg'),
(135328, 9649, 'Big Brother Brasil A Eliminacao S24 E15', 'http://sinalprivado.info:80/series/1533784/1533784/330807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zaMh2Pfnzwx20QBwrBP2LKIjTvM.jpg'),
(135329, 9649, 'Big Brother Brasil A Eliminacao S24 E16', 'http://sinalprivado.info:80/series/1533784/1533784/330808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zaMh2Pfnzwx20QBwrBP2LKIjTvM.jpg'),
(135330, 9650, 'Briarpatch S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qXdcIVPBqzgyxsbjOi5SHvwBYNE.jpg'),
(135331, 9650, 'Briarpatch S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fplGS4qIvxBJtgsUqB0GHILFZCW.jpg'),
(135332, 9650, 'Briarpatch S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/330758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3DwOQCVO6p87SlHKFwjwMmVvkcU.jpg'),
(135333, 9650, 'Briarpatch S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/330759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3DwOQCVO6p87SlHKFwjwMmVvkcU.jpg'),
(135334, 9650, 'Briarpatch S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/338979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3DwOQCVO6p87SlHKFwjwMmVvkcU.jpg'),
(135335, 9650, 'Briarpatch S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/341827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3DwOQCVO6p87SlHKFwjwMmVvkcU.jpg'),
(135336, 9650, 'Briarpatch S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/350162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3DwOQCVO6p87SlHKFwjwMmVvkcU.jpg'),
(135337, 9650, 'Briarpatch S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/350163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3DwOQCVO6p87SlHKFwjwMmVvkcU.jpg'),
(135338, 9650, 'Briarpatch S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/360343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3DwOQCVO6p87SlHKFwjwMmVvkcU.jpg'),
(135339, 9650, 'Briarpatch S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/369690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3DwOQCVO6p87SlHKFwjwMmVvkcU.jpg'),
(135340, 9651, 'Conversa com Bial S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135341, 9651, 'Conversa com Bial S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135342, 9651, 'Conversa com Bial S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135343, 9651, 'Conversa com Bial S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135344, 9651, 'Conversa com Bial S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135345, 9651, 'Conversa com Bial S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135346, 9651, 'Conversa com Bial S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135347, 9651, 'Conversa com Bial S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135348, 9651, 'Conversa com Bial S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135349, 9651, 'Conversa com Bial S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135350, 9651, 'Conversa com Bial S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135351, 9651, 'Conversa com Bial S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135352, 9651, 'Conversa com Bial S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/264380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135353, 9651, 'Conversa com Bial S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/264381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135354, 9651, 'Conversa com Bial S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/264382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135355, 9651, 'Conversa com Bial S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/264383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135356, 9651, 'Conversa com Bial S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/264384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135357, 9651, 'Conversa com Bial S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/264385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135358, 9651, 'Conversa com Bial S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/264386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135359, 9651, 'Conversa com Bial S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/264387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135360, 9651, 'Conversa com Bial S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/264388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135361, 9651, 'Conversa com Bial S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/264389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135362, 9651, 'Conversa com Bial S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/264390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135363, 9651, 'Conversa com Bial S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/264391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135364, 9651, 'Conversa com Bial S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/264392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135365, 9651, 'Conversa com Bial S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/264393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135366, 9651, 'Conversa com Bial S07 E27', 'http://sinalprivado.info:80/series/1533784/1533784/264394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135367, 9651, 'Conversa com Bial S07 E28', 'http://sinalprivado.info:80/series/1533784/1533784/264395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135368, 9651, 'Conversa com Bial S07 E29', 'http://sinalprivado.info:80/series/1533784/1533784/264396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135369, 9651, 'Conversa com Bial S07 E30', 'http://sinalprivado.info:80/series/1533784/1533784/264397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135370, 9651, 'Conversa com Bial S07 E31', 'http://sinalprivado.info:80/series/1533784/1533784/264398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135371, 9651, 'Conversa com Bial S07 E32', 'http://sinalprivado.info:80/series/1533784/1533784/264399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135372, 9651, 'Conversa com Bial S07 E33', 'http://sinalprivado.info:80/series/1533784/1533784/264400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135373, 9651, 'Conversa com Bial S07 E34', 'http://sinalprivado.info:80/series/1533784/1533784/264401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135374, 9651, 'Conversa com Bial S07 E35', 'http://sinalprivado.info:80/series/1533784/1533784/264402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135375, 9651, 'Conversa com Bial S07 E36', 'http://sinalprivado.info:80/series/1533784/1533784/264403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135376, 9651, 'Conversa com Bial S07 E37', 'http://sinalprivado.info:80/series/1533784/1533784/264404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135377, 9651, 'Conversa com Bial S07 E38', 'http://sinalprivado.info:80/series/1533784/1533784/264405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135378, 9651, 'Conversa com Bial S07 E39', 'http://sinalprivado.info:80/series/1533784/1533784/264406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135379, 9651, 'Conversa com Bial S07 E40', 'http://sinalprivado.info:80/series/1533784/1533784/264407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135380, 9651, 'Conversa com Bial S07 E41', 'http://sinalprivado.info:80/series/1533784/1533784/264408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135381, 9651, 'Conversa com Bial S07 E42', 'http://sinalprivado.info:80/series/1533784/1533784/264409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135382, 9651, 'Conversa com Bial S07 E43', 'http://sinalprivado.info:80/series/1533784/1533784/264410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135383, 9651, 'Conversa com Bial S07 E44', 'http://sinalprivado.info:80/series/1533784/1533784/264411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135384, 9651, 'Conversa com Bial S07 E45', 'http://sinalprivado.info:80/series/1533784/1533784/264412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135385, 9651, 'Conversa com Bial S07 E46', 'http://sinalprivado.info:80/series/1533784/1533784/264413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135386, 9651, 'Conversa com Bial S07 E47', 'http://sinalprivado.info:80/series/1533784/1533784/264414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135387, 9651, 'Conversa com Bial S07 E48', 'http://sinalprivado.info:80/series/1533784/1533784/264415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135388, 9651, 'Conversa com Bial S07 E49', 'http://sinalprivado.info:80/series/1533784/1533784/264416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135389, 9651, 'Conversa com Bial S07 E50', 'http://sinalprivado.info:80/series/1533784/1533784/264417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135390, 9651, 'Conversa com Bial S07 E51', 'http://sinalprivado.info:80/series/1533784/1533784/264418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135391, 9651, 'Conversa com Bial S07 E52', 'http://sinalprivado.info:80/series/1533784/1533784/264419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135392, 9651, 'Conversa com Bial S07 E53', 'http://sinalprivado.info:80/series/1533784/1533784/264420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135393, 9651, 'Conversa com Bial S07 E54', 'http://sinalprivado.info:80/series/1533784/1533784/264421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135394, 9651, 'Conversa com Bial S07 E55', 'http://sinalprivado.info:80/series/1533784/1533784/264422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135395, 9651, 'Conversa com Bial S07 E56', 'http://sinalprivado.info:80/series/1533784/1533784/264423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135396, 9651, 'Conversa com Bial S07 E57', 'http://sinalprivado.info:80/series/1533784/1533784/264424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135397, 9651, 'Conversa com Bial S07 E58', 'http://sinalprivado.info:80/series/1533784/1533784/264425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135398, 9651, 'Conversa com Bial S07 E59', 'http://sinalprivado.info:80/series/1533784/1533784/264426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135399, 9651, 'Conversa com Bial S07 E60', 'http://sinalprivado.info:80/series/1533784/1533784/264427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135400, 9651, 'Conversa com Bial S07 E61', 'http://sinalprivado.info:80/series/1533784/1533784/264428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135401, 9651, 'Conversa com Bial S07 E62', 'http://sinalprivado.info:80/series/1533784/1533784/264429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135402, 9651, 'Conversa com Bial S07 E63', 'http://sinalprivado.info:80/series/1533784/1533784/264430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135403, 9651, 'Conversa com Bial S07 E64', 'http://sinalprivado.info:80/series/1533784/1533784/264431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135404, 9651, 'Conversa com Bial S07 E65', 'http://sinalprivado.info:80/series/1533784/1533784/264432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135405, 9651, 'Conversa com Bial S07 E66', 'http://sinalprivado.info:80/series/1533784/1533784/264433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135406, 9651, 'Conversa com Bial S07 E67', 'http://sinalprivado.info:80/series/1533784/1533784/264434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135407, 9651, 'Conversa com Bial S07 E68', 'http://sinalprivado.info:80/series/1533784/1533784/264435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135408, 9651, 'Conversa com Bial S07 E69', 'http://sinalprivado.info:80/series/1533784/1533784/264436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135409, 9651, 'Conversa com Bial S07 E70', 'http://sinalprivado.info:80/series/1533784/1533784/264437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135410, 9651, 'Conversa com Bial S07 E71', 'http://sinalprivado.info:80/series/1533784/1533784/264438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135411, 9651, 'Conversa com Bial S07 E72', 'http://sinalprivado.info:80/series/1533784/1533784/264439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135412, 9651, 'Conversa com Bial S07 E73', 'http://sinalprivado.info:80/series/1533784/1533784/264440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135413, 9651, 'Conversa com Bial S07 E74', 'http://sinalprivado.info:80/series/1533784/1533784/264441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135414, 9651, 'Conversa com Bial S07 E75', 'http://sinalprivado.info:80/series/1533784/1533784/264442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135415, 9651, 'Conversa com Bial S07 E76', 'http://sinalprivado.info:80/series/1533784/1533784/264443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135416, 9651, 'Conversa com Bial S07 E77', 'http://sinalprivado.info:80/series/1533784/1533784/264444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135417, 9651, 'Conversa com Bial S07 E78', 'http://sinalprivado.info:80/series/1533784/1533784/264445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135418, 9651, 'Conversa com Bial S07 E79', 'http://sinalprivado.info:80/series/1533784/1533784/264446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135419, 9651, 'Conversa com Bial S07 E80', 'http://sinalprivado.info:80/series/1533784/1533784/264447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135420, 9651, 'Conversa com Bial S07 E81', 'http://sinalprivado.info:80/series/1533784/1533784/264448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135421, 9651, 'Conversa com Bial S07 E82', 'http://sinalprivado.info:80/series/1533784/1533784/264449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135422, 9651, 'Conversa com Bial S07 E83', 'http://sinalprivado.info:80/series/1533784/1533784/264450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135423, 9651, 'Conversa com Bial S07 E84', 'http://sinalprivado.info:80/series/1533784/1533784/264451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135424, 9651, 'Conversa com Bial S07 E85', 'http://sinalprivado.info:80/series/1533784/1533784/264452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135425, 9651, 'Conversa com Bial S07 E86', 'http://sinalprivado.info:80/series/1533784/1533784/264453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135426, 9651, 'Conversa com Bial S07 E87', 'http://sinalprivado.info:80/series/1533784/1533784/264454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135427, 9651, 'Conversa com Bial S07 E88', 'http://sinalprivado.info:80/series/1533784/1533784/264455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135428, 9651, 'Conversa com Bial S07 E89', 'http://sinalprivado.info:80/series/1533784/1533784/264456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135429, 9651, 'Conversa com Bial S07 E90', 'http://sinalprivado.info:80/series/1533784/1533784/264457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135430, 9651, 'Conversa com Bial S07 E91', 'http://sinalprivado.info:80/series/1533784/1533784/264458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135431, 9651, 'Conversa com Bial S07 E92', 'http://sinalprivado.info:80/series/1533784/1533784/264459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135432, 9651, 'Conversa com Bial S07 E93', 'http://sinalprivado.info:80/series/1533784/1533784/264460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135433, 9651, 'Conversa com Bial S07 E94', 'http://sinalprivado.info:80/series/1533784/1533784/264461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135434, 9651, 'Conversa com Bial S07 E95', 'http://sinalprivado.info:80/series/1533784/1533784/264462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135435, 9651, 'Conversa com Bial S07 E96', 'http://sinalprivado.info:80/series/1533784/1533784/264463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135436, 9651, 'Conversa com Bial S07 E97', 'http://sinalprivado.info:80/series/1533784/1533784/264464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135437, 9651, 'Conversa com Bial S07 E98', 'http://sinalprivado.info:80/series/1533784/1533784/264465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135438, 9651, 'Conversa com Bial S07 E99', 'http://sinalprivado.info:80/series/1533784/1533784/264466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135439, 9651, 'Conversa com Bial S07 E100', 'http://sinalprivado.info:80/series/1533784/1533784/264467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135440, 9651, 'Conversa com Bial S07 E101', 'http://sinalprivado.info:80/series/1533784/1533784/264468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135441, 9651, 'Conversa com Bial S07 E102', 'http://sinalprivado.info:80/series/1533784/1533784/264469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135442, 9651, 'Conversa com Bial S07 E103', 'http://sinalprivado.info:80/series/1533784/1533784/264470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135443, 9651, 'Conversa com Bial S07 E104', 'http://sinalprivado.info:80/series/1533784/1533784/264471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135444, 9651, 'Conversa com Bial S07 E105', 'http://sinalprivado.info:80/series/1533784/1533784/264472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135445, 9651, 'Conversa com Bial S07 E106', 'http://sinalprivado.info:80/series/1533784/1533784/264473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135446, 9651, 'Conversa com Bial S07 E107', 'http://sinalprivado.info:80/series/1533784/1533784/264474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135447, 9651, 'Conversa com Bial S07 E108', 'http://sinalprivado.info:80/series/1533784/1533784/264475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135448, 9651, 'Conversa com Bial S07 E109', 'http://sinalprivado.info:80/series/1533784/1533784/264476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135449, 9651, 'Conversa com Bial S07 E110', 'http://sinalprivado.info:80/series/1533784/1533784/264477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135450, 9651, 'Conversa com Bial S07 E111', 'http://sinalprivado.info:80/series/1533784/1533784/264478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135451, 9651, 'Conversa com Bial S07 E112', 'http://sinalprivado.info:80/series/1533784/1533784/264479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135452, 9651, 'Conversa com Bial S07 E113', 'http://sinalprivado.info:80/series/1533784/1533784/264480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135453, 9651, 'Conversa com Bial S07 E114', 'http://sinalprivado.info:80/series/1533784/1533784/264481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135454, 9651, 'Conversa com Bial S07 E115', 'http://sinalprivado.info:80/series/1533784/1533784/264482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135455, 9651, 'Conversa com Bial S07 E116', 'http://sinalprivado.info:80/series/1533784/1533784/264483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135456, 9651, 'Conversa com Bial S07 E117', 'http://sinalprivado.info:80/series/1533784/1533784/264484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135457, 9651, 'Conversa com Bial S07 E118', 'http://sinalprivado.info:80/series/1533784/1533784/264485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135458, 9651, 'Conversa com Bial S07 E119', 'http://sinalprivado.info:80/series/1533784/1533784/264486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135459, 9651, 'Conversa com Bial S07 E120', 'http://sinalprivado.info:80/series/1533784/1533784/264487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135460, 9651, 'Conversa com Bial S07 E121', 'http://sinalprivado.info:80/series/1533784/1533784/264488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135461, 9651, 'Conversa com Bial S07 E122', 'http://sinalprivado.info:80/series/1533784/1533784/264489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135462, 9651, 'Conversa com Bial S07 E123', 'http://sinalprivado.info:80/series/1533784/1533784/264490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135463, 9651, 'Conversa com Bial S07 E124', 'http://sinalprivado.info:80/series/1533784/1533784/264491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135464, 9651, 'Conversa com Bial S07 E125', 'http://sinalprivado.info:80/series/1533784/1533784/264492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135465, 9651, 'Conversa com Bial S07 E126', 'http://sinalprivado.info:80/series/1533784/1533784/264493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135466, 9651, 'Conversa com Bial S07 E127', 'http://sinalprivado.info:80/series/1533784/1533784/264494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135467, 9651, 'Conversa com Bial S07 E128', 'http://sinalprivado.info:80/series/1533784/1533784/264495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135468, 9651, 'Conversa com Bial S07 E129', 'http://sinalprivado.info:80/series/1533784/1533784/264496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135469, 9651, 'Conversa com Bial S07 E130', 'http://sinalprivado.info:80/series/1533784/1533784/264497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135470, 9651, 'Conversa com Bial S07 E131', 'http://sinalprivado.info:80/series/1533784/1533784/264498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135471, 9651, 'Conversa com Bial S07 E132', 'http://sinalprivado.info:80/series/1533784/1533784/264499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135472, 9651, 'Conversa com Bial S07 E133', 'http://sinalprivado.info:80/series/1533784/1533784/264500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135473, 9651, 'Conversa com Bial S07 E134', 'http://sinalprivado.info:80/series/1533784/1533784/264501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135474, 9651, 'Conversa com Bial S07 E135', 'http://sinalprivado.info:80/series/1533784/1533784/264502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135475, 9651, 'Conversa com Bial S07 E136', 'http://sinalprivado.info:80/series/1533784/1533784/264503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135476, 9651, 'Conversa com Bial S07 E137', 'http://sinalprivado.info:80/series/1533784/1533784/264504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135477, 9651, 'Conversa com Bial S07 E138', 'http://sinalprivado.info:80/series/1533784/1533784/264505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135478, 9651, 'Conversa com Bial S07 E139', 'http://sinalprivado.info:80/series/1533784/1533784/264506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135479, 9651, 'Conversa com Bial S07 E140', 'http://sinalprivado.info:80/series/1533784/1533784/264507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135480, 9651, 'Conversa com Bial S07 E141', 'http://sinalprivado.info:80/series/1533784/1533784/264508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135481, 9651, 'Conversa com Bial S07 E142', 'http://sinalprivado.info:80/series/1533784/1533784/264509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135482, 9651, 'Conversa com Bial S07 E143', 'http://sinalprivado.info:80/series/1533784/1533784/264510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135483, 9651, 'Conversa com Bial S07 E144', 'http://sinalprivado.info:80/series/1533784/1533784/264511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135484, 9651, 'Conversa com Bial S07 E145', 'http://sinalprivado.info:80/series/1533784/1533784/264512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135485, 9651, 'Conversa com Bial S07 E146', 'http://sinalprivado.info:80/series/1533784/1533784/264513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135486, 9651, 'Conversa com Bial S07 E147', 'http://sinalprivado.info:80/series/1533784/1533784/264514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135487, 9651, 'Conversa com Bial S07 E148', 'http://sinalprivado.info:80/series/1533784/1533784/264515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135488, 9651, 'Conversa com Bial S07 E149', 'http://sinalprivado.info:80/series/1533784/1533784/264516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135489, 9651, 'Conversa com Bial S07 E150', 'http://sinalprivado.info:80/series/1533784/1533784/264517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135490, 9651, 'Conversa com Bial S07 E151', 'http://sinalprivado.info:80/series/1533784/1533784/264518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135491, 9651, 'Conversa com Bial S07 E152', 'http://sinalprivado.info:80/series/1533784/1533784/264519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135492, 9651, 'Conversa com Bial S07 E153', 'http://sinalprivado.info:80/series/1533784/1533784/264520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135493, 9651, 'Conversa com Bial S07 E154', 'http://sinalprivado.info:80/series/1533784/1533784/264521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135494, 9651, 'Conversa com Bial S07 E155', 'http://sinalprivado.info:80/series/1533784/1533784/264522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135495, 9651, 'Conversa com Bial S07 E156', 'http://sinalprivado.info:80/series/1533784/1533784/264523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135496, 9651, 'Conversa com Bial S07 E157', 'http://sinalprivado.info:80/series/1533784/1533784/264524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135497, 9651, 'Conversa com Bial S07 E158', 'http://sinalprivado.info:80/series/1533784/1533784/264525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135498, 9651, 'Conversa com Bial S07 E159', 'http://sinalprivado.info:80/series/1533784/1533784/264526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135499, 9651, 'Conversa com Bial S07 E160', 'http://sinalprivado.info:80/series/1533784/1533784/264527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135500, 9651, 'Conversa com Bial S07 E161', 'http://sinalprivado.info:80/series/1533784/1533784/264528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135501, 9651, 'Conversa com Bial S07 E162', 'http://sinalprivado.info:80/series/1533784/1533784/264529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135502, 9651, 'Conversa com Bial S07 E163', 'http://sinalprivado.info:80/series/1533784/1533784/264530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135503, 9651, 'Conversa com Bial S07 E164', 'http://sinalprivado.info:80/series/1533784/1533784/264531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135504, 9651, 'Conversa com Bial S07 E165', 'http://sinalprivado.info:80/series/1533784/1533784/264532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135505, 9651, 'Conversa com Bial S07 E166', 'http://sinalprivado.info:80/series/1533784/1533784/264533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135506, 9651, 'Conversa com Bial S07 E167', 'http://sinalprivado.info:80/series/1533784/1533784/264534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135507, 9651, 'Conversa com Bial S07 E168', 'http://sinalprivado.info:80/series/1533784/1533784/264535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135508, 9651, 'Conversa com Bial S07 E169', 'http://sinalprivado.info:80/series/1533784/1533784/264536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135509, 9651, 'Conversa com Bial S07 E170', 'http://sinalprivado.info:80/series/1533784/1533784/264537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135510, 9651, 'Conversa com Bial S07 E171', 'http://sinalprivado.info:80/series/1533784/1533784/264538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135511, 9651, 'Conversa com Bial S07 E172', 'http://sinalprivado.info:80/series/1533784/1533784/264539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135512, 9651, 'Conversa com Bial S07 E173', 'http://sinalprivado.info:80/series/1533784/1533784/264540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135513, 9651, 'Conversa com Bial S07 E174', 'http://sinalprivado.info:80/series/1533784/1533784/264541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135514, 9651, 'Conversa com Bial S07 E175', 'http://sinalprivado.info:80/series/1533784/1533784/264542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135515, 9651, 'Conversa com Bial S07 E176', 'http://sinalprivado.info:80/series/1533784/1533784/264543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135516, 9651, 'Conversa com Bial S07 E177', 'http://sinalprivado.info:80/series/1533784/1533784/264544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135517, 9651, 'Conversa com Bial S07 E178', 'http://sinalprivado.info:80/series/1533784/1533784/264545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135518, 9651, 'Conversa com Bial S07 E179', 'http://sinalprivado.info:80/series/1533784/1533784/264546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135519, 9651, 'Conversa com Bial S07 E180', 'http://sinalprivado.info:80/series/1533784/1533784/264547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135520, 9651, 'Conversa com Bial S07 E181', 'http://sinalprivado.info:80/series/1533784/1533784/264548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135521, 9651, 'Conversa com Bial S07 E182', 'http://sinalprivado.info:80/series/1533784/1533784/264549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135522, 9651, 'Conversa com Bial S07 E183', 'http://sinalprivado.info:80/series/1533784/1533784/264550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135523, 9651, 'Conversa com Bial S07 E184', 'http://sinalprivado.info:80/series/1533784/1533784/264551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135524, 9651, 'Conversa com Bial S07 E185', 'http://sinalprivado.info:80/series/1533784/1533784/264552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135525, 9651, 'Conversa com Bial S07 E186', 'http://sinalprivado.info:80/series/1533784/1533784/264553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135526, 9651, 'Conversa com Bial S07 E187', 'http://sinalprivado.info:80/series/1533784/1533784/264554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135527, 9651, 'Conversa com Bial S07 E188', 'http://sinalprivado.info:80/series/1533784/1533784/264555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135528, 9651, 'Conversa com Bial S07 E189', 'http://sinalprivado.info:80/series/1533784/1533784/264556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/64rplJqkd1QFGe8poPt10DPDUOT.jpg'),
(135529, 9652, 'Drinques Pelo Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ex0ICQa6cLnuLPzYyS7m4SFtwtR.jpg'),
(135530, 9652, 'Drinques Pelo Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rhDFlkRQo44SPb7SM43XNqXOMCh.jpg'),
(135531, 9652, 'Drinques Pelo Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdpvAUObWRs5rsluOUGcfljXr1j.jpg'),
(135532, 9652, 'Drinques Pelo Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/orrcDVnJRpXMzhO2FnOz0lPqn2x.jpg'),
(135533, 9652, 'Drinques Pelo Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eAUzZUCf6gfNQHl1EDhKzjW8hVh.jpg'),
(135534, 9652, 'Drinques Pelo Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Z2UUUA2wzUGvn37548WABuN8td.jpg'),
(135535, 9652, 'Drinques Pelo Mundo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iogOQAYBrbg7inEINj89fimR4zJ.jpg'),
(135536, 9652, 'Drinques Pelo Mundo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dy9akfkfVq3sbIOtlicTlep5cwN.jpg'),
(135537, 9652, 'Drinques Pelo Mundo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n4oC7EVG3nZ9cn0Hc2GV3fL6zP7.jpg'),
(135538, 9652, 'Drinques Pelo Mundo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i1IRtMRrmJjWhsIpUBL8cQkrTSv.jpg'),
(135539, 9652, 'Drinques Pelo Mundo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pgjw82GcCmxERZeMGKtvSC4wsld.jpg'),
(135540, 9652, 'Drinques Pelo Mundo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135541, 9652, 'Drinques Pelo Mundo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/264333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v1f8DRaWwxz81K5SmJicEF4Z1Vj.jpg'),
(135542, 9652, 'Drinques Pelo Mundo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/264334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dmNb8TedGEKoCaEENPUDtjBcaB9.jpg'),
(135543, 9652, 'Drinques Pelo Mundo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/264335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/248CLMK0SV5vCIoAOgsmF9cYmRI.jpg'),
(135544, 9653, 'Drinques Pelo Mundo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135545, 9653, 'Drinques Pelo Mundo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135546, 9653, 'Drinques Pelo Mundo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135547, 9653, 'Drinques Pelo Mundo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135548, 9653, 'Drinques Pelo Mundo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135549, 9653, 'Drinques Pelo Mundo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135550, 9653, 'Drinques Pelo Mundo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135551, 9653, 'Drinques Pelo Mundo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135552, 9653, 'Drinques Pelo Mundo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135553, 9653, 'Drinques Pelo Mundo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135554, 9653, 'Drinques Pelo Mundo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135555, 9653, 'Drinques Pelo Mundo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135556, 9653, 'Drinques Pelo Mundo S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/264348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135557, 9653, 'Drinques Pelo Mundo S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/264349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135558, 9653, 'Drinques Pelo Mundo S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/264350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135559, 9653, 'Drinques Pelo Mundo S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/264351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135560, 9654, 'Drinques Pelo Mundo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135561, 9654, 'Drinques Pelo Mundo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135562, 9654, 'Drinques Pelo Mundo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135563, 9654, 'Drinques Pelo Mundo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135564, 9654, 'Drinques Pelo Mundo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135565, 9654, 'Drinques Pelo Mundo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(135566, 9654, 'Drinques Pelo Mundo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135567, 9654, 'Drinques Pelo Mundo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135568, 9654, 'Drinques Pelo Mundo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135569, 9654, 'Drinques Pelo Mundo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135570, 9654, 'Drinques Pelo Mundo S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135571, 9654, 'Drinques Pelo Mundo S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135572, 9654, 'Drinques Pelo Mundo S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/264364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135573, 9654, 'Drinques Pelo Mundo S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/264365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135574, 9654, 'Drinques Pelo Mundo S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/264366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135575, 9654, 'Drinques Pelo Mundo S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/264367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6AKpxs5xTDkrmYVzFCpoGfWn6QB.jpg'),
(135576, 2962, 'Fauda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ykj0p1sekNaeVtUQ7qvOm8zzRu.jpg'),
(135577, 2962, 'Fauda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7KHkEPSH7TfOfE4lmqFlYCRITv.jpg'),
(135578, 2962, 'Fauda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8NviP6Fo7eIzjNVntpGXF2pIXd.jpg'),
(135579, 2962, 'Fauda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wTSgmkbfisDIlIsk5nMlreN5eqL.jpg'),
(135580, 2962, 'Fauda S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2hh8sj1uG7QFxJHrmuG2HK73cxk.jpg'),
(135581, 2962, 'Fauda S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bu097wirVCc1KFdp3xqByEnlSbO.jpg'),
(135582, 2962, 'Fauda S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nZPJ6BH9oyGbtirFUaNUiQGyur1.jpg'),
(135583, 2962, 'Fauda S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5I9ygGQl3kLF3EgbOs53djXKJqc.jpg'),
(135584, 2962, 'Fauda S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xGiBHsymS0tnKKfnF6oszx6nsif.jpg'),
(135585, 2962, 'Fauda S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63jNbiypcrAJwqQ0GC8pAc06Pmk.jpg'),
(135586, 2962, 'Fauda S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kwKuIERdbsA8DZUrpEsPICHU6XZ.jpg'),
(135587, 2962, 'Fauda S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g0Bhp39iaSGM23hXuXCZ3B9UrQE.jpg'),
(135588, 9655, 'Kelp o Unicornio do Mar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ddsVPVj9D0UQf7J3OAEmL5E328h.jpg'),
(135589, 9655, 'Kelp o Unicornio do Mar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bNeOKvbkiwZgguFGI9XlwNMJh2u.jpg'),
(135590, 9655, 'Kelp o Unicornio do Mar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vogPQpzp98aWzqfLxMSMCncmAqw.jpg'),
(135591, 9655, 'Kelp o Unicornio do Mar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fp2XVy2Kd1HzBCtmxKf2YsW3H84.jpg'),
(135592, 9655, 'Kelp o Unicornio do Mar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8239Tp6R268udvjfQqT88lYy9t0.jpg'),
(135593, 9655, 'Kelp o Unicornio do Mar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dCgECJ7nWXzMfvVRP0itr0T0f5f.jpg'),
(135594, 9655, 'Kelp o Unicornio do Mar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bd52GXs8eimUFgYO8Ztp8obrJa8.jpg'),
(135595, 9655, 'Kelp o Unicornio do Mar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oy0KxQfd6DDq2zlKFAEhG5MCZCM.jpg'),
(135596, 9655, 'Kelp o Unicornio do Mar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zFMhiWWUMxdm0gyUU90oRsgiA9.jpg'),
(135597, 9655, 'Kelp o Unicornio do Mar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8mzx0CXWhvKqrVks1Ck6sdW9zPl.jpg'),
(135598, 9655, 'Kelp o Unicornio do Mar S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iLVsV13TPSdFXsxW16x4i0STKNE.jpg'),
(135599, 9655, 'Kelp o Unicornio do Mar S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Zh77xNGu6Rtfbh710NR8MiAja6.jpg'),
(135600, 9655, 'Kelp o Unicornio do Mar S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/264282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g8JQpYl4Ryt0mLkGC7HjWIRYrby.jpg'),
(135601, 9655, 'Kelp o Unicornio do Mar S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/264283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2C1lnTFLTJM0dBaEIO9JlAEKWFN.jpg'),
(135602, 9655, 'Kelp o Unicornio do Mar S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/264284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dwIogGzHH8sQB7NRQsyqolPDHgV.jpg'),
(135603, 9655, 'Kelp o Unicornio do Mar S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/264285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lQ8heqvolE2vnI2Wvic25msd1o6.jpg'),
(135604, 9655, 'Kelp o Unicornio do Mar S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/264286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Qje3RKkhcdt7m9pacZKzxqZVaN.jpg'),
(135605, 9655, 'Kelp o Unicornio do Mar S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/264287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aCL3wA2TWVlPNQsAl7ElBYGSCJm.jpg'),
(135606, 9655, 'Kelp o Unicornio do Mar S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/264288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zyacr0AhcsBjvzoaY8qEfjs3WXH.jpg'),
(135607, 9655, 'Kelp o Unicornio do Mar S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/264289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9furV3hNguQzI98q9Ua9IVVjYIH.jpg'),
(135608, 9655, 'Kelp o Unicornio do Mar S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/264290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vn453VwQMFA09XVmeCgGANmLsrt.jpg'),
(135609, 9655, 'Kelp o Unicornio do Mar S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/264291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/krSM4OBzTx9BDleZLSbjRxWQn6d.jpg'),
(135610, 9655, 'Kelp o Unicornio do Mar S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/264292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7w9N6H4jkGXhhtxtwWsIzhCQ1gK.jpg'),
(135611, 9655, 'Kelp o Unicornio do Mar S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/264293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d5OkgfqPhNEXCd3Rbj83i6HuqPJ.jpg'),
(135612, 9655, 'Kelp o Unicornio do Mar S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/264294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dgwarQDnjSKgP2qZOQUacC010oO.jpg'),
(135613, 9655, 'Kelp o Unicornio do Mar S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/264295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dAUIpsFoM76POK5qWSFUEtXjKVJ.jpg'),
(135614, 9655, 'Kelp o Unicornio do Mar S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/264296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fTIi0QCJ5thKxJgbzSfT9VGWvS7.jpg'),
(135615, 9656, 'Kelp o Unicornio do Mar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ldlcEzhWtVIrX1YGmkQsWHC8FmY.jpg'),
(135616, 9656, 'Kelp o Unicornio do Mar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ldlcEzhWtVIrX1YGmkQsWHC8FmY.jpg'),
(135617, 9656, 'Kelp o Unicornio do Mar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ldlcEzhWtVIrX1YGmkQsWHC8FmY.jpg'),
(135618, 9656, 'Kelp o Unicornio do Mar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ldlcEzhWtVIrX1YGmkQsWHC8FmY.jpg'),
(135619, 9656, 'Kelp o Unicornio do Mar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ldlcEzhWtVIrX1YGmkQsWHC8FmY.jpg'),
(135620, 9656, 'Kelp o Unicornio do Mar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ldlcEzhWtVIrX1YGmkQsWHC8FmY.jpg'),
(135621, 9656, 'Kelp o Unicornio do Mar S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ldlcEzhWtVIrX1YGmkQsWHC8FmY.jpg'),
(135622, 9656, 'Kelp o Unicornio do Mar S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ldlcEzhWtVIrX1YGmkQsWHC8FmY.jpg'),
(135623, 9656, 'Kelp o Unicornio do Mar S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ldlcEzhWtVIrX1YGmkQsWHC8FmY.jpg'),
(135624, 9656, 'Kelp o Unicornio do Mar S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ldlcEzhWtVIrX1YGmkQsWHC8FmY.jpg'),
(135625, 9656, 'Kelp o Unicornio do Mar S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ldlcEzhWtVIrX1YGmkQsWHC8FmY.jpg'),
(135626, 9656, 'Kelp o Unicornio do Mar S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ldlcEzhWtVIrX1YGmkQsWHC8FmY.jpg'),
(135627, 9657, 'O Assalto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20ZR2VLxTnInhXoaorSfwfbJ0mU.jpg'),
(135628, 9657, 'O Assalto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20ZR2VLxTnInhXoaorSfwfbJ0mU.jpg'),
(135629, 9657, 'O Assalto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/20ZR2VLxTnInhXoaorSfwfbJ0mU.jpg'),
(135630, 9658, 'Os Passaros Feridos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rLpmdwmGNsUvVhGQPvXMbWufEKd.jpg'),
(135631, 9658, 'Os Passaros Feridos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u5ah2agu3B8gIyyNV2e6SoXrflu.jpg'),
(135632, 9658, 'Os Passaros Feridos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zJ7lamiEiDPUmwfuG4xQvfOw0fv.jpg'),
(135633, 9658, 'Os Passaros Feridos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bJMzAfdWltkq2bWe7ynu25UnpaI.jpg'),
(135634, 9659, 'Transformers Cyberverse S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8NzarfQfmkixlg8TiZeddhSJbX5.jpg'),
(135635, 9659, 'Transformers Cyberverse S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1rlRGa4z5OUlIJPa8KtNFJP3rQp.jpg'),
(135636, 9659, 'Transformers Cyberverse S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cTP8RSsX0sCcUvoQnXR4JlilTg6.jpg'),
(135637, 9659, 'Transformers Cyberverse S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wrpWnbsXwnrkVQcayRfgqdUzNAg.jpg'),
(135638, 9659, 'Transformers Cyberverse S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fMp1tGtQXs0gTT9i5ZVadQE18DZ.jpg'),
(135639, 9659, 'Transformers Cyberverse S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/moY4j8lg0NeS4uPPhwRCr2vwggf.jpg'),
(135640, 9659, 'Transformers Cyberverse S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/98cAtsJPyQcoRozIhDuzzCk6kg0.jpg'),
(135641, 9659, 'Transformers Cyberverse S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1DCa8QJUGEOJS15pp4rD06pJvLv.jpg'),
(135642, 9659, 'Transformers Cyberverse S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z5CJHtY4FTzbl7xWINxuPPt396t.jpg'),
(135643, 9659, 'Transformers Cyberverse S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lvrtFOvEDFuD3ctQTYp6c2TtP3c.jpg'),
(135644, 9659, 'Transformers Cyberverse S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yEJSySb8n1zJdfUttCvx1f2sPUB.jpg'),
(135645, 9659, 'Transformers Cyberverse S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lTr6Z8KNTeQaSqY0GYeifQs1wE1.jpg'),
(135646, 9659, 'Transformers Cyberverse S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/264213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r4mcEEjkFRK8VAjXJzHfH6kqQPT.jpg'),
(135647, 9659, 'Transformers Cyberverse S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/264214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ErHTQXGmHCQJvL7bVoA8gfMUDD.jpg'),
(135648, 9659, 'Transformers Cyberverse S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/264215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dSjXrzkIYsHozg8smgGdMY6Anz1.jpg'),
(135649, 9659, 'Transformers Cyberverse S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/264216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gmlpJoxTIbAj0tbdlC8BMPLH8Gh.jpg'),
(135650, 9659, 'Transformers Cyberverse S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/264217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dHcanCghTYn7MrRAKtsmHBpCp1e.jpg'),
(135651, 9659, 'Transformers Cyberverse S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/264218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5wvxu7QUrXXWZ2VUGTnDwhVbrNt.jpg'),
(135652, 9660, 'Transformers Cyberverse S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135653, 9660, 'Transformers Cyberverse S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135654, 9660, 'Transformers Cyberverse S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135655, 9660, 'Transformers Cyberverse S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135656, 9660, 'Transformers Cyberverse S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135657, 9660, 'Transformers Cyberverse S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135658, 9660, 'Transformers Cyberverse S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135659, 9660, 'Transformers Cyberverse S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135660, 9660, 'Transformers Cyberverse S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135661, 9660, 'Transformers Cyberverse S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135662, 9660, 'Transformers Cyberverse S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135663, 9660, 'Transformers Cyberverse S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135664, 9660, 'Transformers Cyberverse S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/264231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135665, 9660, 'Transformers Cyberverse S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/264232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135666, 9660, 'Transformers Cyberverse S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/264233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135667, 9660, 'Transformers Cyberverse S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/264234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135668, 9660, 'Transformers Cyberverse S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/264235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135669, 9660, 'Transformers Cyberverse S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/264236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135670, 9661, 'Transformers Cyberverse S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1YaHBryzJitb4JgENSQnOVg0y9l.jpg'),
(135671, 9661, 'Transformers Cyberverse S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/88jV6XPPSALVwmoNDZrdAwPIKs4.jpg'),
(135672, 9661, 'Transformers Cyberverse S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6wUc8BL1HDRPTJXVytnoMmgIXY4.jpg'),
(135673, 9661, 'Transformers Cyberverse S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ibDsz506T2FTkeb3ImH10SJ6bt7.jpg'),
(135674, 9661, 'Transformers Cyberverse S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ariKnixbTxZwpHwJ64rHNkOQULl.jpg'),
(135675, 9661, 'Transformers Cyberverse S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/19HpixTBnd7VyWrcYGEZ1W3W1Sj.jpg'),
(135676, 9661, 'Transformers Cyberverse S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vqSphf6VDsjR5tUFNTd7k1nv9Ej.jpg'),
(135677, 9661, 'Transformers Cyberverse S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rjPkz4ntLDR1yB06llIYhwf3iUI.jpg'),
(135678, 9661, 'Transformers Cyberverse S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/264245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135679, 9661, 'Transformers Cyberverse S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/264246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ihNk3qV9Su6mz8MkDQ1sbWNUvAO.jpg'),
(135680, 9661, 'Transformers Cyberverse S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/264247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135681, 9661, 'Transformers Cyberverse S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/264248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135682, 9661, 'Transformers Cyberverse S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/264249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135683, 9661, 'Transformers Cyberverse S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/264250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135684, 9661, 'Transformers Cyberverse S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/264251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135685, 9661, 'Transformers Cyberverse S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/264252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135686, 9661, 'Transformers Cyberverse S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/264253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135687, 9661, 'Transformers Cyberverse S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/264254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135688, 9661, 'Transformers Cyberverse S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/264255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135689, 9661, 'Transformers Cyberverse S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/264256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135690, 9661, 'Transformers Cyberverse S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/264257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135691, 9661, 'Transformers Cyberverse S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/264258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135692, 9661, 'Transformers Cyberverse S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/264259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135693, 9661, 'Transformers Cyberverse S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/264260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135694, 9661, 'Transformers Cyberverse S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/264261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135695, 9661, 'Transformers Cyberverse S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/264262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fxgzkgFavRmKLawUR4w6MQmWmCl.jpg'),
(135696, 9662, 'Barry S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wPQL3IefD2DTlBwk0cgdofjTDft.jpg'),
(135697, 9662, 'Barry S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iFsn7UnuxYx6lIReJ4gZCuXsDfC.jpg'),
(135698, 9662, 'Barry S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hXg7Z4gWRdvjoRqRuQFNQlbw8Sf.jpg'),
(135699, 9662, 'Barry S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bn25jetAErgS75p3nwZ16oslmQB.jpg'),
(135700, 9662, 'Barry S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A8Kv8b7eqiR6OaFbW5EnFoKfXi6.jpg'),
(135701, 9662, 'Barry S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/928arAMuAEd9y7ogrocGbljVq0Z.jpg'),
(135702, 9662, 'Barry S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBdX4koB6T4g1mVZaFnK63ruLjn.jpg'),
(135703, 9662, 'Barry S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/boOjYoKrcE11bFSUSzTVldlamrP.jpg'),
(135704, 9663, 'Barry S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dsKiTJ68w3QBVi8tmvVCjCPoJ1o.jpg'),
(135705, 9663, 'Barry S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iGlwghu3fEv1krqm2LGeZBDCQ3.jpg'),
(135706, 9663, 'Barry S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ifn58I6un50WVS3TAxkBa1ER0gP.jpg'),
(135707, 9663, 'Barry S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2fQ7NXgX31eKJ4tnAxyxg9lgdHA.jpg'),
(135708, 9663, 'Barry S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ssjuixbA56i6ZF4QqE9lpyHIHfY.jpg'),
(135709, 9663, 'Barry S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tbJciAuaG8a85MbFPI63RKnsybM.jpg'),
(135710, 9663, 'Barry S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j1aA7zBeEfwU8ltoRwCfVYNLtFi.jpg'),
(135711, 9663, 'Barry S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ncRcTMguNwiAT6GXu2zICZCMr6h.jpg'),
(135712, 9664, 'Barry S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m9tmuZbTwUNqLuGMu9YseKcKZhy.jpg'),
(135713, 9664, 'Barry S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8dJwOnj6a619rhdcVO6ssUdGRMW.jpg'),
(135714, 9664, 'Barry S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AfpE6RJF6IMx9mZPyvpFj2M5JjO.jpg'),
(135715, 9664, 'Barry S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iVdRhafHjezFQdssmBqoLGwwXEp.jpg'),
(135716, 9664, 'Barry S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vI2igi63OMZoh5Rxq7Z6TZTxdoV.jpg'),
(135717, 9664, 'Barry S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g0xRcEDNNXEkCpvY7q1k43ytHuC.jpg'),
(135718, 9664, 'Barry S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bZ4Z1HzUlimhDZ6FULvgi7q6Og6.jpg'),
(135719, 9664, 'Barry S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ioup7TtchDFOQJ9lqcaXecc19PS.jpg'),
(135720, 9665, 'Barry S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9E5gyk9nkrQRGlHVLp3FPRJFX7r.jpg'),
(135721, 9665, 'Barry S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqlSFzSVTFjww0OwMtXBM4VMqks.jpg'),
(135722, 9665, 'Barry S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cCKODFL5cIgkw8HWwH3v7XuQ811.jpg'),
(135723, 9665, 'Barry S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/264017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pd93HcMnLyEurcnUhbsRUK2Potw.jpg'),
(135724, 9665, 'Barry S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/264018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9goHSdqFRxKuG2JlQRHlm3vnGGB.jpg'),
(135725, 9665, 'Barry S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/264019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z8qYe34tmKa6cFE7w1auHmxQX39.jpg'),
(135726, 9665, 'Barry S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/264020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d4q3SJvay6R29YM96AbRagEXac0.jpg'),
(135727, 9665, 'Barry S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/264021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/miZdCMnUqKmcIub25ONiyx5I8c3.jpg'),
(135728, 9666, 'A Nova pantera Cor de Rosa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135729, 9666, 'A Nova pantera Cor de Rosa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135730, 9666, 'A Nova pantera Cor de Rosa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135731, 9666, 'A Nova pantera Cor de Rosa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135732, 9666, 'A Nova pantera Cor de Rosa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135733, 9666, 'A Nova pantera Cor de Rosa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135734, 9666, 'A Nova pantera Cor de Rosa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135735, 9666, 'A Nova pantera Cor de Rosa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135736, 9666, 'A Nova pantera Cor de Rosa S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135737, 9666, 'A Nova pantera Cor de Rosa S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135738, 9666, 'A Nova pantera Cor de Rosa S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135739, 9666, 'A Nova pantera Cor de Rosa S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135740, 9666, 'A Nova pantera Cor de Rosa S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135741, 9666, 'A Nova pantera Cor de Rosa S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135742, 9666, 'A Nova pantera Cor de Rosa S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135743, 9666, 'A Nova pantera Cor de Rosa S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135744, 9666, 'A Nova pantera Cor de Rosa S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/263946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135745, 9666, 'A Nova pantera Cor de Rosa S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/263947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135746, 9666, 'A Nova pantera Cor de Rosa S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/263948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135747, 9666, 'A Nova pantera Cor de Rosa S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/263949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135748, 9666, 'A Nova pantera Cor de Rosa S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/263950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135749, 9666, 'A Nova pantera Cor de Rosa S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/263951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135750, 9666, 'A Nova pantera Cor de Rosa S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/263952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135751, 9666, 'A Nova pantera Cor de Rosa S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/263953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135752, 9666, 'A Nova pantera Cor de Rosa S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/263954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135753, 9666, 'A Nova pantera Cor de Rosa S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/263955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135754, 9666, 'A Nova pantera Cor de Rosa S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/263956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135755, 9666, 'A Nova pantera Cor de Rosa S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/263957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135756, 9666, 'A Nova pantera Cor de Rosa S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/263958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135757, 9666, 'A Nova pantera Cor de Rosa S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/263959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135758, 9666, 'A Nova pantera Cor de Rosa S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/263960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135759, 9666, 'A Nova pantera Cor de Rosa S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/263961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135760, 9666, 'A Nova pantera Cor de Rosa S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/263962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135761, 9666, 'A Nova pantera Cor de Rosa S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/263963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135762, 9666, 'A Nova pantera Cor de Rosa S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/263964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135763, 9666, 'A Nova pantera Cor de Rosa S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/263965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135764, 9666, 'A Nova pantera Cor de Rosa S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/263966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135765, 9666, 'A Nova pantera Cor de Rosa S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/263967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135766, 9666, 'A Nova pantera Cor de Rosa S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/263968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135767, 9666, 'A Nova pantera Cor de Rosa S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/263969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135768, 9667, 'A Nova pantera Cor de Rosa S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135769, 9667, 'A Nova pantera Cor de Rosa S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135770, 9667, 'A Nova pantera Cor de Rosa S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135771, 9667, 'A Nova pantera Cor de Rosa S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135772, 9667, 'A Nova pantera Cor de Rosa S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135773, 9667, 'A Nova pantera Cor de Rosa S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135774, 9667, 'A Nova pantera Cor de Rosa S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135775, 9667, 'A Nova pantera Cor de Rosa S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135776, 9667, 'A Nova pantera Cor de Rosa S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135777, 9667, 'A Nova pantera Cor de Rosa S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135778, 9667, 'A Nova pantera Cor de Rosa S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135779, 9667, 'A Nova pantera Cor de Rosa S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135780, 9667, 'A Nova pantera Cor de Rosa S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135781, 9667, 'A Nova pantera Cor de Rosa S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135782, 9667, 'A Nova pantera Cor de Rosa S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135783, 9667, 'A Nova pantera Cor de Rosa S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135784, 9667, 'A Nova pantera Cor de Rosa S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/263986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135785, 9667, 'A Nova pantera Cor de Rosa S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/263987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135786, 9667, 'A Nova pantera Cor de Rosa S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/263988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135787, 9667, 'A Nova pantera Cor de Rosa S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/263989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/38h0wNR0KSbmSeTclpPG5UJ5XRg.jpg'),
(135788, 9668, 'Como Mudar sua Mente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uPxNINW728bi3TkUQ57KkCJ1c5R.jpg'),
(135789, 9668, 'Como Mudar sua Mente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vv5texhGag6zbonEdozEBwQiMoY.jpg'),
(135790, 9668, 'Como Mudar sua Mente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vyLMdWT6GrxzMNLjy2KCQIfOJgJ.jpg'),
(135791, 9668, 'Como Mudar sua Mente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aupLCuQmmIO0D9qTPtrnwNicU4r.jpg'),
(135792, 9669, 'Griselda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xxDH9CgYp5oVvtV0NxcWxOlXIfv.jpg'),
(135793, 9669, 'Griselda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Z7qbB41AHpAgebhT9XB6VDx25R.jpg'),
(135794, 9669, 'Griselda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/463RHPPJYe7v4Y3YrYcHyv0HYGq.jpg'),
(135795, 9669, 'Griselda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ry7SLjjFi3BqLiJTgnGlscfpcu2.jpg'),
(135796, 9669, 'Griselda S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q32mLZhJnRuHjDRIJQ5OVaM3m9b.jpg'),
(135797, 9669, 'Griselda S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eyuPr2Bx5P8l3SlWaFDcnxw2kPr.jpg'),
(135798, 9670, 'Hotel Sem Estrelas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z2a3CEGHuIF4QTEQ9FYijD7uGPM.jpg'),
(135799, 9670, 'Hotel Sem Estrelas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z2a3CEGHuIF4QTEQ9FYijD7uGPM.jpg'),
(135800, 9670, 'Hotel Sem Estrelas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z2a3CEGHuIF4QTEQ9FYijD7uGPM.jpg'),
(135801, 9670, 'Hotel Sem Estrelas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z2a3CEGHuIF4QTEQ9FYijD7uGPM.jpg'),
(135802, 9670, 'Hotel Sem Estrelas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z2a3CEGHuIF4QTEQ9FYijD7uGPM.jpg'),
(135803, 9670, 'Hotel Sem Estrelas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z2a3CEGHuIF4QTEQ9FYijD7uGPM.jpg'),
(135804, 9670, 'Hotel Sem Estrelas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z2a3CEGHuIF4QTEQ9FYijD7uGPM.jpg'),
(135805, 9670, 'Hotel Sem Estrelas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z2a3CEGHuIF4QTEQ9FYijD7uGPM.jpg'),
(135806, 9670, 'Hotel Sem Estrelas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z2a3CEGHuIF4QTEQ9FYijD7uGPM.jpg'),
(135807, 9670, 'Hotel Sem Estrelas S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z2a3CEGHuIF4QTEQ9FYijD7uGPM.jpg'),
(135808, 9670, 'Hotel Sem Estrelas S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z2a3CEGHuIF4QTEQ9FYijD7uGPM.jpg'),
(135809, 9670, 'Hotel Sem Estrelas S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z2a3CEGHuIF4QTEQ9FYijD7uGPM.jpg'),
(135810, 9670, 'Hotel Sem Estrelas S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z2a3CEGHuIF4QTEQ9FYijD7uGPM.jpg'),
(135811, 9671, 'O Rebu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2in5LnerCdewpWTanIHA7uuhoPG.jpg'),
(135812, 9671, 'O Rebu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135813, 9671, 'O Rebu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135814, 9671, 'O Rebu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135815, 9671, 'O Rebu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135816, 9671, 'O Rebu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135817, 9671, 'O Rebu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135818, 9671, 'O Rebu S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135819, 9671, 'O Rebu S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135820, 9671, 'O Rebu S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135821, 9671, 'O Rebu S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135822, 9671, 'O Rebu S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135823, 9671, 'O Rebu S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(135824, 9671, 'O Rebu S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135825, 9671, 'O Rebu S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135826, 9671, 'O Rebu S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135827, 9671, 'O Rebu S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/263887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135828, 9671, 'O Rebu S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/263888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135829, 9671, 'O Rebu S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/263889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135830, 9671, 'O Rebu S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/263890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135831, 9671, 'O Rebu S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/263891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135832, 9671, 'O Rebu S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/263892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135833, 9671, 'O Rebu S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/263893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135834, 9671, 'O Rebu S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/263894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135835, 9671, 'O Rebu S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/263895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135836, 9671, 'O Rebu S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/263896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135837, 9671, 'O Rebu S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/263897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135838, 9671, 'O Rebu S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/263898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135839, 9671, 'O Rebu S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/263899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135840, 9671, 'O Rebu S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/263900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135841, 9671, 'O Rebu S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/263901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135842, 9671, 'O Rebu S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/263902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135843, 9671, 'O Rebu S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/263903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135844, 9671, 'O Rebu S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/263904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135845, 9671, 'O Rebu S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/263905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135846, 9671, 'O Rebu S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/263906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ddRLu4jklcYQDUmExwKShPBgBAa.jpg'),
(135847, 9672, 'Os Casagrandes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2PNCUxQRuw5XywabGoiY81HFo3.jpg'),
(135848, 9672, 'Os Casagrandes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDoC4OdjqFhNUchyJF0isu5XFil.jpg'),
(135849, 9672, 'Os Casagrandes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mfe46ZlkOYe2fVndBIBFutKrmKB.jpg'),
(135850, 9672, 'Os Casagrandes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135851, 9672, 'Os Casagrandes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eJ5SANpWpdXgQj60n3WJZyMMJnI.jpg'),
(135852, 9672, 'Os Casagrandes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qym3YNRv7MmDNErqSTCyGEwAv69.jpg'),
(135853, 9672, 'Os Casagrandes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4touVdOOPguCstt3cBcMi0BV2Yu.jpg'),
(135854, 9672, 'Os Casagrandes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jU2tFS8epCsGpmAYKp3ILprinYR.jpg'),
(135855, 9672, 'Os Casagrandes S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dbANBUaD9EHFoSDkl6l3XjvY896.jpg'),
(135856, 9672, 'Os Casagrandes S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/epbeS85hBBDtZlVBw0f74xaVEOc.jpg'),
(135857, 9672, 'Os Casagrandes S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nIvhoI1ZwzdBIUGgnq0cX1N6Kcl.jpg'),
(135858, 9672, 'Os Casagrandes S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1cBc2gyMg0r8xylr1alEYd2sCww.jpg'),
(135859, 9672, 'Os Casagrandes S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135860, 9672, 'Os Casagrandes S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mdMUPIA7uH6UzuXvNUkihTMGoDA.jpg'),
(135861, 9672, 'Os Casagrandes S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/266507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b86wI0NLPdhm6uY9SnJ4k0hmUf1.jpg'),
(135862, 9672, 'Os Casagrandes S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/266508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mOscXAgyBeeaA7D7BudGr5qbRwI.jpg'),
(135863, 9672, 'Os Casagrandes S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/266509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135864, 9672, 'Os Casagrandes S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/266510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2nNqpvDVFe5ap1UpY1DQxFnsv6b.jpg'),
(135865, 9672, 'Os Casagrandes S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/266511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135866, 9672, 'Os Casagrandes S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/266512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hZCKi8FvqUmNPKGP0zzFBxL4ypS.jpg'),
(135867, 9673, 'Os Casagrandes S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135868, 9673, 'Os Casagrandes S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135869, 9673, 'Os Casagrandes S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135870, 9673, 'Os Casagrandes S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135871, 9673, 'Os Casagrandes S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135872, 9673, 'Os Casagrandes S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135873, 9673, 'Os Casagrandes S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135874, 9673, 'Os Casagrandes S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135875, 9673, 'Os Casagrandes S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135876, 9673, 'Os Casagrandes S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135877, 9673, 'Os Casagrandes S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135878, 9673, 'Os Casagrandes S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135879, 9673, 'Os Casagrandes S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135880, 9673, 'Os Casagrandes S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135881, 9673, 'Os Casagrandes S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/266527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135882, 9673, 'Os Casagrandes S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/266528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135883, 9673, 'Os Casagrandes S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/266529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135884, 9673, 'Os Casagrandes S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/266530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135885, 9673, 'Os Casagrandes S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/266531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135886, 9673, 'Os Casagrandes S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/266532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135887, 9674, 'Os Casagrandes S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135888, 9674, 'Os Casagrandes S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135889, 9674, 'Os Casagrandes S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135890, 9674, 'Os Casagrandes S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135891, 9674, 'Os Casagrandes S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135892, 9674, 'Os Casagrandes S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135893, 9674, 'Os Casagrandes S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135894, 9674, 'Os Casagrandes S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135895, 9674, 'Os Casagrandes S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135896, 9674, 'Os Casagrandes S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135897, 9674, 'Os Casagrandes S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135898, 9674, 'Os Casagrandes S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135899, 9674, 'Os Casagrandes S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135900, 9674, 'Os Casagrandes S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135901, 9674, 'Os Casagrandes S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/266547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135902, 9674, 'Os Casagrandes S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/266548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135903, 9674, 'Os Casagrandes S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/266549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135904, 9674, 'Os Casagrandes S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/266550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135905, 9674, 'Os Casagrandes S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/266551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135906, 9674, 'Os Casagrandes S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/266552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/25hN3OoVBkUd0nTkXnJCJnieRhe.jpg'),
(135907, 9675, 'P.O.L.I.C.I.A S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135908, 9675, 'P.O.L.I.C.I.A S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135909, 9675, 'P.O.L.I.C.I.A S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135910, 9675, 'P.O.L.I.C.I.A S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135911, 9675, 'P.O.L.I.C.I.A S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135912, 9675, 'P.O.L.I.C.I.A S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135913, 9675, 'P.O.L.I.C.I.A S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135914, 9675, 'P.O.L.I.C.I.A S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135915, 9675, 'P.O.L.I.C.I.A S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135916, 9675, 'P.O.L.I.C.I.A S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135917, 9675, 'P.O.L.I.C.I.A S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135918, 9675, 'P.O.L.I.C.I.A S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135919, 9675, 'P.O.L.I.C.I.A S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135920, 9676, 'P.O.L.I.C.I.A S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135921, 9676, 'P.O.L.I.C.I.A S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135922, 9676, 'P.O.L.I.C.I.A S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135923, 9676, 'P.O.L.I.C.I.A S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135924, 9676, 'P.O.L.I.C.I.A S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135925, 9676, 'P.O.L.I.C.I.A S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135926, 9676, 'P.O.L.I.C.I.A S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135927, 9676, 'P.O.L.I.C.I.A S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135928, 9676, 'P.O.L.I.C.I.A S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135929, 9676, 'P.O.L.I.C.I.A S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135930, 9676, 'P.O.L.I.C.I.A S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135931, 9676, 'P.O.L.I.C.I.A S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135932, 9676, 'P.O.L.I.C.I.A S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135933, 9677, 'P.O.L.I.C.I.A S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135934, 9677, 'P.O.L.I.C.I.A S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135935, 9677, 'P.O.L.I.C.I.A S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135936, 9677, 'P.O.L.I.C.I.A S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135937, 9677, 'P.O.L.I.C.I.A S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135938, 9677, 'P.O.L.I.C.I.A S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135939, 9677, 'P.O.L.I.C.I.A S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135940, 9677, 'P.O.L.I.C.I.A S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135941, 9677, 'P.O.L.I.C.I.A S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135942, 9677, 'P.O.L.I.C.I.A S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135943, 9677, 'P.O.L.I.C.I.A S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135944, 9677, 'P.O.L.I.C.I.A S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135945, 9677, 'P.O.L.I.C.I.A S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135946, 9678, 'P.O.L.I.C.I.A S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135947, 9678, 'P.O.L.I.C.I.A S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135948, 9678, 'P.O.L.I.C.I.A S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135949, 9678, 'P.O.L.I.C.I.A S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135950, 9678, 'P.O.L.I.C.I.A S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135951, 9678, 'P.O.L.I.C.I.A S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135952, 9678, 'P.O.L.I.C.I.A S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135953, 9678, 'P.O.L.I.C.I.A S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135954, 9678, 'P.O.L.I.C.I.A S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135955, 9678, 'P.O.L.I.C.I.A S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135956, 9678, 'P.O.L.I.C.I.A S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135957, 9678, 'P.O.L.I.C.I.A S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135958, 9678, 'P.O.L.I.C.I.A S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pZdtvjj4EmllVMCzq4aAQf4fLMN.jpg'),
(135959, 9679, 'Resgate 193 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSZX0QYhKaei5lezQgGtorom0UX.jpg'),
(135960, 9679, 'Resgate 193 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSZX0QYhKaei5lezQgGtorom0UX.jpg'),
(135961, 9679, 'Resgate 193 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSZX0QYhKaei5lezQgGtorom0UX.jpg'),
(135962, 9679, 'Resgate 193 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSZX0QYhKaei5lezQgGtorom0UX.jpg'),
(135963, 9679, 'Resgate 193 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSZX0QYhKaei5lezQgGtorom0UX.jpg'),
(135964, 9679, 'Resgate 193 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSZX0QYhKaei5lezQgGtorom0UX.jpg'),
(135965, 9679, 'Resgate 193 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSZX0QYhKaei5lezQgGtorom0UX.jpg'),
(135966, 9679, 'Resgate 193 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSZX0QYhKaei5lezQgGtorom0UX.jpg'),
(135967, 9679, 'Resgate 193 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSZX0QYhKaei5lezQgGtorom0UX.jpg'),
(135968, 9679, 'Resgate 193 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSZX0QYhKaei5lezQgGtorom0UX.jpg'),
(135969, 9679, 'Resgate 193 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSZX0QYhKaei5lezQgGtorom0UX.jpg'),
(135970, 9679, 'Resgate 193 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSZX0QYhKaei5lezQgGtorom0UX.jpg'),
(135971, 9679, 'Resgate 193 S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSZX0QYhKaei5lezQgGtorom0UX.jpg'),
(135972, 9680, 'Resgate 193 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMFWKJHgr2w9LJBKL66mpWKwSiO.jpg'),
(135973, 9680, 'Resgate 193 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMFWKJHgr2w9LJBKL66mpWKwSiO.jpg'),
(135974, 9680, 'Resgate 193 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMFWKJHgr2w9LJBKL66mpWKwSiO.jpg'),
(135975, 9680, 'Resgate 193 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMFWKJHgr2w9LJBKL66mpWKwSiO.jpg'),
(135976, 9680, 'Resgate 193 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMFWKJHgr2w9LJBKL66mpWKwSiO.jpg'),
(135977, 9680, 'Resgate 193 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMFWKJHgr2w9LJBKL66mpWKwSiO.jpg'),
(135978, 9680, 'Resgate 193 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMFWKJHgr2w9LJBKL66mpWKwSiO.jpg'),
(135979, 9680, 'Resgate 193 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMFWKJHgr2w9LJBKL66mpWKwSiO.jpg'),
(135980, 9680, 'Resgate 193 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMFWKJHgr2w9LJBKL66mpWKwSiO.jpg'),
(135981, 9680, 'Resgate 193 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMFWKJHgr2w9LJBKL66mpWKwSiO.jpg'),
(135982, 9680, 'Resgate 193 S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMFWKJHgr2w9LJBKL66mpWKwSiO.jpg'),
(135983, 9680, 'Resgate 193 S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMFWKJHgr2w9LJBKL66mpWKwSiO.jpg'),
(135984, 9680, 'Resgate 193 S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMFWKJHgr2w9LJBKL66mpWKwSiO.jpg'),
(135985, 9681, 'Sexy Beast S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wl8Lrv6HQQxJeWOaIW0hN1xJv7S.jpg'),
(135986, 9681, 'Sexy Beast S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qHqA2xAjr51NPyDFOsZwEDRXkVa.jpg'),
(135987, 9681, 'Sexy Beast S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jc8FmWSnupOG0DJCuvaz6LPFGA2.jpg'),
(135988, 9681, 'Sexy Beast S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2JmAIoadGdOYtYmxaIR0repbbgm.jpg'),
(135989, 9681, 'Sexy Beast S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/270819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2JmAIoadGdOYtYmxaIR0repbbgm.jpg'),
(135990, 9681, 'Sexy Beast S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/272613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2JmAIoadGdOYtYmxaIR0repbbgm.jpg'),
(135991, 9681, 'Sexy Beast S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2JmAIoadGdOYtYmxaIR0repbbgm.jpg'),
(135992, 9681, 'Sexy Beast S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/288213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2JmAIoadGdOYtYmxaIR0repbbgm.jpg'),
(135993, 9682, 'Socorro Imediato S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNdBx7WktoAQeBh6sl4U0Bp9D7K.jpg'),
(135994, 9682, 'Socorro Imediato S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNdBx7WktoAQeBh6sl4U0Bp9D7K.jpg'),
(135995, 9682, 'Socorro Imediato S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNdBx7WktoAQeBh6sl4U0Bp9D7K.jpg'),
(135996, 9682, 'Socorro Imediato S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNdBx7WktoAQeBh6sl4U0Bp9D7K.jpg'),
(135997, 9682, 'Socorro Imediato S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNdBx7WktoAQeBh6sl4U0Bp9D7K.jpg'),
(135998, 9682, 'Socorro Imediato S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNdBx7WktoAQeBh6sl4U0Bp9D7K.jpg'),
(135999, 9682, 'Socorro Imediato S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNdBx7WktoAQeBh6sl4U0Bp9D7K.jpg'),
(136000, 9682, 'Socorro Imediato S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNdBx7WktoAQeBh6sl4U0Bp9D7K.jpg'),
(136001, 9682, 'Socorro Imediato S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNdBx7WktoAQeBh6sl4U0Bp9D7K.jpg'),
(136002, 9682, 'Socorro Imediato S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNdBx7WktoAQeBh6sl4U0Bp9D7K.jpg'),
(136003, 9682, 'Socorro Imediato S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNdBx7WktoAQeBh6sl4U0Bp9D7K.jpg'),
(136004, 9682, 'Socorro Imediato S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNdBx7WktoAQeBh6sl4U0Bp9D7K.jpg'),
(136005, 9682, 'Socorro Imediato S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNdBx7WktoAQeBh6sl4U0Bp9D7K.jpg'),
(136006, 9682, 'Socorro Imediato S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNdBx7WktoAQeBh6sl4U0Bp9D7K.jpg'),
(136007, 9682, 'Socorro Imediato S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNdBx7WktoAQeBh6sl4U0Bp9D7K.jpg'),
(136008, 9683, 'The Misfit of Demon King Academy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8omTdSkGQAnvS2Teq7q4N5bTwe5.jpg'),
(136009, 9683, 'The Misfit of Demon King Academy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1wFdgrS3zyalpYcHzDfyaeG0CuC.jpg'),
(136010, 9683, 'The Misfit of Demon King Academy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AnxXHDup6Zsk6Hrei687HG23XIo.jpg'),
(136011, 9683, 'The Misfit of Demon King Academy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AwkGVYg9MdNJdM2Dq8bjjKXJriN.jpg'),
(136012, 9683, 'The Misfit of Demon King Academy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zYwRHNSuwvvBmOkLojOV9S7FzEk.jpg'),
(136013, 9683, 'The Misfit of Demon King Academy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r9FlPBh5F2uoylTeXyXpq9E4rEg.jpg'),
(136014, 9683, 'The Misfit of Demon King Academy S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c0TYBO1uYejw3jvc8jFvT8bV55h.jpg'),
(136015, 9683, 'The Misfit of Demon King Academy S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/58YiF76gkWgGEgaKkmBFM6yhpGH.jpg'),
(136016, 9683, 'The Misfit of Demon King Academy S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mVhYQ6CRbzgO9EXQVWwAFTtYy5H.jpg'),
(136017, 9683, 'The Misfit of Demon King Academy S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzMv3y3zNy0qWtVS49h3B4ND2oP.jpg'),
(136018, 9683, 'The Misfit of Demon King Academy S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9hBk8zpN1pcz9ZxO17ggYUcl2v.jpg'),
(136019, 9683, 'The Misfit of Demon King Academy S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m3D8kiRM7lGZMyCkpTD6PBgc6Sa.jpg'),
(136020, 9683, 'The Misfit of Demon King Academy S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aIYI1zeXtZ8O58jZIgqtcT9B7xf.jpg'),
(136021, 9684, 'Street Fighter II Victory S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pQvNsSL2jB7NHevojSALmVXlJXv.jpg'),
(136022, 9684, 'Street Fighter II Victory S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rtVRrorrD7dGwSLHJDV7CsOFT7r.jpg'),
(136023, 9684, 'Street Fighter II Victory S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qDfyKDszWL6tsyT6lErhndqBANz.jpg'),
(136024, 9684, 'Street Fighter II Victory S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4YAvTzyP8LU809Tyy9tbbE476w0.jpg'),
(136025, 9684, 'Street Fighter II Victory S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rDrHGnoFHVk73CmYl1XmZpyEIuF.jpg'),
(136026, 9684, 'Street Fighter II Victory S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4aLQosRhcjBEuszEMtXJ4xtf4hb.jpg'),
(136027, 9684, 'Street Fighter II Victory S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pLvFHxBNlmaEiL5QgJrcP0uJnfR.jpg'),
(136028, 9684, 'Street Fighter II Victory S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2rKp3lEFSHmqVmgVA2LknAzu3nX.jpg'),
(136029, 9684, 'Street Fighter II Victory S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/30k3hERLKG54klQ8xTPxydpzow.jpg'),
(136030, 9684, 'Street Fighter II Victory S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11nqMGaTlR6JDKjv48ylWOfq5t9.jpg'),
(136031, 9684, 'Street Fighter II Victory S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/alPONIT7E5iWrnFAWJYoGKLpxb6.jpg'),
(136032, 9684, 'Street Fighter II Victory S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ftZRrxAMkgEyxBo5TYT3R69fLsn.jpg'),
(136033, 9684, 'Street Fighter II Victory S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wsglhPLmH2f31V58gKAwprk61iI.jpg'),
(136034, 9684, 'Street Fighter II Victory S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gAfxrzoYe7BBaFVQLza6XDYAe5r.jpg'),
(136035, 9684, 'Street Fighter II Victory S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xReZTsuhiFRHdGhbMBQjGJnWeHQ.jpg'),
(136036, 9684, 'Street Fighter II Victory S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/npjzoLUvj7fP8DMZRTaXw83ir7K.jpg'),
(136037, 9684, 'Street Fighter II Victory S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/263177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Z3g5u44tRFjApovFQ1u7Urh84J.jpg'),
(136038, 9684, 'Street Fighter II Victory S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/263178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTdEFg04dn1PzbuzsK48nr50neX.jpg'),
(136039, 9684, 'Street Fighter II Victory S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/263179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6x4D2UL2fDXmaYCMxZ7McwCLGX8.jpg'),
(136040, 9684, 'Street Fighter II Victory S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/263180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fnuPTZEbwhNeteEpNYcuKshblbo.jpg'),
(136041, 9684, 'Street Fighter II Victory S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/263181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eATh2mGkpNqT6bWrx5vg7UAufPX.jpg'),
(136042, 9684, 'Street Fighter II Victory S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/263182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lXuE8mF9aWynM3g9obvdIkNbrEM.jpg'),
(136043, 9684, 'Street Fighter II Victory S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/263183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rNnoRdyEJe2XD3VEiWrP2BJdGnk.jpg'),
(136044, 9684, 'Street Fighter II Victory S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/263184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c7BaaHhluWeGX7SuByXVvFosOsl.jpg'),
(136045, 9684, 'Street Fighter II Victory S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/263185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kfclgUmnsle6kL9H3k1sXIZjEHz.jpg'),
(136046, 9684, 'Street Fighter II Victory S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/263186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2MkzOvT7srwHfIgUhyZnLy1TZgp.jpg'),
(136047, 9684, 'Street Fighter II Victory S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/263187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v83XV4pFOzqwSXmsTE8h8P6JYEj.jpg'),
(136048, 9684, 'Street Fighter II Victory S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/263188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZYSrPRugPnufYNH81wjlMNCjs3.jpg'),
(136049, 9684, 'Street Fighter II Victory S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/263189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lKSdz53xrj4N9048e0DLv8jxpM9.jpg'),
(136050, 9685, 'Bobs Burgers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3DeAa3L77itYEIimE5B89vQ6MQt.jpg'),
(136051, 9685, 'Bobs Burgers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sLBdzc5vhkpzaC2zbliCDfhy4sC.jpg'),
(136052, 9685, 'Bobs Burgers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sjga1n3XWs4pyyMFhO7MFpFJtce.jpg'),
(136053, 9685, 'Bobs Burgers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zUgLtUGSC4i0kHKZ64nKn2UIE5R.jpg'),
(136054, 9685, 'Bobs Burgers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ujbIFLc0OUd7ksHHUfeXIH6qUX8.jpg'),
(136055, 9685, 'Bobs Burgers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/puCe5pkmexktefy94dIHDokrTna.jpg'),
(136056, 9685, 'Bobs Burgers S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/592740.mkv', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o2MfRrFld8DPPpmlX5MFpCfpPd.jpg'),
(136057, 9685, 'Bobs Burgers S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pOyIPupKtnOcQyCoQQokju10a29.jpg'),
(136058, 9685, 'Bobs Burgers S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/592743.mkv', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tBtty7fSOcio7H1rEoASGXCuFJ4.jpg'),
(136059, 9685, 'Bobs Burgers S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/262902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5MAzihyDHe9bo1ac4gQiwZKstNn.jpg'),
(136060, 9685, 'Bobs Burgers S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/262903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5lHC32qlp43zlhlU65YSq3AzIft.jpg'),
(136061, 9685, 'Bobs Burgers S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/262904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wKjG69AF28TlLsrCVcx2x00MIEP.jpg'),
(136062, 9685, 'Bobs Burgers S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/262905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jd61dITSP4Njqyl9lSsMl3NssDD.jpg'),
(136063, 9686, 'Bobs Burgers S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6atQgUUrkqX8cwiiTSDLXHkWg65.jpg'),
(136064, 9686, 'Bobs Burgers S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzqhpgbYGdl5dhSTHPSYDVvVUax.jpg'),
(136065, 9686, 'Bobs Burgers S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mXLvoE6RCGZYsTYUWDOUiDKwH4w.jpg'),
(136066, 9686, 'Bobs Burgers S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cuh3T7lDKjWyMF1TziAIrbL9QDC.jpg'),
(136067, 9686, 'Bobs Burgers S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tj2LQODimA88RVo3V83YUeKhWSH.jpg'),
(136068, 9686, 'Bobs Burgers S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x0u2SLNcxarB7sK4AY3nG6AtxtC.jpg'),
(136069, 9686, 'Bobs Burgers S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d5c8d4Kf0vd8wU6v7TARNcujDTT.jpg'),
(136070, 9686, 'Bobs Burgers S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3yyRsYss4UzdiK766fohS0GuWwJ.jpg'),
(136071, 9686, 'Bobs Burgers S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/262914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xlqxwhDPsOvjl8LxkLnkY9hldGJ.jpg'),
(136072, 9687, 'Bobs Burgers S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aztF57FN6ZUa3hOYAogtE855w20.jpg'),
(136073, 9687, 'Bobs Burgers S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wUtxz5wRp3hERIA6vbOGEvKnwQ1.jpg'),
(136074, 9687, 'Bobs Burgers S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t8lY5OJXJvLQ6cig9V6QAzIWH3h.jpg'),
(136075, 9687, 'Bobs Burgers S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZehNlwsXV5BcLyLzkG99ttmoKi.jpg'),
(136076, 9687, 'Bobs Burgers S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1xBb3VPtGJcTBdWVRpvpHhkouk.jpg'),
(136077, 9687, 'Bobs Burgers S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AeqD3w2IKiOEL3GgJq4OfQYWLdb.jpg'),
(136078, 9687, 'Bobs Burgers S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oA4SehjDRBhVmRSOPOkdNqyOT70.jpg'),
(136079, 9687, 'Bobs Burgers S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dG8poW0yWXEgUYzOdLjey01bfih.jpg'),
(136080, 9687, 'Bobs Burgers S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/262923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhH8ecNFgvhVoX143AWzvaMNtyP.jpg'),
(136081, 9687, 'Bobs Burgers S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/262924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3JENwHvrM5yMyiwGNB9cfNqx2Ak.jpg'),
(136082, 9687, 'Bobs Burgers S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/262925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tuLN8ALXMyJufJjPY1swLAYEMVv.jpg'),
(136083, 9687, 'Bobs Burgers S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/262926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dxpPfl8SXkgrNEUgbgB9d6p0guO.jpg'),
(136084, 9687, 'Bobs Burgers S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/262927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/whN2qA9LdZ6Mnd2Ys4QD5yM2w7i.jpg'),
(136085, 9687, 'Bobs Burgers S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/262928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLMSip2CzMPv1UpYZhwS2Higmae.jpg'),
(136086, 9687, 'Bobs Burgers S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/262929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/liUcjx5DyMI4f1Srl2UN4MDQYcP.jpg'),
(136087, 9687, 'Bobs Burgers S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/262930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oUxH2cBJdyO8z2NCwqReNqRGdzA.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(136088, 9687, 'Bobs Burgers S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/262931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kj4S1ULn01e3JuiVQpsCiXIA67N.jpg'),
(136089, 9687, 'Bobs Burgers S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/262932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/plBjobLhwHqbqfHfOppmxo1I7GA.jpg'),
(136090, 9687, 'Bobs Burgers S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/262933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gB28iDTwM29W72rtzw32YRbfq5E.jpg'),
(136091, 9687, 'Bobs Burgers S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/262934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oENWjy88VxZ0CWa3KBxi8yNcEpc.jpg'),
(136092, 9687, 'Bobs Burgers S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/262935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTrCpg0PujOxRQXK4J5ZeGVvXKA.jpg'),
(136093, 9687, 'Bobs Burgers S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/262936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dPaRg6A3pec1tM7k4qDRzUhvqk2.jpg'),
(136094, 9687, 'Bobs Burgers S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/262937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zwHT8OLXu4xzzlhrjizwIXrXm18.jpg'),
(136095, 9688, 'Bobs Burgers S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1QY2hF4Rs9vG5GjSCvLkOXpatdD.jpg'),
(136096, 9688, 'Bobs Burgers S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/R3Gy31HNKvrQJPzEfzfBViG6KH.jpg'),
(136097, 9688, 'Bobs Burgers S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hd3rToxGtZA2e28JKXP08VsjSCg.jpg'),
(136098, 9688, 'Bobs Burgers S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/skxj9daSdDhCAE8eY0VAkfcs3Iu.jpg'),
(136099, 9688, 'Bobs Burgers S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6bLgidbs86NH8D1wMgbcq3rF66s.jpg'),
(136100, 9688, 'Bobs Burgers S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nEhODtL077ecVm8b8vS7pLUABto.jpg'),
(136101, 9688, 'Bobs Burgers S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ilrilmTQUUXhvayAGXQl91I1A2F.jpg'),
(136102, 9688, 'Bobs Burgers S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/osMe4l65SNW0eYxffvBZfYrVIzS.jpg'),
(136103, 9688, 'Bobs Burgers S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/262946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p5zmi1jI22BzYaN3RPasFuNfIc3.jpg'),
(136104, 9688, 'Bobs Burgers S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/262947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f82avPzl31tvgTKDEybgfP2RYKG.jpg'),
(136105, 9688, 'Bobs Burgers S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/262948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xbUMxlh4m466DX9jAlikJ9nond4.jpg'),
(136106, 9688, 'Bobs Burgers S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/262949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/UQgHiGiGVnz6GUC0lhYeb7qc3t.jpg'),
(136107, 9688, 'Bobs Burgers S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/262950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7wNH9fFiV3fQAcojYflxh8hFEkQ.jpg'),
(136108, 9688, 'Bobs Burgers S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/262951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lvRKrtGFZGfZVRQwHZdfVTJRnXs.jpg'),
(136109, 9688, 'Bobs Burgers S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/262952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/guNBLiyA7RN3ABTVa3BACtGRGp1.jpg'),
(136110, 9688, 'Bobs Burgers S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/262953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/daxskBBq3xmtEWSwvluu38R7SNj.jpg'),
(136111, 9688, 'Bobs Burgers S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/262954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oC7EF0lGUEWm8zLfIJsvsIkG02j.jpg'),
(136112, 9688, 'Bobs Burgers S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/262955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vaTPvv873cXrhn8lxeLb4FsK3g2.jpg'),
(136113, 9688, 'Bobs Burgers S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/262956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c4RRSHENAk079NRljLjBZR8xCdh.jpg'),
(136114, 9688, 'Bobs Burgers S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/262957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xyN9uWcYln8dslKHCwFS2scfB8.jpg'),
(136115, 9688, 'Bobs Burgers S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/262958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/616shs6XZZWNg7coTfUD6BPvPgn.jpg'),
(136116, 9688, 'Bobs Burgers S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/262959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3zErFLmhC42jOb2DEiYrVJn2hO8.jpg'),
(136117, 9689, 'Bobs Burgers S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ywYhVtZZcutDHFhX17TWhTOlSyT.jpg'),
(136118, 9689, 'Bobs Burgers S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ofFSZLH5vHo5hsU9MBCccrnDZDB.jpg'),
(136119, 9689, 'Bobs Burgers S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iXK2iHNL66T7zPzFFSJSp9m4CFJ.jpg'),
(136120, 9689, 'Bobs Burgers S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j9A9GsSTuDG4vncl8ZO7O8p3pqd.jpg'),
(136121, 9689, 'Bobs Burgers S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kMWrzSnVDCx6VkSfRqdc4DEJtwW.jpg'),
(136122, 9689, 'Bobs Burgers S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vPkTE7VcL5g3k8sERjToASDQj9j.jpg'),
(136123, 9689, 'Bobs Burgers S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dfd67UBeBAYCHZAlxPImPdKj1L4.jpg'),
(136124, 9689, 'Bobs Burgers S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/45qsL1I5pmXe960qLHMgLSDQRCh.jpg'),
(136125, 9689, 'Bobs Burgers S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/262968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qH4K8BgRhIshk5XZT0fUBmD52M5.jpg'),
(136126, 9689, 'Bobs Burgers S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/262969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1gouSZt9W040gPm4aoG7MkfTqHf.jpg'),
(136127, 9689, 'Bobs Burgers S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/262970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8cPNozbw8PNujM37D1FJGmn3Omh.jpg'),
(136128, 9689, 'Bobs Burgers S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/262971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/16d9brP4qaNqePFzXXTTeCGvuDc.jpg'),
(136129, 9689, 'Bobs Burgers S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/262972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vwuv38pWIFX34pvkEQjWAfBzY0L.jpg'),
(136130, 9689, 'Bobs Burgers S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/262973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qewuK1U9TRanlhmLcIRPW64FQrK.jpg'),
(136131, 9689, 'Bobs Burgers S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/262974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1f7bKRcwZFPzOmZfEREMhMBSqxF.jpg'),
(136132, 9689, 'Bobs Burgers S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/262975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yYITcbObCuh82ftrGvjpCXd8Pgj.jpg'),
(136133, 9689, 'Bobs Burgers S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/262976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1VG4fg2KlvhxdqSaSJRu4eVefpO.jpg'),
(136134, 9689, 'Bobs Burgers S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/262977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qHAtnyxXYnmDabLiGX5mBiP06DF.jpg'),
(136135, 9689, 'Bobs Burgers S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/262978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yVvXjXXO6zfrezu9fPH7q9JgyDf.jpg'),
(136136, 9689, 'Bobs Burgers S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/262979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fN3dzfU2vFeVCJFuxyuZkvVgjbY.jpg'),
(136137, 9689, 'Bobs Burgers S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/262980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qV3tstK14CF8jOVysZLsdlwVs1K.jpg'),
(136138, 9690, 'Bobs Burgers S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1JEse8M0xzP0aP0JSDu9x0Q71Wu.jpg'),
(136139, 9690, 'Bobs Burgers S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6X1HCTn8ZlfyHQXUTbfvFMIqDOh.jpg'),
(136140, 9690, 'Bobs Burgers S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4wIphvt3DXZkLYHiaIUKsCYWosh.jpg'),
(136141, 9690, 'Bobs Burgers S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oYTRcK45yp2OKUW7VrX0NgxbK4b.jpg'),
(136142, 9690, 'Bobs Burgers S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7GdXcCMx9h2zVbEdl20jQLk4ktR.jpg'),
(136143, 9690, 'Bobs Burgers S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sNSlqhduY37ZKItpeOaGPRXKKO5.jpg'),
(136144, 9690, 'Bobs Burgers S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tYiImgPaMW2a9uA7O8ZAsMAaryW.jpg'),
(136145, 9690, 'Bobs Burgers S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hCINEq40fDG8XNMvDUb2mTkz82o.jpg'),
(136146, 9690, 'Bobs Burgers S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/262989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eGXOewiV1166Xj1c8hdxLKFzg55.jpg'),
(136147, 9690, 'Bobs Burgers S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/262990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wCx18b6tzIP0xnP1uEvciBLn0kr.jpg'),
(136148, 9690, 'Bobs Burgers S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/262991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xHvZIWFFXHUKkLGHxJbPJoreBfd.jpg'),
(136149, 9690, 'Bobs Burgers S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/262992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ryOhsNzeGmSNKTVxQ304XEGnCZ8.jpg'),
(136150, 9690, 'Bobs Burgers S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/262993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/293lWsIsyHix8HXfybKhRnwO30r.jpg'),
(136151, 9690, 'Bobs Burgers S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/262994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v9IzvhRE2x6Edy03TCstgSbnTFW.jpg'),
(136152, 9690, 'Bobs Burgers S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/262995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1tyygql8FrW0FmM5wodFXxbY93o.jpg'),
(136153, 9690, 'Bobs Burgers S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/262996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wfMuvpzS7geUiu4pL1ZeKD1ESpy.jpg'),
(136154, 9690, 'Bobs Burgers S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/262997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uSiEixr5C4z4ZS5p7BLKDYZJ3Ip.jpg'),
(136155, 9690, 'Bobs Burgers S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/262998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9phCs4T2RDpe27uTCpR9dK18GAy.jpg'),
(136156, 9690, 'Bobs Burgers S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/262999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n58OyA9QOJWqhs5rq3jDdba747s.jpg'),
(136157, 9691, 'Bobs Burgers S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uMFbhRuipZvERWG8q6iLPJLXSck.jpg'),
(136158, 9691, 'Bobs Burgers S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iTN6F8YGjxTMDAAPoUq9RyJXuHz.jpg'),
(136159, 9691, 'Bobs Burgers S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4yzXKPymLUUin94lDmnPOxxRe7W.jpg'),
(136160, 9691, 'Bobs Burgers S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wTZQp7xr5KVlle1jUfClNgtHJT6.jpg'),
(136161, 9691, 'Bobs Burgers S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7JTDTFWqRvPXDkxVYnUHDBhktPh.jpg'),
(136162, 9691, 'Bobs Burgers S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vB6gk4LDnWRz1DMJpfy5QomhFTs.jpg'),
(136163, 9691, 'Bobs Burgers S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yA5AnTni87w7573sm1fIGWN0L3g.jpg'),
(136164, 9691, 'Bobs Burgers S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uKFC4C3VznqCVTutKWW9VVmZQxB.jpg'),
(136165, 9691, 'Bobs Burgers S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pgL6PMrefuJnCoPgUkQOdEjOQLK.jpg'),
(136166, 9691, 'Bobs Burgers S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rdWz79bHgyQCUo3ADMJZgpKa4yI.jpg'),
(136167, 9691, 'Bobs Burgers S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97PWDhFy2eMNhk0j4IeuMCLhAqD.jpg'),
(136168, 9691, 'Bobs Burgers S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/txFuygzWDtAJlKQP3cUHalzWfnF.jpg'),
(136169, 9691, 'Bobs Burgers S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bdX8k6eI1cXkDIs3MCeFdJn5ISm.jpg'),
(136170, 9691, 'Bobs Burgers S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x06iBIChUAdUHPrb5hX0kLqMR4B.jpg'),
(136171, 9691, 'Bobs Burgers S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9NgNl2PhrgFgSfgN90GL5yUShIy.jpg'),
(136172, 9691, 'Bobs Burgers S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6yjEuucIbpuKaCIcQSmRXIotWHH.jpg'),
(136173, 9691, 'Bobs Burgers S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/263016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z2BpA1tw3Pow5649poLe5WLCDn7.jpg'),
(136174, 9691, 'Bobs Burgers S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/263017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvVfEWWZyDfshFfiLrMdbnB7YfE.jpg'),
(136175, 9691, 'Bobs Burgers S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/263018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3181yrnfLkmmF32f2U16plqOieZ.jpg'),
(136176, 9691, 'Bobs Burgers S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/263019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/31AOE2r5ZKIY0ElWUuUHvn5n5jJ.jpg'),
(136177, 9691, 'Bobs Burgers S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/263020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fqPA65wbOhrGlfm34tr1sE7O2w5.jpg'),
(136178, 9691, 'Bobs Burgers S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/263021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qP20AiGMz4R34gJaYQ60Hzj2Wki.jpg'),
(136179, 9692, 'Bobs Burgers S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hWjgC0Ft0wPhommyJlIPewetpn.jpg'),
(136180, 9692, 'Bobs Burgers S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZkDYWn0QfdAsjcoI6WUcVFZZX2.jpg'),
(136181, 9692, 'Bobs Burgers S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ljdhEBXp9Wh6mzHYqTcRaEOWhvC.jpg'),
(136182, 9692, 'Bobs Burgers S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9wcTrA6rwViFIgXnABsUNqtb16m.jpg'),
(136183, 9692, 'Bobs Burgers S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xeSH96fMg3vxhtBMxNe0DEif8VQ.jpg'),
(136184, 9692, 'Bobs Burgers S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Fd78gzLdhmE3ffHXJkJW0uQ93v.jpg'),
(136185, 9692, 'Bobs Burgers S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gylhka1RYYT1iaZrE6rYnIJNsiI.jpg'),
(136186, 9692, 'Bobs Burgers S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hDJaOyks1fbiYnNkHUo3fVauOyF.jpg'),
(136187, 9692, 'Bobs Burgers S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mfVjmetgRToEciR9OdLhuhTftR3.jpg'),
(136188, 9692, 'Bobs Burgers S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lJyVJugl8rgrV9U5p0AnzweouT6.jpg'),
(136189, 9692, 'Bobs Burgers S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/14FneLwJIt9XEyxXfzrnp7UiP8X.jpg'),
(136190, 9692, 'Bobs Burgers S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wo57ioIryQUexWqvOPiqwymFcW9.jpg'),
(136191, 9692, 'Bobs Burgers S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mgJcGHtysuQquSqpnoh652HnufY.jpg'),
(136192, 9692, 'Bobs Burgers S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4U1Aq1xQGgX0ZqZTh0QHGiYnJk9.jpg'),
(136193, 9692, 'Bobs Burgers S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mYPfvJtR8S6spepBFZ38oSV49oi.jpg'),
(136194, 9692, 'Bobs Burgers S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jkEpS8OBwdXAim7VdVSPIyhPdjc.jpg'),
(136195, 9692, 'Bobs Burgers S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/263038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ka5PwNhTgEZlHFlccgM8zYWRueW.jpg'),
(136196, 9692, 'Bobs Burgers S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/263039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lmqkAhqsU6a1sUN8WTOVzZ6HNzu.jpg'),
(136197, 9692, 'Bobs Burgers S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/263040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6PWdRrXqfhjbUBQ5bDW7Ff7Y8Rb.jpg'),
(136198, 9692, 'Bobs Burgers S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/263041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2AkeKw0eCNWEunQsBdgYC02l4EP.jpg'),
(136199, 9692, 'Bobs Burgers S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/263042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8LEn6npUi9GuGWfdoyWglC4GcSv.jpg'),
(136200, 9693, 'Bobs Burgers S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xdxyYMIYHzn9G66Z6LSbEjYO0OJ.jpg'),
(136201, 9693, 'Bobs Burgers S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j4K78sSH5aB1LK3P4iMJ0RXEMS1.jpg'),
(136202, 9693, 'Bobs Burgers S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oMqYJGHiqgSmVs7A6XBwxsK6YYD.jpg'),
(136203, 9693, 'Bobs Burgers S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7foUP65AsHueojoBGl8pEiV4mx2.jpg'),
(136204, 9693, 'Bobs Burgers S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/45wKXnIg6Fqa5TyiqANeWEj9Jg9.jpg'),
(136205, 9693, 'Bobs Burgers S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iePd5yHlegdi2iIdeSQPj1nZAdc.jpg'),
(136206, 9693, 'Bobs Burgers S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/45MbxI3LJWZFZv83jlQZZu2fWoZ.jpg'),
(136207, 9693, 'Bobs Burgers S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/exrlmIO8l3vKabrK7dG1GtCBZmI.jpg'),
(136208, 9693, 'Bobs Burgers S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/szDv3RtBkt0KZFGUYU0nbFch3ex.jpg'),
(136209, 9693, 'Bobs Burgers S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aO2tuDyYJ4dLq8eacLryWhdTSnd.jpg'),
(136210, 9693, 'Bobs Burgers S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/81AmLa9LotlM84tGwhOLDzZoZzq.jpg'),
(136211, 9693, 'Bobs Burgers S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rP6hMynngIsxbtI6iiG0IrTtKWT.jpg'),
(136212, 9693, 'Bobs Burgers S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PG6lgAZkHhMS2qYOOweEZlepXK.jpg'),
(136213, 9693, 'Bobs Burgers S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fSKOig8SNdYroREQ4oD0DyNjCHX.jpg'),
(136214, 9693, 'Bobs Burgers S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ZUHyHM0fAlL8j63EZjZlrh7WCk.jpg'),
(136215, 9693, 'Bobs Burgers S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hrajLRJmATt3zoFlci89s29YsEZ.jpg'),
(136216, 9693, 'Bobs Burgers S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/263059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2f4Z95oovFMMddI2UpE3rAhzCRK.jpg'),
(136217, 9693, 'Bobs Burgers S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/263060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wDXZDUPIif4adQ12xkluhmiJid9.jpg'),
(136218, 9693, 'Bobs Burgers S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/263061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ccAcOV5DE1SFObRmmJXnr5QCZ4.jpg'),
(136219, 9693, 'Bobs Burgers S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/263062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wvvlBdFy5DQbVCRXIYN7fCC0qol.jpg'),
(136220, 9693, 'Bobs Burgers S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/263063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8XpziHdBmprnB7ghgDM9dJSpM78.jpg'),
(136221, 9693, 'Bobs Burgers S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/263064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hRuAF5yHZImBpkrFu2FJr6VeOjc.jpg'),
(136222, 9694, 'Bobs Burgers S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t4jNQxyUd5suQSTe6jQaGQLgEWa.jpg'),
(136223, 9694, 'Bobs Burgers S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9nO3RW71qaKGuRIoZQA4Dm34vPm.jpg'),
(136224, 9694, 'Bobs Burgers S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1HvgzaF0hOEdHnAkO5R4iuV2OLd.jpg'),
(136225, 9694, 'Bobs Burgers S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oTEEBOuVS1BdGK32yErZICOgiVv.jpg'),
(136226, 9694, 'Bobs Burgers S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bhOikuy20O9336gE4OJVbZgznX2.jpg'),
(136227, 9694, 'Bobs Burgers S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FKascXTy3UEfQGMLWPEpRYo8Xz.jpg'),
(136228, 9694, 'Bobs Burgers S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5bFvnv0nH2Z0ydIGyIKnhV8WoE0.jpg'),
(136229, 9694, 'Bobs Burgers S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h4j3XpU3h9yZ1Ce4sr2ALsTMiuA.jpg'),
(136230, 9694, 'Bobs Burgers S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i1mIkkOuq1tPaGgSQYSjVjjKHmJ.jpg'),
(136231, 9694, 'Bobs Burgers S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4X19LBhmEhp7yb3CvQWb77JsGOH.jpg'),
(136232, 9694, 'Bobs Burgers S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mpBpkxSbl9fqWZsTdo396jUZZBd.jpg'),
(136233, 9694, 'Bobs Burgers S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tCLCJA7bIG0hFChZrnUE5v998bR.jpg'),
(136234, 9694, 'Bobs Burgers S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cg0FUqXOGHMfulStylH5S3lrli7.jpg'),
(136235, 9694, 'Bobs Burgers S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pdi0GlJmh20JWmOmkmaFzSP3BpS.jpg'),
(136236, 9694, 'Bobs Burgers S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7iDy4IPIxAOSMC4CyB38IvC6GVE.jpg'),
(136237, 9694, 'Bobs Burgers S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cxkyhXaTYTXf7ZUmoxrA7Ne9po8.jpg'),
(136238, 9694, 'Bobs Burgers S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/263081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xsCNpGl49eyhf2ZhraOQomdx1PB.jpg'),
(136239, 9694, 'Bobs Burgers S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/263082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kc1ZImIECUTMO2PLDMAeowPei9.jpg'),
(136240, 9694, 'Bobs Burgers S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/263083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3xbDI7snwNx0S3ol8P4xB2VaQB.jpg'),
(136241, 9694, 'Bobs Burgers S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/263084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bNq8y3j4wH4hFxyWX9nd4bb9i5g.jpg'),
(136242, 9694, 'Bobs Burgers S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/263085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u6p95NhZUOnkYRsCA0w4Atet3kO.jpg'),
(136243, 9694, 'Bobs Burgers S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/263086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2YpX5sHay34qu89igeFLZH97fCG.jpg'),
(136244, 9695, 'Bobs Burgers S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wRCdQ4cJFJrn0SdQspmnMqv8IVF.jpg'),
(136245, 9695, 'Bobs Burgers S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bRMOX8rS7AYADSdncM0i8Ee1krl.jpg'),
(136246, 9695, 'Bobs Burgers S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fSGLSqWdZzZCobXBCP4iotsiU7A.jpg'),
(136247, 9695, 'Bobs Burgers S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/at6mLBTKlzIfSBbzJVt3BEkr0oM.jpg'),
(136248, 9695, 'Bobs Burgers S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w4X6Bhn4l5f2U6W6xQnTFzt5DML.jpg'),
(136249, 9695, 'Bobs Burgers S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uOnW7U9oGPA7dtcNwBkHDamU4Se.jpg'),
(136250, 9695, 'Bobs Burgers S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Z9j5SxZdqWJM0sK7KDYkz3XKb0.jpg'),
(136251, 9695, 'Bobs Burgers S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7VLulXnp0izg27kJULY16NgmM2R.jpg'),
(136252, 9695, 'Bobs Burgers S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fEbyXj4XnlMuFp2eM4XUnyPyF5u.jpg'),
(136253, 9695, 'Bobs Burgers S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/foTOCfFitkbLSSYubFmhg0vEi0G.jpg'),
(136254, 9695, 'Bobs Burgers S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1vPusZClzMHVlLBfFLCE7WTrcS2.jpg'),
(136255, 9695, 'Bobs Burgers S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mMy63PHPoktaZgWBfI75hCtkeDJ.jpg'),
(136256, 9695, 'Bobs Burgers S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/58xkVSXtilIZZMfWQkTZkgwKPzm.jpg'),
(136257, 9695, 'Bobs Burgers S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/20RNocWBH4yY7rtb8mD1msfwUlO.jpg'),
(136258, 9695, 'Bobs Burgers S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rdCXWpmXDQbJVzBkhy7yKmgULah.jpg'),
(136259, 9695, 'Bobs Burgers S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d6IAvTpcXsfljrGsuQdaC7welLM.jpg'),
(136260, 9695, 'Bobs Burgers S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/263103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8yfKqWqepYpoaLmfOu2ieV6ijNc.jpg'),
(136261, 9695, 'Bobs Burgers S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/263104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uGSA7jVQst8twegCH3e0Dx4CBgh.jpg'),
(136262, 9695, 'Bobs Burgers S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/263105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cIsmlT2wbDOkgNNIIRnof7YdZmA.jpg'),
(136263, 9695, 'Bobs Burgers S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/263106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lFKeWfTrG5z8XxobhdVWC2kkWzz.jpg'),
(136264, 9695, 'Bobs Burgers S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/263107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kn2G2QdIofhDiDqedYdPnCBWXiS.jpg'),
(136265, 9695, 'Bobs Burgers S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/263108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4vgrFJHLVKDqiBjZVo67QNvnaj4.jpg'),
(136266, 9696, 'Bobs Burgers S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eEXyQG6NOLNmLSHTD3lMKsGstiJ.jpg'),
(136267, 9696, 'Bobs Burgers S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pcML8kgNfrJy6uAYuC0QURA5hp2.jpg'),
(136268, 9696, 'Bobs Burgers S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFVjXAkrWGS5ahgccgDkunxfGGC.jpg'),
(136269, 9696, 'Bobs Burgers S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eipdR0gKRyMx7Nwq12E5dGHb1Xy.jpg'),
(136270, 9696, 'Bobs Burgers S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rxFlsyi2ScGS0oe8O7iaDly2mqG.jpg'),
(136271, 9696, 'Bobs Burgers S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/isoKJuPN6rvroYNPm6Grulj4Kgm.jpg'),
(136272, 9696, 'Bobs Burgers S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkwIDCHMo0WoMFAxYjscMRAECVF.jpg'),
(136273, 9696, 'Bobs Burgers S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Svr9GTCrtTC0yByUiKUGGTLG7G.jpg'),
(136274, 9696, 'Bobs Burgers S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aB7tkhHBLfumFlHY58WBd3ISzZf.jpg'),
(136275, 9696, 'Bobs Burgers S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1vSfBfNJ3r8jySdFHPBmfr7ICkH.jpg'),
(136276, 9696, 'Bobs Burgers S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sJUiXrSHLuCsFpGo2lsowUK1ExP.jpg'),
(136277, 9696, 'Bobs Burgers S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r6MNH9LOickhWLVswSARD7i6MW.jpg'),
(136278, 9696, 'Bobs Burgers S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9m0wr7OlxuV6HnlFGqHe2bivMJE.jpg'),
(136279, 9696, 'Bobs Burgers S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rOKYTXpQKADBqN3CUdTJfCN8kEk.jpg'),
(136280, 9696, 'Bobs Burgers S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uK2fmPaZ0CRzWiZjFMvXDMLSLdH.jpg'),
(136281, 9696, 'Bobs Burgers S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/quJoJhE34qwZmpmOv3Ul3ZyScWA.jpg'),
(136282, 9696, 'Bobs Burgers S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/263125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c6yQ7SJ5Ctmwi1nxPRmbgh02UlO.jpg'),
(136283, 9696, 'Bobs Burgers S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/263126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/564XbDkM52982IUd1PMhkHu7Rjv.jpg'),
(136284, 9696, 'Bobs Burgers S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/263127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2I1QwIUnYUC1pcoFYzWyGhPI5T1.jpg'),
(136285, 9696, 'Bobs Burgers S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/263128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qhR61CbtFEPl05Eu30wLV6rsOb.jpg'),
(136286, 9696, 'Bobs Burgers S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/263129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Khvj4VZouvFW6h65SlD8U6g8YD.jpg'),
(136287, 9696, 'Bobs Burgers S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/263130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9dkfMxCJY5NmjTqIxmIFPXCgvbU.jpg'),
(136288, 9697, 'Bobs Burgers S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4PdElfT1FkKVyDqoghAyH14tqAH.jpg'),
(136289, 9697, 'Bobs Burgers S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7YzFYA8B3WAp96mEajNqCLKKjT4.jpg'),
(136290, 9697, 'Bobs Burgers S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dETKwdV0shdOn9YgVfgcJxWVA7i.jpg'),
(136291, 9697, 'Bobs Burgers S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gdIV4MYWyBUiMgGGObiW7flmPNw.jpg'),
(136292, 9697, 'Bobs Burgers S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xp7p0f3NVhxDQ2GeDlFsMnPc1PW.jpg'),
(136293, 9697, 'Bobs Burgers S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nTzjmBRp7a0994J3QGvqbkxDsvc.jpg'),
(136294, 9697, 'Bobs Burgers S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvt4DfpRu2X5YJAbhelfE6iq9eH.jpg'),
(136295, 9697, 'Bobs Burgers S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yH9R5sGa0hl2mF2yGGC89wOIyDn.jpg'),
(136296, 9697, 'Bobs Burgers S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/263139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/klB4hvgmLlvwYg7RXl3Mr4s7gbm.jpg'),
(136297, 9697, 'Bobs Burgers S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/263140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2XTPcYgayn8uB29YCcAymjsKJAh.jpg'),
(136298, 9697, 'Bobs Burgers S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/263141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i6Pzr8Cli5qEE14dzTA7ie1bbdM.jpg'),
(136299, 9697, 'Bobs Burgers S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/263142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7yhUaQK8rcNnTaxau22EuW5AW6J.jpg'),
(136300, 9697, 'Bobs Burgers S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/263143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pUeTk2AQFWWjm62U5Po4TsRIvC2.jpg'),
(136301, 9697, 'Bobs Burgers S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/263144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x1XLOeMr3DI2rxY3cqkOPMhh59t.jpg'),
(136302, 9697, 'Bobs Burgers S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/263145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZcNHCxt9qzTHJsD24AtvrKPME0.jpg'),
(136303, 9697, 'Bobs Burgers S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/263146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zrBqssTFObpytPInKNYDkRK14Wc.jpg'),
(136304, 9697, 'Bobs Burgers S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/263147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y6KNGrH0PYlnmBdrC6igJM1tMKH.jpg'),
(136305, 9697, 'Bobs Burgers S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/263148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aJQOeBmPvWKVQSrElxAPp0fgD1d.jpg'),
(136306, 9697, 'Bobs Burgers S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/263149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cdARqTrs8sVpZbTLzoYmjXhZJS1.jpg'),
(136307, 9697, 'Bobs Burgers S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/263150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3qvCILicizHghvCo1WHpV3TIm8P.jpg'),
(136308, 9697, 'Bobs Burgers S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/263151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tnUYz1IbjPVAQjBKpjSXAyqAL9r.jpg'),
(136309, 9697, 'Bobs Burgers S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/263152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zJ99yfc8HvQqE0x583EPOp3jKzY.jpg'),
(136310, 9698, 'Bobs Burgers S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/263153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2REWlwjnxX03nRLQ65rsG3gaq7M.jpg'),
(136311, 9698, 'Bobs Burgers S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/263154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vfMloeuVUdVIOE8RCi4YmHWiOjK.jpg'),
(136312, 9698, 'Bobs Burgers S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/263155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x0gr35hyiyOW6yrikiP0Ylv4zqj.jpg'),
(136313, 9698, 'Bobs Burgers S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/263156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSET3WXK7hhqi7NnBPQH0dKvURa.jpg'),
(136314, 9698, 'Bobs Burgers S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/263157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ivNwmBuso4rbStqqpFqcC2AgrKd.jpg'),
(136315, 9698, 'Bobs Burgers S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/263158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dnQj5lFOyIMFsyCmMGyXIhcSW1e.jpg'),
(136316, 9698, 'Bobs Burgers S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/263159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iBWvQKz6QlYXzoopUmuuxIztVDB.jpg'),
(136317, 9698, 'Bobs Burgers S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/263160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5cxRaAOefvM6RsjjfsthCpkCKgE.jpg'),
(136318, 9699, 'Bobs Burgers S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/814423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/couFnWryh9JRmmfDyPU6hUyTKIa.jpg'),
(136319, 9699, 'Bobs Burgers S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/839386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/couFnWryh9JRmmfDyPU6hUyTKIa.jpg'),
(136320, 9699, 'Bobs Burgers S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/839387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/couFnWryh9JRmmfDyPU6hUyTKIa.jpg'),
(136321, 9699, 'Bobs Burgers S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/839388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/couFnWryh9JRmmfDyPU6hUyTKIa.jpg'),
(136322, 9699, 'Bobs Burgers S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/859955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/couFnWryh9JRmmfDyPU6hUyTKIa.jpg'),
(136323, 9699, 'Bobs Burgers S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/881988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/couFnWryh9JRmmfDyPU6hUyTKIa.jpg'),
(136324, 9699, 'Bobs Burgers S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/881989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/couFnWryh9JRmmfDyPU6hUyTKIa.jpg'),
(136325, 9699, 'Bobs Burgers S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/881990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/couFnWryh9JRmmfDyPU6hUyTKIa.jpg'),
(136326, 9699, 'Bobs Burgers S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/881991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/couFnWryh9JRmmfDyPU6hUyTKIa.jpg'),
(136327, 9699, 'Bobs Burgers S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/881992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/couFnWryh9JRmmfDyPU6hUyTKIa.jpg'),
(136328, 9699, 'Bobs Burgers S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/881993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/couFnWryh9JRmmfDyPU6hUyTKIa.jpg'),
(136329, 9699, 'Bobs Burgers S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/881994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/couFnWryh9JRmmfDyPU6hUyTKIa.jpg'),
(136330, 9700, 'Bobs Burgers S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/891893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/couFnWryh9JRmmfDyPU6hUyTKIa.jpg'),
(136331, 9700, 'Bobs Burgers S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/893482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/couFnWryh9JRmmfDyPU6hUyTKIa.jpg'),
(136332, 9700, 'Bobs Burgers S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/894237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/couFnWryh9JRmmfDyPU6hUyTKIa.jpg'),
(136333, 9700, 'Bobs Burgers S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/896498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/couFnWryh9JRmmfDyPU6hUyTKIa.jpg'),
(136334, 9700, 'Bobs Burgers S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/897471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/couFnWryh9JRmmfDyPU6hUyTKIa.jpg'),
(136335, 9701, 'Expatriadas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/264970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7PbQdHRdUkId0xp3itDZu47GHJE.jpg'),
(136336, 9701, 'Expatriadas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/264971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nzqJpBxJwuDalpPQGFRdGUj0xPs.jpg'),
(136337, 9701, 'Expatriadas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/264972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwKvXltGX5j1g1Hg3ARPfGcfvpF.jpg'),
(136338, 9701, 'Expatriadas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/271442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwKvXltGX5j1g1Hg3ARPfGcfvpF.jpg'),
(136339, 9701, 'Expatriadas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/276641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwKvXltGX5j1g1Hg3ARPfGcfvpF.jpg'),
(136340, 9701, 'Expatriadas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/281198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwKvXltGX5j1g1Hg3ARPfGcfvpF.jpg'),
(136341, 9702, 'Mestres do Ar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/270333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cZCokKFtaCDCkuTbP3Px8PKMcHE.jpg'),
(136342, 9702, 'Mestres do Ar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/270334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6tMtKcbZbxjHNGlOdx1AqcvxYzw.jpg'),
(136343, 9702, 'Mestres do Ar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/270335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2LbDCJHciI3pqcy83twtmvrJfk2.jpg'),
(136344, 9702, 'Mestres do Ar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/271040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2LbDCJHciI3pqcy83twtmvrJfk2.jpg'),
(136345, 9702, 'Mestres do Ar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/276364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2LbDCJHciI3pqcy83twtmvrJfk2.jpg'),
(136346, 9702, 'Mestres do Ar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/280746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2LbDCJHciI3pqcy83twtmvrJfk2.jpg'),
(136347, 9702, 'Mestres do Ar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/287034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2LbDCJHciI3pqcy83twtmvrJfk2.jpg'),
(136348, 9702, 'Mestres do Ar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/296242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2LbDCJHciI3pqcy83twtmvrJfk2.jpg'),
(136349, 9702, 'Mestres do Ar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/302492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2LbDCJHciI3pqcy83twtmvrJfk2.jpg'),
(136350, 9703, 'Mestres do Universo A Revolucao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c3vbuHtNGfkf42aRfV7hgvtEg9O.jpg'),
(136351, 9703, 'Mestres do Universo A Revolucao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfCIP2invDTEByl3lKUqybSaZF8.jpg'),
(136352, 9703, 'Mestres do Universo A Revolucao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/daVTLVGoGYQYYA3qlC2GNmFGWtQ.jpg'),
(136353, 9703, 'Mestres do Universo A Revolucao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8lZSb3aWitHZAExqI6vAL2mI9z3.jpg'),
(136354, 9703, 'Mestres do Universo A Revolucao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/guYfPfxGrESkhcU9h5oRyffoD16.jpg'),
(136355, 9704, 'People Magazine Alem da Noticia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/269016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bZLXDiN2nEPVfRlBNq2s92FEfVw.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(136356, 9704, 'People Magazine Alem da Noticia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/269017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vc7bPI1c6Te2VbhGb7CJ4o7pput.jpg'),
(136357, 9704, 'People Magazine Alem da Noticia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/269018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aqTQrMQymspi289DhLrrxrnrNAE.jpg'),
(136358, 9704, 'People Magazine Alem da Noticia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/269019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9WAPdE3DPGKR2YA79yiWUpiyHBj.jpg'),
(136359, 9704, 'People Magazine Alem da Noticia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/269020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d0cVDIYDGSBHfPdS5qQwJOdcbgV.jpg'),
(136360, 9704, 'People Magazine Alem da Noticia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/269021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z2bzQffvc8hy7yixQBOFCQz7wOX.jpg'),
(136361, 9704, 'People Magazine Alem da Noticia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/269022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jA6fU1ZUQrlLR03pbOVO0zWnQlm.jpg'),
(136362, 9704, 'People Magazine Alem da Noticia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/269023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dcQ4UiJjXoznBebEwZcLLtYLtMQ.jpg'),
(136363, 9704, 'People Magazine Alem da Noticia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/269024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d7qmgYOURZ1RenpAg8QxW49UiGG.jpg'),
(136364, 9704, 'People Magazine Alem da Noticia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/269025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mxbTTVR5nr8EPit3bFsRccvS2TK.jpg'),
(136365, 9704, 'People Magazine Alem da Noticia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/269026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rW9s1HS92EtQ7xBjjmmjtGsRUoh.jpg'),
(136366, 9705, 'People Magazine Alem da Noticia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/269027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sO3DIgjvO9QheSKJRAGsoEjw5gc.jpg'),
(136367, 9705, 'People Magazine Alem da Noticia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/269028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tAPGKkM7HOMb5xlAacsHxKSgzve.jpg'),
(136368, 9705, 'People Magazine Alem da Noticia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/269029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w4ixiC0otTJMlWqpPueZcxJ26u4.jpg'),
(136369, 9705, 'People Magazine Alem da Noticia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/269030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rKI9N187m5S7RuTkIWJDti20OB1.jpg'),
(136370, 9705, 'People Magazine Alem da Noticia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/269031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pCnK4emLZQgBotPoRvLeHtwqoLw.jpg'),
(136371, 9705, 'People Magazine Alem da Noticia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/269032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/37NiAhIWMY4h2k6xosEEW9Hc9yB.jpg'),
(136372, 9705, 'People Magazine Alem da Noticia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/269033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dznEJcsK9jTa5qM3XPdV82RxNCE.jpg'),
(136373, 9705, 'People Magazine Alem da Noticia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/269034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dFdpWYjJlpVUJiw2V2cxBghmUHq.jpg'),
(136374, 9705, 'People Magazine Alem da Noticia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/269035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5vCqlWK31846WQZOiNEP6LCCbO.jpg'),
(136375, 9705, 'People Magazine Alem da Noticia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/269036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hGJi8do3I1tSe4SgtFqVy3sgO2a.jpg'),
(136376, 9705, 'People Magazine Alem da Noticia S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/269037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/emp5pPaq4et7j1kfwpEr5yCAD4U.jpg'),
(136377, 9705, 'People Magazine Alem da Noticia S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/269038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/86Ye7EsESnGZ0o2hOu6C0baUfv7.jpg'),
(136378, 9706, 'People Magazine Alem da Noticia S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/269039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/itYYvatWLOCkCuc0azUKSzpFG4z.jpg'),
(136379, 9706, 'People Magazine Alem da Noticia S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/269040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oS9wVG9W2RqFVE7UKP8oLUiAH9G.jpg'),
(136380, 9706, 'People Magazine Alem da Noticia S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/269041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uDCKTRhHkkQYNORNweHt9PlTUxt.jpg'),
(136381, 9706, 'People Magazine Alem da Noticia S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/269042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cEFiP09zBiBIki1I5Xk0kjxUvYX.jpg'),
(136382, 9706, 'People Magazine Alem da Noticia S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/269043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wccidyWeokpIvmUewfyCJKX6aGJ.jpg'),
(136383, 9706, 'People Magazine Alem da Noticia S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/269044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4iwuZbLjbnPFuvBNnZ184MnH8lx.jpg'),
(136384, 9706, 'People Magazine Alem da Noticia S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/269045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AfJJpBosphSfpmkxnemDShFoFsD.jpg'),
(136385, 9706, 'People Magazine Alem da Noticia S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/269046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6qbpFI0JYZ34skpA4NrK1T9xHwo.jpg'),
(136386, 9706, 'People Magazine Alem da Noticia S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/269047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zGzwHUJKu8ogZuCFzuDRaeMNRwu.jpg'),
(136387, 9706, 'People Magazine Alem da Noticia S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/269048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wmqU7yoUuJhGfVL7mwnRYeelnc.jpg'),
(136388, 9706, 'People Magazine Alem da Noticia S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/269049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/puvMA2V5KCQ8AE4SyTOn4Qo9R3W.jpg'),
(136389, 9706, 'People Magazine Alem da Noticia S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/269050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pwqTmBHnU5kEmt8NsPQmNJdcBKP.jpg'),
(136390, 9706, 'People Magazine Alem da Noticia S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/269051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gGLtyvGqxa47BUqWhcNfG4eNbB1.jpg'),
(136391, 9706, 'People Magazine Alem da Noticia S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/269052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ba7qXrHjbIzQkD4z38yiH70KLIw.jpg'),
(136392, 9707, 'People Magazine Alem da Noticia S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/269053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jiQ63nvEU9kk7xt72knFegEjV0T.jpg'),
(136393, 9707, 'People Magazine Alem da Noticia S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/269054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ArgJ6C2fjwpHuJQQMLgI3HCW5J.jpg'),
(136394, 9707, 'People Magazine Alem da Noticia S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/269055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o28pVgANki4zlBZdeo2YCX1R1Ua.jpg'),
(136395, 9707, 'People Magazine Alem da Noticia S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/269056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2li9nCfQ90hBww8pvhKkhj1Cfr.jpg'),
(136396, 9707, 'People Magazine Alem da Noticia S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/269057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fINNQxhDs6s9GgRArluZDSswD7V.jpg'),
(136397, 9707, 'People Magazine Alem da Noticia S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/269058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mPIGEjQN2kwz7F7gnG3eyJUiv0z.jpg'),
(136398, 9707, 'People Magazine Alem da Noticia S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/269059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tOrwxuu7sSgkx8XfaZ2vunq8Kqe.jpg'),
(136399, 9707, 'People Magazine Alem da Noticia S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/269060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lQ9rAhB8HJGLVlMMnzp4dP2dRbb.jpg'),
(136400, 9707, 'People Magazine Alem da Noticia S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/269061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pcj2qzF0q79WfmzoPYk49KegEPY.jpg'),
(136401, 9707, 'People Magazine Alem da Noticia S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/269062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBKkvuXAfUkysos5EDz8pbKcWhc.jpg'),
(136402, 9707, 'People Magazine Alem da Noticia S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/269063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/isuLE3xOiwIwi4NIuy4BvNAvQBp.jpg'),
(136403, 9707, 'People Magazine Alem da Noticia S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/269064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7038Rw656f096NzI0lEyItBVujF.jpg'),
(136404, 9708, 'People Magazine Alem da Noticia S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/269065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z4LWETcSWFf97UTbmDKvfIRzEzM.jpg'),
(136405, 9708, 'People Magazine Alem da Noticia S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/269066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2vOaE7Mramu0Ore1oJRX8R52MDy.jpg'),
(136406, 9708, 'People Magazine Alem da Noticia S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/269067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9m2JwYOCAhqCYnrXtMOq4TM7OtT.jpg'),
(136407, 9708, 'People Magazine Alem da Noticia S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/269068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x9nWCobPLMWuXhPJ9tgLFxesl52.jpg'),
(136408, 9708, 'People Magazine Alem da Noticia S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/269069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vp0TUcMPrDQUvy97rwCP7O0DPJF.jpg'),
(136409, 9708, 'People Magazine Alem da Noticia S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/269070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCwUrvUMuvdectK1mko8yLIShoj.jpg'),
(136410, 9708, 'People Magazine Alem da Noticia S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/269071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nWKKKj1fFRxOsmTzXes7WvO1h9I.jpg'),
(136411, 9708, 'People Magazine Alem da Noticia S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/269072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5OOkYxgNwhvuCHZ5hZscHpcJqKp.jpg'),
(136412, 9708, 'People Magazine Alem da Noticia S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/269073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o3jYh7eU4JEOq45DCCZcFiK4QhN.jpg'),
(136413, 9708, 'People Magazine Alem da Noticia S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/269074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ekUS9wb2Zt3hsFiYxfmYZ2tzMkK.jpg'),
(136414, 9708, 'People Magazine Alem da Noticia S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/269075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i48jGxfU1zUT8c3vMJe5QOFaluz.jpg'),
(136415, 9708, 'People Magazine Alem da Noticia S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/269076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rkRmG8gyWZqG70PZxe3ycrcGa6n.jpg'),
(136416, 9709, 'People Magazine Alem da Noticia S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/269077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nXKDr1aMDci7F19muzmIwXA7e5s.jpg'),
(136417, 9709, 'People Magazine Alem da Noticia S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/269078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hHVfb6uQyuuBhAs3e0aD1hoXpZH.jpg'),
(136418, 9709, 'People Magazine Alem da Noticia S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/269079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9PACWe2qaWOL2X3ukYBfNjboIqO.jpg'),
(136419, 9709, 'People Magazine Alem da Noticia S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/269080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6RsG4ckBrgBXYa5VK24o8S6BtRU.jpg'),
(136420, 9709, 'People Magazine Alem da Noticia S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/269081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4rDMDGc0ttIrJ1JI0t2tAL1oUGr.jpg'),
(136421, 9709, 'People Magazine Alem da Noticia S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/269082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mjx8vYtQT2wPYC2VAsdPt9UHY5i.jpg'),
(136422, 9709, 'People Magazine Alem da Noticia S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/269083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l4KjQVfrUoiHhNAdF35TZ2jKSy7.jpg'),
(136423, 9709, 'People Magazine Alem da Noticia S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/269084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNAnjwMlTh0D8UYBqgAFw8FVHbT.jpg'),
(136424, 9709, 'People Magazine Alem da Noticia S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/269085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eLICDpnmDAm82fKpSRjjkruUJPG.jpg'),
(136425, 9709, 'People Magazine Alem da Noticia S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/269086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2BEfFEv8Vp5QQGi5C0aqGVax4Ku.jpg'),
(136426, 9709, 'People Magazine Alem da Noticia S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/269087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lJ3CmqevetRdBek8clqvCvWXUJc.jpg'),
(136427, 9709, 'People Magazine Alem da Noticia S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/269088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AtPL097q3GJnMiGYAFBn6dL5w8Y.jpg'),
(136428, 9709, 'People Magazine Alem da Noticia S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/269089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136429, 9709, 'People Magazine Alem da Noticia S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/269090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136430, 9709, 'People Magazine Alem da Noticia S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/595002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136431, 9710, 'People Magazine Alem da Noticia S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/303472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136432, 9710, 'People Magazine Alem da Noticia S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/303473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136433, 9710, 'People Magazine Alem da Noticia S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/269092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eeRDp4vRD0E2y9fn9uyPh9X6dAU.jpg'),
(136434, 9710, 'People Magazine Alem da Noticia S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/595006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136435, 9710, 'People Magazine Alem da Noticia S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/595007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136436, 9710, 'People Magazine Alem da Noticia S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/270987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136437, 9710, 'People Magazine Alem da Noticia S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/275235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136438, 9710, 'People Magazine Alem da Noticia S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/279598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136439, 9710, 'People Magazine Alem da Noticia S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/285898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136440, 9710, 'People Magazine Alem da Noticia S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/295433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136441, 9710, 'People Magazine Alem da Noticia S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/305997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136442, 9710, 'People Magazine Alem da Noticia S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/305998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136443, 9711, 'People Magazine Alem da Noticia S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/809123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136444, 9711, 'People Magazine Alem da Noticia S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/809124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136445, 9711, 'People Magazine Alem da Noticia S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/809125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136446, 9711, 'People Magazine Alem da Noticia S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/809126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136447, 9711, 'People Magazine Alem da Noticia S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/809127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136448, 9711, 'People Magazine Alem da Noticia S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/809128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136449, 9711, 'People Magazine Alem da Noticia S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/809129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136450, 9711, 'People Magazine Alem da Noticia S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/809130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136451, 9711, 'People Magazine Alem da Noticia S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/809131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136452, 9711, 'People Magazine Alem da Noticia S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/809132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136453, 9711, 'People Magazine Alem da Noticia S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/809133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136454, 9711, 'People Magazine Alem da Noticia S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/809134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umzp1wlXZKWqtsmDeo4VUX5Rf6V.jpg'),
(136455, 9712, 'SOS Restaurante S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136456, 9712, 'SOS Restaurante S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136457, 9712, 'SOS Restaurante S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136458, 9712, 'SOS Restaurante S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136459, 9712, 'SOS Restaurante S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136460, 9712, 'SOS Restaurante S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136461, 9712, 'SOS Restaurante S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136462, 9712, 'SOS Restaurante S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136463, 9712, 'SOS Restaurante S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/262784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136464, 9712, 'SOS Restaurante S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/262785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136465, 9712, 'SOS Restaurante S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/262786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136466, 9712, 'SOS Restaurante S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/262787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136467, 9712, 'SOS Restaurante S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/262788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136468, 9713, 'SOS Restaurante S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136469, 9713, 'SOS Restaurante S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136470, 9713, 'SOS Restaurante S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136471, 9713, 'SOS Restaurante S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136472, 9713, 'SOS Restaurante S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136473, 9713, 'SOS Restaurante S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136474, 9713, 'SOS Restaurante S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136475, 9713, 'SOS Restaurante S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136476, 9713, 'SOS Restaurante S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/262797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136477, 9713, 'SOS Restaurante S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/262798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136478, 9713, 'SOS Restaurante S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/262799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136479, 9713, 'SOS Restaurante S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/262800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136480, 9713, 'SOS Restaurante S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/262801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136481, 9714, 'SOS Restaurante S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136482, 9714, 'SOS Restaurante S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136483, 9714, 'SOS Restaurante S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136484, 9714, 'SOS Restaurante S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136485, 9714, 'SOS Restaurante S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136486, 9714, 'SOS Restaurante S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136487, 9714, 'SOS Restaurante S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136488, 9714, 'SOS Restaurante S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136489, 9714, 'SOS Restaurante S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/262810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136490, 9714, 'SOS Restaurante S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/262811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136491, 9714, 'SOS Restaurante S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/262812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136492, 9714, 'SOS Restaurante S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/262813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136493, 9714, 'SOS Restaurante S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/262814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136494, 9715, 'SOS Restaurante S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136495, 9715, 'SOS Restaurante S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136496, 9715, 'SOS Restaurante S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136497, 9715, 'SOS Restaurante S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136498, 9715, 'SOS Restaurante S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136499, 9715, 'SOS Restaurante S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136500, 9715, 'SOS Restaurante S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136501, 9716, 'SOS Restaurante S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136502, 9716, 'SOS Restaurante S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136503, 9716, 'SOS Restaurante S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136504, 9716, 'SOS Restaurante S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136505, 9716, 'SOS Restaurante S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136506, 9716, 'SOS Restaurante S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136507, 9716, 'SOS Restaurante S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136508, 9717, 'SOS Restaurante S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136509, 9717, 'SOS Restaurante S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136510, 9717, 'SOS Restaurante S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136511, 9717, 'SOS Restaurante S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136512, 9717, 'SOS Restaurante S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136513, 9717, 'SOS Restaurante S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136514, 9717, 'SOS Restaurante S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136515, 9717, 'SOS Restaurante S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136516, 9718, 'SOS Restaurante S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136517, 9718, 'SOS Restaurante S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136518, 9718, 'SOS Restaurante S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136519, 9718, 'SOS Restaurante S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136520, 9718, 'SOS Restaurante S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136521, 9718, 'SOS Restaurante S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136522, 9718, 'SOS Restaurante S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136523, 9719, 'SOS Restaurante S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136524, 9719, 'SOS Restaurante S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136525, 9719, 'SOS Restaurante S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136526, 9719, 'SOS Restaurante S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136527, 9719, 'SOS Restaurante S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136528, 9719, 'SOS Restaurante S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136529, 9719, 'SOS Restaurante S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136530, 9719, 'SOS Restaurante S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136531, 9719, 'SOS Restaurante S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/262852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136532, 9719, 'SOS Restaurante S16 E10', 'http://sinalprivado.info:80/series/1533784/1533784/262853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136533, 9719, 'SOS Restaurante S16 E11', 'http://sinalprivado.info:80/series/1533784/1533784/262854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136534, 9719, 'SOS Restaurante S16 E12', 'http://sinalprivado.info:80/series/1533784/1533784/262855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136535, 9720, 'SOS Restaurante S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136536, 9720, 'SOS Restaurante S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136537, 9720, 'SOS Restaurante S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136538, 9720, 'SOS Restaurante S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136539, 9720, 'SOS Restaurante S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136540, 9721, 'SOS Restaurante S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136541, 9721, 'SOS Restaurante S18 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136542, 9721, 'SOS Restaurante S18 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136543, 9721, 'SOS Restaurante S18 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136544, 9721, 'SOS Restaurante S18 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136545, 9721, 'SOS Restaurante S18 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136546, 9721, 'SOS Restaurante S18 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136547, 9721, 'SOS Restaurante S18 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136548, 9721, 'SOS Restaurante S18 E09', 'http://sinalprivado.info:80/series/1533784/1533784/262869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136549, 9721, 'SOS Restaurante S18 E10', 'http://sinalprivado.info:80/series/1533784/1533784/262870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136550, 9721, 'SOS Restaurante S18 E11', 'http://sinalprivado.info:80/series/1533784/1533784/262871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136551, 9721, 'SOS Restaurante S18 E12', 'http://sinalprivado.info:80/series/1533784/1533784/262872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136552, 9722, 'SOS Restaurante S19 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136553, 9722, 'SOS Restaurante S19 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136554, 9722, 'SOS Restaurante S19 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136555, 9722, 'SOS Restaurante S19 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136556, 9722, 'SOS Restaurante S19 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136557, 9722, 'SOS Restaurante S19 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136558, 9722, 'SOS Restaurante S19 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136559, 9722, 'SOS Restaurante S19 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136560, 9722, 'SOS Restaurante S19 E09', 'http://sinalprivado.info:80/series/1533784/1533784/262881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136561, 9722, 'SOS Restaurante S19 E10', 'http://sinalprivado.info:80/series/1533784/1533784/262882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136562, 9722, 'SOS Restaurante S19 E11', 'http://sinalprivado.info:80/series/1533784/1533784/262883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136563, 9722, 'SOS Restaurante S19 E12', 'http://sinalprivado.info:80/series/1533784/1533784/262884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136564, 9722, 'SOS Restaurante S19 E13', 'http://sinalprivado.info:80/series/1533784/1533784/262885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136565, 9723, 'SOS Restaurante S20 E01', 'http://sinalprivado.info:80/series/1533784/1533784/605623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136566, 9723, 'SOS Restaurante S20 E02', 'http://sinalprivado.info:80/series/1533784/1533784/605624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136567, 9723, 'SOS Restaurante S20 E03', 'http://sinalprivado.info:80/series/1533784/1533784/605625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136568, 9723, 'SOS Restaurante S20 E04', 'http://sinalprivado.info:80/series/1533784/1533784/605626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136569, 9723, 'SOS Restaurante S20 E05', 'http://sinalprivado.info:80/series/1533784/1533784/605627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136570, 9723, 'SOS Restaurante S20 E06', 'http://sinalprivado.info:80/series/1533784/1533784/605628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136571, 9723, 'SOS Restaurante S20 E07', 'http://sinalprivado.info:80/series/1533784/1533784/605629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136572, 9723, 'SOS Restaurante S20 E08', 'http://sinalprivado.info:80/series/1533784/1533784/605630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136573, 9723, 'SOS Restaurante S20 E09', 'http://sinalprivado.info:80/series/1533784/1533784/376396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136574, 9723, 'SOS Restaurante S20 E10', 'http://sinalprivado.info:80/series/1533784/1533784/376397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136575, 9723, 'SOS Restaurante S20 E11', 'http://sinalprivado.info:80/series/1533784/1533784/385940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136576, 9723, 'SOS Restaurante S20 E12', 'http://sinalprivado.info:80/series/1533784/1533784/385941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136577, 9723, 'SOS Restaurante S20 E13', 'http://sinalprivado.info:80/series/1533784/1533784/385942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136578, 9724, 'SOS Restaurante S21 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136579, 9724, 'SOS Restaurante S21 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136580, 9724, 'SOS Restaurante S21 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136581, 9724, 'SOS Restaurante S21 E04', 'http://sinalprivado.info:80/series/1533784/1533784/657625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136582, 9724, 'SOS Restaurante S21 E05', 'http://sinalprivado.info:80/series/1533784/1533784/657626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136583, 9724, 'SOS Restaurante S21 E06', 'http://sinalprivado.info:80/series/1533784/1533784/657627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136584, 9724, 'SOS Restaurante S21 E07', 'http://sinalprivado.info:80/series/1533784/1533784/657628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136585, 9724, 'SOS Restaurante S21 E08', 'http://sinalprivado.info:80/series/1533784/1533784/657629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136586, 9724, 'SOS Restaurante S21 E09', 'http://sinalprivado.info:80/series/1533784/1533784/657630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136587, 9724, 'SOS Restaurante S21 E10', 'http://sinalprivado.info:80/series/1533784/1533784/657631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136588, 9724, 'SOS Restaurante S21 E11', 'http://sinalprivado.info:80/series/1533784/1533784/657632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136589, 9724, 'SOS Restaurante S21 E12', 'http://sinalprivado.info:80/series/1533784/1533784/657633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136590, 9724, 'SOS Restaurante S21 E13', 'http://sinalprivado.info:80/series/1533784/1533784/657634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136591, 9725, 'SOS Restaurante S22 E01', 'http://sinalprivado.info:80/series/1533784/1533784/704190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mimgrRrfOnssk5XMdfF1h8pqVec.jpg'),
(136592, 9726, 'Seis Nacoes Acesso Total S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/262768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tYKKNykFn5VW75Mzu3faEsCOFRJ.jpg'),
(136593, 9726, 'Seis Nacoes Acesso Total S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/262769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sCo880BUNVLGtZnMknZLi6witOo.jpg'),
(136594, 9726, 'Seis Nacoes Acesso Total S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/262770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4NtAXkwk6B0jfJTspH1QeRnZrvV.jpg'),
(136595, 9726, 'Seis Nacoes Acesso Total S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/262771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5q0gGjfS4E6vImECeP5zW8RuCt.jpg'),
(136596, 9726, 'Seis Nacoes Acesso Total S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/262772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cTv0o0qjipN2dN9eIVXgrTqLnQU.jpg'),
(136597, 9726, 'Seis Nacoes Acesso Total S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/262773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2uuwMtYuhzigg8bKASA5mSFfsdJ.jpg'),
(136598, 9726, 'Seis Nacoes Acesso Total S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/262774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dOG5iszMDWgSf89QcxUpy2CFEWP.jpg'),
(136599, 9726, 'Seis Nacoes Acesso Total S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/262775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ecBS95z5r5zQrXjwZGjXHbN2ft.jpg'),
(136600, 9727, 'Alma Imoral [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ecBS95z5r5zQrXjwZGjXHbN2ft.jpg'),
(136601, 9727, 'Alma Imoral [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ecBS95z5r5zQrXjwZGjXHbN2ft.jpg'),
(136602, 9727, 'Alma Imoral [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ecBS95z5r5zQrXjwZGjXHbN2ft.jpg'),
(136603, 9727, 'Alma Imoral [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ecBS95z5r5zQrXjwZGjXHbN2ft.jpg'),
(136604, 9727, 'Alma Imoral [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ecBS95z5r5zQrXjwZGjXHbN2ft.jpg'),
(136605, 9728, 'Beyblade X [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oBnjkhoyfrWruTVfW55qIMtmqpF.jpg'),
(136606, 9728, 'Beyblade X [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4V7PdAZprFojH9btYEfvBw60iPf.jpg'),
(136607, 9728, 'Beyblade X [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vl6kSgXP6lU1vq6ouQxmd7uGIQb.jpg'),
(136608, 9728, 'Beyblade X [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yXTip0t1CSNJ94dyIKITmgkfqBh.jpg'),
(136609, 9728, 'Beyblade X [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eJAAK73ANjboO5mePx4lA4EttRC.jpg'),
(136610, 9728, 'Beyblade X [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wAe5Y3LF4mMuJf3R4QFQl8jreQj.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(136611, 9728, 'Beyblade X [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4TRQMNBeiCeCM8pPcFmr4aMLEkW.jpg'),
(136612, 9728, 'Beyblade X [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/anNP7rRfNgZphT9hkXp0n2KD8S5.jpg'),
(136613, 9728, 'Beyblade X [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3PrboRtqhxyGHxzqiX1ik7kORq0.jpg'),
(136614, 9728, 'Beyblade X [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4qbrb27dnjtbdjNkOb90W6JgYjU.jpg'),
(136615, 9728, 'Beyblade X [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4lGnkOxOoLGT2PTbL350l8ffmqe.jpg'),
(136616, 9728, 'Beyblade X [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjQPH6eu6LaF1QrlUHERpWoXuNJ.jpg'),
(136617, 9728, 'Beyblade X [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lAELl54FtC7QxgccheGSS2ksKWd.jpg'),
(136618, 9728, 'Beyblade X [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwbqMIKrlkwivqr90vUIWPSjUkr.jpg'),
(136619, 9728, 'Beyblade X [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/95IdikWuhdnaQJwglmylDfzGtn7.jpg'),
(136620, 9729, 'Coppelion [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/djCL5WdIGbiQ9Q4YZfklNwqrj55.jpg'),
(136621, 9729, 'Coppelion [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kpdsG01YsT4u9ySGtcEIqJrySnn.jpg'),
(136622, 9729, 'Coppelion [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8PuJkBCxwxTXwUVGlF21B3S32El.jpg'),
(136623, 9729, 'Coppelion [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ha4tpS1s883PBb4N07GG70u4SOu.jpg'),
(136624, 9729, 'Coppelion [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xaSMWl10fl9tlLpY4sZMTEDX0oD.jpg'),
(136625, 9729, 'Coppelion [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1FNoefp40dLBfTKuaeHXrKtubi.jpg'),
(136626, 9729, 'Coppelion [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJB7SoRaZKPoiGRUaZD5S4XcDLH.jpg'),
(136627, 9729, 'Coppelion [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Z65wgRNiEHvRN1DMGbythcrGEX.jpg'),
(136628, 9729, 'Coppelion [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zPYuz3ipN6ftRrSncp8g2ScoGOQ.jpg'),
(136629, 9729, 'Coppelion [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kLIlmK4YngvpCZzHC3zqAJeM6ru.jpg'),
(136630, 9729, 'Coppelion [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vBfzvr4OZXycIA6d6gjbI3WsjiM.jpg'),
(136631, 9729, 'Coppelion [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3jyc1IVj1m8ax6gzQ7uJDom6LCp.jpg'),
(136632, 9729, 'Coppelion [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Z2DIMTWSLrEbp7I68KcgotBLXL.jpg'),
(136633, 9730, 'Cristobal Balenciaga [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zaVIm7z1mkzmPkRz2MWQut0E8LW.jpg'),
(136634, 9730, 'Cristobal Balenciaga [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2aLFP2hQAq8whfQKGtLCZ4yXnuH.jpg'),
(136635, 9730, 'Cristobal Balenciaga [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rnQ7b9JnHafbYRdlYd7FG54igWw.jpg'),
(136636, 9730, 'Cristobal Balenciaga [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hFYhqE8F8oB8zzp7aKt7VfN1ury.jpg'),
(136637, 9730, 'Cristobal Balenciaga [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vRt9rKYWPLbIzcCnQURznTI2vuh.jpg'),
(136638, 9730, 'Cristobal Balenciaga [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ayRsadsHG0ZVbbSkggTOjJWTXgX.jpg'),
(136639, 9731, 'Em Movimento S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzmsts2DLrQSeWZS3HA9DFyYVML.jpg'),
(136640, 9731, 'Em Movimento S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e4ilufN512VeAvozhkVmafnL8YI.jpg'),
(136641, 9731, 'Em Movimento S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rUz3yxUpJUmjJlRIy6bZjMelFjB.jpg'),
(136642, 9731, 'Em Movimento S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vc2ydZmrEEWZc79U6KoI1vDhmkg.jpg'),
(136643, 9731, 'Em Movimento S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Kj2do8tuB3hUAvgqiLQU5Km63L.jpg'),
(136644, 9731, 'Em Movimento S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cXZ1zIpno8XPAgkBUGSX3hqi8T.jpg'),
(136645, 9731, 'Em Movimento S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fWfIG4n3Bgfaovfm1whBThuwLUa.jpg'),
(136646, 9731, 'Em Movimento S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eICfp1hJNiZqCTUzelnyRWozaJ2.jpg'),
(136647, 9731, 'Em Movimento S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/to9IVB8gTD1XXBovN0W0tyNufWF.jpg'),
(136648, 9731, 'Em Movimento S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uBXfPgFKmTQOVir5pcddoasjAw5.jpg'),
(136649, 9731, 'Em Movimento S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fxpv1CNnfN72rjOm9cpbh2vFJCZ.jpg'),
(136650, 9731, 'Em Movimento S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gzjOA57A1eGkKSybM6yJDwJHqtJ.jpg'),
(136651, 9731, 'Em Movimento S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6XQuFG42gdJA8LXHUAmD1aeywfg.jpg'),
(136652, 9731, 'Em Movimento S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJtRzxiC0JKyD4tV0YtNRjWIrpY.jpg'),
(136653, 9731, 'Em Movimento S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/31rJUgq5H3tm6in5BOHu8icRneM.jpg'),
(136654, 9731, 'Em Movimento S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d67eVq4xDDIfq5zSKEsHdqsBCBl.jpg'),
(136655, 9731, 'Em Movimento S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qrgx8dFyazJmPDacd0WUXoHrcyy.jpg'),
(136656, 9731, 'Em Movimento S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9jRqwq8DxALfsVZOajp8mskAw8b.jpg'),
(136657, 9731, 'Em Movimento S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/368ssUWhGSl5Y4DdETyJdfE8gOZ.jpg'),
(136658, 9731, 'Em Movimento S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7DuuMgXHBfNMGpB7bDpnsKhWUXp.jpg'),
(136659, 9732, 'Febre do Ouro O Desafio de Parker S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266588.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(136660, 9732, 'Febre do Ouro O Desafio de Parker S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266589.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(136661, 9732, 'Febre do Ouro O Desafio de Parker S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/271387.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(136662, 9732, 'Febre do Ouro O Desafio de Parker S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/272943.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(136663, 9732, 'Febre do Ouro O Desafio de Parker S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/281159.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(136664, 9732, 'Febre do Ouro O Desafio de Parker S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/288732.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(136665, 9732, 'Febre do Ouro O Desafio de Parker S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294209.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(136666, 9732, 'Febre do Ouro O Desafio de Parker S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/297963.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(136667, 9732, 'Febre do Ouro O Desafio de Parker S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/308925.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(136668, 9732, 'Febre do Ouro O Desafio de Parker S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/308926.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(136669, 9732, 'Febre do Ouro O Desafio de Parker S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/332996.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(136670, 9732, 'Febre do Ouro O Desafio de Parker S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/332997.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(136671, 9733, 'Fontes Termais de Outro Mundo Diarios de um entusiasta de termas que foi transportado para um paraiso [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nPKmPy4PhKF9rH0RXyoMKLeQO3d.jpg'),
(136672, 9733, 'Fontes Termais de Outro Mundo Diarios de um entusiasta de termas que foi transportado para um paraiso [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1TzUiMJ6upsQupBGejKfQwh9ExH.jpg'),
(136673, 9733, 'Fontes Termais de Outro Mundo Diarios de um entusiasta de termas que foi transportado para um paraiso [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tNTFTbdwWuaqXCdICu0bEVRuzxk.jpg'),
(136674, 9733, 'Fontes Termais de Outro Mundo Diarios de um entusiasta de termas que foi transportado para um paraiso [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/272932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cPMGW8MEvNMS7n0fK2y4JN7wuTX.jpg'),
(136675, 9733, 'Fontes Termais de Outro Mundo Diarios de um entusiasta de termas que foi transportado para um paraiso [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/276586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cPMGW8MEvNMS7n0fK2y4JN7wuTX.jpg'),
(136676, 9733, 'Fontes Termais de Outro Mundo Diarios de um entusiasta de termas que foi transportado para um paraiso [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/276587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cPMGW8MEvNMS7n0fK2y4JN7wuTX.jpg'),
(136677, 9733, 'Fontes Termais de Outro Mundo Diarios de um entusiasta de termas que foi transportado para um paraiso [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/292777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cPMGW8MEvNMS7n0fK2y4JN7wuTX.jpg'),
(136678, 9733, 'Fontes Termais de Outro Mundo Diarios de um entusiasta de termas que foi transportado para um paraiso [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cPMGW8MEvNMS7n0fK2y4JN7wuTX.jpg'),
(136679, 9733, 'Fontes Termais de Outro Mundo Diarios de um entusiasta de termas que foi transportado para um paraiso [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/308890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cPMGW8MEvNMS7n0fK2y4JN7wuTX.jpg'),
(136680, 9733, 'Fontes Termais de Outro Mundo Diarios de um entusiasta de termas que foi transportado para um paraiso [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/308891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cPMGW8MEvNMS7n0fK2y4JN7wuTX.jpg'),
(136681, 9733, 'Fontes Termais de Outro Mundo Diarios de um entusiasta de termas que foi transportado para um paraiso [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/308892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cPMGW8MEvNMS7n0fK2y4JN7wuTX.jpg'),
(136682, 9733, 'Fontes Termais de Outro Mundo Diarios de um entusiasta de termas que foi transportado para um paraiso [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/315838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cPMGW8MEvNMS7n0fK2y4JN7wuTX.jpg'),
(136683, 9734, 'GARO Heir To Steel Armor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCv9nv1eB1oaTsVxxYl7b6P0yAk.jpg'),
(136684, 9734, 'GARO Heir To Steel Armor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9tNFjd0oXTKpe1cjZ4NpX9Unptx.jpg'),
(136685, 9734, 'GARO Heir To Steel Armor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lPaOepCHcOfzMlqKs0mqlYLvZmq.jpg'),
(136686, 9734, 'GARO Heir To Steel Armor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/272905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lPaOepCHcOfzMlqKs0mqlYLvZmq.jpg'),
(136687, 9734, 'GARO Heir To Steel Armor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/272906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lPaOepCHcOfzMlqKs0mqlYLvZmq.jpg'),
(136688, 9734, 'GARO Heir To Steel Armor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lPaOepCHcOfzMlqKs0mqlYLvZmq.jpg'),
(136689, 9734, 'GARO Heir To Steel Armor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lPaOepCHcOfzMlqKs0mqlYLvZmq.jpg'),
(136690, 9734, 'GARO Heir To Steel Armor [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/285429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lPaOepCHcOfzMlqKs0mqlYLvZmq.jpg'),
(136691, 9734, 'GARO Heir To Steel Armor [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/299965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lPaOepCHcOfzMlqKs0mqlYLvZmq.jpg'),
(136692, 9734, 'GARO Heir To Steel Armor [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/304667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lPaOepCHcOfzMlqKs0mqlYLvZmq.jpg'),
(136693, 9734, 'GARO Heir To Steel Armor [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/308856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lPaOepCHcOfzMlqKs0mqlYLvZmq.jpg'),
(136694, 9734, 'GARO Heir To Steel Armor [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/317687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lPaOepCHcOfzMlqKs0mqlYLvZmq.jpg'),
(136695, 9735, 'Grandes Mitos Gregos [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8qtGsek3BP7ZYI3izeJJS9jiJVc.jpg'),
(136696, 9735, 'Grandes Mitos Gregos [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFv6ZqDZ7ZYp7as52r8sTZptoa8.jpg'),
(136697, 9735, 'Grandes Mitos Gregos [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ppIN1XmVcM2CD58fMDdkGDBtZ8w.jpg'),
(136698, 9735, 'Grandes Mitos Gregos [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iH6zZSDz6ghQ1TkY3DPKKN18zn4.jpg'),
(136699, 9735, 'Grandes Mitos Gregos [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4MewtSTyWZyFwc2pn60X2WjaJLd.jpg'),
(136700, 9735, 'Grandes Mitos Gregos [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbCcq06tJYJp3oq0OIUNGfyz2n9.jpg'),
(136701, 9735, 'Grandes Mitos Gregos [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pXVAsb3UuVkeTzb8Ss6UQU6BaId.jpg'),
(136702, 9735, 'Grandes Mitos Gregos [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xMdCGTfrxJ5DNn8wIVbJQgPFPY0.jpg'),
(136703, 9735, 'Grandes Mitos Gregos [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ytRMJos7deIHP8F5MfL29NPRV88.jpg'),
(136704, 9735, 'Grandes Mitos Gregos [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uCaTlcd2O5571wacXiCvElw7znm.jpg'),
(136705, 9735, 'Grandes Mitos Gregos [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A0j4YImtlBXl3NcZqpI8pFKxlcd.jpg'),
(136706, 9735, 'Grandes Mitos Gregos [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/opmNuN0wtTKDBrbN26k4O4hslA.jpg'),
(136707, 9735, 'Grandes Mitos Gregos [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iruv4tW2SacadGe5benGjwll0gj.jpg'),
(136708, 9735, 'Grandes Mitos Gregos [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yfSJUPES7JCZoYvidt3miaUmaJb.jpg'),
(136709, 9735, 'Grandes Mitos Gregos [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Ih3lFkT41YEuLt2VcQDzMZZwLH.jpg'),
(136710, 9735, 'Grandes Mitos Gregos [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zRNOnzNHsl6sR0UIBPo7b61zmiw.jpg'),
(136711, 9735, 'Grandes Mitos Gregos [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vq8Pdce4amX9SWWpIxzIu9yEIh9.jpg'),
(136712, 9735, 'Grandes Mitos Gregos [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rUErYMmZq5ImkzMw27iN5n2nlIS.jpg'),
(136713, 9735, 'Grandes Mitos Gregos [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vI9nO6iDfaHk77qCjiaZt96lbYv.jpg'),
(136714, 9735, 'Grandes Mitos Gregos [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t4muhP9M1OzM3HmF3EIWVmUuQXM.jpg'),
(136715, 9736, 'Grandes Mitos Gregos [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/297863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Qqtv7sPMplvtE2MAwbE8JapMdp.jpg'),
(136716, 9736, 'Grandes Mitos Gregos [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/297864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Qqtv7sPMplvtE2MAwbE8JapMdp.jpg'),
(136717, 9736, 'Grandes Mitos Gregos [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/297865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Qqtv7sPMplvtE2MAwbE8JapMdp.jpg'),
(136718, 9736, 'Grandes Mitos Gregos [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/297866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Qqtv7sPMplvtE2MAwbE8JapMdp.jpg'),
(136719, 9736, 'Grandes Mitos Gregos [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/297867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Qqtv7sPMplvtE2MAwbE8JapMdp.jpg'),
(136720, 9736, 'Grandes Mitos Gregos [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/297868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Qqtv7sPMplvtE2MAwbE8JapMdp.jpg'),
(136721, 9736, 'Grandes Mitos Gregos [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/297869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Qqtv7sPMplvtE2MAwbE8JapMdp.jpg'),
(136722, 9736, 'Grandes Mitos Gregos [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/297870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Qqtv7sPMplvtE2MAwbE8JapMdp.jpg'),
(136723, 9736, 'Grandes Mitos Gregos [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/297871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Qqtv7sPMplvtE2MAwbE8JapMdp.jpg'),
(136724, 9736, 'Grandes Mitos Gregos [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/297872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Qqtv7sPMplvtE2MAwbE8JapMdp.jpg'),
(136725, 9737, 'Grandes Mitos Gregos [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/297873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Qqtv7sPMplvtE2MAwbE8JapMdp.jpg'),
(136726, 9737, 'Grandes Mitos Gregos [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/297874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Qqtv7sPMplvtE2MAwbE8JapMdp.jpg'),
(136727, 9737, 'Grandes Mitos Gregos [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/297875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Qqtv7sPMplvtE2MAwbE8JapMdp.jpg'),
(136728, 9737, 'Grandes Mitos Gregos [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/297876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Qqtv7sPMplvtE2MAwbE8JapMdp.jpg'),
(136729, 9737, 'Grandes Mitos Gregos [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/297877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Qqtv7sPMplvtE2MAwbE8JapMdp.jpg'),
(136730, 9737, 'Grandes Mitos Gregos [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/297878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Qqtv7sPMplvtE2MAwbE8JapMdp.jpg'),
(136731, 9737, 'Grandes Mitos Gregos [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/297879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Qqtv7sPMplvtE2MAwbE8JapMdp.jpg'),
(136732, 9737, 'Grandes Mitos Gregos [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/297880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Qqtv7sPMplvtE2MAwbE8JapMdp.jpg'),
(136733, 9737, 'Grandes Mitos Gregos [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/297881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Qqtv7sPMplvtE2MAwbE8JapMdp.jpg'),
(136734, 9737, 'Grandes Mitos Gregos [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/297882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Qqtv7sPMplvtE2MAwbE8JapMdp.jpg'),
(136735, 9738, 'High School DxD [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n6PE7WDBKP4AA1o3NXpGdiIWW90.jpg'),
(136736, 9738, 'High School DxD [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y7LiMwl4GqyRQyNR7vFLf1gonAu.jpg'),
(136737, 9738, 'High School DxD [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mQs4o0Lls5zaZMVGzhcUc06IeL.jpg'),
(136738, 9738, 'High School DxD [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/icmGQ1i72QsiOvQQ4wXEBuDkmiL.jpg'),
(136739, 9738, 'High School DxD [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kW5dbfBU5c7jhQkS1s0TE6kfOnm.jpg'),
(136740, 9738, 'High School DxD [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2VE70GSq5yrz4HvzAbapvvZZDMf.jpg'),
(136741, 9738, 'High School DxD [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/apUUUMyHJEQUuv27lThX1bDIJau.jpg'),
(136742, 9738, 'High School DxD [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pOqwhBlydJpV6kUkg5qOFkkiV8e.jpg'),
(136743, 9738, 'High School DxD [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wkUfTENeQnZsOOhYPPEIOQdZxd7.jpg'),
(136744, 9738, 'High School DxD [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUzZJY3r4jTPK8gyrYGsyILCdoS.jpg'),
(136745, 9738, 'High School DxD [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6vedP1bi7UvHAM9lRsjfKmYu7tY.jpg'),
(136746, 9738, 'High School DxD [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9wamgE5hRoBYqC0kMCKqvlmle0w.jpg'),
(136747, 9738, 'High School DxD [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yMYvz4vbKMIXb2IMYYi1GSlNaGx.jpg'),
(136748, 9738, 'High School DxD [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yMYvz4vbKMIXb2IMYYi1GSlNaGx.jpg'),
(136749, 9739, 'High School DxD [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mrFC2SVhGp92wCPeRfwqzedYzLY.jpg'),
(136750, 9739, 'High School DxD [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/reQrIKSEuLCrbqVFwyDlwddYkox.jpg'),
(136751, 9739, 'High School DxD [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rHXW9prCcwpZr3VMdIcYCuMsTB2.jpg'),
(136752, 9739, 'High School DxD [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yxgKRNOuhaKHkBtdbAJ0x6Vxx9H.jpg'),
(136753, 9739, 'High School DxD [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/15TDQov8V541wFlaIhnuDRU8GRx.jpg'),
(136754, 9739, 'High School DxD [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSV5REYxrylTo51z2RW873GFYdk.jpg'),
(136755, 9739, 'High School DxD [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t5PZWacd7aYYeT35D3sj75pRfKD.jpg'),
(136756, 9739, 'High School DxD [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6J3NqJ7RKl5c7Zm6qF6bXUUGKPg.jpg'),
(136757, 9739, 'High School DxD [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sQJlI9PqHCy836OPzPhmBcQdHOC.jpg'),
(136758, 9739, 'High School DxD [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/91PRKotW1cCyw9nrPoN8oUcn8l1.jpg'),
(136759, 9739, 'High School DxD [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgzi2ncrIpZiddYMa0kC7fxUVrK.jpg'),
(136760, 9739, 'High School DxD [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/owM0EM9QLEJqsIMM8E6KX00CZrz.jpg'),
(136761, 9739, 'High School DxD [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yMYvz4vbKMIXb2IMYYi1GSlNaGx.jpg'),
(136762, 9740, 'High School DxD [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u3AdEaYh1aNrGkWWbYIhFNbSJvt.jpg'),
(136763, 9740, 'High School DxD [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nEUDwZu5eLvzxbDtMceG6GLQSO5.jpg'),
(136764, 9740, 'High School DxD [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wz1bwfAo0yZLeyXOR6TClWFg4HJ.jpg'),
(136765, 9740, 'High School DxD [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vssG6A1I9t1UyXHBAdAxPn6jpHa.jpg'),
(136766, 9740, 'High School DxD [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pPF2rjJCxOOSvcCiswmgbPDO3DY.jpg'),
(136767, 9740, 'High School DxD [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i8E9Dj15xp3Vtsshl9buVwlJNGx.jpg'),
(136768, 9740, 'High School DxD [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jHjnzqIffQrQVCenZo7GC5tkQnM.jpg'),
(136769, 9740, 'High School DxD [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bUA2IkMEMxPCX2spsQx7yayFpfF.jpg'),
(136770, 9740, 'High School DxD [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AvK3tmHluN6c31QWxG6W8s0373H.jpg'),
(136771, 9740, 'High School DxD [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AhUyMGAOaq40heDG1aJWNAto2mB.jpg'),
(136772, 9740, 'High School DxD [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/muOFOhASjqg2QwVrp6kj2XMcxw4.jpg'),
(136773, 9740, 'High School DxD [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jjLg5jBpw8hVzm8PrLMWkQ72L.jpg'),
(136774, 9740, 'High School DxD [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yMYvz4vbKMIXb2IMYYi1GSlNaGx.jpg'),
(136775, 9741, 'High School DxD [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yMYvz4vbKMIXb2IMYYi1GSlNaGx.jpg'),
(136776, 9741, 'High School DxD [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhhWtaH6IokbAkmFX0K2nuaxapP.jpg'),
(136777, 9741, 'High School DxD [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/irIfCXr9NooEmNsBu0B9VHQNZq.jpg'),
(136778, 9741, 'High School DxD [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/etQj5HUd6wy0qbWMlOet9FSmdm8.jpg'),
(136779, 9741, 'High School DxD [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y5s8tlcsFIdyLA1R9ZIRl2vVrsQ.jpg'),
(136780, 9741, 'High School DxD [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lmvJ2L3yp538ljz2aWhJntcj4XU.jpg'),
(136781, 9741, 'High School DxD [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gNQS2b2Pbjes1P4htn8v24Gprvr.jpg'),
(136782, 9741, 'High School DxD [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZVVo1fVCoBpGRJZDuLbbw8zwIn.jpg'),
(136783, 9741, 'High School DxD [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/69JbwP1H9ZFFPWIKlPO2JQHoqu8.jpg'),
(136784, 9741, 'High School DxD [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6REb80EVtKcwhicuzek4ZSDyaPL.jpg'),
(136785, 9741, 'High School DxD [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hnTY2uKv7ObCuZjTjqWoY3Z6Y7e.jpg'),
(136786, 9741, 'High School DxD [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zNcuohStf1fzIT4nLqS40buFmXV.jpg'),
(136787, 9741, 'High School DxD [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k5fXZOJE4NgFs3ZVn63muIaiVib.jpg'),
(136788, 9742, 'Kingdom [L] (2012) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pockLHjj00wSxzcZR4oGgXSfWO1.jpg'),
(136789, 9742, 'Kingdom [L] (2012) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hN9n59vsEWVCu16EX0DSORUMhac.jpg'),
(136790, 9742, 'Kingdom [L] (2012) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xtQsxhJPiE2cLwlk76VUpfXsORt.jpg'),
(136791, 9742, 'Kingdom [L] (2012) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vr3BFlbgdB1zUqM9bwT3UFTwFD7.jpg'),
(136792, 9742, 'Kingdom [L] (2012) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9YEgiJZisZ0jx44GWab2pUEb606.jpg'),
(136793, 9742, 'Kingdom [L] (2012) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13hF0KrNYJlM4UAAWsfuxO9MGdx.jpg'),
(136794, 9742, 'Kingdom [L] (2012) S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6etlFDpGuD62GGeL2yu4ZBrxToe.jpg'),
(136795, 9742, 'Kingdom [L] (2012) S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gjXjSmnYDduabO3lzesuUZT4fcx.jpg'),
(136796, 9742, 'Kingdom [L] (2012) S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Dfg2WHhGfWPuhc0nVFem1gLlq0.jpg'),
(136797, 9742, 'Kingdom [L] (2012) S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1TXMqA271UymrT41oAplbtombCH.jpg'),
(136798, 9742, 'Kingdom [L] (2012) S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9O0xeBym43IxRVepqa7IL3tSsr8.jpg'),
(136799, 9742, 'Kingdom [L] (2012) S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m0jW0K9c298YgjPdOYYdrmwhIYu.jpg'),
(136800, 9742, 'Kingdom [L] (2012) S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/du6c6O3VsZb4Qzgmiw4CR8y5in1.jpg'),
(136801, 9742, 'Kingdom [L] (2012) S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xyNtEsvd8wDMmAuvgbgK6nTXGTG.jpg'),
(136802, 9742, 'Kingdom [L] (2012) S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4xDkQrNghNOGdavzLfl1NxznCKT.jpg'),
(136803, 9742, 'Kingdom [L] (2012) S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDvE4MvasdjuAPJuaOOMbz3nk36.jpg'),
(136804, 9742, 'Kingdom [L] (2012) S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7cLQsbtoZMyFrO7Py7WjQDvoGI0.jpg'),
(136805, 9742, 'Kingdom [L] (2012) S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rFAyqBKmShGJW0rdCIsjNehPj5r.jpg'),
(136806, 9742, 'Kingdom [L] (2012) S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6woEbpz7U2bE5ytcD9TjylAHRh.jpg'),
(136807, 9742, 'Kingdom [L] (2012) S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sX9jsR7w9BWfcYmEszOTsOXLCKs.jpg'),
(136808, 9742, 'Kingdom [L] (2012) S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/267175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ddTUfleyP9dITUebfpYMhINgzho.jpg'),
(136809, 9742, 'Kingdom [L] (2012) S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/267176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q19pFbhSYmYXZcQzJNK4yLY6YtB.jpg'),
(136810, 9742, 'Kingdom [L] (2012) S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/267177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qD82oa1W8gT4CD6hBSHZ4nzfZ3N.jpg'),
(136811, 9742, 'Kingdom [L] (2012) S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/267178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q8OWgXlXlut4VPbYGjOu4fe8ooH.jpg'),
(136812, 9742, 'Kingdom [L] (2012) S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/267179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pf5c1nxCGpqnnpM6U44TstyfnXZ.jpg'),
(136813, 9742, 'Kingdom [L] (2012) S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/267180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8XNr7DJdx3CgIDZLt7bkS1LPHWb.jpg'),
(136814, 9742, 'Kingdom [L] (2012) S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/267181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/feXqIRISJEYzcxBrbZwdXecOV9l.jpg'),
(136815, 9742, 'Kingdom [L] (2012) S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/267182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fV3kv1GRzOb3YvCnKET8xaktHgW.jpg'),
(136816, 9742, 'Kingdom [L] (2012) S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/267183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bAalxMhUlv0rSW4wswuXaJvSnfa.jpg'),
(136817, 9742, 'Kingdom [L] (2012) S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/267184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cINI0sCgQ4lU7EaJbzHc96Dmg82.jpg'),
(136818, 9742, 'Kingdom [L] (2012) S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/267185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/84Py3LUpiGVead9wGtCVK0QKu1E.jpg'),
(136819, 9742, 'Kingdom [L] (2012) S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/267186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBMDCmw26MWdvCHU9NAr8WawOJs.jpg'),
(136820, 9742, 'Kingdom [L] (2012) S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/267187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xx5mMMf9mPW8nRWqt4IjDoo56iG.jpg'),
(136821, 9742, 'Kingdom [L] (2012) S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/267188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Qf3zsCXghCsxpdWbacDanupUO6.jpg'),
(136822, 9742, 'Kingdom [L] (2012) S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/267189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cfKp4VyOgQ5Giz9UmMzz2jQ5TTj.jpg'),
(136823, 9742, 'Kingdom [L] (2012) S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/267190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/srsy02RNiYsprkbRhUdelj2EcQZ.jpg'),
(136824, 9742, 'Kingdom [L] (2012) S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/267191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9vgAojMZy3XSLRNwNPUQ6gb6yiN.jpg'),
(136825, 9742, 'Kingdom [L] (2012) S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/267192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iNjDLzag5ILlVr6859xA4lUYL4l.jpg'),
(136826, 9743, 'Kingdom [L] (2012) S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AkFBzMwcBxkAIYFy6s1YbppOhUU.jpg'),
(136827, 9743, 'Kingdom [L] (2012) S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rMhnmCUs7vhPc4F48xjoCeeT5k1.jpg'),
(136828, 9743, 'Kingdom [L] (2012) S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zEEcbBeD6bATFm87c3GiujA3Jpz.jpg'),
(136829, 9743, 'Kingdom [L] (2012) S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fsIzkuLRiJpJssu91byk48R2IeG.jpg'),
(136830, 9743, 'Kingdom [L] (2012) S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6KPVVhUlIqucn1V9tu0PoXjvxRl.jpg'),
(136831, 9743, 'Kingdom [L] (2012) S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bSQ2lo1dsy0451ZNnPv9tlAOMIT.jpg'),
(136832, 9743, 'Kingdom [L] (2012) S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mIEoyynP9ljxr6DcaQ1O3mBEHyS.jpg'),
(136833, 9743, 'Kingdom [L] (2012) S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kyolUCxch9BIOzooGPTiz5VgxOr.jpg'),
(136834, 9743, 'Kingdom [L] (2012) S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/btfjfe6ZTTWb19h5jwDqhMVOxZW.jpg'),
(136835, 9743, 'Kingdom [L] (2012) S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sVkYrSxUIURX8nSt7ZKmbkBdaHQ.jpg'),
(136836, 9743, 'Kingdom [L] (2012) S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wmdUgwtKzdW0qnulAg4ynYhLsbg.jpg'),
(136837, 9743, 'Kingdom [L] (2012) S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ei8AxFzBYpvUbr0tpvkC2jGYY42.jpg'),
(136838, 9743, 'Kingdom [L] (2012) S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zmpuVZTe5zLv7MecIrFPKn07VpN.jpg'),
(136839, 9743, 'Kingdom [L] (2012) S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4QJffo1AMX8EmlZMjAjrrAVsL3x.jpg'),
(136840, 9743, 'Kingdom [L] (2012) S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Liu50zgXBEPm7CClr0I0wm4xzU.jpg'),
(136841, 9743, 'Kingdom [L] (2012) S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wvJVefXBbF931RtztPt431XIUxt.jpg'),
(136842, 9743, 'Kingdom [L] (2012) S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lMaxO1ujGIB7uXe7RqIB7yHO493.jpg'),
(136843, 9743, 'Kingdom [L] (2012) S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fq0pJT6hIglI3RYARvTv0ihhnH4.jpg'),
(136844, 9743, 'Kingdom [L] (2012) S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMri0GuWN7KJGOuEc1O2gFfVupW.jpg'),
(136845, 9743, 'Kingdom [L] (2012) S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dBS7PU6Bh3GTlHixpqmvGGqOTkf.jpg'),
(136846, 9743, 'Kingdom [L] (2012) S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/267213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/41PXyubfIioTlMKibKvmHA2xJoj.jpg'),
(136847, 9743, 'Kingdom [L] (2012) S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/267214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/TYCfrH6vb4XwxrYgF31WQ1agIb.jpg'),
(136848, 9743, 'Kingdom [L] (2012) S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/267215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vB0Pjp3kAy0bqS884T2cCWLzz3H.jpg'),
(136849, 9743, 'Kingdom [L] (2012) S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/267216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/JzIYu0oVysmSEWdGhPcVaHuyvJ.jpg'),
(136850, 9743, 'Kingdom [L] (2012) S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/267217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pGid40DHzY5mRkOf3W2hLwaQQx0.jpg'),
(136851, 9743, 'Kingdom [L] (2012) S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/267218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ppDDPXUzSktrYvobnbSjri8Xb3S.jpg'),
(136852, 9743, 'Kingdom [L] (2012) S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/267219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6JenAFidJC3WXpkzGnVAASRkQk.jpg'),
(136853, 9743, 'Kingdom [L] (2012) S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/267220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c3zQM0lLv7zomgyQCs1H9IUtOrs.jpg'),
(136854, 9743, 'Kingdom [L] (2012) S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/267221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gNIH2ABr9xDizqnR6mem9aBOisH.jpg'),
(136855, 9743, 'Kingdom [L] (2012) S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/267222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUKhvFeQxSeQ6v49PqMx00f1j4U.jpg'),
(136856, 9743, 'Kingdom [L] (2012) S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/267223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aKcNCteL0DlsScoe9eLapBWXmMW.jpg'),
(136857, 9743, 'Kingdom [L] (2012) S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/267224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d2LoZ80QFX6J2dv1Eh84CM8a5H3.jpg'),
(136858, 9743, 'Kingdom [L] (2012) S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/267225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m9bxwG6B5xozkn0OjxKQdXTzjBe.jpg'),
(136859, 9743, 'Kingdom [L] (2012) S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/267226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bBJbAu7fZHs2dNXdpuH1koWCkNG.jpg'),
(136860, 9743, 'Kingdom [L] (2012) S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/267227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wfhf8rM1kPgBjagcvMNk4qK3itA.jpg'),
(136861, 9743, 'Kingdom [L] (2012) S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/267228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oGSNZKWfes4pUaleWPHExeQPpQF.jpg'),
(136862, 9743, 'Kingdom [L] (2012) S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/267229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2F5KV6dx79NhboOzeJAnmNVKeoz.jpg'),
(136863, 9743, 'Kingdom [L] (2012) S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/267230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dINCvVq1ikePAXt49i3l0EISLUW.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(136864, 9743, 'Kingdom [L] (2012) S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/267231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bTg0iMfWGKOYd9cbnZELo4QLW52.jpg'),
(136865, 9744, 'Kingdom [L] (2012) S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qn9LwFPdoRFW5Vv9cu9Y4xlwVaI.jpg'),
(136866, 9744, 'Kingdom [L] (2012) S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mWurmPaP6s6wxmQlvlwM4afy7gX.jpg'),
(136867, 9744, 'Kingdom [L] (2012) S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uCBzPz3cJlczW52NlY0YxiHSk45.jpg'),
(136868, 9744, 'Kingdom [L] (2012) S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xnXoOJNkYv3aI943aYPpp4bF9Hr.jpg'),
(136869, 9744, 'Kingdom [L] (2012) S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MGH56X5TdOVQd13FmRMHi3WymW.jpg'),
(136870, 9744, 'Kingdom [L] (2012) S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xdCKpJTPh51z0yWgnoILyjdAsTm.jpg'),
(136871, 9744, 'Kingdom [L] (2012) S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBXgRArrrA7h8Jrl1ZP9dTjfe4M.jpg'),
(136872, 9744, 'Kingdom [L] (2012) S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/discqMSZ7nTk1BcHqr3pTRLBZhl.jpg'),
(136873, 9744, 'Kingdom [L] (2012) S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yYzcQAdHUEl2pYkYFPC37XNhtYL.jpg'),
(136874, 9744, 'Kingdom [L] (2012) S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gMSDcV5aQ52YDNs2cdpwgqgQYyL.jpg'),
(136875, 9744, 'Kingdom [L] (2012) S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o1NV09Nnv0Wx8MGIBIpjtG1rU3u.jpg'),
(136876, 9744, 'Kingdom [L] (2012) S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKXaBlipVvdwy7SxkZlPu8OM0k9.jpg'),
(136877, 9744, 'Kingdom [L] (2012) S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vYKgP1Xw8FLfnZCjwdr9FJ3OZe.jpg'),
(136878, 9744, 'Kingdom [L] (2012) S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9HW9MYtXKMItPxNz9HUuNxOP4kF.jpg'),
(136879, 9744, 'Kingdom [L] (2012) S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iIwsZ4oXDoH7Vql2jbMNgLP3Ex.jpg'),
(136880, 9744, 'Kingdom [L] (2012) S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wvkGzeVFI7wAy7Ke6b4QCWUDsAx.jpg'),
(136881, 9744, 'Kingdom [L] (2012) S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBolGeatRDz5kY2SV8EtJ6FXBys.jpg'),
(136882, 9744, 'Kingdom [L] (2012) S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i015ucHiHwyqbgs4LIVosg7Phi4.jpg'),
(136883, 9744, 'Kingdom [L] (2012) S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZBp9Qwfl0lOpQdL5EpVk4xSU95.jpg'),
(136884, 9744, 'Kingdom [L] (2012) S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rFqato1FB6BJ8pnlP8g00W37TZA.jpg'),
(136885, 9744, 'Kingdom [L] (2012) S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/267252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJLaVfItvi9RBqrENpFrBTRPPbY.jpg'),
(136886, 9744, 'Kingdom [L] (2012) S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/267253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVEJiNa6qp1aEGtMT6f1JVUbfqm.jpg'),
(136887, 9744, 'Kingdom [L] (2012) S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/267254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o42luESWDblD8xRQajV0gKA1XTr.jpg'),
(136888, 9744, 'Kingdom [L] (2012) S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/267255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aY0doUKJJshywrOpAbOx0C925jO.jpg'),
(136889, 9744, 'Kingdom [L] (2012) S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/267256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MofTH4CLvJIjwJlQ7GAgjm4yeU.jpg'),
(136890, 9744, 'Kingdom [L] (2012) S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/267257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dALn1TG96d8U7AXPZINey93nWzb.jpg'),
(136891, 9745, 'Kingdom [L] (2012) S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4dBclYVy9JTKMmOn7W1M1swYqDE.jpg'),
(136892, 9745, 'Kingdom [L] (2012) S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uNpVAbxVmz5GRN1yXPAv5Qe7ghA.jpg'),
(136893, 9745, 'Kingdom [L] (2012) S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e9SoWJWfhOGHv4yCYI15HtrfuKj.jpg'),
(136894, 9745, 'Kingdom [L] (2012) S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lYCS81h1rZtj2XCJ93A3pmep55.jpg'),
(136895, 9745, 'Kingdom [L] (2012) S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iAXJvYhzxsoQ4hQykZHaqzrrq7F.jpg'),
(136896, 9745, 'Kingdom [L] (2012) S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0u5gkHvcrTZ6fJkHJf0HYHIzHx.jpg'),
(136897, 9745, 'Kingdom [L] (2012) S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1taU0cXUKG24HhPBaCnqxhq2K1i.jpg'),
(136898, 9745, 'Kingdom [L] (2012) S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bqRa73hvKjLEEcJcApGTvjqqdE3.jpg'),
(136899, 9745, 'Kingdom [L] (2012) S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNZ0vurB5xHFwzVlx3Vl9cXsSgd.jpg'),
(136900, 9745, 'Kingdom [L] (2012) S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/14couZHbVx8MFoFCRcR7BMDiBdU.jpg'),
(136901, 9745, 'Kingdom [L] (2012) S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnpc93CYaxN9hZej8j9wS24Ojsd.jpg'),
(136902, 9745, 'Kingdom [L] (2012) S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nHUywHSmNtScfsp6d75SZ1QmGj2.jpg'),
(136903, 9745, 'Kingdom [L] (2012) S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mVR3qeaLBxYYq6brucIW3h3xxYn.jpg'),
(136904, 9745, 'Kingdom [L] (2012) S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXrSORYUd0CshNBDfKpREtAzwTu.jpg'),
(136905, 9745, 'Kingdom [L] (2012) S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qLWr08JzBkYU7KVinxaGTYVHkEA.jpg'),
(136906, 9745, 'Kingdom [L] (2012) S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j0v0emhCKZ0ZLzpgks347qARc5f.jpg'),
(136907, 9745, 'Kingdom [L] (2012) S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXi8bFbKa1Evpvx6pppiHTrZh01.jpg'),
(136908, 9745, 'Kingdom [L] (2012) S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ibJrT7bfI1C1GCTEWwqFQLT6pxC.jpg'),
(136909, 9745, 'Kingdom [L] (2012) S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t1oqT3bXvA34NME9SHiuYHLEHeQ.jpg'),
(136910, 9745, 'Kingdom [L] (2012) S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/776t758Fm9PwoUinG76I8JGBUJS.jpg'),
(136911, 9745, 'Kingdom [L] (2012) S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/267278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/474IBUWFsHIAMllq6mJvHgslNUS.jpg'),
(136912, 9745, 'Kingdom [L] (2012) S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/267279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMp6fHYY0VFyPQ53id1XsoJP2i9.jpg'),
(136913, 9745, 'Kingdom [L] (2012) S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/267280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hnzrqDcaE1vx8ri2BQNL7aBrCxf.jpg'),
(136914, 9745, 'Kingdom [L] (2012) S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/267281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nXKV7flvU8plS0m7ZhZgUbjpr4X.jpg'),
(136915, 9745, 'Kingdom [L] (2012) S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/267282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4nqPYomZQxeUZZhlL22i3UeyTt7.jpg'),
(136916, 9745, 'Kingdom [L] (2012) S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/267283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sdBtRs7v6ACq1x991TxEVaRMKEv.jpg'),
(136917, 9746, 'Kingdom [L] (2012) S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ooWxOAjk51eOJlyoG8KEEWLklzN.jpg'),
(136918, 9746, 'Kingdom [L] (2012) S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gTdbHkA3aQ87Qgj24K93iK1vXgI.jpg'),
(136919, 9746, 'Kingdom [L] (2012) S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wsPFjN9dlucR9aXoThihlO8XWx5.jpg'),
(136920, 9747, 'Meiji Gekken 1874 [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rbyRMHm2oxf1MM2JEXDvrjlBgwp.jpg'),
(136921, 9747, 'Meiji Gekken 1874 [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2VjBgof9gg75iD3L1CNa4SGIn8H.jpg'),
(136922, 9747, 'Meiji Gekken 1874 [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bccU7aP0PoXB2aPoR8YHPDAXcwt.jpg'),
(136923, 9747, 'Meiji Gekken 1874 [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/272782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/79cgwtU1Q4apjEyBQnB9YaBEn7t.jpg'),
(136924, 9747, 'Meiji Gekken 1874 [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/272783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/79cgwtU1Q4apjEyBQnB9YaBEn7t.jpg'),
(136925, 9747, 'Meiji Gekken 1874 [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/276370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/79cgwtU1Q4apjEyBQnB9YaBEn7t.jpg'),
(136926, 9747, 'Meiji Gekken 1874 [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/79cgwtU1Q4apjEyBQnB9YaBEn7t.jpg'),
(136927, 9747, 'Meiji Gekken 1874 [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/79cgwtU1Q4apjEyBQnB9YaBEn7t.jpg'),
(136928, 9747, 'Meiji Gekken 1874 [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/299161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/79cgwtU1Q4apjEyBQnB9YaBEn7t.jpg'),
(136929, 9747, 'Meiji Gekken 1874 [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/304291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/79cgwtU1Q4apjEyBQnB9YaBEn7t.jpg'),
(136930, 9748, 'Miss Hammurabi [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vyftGXja69yBagLBbEEuF7BPgXB.jpg'),
(136931, 9748, 'Miss Hammurabi [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fJ19aPPYTSRFK672USEG7oI4Zuk.jpg'),
(136932, 9748, 'Miss Hammurabi [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/32HrlEmZO0QdkdUoIQJfvmj4hkR.jpg'),
(136933, 9748, 'Miss Hammurabi [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w480wFoErHPxfOHUXrwHM4dZ8wU.jpg'),
(136934, 9748, 'Miss Hammurabi [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5BJexCVYbqofzaIp4C3JNgzOPPK.jpg'),
(136935, 9748, 'Miss Hammurabi [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4nRqbhshv0w8Ed1CoZae3cbyaVq.jpg'),
(136936, 9748, 'Miss Hammurabi [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Eeewj9p4ZGPcCCQlVPPP7YTSQW.jpg'),
(136937, 9748, 'Miss Hammurabi [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nBH9jvQ6gVrWLqtzjfcOQzrF6XH.jpg'),
(136938, 9748, 'Miss Hammurabi [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cAbIDj5D1E1Zp97sgwpR15Y0nrh.jpg'),
(136939, 9748, 'Miss Hammurabi [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nY3f4Ofwbc4MhZTteEvOoruaSeo.jpg'),
(136940, 9748, 'Miss Hammurabi [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vtph04hKxVa3Ev1uv8SfRQtOv0N.jpg'),
(136941, 9748, 'Miss Hammurabi [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/faRPuomkawzez5HDSVfFsfG70Nq.jpg'),
(136942, 9748, 'Miss Hammurabi [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zVLXbYySlHIX2B11TSkz8XIoDtA.jpg'),
(136943, 9748, 'Miss Hammurabi [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2aKMJVjNzc408zVdYBjT7IL7yyk.jpg'),
(136944, 9748, 'Miss Hammurabi [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3jkqKvsVsf9ep6QmTkvkFnl1fEX.jpg'),
(136945, 9748, 'Miss Hammurabi [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9wGxHA6dvHMSGVfjbuYyKYSdsbb.jpg'),
(136946, 9749, 'Miss Scarlet and the Duke [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/270305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hCOhkWNsE8Xw7XF8GXtCeV58a0W.jpg'),
(136947, 9749, 'Miss Scarlet and the Duke [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/270306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Rv6hHiormj00oEZJjarHHo11GZ.jpg'),
(136948, 9749, 'Miss Scarlet and the Duke [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/270307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cnXYPblCkd9VPz0DoASayZZAGzG.jpg'),
(136949, 9749, 'Miss Scarlet and the Duke [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/270308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zgdSo7hdsNSQ7I4ZoBjbm93Tyev.jpg'),
(136950, 9749, 'Miss Scarlet and the Duke [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/270309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/reLpdjVeB9PT0ctjJxEqFd8TG5s.jpg'),
(136951, 9749, 'Miss Scarlet and the Duke [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/270310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cX0AbqiAazTEmSR6etib10eSrXg.jpg'),
(136952, 9750, 'Miss Scarlet and the Duke [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/270311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Ixqtv7dRpUJgnZsCilQXhIKJAA.jpg'),
(136953, 9750, 'Miss Scarlet and the Duke [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/270312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Auij6P2HmHacV4gWrF1FYRJ7Fpk.jpg'),
(136954, 9750, 'Miss Scarlet and the Duke [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/270313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s1aXB0kTrhbSg5Y9WLWCipxJBil.jpg'),
(136955, 9750, 'Miss Scarlet and the Duke [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/270314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bYkuhwnomEQJjPbFVoo1yJtdNmM.jpg'),
(136956, 9750, 'Miss Scarlet and the Duke [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/270315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AkPQBFnXvIApLmdn59SKigK7TLP.jpg'),
(136957, 9750, 'Miss Scarlet and the Duke [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/270316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hDS1VB5fP92KLGaqPj4WG2H8QwA.jpg'),
(136958, 9751, 'Miss Scarlet and the Duke [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/270317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8EPyBxLs0BQwsMCvFXEEMysZqnd.jpg'),
(136959, 9751, 'Miss Scarlet and the Duke [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/270318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cM0NbPkSxkbOta5jOqVkDYKXk2r.jpg'),
(136960, 9751, 'Miss Scarlet and the Duke [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/270319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fT3kbZyXAYvL86XBoEqYIRvKC84.jpg'),
(136961, 9751, 'Miss Scarlet and the Duke [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/270320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ki5AoOndSqpPOBOX6uA4DiaETH4.jpg'),
(136962, 9751, 'Miss Scarlet and the Duke [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/270321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aHuki4g5lDxvCegQD0Afcby1ArW.jpg'),
(136963, 9751, 'Miss Scarlet and the Duke [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/270322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fJMTJmIcpb943mWbMVfIY5u3nUF.jpg'),
(136964, 9752, 'Miss Scarlet and the Duke [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/270323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vZjYYekOyYKJhZLVjLxHoXZeBxr.jpg'),
(136965, 9752, 'Miss Scarlet and the Duke [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/270324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z0rKaNH8CgVcrN2GMjjzkxgeBqY.jpg'),
(136966, 9752, 'Miss Scarlet and the Duke [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/270325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QGmnb5QA9PC558N21d3QeadzjE.jpg'),
(136967, 9752, 'Miss Scarlet and the Duke [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/270326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/on6VMTJzyqhE36oNUNTDuOX3fpL.jpg'),
(136968, 9752, 'Miss Scarlet and the Duke [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/270327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/22fIHt8fV3lDV1dz9Obs13BhtTR.jpg'),
(136969, 9752, 'Miss Scarlet and the Duke [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/270328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bxEMMwGZj247kelubXLky7yaGFH.jpg'),
(136970, 9753, 'Miss Scarlet and the Duke [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/525256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bxEMMwGZj247kelubXLky7yaGFH.jpg'),
(136971, 9753, 'Miss Scarlet and the Duke [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/525257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bxEMMwGZj247kelubXLky7yaGFH.jpg'),
(136972, 9753, 'Miss Scarlet and the Duke [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bxEMMwGZj247kelubXLky7yaGFH.jpg'),
(136973, 9753, 'Miss Scarlet and the Duke [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/660259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bxEMMwGZj247kelubXLky7yaGFH.jpg'),
(136974, 9753, 'Miss Scarlet and the Duke [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/668494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bxEMMwGZj247kelubXLky7yaGFH.jpg'),
(136975, 9753, 'Miss Scarlet and the Duke [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/668495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bxEMMwGZj247kelubXLky7yaGFH.jpg'),
(136976, 9754, 'Monsieur Spade [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gjbXoLAtDnzSJn5spAvHOd7xYD2.jpg'),
(136977, 9754, 'Monsieur Spade [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2uqkRZCZjiFY5KXfbJGEdTg7Xxb.jpg'),
(136978, 9754, 'Monsieur Spade [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5B0fvoxRPT7mhZMgMSAM27j6QZb.jpg'),
(136979, 9754, 'Monsieur Spade [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/276359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5B0fvoxRPT7mhZMgMSAM27j6QZb.jpg'),
(136980, 9754, 'Monsieur Spade [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/302483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5B0fvoxRPT7mhZMgMSAM27j6QZb.jpg'),
(136981, 9754, 'Monsieur Spade [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/330542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5B0fvoxRPT7mhZMgMSAM27j6QZb.jpg'),
(136982, 9755, 'Muv Luv Alternative [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7jIDbuoHXnhla2CLDdkBtQXpN5y.jpg'),
(136983, 9755, 'Muv Luv Alternative [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rmRZwKJpseE8RmHMRx5XO8TwqD5.jpg'),
(136984, 9755, 'Muv Luv Alternative [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/YwcIWSnu8KWHEOG7MIXw2KDNLN.jpg'),
(136985, 9755, 'Muv Luv Alternative [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dyOn2qEC615Tfb3X0WcGFFpUyxD.jpg'),
(136986, 9755, 'Muv Luv Alternative [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cyCZqegOb9yzRF5gW6vx2M1rtxh.jpg'),
(136987, 9755, 'Muv Luv Alternative [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mFGUGRLSbtaxMOfUEfrNs2yvuMP.jpg'),
(136988, 9755, 'Muv Luv Alternative [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rjeavyYJZt1t8FiTb7Y9Yzb4Pc1.jpg'),
(136989, 9755, 'Muv Luv Alternative [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pCuTnXKklyjpu4ZoHczLyr7YgXa.jpg'),
(136990, 9755, 'Muv Luv Alternative [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/exwmLytusZDDCtob8uMlYuFJpWv.jpg'),
(136991, 9755, 'Muv Luv Alternative [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/YrpUfadvESqMxkh1mlMCYgXS9v.jpg'),
(136992, 9755, 'Muv Luv Alternative [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mjNMXaneuwDbpSjg2smxK2LSm3F.jpg'),
(136993, 9755, 'Muv Luv Alternative [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2KbCPfOBo9gR9Di1ejkNU7yRGwy.jpg'),
(136994, 9756, 'Muv Luv Alternative [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wAdn6rxFeAYGV5FdtNTO2urzReL.jpg'),
(136995, 9756, 'Muv Luv Alternative [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wAdn6rxFeAYGV5FdtNTO2urzReL.jpg'),
(136996, 9756, 'Muv Luv Alternative [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wAdn6rxFeAYGV5FdtNTO2urzReL.jpg'),
(136997, 9756, 'Muv Luv Alternative [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wAdn6rxFeAYGV5FdtNTO2urzReL.jpg'),
(136998, 9756, 'Muv Luv Alternative [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wAdn6rxFeAYGV5FdtNTO2urzReL.jpg'),
(136999, 9756, 'Muv Luv Alternative [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wAdn6rxFeAYGV5FdtNTO2urzReL.jpg'),
(137000, 9756, 'Muv Luv Alternative [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wAdn6rxFeAYGV5FdtNTO2urzReL.jpg'),
(137001, 9756, 'Muv Luv Alternative [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wAdn6rxFeAYGV5FdtNTO2urzReL.jpg'),
(137002, 9756, 'Muv Luv Alternative [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wAdn6rxFeAYGV5FdtNTO2urzReL.jpg'),
(137003, 9756, 'Muv Luv Alternative [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wAdn6rxFeAYGV5FdtNTO2urzReL.jpg'),
(137004, 9756, 'Muv Luv Alternative [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wAdn6rxFeAYGV5FdtNTO2urzReL.jpg'),
(137005, 9756, 'Muv Luv Alternative [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wAdn6rxFeAYGV5FdtNTO2urzReL.jpg'),
(137006, 9757, 'My Beautiful Man [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sUByJksWE6s42t62lJ0DQNEPpSz.jpg'),
(137007, 9757, 'My Beautiful Man [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tP4J5U9IV7gKDyRMKYiLzgmSIVG.jpg'),
(137008, 9757, 'My Beautiful Man [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9cV3zWDQjlzQEfFPdXHAIY9uoiG.jpg'),
(137009, 9757, 'My Beautiful Man [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5FyxBqS5dS0lmQZkS4jFkghMNZM.jpg'),
(137010, 9757, 'My Beautiful Man [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/79w9lejkWxd9yvKw1Vvay9b9wLd.jpg'),
(137011, 9757, 'My Beautiful Man [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7RnMWg6v0YdmIP63BOjmRH1Mh0p.jpg'),
(137012, 9758, 'My Beautiful Man [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c4iI4vqJArGaJRoi2xt1FYa14PZ.jpg'),
(137013, 9758, 'My Beautiful Man [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qf0zLRyxpGDwf5ZvF39W7Q9PdjQ.jpg'),
(137014, 9758, 'My Beautiful Man [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhLcowv9Yd9n8IzwtLMZmRJAyUO.jpg'),
(137015, 9758, 'My Beautiful Man [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fX5X94GPXHXtkndDyJDEwHkibwv.jpg'),
(137016, 9759, 'O Ultimo Imortal [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xrhciDlauLvss9b9ttaXQMuylAo.jpg'),
(137017, 9759, 'O Ultimo Imortal [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w6S6ajMt0voHWckgWBSFscZ7WEo.jpg'),
(137018, 9759, 'O Ultimo Imortal [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5AUbBdQXuH8eFVTHVXEwZs0I9cv.jpg'),
(137019, 9759, 'O Ultimo Imortal [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rMQh8YTy2j7gs9ccAyt9bT4ktWC.jpg'),
(137020, 9759, 'O Ultimo Imortal [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mmvRymhZo53yjxTjVpBG3eMSK7R.jpg'),
(137021, 9759, 'O Ultimo Imortal [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cSdyYY1bBXgAkDxJJYU4R5IDUfb.jpg'),
(137022, 9759, 'O Ultimo Imortal [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/syj9X607dQxgBZPp2turLIQD0WC.jpg'),
(137023, 9759, 'O Ultimo Imortal [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7DMzkgIsMswx6D2qJVgk2adUI4Z.jpg'),
(137024, 9759, 'O Ultimo Imortal [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qs676Pow6ExvWpUSeuPbuQ9Tv0N.jpg'),
(137025, 9759, 'O Ultimo Imortal [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cbAu045IkqRNuppCjONfDIrYQ73.jpg'),
(137026, 9759, 'O Ultimo Imortal [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1pKslJW3PFHtJMRpBfix8zWFr9J.jpg'),
(137027, 9759, 'O Ultimo Imortal [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xMN1DggzgRXV3gX16ZKN1X3oynv.jpg'),
(137028, 9759, 'O Ultimo Imortal [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ysh5paPc3C4PMsxJdX8pLmMYsl.jpg'),
(137029, 9759, 'O Ultimo Imortal [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/SWn72VflwkVJreynR9GOiBPTr4.jpg'),
(137030, 9759, 'O Ultimo Imortal [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ovldXMnMUEXpwmxwOGLmbMwxZZO.jpg'),
(137031, 9759, 'O Ultimo Imortal [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uzIJQnRkVg4H59is3xCg5xV5gW4.jpg'),
(137032, 9759, 'O Ultimo Imortal [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/reg3POXQhJ8hQWMjUmlbfRVIKbL.jpg'),
(137033, 9759, 'O Ultimo Imortal [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJ0UbhtKl8LbxGwo0A0MVOUqijF.jpg'),
(137034, 9759, 'O Ultimo Imortal [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3lq84PaI6wtnIBE2H47aroiOxW7.jpg'),
(137035, 9759, 'O Ultimo Imortal [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3SLQ5Hh3b5gH8qFnLW5DK1Zvwhr.jpg'),
(137036, 9759, 'O Ultimo Imortal [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/267082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AhmgcT9vHtVXFT2B69QXb1CLZiQ.jpg'),
(137037, 9759, 'O Ultimo Imortal [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/267083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tEte9UHuRHyatNSoZrwMF0i7nXV.jpg'),
(137038, 9759, 'O Ultimo Imortal [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/267084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yLKpwKa7goh1plqL4uYRzgd2jmV.jpg'),
(137039, 9759, 'O Ultimo Imortal [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/267085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fF0sdxInAWL1TtJ1FA39AEcvB6a.jpg'),
(137040, 9759, 'O Ultimo Imortal [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/267086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gl8H5bijwyHizCVvI0j152kdDw9.jpg'),
(137041, 9759, 'O Ultimo Imortal [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/267087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kePm4yOLZiFXVrmL5VYq6v5BG8T.jpg'),
(137042, 9759, 'O Ultimo Imortal [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/267088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/91ZTjkR6tFwZj1KSqGuQX6lpn2K.jpg'),
(137043, 9759, 'O Ultimo Imortal [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/267089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rmztqyH3sF3oKaS611TdIYeB8gk.jpg'),
(137044, 9759, 'O Ultimo Imortal [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/267090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kEMHth9TKfmZ8q7mXs6gJJULVtr.jpg'),
(137045, 9759, 'O Ultimo Imortal [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/267091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7tJI0IxCRNmBGLp1agmSkoyXEuw.jpg'),
(137046, 9759, 'O Ultimo Imortal [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/267092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zmurWMzuSiKCVUqNSGKRDmxa5Cf.jpg'),
(137047, 9759, 'O Ultimo Imortal [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/267093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6uOD8S7Vl7XIVlsHaBPVRkC43hq.jpg'),
(137048, 9759, 'O Ultimo Imortal [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/267094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/55jGBYHDmSlAbXhqGhcqrcBuZ3Y.jpg'),
(137049, 9759, 'O Ultimo Imortal [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/267095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8PGvAKsrTDZaLjouDDZdrslhPcc.jpg'),
(137050, 9759, 'O Ultimo Imortal [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/267096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kphvcvK1kpLv6v8nZaeRTA1DT9z.jpg'),
(137051, 9759, 'O Ultimo Imortal [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/267097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vM6RivRuNWWHq43dx411H82BpLu.jpg'),
(137052, 9759, 'O Ultimo Imortal [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/267098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bn0YQXtKzWAQvcrP3gjAEQGwXul.jpg'),
(137053, 9759, 'O Ultimo Imortal [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/267099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dUdGDjE9OnxVYxNl8iuwVKDzOSe.jpg'),
(137054, 9759, 'O Ultimo Imortal [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/267100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a1h6qceh3xb0H0uAoFuJYAYSArG.jpg'),
(137055, 9759, 'O Ultimo Imortal [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/267101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZk2MPrDDjzH7PcRZFiMrmjL3DJ.jpg'),
(137056, 9760, 'Ossans Love In the Sky [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tOZrwVdXxsrIrw3NrYyVsKO2N31.jpg'),
(137057, 9760, 'Ossans Love In the Sky [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n8mcdFQ3F3iqXp4Q9bDb6fiJozt.jpg'),
(137058, 9760, 'Ossans Love In the Sky [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lfv6pxXTKdpn2naKqP7W5f4qWtJ.jpg'),
(137059, 9760, 'Ossans Love In the Sky [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dhzpSub052JzVmnYSOFRLVZxrtY.jpg'),
(137060, 9760, 'Ossans Love In the Sky [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zPBA74jH9CE60nhYAXEJp0pZgZC.jpg'),
(137061, 9760, 'Ossans Love In the Sky [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wqUMMpr8HL5GKSTvW2A8uKzUWTz.jpg'),
(137062, 9760, 'Ossans Love In the Sky [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b6XcEYGrfGLHGhcQvQHImed24bM.jpg'),
(137063, 9760, 'Ossans Love In the Sky [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eCL8jt8LXn9HYcryamPg9rNHMHe.jpg'),
(137064, 9761, 'Ossans Love Returns [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eJj3fEcvppfXezbLklsqTBf1KoB.jpg'),
(137065, 9761, 'Ossans Love Returns [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4l73v45bSTyKDzOttID5FXZoZAm.jpg'),
(137066, 9761, 'Ossans Love Returns [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4l73v45bSTyKDzOttID5FXZoZAm.jpg'),
(137067, 9761, 'Ossans Love Returns [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4l73v45bSTyKDzOttID5FXZoZAm.jpg'),
(137068, 9761, 'Ossans Love Returns [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/272698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4l73v45bSTyKDzOttID5FXZoZAm.jpg'),
(137069, 9761, 'Ossans Love Returns [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/275241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4l73v45bSTyKDzOttID5FXZoZAm.jpg'),
(137070, 9761, 'Ossans Love Returns [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/290837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4l73v45bSTyKDzOttID5FXZoZAm.jpg'),
(137071, 9761, 'Ossans Love Returns [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/290838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4l73v45bSTyKDzOttID5FXZoZAm.jpg'),
(137072, 9761, 'Ossans Love Returns [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/295442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4l73v45bSTyKDzOttID5FXZoZAm.jpg'),
(137073, 9762, 'Ossans Love [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c5RC0Iv3NLJmvsZmwNdJPOW5HIg.jpg'),
(137074, 9762, 'Ossans Love [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6o5XuUudKLEYzkh3DGUcyANpMEu.jpg'),
(137075, 9762, 'Ossans Love [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jJfqMEkup1MsgkkeRQ3h2AD2BFy.jpg'),
(137076, 9762, 'Ossans Love [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9LKtqr79ptLOdOAqtxAR3ZJ54Z0.jpg'),
(137077, 9762, 'Ossans Love [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pi6tM56ZB59vMCGBMuaRmenMRV7.jpg'),
(137078, 9762, 'Ossans Love [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8D6CPeK56BoBlHAr50ApHpxSJkR.jpg'),
(137079, 9762, 'Ossans Love [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m8qGQISn8xlV0hdD0uIe7isZxXJ.jpg'),
(137080, 9763, 'Planeta Sheen S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1pZIm7qcmX4e1YqEgXPOPblRiJT.jpg'),
(137081, 9763, 'Planeta Sheen S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137082, 9763, 'Planeta Sheen S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137083, 9763, 'Planeta Sheen S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137084, 9763, 'Planeta Sheen S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137085, 9763, 'Planeta Sheen S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137086, 9763, 'Planeta Sheen S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/267027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137087, 9763, 'Planeta Sheen S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/267028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137088, 9763, 'Planeta Sheen S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/267029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137089, 9763, 'Planeta Sheen S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/267030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137090, 9763, 'Planeta Sheen S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/267031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137091, 9763, 'Planeta Sheen S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/267032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137092, 9763, 'Planeta Sheen S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/267033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137093, 9763, 'Planeta Sheen S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/267034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137094, 9763, 'Planeta Sheen S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/267035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137095, 9763, 'Planeta Sheen S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/267036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137096, 9763, 'Planeta Sheen S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/267037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137097, 9763, 'Planeta Sheen S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/267038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137098, 9763, 'Planeta Sheen S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/267039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137099, 9763, 'Planeta Sheen S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137100, 9763, 'Planeta Sheen S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/267041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137101, 9763, 'Planeta Sheen S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/267042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137102, 9763, 'Planeta Sheen S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/267043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137103, 9763, 'Planeta Sheen S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/267044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137104, 9763, 'Planeta Sheen S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/267045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137105, 9763, 'Planeta Sheen S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/267046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27A7tRW34HFdWLVfbBxcwsDuNc8.jpg'),
(137106, 9764, 'Random Acts of Flyness [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mMABu13MtM9xvjwxQKNXfS7FA3Q.jpg'),
(137107, 9764, 'Random Acts of Flyness [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/amSgHSoWKRmz1fg3xXBhdkOcRVh.jpg'),
(137108, 9764, 'Random Acts of Flyness [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wAmjrZIqHBIeu8CX2X1oOnAzPHG.jpg'),
(137109, 9764, 'Random Acts of Flyness [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/imxyuRdGHuuuMVwxdzoOi2n0fTa.jpg'),
(137110, 9764, 'Random Acts of Flyness [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aYM4AGqUjdtVyHozUDpcBm6rIzn.jpg'),
(137111, 9764, 'Random Acts of Flyness [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7IEScAyia15o0AE3hRcHB9ivdPy.jpg'),
(137112, 9765, 'Random Acts of Flyness [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ke14ZCEzcwr6XdvymlMsndRVcav.jpg'),
(137113, 9765, 'Random Acts of Flyness [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u6DgT6pdVCavfr2MvqMU7tL92cS.jpg'),
(137114, 9765, 'Random Acts of Flyness [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7kZj6sh6WF9C988JuVfgDL1a2Bu.jpg'),
(137115, 9765, 'Random Acts of Flyness [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p80bDmg6I1NvIbMjlt4LXU5rK1V.jpg'),
(137116, 9765, 'Random Acts of Flyness [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7rzSH1spqmvjZCbJa8Kz6lRxJ3K.jpg'),
(137117, 9765, 'Random Acts of Flyness [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkBWUZoAN0IYuVvkmkMbsSABAzC.jpg'),
(137118, 9766, 'Sem Atividade Italia [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/267003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nfTY9xHfM8vMdlk2a2uUyV56gQI.jpg'),
(137119, 9766, 'Sem Atividade Italia [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/267004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rn6iF2d3grbz9MpOvFJVwTXN8RF.jpg'),
(137120, 9766, 'Sem Atividade Italia [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/267005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zfuHNZl00M95dfGMWCiWEx4sx5a.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(137121, 9766, 'Sem Atividade Italia [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/267006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xGaTmW8AS0jus53eymwOhVdRPhF.jpg'),
(137122, 9766, 'Sem Atividade Italia [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/267007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nKIjHS5pLf1QoQ0cO6MC2MUWgYB.jpg'),
(137123, 9766, 'Sem Atividade Italia [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/267008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lRp6aSNkLcqtsI8bocRf3iUzeg6.jpg'),
(137124, 9767, 'The Castaways [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o9ysOA3WWZBpOtFdRN7FWpPQTa.jpg'),
(137125, 9767, 'The Castaways [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nzcjCzx08VHP9k0j6jMZaEASdEc.jpg'),
(137126, 9767, 'The Castaways [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x4zWhedIoVJ2WvSKKUuUE3JDG4k.jpg'),
(137127, 9767, 'The Castaways [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x4zWhedIoVJ2WvSKKUuUE3JDG4k.jpg'),
(137128, 9767, 'The Castaways [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x4zWhedIoVJ2WvSKKUuUE3JDG4k.jpg'),
(137129, 9768, 'The Crazy Ones [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bFMrqnywudDEOChmt9NkduypAo7.jpg'),
(137130, 9768, 'The Crazy Ones [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fhxVfPK9jiji9X5wlexV2iGyfN1.jpg'),
(137131, 9768, 'The Crazy Ones [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5pCRf0zIs9Y0cmYk1rzsp2dFm75.jpg'),
(137132, 9768, 'The Crazy Ones [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s2e7hTrdmNUaJDf0yDP5b4AHvrD.jpg'),
(137133, 9768, 'The Crazy Ones [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s2e7hTrdmNUaJDf0yDP5b4AHvrD.jpg'),
(137134, 9768, 'The Crazy Ones [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s2e7hTrdmNUaJDf0yDP5b4AHvrD.jpg'),
(137135, 9768, 'The Crazy Ones [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s2e7hTrdmNUaJDf0yDP5b4AHvrD.jpg'),
(137136, 9768, 'The Crazy Ones [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yJAhEgeYHiVhkSHOXlRvUSWiQhd.jpg'),
(137137, 9768, 'The Crazy Ones [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uw3PluMM8lVt6wtUcWTRxJzwROD.jpg'),
(137138, 9768, 'The Crazy Ones [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fYNa3eprqvQwRVsYGEmHwPEm0B.jpg'),
(137139, 9768, 'The Crazy Ones [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/78po0mGAnNJ5xgyMv6Vm2YdGFlD.jpg'),
(137140, 9768, 'The Crazy Ones [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ykPaTfaIJT9amym6fxRPBtTKhs7.jpg'),
(137141, 9768, 'The Crazy Ones [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yKHn2IUqFzaKWl9wPvLqd2iVgXV.jpg'),
(137142, 9768, 'The Crazy Ones [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2uH5uCAk2F2osH9PqXIin4LNH0d.jpg'),
(137143, 9768, 'The Crazy Ones [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/266995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j5xIGzBrF9ZIkF33UKLOrtTzhBG.jpg'),
(137144, 9768, 'The Crazy Ones [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/266996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g3LMFE6gH9RlKu0JBsLTo3kgcir.jpg'),
(137145, 9768, 'The Crazy Ones [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/266997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/azk2N9pbGQmeFlcXxp3c7dm0nve.jpg'),
(137146, 9768, 'The Crazy Ones [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/266998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kHdfnnpdsqnduaTgAGAfgOL7Ovo.jpg'),
(137147, 9768, 'The Crazy Ones [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/266999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fJMhP11H004MntCyYyJN0fSuBte.jpg'),
(137148, 9768, 'The Crazy Ones [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/267000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Y41RO9vLAYdNDkmMAmHovslxBp.jpg'),
(137149, 9768, 'The Crazy Ones [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/267001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9V2If28ZVlFoo2GwM4367FNoDgY.jpg'),
(137150, 9768, 'The Crazy Ones [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/267002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cHfJkYT342j4Tb6nCavEywhnrRf.jpg'),
(137151, 9769, 'The Fire Hunter [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bbS6d4tKsNE1UxFbilZ1aam2CXu.jpg'),
(137152, 9769, 'The Fire Hunter [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o83ezsAX7GTNFWjbFityCzNIfnZ.jpg'),
(137153, 9769, 'The Fire Hunter [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dDxtWczmpYVK7LNenNxhdZflchg.jpg'),
(137154, 9769, 'The Fire Hunter [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A9boGYOdPrX539X58AwBw99PX3A.jpg'),
(137155, 9769, 'The Fire Hunter [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpEWjeeffZOYdtDpLd6Rn4eJsbs.jpg'),
(137156, 9769, 'The Fire Hunter [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkDeu3NVGJfiJ3GO1Dif7XZC2jA.jpg'),
(137157, 9769, 'The Fire Hunter [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pgnMlxeLNApGg7wkKsRfrNbtUQq.jpg'),
(137158, 9769, 'The Fire Hunter [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y21R6YFxqVfb1lOJGuMHju09mCF.jpg'),
(137159, 9769, 'The Fire Hunter [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2AHRdhdje9hZcVL7YxiUTphOHTL.jpg'),
(137160, 9769, 'The Fire Hunter [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2jBtyNAEzhmjxEMyhzwh2DK5Hc8.jpg'),
(137161, 9770, 'The Fire Hunter [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v8AbZ7MOwoABASQFP3GJp6xLR1f.jpg'),
(137162, 9770, 'The Fire Hunter [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v8AbZ7MOwoABASQFP3GJp6xLR1f.jpg'),
(137163, 9770, 'The Fire Hunter [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v8AbZ7MOwoABASQFP3GJp6xLR1f.jpg'),
(137164, 9770, 'The Fire Hunter [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/282534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v8AbZ7MOwoABASQFP3GJp6xLR1f.jpg'),
(137165, 9770, 'The Fire Hunter [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v8AbZ7MOwoABASQFP3GJp6xLR1f.jpg'),
(137166, 9770, 'The Fire Hunter [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/282536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v8AbZ7MOwoABASQFP3GJp6xLR1f.jpg'),
(137167, 9770, 'The Fire Hunter [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/297061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v8AbZ7MOwoABASQFP3GJp6xLR1f.jpg'),
(137168, 9770, 'The Fire Hunter [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/297062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v8AbZ7MOwoABASQFP3GJp6xLR1f.jpg'),
(137169, 9770, 'The Fire Hunter [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/297063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v8AbZ7MOwoABASQFP3GJp6xLR1f.jpg'),
(137170, 9770, 'The Fire Hunter [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/307141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v8AbZ7MOwoABASQFP3GJp6xLR1f.jpg'),
(137171, 9771, 'The Misfit of Demon King Academy [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8omTdSkGQAnvS2Teq7q4N5bTwe5.jpg'),
(137172, 9771, 'The Misfit of Demon King Academy [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1wFdgrS3zyalpYcHzDfyaeG0CuC.jpg'),
(137173, 9771, 'The Misfit of Demon King Academy [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AnxXHDup6Zsk6Hrei687HG23XIo.jpg'),
(137174, 9771, 'The Misfit of Demon King Academy [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AwkGVYg9MdNJdM2Dq8bjjKXJriN.jpg'),
(137175, 9771, 'The Misfit of Demon King Academy [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zYwRHNSuwvvBmOkLojOV9S7FzEk.jpg'),
(137176, 9771, 'The Misfit of Demon King Academy [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r9FlPBh5F2uoylTeXyXpq9E4rEg.jpg'),
(137177, 9771, 'The Misfit of Demon King Academy [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c0TYBO1uYejw3jvc8jFvT8bV55h.jpg'),
(137178, 9771, 'The Misfit of Demon King Academy [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/58YiF76gkWgGEgaKkmBFM6yhpGH.jpg'),
(137179, 9771, 'The Misfit of Demon King Academy [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mVhYQ6CRbzgO9EXQVWwAFTtYy5H.jpg'),
(137180, 9771, 'The Misfit of Demon King Academy [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzMv3y3zNy0qWtVS49h3B4ND2oP.jpg'),
(137181, 9771, 'The Misfit of Demon King Academy [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9hBk8zpN1pcz9ZxO17ggYUcl2v.jpg'),
(137182, 9771, 'The Misfit of Demon King Academy [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m3D8kiRM7lGZMyCkpTD6PBgc6Sa.jpg'),
(137183, 9771, 'The Misfit of Demon King Academy [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aIYI1zeXtZ8O58jZIgqtcT9B7xf.jpg'),
(137184, 9772, 'The Misfit of Demon King Academy [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mxoh475O9psVBJwczzwWUzjtJgb.jpg'),
(137185, 9772, 'The Misfit of Demon King Academy [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aNWLRgdbaAYLZ7DEQjyYYgsLgpT.jpg'),
(137186, 9772, 'The Misfit of Demon King Academy [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o4rinYH4SQF9jPhAzPaxpBwIqog.jpg'),
(137187, 9772, 'The Misfit of Demon King Academy [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nwnimnTL4w6gieZ0vF9EbSov4XG.jpg'),
(137188, 9772, 'The Misfit of Demon King Academy [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gO7liGJn1RxSiBUQNMUE7HaCtcw.jpg'),
(137189, 9772, 'The Misfit of Demon King Academy [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5EXI01gF2K6y4PoBaSQcU5byhdc.jpg'),
(137190, 9772, 'The Misfit of Demon King Academy [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6nFlAh5zmXhTNzPncDQx1FOVh17.jpg'),
(137191, 9772, 'The Misfit of Demon King Academy [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FZI0KXkoM8hkpc7hacvnNQh4EC.jpg'),
(137192, 9772, 'The Misfit of Demon King Academy [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/89mOvMKXDcxme3qfbAJvHRDtM9k.jpg'),
(137193, 9772, 'The Misfit of Demon King Academy [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ZQBu8AmrWrqSK1VxfPUN57heKI.jpg'),
(137194, 9772, 'The Misfit of Demon King Academy [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7plyIrHZASr4z2UXDKXpHwmVUl0.jpg'),
(137195, 9772, 'The Misfit of Demon King Academy [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZnEwSazlcg8GOb3Vrf0AkEaqTK.jpg'),
(137196, 9772, 'The Misfit of Demon King Academy [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/358365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eo45Dqpi8jvUwcnsFy95mYjuyG8.jpg'),
(137197, 9772, 'The Misfit of Demon King Academy [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/358366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eo45Dqpi8jvUwcnsFy95mYjuyG8.jpg'),
(137198, 9772, 'The Misfit of Demon King Academy [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/358367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eo45Dqpi8jvUwcnsFy95mYjuyG8.jpg'),
(137199, 9772, 'The Misfit of Demon King Academy [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/358368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eo45Dqpi8jvUwcnsFy95mYjuyG8.jpg'),
(137200, 9772, 'The Misfit of Demon King Academy [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/358369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eo45Dqpi8jvUwcnsFy95mYjuyG8.jpg'),
(137201, 9772, 'The Misfit of Demon King Academy [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/358370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eo45Dqpi8jvUwcnsFy95mYjuyG8.jpg'),
(137202, 9772, 'The Misfit of Demon King Academy [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/609976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eo45Dqpi8jvUwcnsFy95mYjuyG8.jpg'),
(137203, 9772, 'The Misfit of Demon King Academy [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/376219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eo45Dqpi8jvUwcnsFy95mYjuyG8.jpg'),
(137204, 9772, 'The Misfit of Demon King Academy [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/394033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eo45Dqpi8jvUwcnsFy95mYjuyG8.jpg'),
(137205, 9772, 'The Misfit of Demon King Academy [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/394034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eo45Dqpi8jvUwcnsFy95mYjuyG8.jpg'),
(137206, 9772, 'The Misfit of Demon King Academy [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/407089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eo45Dqpi8jvUwcnsFy95mYjuyG8.jpg'),
(137207, 9772, 'The Misfit of Demon King Academy [L] S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/414331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eo45Dqpi8jvUwcnsFy95mYjuyG8.jpg'),
(137208, 9773, 'The Strongest Tanks Labyrinth Raids A Tank with a Rare 9999 Resistance Skill Got Kicked from the Heros Party [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/80cJylUX1yB2u9mQGqWxxUk2ZWV.jpg'),
(137209, 9773, 'The Strongest Tanks Labyrinth Raids A Tank with a Rare 9999 Resistance Skill Got Kicked from the Heros Party [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2iBwTYRSKyYr5J1hIo1IotuJXvv.jpg'),
(137210, 9773, 'The Strongest Tanks Labyrinth Raids A Tank with a Rare 9999 Resistance Skill Got Kicked from the Heros Party [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lZTBZQ71rVJZM9t0SkVwsGj6Vqa.jpg'),
(137211, 9773, 'The Strongest Tanks Labyrinth Raids A Tank with a Rare 9999 Resistance Skill Got Kicked from the Heros Party [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kj3sM3OHC5AtCBUVlfvRfpq3VdD.jpg'),
(137212, 9773, 'The Strongest Tanks Labyrinth Raids A Tank with a Rare 9999 Resistance Skill Got Kicked from the Heros Party [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lOyFi5mNkUIELYrB1TvoIf9IPT6.jpg'),
(137213, 9773, 'The Strongest Tanks Labyrinth Raids A Tank with a Rare 9999 Resistance Skill Got Kicked from the Heros Party [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/272497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lOyFi5mNkUIELYrB1TvoIf9IPT6.jpg'),
(137214, 9773, 'The Strongest Tanks Labyrinth Raids A Tank with a Rare 9999 Resistance Skill Got Kicked from the Heros Party [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/285691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lOyFi5mNkUIELYrB1TvoIf9IPT6.jpg'),
(137215, 9773, 'The Strongest Tanks Labyrinth Raids A Tank with a Rare 9999 Resistance Skill Got Kicked from the Heros Party [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/279403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lOyFi5mNkUIELYrB1TvoIf9IPT6.jpg'),
(137216, 9773, 'The Strongest Tanks Labyrinth Raids A Tank with a Rare 9999 Resistance Skill Got Kicked from the Heros Party [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/285693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lOyFi5mNkUIELYrB1TvoIf9IPT6.jpg'),
(137217, 9773, 'The Strongest Tanks Labyrinth Raids A Tank with a Rare 9999 Resistance Skill Got Kicked from the Heros Party [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/297000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lOyFi5mNkUIELYrB1TvoIf9IPT6.jpg'),
(137218, 9773, 'The Strongest Tanks Labyrinth Raids A Tank with a Rare 9999 Resistance Skill Got Kicked from the Heros Party [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/300983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lOyFi5mNkUIELYrB1TvoIf9IPT6.jpg'),
(137219, 9773, 'The Strongest Tanks Labyrinth Raids A Tank with a Rare 9999 Resistance Skill Got Kicked from the Heros Party [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/307014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lOyFi5mNkUIELYrB1TvoIf9IPT6.jpg'),
(137220, 9774, 'The Vexations of a Shut In Vampire Princess [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/be7ZPbCztdKLsxKZAms96TLPuUr.jpg'),
(137221, 9774, 'The Vexations of a Shut In Vampire Princess [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dtYhasZdsKFwzFwYUD1yXShVVJc.jpg'),
(137222, 9774, 'The Vexations of a Shut In Vampire Princess [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/272491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rUBV8M3kfrfeEfpSztwcbRKLQci.jpg'),
(137223, 9774, 'The Vexations of a Shut In Vampire Princess [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/279386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rUBV8M3kfrfeEfpSztwcbRKLQci.jpg'),
(137224, 9774, 'The Vexations of a Shut In Vampire Princess [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/279387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rUBV8M3kfrfeEfpSztwcbRKLQci.jpg'),
(137225, 9774, 'The Vexations of a Shut In Vampire Princess [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/293941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rUBV8M3kfrfeEfpSztwcbRKLQci.jpg'),
(137226, 9774, 'The Vexations of a Shut In Vampire Princess [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/303790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rUBV8M3kfrfeEfpSztwcbRKLQci.jpg'),
(137227, 9774, 'The Vexations of a Shut In Vampire Princess [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/320986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rUBV8M3kfrfeEfpSztwcbRKLQci.jpg'),
(137228, 9774, 'The Vexations of a Shut In Vampire Princess [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/320987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rUBV8M3kfrfeEfpSztwcbRKLQci.jpg'),
(137229, 9774, 'The Vexations of a Shut In Vampire Princess [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/335678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rUBV8M3kfrfeEfpSztwcbRKLQci.jpg'),
(137230, 9774, 'The Vexations of a Shut In Vampire Princess [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/358264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rUBV8M3kfrfeEfpSztwcbRKLQci.jpg'),
(137231, 9774, 'The Vexations of a Shut In Vampire Princess [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/376186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rUBV8M3kfrfeEfpSztwcbRKLQci.jpg'),
(137232, 9775, 'Consciencia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1C4NSnaPD7exAvYgwe5ADpVOmGY.jpg'),
(137233, 9775, 'Consciencia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1C4NSnaPD7exAvYgwe5ADpVOmGY.jpg'),
(137234, 9775, 'Consciencia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1C4NSnaPD7exAvYgwe5ADpVOmGY.jpg'),
(137235, 9775, 'Consciencia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1C4NSnaPD7exAvYgwe5ADpVOmGY.jpg'),
(137236, 9775, 'Consciencia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1C4NSnaPD7exAvYgwe5ADpVOmGY.jpg'),
(137237, 9776, 'Drunk History A Historia Bebada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kTOpAg26R0gnxKR4DPhruVwLIi4.jpg'),
(137238, 9776, 'Drunk History A Historia Bebada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kTOpAg26R0gnxKR4DPhruVwLIi4.jpg'),
(137239, 9776, 'Drunk History A Historia Bebada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kTOpAg26R0gnxKR4DPhruVwLIi4.jpg'),
(137240, 9776, 'Drunk History A Historia Bebada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kTOpAg26R0gnxKR4DPhruVwLIi4.jpg'),
(137241, 9776, 'Drunk History A Historia Bebada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kTOpAg26R0gnxKR4DPhruVwLIi4.jpg'),
(137242, 9776, 'Drunk History A Historia Bebada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kTOpAg26R0gnxKR4DPhruVwLIi4.jpg'),
(137243, 9776, 'Drunk History A Historia Bebada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kTOpAg26R0gnxKR4DPhruVwLIi4.jpg'),
(137244, 9776, 'Drunk History A Historia Bebada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kTOpAg26R0gnxKR4DPhruVwLIi4.jpg'),
(137245, 9777, 'The OA S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJcYuR1CEIOYD4NIshCElZJQGpt.jpg'),
(137246, 9777, 'The OA S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7wU5qjeV4rk0yknLHgbedGL7qiB.jpg'),
(137247, 9777, 'The OA S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9gEq2vuvJGObh7HhJNm6PkHvnYR.jpg'),
(137248, 9777, 'The OA S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3TixJKjVFCzTkdFeGIjmaxCUD2m.jpg'),
(137249, 9777, 'The OA S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/reSZh2PGTnDLnpMijGldheQqxQ8.jpg'),
(137250, 9777, 'The OA S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mVNQoLpKi9wHOo1VgW6uUVYd0PC.jpg'),
(137251, 9777, 'The OA S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AtWZU7cS8vTwi7o8iaPv8SHhATy.jpg'),
(137252, 9777, 'The OA S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5rBNqkhQTXGvCSS6e280mmvo93X.jpg'),
(137253, 9778, 'The OA S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7YabSTKJVTuMKDt9NYFayPhOQMh.jpg'),
(137254, 9778, 'The OA S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qr4tngnSriVjDxEdmp79tTXjo7a.jpg'),
(137255, 9778, 'The OA S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vRGdAO9sSb68oVxCO63e3eZs3NC.jpg'),
(137256, 9778, 'The OA S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2x0CqtOphcZq7jkBKLa2P1BIZdb.jpg'),
(137257, 9778, 'The OA S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/weMykWd7luQfsxGUgXCOCNslGnG.jpg'),
(137258, 9778, 'The OA S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t5YHbJUkpbk5HFXBLZXYFwZY65q.jpg'),
(137259, 9778, 'The OA S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9zFC3Lvjcoq3HljvWp6BCtzdgzF.jpg'),
(137260, 9778, 'The OA S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4GnqkTkBMgWaQ2nMtZI6uiw8Kcv.jpg'),
(137261, 9779, 'Medabots S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137262, 9779, 'Medabots S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137263, 9779, 'Medabots S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137264, 9779, 'Medabots S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137265, 9779, 'Medabots S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137266, 9779, 'Medabots S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137267, 9779, 'Medabots S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137268, 9779, 'Medabots S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137269, 9779, 'Medabots S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137270, 9779, 'Medabots S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137271, 9779, 'Medabots S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137272, 9779, 'Medabots S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137273, 9779, 'Medabots S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137274, 9779, 'Medabots S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137275, 9779, 'Medabots S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/266747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137276, 9779, 'Medabots S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/266748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137277, 9779, 'Medabots S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/266749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137278, 9779, 'Medabots S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/266750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137279, 9779, 'Medabots S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/266751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137280, 9779, 'Medabots S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/266752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137281, 9779, 'Medabots S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/266753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137282, 9779, 'Medabots S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/266754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137283, 9779, 'Medabots S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/266755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137284, 9779, 'Medabots S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/266756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137285, 9779, 'Medabots S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/266757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137286, 9779, 'Medabots S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/266758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137287, 9779, 'Medabots S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/266759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137288, 9779, 'Medabots S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/266760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137289, 9779, 'Medabots S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/266761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137290, 9779, 'Medabots S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/266762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137291, 9779, 'Medabots S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/266763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137292, 9779, 'Medabots S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/266764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137293, 9779, 'Medabots S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/266765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137294, 9779, 'Medabots S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/266766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137295, 9779, 'Medabots S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/266767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137296, 9779, 'Medabots S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/266768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137297, 9779, 'Medabots S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/266769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137298, 9779, 'Medabots S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/266770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137299, 9779, 'Medabots S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/266771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137300, 9779, 'Medabots S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/266772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137301, 9779, 'Medabots S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/266773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137302, 9779, 'Medabots S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/266774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137303, 9779, 'Medabots S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/266775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137304, 9779, 'Medabots S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/266776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137305, 9779, 'Medabots S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/266777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137306, 9779, 'Medabots S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/266778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137307, 9779, 'Medabots S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/266779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137308, 9779, 'Medabots S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/266780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137309, 9779, 'Medabots S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/266781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137310, 9779, 'Medabots S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/266782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137311, 9779, 'Medabots S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/266783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137312, 9779, 'Medabots S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/266784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137313, 9779, 'Medabots S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/266785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137314, 9779, 'Medabots S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/266786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137315, 9779, 'Medabots S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/266787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137316, 9779, 'Medabots S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/266788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137317, 9779, 'Medabots S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/266789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137318, 9779, 'Medabots S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/266790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137319, 9779, 'Medabots S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/266791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137320, 9779, 'Medabots S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/266792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137321, 9779, 'Medabots S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/266793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137322, 9779, 'Medabots S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/266794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137323, 9779, 'Medabots S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/266795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137324, 9779, 'Medabots S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/266796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137325, 9779, 'Medabots S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/266797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137326, 9779, 'Medabots S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/266798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137327, 9779, 'Medabots S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/266799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137328, 9779, 'Medabots S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/266800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137329, 9779, 'Medabots S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/266801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137330, 9779, 'Medabots S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/266802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137331, 9779, 'Medabots S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/266803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137332, 9779, 'Medabots S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/266804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137333, 9779, 'Medabots S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/266805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137334, 9779, 'Medabots S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/266806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137335, 9779, 'Medabots S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/266807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137336, 9779, 'Medabots S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/266808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137337, 9779, 'Medabots S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/266809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137338, 9779, 'Medabots S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/266810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137339, 9779, 'Medabots S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/266811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137340, 9779, 'Medabots S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/266812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137341, 9779, 'Medabots S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/266813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137342, 9779, 'Medabots S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/266814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137343, 9779, 'Medabots S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/266815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137344, 9779, 'Medabots S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/266816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137345, 9779, 'Medabots S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/266817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137346, 9779, 'Medabots S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/266818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137347, 9779, 'Medabots S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/266819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137348, 9779, 'Medabots S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/266820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137349, 9779, 'Medabots S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/266821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137350, 9779, 'Medabots S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/266822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137351, 9779, 'Medabots S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/266823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rlSqPQng6LYkNuhEr69GLM74j97.jpg'),
(137352, 9780, 'A Lua Abraca o Sol S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tddKgA957FmlaHxZWduvJntKxhL.jpg'),
(137353, 9780, 'A Lua Abraca o Sol S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z4lfPT5IXmpSMtQaALQZSfsKU60.jpg'),
(137354, 9780, 'A Lua Abraca o Sol S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mu16NFCnjPeLd93RySFugsvSLho.jpg'),
(137355, 9780, 'A Lua Abraca o Sol S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2AjeA1PbXjZoIyU0HDLDEjLlF75.jpg'),
(137356, 9780, 'A Lua Abraca o Sol S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qbHm5f5fO1RRmPW3aKhVksoqtlD.jpg'),
(137357, 9780, 'A Lua Abraca o Sol S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lKOP56Wz5pvMPeZaVeCmI0R3oHQ.jpg'),
(137358, 9780, 'A Lua Abraca o Sol S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1HTiJ2dORnCUTjk6fg98zMcTZ68.jpg'),
(137359, 9780, 'A Lua Abraca o Sol S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dnebpgZMb8fyBpIBi9lHQKNvF8f.jpg'),
(137360, 9780, 'A Lua Abraca o Sol S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nFQXj3LTII76akk4jbHRWVgzWru.jpg'),
(137361, 9780, 'A Lua Abraca o Sol S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zIXvpsERGTs6dStE7w74kDujPI4.jpg'),
(137362, 9780, 'A Lua Abraca o Sol S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xFHuSJRzYl9M9htDbweIouGsWL7.jpg'),
(137363, 9780, 'A Lua Abraca o Sol S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n2R41XZYhBEzawuunIYJJxFObHJ.jpg'),
(137364, 9780, 'A Lua Abraca o Sol S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8KAhhu6ue6fOriNiZaZ7pnBRTfG.jpg'),
(137365, 9780, 'A Lua Abraca o Sol S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ns5MAH8tFrc8xDTqS7BCTmFCX33.jpg'),
(137366, 9780, 'A Lua Abraca o Sol S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/266727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/py29ekfvXy7e3LyUI06us1MsXff.jpg'),
(137367, 9780, 'A Lua Abraca o Sol S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/266728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1kSE1UeULouPM2uyZ8j0ksMNhcw.jpg'),
(137368, 9780, 'A Lua Abraca o Sol S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/266729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tXhPIZGy30H9w9yQOwL85umnBUD.jpg'),
(137369, 9780, 'A Lua Abraca o Sol S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/266730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dGUjhjUczHoUaakz0vfao4E4ABD.jpg'),
(137370, 9780, 'A Lua Abraca o Sol S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/266731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDDB7E5ykZDAzoFrEud73tUn8uL.jpg'),
(137371, 9780, 'A Lua Abraca o Sol S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/266732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7jcaX9V9x5AAwKIT6bRx9JgXnsv.jpg'),
(137372, 9781, 'Formula Dreams S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAn6UerbPG7PTbn8a3KlfoDnQJa.jpg'),
(137373, 9781, 'Formula Dreams S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAn6UerbPG7PTbn8a3KlfoDnQJa.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(137374, 9781, 'Formula Dreams S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAn6UerbPG7PTbn8a3KlfoDnQJa.jpg'),
(137375, 9781, 'Formula Dreams S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAn6UerbPG7PTbn8a3KlfoDnQJa.jpg'),
(137376, 9781, 'Formula Dreams S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAn6UerbPG7PTbn8a3KlfoDnQJa.jpg'),
(137377, 9781, 'Formula Dreams S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAn6UerbPG7PTbn8a3KlfoDnQJa.jpg'),
(137378, 9781, 'Formula Dreams S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAn6UerbPG7PTbn8a3KlfoDnQJa.jpg'),
(137379, 9781, 'Formula Dreams S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAn6UerbPG7PTbn8a3KlfoDnQJa.jpg'),
(137380, 9781, 'Formula Dreams S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAn6UerbPG7PTbn8a3KlfoDnQJa.jpg'),
(137381, 9781, 'Formula Dreams S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cAn6UerbPG7PTbn8a3KlfoDnQJa.jpg'),
(137382, 9782, 'NASCAR Velocidade Maxima S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJgsn63yfHhrXAZOccGpGsLkfFl.jpg'),
(137383, 9782, 'NASCAR Velocidade Maxima S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zOZrAvcagCCRM19rSv0iBWWzCfW.jpg'),
(137384, 9782, 'NASCAR Velocidade Maxima S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kaSFYVoiZg0UAG7bF6ACZatVUJN.jpg'),
(137385, 9782, 'NASCAR Velocidade Maxima S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oJN5EXTTXCcMhdqlNTqhN7d9JBi.jpg'),
(137386, 9782, 'NASCAR Velocidade Maxima S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8WA0rablDLhRxEwdRoR5zP4QN21.jpg'),
(137387, 9783, 'NASCAR Velocidade Maxima S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/789606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fXhZCpFlFXST8qZt2dYT4XTeF1E.jpg'),
(137388, 9783, 'NASCAR Velocidade Maxima S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/789607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fXhZCpFlFXST8qZt2dYT4XTeF1E.jpg'),
(137389, 9783, 'NASCAR Velocidade Maxima S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/789608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fXhZCpFlFXST8qZt2dYT4XTeF1E.jpg'),
(137390, 9783, 'NASCAR Velocidade Maxima S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/789609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fXhZCpFlFXST8qZt2dYT4XTeF1E.jpg'),
(137391, 9783, 'NASCAR Velocidade Maxima S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/789610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fXhZCpFlFXST8qZt2dYT4XTeF1E.jpg'),
(137392, 9784, 'A Bloody Lucky Day S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1kowNF6JoZHMr0tinQWy0sPHRAk.jpg'),
(137393, 9784, 'A Bloody Lucky Day S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f6uDLx6mRSlXRwzIBAqsUqYjeye.jpg'),
(137394, 9784, 'A Bloody Lucky Day S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zlUDgR9k3roFgfS7k75Q8QAzSTV.jpg'),
(137395, 9784, 'A Bloody Lucky Day S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/crj2t9puAs5C5Fjq26GjdynDL6l.jpg'),
(137396, 9784, 'A Bloody Lucky Day S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cCjSeVPjqVlDrkZeHwSGB8YOMAx.jpg'),
(137397, 9784, 'A Bloody Lucky Day S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8iZFxw4UKUiET2RMD4Sxo3vZLeC.jpg'),
(137398, 9784, 'A Bloody Lucky Day S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uGdyph9KKZqvl9hxoulpwkYjVlw.jpg'),
(137399, 9784, 'A Bloody Lucky Day S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1oXwLJvT2vJ7k3WeUyrJg8esm7W.jpg'),
(137400, 9784, 'A Bloody Lucky Day S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2O67RNT7bproLJkex4YcVEmabUa.jpg'),
(137401, 9784, 'A Bloody Lucky Day S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5D72GQFrQr4XShxhIhmYqOnpxSH.jpg'),
(137402, 9785, 'Friends [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fbtaoynlPpENx3Ss2laC7wgqLIP.jpg'),
(137403, 9785, 'Friends [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q00vWBNdLBIprqA3zQJ3TpfXNhu.jpg'),
(137404, 9785, 'Friends [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLZb1o6dTpUmTNdODdbqH8dJpjc.jpg'),
(137405, 9785, 'Friends [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ewcHihTEPLvPPW7o0SDc0ZTs66o.jpg'),
(137406, 9785, 'Friends [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1JLPosNtPdj83jOwwPCBRhuJu3m.jpg'),
(137407, 9785, 'Friends [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/raXlzz3GBvm3uEzcDtu0IAqm96S.jpg'),
(137408, 9785, 'Friends [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4s280bCobeuCw4d4djtFUpVKNHz.jpg'),
(137409, 9785, 'Friends [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mlctpU7B2e9XnKrp5LHFf8WrOZp.jpg'),
(137410, 9785, 'Friends [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wiS3bKGiH3jglke48Tb3Jkk8Rfe.jpg'),
(137411, 9785, 'Friends [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uk0yh6xFTwwQcHGlbhJ5X5gKT33.jpg'),
(137412, 9785, 'Friends [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pCStDEs8Ga900w8dz8Forg4PCjL.jpg'),
(137413, 9785, 'Friends [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y4NsVEIvJadmc5d3KAXvrom26qu.jpg'),
(137414, 9785, 'Friends [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xdHWHWNBctJbTRMKFDJe2se7Pdd.jpg'),
(137415, 9785, 'Friends [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k4ZTQpB51rH0cxH2k8w602ndLw.jpg'),
(137416, 9785, 'Friends [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/266215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9BaRbjqBUhs59cRQxVbK8Z7E6aV.jpg'),
(137417, 9785, 'Friends [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/266216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aNTEPjwbPBKfJO4ANNULCm2odSh.jpg'),
(137418, 9785, 'Friends [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/266217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sxm7L3rGvDLVqvsTYjtTxMnF6AK.jpg'),
(137419, 9785, 'Friends [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/266218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1DI0uapLj8BAFsOPCzrBSGWSree.jpg'),
(137420, 9785, 'Friends [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/266219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rIMnr0VbnW4vBfik4SkOB5piRUH.jpg'),
(137421, 9785, 'Friends [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/266220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vSKytvZZf7ix9Igk12XM8LNN2gY.jpg'),
(137422, 9785, 'Friends [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/266221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/P5VdD2h4oogjjvIyP7kgYB2YLB.jpg'),
(137423, 9785, 'Friends [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/266222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wdNKFtPbhWUFWvNxgWZT83H0rA5.jpg'),
(137424, 9785, 'Friends [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/266223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vw6110Vh0j0QtmGqB6BnmbOmMda.jpg'),
(137425, 9785, 'Friends [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/266224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9mKWvYLOAh3mgEB9aVBeVeHw9s.jpg'),
(137426, 9786, 'Friends [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/grt1km00cjrwAckfgO3QGiHYq89.jpg'),
(137427, 9786, 'Friends [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dyBB19jEpwj6gzGA1IcXxj9kq1e.jpg'),
(137428, 9786, 'Friends [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ny7ArJi6VmHyrHmyOmToGpjUbzD.jpg'),
(137429, 9786, 'Friends [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jtYyA2OO0Xj6GPq7DGCVCOKvspt.jpg'),
(137430, 9786, 'Friends [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8fCf2sdGC5nxfULSTE8VYFMXuJR.jpg'),
(137431, 9786, 'Friends [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4RxxAAbQgt8wgOXDWXcKVUVqXr5.jpg'),
(137432, 9786, 'Friends [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1oGAR9wigUiz00YiCdTFniTevMx.jpg'),
(137433, 9786, 'Friends [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ng1mU6n9Yb9JWwNH2bIlzIUdZhx.jpg'),
(137434, 9786, 'Friends [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/HiNO3Gyp69e59Pax6a0g2Vhr1S.jpg'),
(137435, 9786, 'Friends [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zDoRfPdUWKdhl3MSiMckp1wtzWC.jpg'),
(137436, 9786, 'Friends [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sHhsoHmPSG0hVopaKsnM9pu7zD6.jpg'),
(137437, 9786, 'Friends [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lPPHEnQDdTEFWzG0fLEFp7AAAU1.jpg'),
(137438, 9786, 'Friends [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aAOWF2fMQiDrdzb6IpAOiTmnJaC.jpg'),
(137439, 9786, 'Friends [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yaj00vryGCmBzpkrEDHgT6Pj5z5.jpg'),
(137440, 9786, 'Friends [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/266239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vEnD6mvkwRgapYZr8tZBSoEAHcn.jpg'),
(137441, 9786, 'Friends [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/266240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7OKGNoKDtFxQY3hNXOP6y3JRO53.jpg'),
(137442, 9786, 'Friends [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/266241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zjGdr3fu5LaoFGKMcXwvwEX3lNu.jpg'),
(137443, 9786, 'Friends [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/266242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2CdJM0V4iUOYTrGbn7XZ0sfdmaG.jpg'),
(137444, 9786, 'Friends [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/266243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nPaqxogdoDIb81HJ488dsVbkpCw.jpg'),
(137445, 9786, 'Friends [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/266244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfBhzSGoBFWnHr7HGo4OHUn48gI.jpg'),
(137446, 9786, 'Friends [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/266245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cNgv7rAm7YkvooOGOpFSTlfS5wS.jpg'),
(137447, 9786, 'Friends [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/266246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aKmPfjA0QssEqOuiSMyJGEoEJdt.jpg'),
(137448, 9786, 'Friends [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/266247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVSXGWFFGGKs3iWDX8RZmtNJlDA.jpg'),
(137449, 9786, 'Friends [L] S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/266248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3o85MotMLDmbCPIiIwCfPYzDYgY.jpg'),
(137450, 9787, 'Friends [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ci28CPpvg6EEDPlCbMLtNUDJPcR.jpg'),
(137451, 9787, 'Friends [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bBmgNbrW0ozjaiKDKKfijwKWdRc.jpg'),
(137452, 9787, 'Friends [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fNgjqLtlhQBjNRFdX10edanoke1.jpg'),
(137453, 9787, 'Friends [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jLnfUmRWirw55UJ9vUu9DBXhxKw.jpg'),
(137454, 9787, 'Friends [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xV4gS3ZbpbDDRy1iTAzD9pWone2.jpg'),
(137455, 9787, 'Friends [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vAVRp4FQO858ZurhMkjy2Ry8BbM.jpg'),
(137456, 9787, 'Friends [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCUk2Mytau5IX7oEndRnwtzThOT.jpg'),
(137457, 9787, 'Friends [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lu2f7cegzxOPSI3snkYj5CgdEGO.jpg'),
(137458, 9787, 'Friends [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mQpnuhi29rAZLp820hakowPpPaR.jpg'),
(137459, 9787, 'Friends [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dVgaNrwBiYu0O1mpqvOLuEvvIf3.jpg'),
(137460, 9787, 'Friends [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/14vp2eC2vuJvvmxry86j6gugpNF.jpg'),
(137461, 9787, 'Friends [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yz9hYNhS92EFfii4apZoPaH3TxZ.jpg'),
(137462, 9787, 'Friends [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qIbd5XEEa5gK2oXRbIeYT9PrK2W.jpg'),
(137463, 9787, 'Friends [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Towvxh6qAtJycuJ7XW8GJQhB3N.jpg'),
(137464, 9787, 'Friends [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/266263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQ7vb9GxKeHq8zhy3L15TWmcXlq.jpg'),
(137465, 9787, 'Friends [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/266264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5rM97ao2TZZMHUrfsnP1XCOh1Jx.jpg'),
(137466, 9787, 'Friends [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/266265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6xO5fIPn0xa9IAS30U3POy3ZG8c.jpg'),
(137467, 9787, 'Friends [L] S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/266266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l01b0UomTW9WNWmDr87aOFoQW1T.jpg'),
(137468, 9787, 'Friends [L] S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/266267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sxEjTxnAGl0kTaBJdH0WAF8DmpD.jpg'),
(137469, 9787, 'Friends [L] S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/266268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qKaDNoe48je6AQIjNIM110c8SeY.jpg'),
(137470, 9787, 'Friends [L] S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/266269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8yZycDRGAImK2Qpmm5PdG3gforx.jpg'),
(137471, 9787, 'Friends [L] S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/266270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vHqib05ysQ05YcFTdFSNdyKHDA.jpg'),
(137472, 9787, 'Friends [L] S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/266271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgQi42yjC73KixG77IDuasPSdXl.jpg'),
(137473, 9787, 'Friends [L] S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/266272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2ryBGyo6AAfcGnpGrSNt35lgVF.jpg'),
(137474, 9787, 'Friends [L] S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/266273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1YwKZ32SvyhjdA3cBtoyn5oNXFL.jpg'),
(137475, 9788, 'Friends [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/67tiGi36IUXlNAPlPJy98INk2DQ.jpg'),
(137476, 9788, 'Friends [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1zEnoQyjbystjf9nywj07dpMwza.jpg'),
(137477, 9788, 'Friends [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fqXZu4P3QTa27Ne2fzkZM5sdbpG.jpg'),
(137478, 9788, 'Friends [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/khxmKmjmsQVXxJW1P8VbCdeFMoA.jpg'),
(137479, 9788, 'Friends [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Hym8m1BzQct9GHljwzNgLPQoLy.jpg'),
(137480, 9788, 'Friends [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4yt3mMbJHwNxhFGMzXMWulzfE2T.jpg'),
(137481, 9788, 'Friends [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9MhRmA4n6ZBDum4dBTF9xDBiuwx.jpg'),
(137482, 9788, 'Friends [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hOz3zqyisPN5MkFi7KMFw2uYx4A.jpg'),
(137483, 9788, 'Friends [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A8zYaSOftPKM4q05IOQcqYdWrs7.jpg'),
(137484, 9788, 'Friends [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bNLBOFFQN5r3GpFUKvPmWYWz6DM.jpg'),
(137485, 9788, 'Friends [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nT2D93C06aLnO8VkxA6rnTSiuVm.jpg'),
(137486, 9788, 'Friends [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nRXtaq1enijfiDwxzAPhJKkFtsu.jpg'),
(137487, 9788, 'Friends [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vIMOQQjaxNqPdmw0ro3ilrRAC4d.jpg'),
(137488, 9788, 'Friends [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bNXV6xfkk1njmF3ftIHxJ3A1vkh.jpg'),
(137489, 9788, 'Friends [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/266288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sTWf0xRUTztjHXElg65TiXKW4nS.jpg'),
(137490, 9788, 'Friends [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/266289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sjFybiEckDorc9beXc8cHxNeAHg.jpg'),
(137491, 9788, 'Friends [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/266290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dlg9ZvKBF6JmxogJx1syGqvXB2D.jpg'),
(137492, 9788, 'Friends [L] S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/266291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lX0Ui3DMEyljM5oDWWfInQaGtRP.jpg'),
(137493, 9788, 'Friends [L] S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/266292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qcJAFWAHCsjcrl4cxB9SLM5vek4.jpg'),
(137494, 9788, 'Friends [L] S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/266293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5HoqXdCE3NItOrlgKzE5HsUHuSE.jpg'),
(137495, 9788, 'Friends [L] S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/266294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xOlyFkFyMhhoeHbVxgKGRneplS9.jpg'),
(137496, 9788, 'Friends [L] S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/266295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBaqspVkyo2C7XlEAnGEylM7pG.jpg'),
(137497, 9788, 'Friends [L] S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/266296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fvRlowH2KAAHaveAHXA6ZvyHPvD.jpg'),
(137498, 9788, 'Friends [L] S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/266297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2koX1xLkpTQM4IZebYvKysFW1Nh.jpg'),
(137499, 9789, 'Friends [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1jn9nGNo7avmHNqfk1qeVI9U7i6.jpg'),
(137500, 9789, 'Friends [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5LswaLN9QpjjBNFbtPrLQoHXSi0.jpg'),
(137501, 9789, 'Friends [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f6ZuOAGSqls2mr012J0IK1D7m4u.jpg'),
(137502, 9789, 'Friends [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8D2MBiGgf1mBPKZ31N3L9sVGNve.jpg'),
(137503, 9789, 'Friends [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5QOC8UgmezlCsk5vu7DGjtNG1Qd.jpg'),
(137504, 9789, 'Friends [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t8frUbTNAaU585dwir1wRcylauR.jpg'),
(137505, 9789, 'Friends [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9hBS598Oi90z7A0CRISPbwJ9JPH.jpg'),
(137506, 9789, 'Friends [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/49W5shiaO1VYhHErOt2tJXCqfz0.jpg'),
(137507, 9789, 'Friends [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zcsl24ON4OM0O5Nsy6ZAdF9469c.jpg'),
(137508, 9789, 'Friends [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pUeg9m9Nplam46nlchyfGeE9ZWC.jpg'),
(137509, 9789, 'Friends [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/842QH0JXJixa6GKeL5AyVbbIhrI.jpg'),
(137510, 9789, 'Friends [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6NlO0o3YwcrC22ODfSJJlMq37r5.jpg'),
(137511, 9789, 'Friends [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wKV9NJAG9Dey4dMELVFwQWJGlCv.jpg'),
(137512, 9789, 'Friends [L] S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/widPOemNRxvcAnV5QthXouKyTK.jpg'),
(137513, 9789, 'Friends [L] S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/266312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zrc6ZSrttUlXghs2DNgsFOgGGNo.jpg'),
(137514, 9789, 'Friends [L] S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/266313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qDSmE7EeiiWQkVPMTOi7XqtkLsk.jpg'),
(137515, 9789, 'Friends [L] S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/266314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sPCW94qruOX0aRPuj5Uy8vlJKSJ.jpg'),
(137516, 9789, 'Friends [L] S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/266315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zXPDYJa1yWBGLRTDOexq6VJMedL.jpg'),
(137517, 9789, 'Friends [L] S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/266316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nURp3j9Fax9yt2qvhRttzPygkJN.jpg'),
(137518, 9789, 'Friends [L] S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/266317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5xBJqfHQI3qUOC9XB5ePZzbYD4L.jpg'),
(137519, 9789, 'Friends [L] S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/266318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rgMzbHY39qF0uwPfH14jZNJDypw.jpg'),
(137520, 9789, 'Friends [L] S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/266319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kAV4BBUpsnlPATryvLZyh9aiH1U.jpg'),
(137521, 9789, 'Friends [L] S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/266320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jB39sjCHdWGoyHOkFdbM9AN1fLK.jpg'),
(137522, 9789, 'Friends [L] S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/266321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2koX1xLkpTQM4IZebYvKysFW1Nh.jpg'),
(137523, 9790, 'Friends [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2T3D3y98XDM2owdjxcj8PEiQFP8.jpg'),
(137524, 9790, 'Friends [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d5c8xKhUKsR4afHWc17POaCs444.jpg'),
(137525, 9790, 'Friends [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/brF8eLr2ml3UaNMmBVZQ615iyBy.jpg'),
(137526, 9790, 'Friends [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ohFKAbC5iZtGfzLh9JfylXfhwKr.jpg'),
(137527, 9790, 'Friends [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/itDy7O5nij71D7Z1MZXJjlLB9w0.jpg'),
(137528, 9790, 'Friends [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8nNQPYtxDjMmtlJie8LLtzYu5gU.jpg'),
(137529, 9790, 'Friends [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGA8jD6BqXSAVoEGy5bmbZOHqQY.jpg'),
(137530, 9790, 'Friends [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/937TB5b6bv9OJb4OPfXvVTtweOf.jpg'),
(137531, 9790, 'Friends [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cu4c4rxWLPox2VAV2kWvT4MpYvO.jpg'),
(137532, 9790, 'Friends [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hGOc4JFywXjpQclb0ZFNN1OgOVj.jpg'),
(137533, 9790, 'Friends [L] S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5W0BPGJbP5sjJWgjLlnQGkXWKYF.jpg'),
(137534, 9790, 'Friends [L] S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zaDAyW9hOFhFjhcYBwvNqIpDCe.jpg'),
(137535, 9790, 'Friends [L] S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lIekB9Iqefj7g2RTUgeOrawGhDV.jpg'),
(137536, 9790, 'Friends [L] S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v9jXwRkamJyt5ZwoC9eD3c2XHKJ.jpg'),
(137537, 9790, 'Friends [L] S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/266336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fhUs4A5qAOZZRkHsiBNvhUbzAbd.jpg'),
(137538, 9790, 'Friends [L] S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/266337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kAf0eTcqL8ehrfWYyKbNSzwiHuv.jpg'),
(137539, 9790, 'Friends [L] S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/266338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/12OVdVusbxyZKN5YFEhuMLkuFQP.jpg'),
(137540, 9790, 'Friends [L] S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/266339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AsK0ljsXaUVPJyMMyEZLIFjhHzR.jpg'),
(137541, 9790, 'Friends [L] S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/266340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l8EycgFaGhknaUnWxkMza4Okj24.jpg'),
(137542, 9790, 'Friends [L] S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/266341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5t8pBcCf87asXhsO1UYvECTKU1b.jpg'),
(137543, 9790, 'Friends [L] S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/266342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jyzT86Ob4sqWevYel1ZdroL2hSV.jpg'),
(137544, 9790, 'Friends [L] S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/266343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/grpysBMIoetM5LqWxWVZwjQsoT3.jpg'),
(137545, 9790, 'Friends [L] S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/266344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3OWXfD3koZkh2EbTLk95rSGJcG.jpg'),
(137546, 9790, 'Friends [L] S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/266345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2koX1xLkpTQM4IZebYvKysFW1Nh.jpg'),
(137547, 9790, 'Friends [L] S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/266346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2koX1xLkpTQM4IZebYvKysFW1Nh.jpg'),
(137548, 9791, 'Friends [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/imDBzYIzNH5iSOarKkq84I5L167.jpg'),
(137549, 9791, 'Friends [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yV05qgkIsfjEN33gDsuNMgqPjAT.jpg'),
(137550, 9791, 'Friends [L] S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s2jCzF7wnHJMs0gLrJzgPEbd1Zd.jpg'),
(137551, 9791, 'Friends [L] S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o8pwwXI3buttxvgjBvn1ShmFb89.jpg'),
(137552, 9791, 'Friends [L] S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9SKIbk7GXFVk7o95eLrNXsTboNl.jpg'),
(137553, 9791, 'Friends [L] S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d2DIHHrmqqyaEEzwVF6kXGEFUuQ.jpg'),
(137554, 9791, 'Friends [L] S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/st1Om9JiUPGUNuF2gnYfAspMDNY.jpg'),
(137555, 9791, 'Friends [L] S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWoxm88Cqir55r6QMQX5ZT4eLQ1.jpg'),
(137556, 9791, 'Friends [L] S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9kX1MNGKOCJl5mn6E02upYEvowd.jpg'),
(137557, 9791, 'Friends [L] S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rfwc29L9N22vhU1mh7I8QBrXLjX.jpg'),
(137558, 9791, 'Friends [L] S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1WSZPGVEY78CsWiFBr6LfERuZwT.jpg'),
(137559, 9791, 'Friends [L] S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q1lnv5Nar6WIxbrQo5cV7P8YAeU.jpg'),
(137560, 9791, 'Friends [L] S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oeur7OVIlBZpNXKl4cgsPFQnVJ7.jpg'),
(137561, 9791, 'Friends [L] S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eghy8EUnsmH6w6vEMAV2Ug18GXn.jpg'),
(137562, 9791, 'Friends [L] S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/266361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jCJg30mOZFUUjAdig3aeSbXL7VW.jpg'),
(137563, 9791, 'Friends [L] S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/266362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tfsPxEQ5cmpg4pEDAWssR3TW489.jpg'),
(137564, 9791, 'Friends [L] S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/266363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6EdqJXkjEaoN09otW5e0Q3fchIl.jpg'),
(137565, 9791, 'Friends [L] S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/266364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7j4ammK2F5K9pmyLh946m1eIhOF.jpg'),
(137566, 9791, 'Friends [L] S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/266365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ikhwogIjntfhWquuOfxdJwg8GHL.jpg'),
(137567, 9791, 'Friends [L] S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/266366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xh9Wk6wyQDza7mKVc39wGcjGDRb.jpg'),
(137568, 9791, 'Friends [L] S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/266367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kgLt31d0oEed39CIkw3lsO4EZ9c.jpg'),
(137569, 9791, 'Friends [L] S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/266368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ApTQ7uUhUkLI3si7r2iLp3xXt4.jpg'),
(137570, 9791, 'Friends [L] S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/266369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/omXc88sdzQHamGPW0GR5zL5McPB.jpg'),
(137571, 9791, 'Friends [L] S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/266370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2koX1xLkpTQM4IZebYvKysFW1Nh.jpg'),
(137572, 9792, 'Friends [L] S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zTVPfthOgP1yz9PcOxHRwPMEAUS.jpg'),
(137573, 9792, 'Friends [L] S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ac5DNKZFRjlemuae22SKqI8geEB.jpg'),
(137574, 9792, 'Friends [L] S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZeIsy5034XouvErUT9fAI8UIjy.jpg'),
(137575, 9792, 'Friends [L] S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1znECVU4xrWkzs2Khs0YHvTNSTo.jpg'),
(137576, 9792, 'Friends [L] S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hn9Wxur1Y4s8esWI8w8VrNbSbz8.jpg'),
(137577, 9792, 'Friends [L] S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/etHUWVLhXpPHCbzH4uNNetEQkUq.jpg'),
(137578, 9792, 'Friends [L] S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/busMxkMHJCt5hyd4LRMH9Teg5KZ.jpg'),
(137579, 9792, 'Friends [L] S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ol7aXhn4TCZmwbud9g72uR8WGFc.jpg'),
(137580, 9792, 'Friends [L] S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nhQ7irmtvCdMqGbfmN21Vf0FI4H.jpg'),
(137581, 9792, 'Friends [L] S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qRRYtxCn7nrS2Y6rHwg2vpnSt68.jpg'),
(137582, 9792, 'Friends [L] S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s7JMRcbWK211dg4GUABjZWOjykB.jpg'),
(137583, 9792, 'Friends [L] S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kagedGmNAj0de2q2ej1CQVyAlsk.jpg'),
(137584, 9792, 'Friends [L] S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bcmxlN6YdOIScblA4c3qmq2gsx8.jpg'),
(137585, 9792, 'Friends [L] S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pIZ4ZbdqiUW0X7iGDbC1eTBwSms.jpg'),
(137586, 9792, 'Friends [L] S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/266385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dRwuancw8f7wJr5t3bkct4X5E5P.jpg'),
(137587, 9792, 'Friends [L] S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/266386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4t7nMNohxhwKBUuDI1v93Y9ekWF.jpg'),
(137588, 9792, 'Friends [L] S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/266387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZB8MEwEBktPcL2nr8dqyl1bi0x.jpg'),
(137589, 9792, 'Friends [L] S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/266388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6KO8iJzaNQBbQxYzoJtV1W06T4S.jpg'),
(137590, 9792, 'Friends [L] S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/266389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yIw1XSopqnujd78Tgm24I2Pzq61.jpg'),
(137591, 9792, 'Friends [L] S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/266390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qQIq9ALRWu2WB2WDMVz7lWNTnQd.jpg'),
(137592, 9792, 'Friends [L] S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/266391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/paUWeSKy1BRnh7a1D4hUi8SQnJh.jpg'),
(137593, 9792, 'Friends [L] S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/266392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtyhJQESigpYObHoJDdfTIjnt8g.jpg'),
(137594, 9792, 'Friends [L] S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/266393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rk7CtLH2RXUK5LBdr6Mg1YZxn3j.jpg'),
(137595, 9792, 'Friends [L] S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/266394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2koX1xLkpTQM4IZebYvKysFW1Nh.jpg'),
(137596, 9793, 'Friends [L] S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dNqS2szoMmfgfFttsVZTggXjttz.jpg'),
(137597, 9793, 'Friends [L] S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1WMGVmrp5ZOiLjMTCcx8J7Ws18g.jpg'),
(137598, 9793, 'Friends [L] S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svtWGUDz560o96lHLSIo0PN8zxS.jpg'),
(137599, 9793, 'Friends [L] S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nlogeZvRNX0kkN80hhoPAMjMoZT.jpg'),
(137600, 9793, 'Friends [L] S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iAN1Ws0X6seDBw9sSq5IeTThXSh.jpg'),
(137601, 9793, 'Friends [L] S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/95NzE8ACrk96PtNCM88k1o98wuj.jpg'),
(137602, 9793, 'Friends [L] S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pBnUEJawXmeYZyY32jxvcepvfFY.jpg'),
(137603, 9793, 'Friends [L] S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kYfo4vNSEDjDu9jhGAPDvJBVNde.jpg'),
(137604, 9793, 'Friends [L] S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9fLrbwWlk71ijfQNQd7ZGIkokgM.jpg'),
(137605, 9793, 'Friends [L] S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dg0JY99c3DOKkt9VuBUQ1rYwctA.jpg'),
(137606, 9793, 'Friends [L] S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zpY4Re3IqvYrPG75AlTrRQAvYNW.jpg'),
(137607, 9793, 'Friends [L] S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lTlqu2AsioTFRDiok3oVV0OFTGl.jpg'),
(137608, 9793, 'Friends [L] S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/upFUL4W5piQPWrHRwykCHNnlQe3.jpg'),
(137609, 9793, 'Friends [L] S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/FRftNRoz7VDKiWMBNfv0uxbMXh.jpg'),
(137610, 9793, 'Friends [L] S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/266409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nBEazpZAqKuTMliM1ydfTq2QGWc.jpg'),
(137611, 9793, 'Friends [L] S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/266410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4xNYEIa6uVBNSeplys4pAjT195U.jpg'),
(137612, 9793, 'Friends [L] S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/266411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z0Lu8f06CXqIB1KHqFNdU41zcco.jpg'),
(137613, 9793, 'Friends [L] S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/266412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/toJZ7LoCvdJRjLFLKmtDav3gBhi.jpg'),
(137614, 9793, 'Friends [L] S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/266413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/862ijAk0BbamUuYNbPAR1vr60ov.jpg'),
(137615, 9793, 'Friends [L] S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/266414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4wH9b3svJ1m2kZGc7rNCqfkvvCJ.jpg'),
(137616, 9793, 'Friends [L] S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/266415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o7VpwLq0wtQLHEl0a05BNq4TWEb.jpg'),
(137617, 9793, 'Friends [L] S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/266416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Wne3Hui6xRR9pmbYr4cjxpvWIU.jpg'),
(137618, 9793, 'Friends [L] S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/266417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bNPVvR7WmxgxRddVxOA3xdxVOKj.jpg'),
(137619, 9794, 'Friends [L] S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eo4ySedQXdpKoB2cRshDA9UEbLO.jpg'),
(137620, 9794, 'Friends [L] S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2K1zPklVTR9Z2l47iJFuvRzGjOx.jpg'),
(137621, 9794, 'Friends [L] S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u2NYOpUX2ZE1KFkBr2h5mrYiN1P.jpg'),
(137622, 9794, 'Friends [L] S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fY5jQGe5Z6yyV66ElDGwDcNZGMQ.jpg'),
(137623, 9794, 'Friends [L] S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCmLkDHifFFkoFnZ9j7h4Vrxnaf.jpg'),
(137624, 9794, 'Friends [L] S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kEsHJvPzYy5ajdY3Rkct2Z5QrZ6.jpg'),
(137625, 9794, 'Friends [L] S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mCnDBgrjzDPIBPMSlo1TdMk28C6.jpg'),
(137626, 9794, 'Friends [L] S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wy23se5VuWF574aHoljxvwoSudK.jpg'),
(137627, 9794, 'Friends [L] S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4s7D54BlT3bx1nNoTUEYxofeIMW.jpg'),
(137628, 9794, 'Friends [L] S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Md5d3VpR4MbP0MjbelfmDeB81A.jpg'),
(137629, 9794, 'Friends [L] S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8lMKnJt9mdMAOO063pTPp8pDB4A.jpg'),
(137630, 9794, 'Friends [L] S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uOQGYXWmvgBVslgEbmy67Zu4eOq.jpg'),
(137631, 9794, 'Friends [L] S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xvULxfWrSrPgpaeNF6MqbHRo7jp.jpg'),
(137632, 9794, 'Friends [L] S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tUs9QYIyKLxAqIwLvDDOrTgvkW8.jpg'),
(137633, 9794, 'Friends [L] S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/266432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jsTrgh20e7J7zq8QLbCE7jNVPmH.jpg'),
(137634, 9794, 'Friends [L] S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/266433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hUrlzwAmzoLj7TvZIWs9OJO7up1.jpg'),
(137635, 9794, 'Friends [L] S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/266434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7XmwmXkJtObpt6ABPENanrJHlg9.jpg'),
(137636, 9795, 'Segredos do Fundo do Mar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bcH2WGZIySc9YDxL5rlaSgOadrv.jpg'),
(137637, 9795, 'Segredos do Fundo do Mar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kOGn1JMR2Yklm29DRcgvKLPycIF.jpg'),
(137638, 9795, 'Segredos do Fundo do Mar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fSllzVlAB0OfP9irnE9MaiPqOzm.jpg'),
(137639, 9795, 'Segredos do Fundo do Mar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dCugBmLBpz4uKdYIzDTXBNhXeVi.jpg'),
(137640, 9795, 'Segredos do Fundo do Mar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/crWIf3WjzGpd6pZTPNGacjVqO39.jpg'),
(137641, 9795, 'Segredos do Fundo do Mar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qMOaYVS9Mdby9nLnMFVqGkaRMFT.jpg'),
(137642, 9795, 'Segredos do Fundo do Mar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ywGNZOH4rTO8Rixq8fusEGkV5rW.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(137643, 9795, 'Segredos do Fundo do Mar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/irKwixF2q86q2FI6Hrxc9sVmE4o.jpg'),
(137644, 9795, 'Segredos do Fundo do Mar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7uWD6nikDSS78Hko00rtd0qMPLu.jpg'),
(137645, 9795, 'Segredos do Fundo do Mar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3WgYJnuBgxMawL0a7TtWJMJ56CV.jpg'),
(137646, 9796, 'Segredos do Fundo do Mar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYlZXbcYH2Cq91oTWVnvm9b2TQw.jpg'),
(137647, 9796, 'Segredos do Fundo do Mar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYlZXbcYH2Cq91oTWVnvm9b2TQw.jpg'),
(137648, 9796, 'Segredos do Fundo do Mar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYlZXbcYH2Cq91oTWVnvm9b2TQw.jpg'),
(137649, 9796, 'Segredos do Fundo do Mar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYlZXbcYH2Cq91oTWVnvm9b2TQw.jpg'),
(137650, 9796, 'Segredos do Fundo do Mar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYlZXbcYH2Cq91oTWVnvm9b2TQw.jpg'),
(137651, 9796, 'Segredos do Fundo do Mar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYlZXbcYH2Cq91oTWVnvm9b2TQw.jpg'),
(137652, 9796, 'Segredos do Fundo do Mar S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYlZXbcYH2Cq91oTWVnvm9b2TQw.jpg'),
(137653, 9796, 'Segredos do Fundo do Mar S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYlZXbcYH2Cq91oTWVnvm9b2TQw.jpg'),
(137654, 9796, 'Segredos do Fundo do Mar S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYlZXbcYH2Cq91oTWVnvm9b2TQw.jpg'),
(137655, 9796, 'Segredos do Fundo do Mar S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYlZXbcYH2Cq91oTWVnvm9b2TQw.jpg'),
(137656, 9796, 'Segredos do Fundo do Mar S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYlZXbcYH2Cq91oTWVnvm9b2TQw.jpg'),
(137657, 9796, 'Segredos do Fundo do Mar S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYlZXbcYH2Cq91oTWVnvm9b2TQw.jpg'),
(137658, 9796, 'Segredos do Fundo do Mar S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYlZXbcYH2Cq91oTWVnvm9b2TQw.jpg'),
(137659, 9796, 'Segredos do Fundo do Mar S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYlZXbcYH2Cq91oTWVnvm9b2TQw.jpg'),
(137660, 9796, 'Segredos do Fundo do Mar S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/266176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYlZXbcYH2Cq91oTWVnvm9b2TQw.jpg'),
(137661, 9797, 'Segredos do Fundo do Mar S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xCrzfBFMR7WJkssEwVoK7HRekTc.jpg'),
(137662, 9797, 'Segredos do Fundo do Mar S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dVmPouCjyZ7iyKftAr7lwSPXVmm.jpg'),
(137663, 9797, 'Segredos do Fundo do Mar S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/giMzN4hNgjgfqdsRX06VXPBjV4T.jpg'),
(137664, 9797, 'Segredos do Fundo do Mar S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6XCjhFUy5tG19K1IwNujtB3YmE6.jpg'),
(137665, 9797, 'Segredos do Fundo do Mar S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7t1xHBwYZbx7mWU9blW16zcIASW.jpg'),
(137666, 9797, 'Segredos do Fundo do Mar S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t0Ulr3PbLIJvmVUM1i8vrVMpryW.jpg'),
(137667, 9797, 'Segredos do Fundo do Mar S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qzZFNIG9GFgY2trivqEle2nKRxB.jpg'),
(137668, 9797, 'Segredos do Fundo do Mar S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LtTyhOClw94F9MEiw483hAJAR8.jpg'),
(137669, 9797, 'Segredos do Fundo do Mar S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwZBM6KwI5fqEfluGSb2tnnZUH4.jpg'),
(137670, 9797, 'Segredos do Fundo do Mar S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHW1NsJ4lK7s09eRT1B6v6pKiSa.jpg'),
(137671, 9798, 'Segredos do Fundo do Mar S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ddGm1uNDAaq1UlDJ4CrI4QPknD2.jpg'),
(137672, 9798, 'Segredos do Fundo do Mar S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTYOsCfJXUYkEfe3OKwQrNaUqo1.jpg'),
(137673, 9798, 'Segredos do Fundo do Mar S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h0W2WjldLIe7BsmvoF6cywdY8Ii.jpg'),
(137674, 9798, 'Segredos do Fundo do Mar S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/evz4jSPVGZTewXoahwWWaPpPhLu.jpg'),
(137675, 9798, 'Segredos do Fundo do Mar S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r6HmxKGnKNAZ5VxjNHx2Y9XSlav.jpg'),
(137676, 9798, 'Segredos do Fundo do Mar S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mHmbHFYLCGXDJtv0yqtSBJMkhcS.jpg'),
(137677, 9798, 'Segredos do Fundo do Mar S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qRylZXsZ8X2WZPZ4lldQGN7mRZ.jpg'),
(137678, 9798, 'Segredos do Fundo do Mar S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6CfBKQE3amsoKr5oWsM9GYOPRkE.jpg'),
(137679, 9799, 'Segredos do Fundo do Mar S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYlZXbcYH2Cq91oTWVnvm9b2TQw.jpg'),
(137680, 9799, 'Segredos do Fundo do Mar S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYlZXbcYH2Cq91oTWVnvm9b2TQw.jpg'),
(137681, 9799, 'Segredos do Fundo do Mar S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYlZXbcYH2Cq91oTWVnvm9b2TQw.jpg'),
(137682, 9799, 'Segredos do Fundo do Mar S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYlZXbcYH2Cq91oTWVnvm9b2TQw.jpg'),
(137683, 9799, 'Segredos do Fundo do Mar S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYlZXbcYH2Cq91oTWVnvm9b2TQw.jpg'),
(137684, 9799, 'Segredos do Fundo do Mar S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYlZXbcYH2Cq91oTWVnvm9b2TQw.jpg'),
(137685, 9800, 'The Shield Acima da Lei S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMraKQLiSo9zgB0TQOOkDhG6mrX.jpg'),
(137686, 9800, 'The Shield Acima da Lei S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4AeY6X9ECZsDEWHpBmMxif5x8Uk.jpg'),
(137687, 9800, 'The Shield Acima da Lei S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/czJlYyvOodSvr4hINiKSwjDAc8X.jpg'),
(137688, 9800, 'The Shield Acima da Lei S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwgWlcKoRXPS2gXbefb8F53Q0QH.jpg'),
(137689, 9800, 'The Shield Acima da Lei S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mYremiHxIGllclaPofqLFNy1EUl.jpg'),
(137690, 9800, 'The Shield Acima da Lei S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mjHVqng8exYG20vNs7umFDiitI.jpg'),
(137691, 9800, 'The Shield Acima da Lei S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oEy1F2SJjisAXY5sj1qk3LIS9OF.jpg'),
(137692, 9800, 'The Shield Acima da Lei S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nehROVznlNwOmClnkyQBFCjls3N.jpg'),
(137693, 9800, 'The Shield Acima da Lei S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hu6GghlDbv7oEzOmQvuADvACTmB.jpg'),
(137694, 9800, 'The Shield Acima da Lei S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zXpfxmE1qBbn93SSiYe6XutghA0.jpg'),
(137695, 9800, 'The Shield Acima da Lei S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7WrD3C9l8bKJWlduwzjABDMKErM.jpg'),
(137696, 9800, 'The Shield Acima da Lei S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kNe0DURzs4q3tlBlB44RnTDV3zB.jpg'),
(137697, 9800, 'The Shield Acima da Lei S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mEo76Y18kMY9Dx9d6P8PkjyGKN9.jpg'),
(137698, 9801, 'The Shield Acima da Lei S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqYqwpRWBJNAcE0r96SxXvyeu67.jpg'),
(137699, 9801, 'The Shield Acima da Lei S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rQygbAE693QGlTZ8JbeRhLZwAIC.jpg'),
(137700, 9801, 'The Shield Acima da Lei S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3pgVoNEZ6VmeekXa864uv8NHymK.jpg'),
(137701, 9801, 'The Shield Acima da Lei S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9xE2fbLW3jpYfngsXkCbGnSwMLE.jpg'),
(137702, 9801, 'The Shield Acima da Lei S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5MDgSUpED0EFmh1v2taBLOpidWz.jpg'),
(137703, 9801, 'The Shield Acima da Lei S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8UrtILhJNYSFHQLnMKOYiCurppm.jpg'),
(137704, 9801, 'The Shield Acima da Lei S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ppqZsMfQZzqRcuAoQc0oYH1whay.jpg'),
(137705, 9801, 'The Shield Acima da Lei S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/79tUzp59rQwaFBXwcvKdJ9cdygq.jpg'),
(137706, 9801, 'The Shield Acima da Lei S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2bFQ6Z5AtlLfLKkdTYWn8GXaS05.jpg'),
(137707, 9801, 'The Shield Acima da Lei S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wO5BJHeNARrcZ76a4Agiaevuvbt.jpg'),
(137708, 9801, 'The Shield Acima da Lei S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s0XzFc146fi9ReET7q9cjbWEDAF.jpg'),
(137709, 9801, 'The Shield Acima da Lei S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tauA6OzxC8ZdLgcvB8JMML4ZzJ8.jpg'),
(137710, 9801, 'The Shield Acima da Lei S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5fKWuEb6ALeD4G8GFhuMb27JbTr.jpg'),
(137711, 9802, 'The Shield Acima da Lei S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUWI3XnriAI5uHmctdtV86LLMW1.jpg'),
(137712, 9802, 'The Shield Acima da Lei S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eOUsqOB3zmhTf792gPFQ8AYwK9l.jpg'),
(137713, 9802, 'The Shield Acima da Lei S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kOWex4v4qseUFZHmxgoTk6jikMO.jpg'),
(137714, 9802, 'The Shield Acima da Lei S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yJrb3O2MHsBPS3bkkjSvgtBUgyb.jpg'),
(137715, 9802, 'The Shield Acima da Lei S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3qtpAPc8KiNCPDmtvNjFiwwiVil.jpg'),
(137716, 9802, 'The Shield Acima da Lei S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5U1YRQErN6n7V4UssBf9Ipx9sMx.jpg'),
(137717, 9802, 'The Shield Acima da Lei S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9jf5N44ggoLD6u32cvrV7pt8Kj2.jpg'),
(137718, 9802, 'The Shield Acima da Lei S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3iante5FrjnlpDBXgpTsIeecw9K.jpg'),
(137719, 9802, 'The Shield Acima da Lei S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/44S1zjBvJb3JLFrTl9GgoC0YwMV.jpg'),
(137720, 9802, 'The Shield Acima da Lei S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e3V7hMzA9n8z4swguU3MicLfjVA.jpg'),
(137721, 9802, 'The Shield Acima da Lei S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tEGsEBMgk4SKeOxAsl5koNhi7zK.jpg'),
(137722, 9802, 'The Shield Acima da Lei S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6YkWNNNUSDpBFrh58EGVZjY30hq.jpg'),
(137723, 9802, 'The Shield Acima da Lei S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/400pOezYTgrQY9EEcDPtZIrlZ5g.jpg'),
(137724, 9802, 'The Shield Acima da Lei S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/266103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/prEwIETKHcH2SovZICgiDB6YMTe.jpg'),
(137725, 9802, 'The Shield Acima da Lei S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/266104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bywp9Ph7DUKMkZN6C49VmHJ0TEP.jpg'),
(137726, 9803, 'The Shield Acima da Lei S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZKMzwzMWpUB1JJ9qpqVtKfLNld.jpg'),
(137727, 9803, 'The Shield Acima da Lei S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vkZmNM3QiWJQCMbHRmUCLf7cZ2Z.jpg'),
(137728, 9803, 'The Shield Acima da Lei S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ipvqew1ULLhGBnzVlEU72C8xsyt.jpg'),
(137729, 9803, 'The Shield Acima da Lei S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3EXzqz8a4kpmPa7xHcCSs2WucDZ.jpg'),
(137730, 9803, 'The Shield Acima da Lei S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/885mOZqlyHA7eacjMCzc6DTToav.jpg'),
(137731, 9803, 'The Shield Acima da Lei S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9GVQUidPoteh8zThdiYaVtkydSm.jpg'),
(137732, 9803, 'The Shield Acima da Lei S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sktcEMq9P2Kjkx7jNL6q7vhGYQT.jpg'),
(137733, 9803, 'The Shield Acima da Lei S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oMGAqWD2L6iEHVnqPo4D0YX0VEO.jpg'),
(137734, 9803, 'The Shield Acima da Lei S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zAVJPBUDg5cAbc7nclnc4dJIALu.jpg'),
(137735, 9803, 'The Shield Acima da Lei S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/74q9rOG0r0NfSzmFwyH7BWojdZ3.jpg'),
(137736, 9803, 'The Shield Acima da Lei S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/X4QLWLcEL8lfv1757iHEWdC9w.jpg'),
(137737, 9803, 'The Shield Acima da Lei S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQb6ubNTVMARl1GQTK9ot34X6fq.jpg'),
(137738, 9803, 'The Shield Acima da Lei S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sgvZ6JhGNASAS5JuK00op6SNCFw.jpg'),
(137739, 9804, 'The Shield Acima da Lei S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k6FpSCjPp1RMCTW8xcNGS6xdsNT.jpg'),
(137740, 9804, 'The Shield Acima da Lei S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3zYKdq84wAj5i8GIHjBSceRe8KN.jpg'),
(137741, 9804, 'The Shield Acima da Lei S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l0fLOBhdgcZ0cHV8pDg8AoXYKi.jpg'),
(137742, 9804, 'The Shield Acima da Lei S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l0PxBwFusLaeOw6zfcJw5pN10bV.jpg'),
(137743, 9804, 'The Shield Acima da Lei S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udmDp7rwsvm0GvNp4RqAabf44QJ.jpg'),
(137744, 9804, 'The Shield Acima da Lei S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jpdqidRRtzNNAY8pS479u1Wg9xP.jpg'),
(137745, 9804, 'The Shield Acima da Lei S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sSuTgUvWemhEtKfQxzqSJYarN9x.jpg'),
(137746, 9804, 'The Shield Acima da Lei S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/roHI0pTUoBxYd7ciOVngO2OIKcp.jpg'),
(137747, 9804, 'The Shield Acima da Lei S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wXfc1rDdARN3E8oZ51pQLk3au23.jpg'),
(137748, 9804, 'The Shield Acima da Lei S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8zAtxgmbcJQrfppB4omphW9VqTK.jpg'),
(137749, 9804, 'The Shield Acima da Lei S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vtgvqJIE0PackSQeYLecdzkRqDZ.jpg'),
(137750, 9805, 'The Shield Acima da Lei S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uuz4FCbFtAiY5VCsulIXHck3WAM.jpg'),
(137751, 9805, 'The Shield Acima da Lei S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfzM7EMcdvoLNAx84rc1HVMdtL9.jpg'),
(137752, 9805, 'The Shield Acima da Lei S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3bUqbflG4CL7Fa81St699px81oh.jpg'),
(137753, 9805, 'The Shield Acima da Lei S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gi20Sflc6UiWefjqgOmskfbQ4sy.jpg'),
(137754, 9805, 'The Shield Acima da Lei S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJhgmRKIJAzImrkTdIkSVkAf4Ja.jpg'),
(137755, 9805, 'The Shield Acima da Lei S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ve6nsj1ddR0LMTf8hGeJ39wnhq.jpg'),
(137756, 9805, 'The Shield Acima da Lei S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xFJhDzubNfgZdTAfZNRCq9c79jo.jpg'),
(137757, 9805, 'The Shield Acima da Lei S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eThDK3PXIbdEhwF5MHaCf7UBacP.jpg'),
(137758, 9805, 'The Shield Acima da Lei S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ZToNlm9qHbbQmUFaq2gdHKTmm9.jpg'),
(137759, 9805, 'The Shield Acima da Lei S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o07xwmmQNQ2Vu7X4XKBxZT7wZP5.jpg'),
(137760, 9806, 'The Shield Acima da Lei S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uaseuvPVN7RTljyRoDcfh13h2WX.jpg'),
(137761, 9806, 'The Shield Acima da Lei S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fWqDPnoXtMGhkzs2Xr4jDnzYXYU.jpg'),
(137762, 9806, 'The Shield Acima da Lei S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tyvGUpyzenzRWdzJOikhVEpiUae.jpg'),
(137763, 9806, 'The Shield Acima da Lei S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hnhcASSS4h7IcT30mGvkL2VrcRP.jpg'),
(137764, 9806, 'The Shield Acima da Lei S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4zPybBbV9dD20d4sgwH8oPO4Khv.jpg'),
(137765, 9806, 'The Shield Acima da Lei S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i4VD3IWzLLvUF0KViVuySKkGrSQ.jpg'),
(137766, 9806, 'The Shield Acima da Lei S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uK89j39M0K1gWz48kJhwEUUb3Zo.jpg'),
(137767, 9806, 'The Shield Acima da Lei S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sEFyENYp0RXiiGxvOElx8fwfMDD.jpg'),
(137768, 9806, 'The Shield Acima da Lei S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cGr6LQQmb8NZGesUeaf4UkT2W4a.jpg'),
(137769, 9806, 'The Shield Acima da Lei S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9REbM0Xkb7DyBCSb5QZ5RNzetJO.jpg'),
(137770, 9806, 'The Shield Acima da Lei S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9KwYhY9a7h1znPkiLZu3OyblUm.jpg'),
(137771, 9806, 'The Shield Acima da Lei S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLKWibQ5i9UvQhta6hvzYT8v2lc.jpg'),
(137772, 9806, 'The Shield Acima da Lei S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a2j2c5xLcNmim76d9yRewk5zkXI.jpg'),
(137773, 9807, 'Better Call Saul [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kXPlwZm3RefxpSU5E3Mu4Yyvn40.jpg'),
(137774, 9807, 'Better Call Saul [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOkddHcnj8Fae8VbLbKMh641HHy.jpg'),
(137775, 9807, 'Better Call Saul [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xF1LKhLd0xAcddb9HrgAJ2W6gav.jpg'),
(137776, 9807, 'Better Call Saul [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1effMQQBq8BhBQXeqLNFcr8RGVb.jpg'),
(137777, 9807, 'Better Call Saul [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iDW7BZtI7M1xIzL4vGG637EzbPT.jpg'),
(137778, 9807, 'Better Call Saul [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7tSG2a6GSQyEcWH3P5e4zNqjVZO.jpg'),
(137779, 9807, 'Better Call Saul [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBrT8Hz6fFioPabezfWb3nLPCvA.jpg'),
(137780, 9807, 'Better Call Saul [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5vpI6D2n4zma4xqQBRq2Bz3tHu5.jpg'),
(137781, 9807, 'Better Call Saul [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iCMwMQstYZz8SRsiULMtiiP2xes.jpg'),
(137782, 9807, 'Better Call Saul [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUl8LoEhEtIy0kdyvwgo2ZNSH9B.jpg'),
(137783, 9808, 'Better Call Saul [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLx6Ow42rtFGJ0missJEfwUN4yF.jpg'),
(137784, 9808, 'Better Call Saul [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wRVKkfXsyhLAzpRC7J8Uek5dYg3.jpg'),
(137785, 9808, 'Better Call Saul [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o3euy8qB8AErKQcVHRrGWV1Xtiq.jpg'),
(137786, 9808, 'Better Call Saul [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rtVuaHImiLxvnffNASJbF4Q3F89.jpg'),
(137787, 9808, 'Better Call Saul [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hU120urNKVue1UIX25EXPTVBOcB.jpg'),
(137788, 9808, 'Better Call Saul [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUZtWB6MGftmrttpvfkc7GcGMtF.jpg'),
(137789, 9808, 'Better Call Saul [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1RumrNbk6ZAGB5U1YqQR6h96u77.jpg'),
(137790, 9808, 'Better Call Saul [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/43SruAr8U7y2qteRb9OaSTesQzy.jpg'),
(137791, 9808, 'Better Call Saul [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Q9JaQ63y3diwZ6HVebbMLfH9sc.jpg'),
(137792, 9808, 'Better Call Saul [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zit4sAsSYOnpk5MOcceRiQf0VTj.jpg'),
(137793, 9809, 'Better Call Saul [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aG3q36NweQneIsYG74LaOYB3ubv.jpg'),
(137794, 9809, 'Better Call Saul [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/buKhfwuOyXv5ZbZSlkWz0pR6Il5.jpg'),
(137795, 9809, 'Better Call Saul [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gGm2dT0m297MGdFjcdBRRYVosF5.jpg'),
(137796, 9809, 'Better Call Saul [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pFjMOyhgP8HCwkRG34ZD8C0VTDz.jpg'),
(137797, 9809, 'Better Call Saul [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rsYlkD587vrj6fp1DToyQ9PpjJ6.jpg'),
(137798, 9809, 'Better Call Saul [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lAEikpCAspgsGAaNpnbyxXHO6nj.jpg'),
(137799, 9809, 'Better Call Saul [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jqVsNTUU6uhgjIpxzTgOa8U1teK.jpg'),
(137800, 9809, 'Better Call Saul [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pnOBvxBuWqNNGrU36PU5xg2Np8t.jpg'),
(137801, 9809, 'Better Call Saul [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1I5fgW7h62PsDmMGpThHJ0tSdg3.jpg'),
(137802, 9809, 'Better Call Saul [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8UlFIL3uitcmfKTaEpK8f0WZMyS.jpg'),
(137803, 9810, 'Better Call Saul [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gcG57V96qWemZYCwfW7osDXl4f2.jpg'),
(137804, 9810, 'Better Call Saul [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qlNNq4SiVwmgxrZLaO9Xoph7UgN.jpg'),
(137805, 9810, 'Better Call Saul [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bkvPvenDuk7IqBMi0dFqi3RH2Dp.jpg'),
(137806, 9810, 'Better Call Saul [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vo8wNDe1HfWIY1Pf1pPg10lchT5.jpg'),
(137807, 9810, 'Better Call Saul [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sA6ZZA1VELtpQAnRxZtFhagiPgL.jpg'),
(137808, 9810, 'Better Call Saul [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y8lB4NeGWqlRfVtULraOiarXPAl.jpg'),
(137809, 9810, 'Better Call Saul [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/drxVhOlWzRp4V9rrcGZIEqrhwG6.jpg'),
(137810, 9810, 'Better Call Saul [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ru5Kxn15IoJS0SA2UetbQIASGdk.jpg'),
(137811, 9810, 'Better Call Saul [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dsZZClwZHFqAUK6VjVIuPOwtxfS.jpg'),
(137812, 9810, 'Better Call Saul [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Gqb3QyBSYEn71pcTWortPcdbcu.jpg'),
(137813, 9811, 'Better Call Saul [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s3dkWr75dnprdINXDJwbLj5K2k4.jpg'),
(137814, 9811, 'Better Call Saul [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y3hl0ho1RFX4cc7QA0ASstYxrRd.jpg'),
(137815, 9811, 'Better Call Saul [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mK6JroS6efUPeNVwZYSWN5T06Ej.jpg'),
(137816, 9811, 'Better Call Saul [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2r0dRdlofscCZQkEVbjGXP27tk.jpg'),
(137817, 9811, 'Better Call Saul [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dATaoHp0uLqxS3AoLW3MiJFQEDS.jpg'),
(137818, 9811, 'Better Call Saul [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cdrY5PlUUmWBxn5z2nTHKCeRI2o.jpg'),
(137819, 9811, 'Better Call Saul [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/njldwLw48kBdRN7mzfsLh5SN20d.jpg'),
(137820, 9811, 'Better Call Saul [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nB40Q7kPgJJJbGAGnoLESPzYYZY.jpg'),
(137821, 9811, 'Better Call Saul [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Z5gCUKmZrU6KRBOpPjOOAI2htH.jpg'),
(137822, 9811, 'Better Call Saul [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQIhr0zJ7Qczpr1FsahK6hC9TgE.jpg'),
(137823, 9812, 'Better Call Saul [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/266041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/spRkg6Qa2X4C856KOMlRGQHg6cE.jpg'),
(137824, 9812, 'Better Call Saul [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/266042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c3f50t1DedALX5Tr2VKyOoAhQRe.jpg'),
(137825, 9812, 'Better Call Saul [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/266043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/boQ8tjHdabQB6TXEDgJux7gEzSW.jpg'),
(137826, 9812, 'Better Call Saul [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/266044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7DYo2VCcSiP3R7GQFC5RM6sfll.jpg'),
(137827, 9812, 'Better Call Saul [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/266045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v8eRAlbjDMwDx4JuCsyimHZ6kxE.jpg'),
(137828, 9812, 'Better Call Saul [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/266046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/48SkTDWOgXt1hjc5rE0pT9QlAGA.jpg'),
(137829, 9812, 'Better Call Saul [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/266047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/flVUI98wSTtLmYDCx81gowleQTe.jpg'),
(137830, 9812, 'Better Call Saul [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/266048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j00SYyNwv9agYN4gxW1f5AYFrhG.jpg'),
(137831, 9812, 'Better Call Saul [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/266049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qR1Thp9EntDwuyXTo5hUAo9OyRr.jpg'),
(137832, 9812, 'Better Call Saul [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/266050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZuBaYUf0hs9hxNUdTMO8aU9b6q.jpg'),
(137833, 9812, 'Better Call Saul [L] S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/266051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/luhdkeBz7FbXLkblFLAwRp9F7bw.jpg'),
(137834, 9812, 'Better Call Saul [L] S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/266052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eeNijlYY7NQEqHLp8ZqlLfGDtXV.jpg'),
(137835, 9812, 'Better Call Saul [L] S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/266053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZFwz8FaM9MXFqwakFnhhNjYZSv.jpg'),
(137836, 9813, 'Alexandre O Nascimento de um Deus S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ggU521zEDKqtMy3w4kBxzmHEwW.jpg'),
(137837, 9813, 'Alexandre O Nascimento de um Deus S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s2uCEersZ6Y7wp3aMlwPzXdVXMC.jpg'),
(137838, 9813, 'Alexandre O Nascimento de um Deus S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uMaCfp08LuV06gbOgZUgRVvnZBL.jpg'),
(137839, 9813, 'Alexandre O Nascimento de um Deus S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/benART9WCJIzT9x5n5I1k6UG87P.jpg'),
(137840, 9813, 'Alexandre O Nascimento de um Deus S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PFtTSP1z4ajN2ARY8pVNkHc5Gp.jpg'),
(137841, 9813, 'Alexandre O Nascimento de um Deus S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fFNzMkkd1M8bqVSc7Smq2OHF7Ub.jpg'),
(137842, 9814, 'Baby Bandito S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dKFSCimy2Lfqmh9bqXskzzLZrSC.jpg'),
(137843, 9814, 'Baby Bandito S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dKFSCimy2Lfqmh9bqXskzzLZrSC.jpg'),
(137844, 9814, 'Baby Bandito S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dKFSCimy2Lfqmh9bqXskzzLZrSC.jpg'),
(137845, 9814, 'Baby Bandito S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dKFSCimy2Lfqmh9bqXskzzLZrSC.jpg'),
(137846, 9814, 'Baby Bandito S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dKFSCimy2Lfqmh9bqXskzzLZrSC.jpg'),
(137847, 9814, 'Baby Bandito S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dKFSCimy2Lfqmh9bqXskzzLZrSC.jpg'),
(137848, 9814, 'Baby Bandito S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dKFSCimy2Lfqmh9bqXskzzLZrSC.jpg'),
(137849, 9814, 'Baby Bandito S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dKFSCimy2Lfqmh9bqXskzzLZrSC.jpg'),
(137850, 9815, 'Enredos da Liberdade O Grito do Samba pela Democracia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8JBCjjRyXR1v86Z5VioBc7dToCF.jpg'),
(137851, 9815, 'Enredos da Liberdade O Grito do Samba pela Democracia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8JBCjjRyXR1v86Z5VioBc7dToCF.jpg'),
(137852, 9815, 'Enredos da Liberdade O Grito do Samba pela Democracia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8JBCjjRyXR1v86Z5VioBc7dToCF.jpg'),
(137853, 9815, 'Enredos da Liberdade O Grito do Samba pela Democracia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8JBCjjRyXR1v86Z5VioBc7dToCF.jpg'),
(137854, 9815, 'Enredos da Liberdade O Grito do Samba pela Democracia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8JBCjjRyXR1v86Z5VioBc7dToCF.jpg'),
(137855, 9816, 'Battlestar Galactica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zaS8EV6tUsdM7HVurUIKz6Ypz03.jpg'),
(137856, 9816, 'Battlestar Galactica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/drzZmV3fRa9meIUhIY6IKfZwfD8.jpg'),
(137857, 9816, 'Battlestar Galactica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ywLke5tjeaHbA45inoz9OmpYe8c.jpg'),
(137858, 9816, 'Battlestar Galactica S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jW6ZI0GnmzprqyV4oQMuMFKApdC.jpg'),
(137859, 9816, 'Battlestar Galactica S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n4ypvV4KZ8qksB5ONf5bPvS2c4a.jpg'),
(137860, 9816, 'Battlestar Galactica S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rPll3uIzpocuS5SKl8aeWKY6l7h.jpg'),
(137861, 9816, 'Battlestar Galactica S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n5tSyPEJ8RAyES8WHKI5WeSRspG.jpg'),
(137862, 9816, 'Battlestar Galactica S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8AsTsntFjyTYvx508NeRCbsHIfF.jpg'),
(137863, 9816, 'Battlestar Galactica S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ca7HjJuhbecgGL2Oqe4inoeEMWT.jpg'),
(137864, 9816, 'Battlestar Galactica S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4hc4dSiynmFNrBYRZZU4ZO29zef.jpg'),
(137865, 9816, 'Battlestar Galactica S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fLsnxZVqTYsjMPW48FFLNzyKWGg.jpg'),
(137866, 9816, 'Battlestar Galactica S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a8YRuR1qOm8ANHAwzFba7UiS5F9.jpg'),
(137867, 9816, 'Battlestar Galactica S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tGjlO5GoD8U9ALFVtpYQLxcDD2e.jpg'),
(137868, 9817, 'Battlestar Galactica S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vQttLi1KPXju9FICRfN0mr0LQL8.jpg'),
(137869, 9817, 'Battlestar Galactica S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5If0bjF4iYFP96rIfMWrddLfxH8.jpg'),
(137870, 9817, 'Battlestar Galactica S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nLFYUqAFa6YP4v1hXAi6gBsbgZv.jpg'),
(137871, 9817, 'Battlestar Galactica S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmVLMofTPozkoGc8C9mCRGlNvFU.jpg'),
(137872, 9817, 'Battlestar Galactica S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vz2cBjXZGjIlTwgVlGnHW05jY1Y.jpg'),
(137873, 9817, 'Battlestar Galactica S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/CqrI2Rj3gyNbhFjtvOi3vOtq0b.jpg'),
(137874, 9817, 'Battlestar Galactica S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLJAt911PzhcQIKNqHeLkXL42yl.jpg'),
(137875, 9817, 'Battlestar Galactica S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/peHONCLj52l4oY6Ey0lekcZ7cDg.jpg'),
(137876, 9817, 'Battlestar Galactica S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7LrozItqxmQqeM1VS2jU4J9sV4I.jpg'),
(137877, 9817, 'Battlestar Galactica S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/orEwvT6DpH2SgBtuS7vnAzYzYel.jpg'),
(137878, 9817, 'Battlestar Galactica S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vR0JLjTCM5P4n69w0OyWJzhj3BZ.jpg'),
(137879, 9817, 'Battlestar Galactica S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/djRPC6FE8QUQheXVa3KfjkDBVTs.jpg'),
(137880, 9817, 'Battlestar Galactica S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1L3C6KCfVt2PSzz0xqkJ4fWbpY3.jpg'),
(137881, 9817, 'Battlestar Galactica S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y3N7sRtPMofKzHxRsVJpVJS3d6m.jpg'),
(137882, 9817, 'Battlestar Galactica S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5JZL9jYdOjLZOmebKybZr4ZzRxt.jpg'),
(137883, 9817, 'Battlestar Galactica S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qsafRWRSzoEqDTN3pDyAMPqMe5F.jpg'),
(137884, 9817, 'Battlestar Galactica S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ku72FVmj6HP0F8mjICRkp75YbHV.jpg'),
(137885, 9817, 'Battlestar Galactica S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/265931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1cNQHWZ8I8jDa8WRh9ejixx7rqU.jpg'),
(137886, 9817, 'Battlestar Galactica S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/265932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6t80RHtwo4PumNUkeoMiXqHtfxZ.jpg'),
(137887, 9817, 'Battlestar Galactica S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/265933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kv8UGskDcRBOKzaZpBTNTUD2FWd.jpg'),
(137888, 9818, 'Battlestar Galactica S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zuW7ejuxPJmVIUmtB5E7gjehXhw.jpg'),
(137889, 9818, 'Battlestar Galactica S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f3uCFJDeyi3uq5SUWG6mVjX7ByR.jpg'),
(137890, 9818, 'Battlestar Galactica S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lan8sfYrRxbjG7ZfYansuliZxG7.jpg'),
(137891, 9818, 'Battlestar Galactica S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBzoFRdGYVnoHzNrExmweKSKTY4.jpg'),
(137892, 9818, 'Battlestar Galactica S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vYOF6jr744uTJo2P1JZ6naLXg5W.jpg'),
(137893, 9818, 'Battlestar Galactica S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q2WX6YmLe89UOdLjpHwVgmwckHH.jpg'),
(137894, 9818, 'Battlestar Galactica S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8e7JQBUZso9PLvh7JP9THSovlS7.jpg'),
(137895, 9818, 'Battlestar Galactica S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lFPGQtFu1pp1CCytAHy4V4YyhtP.jpg'),
(137896, 9818, 'Battlestar Galactica S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dEgHRsKp8KffT5jXzR78mNWhB2v.jpg'),
(137897, 9818, 'Battlestar Galactica S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2tyVBTOAuYroQx55QHNJr4ZxYLz.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(137898, 9818, 'Battlestar Galactica S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvh2zgnDP4lStnB1S2812iVn84D.jpg'),
(137899, 9818, 'Battlestar Galactica S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f1Llg4aepiro1WPi0EybRbuDZaV.jpg'),
(137900, 9818, 'Battlestar Galactica S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ui4PSkbScb61s9KVSSfEwB5agJN.jpg'),
(137901, 9818, 'Battlestar Galactica S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4gzzjCyeWexIS7bJdaToTr6OJck.jpg'),
(137902, 9818, 'Battlestar Galactica S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xO1ThE3SFnivExDDN15qafgcrV5.jpg'),
(137903, 9818, 'Battlestar Galactica S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/up7jZHwmpSFPF2ljmSJHFchVEFi.jpg'),
(137904, 9818, 'Battlestar Galactica S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jFhzhkqiQsac1aJdhndZMimrq9Z.jpg'),
(137905, 9818, 'Battlestar Galactica S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/265951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bYXJzel7wjX9LP3juybiaNM5LST.jpg'),
(137906, 9818, 'Battlestar Galactica S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/265952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odbUggiG9dBwcx4LhEk3MVIN78l.jpg'),
(137907, 9819, 'Battlestar Galactica S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tycc0si6hFwZB6zXl6BLhUlG3dV.jpg'),
(137908, 9819, 'Battlestar Galactica S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUzvMuhsf349qjT7k1x9apmAV6P.jpg'),
(137909, 9819, 'Battlestar Galactica S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cwdi3gtLlETWbPY9jizrqcHcgnE.jpg'),
(137910, 9819, 'Battlestar Galactica S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJBwyNSk19vUk9zvFmpJDnlfPyH.jpg'),
(137911, 9819, 'Battlestar Galactica S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6CJLDslwiap6ucJ7OHdhCwnUUoH.jpg'),
(137912, 9819, 'Battlestar Galactica S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4MZHKE6cCX6o2LqV5NDNKLetW1p.jpg'),
(137913, 9819, 'Battlestar Galactica S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jcGOojEe18P4nq1g78PbQuvp9ym.jpg'),
(137914, 9819, 'Battlestar Galactica S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5mopODAJ5TLP1RlxtGiW3UwmSBS.jpg'),
(137915, 9819, 'Battlestar Galactica S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9GpIJvaziZPdMy1BOYI7gIe4hzU.jpg'),
(137916, 9819, 'Battlestar Galactica S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s6fuTvDiAIJzP31RYuaTKETdLo.jpg'),
(137917, 9819, 'Battlestar Galactica S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bd2QYUaTpRIPR5xu00WQCsDib25.jpg'),
(137918, 9819, 'Battlestar Galactica S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyLvRgwljAKFh2SfR0opE3Rfcms.jpg'),
(137919, 9819, 'Battlestar Galactica S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fRjEAJl5jNYtZJW5JrTaBmGFBes.jpg'),
(137920, 9819, 'Battlestar Galactica S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rjQwjUxLfMpdcNX1acMUyQ1rv5j.jpg'),
(137921, 9819, 'Battlestar Galactica S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mF6quZjTzd3rwozlrI4yPT3cbgo.jpg'),
(137922, 9819, 'Battlestar Galactica S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oA7y1ouXOmJKLcDSZGyUPoKIovJ.jpg'),
(137923, 9819, 'Battlestar Galactica S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9OP9pxSXPXbyGptx5hNrjwNTRdt.jpg'),
(137924, 9819, 'Battlestar Galactica S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/265970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8kfJTvkPbMl6OqSPLCi8aqF1zFH.jpg'),
(137925, 9819, 'Battlestar Galactica S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/265971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/99PJSbcO2LeM10uOGWeFihNp77j.jpg'),
(137926, 9820, 'Big Bang A Teoria [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rxWlBXZhGWhumbLB8gAHyyW3ITD.jpg'),
(137927, 9820, 'Big Bang A Teoria [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Itgr82yyAEtwegAZgMm30UqJXK.jpg'),
(137928, 9820, 'Big Bang A Teoria [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eDyDC7cwKz9ZTA4CX44eKuHjPgZ.jpg'),
(137929, 9820, 'Big Bang A Teoria [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bk8aIjAyS6XDG3I3otseP0jaR4x.jpg'),
(137930, 9820, 'Big Bang A Teoria [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zO3CSyb13PQyzWICp4mmZEUeExp.jpg'),
(137931, 9820, 'Big Bang A Teoria [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4P20QdmB6QL8aa0b8dKR8sHK1iW.jpg'),
(137932, 9820, 'Big Bang A Teoria [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4y5rvzPZF5ukM3vtktqWTp9MhyH.jpg'),
(137933, 9820, 'Big Bang A Teoria [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rbVfuB7vBrrXygo0d8qhk9FhmAd.jpg'),
(137934, 9820, 'Big Bang A Teoria [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8MvMEvZzZPBkgQZIVk9KvF8nLH5.jpg'),
(137935, 9820, 'Big Bang A Teoria [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6dssfbhNv1g3FFqKWKJhNqaqSQH.jpg'),
(137936, 9820, 'Big Bang A Teoria [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0E0GNUMHWZDNKbygCjKJGiFc9G.jpg'),
(137937, 9820, 'Big Bang A Teoria [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wlo6NGvrpo58hnUztkAmdDBPj2D.jpg'),
(137938, 9820, 'Big Bang A Teoria [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w1Et8tW5En8a2ieEWRlolAVkyED.jpg'),
(137939, 9820, 'Big Bang A Teoria [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sktEOfZVIBnyW6MeZlGXbcdp6vO.jpg'),
(137940, 9820, 'Big Bang A Teoria [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBlf2PEd6RDGnyOip6ZPJ825AMw.jpg'),
(137941, 9820, 'Big Bang A Teoria [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jnI6qR3y9Hfn7hA1uCUJhYMkIAv.jpg'),
(137942, 9820, 'Big Bang A Teoria [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3RCfgXjtRcWRt1ci7RIYi3JzJQ9.jpg'),
(137943, 9821, 'Big Bang A Teoria [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y9cFxQyFRBOewwVvkMl6SaH2om0.jpg'),
(137944, 9821, 'Big Bang A Teoria [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a9k5gM9GYU4IBW93LJc4IjRbgHI.jpg'),
(137945, 9821, 'Big Bang A Teoria [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0bhAlY77x9XwfpHYrDScHZvMQE.jpg'),
(137946, 9821, 'Big Bang A Teoria [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AvCiGNJqqaowpZlBdoO6Bp2hIdp.jpg'),
(137947, 9821, 'Big Bang A Teoria [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/84UnqiLl4J8LCmJXWwTNfne4pWC.jpg'),
(137948, 9821, 'Big Bang A Teoria [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2WAmfZtammDEhuQuDgxqQT7BR9z.jpg'),
(137949, 9821, 'Big Bang A Teoria [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nBAjkqE9I805f9OCqxZAKVqnJT2.jpg'),
(137950, 9821, 'Big Bang A Teoria [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AlvHVY7gvBHfQvMLAvB9PODeYQw.jpg'),
(137951, 9821, 'Big Bang A Teoria [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f5ls4tc9cY8Zh9998lMyZ3A9E6B.jpg'),
(137952, 9821, 'Big Bang A Teoria [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uosBIO5639eeocnvjCxqrLl2HEN.jpg'),
(137953, 9821, 'Big Bang A Teoria [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUh7k8uTCSjnlFqQZ4HVKZ8N7rA.jpg'),
(137954, 9821, 'Big Bang A Teoria [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdo2epxMfOhpAWJ3EWplioQakRK.jpg'),
(137955, 9821, 'Big Bang A Teoria [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9q49iyMGcO9EIk9vWbnBZgfGNSF.jpg'),
(137956, 9821, 'Big Bang A Teoria [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wC2YMYgyCnEixzO1ztYx1LUAndL.jpg'),
(137957, 9821, 'Big Bang A Teoria [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cShchuw3099TXbfav7e9XU6qCoV.jpg'),
(137958, 9821, 'Big Bang A Teoria [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/egK4v3alm6G7cm0CmMRGR3p8Yx3.jpg'),
(137959, 9821, 'Big Bang A Teoria [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uorhUtKMHkx7EokhUcSBl3q6GRt.jpg'),
(137960, 9821, 'Big Bang A Teoria [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/265657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fkaYEuDqCyBsODp0XYMAZrLULYs.jpg'),
(137961, 9821, 'Big Bang A Teoria [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/265658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8LL0P42Z8mwyFXfnF3jnaabSZYt.jpg'),
(137962, 9821, 'Big Bang A Teoria [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/265659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/otMgg5qrM4XfHwbGnpWhPy8R2yD.jpg'),
(137963, 9821, 'Big Bang A Teoria [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/265660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5SRU3ZHSjhdh7MOWHxivvO6p2Xs.jpg'),
(137964, 9821, 'Big Bang A Teoria [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/265661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jNdjEnmBwdJiojaG6weilqZPfOn.jpg'),
(137965, 9821, 'Big Bang A Teoria [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/265662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5NiLbb4TXeiiAjTPyqP08Swu8w5.jpg'),
(137966, 9822, 'Big Bang A Teoria [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4MFmDclUoXHM0se1IM9jKRhHp6n.jpg'),
(137967, 9822, 'Big Bang A Teoria [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJRmBDoo2MrbYjs91ViaXMUUMru.jpg'),
(137968, 9822, 'Big Bang A Teoria [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8iWdGkONXwKYsv73HZr6p80Csaa.jpg'),
(137969, 9822, 'Big Bang A Teoria [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/doGrzGYbdS9HzjkfROUENBv6gpk.jpg'),
(137970, 9822, 'Big Bang A Teoria [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j7HZdRP1eVcnQYGEu9o3TruEKvL.jpg'),
(137971, 9822, 'Big Bang A Teoria [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ethrkqDoGEbXtmN48IhN9aIESfa.jpg'),
(137972, 9822, 'Big Bang A Teoria [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vbpHo8Px5CILtVR9wU3wyPSHn56.jpg'),
(137973, 9822, 'Big Bang A Teoria [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8EbctrCaN3RJXiTKe2a9yebM9rZ.jpg'),
(137974, 9822, 'Big Bang A Teoria [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x9hd50SQpxiZ1nLXeyhHeeAnT8x.jpg'),
(137975, 9822, 'Big Bang A Teoria [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xUaKd5XBnmqny83essybaiQSICd.jpg'),
(137976, 9822, 'Big Bang A Teoria [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kioeIQpVHRmhILyFGHiiebACdX1.jpg'),
(137977, 9822, 'Big Bang A Teoria [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5uXitxxXHYVKHrEGmT3ylHRxOjn.jpg'),
(137978, 9822, 'Big Bang A Teoria [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jLh4QS3YkclWPrioytdMbuVjwXL.jpg'),
(137979, 9822, 'Big Bang A Teoria [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7tx6fSRlOn6r5HXVOzOjilaqeZI.jpg'),
(137980, 9822, 'Big Bang A Teoria [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/X19dpYs9iBJeiqiqb72STdjCg0.jpg'),
(137981, 9822, 'Big Bang A Teoria [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6waZYJy3LVmnMO6Im6aFuBTDgJg.jpg'),
(137982, 9822, 'Big Bang A Teoria [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzlFMjsXZrIBEG6s3hplvJyLhBX.jpg'),
(137983, 9822, 'Big Bang A Teoria [L] S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/265680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lyAMqIxYBlBNk8Brb6CWceltipC.jpg'),
(137984, 9822, 'Big Bang A Teoria [L] S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/265681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHlOeHU6ruNOCE2yvRYG21r0AB5.jpg'),
(137985, 9822, 'Big Bang A Teoria [L] S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/265682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/94BO8OvR6Fz9VVBWWpuS5ah4Gc4.jpg'),
(137986, 9822, 'Big Bang A Teoria [L] S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/265683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/maRYQapYCEnJYwNlkpLWbH9qq8a.jpg'),
(137987, 9822, 'Big Bang A Teoria [L] S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/265684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qq9pGaUcCyVf2rv7iEwSMyYWeWm.jpg'),
(137988, 9822, 'Big Bang A Teoria [L] S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/265685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p44sacZuH1LDmctn896hH10mI9m.jpg'),
(137989, 9823, 'Big Bang A Teoria [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Ab7pe6u7bQo55w0BArx11OQ4xI.jpg'),
(137990, 9823, 'Big Bang A Teoria [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gbdirXM1Gw9K4NZWhWHV4qjPDbX.jpg'),
(137991, 9823, 'Big Bang A Teoria [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eBLxhs3TDM8d0zlutOGhIfDDVd2.jpg'),
(137992, 9823, 'Big Bang A Teoria [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/isCe5dxkG0Ufi4cNRfmCr2HsoJd.jpg'),
(137993, 9823, 'Big Bang A Teoria [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mOhDhRyqDZU5HVHmgypFte7jTAU.jpg'),
(137994, 9823, 'Big Bang A Teoria [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/srBGG50Cw4XOn2f4bZUqtnwznVM.jpg'),
(137995, 9823, 'Big Bang A Teoria [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jXGtTcqfYmwDdIpkE0nk1l0PgYL.jpg'),
(137996, 9823, 'Big Bang A Teoria [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/TxfaPETKaKt5ejJYRKG5zyrJQ9.jpg'),
(137997, 9823, 'Big Bang A Teoria [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ksiCi17L2Ko4QaB1NBxnYdlYrGV.jpg'),
(137998, 9823, 'Big Bang A Teoria [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pWWRt2BzusW1WPaXs7E8J0fQGqf.jpg'),
(137999, 9823, 'Big Bang A Teoria [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uUUUozntwqQiivWD7qsuyV8hg2O.jpg'),
(138000, 9823, 'Big Bang A Teoria [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ksC48YK2UFV8GeBETu11fTM7r0a.jpg'),
(138001, 9823, 'Big Bang A Teoria [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dBYcZAs8g77jjvyHGXClQIluFwc.jpg'),
(138002, 9823, 'Big Bang A Teoria [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oOd0acUQiDF7CyoJf9z52JyGBA5.jpg'),
(138003, 9823, 'Big Bang A Teoria [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mRo77oUOj2kq4DLqOdpXkmtBjOv.jpg'),
(138004, 9823, 'Big Bang A Teoria [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwHPcYlrCFfRO5UEJ7oFfhg84me.jpg'),
(138005, 9823, 'Big Bang A Teoria [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/WeOnAUVBQn5VrT409KoZUh19HY.jpg'),
(138006, 9823, 'Big Bang A Teoria [L] S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/265703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lxpNNW7buxaTnWDtPAnqpc6ly7g.jpg'),
(138007, 9823, 'Big Bang A Teoria [L] S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/265704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zoY6h6LtJCShaLfuPUSnBCNRdHN.jpg'),
(138008, 9823, 'Big Bang A Teoria [L] S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/265705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nlidiQe6jIloJSrBLxQdPDZuVb5.jpg'),
(138009, 9823, 'Big Bang A Teoria [L] S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/265706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8pkhzxsCYsknfd3gsiGH56yKACs.jpg'),
(138010, 9823, 'Big Bang A Teoria [L] S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/265707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dNJ1kLNhA9dDuGjZIq8OK8l5ROi.jpg'),
(138011, 9823, 'Big Bang A Teoria [L] S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/265708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/teak3DATV9pjGKIriGMTYylMUT5.jpg'),
(138012, 9823, 'Big Bang A Teoria [L] S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/265709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a3VbByTzFL1ew0gmdQVzFXF9mmz.jpg'),
(138013, 9824, 'Big Bang A Teoria [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSGRUzwEeW4LMOPuYKQloqCVEhH.jpg'),
(138014, 9824, 'Big Bang A Teoria [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tVqTk7JdBxuI2drlZ2jJ4ICBicl.jpg'),
(138015, 9824, 'Big Bang A Teoria [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wEdMYpz2tWAmp626nAWq0l44ltA.jpg'),
(138016, 9824, 'Big Bang A Teoria [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iStKftXNjUbKLjvKAzTXmT3tuZn.jpg'),
(138017, 9824, 'Big Bang A Teoria [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pB5Ia00Um7dbybAUhWQTCV18V4z.jpg'),
(138018, 9824, 'Big Bang A Teoria [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1nXbeQy9vdPlvm2Ap97Lhg8suir.jpg'),
(138019, 9824, 'Big Bang A Teoria [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cUm2yLiZ2QPdSgIdUYiob0ThcDe.jpg'),
(138020, 9824, 'Big Bang A Teoria [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cH0vx6h3gcuJCVGrgEaxPqiUmbv.jpg'),
(138021, 9824, 'Big Bang A Teoria [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ibkOlSREPuB4GMOKGhzs2ZIdNZ7.jpg'),
(138022, 9824, 'Big Bang A Teoria [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sf1FDxLxinOqyY05Uk3MRZzlP1V.jpg'),
(138023, 9824, 'Big Bang A Teoria [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Dn4asZCyq9I0iRtyVCiu9GMhce.jpg'),
(138024, 9824, 'Big Bang A Teoria [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dHAL94ft1SipqmaHL6uNAsegots.jpg'),
(138025, 9824, 'Big Bang A Teoria [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7GZNVew1Fw24MKcCUKlGuvGJ2LR.jpg'),
(138026, 9824, 'Big Bang A Teoria [L] S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZTRt2pZ2Ty5kka8iPqXocXO779.jpg'),
(138027, 9824, 'Big Bang A Teoria [L] S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aTgjYCtHKEoR0meeXcd2tEXdAkl.jpg'),
(138028, 9824, 'Big Bang A Teoria [L] S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k6a9X7SdwEwzFlt7mx6gAkjlgTu.jpg'),
(138029, 9824, 'Big Bang A Teoria [L] S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bcs07iCu9l2yP6HfjcrPUViXouG.jpg'),
(138030, 9824, 'Big Bang A Teoria [L] S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/265727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1gdddSpcbY8Eh98Hg6xCFPoDWpu.jpg'),
(138031, 9824, 'Big Bang A Teoria [L] S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/265728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gN7RrKwH3pmL8u1sJiOlzChZBAb.jpg'),
(138032, 9824, 'Big Bang A Teoria [L] S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/265729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wcPVenMYOg1IGGcwgSPzWAjdAkO.jpg'),
(138033, 9824, 'Big Bang A Teoria [L] S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/265730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dh75Gnq9vlvTIxvheYo3D86lSnm.jpg'),
(138034, 9824, 'Big Bang A Teoria [L] S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/265731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/FDRRgbb4PkOljdmEjKawpnyFlK.jpg'),
(138035, 9824, 'Big Bang A Teoria [L] S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/265732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aGhOWNabAScjiHEzs1TebXH1kVa.jpg'),
(138036, 9824, 'Big Bang A Teoria [L] S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/265733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jEvrX87J4tGgbvkePKJzWZJWrZp.jpg'),
(138037, 9825, 'Big Bang A Teoria [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Ayyn5aUTiWyFe4NpWIlMNloJnk.jpg'),
(138038, 9825, 'Big Bang A Teoria [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iCabbwLLDz3UeYeBWBLUTofeVKC.jpg'),
(138039, 9825, 'Big Bang A Teoria [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aFEMUGUCTecVLXfBkt8bVXA7tqV.jpg'),
(138040, 9825, 'Big Bang A Teoria [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lFDe5o3cJBNGM1dgyl8ODXxrOds.jpg'),
(138041, 9825, 'Big Bang A Teoria [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zxD6kV0f0hKXELHgfRugzj5mLzA.jpg'),
(138042, 9825, 'Big Bang A Teoria [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hFo8nKHHdIqnnGaG1tiou6R9lWc.jpg'),
(138043, 9825, 'Big Bang A Teoria [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mwvOUXUJI8Oqa7w1w5GJswESuik.jpg'),
(138044, 9825, 'Big Bang A Teoria [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eFAeunnPvLmHPfxW799YH2gLXgQ.jpg'),
(138045, 9825, 'Big Bang A Teoria [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ildLJA1MOjw2gISEi6PKWiw1mMS.jpg'),
(138046, 9825, 'Big Bang A Teoria [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b1kSMZm7qsVwKFG6bzFYtFUsKJV.jpg'),
(138047, 9825, 'Big Bang A Teoria [L] S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6HD4K6oZEyd76yyki9wFwGwMlP4.jpg'),
(138048, 9825, 'Big Bang A Teoria [L] S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/syvmicoYIDzmehm7BrKnHSuXNNO.jpg'),
(138049, 9825, 'Big Bang A Teoria [L] S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fGB9j3zU65aJL5btwWH57dKq77r.jpg'),
(138050, 9825, 'Big Bang A Teoria [L] S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWDdPEhogoFt9mw8grFaaXL7Fy7.jpg'),
(138051, 9825, 'Big Bang A Teoria [L] S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iOHlTynlPg2CEcyDsppdzcwpUnw.jpg'),
(138052, 9825, 'Big Bang A Teoria [L] S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u1jD82NzWmOJ3C2Rr4WXEOlPNrV.jpg'),
(138053, 9825, 'Big Bang A Teoria [L] S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oenhInvrEh4pSA315BctlyBggPh.jpg'),
(138054, 9825, 'Big Bang A Teoria [L] S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/265751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjzI8Mr4wMJNsF3VUvleyP2MaQA.jpg'),
(138055, 9825, 'Big Bang A Teoria [L] S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/265752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tkeFF4tTKideY2yHuRWGbpe2VrX.jpg'),
(138056, 9825, 'Big Bang A Teoria [L] S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/265753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f1EjNAr5oQRsFLhx9igoyHWb2wk.jpg'),
(138057, 9825, 'Big Bang A Teoria [L] S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/265754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pNnMlfzNQOuN7Ml26JOCxgzH32W.jpg'),
(138058, 9825, 'Big Bang A Teoria [L] S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/265755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/db0LtfGVAa2mitePHU7YcyLU4j3.jpg'),
(138059, 9825, 'Big Bang A Teoria [L] S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/265756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a1OEeJ7q8tY1PjLBoogyoCZ6w05.jpg'),
(138060, 9825, 'Big Bang A Teoria [L] S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/265757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yLAWYAFkzOFbJdTNb9v7fzC2Ond.jpg'),
(138061, 9826, 'Big Bang A Teoria [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nf766vILhf88IUK49TE6kzN125n.jpg'),
(138062, 9826, 'Big Bang A Teoria [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bR3Xk5ZEGDC902HncROZmjdKbGK.jpg'),
(138063, 9826, 'Big Bang A Teoria [L] S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AsjWlSjl6PSwQQy5q8hbNGqAykL.jpg'),
(138064, 9826, 'Big Bang A Teoria [L] S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/66MAd0Sos3XnYxpHlKpvYo1nSw0.jpg'),
(138065, 9826, 'Big Bang A Teoria [L] S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k8atjbd5gAsntuhbPnFpvnvo0qn.jpg'),
(138066, 9826, 'Big Bang A Teoria [L] S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y6jm6HlK6b2EaOitYUjapVLDQq0.jpg'),
(138067, 9826, 'Big Bang A Teoria [L] S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j1NUVbJ36CaGqjgFJDi0xR47YON.jpg'),
(138068, 9826, 'Big Bang A Teoria [L] S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hHU9wgntzMzHneZ8quyVzAsuMa9.jpg'),
(138069, 9826, 'Big Bang A Teoria [L] S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wz5UxaCaHm7cehjD2uqxHLLI29s.jpg'),
(138070, 9826, 'Big Bang A Teoria [L] S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eNEHrIcKPR62YiXQNxRZ3VRUjIG.jpg'),
(138071, 9826, 'Big Bang A Teoria [L] S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5IPGYLsPs2XQVi1jzg7Pk6QYE3.jpg'),
(138072, 9826, 'Big Bang A Teoria [L] S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/znhuvcswL1TtQZHMG1OwBEb8IUW.jpg'),
(138073, 9826, 'Big Bang A Teoria [L] S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6nWIj6pBKcElp8d2XPsBxmh8ICO.jpg'),
(138074, 9826, 'Big Bang A Teoria [L] S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ogCao2o4NJfNJtU9PRTUSNuVCEk.jpg'),
(138075, 9826, 'Big Bang A Teoria [L] S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rvUHJolWcZjsylolTowKMSMlZPD.jpg'),
(138076, 9826, 'Big Bang A Teoria [L] S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lG38WAOKYwZVGFh6SjNHjpxK4ha.jpg'),
(138077, 9826, 'Big Bang A Teoria [L] S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A7ciWxOm5ysb5xI8gspY4Q96OJH.jpg'),
(138078, 9826, 'Big Bang A Teoria [L] S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/265775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xOlmMD8mkSYcZjGDibQ0sglYLl4.jpg'),
(138079, 9826, 'Big Bang A Teoria [L] S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/265776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQ2Sa0JlkjR7QMnxGZkNQxjz8PI.jpg'),
(138080, 9826, 'Big Bang A Teoria [L] S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/265777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wufZnQDjcK86JqSAcnR1Xowv2KU.jpg'),
(138081, 9826, 'Big Bang A Teoria [L] S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/265778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gqjU1LjuTzWmQqLp3XCjQ4zhyUX.jpg'),
(138082, 9826, 'Big Bang A Teoria [L] S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/265779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mTOX0QJ4S4XJZRTLgNv7ph1H2Cl.jpg'),
(138083, 9826, 'Big Bang A Teoria [L] S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/265780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhcQnZ5ZsDlVBHePHnJwYjs3xWt.jpg'),
(138084, 9826, 'Big Bang A Teoria [L] S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/265781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zPV7LQqkOR2F479tBCTHvE8oiVR.jpg'),
(138085, 9827, 'Big Bang A Teoria [L] S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eiknk78qNy9yYtmwjBZYLURhR19.jpg'),
(138086, 9827, 'Big Bang A Teoria [L] S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gzDRKQVGyX4FTKv51CWFqVc34TG.jpg'),
(138087, 9827, 'Big Bang A Teoria [L] S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eHuRYLXpxZATwCJrqubQelPEjHs.jpg'),
(138088, 9827, 'Big Bang A Teoria [L] S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fxyeZcehNMkV7o8qtuv2tMzI2pn.jpg'),
(138089, 9827, 'Big Bang A Teoria [L] S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hlJaHgvB4vOD5YVX0AXS9B2V0HG.jpg'),
(138090, 9827, 'Big Bang A Teoria [L] S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nh5DYUzf3waIHJAO7Ircv7MnMHj.jpg'),
(138091, 9827, 'Big Bang A Teoria [L] S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/34TSv9Gzanl0bnbeAiVBgQ7nAZl.jpg'),
(138092, 9827, 'Big Bang A Teoria [L] S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4j2EMbHRVvimywvBwZQ5q7O3wOS.jpg'),
(138093, 9827, 'Big Bang A Teoria [L] S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ywnhAABDYKUpdxfn9vz1oH4zBee.jpg'),
(138094, 9827, 'Big Bang A Teoria [L] S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24ShQB4KKIoBy0jIy9pdYt7GnPE.jpg'),
(138095, 9827, 'Big Bang A Teoria [L] S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r9WIq3OcYVeBxTEzCKgB4lGOEhd.jpg'),
(138096, 9827, 'Big Bang A Teoria [L] S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDT0ktiJ5h7N2LoH4PD7YERuMyp.jpg'),
(138097, 9827, 'Big Bang A Teoria [L] S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nQB2Pa1TXKQjSR4coCDRmox9UoE.jpg'),
(138098, 9827, 'Big Bang A Teoria [L] S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kRpSOJmWA0ek6Qyua4pn3zYEvfr.jpg'),
(138099, 9827, 'Big Bang A Teoria [L] S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uDHVXadIwiUvYENRrzFyCJoSjFw.jpg'),
(138100, 9827, 'Big Bang A Teoria [L] S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qfmckms5xxLtjwCbyWCQa5G2gu6.jpg'),
(138101, 9827, 'Big Bang A Teoria [L] S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Jh4pXXaagHSb9Ap40rQBDefRFl.jpg'),
(138102, 9827, 'Big Bang A Teoria [L] S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/265799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qRNOiaPWO6m5gR5STlrGjSSS0Cv.jpg'),
(138103, 9827, 'Big Bang A Teoria [L] S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/265800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6O7dxVBPOFKp2cdfFIl5Lf0mys2.jpg'),
(138104, 9827, 'Big Bang A Teoria [L] S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/265801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1VqKU1CVOkLDRoYnognbKuXTlBn.jpg'),
(138105, 9827, 'Big Bang A Teoria [L] S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/265802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ApopO3nNzWkFgE7ATs1jMOOaAzF.jpg'),
(138106, 9827, 'Big Bang A Teoria [L] S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/265803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/54TfSCfz5kMrQH81oppiCT6dqZl.jpg'),
(138107, 9827, 'Big Bang A Teoria [L] S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/265804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHVsK60TKWghadrtZ2G9MEsqIWd.jpg'),
(138108, 9827, 'Big Bang A Teoria [L] S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/265805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qhmAkhpkWpZnOPzTFbNfuvgot09.jpg'),
(138109, 9828, 'Big Bang A Teoria [L] S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/za6BAvh7hGFooEcANqJC5srF1FA.jpg'),
(138110, 9828, 'Big Bang A Teoria [L] S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n0uM0N3qz0kp51ad2lPajyt9Rhm.jpg'),
(138111, 9828, 'Big Bang A Teoria [L] S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kgCQZJjHWx4nCyjij5cgwnyi7nK.jpg'),
(138112, 9828, 'Big Bang A Teoria [L] S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bvJvnDJRTxJKa0Z2UoZIYDclEdA.jpg'),
(138113, 9828, 'Big Bang A Teoria [L] S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eDOUvJIpKqK276AfbdnzrBC2XJR.jpg'),
(138114, 9828, 'Big Bang A Teoria [L] S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tqZH3yGasgJiW9WEuq7AG019Jot.jpg'),
(138115, 9828, 'Big Bang A Teoria [L] S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4MNxa2TmPwUlU8GYgHGfIkMNmkq.jpg'),
(138116, 9828, 'Big Bang A Teoria [L] S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2kduB25FNPL7V8uuTIdGbT9vaO.jpg'),
(138117, 9828, 'Big Bang A Teoria [L] S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uYdqPZZGn6bsJMl9ib8NmPlin9z.jpg'),
(138118, 9828, 'Big Bang A Teoria [L] S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hrvQM75S6sCQDW5PKuadSDkyaBz.jpg'),
(138119, 9828, 'Big Bang A Teoria [L] S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cBuocsZkWGrIUZgjpBMRJpy94Kv.jpg'),
(138120, 9828, 'Big Bang A Teoria [L] S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4DnDFLbjiljaQuK2u7gv8ZP56lB.jpg'),
(138121, 9828, 'Big Bang A Teoria [L] S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ge9x2mL8kKRlAuaULVy5cNS1t98.jpg'),
(138122, 9828, 'Big Bang A Teoria [L] S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e4KZVnhg3UyZSAZIB6d3m38ToJz.jpg'),
(138123, 9828, 'Big Bang A Teoria [L] S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w93H4gv8LIb9nlITuGpR9ndDUk8.jpg'),
(138124, 9828, 'Big Bang A Teoria [L] S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cybOS60LRof6PljKrYXAyCh8637.jpg'),
(138125, 9828, 'Big Bang A Teoria [L] S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aCCxCIQjlFmlS97jCIzd2uameQl.jpg'),
(138126, 9828, 'Big Bang A Teoria [L] S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/265823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jUOKCbKMhg2jEarqXnuy0rdcLXO.jpg'),
(138127, 9828, 'Big Bang A Teoria [L] S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/265824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kl5SoKzqxhwK9irTvarRHOmTvi6.jpg'),
(138128, 9828, 'Big Bang A Teoria [L] S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/265825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eL2nmkRYtWcvXUVfx4SQGJeDULl.jpg'),
(138129, 9828, 'Big Bang A Teoria [L] S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/265826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/layOKctrtjUcwKZ1ofk1vuF65L5.jpg'),
(138130, 9828, 'Big Bang A Teoria [L] S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/265827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lUwn0Uxldc3B76B26Yd8aIPj4uM.jpg'),
(138131, 9828, 'Big Bang A Teoria [L] S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/265828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFmeHdgLoNVyRYv4omvrSoe9yLO.jpg'),
(138132, 9828, 'Big Bang A Teoria [L] S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/265829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/18nmVxxyu7jlKxqwn088P2hkQ4J.jpg'),
(138133, 9829, 'Big Bang A Teoria [L] S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9DPH88iL7f0GEFq8BggmOc6L0vk.jpg'),
(138134, 9829, 'Big Bang A Teoria [L] S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/chN747cMwRMuxm1JL1YKsKOsu9O.jpg'),
(138135, 9829, 'Big Bang A Teoria [L] S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sPTHeziA20nRw3NqA9j8FchsVdS.jpg'),
(138136, 9829, 'Big Bang A Teoria [L] S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dUEDKR7xxWcmGeKtfqI7e9fyQAw.jpg'),
(138137, 9829, 'Big Bang A Teoria [L] S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sXpnjSU96ED3yYVrm9BqYhgf4eG.jpg'),
(138138, 9829, 'Big Bang A Teoria [L] S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yEDSHVRQiHtIWQ3fcLutr2CSgVC.jpg'),
(138139, 9829, 'Big Bang A Teoria [L] S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kj7XGHGwP2rAr9SZQl0361rc1Q8.jpg'),
(138140, 9829, 'Big Bang A Teoria [L] S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/txfP3RGQrH975I1mVohAUOxYkjh.jpg'),
(138141, 9829, 'Big Bang A Teoria [L] S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lkrG22IN1cDzQUik3DSE0Gizkro.jpg'),
(138142, 9829, 'Big Bang A Teoria [L] S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gdmbxOWVmc35uryPjQdGeIFYhbU.jpg'),
(138143, 9829, 'Big Bang A Teoria [L] S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3FkVpR8xDoXlJ4E07JpwkTknaWK.jpg'),
(138144, 9829, 'Big Bang A Teoria [L] S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e0nr2JM5ZgLXtJejueg1uTIti6H.jpg'),
(138145, 9829, 'Big Bang A Teoria [L] S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yik9SnRIwGbJcbLKDdN64z796rl.jpg'),
(138146, 9829, 'Big Bang A Teoria [L] S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Dx0gT8VsA9iC9migoWFiepWMQf.jpg'),
(138147, 9829, 'Big Bang A Teoria [L] S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTNAUYH3FVQjdljPhsKWryYYjWW.jpg'),
(138148, 9829, 'Big Bang A Teoria [L] S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vu8eDZ7MiefrZxX2OhFbda6noB2.jpg'),
(138149, 9829, 'Big Bang A Teoria [L] S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wv69h7bKeHblo3taVkPhHLnCxk4.jpg'),
(138150, 9829, 'Big Bang A Teoria [L] S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/265847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4iPNBT5dpaBzRrylQPx6j7dI3nT.jpg'),
(138151, 9829, 'Big Bang A Teoria [L] S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/265848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/XqD2Q7kM5lrTjDRwkKK7s3OzGz.jpg'),
(138152, 9829, 'Big Bang A Teoria [L] S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/265849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJJ7LLPDRHUQYVaeaxXSrdmWt34.jpg'),
(138153, 9829, 'Big Bang A Teoria [L] S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/265850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYnc1Ypn8Cdbme8hpe13RLEB0Ud.jpg'),
(138154, 9829, 'Big Bang A Teoria [L] S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/265851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dvyGCnhsCDaMTQl8fLW9hu343iB.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(138155, 9829, 'Big Bang A Teoria [L] S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/265852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1iG6nwkQb75R8zxsypJL5xVqpxy.jpg'),
(138156, 9829, 'Big Bang A Teoria [L] S10 E24', 'http://sinalprivado.info:80/series/1533784/1533784/265853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zz9pvqUVLq9OWoei50kYXfVXccH.jpg'),
(138157, 9830, 'Big Bang A Teoria [L] S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oBOVgg2gIryBkWg2XtSr0svsO3a.jpg'),
(138158, 9830, 'Big Bang A Teoria [L] S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c82DYxLLoxwPKWQ0Evgmtphmleq.jpg'),
(138159, 9830, 'Big Bang A Teoria [L] S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mycjsvb91uw1WG6zqld9DEozlAB.jpg'),
(138160, 9830, 'Big Bang A Teoria [L] S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zNPtqkWh19br721s6IBwLOaoe22.jpg'),
(138161, 9830, 'Big Bang A Teoria [L] S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jHDHHiJbPIjJLPTpD31pAFgKhXc.jpg'),
(138162, 9830, 'Big Bang A Teoria [L] S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/57CoA3eyykJU9q0dkOcJ1WkZaKV.jpg'),
(138163, 9830, 'Big Bang A Teoria [L] S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lM1VwTSFT5IOLqfHBcImibCNDcR.jpg'),
(138164, 9830, 'Big Bang A Teoria [L] S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dbQX2a99jcPa1pG9mSIM2D8Wx9u.jpg'),
(138165, 9830, 'Big Bang A Teoria [L] S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sUeYryl4noJ1ZeoygZki5mVSEAF.jpg'),
(138166, 9830, 'Big Bang A Teoria [L] S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/661iWFo3pdIjCRN8iqHTF5UPmNe.jpg'),
(138167, 9830, 'Big Bang A Teoria [L] S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pax2p8RTOa1cyOy8RdYBLLvBQcU.jpg'),
(138168, 9830, 'Big Bang A Teoria [L] S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ak6A2V7tiXV5hU0UIRNupFUyThz.jpg'),
(138169, 9830, 'Big Bang A Teoria [L] S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/twXUFhbnn9xuoBwzwHZzyi6qAtk.jpg'),
(138170, 9830, 'Big Bang A Teoria [L] S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aKGQFSnqc5r9mWCUcRjWYi5SiWc.jpg'),
(138171, 9830, 'Big Bang A Teoria [L] S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AnGIz9QR5vd1BvfaLKIavRYVdAx.jpg'),
(138172, 9830, 'Big Bang A Teoria [L] S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y8cPPUKibxpbGlo9feqkWHae4Gk.jpg'),
(138173, 9830, 'Big Bang A Teoria [L] S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zDdcH0sQ3cRXbXolXrXpBcRBIv.jpg'),
(138174, 9830, 'Big Bang A Teoria [L] S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/265871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eXK5rWsLFCznTnclbcKlhtVYd6Z.jpg'),
(138175, 9830, 'Big Bang A Teoria [L] S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/265872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/noQkLOIcY439DTVA1mcqi07B2SW.jpg'),
(138176, 9830, 'Big Bang A Teoria [L] S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/265873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4onNHSndrG9u2DrkFI3Bw5ZEicl.jpg'),
(138177, 9830, 'Big Bang A Teoria [L] S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/265874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bRcRtDtinAA0q4OEGq68VF6GyQz.jpg'),
(138178, 9830, 'Big Bang A Teoria [L] S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/265875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bh6HEOeXk2hCrpt31wudk0wXGJu.jpg'),
(138179, 9830, 'Big Bang A Teoria [L] S11 E23', 'http://sinalprivado.info:80/series/1533784/1533784/265876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6wr77OIGHkAPK57HMpALaejKaS.jpg'),
(138180, 9830, 'Big Bang A Teoria [L] S11 E24', 'http://sinalprivado.info:80/series/1533784/1533784/265877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gOhiFetvZtTMD9lvyeqmxeDedso.jpg'),
(138181, 9831, 'Big Bang A Teoria [L] S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tH6udsYfheFElUCMtc10PoxzhHH.jpg'),
(138182, 9831, 'Big Bang A Teoria [L] S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6dkPSJozX9LPiNpv1nUfPSkCCZy.jpg'),
(138183, 9831, 'Big Bang A Teoria [L] S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l44ODD3iKdq06UT3MwVb5eAfgtl.jpg'),
(138184, 9831, 'Big Bang A Teoria [L] S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/llMnVr3aHN87ehC7NjFoXrZJC6u.jpg'),
(138185, 9831, 'Big Bang A Teoria [L] S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uXk8oplxCvrXnMDillhjPdjAz1c.jpg'),
(138186, 9831, 'Big Bang A Teoria [L] S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xo7XJKGKLBcymivyVeRawWDDHtP.jpg'),
(138187, 9831, 'Big Bang A Teoria [L] S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/14abiXaAjOnkYMke8WOPYfJb2Ud.jpg'),
(138188, 9831, 'Big Bang A Teoria [L] S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u2Fvvq2DwjnmgCLXM3XKpZHtJUQ.jpg'),
(138189, 9831, 'Big Bang A Teoria [L] S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7QzKWzJZ5nhRIHy8ffYRAHsSDb.jpg'),
(138190, 9831, 'Big Bang A Teoria [L] S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ifZjvUR7qrzRFeMidPv3WQIPX0n.jpg'),
(138191, 9831, 'Big Bang A Teoria [L] S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g9aR3enICwN7QF3RZ8KTgKVhvi3.jpg'),
(138192, 9831, 'Big Bang A Teoria [L] S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yk9ngrWh99IferzYCzkzgmV4Y8H.jpg'),
(138193, 9831, 'Big Bang A Teoria [L] S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ikoSMAv9hEQHnk3dEg3qerNxsso.jpg'),
(138194, 9831, 'Big Bang A Teoria [L] S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6A3l7dDqA9nA94pZNzJ8Fsv3Bp4.jpg'),
(138195, 9831, 'Big Bang A Teoria [L] S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ZKXKQvrlWTyjEe6VYjpsHaaOZa.jpg'),
(138196, 9831, 'Big Bang A Teoria [L] S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v9o9lIGgrKn3CVC3VqjXsOxiDBu.jpg'),
(138197, 9831, 'Big Bang A Teoria [L] S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ibeFZjHPpdLLCsM9Ul4QZGU5Bns.jpg'),
(138198, 9831, 'Big Bang A Teoria [L] S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/265895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNLmPBFzi9nGTtBsaQJNnbsDrwx.jpg'),
(138199, 9831, 'Big Bang A Teoria [L] S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/265896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hX1cQjB1uoCEBveWwx7ArPX2GKB.jpg'),
(138200, 9831, 'Big Bang A Teoria [L] S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/265897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6EwGVgvBRPX6huHhj80whNK3aXD.jpg'),
(138201, 9831, 'Big Bang A Teoria [L] S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/265898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Adw0tiCkOOBfQv0DGcxgopuWpYJ.jpg'),
(138202, 9831, 'Big Bang A Teoria [L] S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/265899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/swB9SAr1YhSPq6MuJTrtLEfhUVf.jpg'),
(138203, 9831, 'Big Bang A Teoria [L] S12 E23', 'http://sinalprivado.info:80/series/1533784/1533784/265900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x422znm59wC6RnRFH8nUxVfbsH2.jpg'),
(138204, 9832, 'Battlestar Galactica [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zaS8EV6tUsdM7HVurUIKz6Ypz03.jpg'),
(138205, 9832, 'Battlestar Galactica [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/drzZmV3fRa9meIUhIY6IKfZwfD8.jpg'),
(138206, 9832, 'Battlestar Galactica [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ywLke5tjeaHbA45inoz9OmpYe8c.jpg'),
(138207, 9832, 'Battlestar Galactica [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jW6ZI0GnmzprqyV4oQMuMFKApdC.jpg'),
(138208, 9832, 'Battlestar Galactica [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n4ypvV4KZ8qksB5ONf5bPvS2c4a.jpg'),
(138209, 9832, 'Battlestar Galactica [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rPll3uIzpocuS5SKl8aeWKY6l7h.jpg'),
(138210, 9832, 'Battlestar Galactica [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n5tSyPEJ8RAyES8WHKI5WeSRspG.jpg'),
(138211, 9832, 'Battlestar Galactica [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8AsTsntFjyTYvx508NeRCbsHIfF.jpg'),
(138212, 9832, 'Battlestar Galactica [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ca7HjJuhbecgGL2Oqe4inoeEMWT.jpg'),
(138213, 9832, 'Battlestar Galactica [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4hc4dSiynmFNrBYRZZU4ZO29zef.jpg'),
(138214, 9832, 'Battlestar Galactica [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fLsnxZVqTYsjMPW48FFLNzyKWGg.jpg'),
(138215, 9832, 'Battlestar Galactica [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a8YRuR1qOm8ANHAwzFba7UiS5F9.jpg'),
(138216, 9832, 'Battlestar Galactica [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tGjlO5GoD8U9ALFVtpYQLxcDD2e.jpg'),
(138217, 9833, 'Battlestar Galactica [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vQttLi1KPXju9FICRfN0mr0LQL8.jpg'),
(138218, 9833, 'Battlestar Galactica [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5If0bjF4iYFP96rIfMWrddLfxH8.jpg'),
(138219, 9833, 'Battlestar Galactica [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nLFYUqAFa6YP4v1hXAi6gBsbgZv.jpg'),
(138220, 9833, 'Battlestar Galactica [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmVLMofTPozkoGc8C9mCRGlNvFU.jpg'),
(138221, 9833, 'Battlestar Galactica [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vz2cBjXZGjIlTwgVlGnHW05jY1Y.jpg'),
(138222, 9833, 'Battlestar Galactica [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/CqrI2Rj3gyNbhFjtvOi3vOtq0b.jpg'),
(138223, 9833, 'Battlestar Galactica [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLJAt911PzhcQIKNqHeLkXL42yl.jpg'),
(138224, 9833, 'Battlestar Galactica [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/peHONCLj52l4oY6Ey0lekcZ7cDg.jpg'),
(138225, 9833, 'Battlestar Galactica [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7LrozItqxmQqeM1VS2jU4J9sV4I.jpg'),
(138226, 9833, 'Battlestar Galactica [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/orEwvT6DpH2SgBtuS7vnAzYzYel.jpg'),
(138227, 9833, 'Battlestar Galactica [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vR0JLjTCM5P4n69w0OyWJzhj3BZ.jpg'),
(138228, 9833, 'Battlestar Galactica [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/djRPC6FE8QUQheXVa3KfjkDBVTs.jpg'),
(138229, 9833, 'Battlestar Galactica [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1L3C6KCfVt2PSzz0xqkJ4fWbpY3.jpg'),
(138230, 9833, 'Battlestar Galactica [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y3N7sRtPMofKzHxRsVJpVJS3d6m.jpg'),
(138231, 9833, 'Battlestar Galactica [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5JZL9jYdOjLZOmebKybZr4ZzRxt.jpg'),
(138232, 9833, 'Battlestar Galactica [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qsafRWRSzoEqDTN3pDyAMPqMe5F.jpg'),
(138233, 9833, 'Battlestar Galactica [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ku72FVmj6HP0F8mjICRkp75YbHV.jpg'),
(138234, 9833, 'Battlestar Galactica [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/265582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1cNQHWZ8I8jDa8WRh9ejixx7rqU.jpg'),
(138235, 9833, 'Battlestar Galactica [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/265583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6t80RHtwo4PumNUkeoMiXqHtfxZ.jpg'),
(138236, 9833, 'Battlestar Galactica [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/265584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kv8UGskDcRBOKzaZpBTNTUD2FWd.jpg'),
(138237, 9834, 'Battlestar Galactica [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zuW7ejuxPJmVIUmtB5E7gjehXhw.jpg'),
(138238, 9834, 'Battlestar Galactica [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f3uCFJDeyi3uq5SUWG6mVjX7ByR.jpg'),
(138239, 9834, 'Battlestar Galactica [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lan8sfYrRxbjG7ZfYansuliZxG7.jpg'),
(138240, 9834, 'Battlestar Galactica [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBzoFRdGYVnoHzNrExmweKSKTY4.jpg'),
(138241, 9834, 'Battlestar Galactica [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vYOF6jr744uTJo2P1JZ6naLXg5W.jpg'),
(138242, 9834, 'Battlestar Galactica [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q2WX6YmLe89UOdLjpHwVgmwckHH.jpg'),
(138243, 9834, 'Battlestar Galactica [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8e7JQBUZso9PLvh7JP9THSovlS7.jpg'),
(138244, 9834, 'Battlestar Galactica [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lFPGQtFu1pp1CCytAHy4V4YyhtP.jpg'),
(138245, 9834, 'Battlestar Galactica [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dEgHRsKp8KffT5jXzR78mNWhB2v.jpg'),
(138246, 9834, 'Battlestar Galactica [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2tyVBTOAuYroQx55QHNJr4ZxYLz.jpg'),
(138247, 9834, 'Battlestar Galactica [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvh2zgnDP4lStnB1S2812iVn84D.jpg'),
(138248, 9834, 'Battlestar Galactica [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f1Llg4aepiro1WPi0EybRbuDZaV.jpg'),
(138249, 9834, 'Battlestar Galactica [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ui4PSkbScb61s9KVSSfEwB5agJN.jpg'),
(138250, 9834, 'Battlestar Galactica [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4gzzjCyeWexIS7bJdaToTr6OJck.jpg'),
(138251, 9834, 'Battlestar Galactica [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xO1ThE3SFnivExDDN15qafgcrV5.jpg'),
(138252, 9834, 'Battlestar Galactica [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/up7jZHwmpSFPF2ljmSJHFchVEFi.jpg'),
(138253, 9834, 'Battlestar Galactica [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jFhzhkqiQsac1aJdhndZMimrq9Z.jpg'),
(138254, 9834, 'Battlestar Galactica [L] S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/265602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bYXJzel7wjX9LP3juybiaNM5LST.jpg'),
(138255, 9834, 'Battlestar Galactica [L] S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/265603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odbUggiG9dBwcx4LhEk3MVIN78l.jpg'),
(138256, 9835, 'Battlestar Galactica [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tycc0si6hFwZB6zXl6BLhUlG3dV.jpg'),
(138257, 9835, 'Battlestar Galactica [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUzvMuhsf349qjT7k1x9apmAV6P.jpg'),
(138258, 9835, 'Battlestar Galactica [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cwdi3gtLlETWbPY9jizrqcHcgnE.jpg'),
(138259, 9835, 'Battlestar Galactica [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJBwyNSk19vUk9zvFmpJDnlfPyH.jpg'),
(138260, 9835, 'Battlestar Galactica [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6CJLDslwiap6ucJ7OHdhCwnUUoH.jpg'),
(138261, 9835, 'Battlestar Galactica [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4MZHKE6cCX6o2LqV5NDNKLetW1p.jpg'),
(138262, 9835, 'Battlestar Galactica [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jcGOojEe18P4nq1g78PbQuvp9ym.jpg'),
(138263, 9835, 'Battlestar Galactica [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5mopODAJ5TLP1RlxtGiW3UwmSBS.jpg'),
(138264, 9835, 'Battlestar Galactica [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9GpIJvaziZPdMy1BOYI7gIe4hzU.jpg'),
(138265, 9835, 'Battlestar Galactica [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s6fuTvDiAIJzP31RYuaTKETdLo.jpg'),
(138266, 9835, 'Battlestar Galactica [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bd2QYUaTpRIPR5xu00WQCsDib25.jpg'),
(138267, 9835, 'Battlestar Galactica [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyLvRgwljAKFh2SfR0opE3Rfcms.jpg'),
(138268, 9835, 'Battlestar Galactica [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fRjEAJl5jNYtZJW5JrTaBmGFBes.jpg'),
(138269, 9835, 'Battlestar Galactica [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rjQwjUxLfMpdcNX1acMUyQ1rv5j.jpg'),
(138270, 9835, 'Battlestar Galactica [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mF6quZjTzd3rwozlrI4yPT3cbgo.jpg'),
(138271, 9835, 'Battlestar Galactica [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oA7y1ouXOmJKLcDSZGyUPoKIovJ.jpg'),
(138272, 9835, 'Battlestar Galactica [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9OP9pxSXPXbyGptx5hNrjwNTRdt.jpg'),
(138273, 9835, 'Battlestar Galactica [L] S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/265621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8kfJTvkPbMl6OqSPLCi8aqF1zFH.jpg'),
(138274, 9835, 'Battlestar Galactica [L] S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/265622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/99PJSbcO2LeM10uOGWeFihNp77j.jpg'),
(138275, 9836, 'Sr. e Sra. Smith S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/brecJ9G1rcXsk5BT94sdLReMyrr.jpg'),
(138276, 9836, 'Sr. e Sra. Smith S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/od0Td6tCPOVbON1XoBOjQ2tMXI0.jpg'),
(138277, 9836, 'Sr. e Sra. Smith S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hk5D2lLfjCxKC8P4ramPYp7ZRP1.jpg'),
(138278, 9836, 'Sr. e Sra. Smith S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7X55dEBF6DRUpoUkp8Ifrc7G17S.jpg'),
(138279, 9836, 'Sr. e Sra. Smith S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jiMKFIOPGk9KZZMRmpKEpjWEzn3.jpg'),
(138280, 9836, 'Sr. e Sra. Smith S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8VClVpZ3jwj1buFBP8jJvvvcswl.jpg'),
(138281, 9836, 'Sr. e Sra. Smith S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5rHaexHUYBhrtykm4zpNwuD7xHY.jpg'),
(138282, 9836, 'Sr. e Sra. Smith S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oyXkzq70tuXZCWDDza1RcwTxKj.jpg'),
(138283, 9837, 'Kyle XY S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yyU1bdOO0qx3NMkPbdzDUP9F93Y.jpg'),
(138284, 9837, 'Kyle XY S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nbWQRUl2WBesUtFxKL2q9pVJvKd.jpg'),
(138285, 9837, 'Kyle XY S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/scVEWHEv1IYAa5vWiUrVuVucwxM.jpg'),
(138286, 9837, 'Kyle XY S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzUofYHuDEnjRLr2TpUPeVIQTXZ.jpg'),
(138287, 9837, 'Kyle XY S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gdRUKt4ypOcuIEljrqoiNDDTmh7.jpg'),
(138288, 9837, 'Kyle XY S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u3nzL88aibr4K6CBQPmkDutWIJD.jpg'),
(138289, 9837, 'Kyle XY S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9cXryjLtVM5pyDHT3r2lI84SyLz.jpg'),
(138290, 9837, 'Kyle XY S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2zDG35OQf9Y3Bkzx28zXl9wuCm.jpg'),
(138291, 9837, 'Kyle XY S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3M5HMSa3mvDTC9iAIHS057b3xOr.jpg'),
(138292, 9837, 'Kyle XY S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOesK5xZXaEhqK3R56wCKNRBwQ6.jpg'),
(138293, 9838, 'Kyle XY S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ZsAQjZ2JcWVyEREtOkulGiUQjo.jpg'),
(138294, 9838, 'Kyle XY S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qoW4cqLW8yhnBj1Ca4UmgRzA4ks.jpg'),
(138295, 9838, 'Kyle XY S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6wncCFurYVUOIxDn0lr8rEyd4Cd.jpg'),
(138296, 9838, 'Kyle XY S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/91Oir1MiLxiE3MIxxs2Dc5khUj4.jpg'),
(138297, 9838, 'Kyle XY S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUVL1gWQE8aJOpsraUbz9Z6xrmj.jpg'),
(138298, 9838, 'Kyle XY S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sbnlHltzGQrITSkshpIN3durKea.jpg'),
(138299, 9838, 'Kyle XY S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8oqaGq0jYdD8U14AP4jOMM7xXHQ.jpg'),
(138300, 9838, 'Kyle XY S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mQCz98LQ9GzB8gto0JLkCueTwHO.jpg'),
(138301, 9838, 'Kyle XY S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bn77tHNtgUyndXqfWz9Boi0OY4e.jpg'),
(138302, 9838, 'Kyle XY S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ejiLmJEOTgsCI9OcttqM0MiAIfU.jpg'),
(138303, 9838, 'Kyle XY S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/265252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzbpBaYzBuYjale5lj09ruLuwj7.jpg'),
(138304, 9838, 'Kyle XY S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/265253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AsFJgmNfJdAxxGe09NrlScvZyi5.jpg'),
(138305, 9838, 'Kyle XY S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/265254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnoN6my5gv95Dd9YcoReKjbRiKO.jpg'),
(138306, 9838, 'Kyle XY S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/265255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oj74M5EhSVhI3UbbGMjuX42itBc.jpg'),
(138307, 9838, 'Kyle XY S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/265256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2n1cmfktTWBknbA1fzwCdaPlSN.jpg'),
(138308, 9838, 'Kyle XY S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/265257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r6qJ2G0Ey4q4WWMQvtqNx4dNH7B.jpg'),
(138309, 9838, 'Kyle XY S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/265258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bcm5rXrr9SMfVOMGNLuPVu3ONhP.jpg'),
(138310, 9838, 'Kyle XY S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/265259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kssJbuPoJbg5crnXPnmOVqfoWTz.jpg'),
(138311, 9838, 'Kyle XY S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/265260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/264I2OZoKoYaHvDIECGQwQuYFf0.jpg'),
(138312, 9838, 'Kyle XY S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/265261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z6DIFCpzmBKEWghmGBt3cdkXQA5.jpg'),
(138313, 9838, 'Kyle XY S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/265262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ujJFiUVesR1CeEEuoE08NVpeWJR.jpg'),
(138314, 9838, 'Kyle XY S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/265263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iNQsGIx7IvZ68iuD50Ui5zrSrPS.jpg'),
(138315, 9838, 'Kyle XY S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/265264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/twA6U284LJ44SLy8J1A7lWkGQSM.jpg'),
(138316, 9839, 'Kyle XY S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/265265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vMtpnpkUGW4Z3Kf9bnqPY23GuL.jpg'),
(138317, 9839, 'Kyle XY S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/265266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ewMaVMEnCLIYIB1oUvfjsHcexgi.jpg'),
(138318, 9839, 'Kyle XY S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/265267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtzSkp8CV36A0xOhclQNKgD2RvY.jpg'),
(138319, 9839, 'Kyle XY S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/265268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dRjgIKBSRtuFCrq5FxJiIsXZz4c.jpg'),
(138320, 9839, 'Kyle XY S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/265269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yyUF6p4G9f1pqLOiBG3nT1TwgM5.jpg'),
(138321, 9839, 'Kyle XY S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/265270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/42fRbjwBKF6BTUTLggMBFuO6phu.jpg'),
(138322, 9839, 'Kyle XY S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/265271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/864CEMoabQqB0bzqglJ73JdKPVS.jpg'),
(138323, 9839, 'Kyle XY S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/265272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ael4aLT0qzeJ8tOgbqZbathjiIf.jpg'),
(138324, 9839, 'Kyle XY S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/265273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eHtFhjCFKllD6vPyYk5Fi4WkxTI.jpg'),
(138325, 9839, 'Kyle XY S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/265274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oc9ljEdBU8uklPRCuXPFg6omQK1.jpg'),
(138326, 9840, 'Smallville As Aventuras do Superboy [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n798Lp6UuVy99fVoI4gSazxebHt.jpg'),
(138327, 9840, 'Smallville As Aventuras do Superboy [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e9Vfgl5oUeSnx5z4m7uTlfzTCmW.jpg'),
(138328, 9840, 'Smallville As Aventuras do Superboy [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gieenixNjvQzQxEQQRblIgS9znX.jpg'),
(138329, 9840, 'Smallville As Aventuras do Superboy [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pUcfmdDWa5YgywzeiAZMW1y3a7j.jpg'),
(138330, 9840, 'Smallville As Aventuras do Superboy [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/47hiZkQKYOPCCi9F4bN3OTT7K7y.jpg'),
(138331, 9840, 'Smallville As Aventuras do Superboy [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4EMav7jZIMnYO4fM87PmTzVZb4q.jpg'),
(138332, 9840, 'Smallville As Aventuras do Superboy [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/785UseKOE3fTNqsia6IRUwARAc3.jpg'),
(138333, 9840, 'Smallville As Aventuras do Superboy [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ylf4LDYAHy2JkQPQbEnH8xLcaqw.jpg'),
(138334, 9840, 'Smallville As Aventuras do Superboy [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/og5FIxtqBsgu7hUgpen7T4zj25j.jpg'),
(138335, 9840, 'Smallville As Aventuras do Superboy [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8OprUAuMqvpcIYuaOQRBeY9tfcG.jpg'),
(138336, 9840, 'Smallville As Aventuras do Superboy [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8XjPXIzhiHbUH6lNRdsmMCiGNOA.jpg'),
(138337, 9840, 'Smallville As Aventuras do Superboy [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1UHmwuLZylLPNItojK6ODSoFsbM.jpg'),
(138338, 9840, 'Smallville As Aventuras do Superboy [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w7F5rqcGfBgB0a6EVRjzeXOPVOj.jpg'),
(138339, 9840, 'Smallville As Aventuras do Superboy [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aC2sFxAkrjvnWRDSKrsixQfoIVe.jpg'),
(138340, 9840, 'Smallville As Aventuras do Superboy [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/268717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zeSy5hjENExq7du00Dx6HpnQ6rv.jpg'),
(138341, 9840, 'Smallville As Aventuras do Superboy [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/268718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lvKMLWOmXxjQNMqotaFdyR3HYRv.jpg'),
(138342, 9840, 'Smallville As Aventuras do Superboy [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/268719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hP7heIF40ehxhowZyORkm67QM4d.jpg'),
(138343, 9840, 'Smallville As Aventuras do Superboy [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/268720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Yz62dswA06KdkLHyhLbAszhU9X.jpg'),
(138344, 9840, 'Smallville As Aventuras do Superboy [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/268721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7sE4lnHew1dhBpvCRxFPzjNfAJ6.jpg'),
(138345, 9840, 'Smallville As Aventuras do Superboy [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/268722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4wcm7vY2UpACDjEM6irw7NgU9zN.jpg'),
(138346, 9840, 'Smallville As Aventuras do Superboy [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/268723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/efIwNsN4bV8zMJeI6h0X0nBd3PZ.jpg'),
(138347, 9841, 'Smallville As Aventuras do Superboy [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xd1Sa262IbmQLN0pHq8YzfSrwvV.jpg'),
(138348, 9841, 'Smallville As Aventuras do Superboy [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d7eaniTwsqfqbqTW6KYeyJz1Ipr.jpg'),
(138349, 9841, 'Smallville As Aventuras do Superboy [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rvL6NrdMm8Z4YPtrfofWeDd1UZG.jpg'),
(138350, 9841, 'Smallville As Aventuras do Superboy [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3EOdconLaaebq2FevF5dFLOjPN6.jpg'),
(138351, 9841, 'Smallville As Aventuras do Superboy [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h25I4dW6W05M63ol8EPrvpmoCWD.jpg'),
(138352, 9841, 'Smallville As Aventuras do Superboy [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9bHwAQFriKZsHb2PQHayB9X59a6.jpg'),
(138353, 9841, 'Smallville As Aventuras do Superboy [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dcGug0g2gN18UWhMStNrbBeyhJR.jpg'),
(138354, 9841, 'Smallville As Aventuras do Superboy [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dSMUceIZ48hJWkG38Ujnc75wFFr.jpg'),
(138355, 9841, 'Smallville As Aventuras do Superboy [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zZKGlJVwdw0qm7cqCVfykMecUfq.jpg'),
(138356, 9841, 'Smallville As Aventuras do Superboy [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oBZhEko4XHWJIdDpQqhad1BqTDv.jpg'),
(138357, 9841, 'Smallville As Aventuras do Superboy [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4uiOALMbLldWGY7ktX6szZNCXLh.jpg'),
(138358, 9841, 'Smallville As Aventuras do Superboy [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pMhioyVw8FcfNc9L9sU6bqFASPM.jpg'),
(138359, 9841, 'Smallville As Aventuras do Superboy [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nhxsx8gzULQKDy87XFlqU9Io0x4.jpg'),
(138360, 9841, 'Smallville As Aventuras do Superboy [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hpbmzyDqms2Glu5YTC97IUhkm2Q.jpg'),
(138361, 9841, 'Smallville As Aventuras do Superboy [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/268738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xIwTT160OhgCLwEgFhSpmdd5afV.jpg'),
(138362, 9841, 'Smallville As Aventuras do Superboy [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/268739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iuHxPTzYvbJc4MjesxWEGk7alXi.jpg'),
(138363, 9841, 'Smallville As Aventuras do Superboy [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/268740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g56d3woWOeW5XUaK9yRD7qZLsnR.jpg'),
(138364, 9841, 'Smallville As Aventuras do Superboy [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/268741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pcGnWArGAIs2Z3v6KUE6NfK4akC.jpg'),
(138365, 9841, 'Smallville As Aventuras do Superboy [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/268742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AtouXtpShWJTAze56WwamvZahem.jpg'),
(138366, 9841, 'Smallville As Aventuras do Superboy [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/268743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mxqC25BFaqQAe4fJBvRVS1Eu1ba.jpg'),
(138367, 9841, 'Smallville As Aventuras do Superboy [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/268744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uOssv8dWs7gfaSdOQlfEoIOwL1B.jpg'),
(138368, 9841, 'Smallville As Aventuras do Superboy [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/268745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yc4g52aGkeSg9LFZ5jqBp07TLYf.jpg'),
(138369, 9842, 'Smallville As Aventuras do Superboy [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i79D7el58Q7ytVtWuJJQDp8AHKy.jpg'),
(138370, 9842, 'Smallville As Aventuras do Superboy [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3xBCrAykhOrA5tprfnbf9ILDcIJ.jpg'),
(138371, 9842, 'Smallville As Aventuras do Superboy [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rZJTTDZBfgjR8RCvnjA76ZgP1f.jpg'),
(138372, 9842, 'Smallville As Aventuras do Superboy [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/owBolOLItBFW9NGrLyd9TpY787C.jpg'),
(138373, 9842, 'Smallville As Aventuras do Superboy [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkn0rrOdfAGqBuvOnM7z4EBy6vk.jpg'),
(138374, 9842, 'Smallville As Aventuras do Superboy [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5jUkBrXdZa1o21UdCBZUY3IhiuF.jpg'),
(138375, 9842, 'Smallville As Aventuras do Superboy [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJmoixxTp4O7FEi2nLl6cl0vRYc.jpg'),
(138376, 9842, 'Smallville As Aventuras do Superboy [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qNU4vlSwrRUu5BJc2NhgBYWVuOm.jpg'),
(138377, 9842, 'Smallville As Aventuras do Superboy [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s2tuq3XDqTb3e4TghPccL2Hz8WL.jpg'),
(138378, 9842, 'Smallville As Aventuras do Superboy [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yK6uLAzUnIlHMjnmF4usOsPvHXT.jpg'),
(138379, 9842, 'Smallville As Aventuras do Superboy [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kaLFmBJs9McZrs3u7ayuVxJNrNF.jpg'),
(138380, 9842, 'Smallville As Aventuras do Superboy [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzObr6mlsG6DDBMsU6PzVwvwoIh.jpg'),
(138381, 9842, 'Smallville As Aventuras do Superboy [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tS0T8Cvk3gpBxutgpIYmpZs3BVO.jpg'),
(138382, 9842, 'Smallville As Aventuras do Superboy [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qhh6BAXp0Dd7BmCEOBnUPyXgrJ4.jpg'),
(138383, 9842, 'Smallville As Aventuras do Superboy [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/268760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lO5wYBpgtP6Bs9p1TopwtRzDQj1.jpg'),
(138384, 9842, 'Smallville As Aventuras do Superboy [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/268761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9ATzdYKws9NynDzMHyVwRX4EyK.jpg'),
(138385, 9842, 'Smallville As Aventuras do Superboy [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/268762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wszMaPugz0oISB60cvW1V3Fi8gc.jpg'),
(138386, 9842, 'Smallville As Aventuras do Superboy [L] S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/268763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rf2RDbgvRy99deBlDnhwRSIAokF.jpg'),
(138387, 9842, 'Smallville As Aventuras do Superboy [L] S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/268764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iQs1A4CwFQNpCu7cQPrgoJvjYrB.jpg'),
(138388, 9842, 'Smallville As Aventuras do Superboy [L] S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/268765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/53OGaA3qZboMGE73LtmetX1dLhM.jpg'),
(138389, 9842, 'Smallville As Aventuras do Superboy [L] S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/268766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h8tBdTWidSH4452BqhXtYQsxA2k.jpg'),
(138390, 9842, 'Smallville As Aventuras do Superboy [L] S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/268767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zFVOpndnLWcESIiASQwSSjMm4X9.jpg'),
(138391, 9843, 'Smallville As Aventuras do Superboy [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v8vrx435b40ci34GeVtEvHA1hnj.jpg'),
(138392, 9843, 'Smallville As Aventuras do Superboy [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bWLk9TwJDsyfn054O8QOfnYqGhJ.jpg'),
(138393, 9843, 'Smallville As Aventuras do Superboy [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gl9VlMMI5xQlz1Vt02E4CpATnpS.jpg'),
(138394, 9843, 'Smallville As Aventuras do Superboy [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z9xlDgHD5YViZQZVYA4YZMShvAp.jpg'),
(138395, 9843, 'Smallville As Aventuras do Superboy [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kEDtnhtR6ildo8pPjc3TSClpLOT.jpg'),
(138396, 9843, 'Smallville As Aventuras do Superboy [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cfmBdsV4AJgwgikmmRoWByIIJz3.jpg'),
(138397, 9843, 'Smallville As Aventuras do Superboy [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i5nUTb5InawJzBNbwcXUENeqCyz.jpg'),
(138398, 9843, 'Smallville As Aventuras do Superboy [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hOEbdvEriBgMC66pN3BXWj17LMd.jpg'),
(138399, 9843, 'Smallville As Aventuras do Superboy [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/NGc4bCOxG6ubTplQKgtStglM46.jpg'),
(138400, 9843, 'Smallville As Aventuras do Superboy [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/atoNwOLS5sODHJ1Sls5cqh6UGCs.jpg'),
(138401, 9843, 'Smallville As Aventuras do Superboy [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iHgvKngP4DTD8XcnPovts8XB5mM.jpg'),
(138402, 9843, 'Smallville As Aventuras do Superboy [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nl1bKpLDkkryIwrYxXy4cxu6f7g.jpg'),
(138403, 9843, 'Smallville As Aventuras do Superboy [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7hk8UATVXYIprI75rVS2KxzpDfA.jpg'),
(138404, 9843, 'Smallville As Aventuras do Superboy [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oWhFSYR1IrSbUJfkFmRSHWz89zv.jpg'),
(138405, 9843, 'Smallville As Aventuras do Superboy [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/268782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y1auMqqMRMffJbEA52ZCCfbhXnu.jpg'),
(138406, 9843, 'Smallville As Aventuras do Superboy [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/268783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4TIRVwvHBXvNE9StP9ODVS6wCvv.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(138407, 9843, 'Smallville As Aventuras do Superboy [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/268784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4eoJHx8sNVQjJeQw4uErdJ6ICrv.jpg'),
(138408, 9843, 'Smallville As Aventuras do Superboy [L] S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/268785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6zM2n8okmpKg2FWPtgLQCFdpXQ4.jpg'),
(138409, 9843, 'Smallville As Aventuras do Superboy [L] S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/268786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wcqA2pRWE6OWWLPGeC8sc2O01gb.jpg'),
(138410, 9843, 'Smallville As Aventuras do Superboy [L] S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/268787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1vv8p7LW65yBQrcMNjUUsmBfddl.jpg'),
(138411, 9843, 'Smallville As Aventuras do Superboy [L] S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/268788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oW2wApJr59JMjXG5UzX1eP2a2A1.jpg'),
(138412, 9843, 'Smallville As Aventuras do Superboy [L] S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/268789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfJatujpAwNGqzTyxAnjYMMquBD.jpg'),
(138413, 9844, 'Smallville As Aventuras do Superboy [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fpkE0EGG9JprSGKv2wPFb2hLQqj.jpg'),
(138414, 9844, 'Smallville As Aventuras do Superboy [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ntMrI2PjqTF8QidhiGAiTn6d5tm.jpg'),
(138415, 9844, 'Smallville As Aventuras do Superboy [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfdsLBmWjVXOZTwQcSj9lYSlaV2.jpg'),
(138416, 9844, 'Smallville As Aventuras do Superboy [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZWBz7ygNurPMUQClf6U3YZiogl.jpg'),
(138417, 9844, 'Smallville As Aventuras do Superboy [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qqtUsjCeCVs6pBbW9e3QAEfpezm.jpg'),
(138418, 9844, 'Smallville As Aventuras do Superboy [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rS7a7M1EiSnTDXxpm5OScG7l6a7.jpg'),
(138419, 9844, 'Smallville As Aventuras do Superboy [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ar8D8alZxxWjmRGPw7qj61OMOaM.jpg'),
(138420, 9844, 'Smallville As Aventuras do Superboy [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/szxHsWybJXPpqW3eAYmBikUCpaO.jpg'),
(138421, 9844, 'Smallville As Aventuras do Superboy [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1nSRbYR7UtDlzioOJ3ywvT9xlJQ.jpg'),
(138422, 9844, 'Smallville As Aventuras do Superboy [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bxbvYKKxnwZQ3NrruM7WLYe9PP9.jpg'),
(138423, 9844, 'Smallville As Aventuras do Superboy [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lVx5MT94LBeuGOyBIKBxmjPYtK6.jpg'),
(138424, 9844, 'Smallville As Aventuras do Superboy [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9lq55IwxzBGrmhgpDnLNVpPFnaS.jpg'),
(138425, 9844, 'Smallville As Aventuras do Superboy [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ulX6o2yxkmFTAzWxio95ck7ntHF.jpg'),
(138426, 9844, 'Smallville As Aventuras do Superboy [L] S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mdL57trQZjGIsUhqbSVKTvmjxWs.jpg'),
(138427, 9844, 'Smallville As Aventuras do Superboy [L] S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/268804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/adTztTM3MLxZ0m1SpVu4arZaopp.jpg'),
(138428, 9844, 'Smallville As Aventuras do Superboy [L] S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/268805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1zuF3WMJU4Ik1tAe5fbrsEDPWG.jpg'),
(138429, 9844, 'Smallville As Aventuras do Superboy [L] S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/268806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/awCoP3ioZSYmKvUhTP4oiJO1iOb.jpg'),
(138430, 9844, 'Smallville As Aventuras do Superboy [L] S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/268807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xVp9MXjTaB73ZRWhNJMAY5BwT3E.jpg'),
(138431, 9844, 'Smallville As Aventuras do Superboy [L] S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/268808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/18b0Hxo9trxLCUc8jjtv98bLyEp.jpg'),
(138432, 9844, 'Smallville As Aventuras do Superboy [L] S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/268809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c1nW5UwaY1czCuKFyBuaRxmWA1i.jpg'),
(138433, 9844, 'Smallville As Aventuras do Superboy [L] S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/268810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6k9NAcaNyT6b2dNuLpQR7Pc4I3w.jpg'),
(138434, 9844, 'Smallville As Aventuras do Superboy [L] S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/268811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qUzW5wPz6txROilc6J4IJdDIdge.jpg'),
(138435, 9845, 'Smallville As Aventuras do Superboy [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ke97OyYIIe1EJSmnmMr8BIEQ2sx.jpg'),
(138436, 9845, 'Smallville As Aventuras do Superboy [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j6krxDmAbOPdeAGK8PpBnDqJfQa.jpg'),
(138437, 9845, 'Smallville As Aventuras do Superboy [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3TxjrWgyw1I4dRR0dJHf04aqMLM.jpg'),
(138438, 9845, 'Smallville As Aventuras do Superboy [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qhC9YTmRkg5o5NkpdzKlBe1S8Ye.jpg'),
(138439, 9845, 'Smallville As Aventuras do Superboy [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kXn1mVCsOTS2D7aIpqkIzasmAzy.jpg'),
(138440, 9845, 'Smallville As Aventuras do Superboy [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKgJnk2vvzHmCbbhiqTGXBmv49Z.jpg'),
(138441, 9845, 'Smallville As Aventuras do Superboy [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4bzLy9mcpo9FQTBrHpDyIo2IKP4.jpg'),
(138442, 9845, 'Smallville As Aventuras do Superboy [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3pvb6hQAGl2u9ElZOcwFtJ0wYGE.jpg'),
(138443, 9845, 'Smallville As Aventuras do Superboy [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fdQvBzjQ4We3JsQOdpnJZcDrvOH.jpg'),
(138444, 9845, 'Smallville As Aventuras do Superboy [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/egLpZVl1Xn2J7c7IY5vszntm3us.jpg'),
(138445, 9845, 'Smallville As Aventuras do Superboy [L] S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/urfMRDWGB6mdweFh4AaJYoYMuCw.jpg'),
(138446, 9845, 'Smallville As Aventuras do Superboy [L] S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aOR6Grie9KMDr6tCDXynCrwxF2T.jpg'),
(138447, 9845, 'Smallville As Aventuras do Superboy [L] S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oG6UdaXQFc73n5EnOqMskLn0y2K.jpg'),
(138448, 9845, 'Smallville As Aventuras do Superboy [L] S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhrtC83oKqPOLSeWR65cd0juWto.jpg'),
(138449, 9845, 'Smallville As Aventuras do Superboy [L] S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/268826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ogPjxBI7bcJlOIXdzroR0cToA6.jpg'),
(138450, 9845, 'Smallville As Aventuras do Superboy [L] S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/268827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tYqQ6I3X6xa4HfNdfYpQq3yR989.jpg'),
(138451, 9845, 'Smallville As Aventuras do Superboy [L] S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/268828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dlWbjqDuTMBCByRmbHahBQK7mma.jpg'),
(138452, 9845, 'Smallville As Aventuras do Superboy [L] S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/268829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wPs6KIWgHdNIEaFF5JrDH6QrD1I.jpg'),
(138453, 9845, 'Smallville As Aventuras do Superboy [L] S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/268830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3v4uyoHMWTGq2wbYNDpYTfEl4Ar.jpg'),
(138454, 9845, 'Smallville As Aventuras do Superboy [L] S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/268831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rTMygxVPEws4Q8as3iXw9nRLyII.jpg'),
(138455, 9845, 'Smallville As Aventuras do Superboy [L] S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/268832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nTy20V1s3KV9L1gxGKjwkqVEZYK.jpg'),
(138456, 9845, 'Smallville As Aventuras do Superboy [L] S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/268833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fqVt9dYB10lwwC7gfnBl8vWetlX.jpg'),
(138457, 9846, 'Smallville As Aventuras do Superboy [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jClWDCg213IlN7HfGlBA5DHKOuS.jpg'),
(138458, 9846, 'Smallville As Aventuras do Superboy [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aqoHLr9aVo9a1OUM06ASOrSoL0z.jpg'),
(138459, 9846, 'Smallville As Aventuras do Superboy [L] S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8oevX1DTZjbCx7hFolLGAH2xzul.jpg'),
(138460, 9846, 'Smallville As Aventuras do Superboy [L] S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rHpOZl03a0Mb0ayk9AHcYljhYAV.jpg'),
(138461, 9846, 'Smallville As Aventuras do Superboy [L] S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sWyZjvGvJCmIlA0NI19yW0x91HJ.jpg'),
(138462, 9846, 'Smallville As Aventuras do Superboy [L] S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sFBiuHThZc7sFE5WierjGgNMKL4.jpg'),
(138463, 9846, 'Smallville As Aventuras do Superboy [L] S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jA6ZgjWL2obBwxq8QTsNfrq85bN.jpg'),
(138464, 9846, 'Smallville As Aventuras do Superboy [L] S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eOSdt4Axw7KIfM6DjrjwyCMNkC9.jpg'),
(138465, 9846, 'Smallville As Aventuras do Superboy [L] S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zwK1sI4VI3qfulpHbMmTl5S9w8Q.jpg'),
(138466, 9846, 'Smallville As Aventuras do Superboy [L] S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7L59V40P7bTXErEO5rdtcLN7n28.jpg'),
(138467, 9846, 'Smallville As Aventuras do Superboy [L] S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fE47244Nip9p1XTucDdldbtRlJn.jpg'),
(138468, 9846, 'Smallville As Aventuras do Superboy [L] S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9czTfCg76bGeFHAqMD4OJPYJUoR.jpg'),
(138469, 9846, 'Smallville As Aventuras do Superboy [L] S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ABxbvxvLaAatW07bz9GlWK5Ocq.jpg'),
(138470, 9846, 'Smallville As Aventuras do Superboy [L] S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fisau6gftk2WhSxErUglf2aI5MB.jpg'),
(138471, 9846, 'Smallville As Aventuras do Superboy [L] S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/268848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nZ4JfFGXO1WrKTQEZwZr4IBy3mN.jpg'),
(138472, 9846, 'Smallville As Aventuras do Superboy [L] S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/268849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1p1fPXd0VQWpJ2aKyMj2OZP7HrL.jpg'),
(138473, 9846, 'Smallville As Aventuras do Superboy [L] S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/268850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fHBrJlAj6DDDjxMDvZ5ieBpWzfM.jpg'),
(138474, 9846, 'Smallville As Aventuras do Superboy [L] S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/268851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A90R1qbK706OeNyZll2nVqIVC8A.jpg'),
(138475, 9846, 'Smallville As Aventuras do Superboy [L] S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/268852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qvGocNcVCBm6tUvU0dYjWvX3Fzk.jpg'),
(138476, 9846, 'Smallville As Aventuras do Superboy [L] S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/268853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wl2zAVQ0mF8MxLZzs6Qh4H279e6.jpg'),
(138477, 9847, 'Smallville As Aventuras do Superboy [L] S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5bGA9qLdIsaucrQrdSiek4Oqmw.jpg'),
(138478, 9847, 'Smallville As Aventuras do Superboy [L] S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/suo5eySDxram13IQLXQQHNDxjXM.jpg'),
(138479, 9847, 'Smallville As Aventuras do Superboy [L] S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7l2JgnKbuVOZ1z5k4AzO0il6OoD.jpg'),
(138480, 9847, 'Smallville As Aventuras do Superboy [L] S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z5SCxvz9CEJV8D6YMxfsDUQBpJu.jpg'),
(138481, 9847, 'Smallville As Aventuras do Superboy [L] S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iMddIxenizRuwhEwkjp7TuDS9sq.jpg'),
(138482, 9847, 'Smallville As Aventuras do Superboy [L] S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fcgdZBsoUGFcnqxh7uqvS6BM4dq.jpg'),
(138483, 9847, 'Smallville As Aventuras do Superboy [L] S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mB0RXF6CGZUZiNbg8bvP8Ntew10.jpg'),
(138484, 9847, 'Smallville As Aventuras do Superboy [L] S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g4z69AZz62wihAyHFRn6ZCDFsT5.jpg'),
(138485, 9847, 'Smallville As Aventuras do Superboy [L] S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d8bX6TDYjclLKQt9PceOY8mRirG.jpg'),
(138486, 9847, 'Smallville As Aventuras do Superboy [L] S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bnRiEEMhJHvha0x6prPNUgLN5v7.jpg'),
(138487, 9847, 'Smallville As Aventuras do Superboy [L] S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hzyBWDFFXUCB0JtrHH3isVGjYFy.jpg'),
(138488, 9847, 'Smallville As Aventuras do Superboy [L] S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dFzoJsVlLQLRdZdSLZFAy91ln6t.jpg'),
(138489, 9847, 'Smallville As Aventuras do Superboy [L] S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gs0nfIwaq0oJDKKhD835uMsYnUp.jpg'),
(138490, 9847, 'Smallville As Aventuras do Superboy [L] S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFZEOlg6uELygrCCCa2j8zqFNQ1.jpg'),
(138491, 9847, 'Smallville As Aventuras do Superboy [L] S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/268868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3517rKSh8sonFSjkG6ueaOxglJ.jpg'),
(138492, 9847, 'Smallville As Aventuras do Superboy [L] S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/268869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ztaS8CGDWw5BKy33v83lQqlGOIq.jpg'),
(138493, 9847, 'Smallville As Aventuras do Superboy [L] S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/268870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfGCoUy4je5UdoH4lzLq5DE5IGY.jpg'),
(138494, 9847, 'Smallville As Aventuras do Superboy [L] S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/268871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1nl1qJRuzY92RTkNZD2zhDXUG1J.jpg'),
(138495, 9847, 'Smallville As Aventuras do Superboy [L] S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/268872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ahe7kT3utyQNVvcBL0jYbqTluc5.jpg'),
(138496, 9847, 'Smallville As Aventuras do Superboy [L] S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/268873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7IGaMcsrFmSaFS8zuYSmEYqk61w.jpg'),
(138497, 9847, 'Smallville As Aventuras do Superboy [L] S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/268874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Ism4ICsMSgJmuKVzwjWrMjpOq9.jpg'),
(138498, 9847, 'Smallville As Aventuras do Superboy [L] S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/268875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kgLmrdqtoikzTBaZrn6Cize7Eqq.jpg'),
(138499, 9848, 'Smallville As Aventuras do Superboy [L] S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ydfsuJTkrzviZA8vuN1PiCwDHG5.jpg'),
(138500, 9848, 'Smallville As Aventuras do Superboy [L] S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uftQS6dAx5xNVG0htRqMnQVRJ6W.jpg'),
(138501, 9848, 'Smallville As Aventuras do Superboy [L] S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c77IXxzFgqBg2c002DHwGcY5R5g.jpg'),
(138502, 9848, 'Smallville As Aventuras do Superboy [L] S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/suicCwrnX0agpF7OSG0uUtaabKg.jpg'),
(138503, 9848, 'Smallville As Aventuras do Superboy [L] S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnPYoF8tCqf4aYnCJAXQq8MJ0La.jpg'),
(138504, 9848, 'Smallville As Aventuras do Superboy [L] S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s7xzxZrE2rqhAHf19tm7IazS7lO.jpg'),
(138505, 9848, 'Smallville As Aventuras do Superboy [L] S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1K3w2J89dFmaOhgJGn7CVoBTpXU.jpg'),
(138506, 9848, 'Smallville As Aventuras do Superboy [L] S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jsozzIKFBtNFxdFSsuMs9KmtN2r.jpg'),
(138507, 9848, 'Smallville As Aventuras do Superboy [L] S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vq3ugTNvluznXSulUrh644fwIuT.jpg'),
(138508, 9848, 'Smallville As Aventuras do Superboy [L] S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkWhpK7xQSzymERKP3PUWu9t5hB.jpg'),
(138509, 9848, 'Smallville As Aventuras do Superboy [L] S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/meYJjWLxI8iy1LH33wpwHlUJXS6.jpg'),
(138510, 9848, 'Smallville As Aventuras do Superboy [L] S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x6dUe48l1pUfXBS5MnjnYJ4fJtQ.jpg'),
(138511, 9848, 'Smallville As Aventuras do Superboy [L] S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uJFvyl8Oj1f7ESOVjjt27QK3wcA.jpg'),
(138512, 9848, 'Smallville As Aventuras do Superboy [L] S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6DiyT3xzPe2XyX8a6IJ5exejHvd.jpg'),
(138513, 9848, 'Smallville As Aventuras do Superboy [L] S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/268890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rdDLumWlZDzo8cMX49TrFsvwgX4.jpg'),
(138514, 9848, 'Smallville As Aventuras do Superboy [L] S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/268891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/39xTbomeyFOjwCmalahfgMtG3dw.jpg'),
(138515, 9848, 'Smallville As Aventuras do Superboy [L] S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/268892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AiiVvi8cGqxlIYyBRQSg4h4lbfF.jpg'),
(138516, 9848, 'Smallville As Aventuras do Superboy [L] S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/268893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iDBHBMiV1RG5QQrnHTEhvtrzSij.jpg'),
(138517, 9848, 'Smallville As Aventuras do Superboy [L] S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/268894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pbnDD1zCs4tv2q17x7RNc6hpcbR.jpg'),
(138518, 9848, 'Smallville As Aventuras do Superboy [L] S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/268895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dqcmQ7jZwCVmzOeaXfwVX6lraPP.jpg'),
(138519, 9848, 'Smallville As Aventuras do Superboy [L] S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/268896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/llmi30cNOjQCfycrhL2GQfZ1GPC.jpg'),
(138520, 9849, 'Smallville As Aventuras do Superboy [L] S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ySSKh9sZYEvpRUPKFWIpAu7Cgl6.jpg'),
(138521, 9849, 'Smallville As Aventuras do Superboy [L] S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/firIVCPPasYHsWyHiD1XI3SFRCp.jpg'),
(138522, 9849, 'Smallville As Aventuras do Superboy [L] S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fFyWOpyNPhG2mQYELRdn15AVWWt.jpg'),
(138523, 9849, 'Smallville As Aventuras do Superboy [L] S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A8xN63ZY13eeYtWD5kfD6ed7Jsp.jpg'),
(138524, 9849, 'Smallville As Aventuras do Superboy [L] S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sUnImBJUsuoDRpQ7Z0YFA9FgVEx.jpg'),
(138525, 9849, 'Smallville As Aventuras do Superboy [L] S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jHVSXHV0tLTAzXbyrBqJ0MRCdv2.jpg'),
(138526, 9849, 'Smallville As Aventuras do Superboy [L] S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xspgabR39swc4a7E4wpAX6OTkCN.jpg'),
(138527, 9849, 'Smallville As Aventuras do Superboy [L] S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g2Hpgl8LonxTwJEcJlisuagKWry.jpg'),
(138528, 9849, 'Smallville As Aventuras do Superboy [L] S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Qv4Cf5rXg8M9qr9FlYs30Qkjqj.jpg'),
(138529, 9849, 'Smallville As Aventuras do Superboy [L] S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/md9T2cwoOnTqGF2YT8NiGcXrpva.jpg'),
(138530, 9849, 'Smallville As Aventuras do Superboy [L] S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9KzmNOnHrtOMzEVC9pFwxrM2iaW.jpg'),
(138531, 9849, 'Smallville As Aventuras do Superboy [L] S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qrRARJdX6kWizDQTe14NIdKYMOq.jpg'),
(138532, 9849, 'Smallville As Aventuras do Superboy [L] S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8sBvxAp96bNDrFfSt2Zi7xJUR0p.jpg'),
(138533, 9849, 'Smallville As Aventuras do Superboy [L] S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t5dqhpc8i8v2u88s1Q2GuFg5Yt5.jpg'),
(138534, 9849, 'Smallville As Aventuras do Superboy [L] S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/268911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/GxYnCo4VSlH305rVBglev4T40h.jpg'),
(138535, 9849, 'Smallville As Aventuras do Superboy [L] S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/268912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9cUwSSufDlwu8LtytAMZ1OZAlF3.jpg'),
(138536, 9849, 'Smallville As Aventuras do Superboy [L] S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/268913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1ElDrhLKyPazP8eJYXhplW07vN.jpg'),
(138537, 9849, 'Smallville As Aventuras do Superboy [L] S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/268914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nMDcJEKQZFYo5d44wBbCFhWhYLX.jpg'),
(138538, 9849, 'Smallville As Aventuras do Superboy [L] S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/268915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nlQQz2iT9JWzHiiHBFSTlx43HRq.jpg'),
(138539, 9849, 'Smallville As Aventuras do Superboy [L] S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/268916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/etNm6Io7Yxn4sZGaChFLsl2M0OX.jpg'),
(138540, 9849, 'Smallville As Aventuras do Superboy [L] S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/268917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6NTiC2G9qSdplHmULSygtkUATk8.jpg'),
(138541, 9849, 'Smallville As Aventuras do Superboy [L] S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/268918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pYEuYI4n8BQNtuHIqRlhWQ4O1Sj.jpg'),
(138542, 9850, 'Vestigios do Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gNF9gHiXtvbGqS81NW2iBf8BLFB.jpg'),
(138543, 9850, 'Vestigios do Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gNF9gHiXtvbGqS81NW2iBf8BLFB.jpg'),
(138544, 9850, 'Vestigios do Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gNF9gHiXtvbGqS81NW2iBf8BLFB.jpg'),
(138545, 9850, 'Vestigios do Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gNF9gHiXtvbGqS81NW2iBf8BLFB.jpg'),
(138546, 9850, 'Vestigios do Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gNF9gHiXtvbGqS81NW2iBf8BLFB.jpg'),
(138547, 9850, 'Vestigios do Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gNF9gHiXtvbGqS81NW2iBf8BLFB.jpg'),
(138548, 9850, 'Vestigios do Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gNF9gHiXtvbGqS81NW2iBf8BLFB.jpg'),
(138549, 9850, 'Vestigios do Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gNF9gHiXtvbGqS81NW2iBf8BLFB.jpg'),
(138550, 9850, 'Vestigios do Brasil S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gNF9gHiXtvbGqS81NW2iBf8BLFB.jpg'),
(138551, 9850, 'Vestigios do Brasil S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gNF9gHiXtvbGqS81NW2iBf8BLFB.jpg'),
(138552, 9850, 'Vestigios do Brasil S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gNF9gHiXtvbGqS81NW2iBf8BLFB.jpg'),
(138553, 9850, 'Vestigios do Brasil S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gNF9gHiXtvbGqS81NW2iBf8BLFB.jpg'),
(138554, 9851, 'Bucchigiri S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pE1zPEUsc6N1XhhNRoJkGJdEbxI.jpg'),
(138555, 9851, 'Bucchigiri S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/271674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mTphiAP2vMMNcVSB5a1pWEMZuo3.jpg'),
(138556, 9851, 'Bucchigiri S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/285595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mTphiAP2vMMNcVSB5a1pWEMZuo3.jpg'),
(138557, 9851, 'Bucchigiri S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/285596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mTphiAP2vMMNcVSB5a1pWEMZuo3.jpg'),
(138558, 9851, 'Bucchigiri S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/271675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mTphiAP2vMMNcVSB5a1pWEMZuo3.jpg'),
(138559, 9851, 'Bucchigiri S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/298200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mTphiAP2vMMNcVSB5a1pWEMZuo3.jpg'),
(138560, 9851, 'Bucchigiri S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/309297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mTphiAP2vMMNcVSB5a1pWEMZuo3.jpg'),
(138561, 9851, 'Bucchigiri S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/316195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mTphiAP2vMMNcVSB5a1pWEMZuo3.jpg'),
(138562, 9851, 'Bucchigiri S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/323013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mTphiAP2vMMNcVSB5a1pWEMZuo3.jpg'),
(138563, 9851, 'Bucchigiri S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/326315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mTphiAP2vMMNcVSB5a1pWEMZuo3.jpg'),
(138564, 9851, 'Bucchigiri S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/333861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mTphiAP2vMMNcVSB5a1pWEMZuo3.jpg'),
(138565, 9851, 'Bucchigiri S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/338974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mTphiAP2vMMNcVSB5a1pWEMZuo3.jpg'),
(138566, 9852, 'Confronto Entre Potencias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k6Rvnsq95Wim7u7jiljODWQwhsz.jpg'),
(138567, 9852, 'Confronto Entre Potencias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k6Rvnsq95Wim7u7jiljODWQwhsz.jpg'),
(138568, 9852, 'Confronto Entre Potencias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/281433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k6Rvnsq95Wim7u7jiljODWQwhsz.jpg'),
(138569, 9852, 'Confronto Entre Potencias S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/281434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k6Rvnsq95Wim7u7jiljODWQwhsz.jpg'),
(138570, 9853, 'Confronto Entre Potencias S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/288741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k6Rvnsq95Wim7u7jiljODWQwhsz.jpg'),
(138571, 9853, 'Confronto Entre Potencias S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/288742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k6Rvnsq95Wim7u7jiljODWQwhsz.jpg'),
(138572, 9853, 'Confronto Entre Potencias S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k6Rvnsq95Wim7u7jiljODWQwhsz.jpg'),
(138573, 9854, 'Guerras Russas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/emW0PGaNx4FfVPPNnj6rwlv8iMM.jpg'),
(138574, 9854, 'Guerras Russas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/272901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/emW0PGaNx4FfVPPNnj6rwlv8iMM.jpg'),
(138575, 9854, 'Guerras Russas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/276504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/emW0PGaNx4FfVPPNnj6rwlv8iMM.jpg'),
(138576, 9855, 'Labirinto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mErC8JMBomuAO1njvy6YpjFsvB.jpg'),
(138577, 9855, 'Labirinto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mErC8JMBomuAO1njvy6YpjFsvB.jpg'),
(138578, 9855, 'Labirinto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mErC8JMBomuAO1njvy6YpjFsvB.jpg'),
(138579, 9855, 'Labirinto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mErC8JMBomuAO1njvy6YpjFsvB.jpg'),
(138580, 9855, 'Labirinto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mErC8JMBomuAO1njvy6YpjFsvB.jpg'),
(138581, 9855, 'Labirinto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mErC8JMBomuAO1njvy6YpjFsvB.jpg'),
(138582, 9855, 'Labirinto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mErC8JMBomuAO1njvy6YpjFsvB.jpg'),
(138583, 9855, 'Labirinto S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mErC8JMBomuAO1njvy6YpjFsvB.jpg'),
(138584, 9855, 'Labirinto S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mErC8JMBomuAO1njvy6YpjFsvB.jpg'),
(138585, 9855, 'Labirinto S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mErC8JMBomuAO1njvy6YpjFsvB.jpg'),
(138586, 9855, 'Labirinto S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mErC8JMBomuAO1njvy6YpjFsvB.jpg'),
(138587, 9855, 'Labirinto S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mErC8JMBomuAO1njvy6YpjFsvB.jpg'),
(138588, 9855, 'Labirinto S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mErC8JMBomuAO1njvy6YpjFsvB.jpg'),
(138589, 9855, 'Labirinto S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mErC8JMBomuAO1njvy6YpjFsvB.jpg'),
(138590, 9855, 'Labirinto S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/268243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mErC8JMBomuAO1njvy6YpjFsvB.jpg'),
(138591, 9855, 'Labirinto S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/268244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mErC8JMBomuAO1njvy6YpjFsvB.jpg'),
(138592, 9855, 'Labirinto S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/268245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mErC8JMBomuAO1njvy6YpjFsvB.jpg'),
(138593, 9855, 'Labirinto S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/268246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mErC8JMBomuAO1njvy6YpjFsvB.jpg'),
(138594, 9855, 'Labirinto S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/268247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mErC8JMBomuAO1njvy6YpjFsvB.jpg'),
(138595, 9855, 'Labirinto S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/268248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8mErC8JMBomuAO1njvy6YpjFsvB.jpg'),
(138596, 9856, 'Reino da Conquista S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hYYHpszEGXW053SVP6CK8O9ZgSz.jpg'),
(138597, 9856, 'Reino da Conquista S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h0BC3elXIAL0GfczxowVD9YFhiM.jpg'),
(138598, 9856, 'Reino da Conquista S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/270902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/llCDNlOzbjrDIroIMQwCQDoElZU.jpg'),
(138599, 9856, 'Reino da Conquista S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/270903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/llCDNlOzbjrDIroIMQwCQDoElZU.jpg'),
(138600, 9856, 'Reino da Conquista S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/275095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/llCDNlOzbjrDIroIMQwCQDoElZU.jpg'),
(138601, 9856, 'Reino da Conquista S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/275096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/llCDNlOzbjrDIroIMQwCQDoElZU.jpg'),
(138602, 9856, 'Reino da Conquista S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/279515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/llCDNlOzbjrDIroIMQwCQDoElZU.jpg'),
(138603, 9856, 'Reino da Conquista S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/279516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/llCDNlOzbjrDIroIMQwCQDoElZU.jpg'),
(138604, 9856, 'Reino da Conquista S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/285814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/llCDNlOzbjrDIroIMQwCQDoElZU.jpg'),
(138605, 9856, 'Reino da Conquista S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/285815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/llCDNlOzbjrDIroIMQwCQDoElZU.jpg'),
(138606, 9856, 'Reino da Conquista S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/295298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/llCDNlOzbjrDIroIMQwCQDoElZU.jpg'),
(138607, 9856, 'Reino da Conquista S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/295299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/llCDNlOzbjrDIroIMQwCQDoElZU.jpg'),
(138608, 9856, 'Reino da Conquista S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/301105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/llCDNlOzbjrDIroIMQwCQDoElZU.jpg'),
(138609, 9856, 'Reino da Conquista S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/301106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/llCDNlOzbjrDIroIMQwCQDoElZU.jpg'),
(138610, 9856, 'Reino da Conquista S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/307305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/llCDNlOzbjrDIroIMQwCQDoElZU.jpg'),
(138611, 9856, 'Reino da Conquista S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/307306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/llCDNlOzbjrDIroIMQwCQDoElZU.jpg'),
(138612, 9857, 'Um Dia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1EvCd9C2hjRFBNOuRJJ3QlWXdiu.jpg'),
(138613, 9857, 'Um Dia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cW1jzVfCOuwvXjUbnfnktMpFh6x.jpg'),
(138614, 9857, 'Um Dia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jJDgSeDJ2aDQgi7HI19vTjwwfTU.jpg'),
(138615, 9857, 'Um Dia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cwQdM99mpBAaL3NdBec6MVaxCBv.jpg'),
(138616, 9857, 'Um Dia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/40yNDXbFE7p7BOYS3Wj1xVUEeug.jpg'),
(138617, 9857, 'Um Dia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pImJ56ZlUIfUicoxJef4OFnJFPN.jpg'),
(138618, 9857, 'Um Dia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l4VFWg5gLWqOx46Qt6XSBT8WWrl.jpg'),
(138619, 9857, 'Um Dia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fyJ4XN3rcLnUufmBamxFKGY087H.jpg'),
(138620, 9857, 'Um Dia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tPljN0rHJTU2e8hj8UDavV1jsnz.jpg'),
(138621, 9857, 'Um Dia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/WRNXpG5ywfc4toGNySIxYXHUvm.jpg'),
(138622, 9857, 'Um Dia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pRVF7olO9PFw1JjtzMGVbRvP48P.jpg'),
(138623, 9857, 'Um Dia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7uUAvTg8zd8Q57WeO5XE3K3W9HQ.jpg'),
(138624, 9857, 'Um Dia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wHlzsW4dpuhdmGKoPKHtoQZRtYE.jpg'),
(138625, 9857, 'Um Dia S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rENGz6QcH56EVah01YXpgizyBGC.jpg'),
(138626, 9858, 'Danny Phantom S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHJSrxXvFmxiU3wIABnRksF29DM.jpg'),
(138627, 9858, 'Danny Phantom S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3OaCP5GbHjJ1z2drHZDdnS9gimn.jpg'),
(138628, 9858, 'Danny Phantom S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oCdebTx34nUjg4IVCsTF61aIOXU.jpg'),
(138629, 9858, 'Danny Phantom S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k78jGxeBPgsaVNoAAipGFoqxAFc.jpg'),
(138630, 9858, 'Danny Phantom S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8XdcGlcCtpdJ7UO6CTPuprlJa5B.jpg'),
(138631, 9858, 'Danny Phantom S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/he5uIG3WwCEBlwUQLRxbW1WHLEw.jpg'),
(138632, 9858, 'Danny Phantom S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cbXm5dO0RL74bkiLC1F4mHzSM9u.jpg'),
(138633, 9858, 'Danny Phantom S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zMuA38LKhxVllfdc3sKSk0VYMMQ.jpg'),
(138634, 9858, 'Danny Phantom S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cvavBXhAKuSAEoag7Kz2kucowkb.jpg'),
(138635, 9858, 'Danny Phantom S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1KxbjXseWYjTfPMgVN5Fc3ENX1f.jpg'),
(138636, 9858, 'Danny Phantom S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmiSJgUpxpxjbDnZFUlza0ckDgg.jpg'),
(138637, 9858, 'Danny Phantom S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nYQh42taavMpoL2Qemi9xlopE7X.jpg'),
(138638, 9858, 'Danny Phantom S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/akjrsF5yI3g7wqxADBp66N2aXAg.jpg'),
(138639, 9858, 'Danny Phantom S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vheWH3rHoGzoYt5MxzoUIAqOaJC.jpg'),
(138640, 9858, 'Danny Phantom S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/268174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/87aGmSrH9UukVIqXi9JAkzXqfhZ.jpg'),
(138641, 9858, 'Danny Phantom S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/268175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yiyDMItfimz6vHMXxk98wxsWlgt.jpg'),
(138642, 9858, 'Danny Phantom S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/268176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zh7OjR7yRCPEz4jumXr7XMPksxh.jpg'),
(138643, 9858, 'Danny Phantom S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/268177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vSwmpgvUbknVHcMIihe261xdpK6.jpg'),
(138644, 9858, 'Danny Phantom S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/268178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1R0esgvT4DUBK0eKxmT7v0O8T6P.jpg'),
(138645, 9859, 'Danny Phantom S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Mrl7r9HRzq0oS76ptg2agU9NSR.jpg'),
(138646, 9859, 'Danny Phantom S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4VvlSkU6VqATm6YN618PbqbxzzP.jpg'),
(138647, 9859, 'Danny Phantom S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jP7cALi4osogHKZ8wDv1YXN943P.jpg'),
(138648, 9859, 'Danny Phantom S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lSEaaosK7Ch0j8ZdWIBxmhjpfjt.jpg'),
(138649, 9859, 'Danny Phantom S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j5mgZvV47FYLDdQ3bjrgbXSFo5X.jpg'),
(138650, 9859, 'Danny Phantom S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1FEiA0E27nDOo9tXXUmyNJxWMgU.jpg'),
(138651, 9859, 'Danny Phantom S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ujHm7KCAsbN4QZ41TgMSyQqvfQ1.jpg'),
(138652, 9859, 'Danny Phantom S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iK1r6P2aBiU0C8oYgMU8Vqy5Y1B.jpg'),
(138653, 9859, 'Danny Phantom S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEcwVmWiTMk8MuakqCiR2AuRdy4.jpg'),
(138654, 9859, 'Danny Phantom S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9izYmVKUiwczLx9x7yJjM45QmQN.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(138655, 9859, 'Danny Phantom S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lRxRzExNb7Bp9nSA7HIlI3w0NyX.jpg'),
(138656, 9859, 'Danny Phantom S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wqys5XWb6H8ZJvnGFhk5qBVVZc6.jpg'),
(138657, 9859, 'Danny Phantom S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kt60u528eeBVt9TQSiyBZIsIjrH.jpg'),
(138658, 9859, 'Danny Phantom S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yyMuWKuPyQ05jr6LE07lubmJD4g.jpg'),
(138659, 9859, 'Danny Phantom S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/268193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFkfImokgdENEo9fStP5iaujYtn.jpg'),
(138660, 9859, 'Danny Phantom S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/268194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2lBVUMTOenCtn6BTVXzY3rbdPzy.jpg'),
(138661, 9859, 'Danny Phantom S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/268195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/juAR0eFJumMpqW58nGPV1ENzoSw.jpg'),
(138662, 9859, 'Danny Phantom S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/268196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pBUOFBmZLaIxzjDjQP7d3QZrd4w.jpg'),
(138663, 9859, 'Danny Phantom S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/268197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pBUOFBmZLaIxzjDjQP7d3QZrd4w.jpg'),
(138664, 9859, 'Danny Phantom S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/268198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pBUOFBmZLaIxzjDjQP7d3QZrd4w.jpg'),
(138665, 9859, 'Danny Phantom S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/268199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pBUOFBmZLaIxzjDjQP7d3QZrd4w.jpg'),
(138666, 9860, 'Danny Phantom S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pcCy3Vl7xhCu3Or4mlrAeWfhAAf.jpg'),
(138667, 9860, 'Danny Phantom S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAcSFeK5U1lOiW5Gfx9Hdk2Ee9B.jpg'),
(138668, 9860, 'Danny Phantom S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4kqFp7RZ4HeJ9vkmpF6jd8mwmvD.jpg'),
(138669, 9860, 'Danny Phantom S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w0vMaCc9askpEmFDqZHBrmBaGya.jpg'),
(138670, 9860, 'Danny Phantom S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ldVyZeSqUWoLOrI9Z721HdD2wDk.jpg'),
(138671, 9860, 'Danny Phantom S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wVgW5iv3mr7mVjIFSL2BRsi5zjR.jpg'),
(138672, 9860, 'Danny Phantom S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oLhy5Hgx8WcowmWajv25j0gDwKC.jpg'),
(138673, 9860, 'Danny Phantom S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nthvIn1iY4Exk57zblCErzVPjao.jpg'),
(138674, 9860, 'Danny Phantom S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/98PqHNbJLQ86wOvYcYv2YioaUNJ.jpg'),
(138675, 9860, 'Danny Phantom S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nRQHb9qwe6k8Z24BaBB504eAf2m.jpg'),
(138676, 9860, 'Danny Phantom S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1u17CYAWU5KTf0m6btN1tATk8LF.jpg'),
(138677, 9860, 'Danny Phantom S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mM9q6CoAlV8g05JUDCSQtpaF9P5.jpg'),
(138678, 9860, 'Danny Phantom S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pBUOFBmZLaIxzjDjQP7d3QZrd4w.jpg'),
(138679, 9861, 'Minha Menina [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iPwtCk9zk80sed4heluxdPu72sD.jpg'),
(138680, 9861, 'Minha Menina [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uXvKcWyqFN3ukl0lwZGvLAOWRt8.jpg'),
(138681, 9861, 'Minha Menina [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9VjcO0QN9kRR0vGrIIJD5RNmrJ.jpg'),
(138682, 9861, 'Minha Menina [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q6pyOkTqYtNwrTvclGC4VaYypop.jpg'),
(138683, 9861, 'Minha Menina [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7oKrL8PFpc4Bdu74pLjLBwMEPjj.jpg'),
(138684, 9861, 'Minha Menina [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Ky5yrQvqCePDyhgKJxHWc5Om8P.jpg'),
(138685, 9861, 'Minha Menina [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4qH9wcroN5wIkQOdYiA1iCRpT08.jpg'),
(138686, 9861, 'Minha Menina [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uO8QhIYXPVxqx9cdujSYRR2uTFX.jpg'),
(138687, 9861, 'Minha Menina [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZ1DRSiFoEVYXZ7yKyFy4jbdcLe.jpg'),
(138688, 9861, 'Minha Menina [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jvzcKtPtyytoYdMNsMsZfQkWe8J.jpg'),
(138689, 9861, 'Minha Menina [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4enR43nwNNOS0GPLRDP8CnUEZE.jpg'),
(138690, 9861, 'Minha Menina [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/piSu9GN4SNkdecOTKxeKUZ4u1pB.jpg'),
(138691, 9861, 'Minha Menina [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zEvcIOty76vRx8ToKRdsKHVuEMv.jpg'),
(138692, 9861, 'Minha Menina [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ktMX80EKndgWya5dK5cBRDGCvIM.jpg'),
(138693, 9861, 'Minha Menina [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/268124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bG0Ju9rgLDfSMF74jDxPr1XRzQY.jpg'),
(138694, 9861, 'Minha Menina [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/268125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jwHNtIiRkyEz3JCFiZyF57Lm62f.jpg'),
(138695, 9861, 'Minha Menina [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/268126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c04wL1U4SSua3dWc3RGBV9ryFUm.jpg'),
(138696, 9861, 'Minha Menina [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/268127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8HJKnbyEQ8o5ULUKnUmkY0Uk6T1.jpg'),
(138697, 9861, 'Minha Menina [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/268128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x84QzqgDY3E009aH2OsTcK3wokM.jpg'),
(138698, 9861, 'Minha Menina [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/268129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mpKEqorWwZhrvH6klXUAM2Ps6YA.jpg'),
(138699, 9861, 'Minha Menina [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/268130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vgr9o1bdFTP9O2s2tcyeeeR3phC.jpg'),
(138700, 9861, 'Minha Menina [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/268131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x4w9dX3BEw4T7M8EacIhC08vksW.jpg'),
(138701, 9861, 'Minha Menina [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/268132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wW0GjpHFE4KYrsOLO282Thqbf7D.jpg'),
(138702, 9861, 'Minha Menina [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/268133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBVexkgLcp5C4Ix8GtOsqhpkzeL.jpg'),
(138703, 9861, 'Minha Menina [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/268134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1itRIj9MWqwCXn9gzdTPeJwvqI.jpg'),
(138704, 9861, 'Minha Menina [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/268135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uLSa2pHLKK44vvz6pACCTEp1wM8.jpg'),
(138705, 9861, 'Minha Menina [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/268136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uLSa2pHLKK44vvz6pACCTEp1wM8.jpg'),
(138706, 9861, 'Minha Menina [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/268137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uLSa2pHLKK44vvz6pACCTEp1wM8.jpg'),
(138707, 9861, 'Minha Menina [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/268138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uLSa2pHLKK44vvz6pACCTEp1wM8.jpg'),
(138708, 9861, 'Minha Menina [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/268139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uLSa2pHLKK44vvz6pACCTEp1wM8.jpg'),
(138709, 9861, 'Minha Menina [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/268140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uLSa2pHLKK44vvz6pACCTEp1wM8.jpg'),
(138710, 9861, 'Minha Menina [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/268141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uLSa2pHLKK44vvz6pACCTEp1wM8.jpg'),
(138711, 9861, 'Minha Menina [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/268142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uLSa2pHLKK44vvz6pACCTEp1wM8.jpg'),
(138712, 9861, 'Minha Menina [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/268143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uLSa2pHLKK44vvz6pACCTEp1wM8.jpg'),
(138713, 9861, 'Minha Menina [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/268144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uLSa2pHLKK44vvz6pACCTEp1wM8.jpg'),
(138714, 9861, 'Minha Menina [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/268145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uLSa2pHLKK44vvz6pACCTEp1wM8.jpg'),
(138715, 9861, 'Minha Menina [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/268146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uLSa2pHLKK44vvz6pACCTEp1wM8.jpg'),
(138716, 9861, 'Minha Menina [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/268147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uLSa2pHLKK44vvz6pACCTEp1wM8.jpg'),
(138717, 9861, 'Minha Menina [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/268148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uLSa2pHLKK44vvz6pACCTEp1wM8.jpg'),
(138718, 9861, 'Minha Menina [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/268149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uLSa2pHLKK44vvz6pACCTEp1wM8.jpg'),
(138719, 9861, 'Minha Menina [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/268150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uLSa2pHLKK44vvz6pACCTEp1wM8.jpg'),
(138720, 9861, 'Minha Menina [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/268151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5aqqUGwH2OtRTsZ1nP5db8e8cqH.jpg'),
(138721, 9861, 'Minha Menina [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/268152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5aqqUGwH2OtRTsZ1nP5db8e8cqH.jpg'),
(138722, 9861, 'Minha Menina [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/268153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5aqqUGwH2OtRTsZ1nP5db8e8cqH.jpg'),
(138723, 9861, 'Minha Menina [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/268154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5aqqUGwH2OtRTsZ1nP5db8e8cqH.jpg'),
(138724, 9861, 'Minha Menina [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/268155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5aqqUGwH2OtRTsZ1nP5db8e8cqH.jpg'),
(138725, 9861, 'Minha Menina [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/268156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5aqqUGwH2OtRTsZ1nP5db8e8cqH.jpg'),
(138726, 9861, 'Minha Menina [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/268157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5aqqUGwH2OtRTsZ1nP5db8e8cqH.jpg'),
(138727, 9861, 'Minha Menina [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/268158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5aqqUGwH2OtRTsZ1nP5db8e8cqH.jpg'),
(138728, 9861, 'Minha Menina [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/268159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5aqqUGwH2OtRTsZ1nP5db8e8cqH.jpg'),
(138729, 9862, 'Jake Long O Dragao Ocidental S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqMxb0N94LR9xIisjq2OVZkRAS1.jpg'),
(138730, 9862, 'Jake Long O Dragao Ocidental S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3g3t09UkdRnQ36Qu49LqbYWHZ6u.jpg'),
(138731, 9862, 'Jake Long O Dragao Ocidental S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nResS24USeRVQXly53XYdxtQptJ.jpg'),
(138732, 9862, 'Jake Long O Dragao Ocidental S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bFfsKwxNFwYuHYjX5vWBECd13kQ.jpg'),
(138733, 9862, 'Jake Long O Dragao Ocidental S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jAEIkPe6a7I8RL2Ix2oHIj0sslq.jpg'),
(138734, 9862, 'Jake Long O Dragao Ocidental S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nPeP8VvEyCPWWoJPMShJ7TYoUYk.jpg'),
(138735, 9862, 'Jake Long O Dragao Ocidental S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o6JJMq2zg1Dl6Nx6rvUVJKzrKbm.jpg'),
(138736, 9862, 'Jake Long O Dragao Ocidental S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qeV16D7AXgBmv43K9AqkxiVSGno.jpg'),
(138737, 9862, 'Jake Long O Dragao Ocidental S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x9MdW4X4YaGLAtsjEHQcVL5pkSC.jpg'),
(138738, 9862, 'Jake Long O Dragao Ocidental S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o6JJMq2zg1Dl6Nx6rvUVJKzrKbm.jpg'),
(138739, 9862, 'Jake Long O Dragao Ocidental S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/32dDl4ZTGOUFHuWqRhUbKq2KUpf.jpg'),
(138740, 9862, 'Jake Long O Dragao Ocidental S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1JRuPH7LHeOHzQjOR5ibU6cp4tO.jpg'),
(138741, 9862, 'Jake Long O Dragao Ocidental S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fvIDEFcQaodH2kMvsfDxgEb00iD.jpg'),
(138742, 9862, 'Jake Long O Dragao Ocidental S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mo6EHoZmnNGFQuQC53p8s7lRT.jpg'),
(138743, 9862, 'Jake Long O Dragao Ocidental S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/268072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3LvOoQ7SpqTF5RoidPWfcgNYC2A.jpg'),
(138744, 9862, 'Jake Long O Dragao Ocidental S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/268073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZxnrzlgE2dAGNNmbAHL9iB8mR8.jpg'),
(138745, 9862, 'Jake Long O Dragao Ocidental S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/268074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2WINlwPtYVm1pJaH20Opn0sXe7J.jpg'),
(138746, 9862, 'Jake Long O Dragao Ocidental S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/268075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1tSEDjkMJ0i9vVooBQbvBeose7E.jpg'),
(138747, 9862, 'Jake Long O Dragao Ocidental S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/268076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dEa1KNF5v4yTP56a2OuH503gCBV.jpg'),
(138748, 9862, 'Jake Long O Dragao Ocidental S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/268077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMlqQfM45ohdANvvpx2SVMZeXpJ.jpg'),
(138749, 9862, 'Jake Long O Dragao Ocidental S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/268078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o6JJMq2zg1Dl6Nx6rvUVJKzrKbm.jpg'),
(138750, 9863, 'Jake Long O Dragao Ocidental S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/268079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w34Jrh5YiVDRnmIdxpiXWACSYt0.jpg'),
(138751, 9863, 'Jake Long O Dragao Ocidental S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/268080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hNhbfyJV0CLpsPYg9bUOTDwa8tU.jpg'),
(138752, 9863, 'Jake Long O Dragao Ocidental S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/268081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9DcquCwoS86WxjhYu6j2us70zo2.jpg'),
(138753, 9863, 'Jake Long O Dragao Ocidental S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/268082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/idLrpDc8WzEluhzuddfknozuDfv.jpg'),
(138754, 9863, 'Jake Long O Dragao Ocidental S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/268083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hz3kkRokMJeYRmWwAsuugKSQqzr.jpg'),
(138755, 9863, 'Jake Long O Dragao Ocidental S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/268084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z84Zj4aUJwZjHitPWizeHUlowq4.jpg'),
(138756, 9863, 'Jake Long O Dragao Ocidental S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/268085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3bKvoRm9JuFPmi2YvPjA7qPKOvM.jpg'),
(138757, 9863, 'Jake Long O Dragao Ocidental S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/268086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A2bbkbRrKXWFw01UvcreYgWtQDy.jpg'),
(138758, 9863, 'Jake Long O Dragao Ocidental S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/268087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFe87ZSq4CEbG1FjRnX9BJen1HU.jpg'),
(138759, 9863, 'Jake Long O Dragao Ocidental S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/268088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8HYyfKqhhG4WiipjzIjOSvqKMHr.jpg'),
(138760, 9863, 'Jake Long O Dragao Ocidental S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/268089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xgFJiP24A9xfu5g6JcRRu7vEPH.jpg'),
(138761, 9863, 'Jake Long O Dragao Ocidental S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/268090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b6qVkJyOYwBxKpNY2LxQBh6YQkR.jpg'),
(138762, 9863, 'Jake Long O Dragao Ocidental S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/268091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mA14pMoW5Qx9KtmDiKid47uhtFd.jpg'),
(138763, 9863, 'Jake Long O Dragao Ocidental S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/268092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pBHYiHy02iPM59hZsoq90OYk43C.jpg'),
(138764, 9863, 'Jake Long O Dragao Ocidental S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/268093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h8MguCO5E5e2bGOXlqOwT2qTs2w.jpg'),
(138765, 9863, 'Jake Long O Dragao Ocidental S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/268094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s3APmr3UjKZ1fZovmZvptPjwDZP.jpg'),
(138766, 9863, 'Jake Long O Dragao Ocidental S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/268095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qVGLqMpVzj2ypmJe5tzA7ytN4Pt.jpg'),
(138767, 9863, 'Jake Long O Dragao Ocidental S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/268096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vqK4RCVysiCb39wzkui6O0Cphc7.jpg'),
(138768, 9863, 'Jake Long O Dragao Ocidental S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/268097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iRqe5CBfW7AhrLAfgJq0EA4Jb3c.jpg'),
(138769, 9863, 'Jake Long O Dragao Ocidental S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/268098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkuDg1JjCPZci48SHlNGqrzLwBr.jpg'),
(138770, 9863, 'Jake Long O Dragao Ocidental S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/268099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dnvW6S7Eh11LlapDtAjGBsmZa3K.jpg'),
(138771, 9863, 'Jake Long O Dragao Ocidental S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/268100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9IHS8BWzYdztxiYNHhB0h3h8tKK.jpg'),
(138772, 9863, 'Jake Long O Dragao Ocidental S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/268101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lLOGEAQ8wYjcql1slpUvFnoGpbp.jpg'),
(138773, 9863, 'Jake Long O Dragao Ocidental S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/268102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lHnny6rtxFF0UAb8MgG8GJi5w3G.jpg'),
(138774, 9863, 'Jake Long O Dragao Ocidental S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/268103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/plUdp3T5TjIOpYdfezzoe1CQJZ4.jpg'),
(138775, 9863, 'Jake Long O Dragao Ocidental S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/268104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kjcwW6DAz3HSXCTiqdpiaeCtLp.jpg'),
(138776, 9863, 'Jake Long O Dragao Ocidental S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/268105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cx5YcBdcafOQqKNQ3845wT6rr7Q.jpg'),
(138777, 9863, 'Jake Long O Dragao Ocidental S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/268106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fZre3cO7UM71xkxSXSFcVmoPHml.jpg'),
(138778, 9863, 'Jake Long O Dragao Ocidental S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/268107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6seoUZJ4GW3Mng7c4R96YO00nTs.jpg'),
(138779, 9863, 'Jake Long O Dragao Ocidental S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/268108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vRuPe4Mw7xXy1fOSVkd6EQcOM88.jpg'),
(138780, 9863, 'Jake Long O Dragao Ocidental S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/268109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o1qHssTd7kuTxNeZ3BgYd7TInXx.jpg'),
(138781, 9864, 'A Killer Paradox S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/271816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yp0vjgKJtNLP4HnmalWnBAtgvQS.jpg'),
(138782, 9864, 'A Killer Paradox S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/271817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vIuDKnVgngZ4EVsXKBsyC1d5SSu.jpg'),
(138783, 9864, 'A Killer Paradox S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/271818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/SrToHbiYA5diYyR0poNbfsWLBB.jpg'),
(138784, 9864, 'A Killer Paradox S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/271819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dFPwEZ6DxmGWfDgrM6gFjcsm6Zd.jpg'),
(138785, 9864, 'A Killer Paradox S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/271820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3lKsM8JZpTiWlbXbYImlg6PHSAy.jpg'),
(138786, 9864, 'A Killer Paradox S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/271821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sqBOiYO1DEHIaPmXHVp0oheCHE5.jpg'),
(138787, 9864, 'A Killer Paradox S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/271822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o0Ajl26VwWSDi6V5aJZsEv2mChG.jpg'),
(138788, 9864, 'A Killer Paradox S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/271823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hS5wWiFDMULV5PiLnMB4Vyb2tiF.jpg'),
(138789, 9865, 'Maldito Dia De Sorte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/271806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1kowNF6JoZHMr0tinQWy0sPHRAk.jpg'),
(138790, 9865, 'Maldito Dia De Sorte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/271807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f6uDLx6mRSlXRwzIBAqsUqYjeye.jpg'),
(138791, 9865, 'Maldito Dia De Sorte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/271808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zlUDgR9k3roFgfS7k75Q8QAzSTV.jpg'),
(138792, 9865, 'Maldito Dia De Sorte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/271809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/crj2t9puAs5C5Fjq26GjdynDL6l.jpg'),
(138793, 9865, 'Maldito Dia De Sorte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/271810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cCjSeVPjqVlDrkZeHwSGB8YOMAx.jpg'),
(138794, 9865, 'Maldito Dia De Sorte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/271811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8iZFxw4UKUiET2RMD4Sxo3vZLeC.jpg'),
(138795, 9865, 'Maldito Dia De Sorte S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/271812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uGdyph9KKZqvl9hxoulpwkYjVlw.jpg'),
(138796, 9865, 'Maldito Dia De Sorte S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/271813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1oXwLJvT2vJ7k3WeUyrJg8esm7W.jpg'),
(138797, 9865, 'Maldito Dia De Sorte S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/271814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2O67RNT7bproLJkex4YcVEmabUa.jpg'),
(138798, 9865, 'Maldito Dia De Sorte S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/271815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5D72GQFrQr4XShxhIhmYqOnpxSH.jpg'),
(138799, 9866, 'Luz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/271786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/76K0PllreXlj5HPmv30LnlVbRXI.jpg'),
(138800, 9866, 'Luz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/271787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pw0pJUYpvD3fwxAwCJQct2shs0K.jpg'),
(138801, 9866, 'Luz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/271788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pOdHibrEkZSk1STPxGp8DmW0bcr.jpg'),
(138802, 9866, 'Luz S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/271789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wYhTpOgZDmrlvPpNfQIrqXD4rxM.jpg'),
(138803, 9866, 'Luz S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/271790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h3EfPVI2K7g63zA2k1Ams2Y4qtW.jpg'),
(138804, 9866, 'Luz S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/271791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m3erQtgJAF3ictl2V0v48qon7vf.jpg'),
(138805, 9866, 'Luz S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/271792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ntV5uhOtyKFlcs74EQyFNWRp04I.jpg'),
(138806, 9866, 'Luz S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/271793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6GCk7DIuCA2OabDdiBenGG2tIwf.jpg'),
(138807, 9866, 'Luz S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/271794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2zOhnYzOCto2fW7Z7i08cKVjahO.jpg'),
(138808, 9866, 'Luz S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/271795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/twjuqHmu53NiChRrMFpj7lyaIJe.jpg'),
(138809, 9866, 'Luz S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/271796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lGtxLiyXOaoOAjbPphkITEce8c5.jpg'),
(138810, 9866, 'Luz S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/271797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ygpSntgraeFCBu9sbeyUAhJz3R.jpg'),
(138811, 9866, 'Luz S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/271798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t4dQzHUaoTHP4kcuCwNCaPImrhu.jpg'),
(138812, 9866, 'Luz S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/271799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dUe7nuHF7FDNe6vppktx0VtBafa.jpg'),
(138813, 9866, 'Luz S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/271800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a4tjOzMwB4NQBlSftbt1EWolOZy.jpg'),
(138814, 9866, 'Luz S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/271801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dAyappHOgfeoeTs5HVo9qPq0C5h.jpg'),
(138815, 9866, 'Luz S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/271802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3GH4vDpV8shXJVTIMHW31be6eCN.jpg'),
(138816, 9866, 'Luz S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/271803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nQLcCIFPbB3YbVaCFQfRD9xZflh.jpg'),
(138817, 9866, 'Luz S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/271804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhuWMDejulsPb1uEFL3psB6yEVJ.jpg'),
(138818, 9866, 'Luz S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/271805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7SXkk2P4VN4OztLCd745evw81p9.jpg'),
(138819, 9867, 'Bad Buddy The Series [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jmidPE9n3Ng1wYtepHkv5mfA5mJ.jpg'),
(138820, 9867, 'Bad Buddy The Series [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y0TzCdl3Z6NRnkAfXULnRTnpo9L.jpg'),
(138821, 9867, 'Bad Buddy The Series [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7QK4DAHxAcRXIfftxhLAsMlHeZh.jpg'),
(138822, 9867, 'Bad Buddy The Series [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dBU1EKQYHC5AS0F5Ai2wPA9IYRg.jpg'),
(138823, 9867, 'Bad Buddy The Series [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v73GGP1HIuNS3CkdDYUKuphv98c.jpg'),
(138824, 9867, 'Bad Buddy The Series [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t37j2WKFGr8w0BltGC3jBAM7bjy.jpg'),
(138825, 9867, 'Bad Buddy The Series [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uMBYBl9pXaOv5czZOweqN6yXRD9.jpg'),
(138826, 9867, 'Bad Buddy The Series [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/36hjm6cB5tE6p1fAomkUFvLQpdS.jpg'),
(138827, 9867, 'Bad Buddy The Series [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/273891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cyIYTzU5BhVL053E88qT9UI4ot1.jpg'),
(138828, 9867, 'Bad Buddy The Series [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/273892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Hm6wdEO0VrS0Sda95RFfTBcxO3.jpg'),
(138829, 9867, 'Bad Buddy The Series [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/273893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8EC4V5wGvCJNmyUFxkY7V53sJrS.jpg'),
(138830, 9867, 'Bad Buddy The Series [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/273894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kavn9kjNG0tjjzFcRnuJmyak99Z.jpg'),
(138831, 9868, 'Enquanto Voce Dormia [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZPmespjZOlV2dPCpAQzYKEDAUR.jpg'),
(138832, 9868, 'Enquanto Voce Dormia [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZPmespjZOlV2dPCpAQzYKEDAUR.jpg'),
(138833, 9868, 'Enquanto Voce Dormia [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bztvyvKYvjo0el1JvxYbkOS3Xvr.jpg'),
(138834, 9868, 'Enquanto Voce Dormia [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bztvyvKYvjo0el1JvxYbkOS3Xvr.jpg'),
(138835, 9868, 'Enquanto Voce Dormia [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9HWlDO4cOc6hcOQjZjBogT9MtKu.jpg'),
(138836, 9868, 'Enquanto Voce Dormia [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9HWlDO4cOc6hcOQjZjBogT9MtKu.jpg'),
(138837, 9868, 'Enquanto Voce Dormia [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8oPcXz5W0ErwNqWvnU6gCIYaXSz.jpg'),
(138838, 9868, 'Enquanto Voce Dormia [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8oPcXz5W0ErwNqWvnU6gCIYaXSz.jpg'),
(138839, 9868, 'Enquanto Voce Dormia [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/273875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kICJvs6zsrACGi1KMmDkgexYLKj.jpg'),
(138840, 9868, 'Enquanto Voce Dormia [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/273876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kICJvs6zsrACGi1KMmDkgexYLKj.jpg'),
(138841, 9868, 'Enquanto Voce Dormia [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/273877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oSQC4NzPBhymcKLA82IYb4sxqTQ.jpg'),
(138842, 9868, 'Enquanto Voce Dormia [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/273878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oSQC4NzPBhymcKLA82IYb4sxqTQ.jpg'),
(138843, 9868, 'Enquanto Voce Dormia [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/273879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mKeFEHde9gCazzJwd0Sd99ZCg7s.jpg'),
(138844, 9868, 'Enquanto Voce Dormia [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/273880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mKeFEHde9gCazzJwd0Sd99ZCg7s.jpg'),
(138845, 9868, 'Enquanto Voce Dormia [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/273881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uQyHQtBMzoekCgRfs5CsoCYcNAJ.jpg'),
(138846, 9868, 'Enquanto Voce Dormia [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/273882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uQyHQtBMzoekCgRfs5CsoCYcNAJ.jpg'),
(138847, 9869, 'Equal [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hzXurR3MGBwbUIz4GXphxtUIcMa.jpg'),
(138848, 9869, 'Equal [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3m3wUNiLHDXOfMP0WWgWTrBXhnb.jpg'),
(138849, 9869, 'Equal [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dxMoEi5i4nOlKuKVj5HJgkrntqy.jpg'),
(138850, 9869, 'Equal [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aa5Wx2P2LTd66yWGfYdOxt12zCY.jpg'),
(138851, 9870, 'Hard Knocks in Season The Miami Dolphins [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UIIgehamg7AQctZk9gJittq6p1.jpg'),
(138852, 9870, 'Hard Knocks in Season The Miami Dolphins [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UIIgehamg7AQctZk9gJittq6p1.jpg'),
(138853, 9870, 'Hard Knocks in Season The Miami Dolphins [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UIIgehamg7AQctZk9gJittq6p1.jpg'),
(138854, 9870, 'Hard Knocks in Season The Miami Dolphins [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UIIgehamg7AQctZk9gJittq6p1.jpg'),
(138855, 9870, 'Hard Knocks in Season The Miami Dolphins [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UIIgehamg7AQctZk9gJittq6p1.jpg'),
(138856, 9870, 'Hard Knocks in Season The Miami Dolphins [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UIIgehamg7AQctZk9gJittq6p1.jpg'),
(138857, 9870, 'Hard Knocks in Season The Miami Dolphins [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UIIgehamg7AQctZk9gJittq6p1.jpg'),
(138858, 9870, 'Hard Knocks in Season The Miami Dolphins [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UIIgehamg7AQctZk9gJittq6p1.jpg'),
(138859, 9870, 'Hard Knocks in Season The Miami Dolphins [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/273862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4UIIgehamg7AQctZk9gJittq6p1.jpg'),
(138860, 9871, 'Hay algo en el bosque S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tYjgUZZ1vXFNeKsGjYJaPBv72Mz.jpg'),
(138861, 9871, 'Hay algo en el bosque S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wMkahTeRP9DyBUhTZpxgItUizNl.jpg'),
(138862, 9871, 'Hay algo en el bosque S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vetU9w7TpRea4SNpMJlA7eIMUcb.jpg'),
(138863, 9871, 'Hay algo en el bosque S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LOSf7YRReIKYlZrHaJyQJO5XHh.jpg'),
(138864, 9871, 'Hay algo en el bosque S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ydqcZgoF4PAJlOSXawsNI6VZAR.jpg'),
(138865, 9871, 'Hay algo en el bosque S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6NoxUmJRngOrzFS3K0GNq9Hr2Om.jpg'),
(138866, 9871, 'Hay algo en el bosque S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o97Rmz1ru7w6ztmxLgciEjnqDBR.jpg'),
(138867, 9871, 'Hay algo en el bosque S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8JuhALhL5fwEaUclEXLvSJSjsWs.jpg'),
(138868, 9872, 'House of Ninjas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AlXpz6vXVSpiWYCkUmv2udY2iTP.jpg'),
(138869, 9872, 'House of Ninjas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gtdmqPYrdALtq9NxeuxRXEjDbs0.jpg'),
(138870, 9872, 'House of Ninjas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4QoCKPQVmS6UuehiBbtYBGulMVt.jpg'),
(138871, 9872, 'House of Ninjas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qrZJyLiVkNeVE8VYWirzMjmJEUV.jpg'),
(138872, 9872, 'House of Ninjas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMkWx0e6DDl7nQtgfbZjtZsZNQw.jpg'),
(138873, 9872, 'House of Ninjas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lPrR0XBgDjYLggOgPXIQTgMj5Hj.jpg'),
(138874, 9872, 'House of Ninjas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/laH3xdQqQoC39YErJI14371s88a.jpg'),
(138875, 9872, 'House of Ninjas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rTxt5S74reXiEmzAQgTWTe6F2Yo.jpg'),
(138876, 9873, 'Israel Uma Terra Duplamente Prometida [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zI7awN5bS87towuhZ3SnSOdk7ie.jpg'),
(138877, 9873, 'Israel Uma Terra Duplamente Prometida [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cn3kdByzDPCCryjDcq7t8TP4nUK.jpg'),
(138878, 9742, 'Kingdom [L] (2012) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pockLHjj00wSxzcZR4oGgXSfWO1.jpg'),
(138879, 9742, 'Kingdom [L] (2012) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hN9n59vsEWVCu16EX0DSORUMhac.jpg'),
(138880, 9742, 'Kingdom [L] (2012) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xtQsxhJPiE2cLwlk76VUpfXsORt.jpg'),
(138881, 9742, 'Kingdom [L] (2012) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vr3BFlbgdB1zUqM9bwT3UFTwFD7.jpg'),
(138882, 9742, 'Kingdom [L] (2012) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9YEgiJZisZ0jx44GWab2pUEb606.jpg'),
(138883, 9742, 'Kingdom [L] (2012) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13hF0KrNYJlM4UAAWsfuxO9MGdx.jpg'),
(138884, 9742, 'Kingdom [L] (2012) S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6etlFDpGuD62GGeL2yu4ZBrxToe.jpg'),
(138885, 9742, 'Kingdom [L] (2012) S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gjXjSmnYDduabO3lzesuUZT4fcx.jpg'),
(138886, 9742, 'Kingdom [L] (2012) S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/273736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Dfg2WHhGfWPuhc0nVFem1gLlq0.jpg'),
(138887, 9742, 'Kingdom [L] (2012) S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/273737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1TXMqA271UymrT41oAplbtombCH.jpg'),
(138888, 9742, 'Kingdom [L] (2012) S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/273738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9O0xeBym43IxRVepqa7IL3tSsr8.jpg'),
(138889, 9742, 'Kingdom [L] (2012) S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/273739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m0jW0K9c298YgjPdOYYdrmwhIYu.jpg'),
(138890, 9742, 'Kingdom [L] (2012) S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/273740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/du6c6O3VsZb4Qzgmiw4CR8y5in1.jpg'),
(138891, 9742, 'Kingdom [L] (2012) S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/273741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xyNtEsvd8wDMmAuvgbgK6nTXGTG.jpg'),
(138892, 9742, 'Kingdom [L] (2012) S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/273742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4xDkQrNghNOGdavzLfl1NxznCKT.jpg'),
(138893, 9742, 'Kingdom [L] (2012) S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/273743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDvE4MvasdjuAPJuaOOMbz3nk36.jpg'),
(138894, 9742, 'Kingdom [L] (2012) S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/273744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7cLQsbtoZMyFrO7Py7WjQDvoGI0.jpg'),
(138895, 9742, 'Kingdom [L] (2012) S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/273745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rFAyqBKmShGJW0rdCIsjNehPj5r.jpg'),
(138896, 9742, 'Kingdom [L] (2012) S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/273746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6woEbpz7U2bE5ytcD9TjylAHRh.jpg'),
(138897, 9742, 'Kingdom [L] (2012) S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/273747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sX9jsR7w9BWfcYmEszOTsOXLCKs.jpg'),
(138898, 9742, 'Kingdom [L] (2012) S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/273748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ddTUfleyP9dITUebfpYMhINgzho.jpg'),
(138899, 9742, 'Kingdom [L] (2012) S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/273749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q19pFbhSYmYXZcQzJNK4yLY6YtB.jpg'),
(138900, 9742, 'Kingdom [L] (2012) S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/273750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qD82oa1W8gT4CD6hBSHZ4nzfZ3N.jpg'),
(138901, 9742, 'Kingdom [L] (2012) S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/273751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q8OWgXlXlut4VPbYGjOu4fe8ooH.jpg'),
(138902, 9742, 'Kingdom [L] (2012) S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/273752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pf5c1nxCGpqnnpM6U44TstyfnXZ.jpg'),
(138903, 9742, 'Kingdom [L] (2012) S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/273753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8XNr7DJdx3CgIDZLt7bkS1LPHWb.jpg'),
(138904, 9742, 'Kingdom [L] (2012) S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/273754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/feXqIRISJEYzcxBrbZwdXecOV9l.jpg'),
(138905, 9742, 'Kingdom [L] (2012) S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/273755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fV3kv1GRzOb3YvCnKET8xaktHgW.jpg'),
(138906, 9742, 'Kingdom [L] (2012) S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/273756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bAalxMhUlv0rSW4wswuXaJvSnfa.jpg'),
(138907, 9742, 'Kingdom [L] (2012) S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/273757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cINI0sCgQ4lU7EaJbzHc96Dmg82.jpg'),
(138908, 9742, 'Kingdom [L] (2012) S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/273758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/84Py3LUpiGVead9wGtCVK0QKu1E.jpg'),
(138909, 9742, 'Kingdom [L] (2012) S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/273759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBMDCmw26MWdvCHU9NAr8WawOJs.jpg'),
(138910, 9742, 'Kingdom [L] (2012) S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/273760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xx5mMMf9mPW8nRWqt4IjDoo56iG.jpg'),
(138911, 9742, 'Kingdom [L] (2012) S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/273761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Qf3zsCXghCsxpdWbacDanupUO6.jpg'),
(138912, 9742, 'Kingdom [L] (2012) S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/273762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cfKp4VyOgQ5Giz9UmMzz2jQ5TTj.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(138913, 9742, 'Kingdom [L] (2012) S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/273763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/srsy02RNiYsprkbRhUdelj2EcQZ.jpg'),
(138914, 9742, 'Kingdom [L] (2012) S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/273764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9vgAojMZy3XSLRNwNPUQ6gb6yiN.jpg'),
(138915, 9742, 'Kingdom [L] (2012) S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/273765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iNjDLzag5ILlVr6859xA4lUYL4l.jpg'),
(138916, 9743, 'Kingdom [L] (2012) S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AkFBzMwcBxkAIYFy6s1YbppOhUU.jpg'),
(138917, 9743, 'Kingdom [L] (2012) S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rMhnmCUs7vhPc4F48xjoCeeT5k1.jpg'),
(138918, 9743, 'Kingdom [L] (2012) S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zEEcbBeD6bATFm87c3GiujA3Jpz.jpg'),
(138919, 9743, 'Kingdom [L] (2012) S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fsIzkuLRiJpJssu91byk48R2IeG.jpg'),
(138920, 9743, 'Kingdom [L] (2012) S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6KPVVhUlIqucn1V9tu0PoXjvxRl.jpg'),
(138921, 9743, 'Kingdom [L] (2012) S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bSQ2lo1dsy0451ZNnPv9tlAOMIT.jpg'),
(138922, 9743, 'Kingdom [L] (2012) S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mIEoyynP9ljxr6DcaQ1O3mBEHyS.jpg'),
(138923, 9743, 'Kingdom [L] (2012) S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kyolUCxch9BIOzooGPTiz5VgxOr.jpg'),
(138924, 9743, 'Kingdom [L] (2012) S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/273774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/btfjfe6ZTTWb19h5jwDqhMVOxZW.jpg'),
(138925, 9743, 'Kingdom [L] (2012) S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/273775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sVkYrSxUIURX8nSt7ZKmbkBdaHQ.jpg'),
(138926, 9743, 'Kingdom [L] (2012) S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/273776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wmdUgwtKzdW0qnulAg4ynYhLsbg.jpg'),
(138927, 9743, 'Kingdom [L] (2012) S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/273777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ei8AxFzBYpvUbr0tpvkC2jGYY42.jpg'),
(138928, 9743, 'Kingdom [L] (2012) S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/273778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zmpuVZTe5zLv7MecIrFPKn07VpN.jpg'),
(138929, 9743, 'Kingdom [L] (2012) S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/273779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4QJffo1AMX8EmlZMjAjrrAVsL3x.jpg'),
(138930, 9743, 'Kingdom [L] (2012) S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/273780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Liu50zgXBEPm7CClr0I0wm4xzU.jpg'),
(138931, 9743, 'Kingdom [L] (2012) S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/273781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wvJVefXBbF931RtztPt431XIUxt.jpg'),
(138932, 9743, 'Kingdom [L] (2012) S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/273782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lMaxO1ujGIB7uXe7RqIB7yHO493.jpg'),
(138933, 9743, 'Kingdom [L] (2012) S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/273783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fq0pJT6hIglI3RYARvTv0ihhnH4.jpg'),
(138934, 9743, 'Kingdom [L] (2012) S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/273784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMri0GuWN7KJGOuEc1O2gFfVupW.jpg'),
(138935, 9743, 'Kingdom [L] (2012) S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/273785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dBS7PU6Bh3GTlHixpqmvGGqOTkf.jpg'),
(138936, 9743, 'Kingdom [L] (2012) S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/273786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/41PXyubfIioTlMKibKvmHA2xJoj.jpg'),
(138937, 9743, 'Kingdom [L] (2012) S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/273787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/TYCfrH6vb4XwxrYgF31WQ1agIb.jpg'),
(138938, 9743, 'Kingdom [L] (2012) S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/273788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vB0Pjp3kAy0bqS884T2cCWLzz3H.jpg'),
(138939, 9743, 'Kingdom [L] (2012) S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/273789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/JzIYu0oVysmSEWdGhPcVaHuyvJ.jpg'),
(138940, 9743, 'Kingdom [L] (2012) S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/273790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pGid40DHzY5mRkOf3W2hLwaQQx0.jpg'),
(138941, 9743, 'Kingdom [L] (2012) S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/273791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ppDDPXUzSktrYvobnbSjri8Xb3S.jpg'),
(138942, 9743, 'Kingdom [L] (2012) S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/273792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6JenAFidJC3WXpkzGnVAASRkQk.jpg'),
(138943, 9743, 'Kingdom [L] (2012) S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/273793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c3zQM0lLv7zomgyQCs1H9IUtOrs.jpg'),
(138944, 9743, 'Kingdom [L] (2012) S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/273794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gNIH2ABr9xDizqnR6mem9aBOisH.jpg'),
(138945, 9743, 'Kingdom [L] (2012) S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/273795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUKhvFeQxSeQ6v49PqMx00f1j4U.jpg'),
(138946, 9743, 'Kingdom [L] (2012) S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/273796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aKcNCteL0DlsScoe9eLapBWXmMW.jpg'),
(138947, 9743, 'Kingdom [L] (2012) S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/273797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d2LoZ80QFX6J2dv1Eh84CM8a5H3.jpg'),
(138948, 9743, 'Kingdom [L] (2012) S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/273798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m9bxwG6B5xozkn0OjxKQdXTzjBe.jpg'),
(138949, 9743, 'Kingdom [L] (2012) S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/273799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bBJbAu7fZHs2dNXdpuH1koWCkNG.jpg'),
(138950, 9743, 'Kingdom [L] (2012) S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/273800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wfhf8rM1kPgBjagcvMNk4qK3itA.jpg'),
(138951, 9743, 'Kingdom [L] (2012) S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/273801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oGSNZKWfes4pUaleWPHExeQPpQF.jpg'),
(138952, 9743, 'Kingdom [L] (2012) S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/273802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2F5KV6dx79NhboOzeJAnmNVKeoz.jpg'),
(138953, 9743, 'Kingdom [L] (2012) S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/273803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dINCvVq1ikePAXt49i3l0EISLUW.jpg'),
(138954, 9743, 'Kingdom [L] (2012) S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/273804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bTg0iMfWGKOYd9cbnZELo4QLW52.jpg'),
(138955, 9744, 'Kingdom [L] (2012) S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qn9LwFPdoRFW5Vv9cu9Y4xlwVaI.jpg'),
(138956, 9744, 'Kingdom [L] (2012) S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mWurmPaP6s6wxmQlvlwM4afy7gX.jpg'),
(138957, 9744, 'Kingdom [L] (2012) S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uCBzPz3cJlczW52NlY0YxiHSk45.jpg'),
(138958, 9744, 'Kingdom [L] (2012) S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xnXoOJNkYv3aI943aYPpp4bF9Hr.jpg'),
(138959, 9744, 'Kingdom [L] (2012) S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MGH56X5TdOVQd13FmRMHi3WymW.jpg'),
(138960, 9744, 'Kingdom [L] (2012) S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xdCKpJTPh51z0yWgnoILyjdAsTm.jpg'),
(138961, 9744, 'Kingdom [L] (2012) S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBXgRArrrA7h8Jrl1ZP9dTjfe4M.jpg'),
(138962, 9744, 'Kingdom [L] (2012) S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/discqMSZ7nTk1BcHqr3pTRLBZhl.jpg'),
(138963, 9744, 'Kingdom [L] (2012) S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/273813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yYzcQAdHUEl2pYkYFPC37XNhtYL.jpg'),
(138964, 9744, 'Kingdom [L] (2012) S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/273814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gMSDcV5aQ52YDNs2cdpwgqgQYyL.jpg'),
(138965, 9744, 'Kingdom [L] (2012) S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/273815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o1NV09Nnv0Wx8MGIBIpjtG1rU3u.jpg'),
(138966, 9744, 'Kingdom [L] (2012) S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/273816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKXaBlipVvdwy7SxkZlPu8OM0k9.jpg'),
(138967, 9744, 'Kingdom [L] (2012) S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/273817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vYKgP1Xw8FLfnZCjwdr9FJ3OZe.jpg'),
(138968, 9744, 'Kingdom [L] (2012) S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/273818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9HW9MYtXKMItPxNz9HUuNxOP4kF.jpg'),
(138969, 9744, 'Kingdom [L] (2012) S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/273819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iIwsZ4oXDoH7Vql2jbMNgLP3Ex.jpg'),
(138970, 9744, 'Kingdom [L] (2012) S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/273820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wvkGzeVFI7wAy7Ke6b4QCWUDsAx.jpg'),
(138971, 9744, 'Kingdom [L] (2012) S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/273821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBolGeatRDz5kY2SV8EtJ6FXBys.jpg'),
(138972, 9744, 'Kingdom [L] (2012) S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/273822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i015ucHiHwyqbgs4LIVosg7Phi4.jpg'),
(138973, 9744, 'Kingdom [L] (2012) S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/273823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZBp9Qwfl0lOpQdL5EpVk4xSU95.jpg'),
(138974, 9744, 'Kingdom [L] (2012) S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/273824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rFqato1FB6BJ8pnlP8g00W37TZA.jpg'),
(138975, 9744, 'Kingdom [L] (2012) S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/273825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJLaVfItvi9RBqrENpFrBTRPPbY.jpg'),
(138976, 9744, 'Kingdom [L] (2012) S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/273826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVEJiNa6qp1aEGtMT6f1JVUbfqm.jpg'),
(138977, 9744, 'Kingdom [L] (2012) S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/273827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o42luESWDblD8xRQajV0gKA1XTr.jpg'),
(138978, 9744, 'Kingdom [L] (2012) S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/273828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aY0doUKJJshywrOpAbOx0C925jO.jpg'),
(138979, 9744, 'Kingdom [L] (2012) S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/273829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MofTH4CLvJIjwJlQ7GAgjm4yeU.jpg'),
(138980, 9744, 'Kingdom [L] (2012) S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/273830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dALn1TG96d8U7AXPZINey93nWzb.jpg'),
(138981, 9746, 'Kingdom [L] (2012) S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ooWxOAjk51eOJlyoG8KEEWLklzN.jpg'),
(138982, 9746, 'Kingdom [L] (2012) S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gTdbHkA3aQ87Qgj24K93iK1vXgI.jpg'),
(138983, 9746, 'Kingdom [L] (2012) S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wsPFjN9dlucR9aXoThihlO8XWx5.jpg'),
(138984, 9746, 'Kingdom [L] (2012) S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8BZgFDv6Ebwl4dYKVx2s0pQ5Lso.jpg'),
(138985, 9746, 'Kingdom [L] (2012) S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A0DzfR50cyz2Mn0MIVgAspkpF5R.jpg'),
(138986, 9874, 'Ku Klux Klan Uma Historia Americana [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOuBw5eETRxmABydFp2DTEg4iXr.jpg'),
(138987, 9874, 'Ku Klux Klan Uma Historia Americana [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aCg0Xpa5LmVEVKKPOInrD81nEXi.jpg'),
(138988, 9875, 'Loucos Por Pimenta [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7HRTgLCW71LeFvW9N5JAbkTURh.jpg'),
(138989, 9875, 'Loucos Por Pimenta [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bMA1JNEFvS5FqSG5Rgrg3Pl5Z0a.jpg'),
(138990, 9875, 'Loucos Por Pimenta [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xqEUQGADTv1zFbzA0vg6HYyjl9D.jpg'),
(138991, 9875, 'Loucos Por Pimenta [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xLQQ6mvy8HjMh5oDfVnYKyGsLhy.jpg'),
(138992, 9875, 'Loucos Por Pimenta [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/585o3moMTLx5ADUAWzYGuyf4ha2.jpg'),
(138993, 9875, 'Loucos Por Pimenta [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qFLSd82SBdebQHPBm4AkayJdynU.jpg'),
(138994, 9875, 'Loucos Por Pimenta [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vCcZdri7U0BlMyEeuXVzqN6okDf.jpg'),
(138995, 9875, 'Loucos Por Pimenta [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/929nIt2h3SRngS0alSCPVRo7qH4.jpg'),
(138996, 9875, 'Loucos Por Pimenta [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/273724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9GtjSbDaaoNph4FnCoFYJXsGLXY.jpg'),
(138997, 9875, 'Loucos Por Pimenta [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/273725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4WfmwoDwCxZC0n5CSjn4KgJ11b.jpg'),
(138998, 9876, 'Misterios do Arquivo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uwWogIlniW4zwPUTbXo7rwr90nR.jpg'),
(138999, 9876, 'Misterios do Arquivo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6GFl2NOYOUHeEENPhMuL34vEghW.jpg'),
(139000, 9876, 'Misterios do Arquivo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vTX3wemrTApwOSJsfcPh5z822hz.jpg'),
(139001, 9876, 'Misterios do Arquivo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p9DgQsaX2Lv0mruvRYeJXlWL9VG.jpg'),
(139002, 9876, 'Misterios do Arquivo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sLTDxZG4NgWwV0vkKFmq8Uew1gm.jpg'),
(139003, 9876, 'Misterios do Arquivo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4FycmmfsguGYjr93uG62aNcPOPI.jpg'),
(139004, 9876, 'Misterios do Arquivo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jIlJCgc3Mgt9vRezp01AQijjfOu.jpg'),
(139005, 9876, 'Misterios do Arquivo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bijVhCNUF7vOc9LdFYSY6fQg1lN.jpg'),
(139006, 9876, 'Misterios do Arquivo [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/273714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mfLgaUwHYjCLXHXVYGVow8faHUO.jpg'),
(139007, 9876, 'Misterios do Arquivo [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/273715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s2rN5xoANoUjDBfvpWUEWpurDSF.jpg'),
(139008, 9877, 'O que Possuimos O Conceito de Propriedade ao Redor do Mundo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63wCZcFPlGr8jDj5Vv1OmBNfWQV.jpg'),
(139009, 9877, 'O que Possuimos O Conceito de Propriedade ao Redor do Mundo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3XaugWf0KD3qN3P1scLtnMqhF2o.jpg'),
(139010, 9877, 'O que Possuimos O Conceito de Propriedade ao Redor do Mundo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mvJzgeGjRZd8nSS74o81n6yGcjp.jpg'),
(139011, 9877, 'O que Possuimos O Conceito de Propriedade ao Redor do Mundo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bBxyUQP7Z0IBrBTzAvuSBQNtB6.jpg'),
(139012, 9878, 'The New Look S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2jOUliP7d1SYijR1Qs4ftP6vVkM.jpg'),
(139013, 9878, 'The New Look S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5eC0VKiKFJddS0kkibrZs5P5rvm.jpg'),
(139014, 9878, 'The New Look S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iUa0CfTl9gPFQv8ARxdCRdffb9U.jpg'),
(139015, 9878, 'The New Look S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/279407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQBpF8VmEIgow41OL9h4nU4WN6v.jpg'),
(139016, 9878, 'The New Look S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/288404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQBpF8VmEIgow41OL9h4nU4WN6v.jpg'),
(139017, 9878, 'The New Look S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/293947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQBpF8VmEIgow41OL9h4nU4WN6v.jpg'),
(139018, 9878, 'The New Look S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/299761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQBpF8VmEIgow41OL9h4nU4WN6v.jpg'),
(139019, 9878, 'The New Look S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/303815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQBpF8VmEIgow41OL9h4nU4WN6v.jpg'),
(139020, 9878, 'The New Look S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/309568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQBpF8VmEIgow41OL9h4nU4WN6v.jpg'),
(139021, 9878, 'The New Look S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/316995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQBpF8VmEIgow41OL9h4nU4WN6v.jpg'),
(139022, 9879, 'Uma Verdadeira Vida de Inseto [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n35XgbwAYrXjxCXHr07TW0vSl0H.jpg'),
(139023, 9879, 'Uma Verdadeira Vida de Inseto [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/klMSnHNcJnzHxQMMboxCD95lxZh.jpg'),
(139024, 9879, 'Uma Verdadeira Vida de Inseto [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9j333Pv1YKf6Ib9nMFxmgrYUprV.jpg'),
(139025, 9879, 'Uma Verdadeira Vida de Inseto [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tNCQq0754VCvndl6cjV1FNyWYKs.jpg'),
(139026, 9879, 'Uma Verdadeira Vida de Inseto [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wwAVPVfBgyNzqlN5hcRDRNjqXMI.jpg'),
(139027, 9880, 'Nova York Contra o Crime [L] (1993) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/86pliv59X46KJgYZw6kUPPQhrkt.jpg'),
(139028, 9880, 'Nova York Contra o Crime [L] (1993) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hyZCsyGBY4etCPYNMNFBo13WcGZ.jpg'),
(139029, 9880, 'Nova York Contra o Crime [L] (1993) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bcCFr6bZawA8gGepKUwfzSzcePC.jpg'),
(139030, 9880, 'Nova York Contra o Crime [L] (1993) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qhnQZNVFUVnGSacjHd9ThQOtIZx.jpg'),
(139031, 9880, 'Nova York Contra o Crime [L] (1993) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/paiPlFqZEwxQzdr4HMRWxe7NPV2.jpg'),
(139032, 9880, 'Nova York Contra o Crime [L] (1993) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCbFtBFPO7EV9oxcAD2Oqa32bwm.jpg'),
(139033, 9880, 'Nova York Contra o Crime [L] (1993) S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kM2l0mfsl3VNGRQwXNfSjXKe4mE.jpg'),
(139034, 9880, 'Nova York Contra o Crime [L] (1993) S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uVBhA9IklOy2MKsp9fAl4xT9wGw.jpg'),
(139035, 9880, 'Nova York Contra o Crime [L] (1993) S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/273465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bv04u3kZqnTRRjzsmC5qY3YbzZ7.jpg'),
(139036, 9880, 'Nova York Contra o Crime [L] (1993) S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/273466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKHiniZKHzBp70hzUMe7l0MotFU.jpg'),
(139037, 9880, 'Nova York Contra o Crime [L] (1993) S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/273467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aORU7c82eH6R04eiYE0g07C1fTp.jpg'),
(139038, 9880, 'Nova York Contra o Crime [L] (1993) S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/273468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vvi2dWHzvF4bt47aHufYPUazYde.jpg'),
(139039, 9880, 'Nova York Contra o Crime [L] (1993) S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/273469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pG6ZEsvhoxhHTGdVCR7w4JsPXEG.jpg'),
(139040, 9880, 'Nova York Contra o Crime [L] (1993) S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/273470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vRFdAWyFUj5cIIdsCPeen1rhVgh.jpg'),
(139041, 9880, 'Nova York Contra o Crime [L] (1993) S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/273471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDiaGAax6miHyJmBtxAG1CRp4qQ.jpg'),
(139042, 9880, 'Nova York Contra o Crime [L] (1993) S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/273472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sejwPsN5i4ssT9NlEiSCCUNmayA.jpg'),
(139043, 9880, 'Nova York Contra o Crime [L] (1993) S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/273473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1it9V9gysbcaSlnWKtQcCUIpgvG.jpg'),
(139044, 9880, 'Nova York Contra o Crime [L] (1993) S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/273474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3XV5L30YJ4Urhei3NQxRq5rGUDn.jpg'),
(139045, 9880, 'Nova York Contra o Crime [L] (1993) S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/273475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c9suy9myzbHYOQYw7uuW5srWGvd.jpg'),
(139046, 9880, 'Nova York Contra o Crime [L] (1993) S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/273476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rMSstzCre8ESi7pNwEGESczYE3k.jpg'),
(139047, 9880, 'Nova York Contra o Crime [L] (1993) S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/273477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQ5MGQuf4j6JH5vpiBA1UUcugld.jpg'),
(139048, 9880, 'Nova York Contra o Crime [L] (1993) S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/273478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7DZGRVPEEOUUYRHd14G0Oa6AWw8.jpg'),
(139049, 9881, 'Nova York Contra o Crime [L] (1993) S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oN1xM8lMH1aj1aH87lCeR7btVKf.jpg'),
(139050, 9881, 'Nova York Contra o Crime [L] (1993) S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l24dDjAMpB5w6RiUoi6vPaiz7jN.jpg'),
(139051, 9881, 'Nova York Contra o Crime [L] (1993) S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jdklv5WaBab5Fe4MWMrfAfcnl0g.jpg'),
(139052, 9881, 'Nova York Contra o Crime [L] (1993) S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wadxuOi8Xbtl8VkRBYdShpU0X7w.jpg'),
(139053, 9881, 'Nova York Contra o Crime [L] (1993) S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2bmF0YEOeWmN25CibQjWuv8jYXe.jpg'),
(139054, 9881, 'Nova York Contra o Crime [L] (1993) S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l8ub7oDT1NOlm8BpedzIlAuyADH.jpg'),
(139055, 9881, 'Nova York Contra o Crime [L] (1993) S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fvTMZ659IxNj1VNAz3lNlfFVuAU.jpg'),
(139056, 9881, 'Nova York Contra o Crime [L] (1993) S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bwnWaz3Uk0clW8MN8MqFVxyNRag.jpg'),
(139057, 9881, 'Nova York Contra o Crime [L] (1993) S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/273487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6jn0ep7oHKmSy6ofljR9Wb5FYo6.jpg'),
(139058, 9881, 'Nova York Contra o Crime [L] (1993) S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/273488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7cFjbhhPToq0Gd8eNrYqQcukUWU.jpg'),
(139059, 9881, 'Nova York Contra o Crime [L] (1993) S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/273489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/arHZrWExikGYhPQndx3XPB5vlVd.jpg'),
(139060, 9881, 'Nova York Contra o Crime [L] (1993) S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/273490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJuM6C6MGRCzeT85ZzsG36PG01m.jpg'),
(139061, 9881, 'Nova York Contra o Crime [L] (1993) S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/273491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dHUOGUc0PfaF7Dv7ddYVQDWFp30.jpg'),
(139062, 9881, 'Nova York Contra o Crime [L] (1993) S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/273492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/93iAEh3RiTkAluNMOP8xW1QfQvG.jpg'),
(139063, 9881, 'Nova York Contra o Crime [L] (1993) S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/273493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/giYxx1TBzyqURkXWeM94iAgT8mv.jpg'),
(139064, 9881, 'Nova York Contra o Crime [L] (1993) S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/273494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qKlDlAsG0HiJ0w7KqspKmIbtkdF.jpg'),
(139065, 9881, 'Nova York Contra o Crime [L] (1993) S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/273495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d589TciCngsbqdjw2wzrzC5bPCo.jpg'),
(139066, 9881, 'Nova York Contra o Crime [L] (1993) S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/273496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y0UXZ1sSZbLeo9NQq5na47whlsK.jpg'),
(139067, 9881, 'Nova York Contra o Crime [L] (1993) S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/273497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l7reunz7OkY4qZzuZ9VCtu7axkq.jpg'),
(139068, 9881, 'Nova York Contra o Crime [L] (1993) S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/273498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zeEHshI4h6PXeT2S4smdnrvyShc.jpg'),
(139069, 9881, 'Nova York Contra o Crime [L] (1993) S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/273499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xT3atTQqkASq1OX3sdtaeTqvgja.jpg'),
(139070, 9881, 'Nova York Contra o Crime [L] (1993) S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/273500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hfMbgHKkqdG0SFkPo7cNGC09Md9.jpg'),
(139071, 9882, 'Nova York Contra o Crime [L] (1993) S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZYhBup2Sznsess1BegEs7tQMEO.jpg'),
(139072, 9882, 'Nova York Contra o Crime [L] (1993) S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wDioRUGzqg4MIwVSTDMndYFgDq6.jpg'),
(139073, 9882, 'Nova York Contra o Crime [L] (1993) S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rwJemtvCvL2wFX62IgfsX8Lx3F4.jpg'),
(139074, 9882, 'Nova York Contra o Crime [L] (1993) S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kfnimcBluYXeYWelFCe7yqlDrcS.jpg'),
(139075, 9882, 'Nova York Contra o Crime [L] (1993) S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNFTQdcNZS1dfvN4wNGeWAdRGsc.jpg'),
(139076, 9882, 'Nova York Contra o Crime [L] (1993) S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mlemi69wAo9wjXHzYDRGR2CVTvy.jpg'),
(139077, 9882, 'Nova York Contra o Crime [L] (1993) S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5eJ7UzKA97aDVjLFWV6RfqRQUC.jpg'),
(139078, 9882, 'Nova York Contra o Crime [L] (1993) S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AqLbrdebN7HYbKsZ0gAg6OW800t.jpg'),
(139079, 9882, 'Nova York Contra o Crime [L] (1993) S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/273509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yrdm5F9Zfv3IsZUzdmyTbtWgFq5.jpg'),
(139080, 9882, 'Nova York Contra o Crime [L] (1993) S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/273510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5av7DOPqw9kPCGHBbmHJBUSgQBI.jpg'),
(139081, 9882, 'Nova York Contra o Crime [L] (1993) S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/273511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9O1RKpaLOuhdNoOaNviywzfSXtZ.jpg'),
(139082, 9882, 'Nova York Contra o Crime [L] (1993) S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/273512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tU4pRKJZZ7YOPteayVqIxFBSNqt.jpg'),
(139083, 9882, 'Nova York Contra o Crime [L] (1993) S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/273513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9CZvWf3M8zVakFzoltQH5ayMcp0.jpg'),
(139084, 9882, 'Nova York Contra o Crime [L] (1993) S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/273514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glCvvrUtsSeul7eujdHw2PqJs8R.jpg'),
(139085, 9882, 'Nova York Contra o Crime [L] (1993) S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/273515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bcBTI3xkHmMP9ZHERgReIHYxH7N.jpg'),
(139086, 9882, 'Nova York Contra o Crime [L] (1993) S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/273516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBbbfmevcu8dFhX04U6TO8h5ufG.jpg'),
(139087, 9882, 'Nova York Contra o Crime [L] (1993) S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/273517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6nrHpiamRBFN5XpKqddzXkK5NWF.jpg'),
(139088, 9882, 'Nova York Contra o Crime [L] (1993) S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/273518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/CseqgucZxG6SC1xuX2Q9lM6Uiu.jpg'),
(139089, 9882, 'Nova York Contra o Crime [L] (1993) S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/273519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uIxkWEVoqmx3edT98m6MQRIxYnP.jpg'),
(139090, 9882, 'Nova York Contra o Crime [L] (1993) S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/273520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iaCOwN9wVaZXdb3ypyy4flanw2P.jpg'),
(139091, 9882, 'Nova York Contra o Crime [L] (1993) S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/273521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jsoqJ9oMKsvhnQBue056Bb0IWr5.jpg'),
(139092, 9882, 'Nova York Contra o Crime [L] (1993) S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/273522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fbrDH15yy9kcFDfsbMvTDCNydsh.jpg'),
(139093, 9883, 'Nova York Contra o Crime [L] (1993) S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/70E1bsLwbrSCriE06uFcxAn66Zn.jpg'),
(139094, 9883, 'Nova York Contra o Crime [L] (1993) S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sV4b8JBS7ThAD3PI4tv9NtxT1R5.jpg'),
(139095, 9883, 'Nova York Contra o Crime [L] (1993) S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jUyQ6b89KE9vPE7FnbxZsvvNPoa.jpg'),
(139096, 9883, 'Nova York Contra o Crime [L] (1993) S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8LrttoZLESBWRYRKMDBYoPEk8Sm.jpg'),
(139097, 9883, 'Nova York Contra o Crime [L] (1993) S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oPPrGh7TxW8V15rKME4wJZmGMja.jpg'),
(139098, 9883, 'Nova York Contra o Crime [L] (1993) S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fuINSvdytvRMPfAKESfTthU39i3.jpg'),
(139099, 9883, 'Nova York Contra o Crime [L] (1993) S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1VEJGKF6dyXBwyjLVbFXM8TDHiZ.jpg'),
(139100, 9883, 'Nova York Contra o Crime [L] (1993) S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xAPoXR77TlLqoNwocewueGOGRKq.jpg'),
(139101, 9883, 'Nova York Contra o Crime [L] (1993) S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/273531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vl7H1VIcuh8opYQ7UUhQ3ZkaYGC.jpg'),
(139102, 9883, 'Nova York Contra o Crime [L] (1993) S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/273532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jIeunzpt0LHL9qFzs7dKM16zZdj.jpg'),
(139103, 9883, 'Nova York Contra o Crime [L] (1993) S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/273533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sX95wnViWOhrM0ipbHtllNrjV1t.jpg'),
(139104, 9883, 'Nova York Contra o Crime [L] (1993) S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/273534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e3hXx4Qn4TUHOzlkEDPnDTcHpYl.jpg'),
(139105, 9883, 'Nova York Contra o Crime [L] (1993) S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/273535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qszn7VXfs2XBBTiSIgdhItpUijk.jpg'),
(139106, 9883, 'Nova York Contra o Crime [L] (1993) S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/273536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wkwDMLZRDRbNrIeWhRMDwdFqb0T.jpg'),
(139107, 9883, 'Nova York Contra o Crime [L] (1993) S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/273537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/roXdURjjGfUMZ1m8XUjxRFIEfFR.jpg'),
(139108, 9883, 'Nova York Contra o Crime [L] (1993) S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/273538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hyhlI34MMUWKLW5pbP77pdm4iB0.jpg'),
(139109, 9883, 'Nova York Contra o Crime [L] (1993) S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/273539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/56NemQFIi9uSgW7GAkTSx9eIFPH.jpg'),
(139110, 9883, 'Nova York Contra o Crime [L] (1993) S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/273540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/JFyQXXl1PUoHn6chvqmFZOaLYm.jpg'),
(139111, 9883, 'Nova York Contra o Crime [L] (1993) S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/273541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yERpxLns5FDs2z5rksldu5pWL5j.jpg'),
(139112, 9883, 'Nova York Contra o Crime [L] (1993) S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/273542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qNOiCId198UEB7eCz0PXC6KfjJd.jpg'),
(139113, 9883, 'Nova York Contra o Crime [L] (1993) S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/273543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9nxzwQxcGqzLFOPWy1D5ZUyzCKG.jpg'),
(139114, 9883, 'Nova York Contra o Crime [L] (1993) S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/273544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4HYg7A0aY0j3AabV7uSn5z5Pkdx.jpg'),
(139115, 9884, 'Nova York Contra o Crime [L] (1993) S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zcHGeIcHQHqzSGB85RErgfqjb6x.jpg'),
(139116, 9884, 'Nova York Contra o Crime [L] (1993) S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/55gc65Y0MffhaKZMs91N1s82UND.jpg'),
(139117, 9884, 'Nova York Contra o Crime [L] (1993) S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1vR0vXOfdtJMdG5pCv8gOBpVhuU.jpg'),
(139118, 9884, 'Nova York Contra o Crime [L] (1993) S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yj8ndFWrl3vPqg0qqdpgYn1JPJ4.jpg'),
(139119, 9884, 'Nova York Contra o Crime [L] (1993) S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2b6jIAWjCkOHVYKCoZtROtorxKV.jpg'),
(139120, 9884, 'Nova York Contra o Crime [L] (1993) S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9T5dr09JKsXI5N3KUC5gPZXBZm9.jpg'),
(139121, 9884, 'Nova York Contra o Crime [L] (1993) S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uV3gFqDIJpXJihXOk5CbNtc5Yqf.jpg'),
(139122, 9884, 'Nova York Contra o Crime [L] (1993) S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bEFpHh5MAtrzI7J0efDcoTltfUo.jpg'),
(139123, 9884, 'Nova York Contra o Crime [L] (1993) S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/273553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nqO6pq8TCbOVPgoFoQfCUc0Oqk5.jpg'),
(139124, 9884, 'Nova York Contra o Crime [L] (1993) S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/273554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AwvDllTBrEQCba2AdzLBx1kwG68.jpg'),
(139125, 9884, 'Nova York Contra o Crime [L] (1993) S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/273555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ef1fSoGxXcpE3lYWuCVwonuYCAT.jpg'),
(139126, 9884, 'Nova York Contra o Crime [L] (1993) S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/273556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jwZw50s5uHUua7mXmPbV4LtJN68.jpg'),
(139127, 9884, 'Nova York Contra o Crime [L] (1993) S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/273557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1tl4tnqraADBI123Z22MGU19Zkb.jpg'),
(139128, 9884, 'Nova York Contra o Crime [L] (1993) S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/273558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yyVq1EL8pZKsooF0i9jK1nOHrjU.jpg'),
(139129, 9884, 'Nova York Contra o Crime [L] (1993) S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/273559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvF6jr5SnUp7RvRDALLLeM91Hz6.jpg'),
(139130, 9884, 'Nova York Contra o Crime [L] (1993) S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/273560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qQvLcaJHYfNE1yzwiXhiFaVFxK2.jpg'),
(139131, 9884, 'Nova York Contra o Crime [L] (1993) S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/273561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vi6VrX9Mj7zQSDazRrtmYNkcDc0.jpg'),
(139132, 9884, 'Nova York Contra o Crime [L] (1993) S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/273562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QK2KhS87H6SKA3ZHuvmnzl3emH.jpg'),
(139133, 9884, 'Nova York Contra o Crime [L] (1993) S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/273563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h9gOxbw3ZJl77D7ZUgeypFprBHk.jpg'),
(139134, 9884, 'Nova York Contra o Crime [L] (1993) S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/273564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3A8QCESnHgGtBMtRvoSWHMOca28.jpg'),
(139135, 9884, 'Nova York Contra o Crime [L] (1993) S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/273565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rjqeNs1suG4aLGz4APnKk0RqAKM.jpg'),
(139136, 9884, 'Nova York Contra o Crime [L] (1993) S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/273566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sd8qJwJtms4gozFvPwijN5gBU5C.jpg'),
(139137, 9885, 'Nova York Contra o Crime [L] (1993) S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gIvdz9AmBb8538K699FQGHL8wqE.jpg'),
(139138, 9885, 'Nova York Contra o Crime [L] (1993) S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Z8w2sqwHEnr8ty6GDe9KqhFQuf.jpg'),
(139139, 9885, 'Nova York Contra o Crime [L] (1993) S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nGLGNMp1IdOzDjwEXypiRxw7pzq.jpg'),
(139140, 9885, 'Nova York Contra o Crime [L] (1993) S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fFEOA9AXQXpHo6YFyS2JIxVSMyf.jpg'),
(139141, 9885, 'Nova York Contra o Crime [L] (1993) S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lt5m834GQp6lZDgTbAdiPYy1TkG.jpg'),
(139142, 9885, 'Nova York Contra o Crime [L] (1993) S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hVksTFJvXP9kAXEb8ZbpzOLw1ZO.jpg'),
(139143, 9885, 'Nova York Contra o Crime [L] (1993) S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9obalGLYJrvt0l251wg8UhesUCb.jpg'),
(139144, 9885, 'Nova York Contra o Crime [L] (1993) S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tpNFQ13j5alkz2H8F94pe0ErRZP.jpg'),
(139145, 9885, 'Nova York Contra o Crime [L] (1993) S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/273575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ocbIPokcfdiW7OodYIT9uzOFXRF.jpg'),
(139146, 9885, 'Nova York Contra o Crime [L] (1993) S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/273576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wXqWQ9ytTpdY4utYtOXps2k1QEa.jpg'),
(139147, 9885, 'Nova York Contra o Crime [L] (1993) S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/273577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kn8yijGee5SUWtUF6B6dGZ81u8s.jpg'),
(139148, 9885, 'Nova York Contra o Crime [L] (1993) S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/273578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3hVkKgmAhHjsNFFBFDDl7ioUWBF.jpg'),
(139149, 9885, 'Nova York Contra o Crime [L] (1993) S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/273579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v7klnGAYMUglrXVcFEaMf7jKIFq.jpg'),
(139150, 9885, 'Nova York Contra o Crime [L] (1993) S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/273580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h6QPPGeZwov5UmzCAFlFuYzBT8I.jpg'),
(139151, 9885, 'Nova York Contra o Crime [L] (1993) S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/273581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/42KhEQAT5XmuGON3IuNYEtHsoCK.jpg'),
(139152, 9885, 'Nova York Contra o Crime [L] (1993) S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/273582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hVbO7MCnqKUsmTE7WSDN2rIoUYq.jpg'),
(139153, 9885, 'Nova York Contra o Crime [L] (1993) S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/273583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w92tTo5LNUN5tRnXBsphZNQ8D8s.jpg'),
(139154, 9885, 'Nova York Contra o Crime [L] (1993) S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/273584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13HA5cz293gpCHgN1HDYSgXhdcC.jpg'),
(139155, 9885, 'Nova York Contra o Crime [L] (1993) S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/273585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hUoCgKGy79zJAifJ3ofLYzlmbWI.jpg'),
(139156, 9885, 'Nova York Contra o Crime [L] (1993) S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/273586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aqqtesc9eT7strHjBhuQb5eQUc5.jpg'),
(139157, 9885, 'Nova York Contra o Crime [L] (1993) S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/273587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/az4g2omlx8YNIS2RUfSdysMYu0x.jpg'),
(139158, 9885, 'Nova York Contra o Crime [L] (1993) S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/273588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/st6qH5f9T1ZO6bTvDCpUvboucf4.jpg'),
(139159, 9886, 'Nova York Contra o Crime [L] (1993) S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gbJFd2w7JYV6OElSPUq9Y4zYn9l.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(139160, 9886, 'Nova York Contra o Crime [L] (1993) S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7fN2BoZdgQU7SMbOfJfzhhFLduw.jpg'),
(139161, 9886, 'Nova York Contra o Crime [L] (1993) S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dM2qkQxHfyCu54HK4XvOezawFoD.jpg'),
(139162, 9886, 'Nova York Contra o Crime [L] (1993) S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ndTQcJobG3BAJQeWU1TsxUSHfmM.jpg'),
(139163, 9886, 'Nova York Contra o Crime [L] (1993) S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eaEIZWjC5Vprzm2wWt3TByD8rDk.jpg'),
(139164, 9886, 'Nova York Contra o Crime [L] (1993) S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4EwxlYJYJVQLWotBpOpNb9buREU.jpg'),
(139165, 9886, 'Nova York Contra o Crime [L] (1993) S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/moMdfDSk3gLDZ1eUQSgpZOSRHXm.jpg'),
(139166, 9886, 'Nova York Contra o Crime [L] (1993) S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZQrPGe0QKq4nRODz6MwdT3JWff.jpg'),
(139167, 9886, 'Nova York Contra o Crime [L] (1993) S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/273597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWJ2k71tpJS1SP2xl1Bj4aIUS4v.jpg'),
(139168, 9886, 'Nova York Contra o Crime [L] (1993) S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/273598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2xBdxU120EbIpRYntVx3G1wEt1G.jpg'),
(139169, 9886, 'Nova York Contra o Crime [L] (1993) S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/273599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e9uOGOIyAsar1qdMcAqGRkoNDa4.jpg'),
(139170, 9886, 'Nova York Contra o Crime [L] (1993) S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/273600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/36JGvqa3PLrRoyEGa8JbFBhmXoi.jpg'),
(139171, 9886, 'Nova York Contra o Crime [L] (1993) S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/273601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cRPRPipuZW592eeNFbhQGMNw9sv.jpg'),
(139172, 9886, 'Nova York Contra o Crime [L] (1993) S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/273602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iAPzPfUULqpqsiFsJcqm6ppcNUJ.jpg'),
(139173, 9886, 'Nova York Contra o Crime [L] (1993) S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/273603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nSyYalStVE06trGWGT69hfV9nhB.jpg'),
(139174, 9886, 'Nova York Contra o Crime [L] (1993) S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/273604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ugkHDoPsWL0HuBpWaY11WZOpx08.jpg'),
(139175, 9886, 'Nova York Contra o Crime [L] (1993) S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/273605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwyLieYUzVIWIAxOl75a2ZYz0Xu.jpg'),
(139176, 9886, 'Nova York Contra o Crime [L] (1993) S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/273606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tVA08AtBUv7oBfgYIJq9S1x6fPT.jpg'),
(139177, 9886, 'Nova York Contra o Crime [L] (1993) S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/273607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tpRhjWTF1StOAowteUquKOtPPhQ.jpg'),
(139178, 9886, 'Nova York Contra o Crime [L] (1993) S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/273608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qWfJVDUWZJveXPxJ3THRxt7Wt8Z.jpg'),
(139179, 9886, 'Nova York Contra o Crime [L] (1993) S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/273609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6XllbBnkODmiSE4o4qSGa7UfNNt.jpg'),
(139180, 9886, 'Nova York Contra o Crime [L] (1993) S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/273610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sVTN3VFGo3wcLtbAht6qv0qd8eH.jpg'),
(139181, 9887, 'Nova York Contra o Crime [L] (1993) S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ftBOZaufqmKjsi4Kuk89PFtOlpe.jpg'),
(139182, 9887, 'Nova York Contra o Crime [L] (1993) S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9XksfBiI4bImvL2I8SkUQ6RAwM.jpg'),
(139183, 9887, 'Nova York Contra o Crime [L] (1993) S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iqzgKeWA69taVSW4pHyvUh7TXed.jpg'),
(139184, 9887, 'Nova York Contra o Crime [L] (1993) S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wIbwrvtTrgkfm7hyBQ2kqmtvXbQ.jpg'),
(139185, 9887, 'Nova York Contra o Crime [L] (1993) S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2JjIwS5hRruCQ0TSTfySsjAIiIK.jpg'),
(139186, 9887, 'Nova York Contra o Crime [L] (1993) S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p09c4bqemL7Ur9TOzjXsWH7Gpd0.jpg'),
(139187, 9887, 'Nova York Contra o Crime [L] (1993) S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sUhv06KGwSMK3kawpWgXXxAY1an.jpg'),
(139188, 9887, 'Nova York Contra o Crime [L] (1993) S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sGljXyxvKBetkUoiX39wWUjds81.jpg'),
(139189, 9887, 'Nova York Contra o Crime [L] (1993) S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/273619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/62F7mME7VOmla3JHC9gd8w6ElU7.jpg'),
(139190, 9887, 'Nova York Contra o Crime [L] (1993) S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/273620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/diibk4PcOlIGSbgbyRGBXziTDFn.jpg'),
(139191, 9887, 'Nova York Contra o Crime [L] (1993) S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/273621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/46fI7W617Da4KzGRZ5UCak3piUT.jpg'),
(139192, 9887, 'Nova York Contra o Crime [L] (1993) S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/273622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xGxFKSEs6uwY3moLk36iTVosOEJ.jpg'),
(139193, 9887, 'Nova York Contra o Crime [L] (1993) S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/273623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2q2mvxGOHw7aasz4R1OBU4Y5sQm.jpg'),
(139194, 9887, 'Nova York Contra o Crime [L] (1993) S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/273624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ljDHtZu5MNfkjePu3wn1SIm9sxI.jpg'),
(139195, 9887, 'Nova York Contra o Crime [L] (1993) S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/273625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9wWoeAbUHyQ1QUU3hgjz8JKY5lL.jpg'),
(139196, 9887, 'Nova York Contra o Crime [L] (1993) S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/273626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2VjykGNUCFla6a2E9aWWZpZUcu.jpg'),
(139197, 9887, 'Nova York Contra o Crime [L] (1993) S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/273627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mMxqQNIy5nlXFQe2eF8Ja0eUevM.jpg'),
(139198, 9887, 'Nova York Contra o Crime [L] (1993) S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/273628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6LlQtCYSm6xHPCEi4U8irz2w4mR.jpg'),
(139199, 9887, 'Nova York Contra o Crime [L] (1993) S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/273629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cshpb1kEgD3FcrTDtIuDcuCVGyq.jpg'),
(139200, 9887, 'Nova York Contra o Crime [L] (1993) S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/273630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qYYg1iRyPKI63DFqYdI0IDhybNc.jpg'),
(139201, 9888, 'Nova York Contra o Crime [L] (1993) S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWB83U2q74rM5gTd4cdcCaDesd0.jpg'),
(139202, 9888, 'Nova York Contra o Crime [L] (1993) S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3PR3JoQMQp49E0OvIf4zTb2xlNy.jpg'),
(139203, 9888, 'Nova York Contra o Crime [L] (1993) S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kiSZJFgR9enHDAsltStQuWD4Tgj.jpg'),
(139204, 9888, 'Nova York Contra o Crime [L] (1993) S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qR0POHnbthlZSLS3DQykoN2Cqyy.jpg'),
(139205, 9888, 'Nova York Contra o Crime [L] (1993) S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wPWQJ51gIWUZjGuzOpi6bwVpy4C.jpg'),
(139206, 9888, 'Nova York Contra o Crime [L] (1993) S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pFcUyj3hcrDFf2EEiKdCgHBoWf3.jpg'),
(139207, 9888, 'Nova York Contra o Crime [L] (1993) S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6cQF1tXvORUq3OJPgdxuEqJgVfu.jpg'),
(139208, 9888, 'Nova York Contra o Crime [L] (1993) S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vLaTnnzBrksJODzSnghb7JtHsDq.jpg'),
(139209, 9888, 'Nova York Contra o Crime [L] (1993) S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/273639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ICFD3FlpZir3eQi0yF7c3qDZzz.jpg'),
(139210, 9888, 'Nova York Contra o Crime [L] (1993) S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/273640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kq7sHVLICHNvw5ZlfY679NJZm6e.jpg'),
(139211, 9888, 'Nova York Contra o Crime [L] (1993) S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/273641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wCG3Yai3G4XX0EjfWpXB1N37Fkc.jpg'),
(139212, 9888, 'Nova York Contra o Crime [L] (1993) S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/273642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jtsAWFBw7GIscXwDiDvgM6nfeYs.jpg'),
(139213, 9888, 'Nova York Contra o Crime [L] (1993) S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/273643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bGk4Qw3rxZgB8t4FDrbPE7O83Kw.jpg'),
(139214, 9888, 'Nova York Contra o Crime [L] (1993) S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/273644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iIL2qafTXt9M1b5h0IGMIWpt1Du.jpg'),
(139215, 9888, 'Nova York Contra o Crime [L] (1993) S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/273645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n2IDIu91jdS6ZHUwzK9YxgzBh0q.jpg'),
(139216, 9888, 'Nova York Contra o Crime [L] (1993) S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/273646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8YFaUwqU8pD2yJbepPKXRcanLa.jpg'),
(139217, 9888, 'Nova York Contra o Crime [L] (1993) S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/273647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m48SwRgzrnxBRbzBI2clxLRvTJw.jpg'),
(139218, 9888, 'Nova York Contra o Crime [L] (1993) S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/273648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zmFZYpSaNsYZuRDTKjphGNovDoi.jpg'),
(139219, 9888, 'Nova York Contra o Crime [L] (1993) S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/273649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1l83LPVYCovahMkQo1BA3zWcisJ.jpg'),
(139220, 9888, 'Nova York Contra o Crime [L] (1993) S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/273650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qb38QL0gYVucAbP9nLUxyTRqgLa.jpg'),
(139221, 9888, 'Nova York Contra o Crime [L] (1993) S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/273651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nvxyMbi3kQGlURDWX4WLg0Gggrh.jpg'),
(139222, 9888, 'Nova York Contra o Crime [L] (1993) S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/273652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pKfmLq1QskAknDOklhXmyLyxAqr.jpg'),
(139223, 9889, 'Nova York Contra o Crime [L] (1993) S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ygXyKoOpts6QNaXrVp1rCb0qdRt.jpg'),
(139224, 9889, 'Nova York Contra o Crime [L] (1993) S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/knyYQeCafep6vvPd5tfXJx5M0wa.jpg'),
(139225, 9889, 'Nova York Contra o Crime [L] (1993) S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3sxknDq4OpSRQZ7xkwmmwotHYsi.jpg'),
(139226, 9889, 'Nova York Contra o Crime [L] (1993) S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Yoq4YWE5zuisGUrX3adOqQsxTB.jpg'),
(139227, 9889, 'Nova York Contra o Crime [L] (1993) S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aXHVB4rQ3yrbF70zN4aKVdkVwdH.jpg'),
(139228, 9889, 'Nova York Contra o Crime [L] (1993) S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3cVSqVjDTnEO3tZA6Ri3t29RgKL.jpg'),
(139229, 9889, 'Nova York Contra o Crime [L] (1993) S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/41UrRiRNDjQo37qHLMlNs8auS29.jpg'),
(139230, 9889, 'Nova York Contra o Crime [L] (1993) S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f8tMqiwIFHuj9nL95UosdbH6r0q.jpg'),
(139231, 9889, 'Nova York Contra o Crime [L] (1993) S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/273661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A9FqCrG6Ql4PQavJCO4s2Ou8FID.jpg'),
(139232, 9889, 'Nova York Contra o Crime [L] (1993) S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/273662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6aeJzCSWEGb9DJBNSmDXvpOhU6B.jpg'),
(139233, 9889, 'Nova York Contra o Crime [L] (1993) S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/273663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ytynD3CHjYQi0r8UOH66qKPBP7u.jpg'),
(139234, 9889, 'Nova York Contra o Crime [L] (1993) S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/273664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qDTeQtL33ZEdn1qHds8ros4RIL9.jpg'),
(139235, 9889, 'Nova York Contra o Crime [L] (1993) S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/273665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2GmhEZpdONApx1u4xcLlyx5iBo.jpg'),
(139236, 9889, 'Nova York Contra o Crime [L] (1993) S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/273666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2tzffwF1zODMQRP2T6NXoeV7Itk.jpg'),
(139237, 9889, 'Nova York Contra o Crime [L] (1993) S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/273667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ccvd8DHyT0mUnkIeR1Ep6fE88S6.jpg'),
(139238, 9889, 'Nova York Contra o Crime [L] (1993) S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/273668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/krrxBwMNjOFWuHbEz5I1Jl5U39G.jpg'),
(139239, 9889, 'Nova York Contra o Crime [L] (1993) S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/273669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iUy4805GWU3w9BRJ4Wh364OfuRD.jpg'),
(139240, 9889, 'Nova York Contra o Crime [L] (1993) S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/273670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zOyqlWXDOWzf0trxEAt3ZJI110R.jpg'),
(139241, 9889, 'Nova York Contra o Crime [L] (1993) S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/273671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gnK2pLaKf6ajj2fG8dn6twRqYXj.jpg'),
(139242, 9889, 'Nova York Contra o Crime [L] (1993) S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/273672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/draM1TtfSO45ILyARidJkDeYMcB.jpg'),
(139243, 9889, 'Nova York Contra o Crime [L] (1993) S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/273673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Oy6zD7SYur4PbuhfIVyAiyG5PX.jpg'),
(139244, 9890, 'Nova York Contra o Crime [L] (1993) S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/273674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9v9JKNcmKqgcGZmqwlDStrtruJi.jpg'),
(139245, 9890, 'Nova York Contra o Crime [L] (1993) S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/273675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ml95t9Byi6r01Mjcv0x54J3pn6E.jpg'),
(139246, 9890, 'Nova York Contra o Crime [L] (1993) S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/273676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kgeDqZXQQDXOnpVIrOiUwdw6iYv.jpg'),
(139247, 9890, 'Nova York Contra o Crime [L] (1993) S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/273677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zcQs2zDAv9Vcg5G3R2qHCNpxdY1.jpg'),
(139248, 9890, 'Nova York Contra o Crime [L] (1993) S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/273678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d6IT1rd1XKpaHLeL3PHbNPVAFDk.jpg'),
(139249, 9890, 'Nova York Contra o Crime [L] (1993) S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/273679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4M6BaGtrbND8EIv1zcj6iG7kfWT.jpg'),
(139250, 9890, 'Nova York Contra o Crime [L] (1993) S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/273680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eEfizcsJTPeOc1JF464JdEJf5xk.jpg'),
(139251, 9890, 'Nova York Contra o Crime [L] (1993) S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/273681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bRVOGm7wrqTqsRussbPXZqYR8yk.jpg'),
(139252, 9890, 'Nova York Contra o Crime [L] (1993) S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/273682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yREcZvPcz29UAIEPDhQ7ZGqfzL1.jpg'),
(139253, 9890, 'Nova York Contra o Crime [L] (1993) S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/273683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hJkLbHUs6mx1SE0isNvtLNqjB56.jpg'),
(139254, 9890, 'Nova York Contra o Crime [L] (1993) S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/273684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tiSvIBrBDAdSpEO1TRt1OmQRWcF.jpg'),
(139255, 9890, 'Nova York Contra o Crime [L] (1993) S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/273685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r9LhEKor7Lzh8oEaS4lyKgARXkS.jpg'),
(139256, 9890, 'Nova York Contra o Crime [L] (1993) S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/273686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iCSscCHNJqMht9JI8CPDMikPjUb.jpg'),
(139257, 9890, 'Nova York Contra o Crime [L] (1993) S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/273687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gic0pHpKknWF6QNgiAG6xl7S4te.jpg'),
(139258, 9890, 'Nova York Contra o Crime [L] (1993) S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/273688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSVbdSkzmX0T0hEKEWtuMuOVMlf.jpg'),
(139259, 9890, 'Nova York Contra o Crime [L] (1993) S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/273689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iUy4805GWU3w9BRJ4Wh364OfuRD.jpg'),
(139260, 9890, 'Nova York Contra o Crime [L] (1993) S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/273690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/znGeGbY3uaSl99DZ9FhZRjlyIBM.jpg'),
(139261, 9890, 'Nova York Contra o Crime [L] (1993) S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/273691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hdqhEN7wcL5nB4OHbibGlXlYMbY.jpg'),
(139262, 9890, 'Nova York Contra o Crime [L] (1993) S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/273692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vOmON0SvIRXJOKJTutChf4xKgE0.jpg'),
(139263, 9890, 'Nova York Contra o Crime [L] (1993) S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/273693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d5iy90i8vuHlFu7cd8CarnIHjrH.jpg'),
(139264, 9891, 'Equipe do Pavor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/271854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v3RT4AlHm1Eikr75IngpktBHCpE.jpg'),
(139265, 9891, 'Equipe do Pavor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/271855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m09Y1bmO8PGc76VwaFAh8sq3NBu.jpg'),
(139266, 9891, 'Equipe do Pavor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/271856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bBh5nV8tbk7zIsnxioner7vbmRm.jpg'),
(139267, 9891, 'Equipe do Pavor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/271857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jvgrAdkB3jOyeLDEIjeeOG0Mo62.jpg'),
(139268, 9891, 'Equipe do Pavor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/271858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yogb6qr8KsuRxugC1o0595Z7VDn.jpg'),
(139269, 9891, 'Equipe do Pavor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/271859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jvZ0ScNArDunHhoblVJyJMEQTWL.jpg'),
(139270, 9891, 'Equipe do Pavor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/271860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kHa4OMEUEDcp6nYO25VWdhExtqV.jpg'),
(139271, 9891, 'Equipe do Pavor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/271861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/flpCBEXzHdJgeiCy4NBrMshm7Ko.jpg'),
(139272, 9891, 'Equipe do Pavor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/271862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJUy4B6Ww6fb7jeOEhc00Gf108R.jpg'),
(139273, 9891, 'Equipe do Pavor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/271863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gUxiRH7f7Ya7Svk2nszWgVKOXZY.jpg'),
(139274, 9892, 'Equipe do Pavor S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/419596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/63S6OLbrdLTi1fCh7SelF0qieAu.jpg'),
(139275, 9892, 'Equipe do Pavor S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/419597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/63S6OLbrdLTi1fCh7SelF0qieAu.jpg'),
(139276, 9892, 'Equipe do Pavor S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/419598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/63S6OLbrdLTi1fCh7SelF0qieAu.jpg'),
(139277, 9892, 'Equipe do Pavor S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/419599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/63S6OLbrdLTi1fCh7SelF0qieAu.jpg'),
(139278, 9892, 'Equipe do Pavor S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/419600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/63S6OLbrdLTi1fCh7SelF0qieAu.jpg'),
(139279, 9892, 'Equipe do Pavor S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/419601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/63S6OLbrdLTi1fCh7SelF0qieAu.jpg'),
(139280, 9892, 'Equipe do Pavor S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/419602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/63S6OLbrdLTi1fCh7SelF0qieAu.jpg'),
(139281, 9892, 'Equipe do Pavor S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/419603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/63S6OLbrdLTi1fCh7SelF0qieAu.jpg'),
(139282, 9892, 'Equipe do Pavor S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/419604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/63S6OLbrdLTi1fCh7SelF0qieAu.jpg'),
(139283, 9892, 'Equipe do Pavor S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/419605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/63S6OLbrdLTi1fCh7SelF0qieAu.jpg'),
(139284, 9893, 'Branding in Seongsu [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7M5tePclTAiyoRZ8OAAe5bF3yMY.jpg'),
(139285, 9893, 'Branding in Seongsu [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d8xjuhOVlgOWwUjDxrAfsLbElEW.jpg'),
(139286, 9893, 'Branding in Seongsu [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kyng8QEad1zrqKoZ5ozCIA9yQve.jpg'),
(139287, 9893, 'Branding in Seongsu [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7cbxhotJZ5NhCUn1JyxH9itlAWN.jpg'),
(139288, 9893, 'Branding in Seongsu [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lwTt4LmqZgRBVsIHTaclDvP9jd.jpg'),
(139289, 9893, 'Branding in Seongsu [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/23iQO5k7aXHqtQrUfPACCkmz9Do.jpg'),
(139290, 9893, 'Branding in Seongsu [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3bisWVJgM4fUlfoYCAeAHfvJtWK.jpg'),
(139291, 9893, 'Branding in Seongsu [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/274289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dr1eliCiLJlhdTVJO34TK5bsXgN.jpg'),
(139292, 9893, 'Branding in Seongsu [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/274290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lfC4UETvJlEHmX0oAddargXSD50.jpg'),
(139293, 9893, 'Branding in Seongsu [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/289223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WP9b2HOWpKwPUlJcZWYNxAyueh.jpg'),
(139294, 9893, 'Branding in Seongsu [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/595824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WP9b2HOWpKwPUlJcZWYNxAyueh.jpg'),
(139295, 9893, 'Branding in Seongsu [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/279124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WP9b2HOWpKwPUlJcZWYNxAyueh.jpg'),
(139296, 9893, 'Branding in Seongsu [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/283104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WP9b2HOWpKwPUlJcZWYNxAyueh.jpg'),
(139297, 9893, 'Branding in Seongsu [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/289227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WP9b2HOWpKwPUlJcZWYNxAyueh.jpg'),
(139298, 9893, 'Branding in Seongsu [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/289228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WP9b2HOWpKwPUlJcZWYNxAyueh.jpg'),
(139299, 9893, 'Branding in Seongsu [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/289229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WP9b2HOWpKwPUlJcZWYNxAyueh.jpg'),
(139300, 9893, 'Branding in Seongsu [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/289230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WP9b2HOWpKwPUlJcZWYNxAyueh.jpg'),
(139301, 9893, 'Branding in Seongsu [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/294473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WP9b2HOWpKwPUlJcZWYNxAyueh.jpg'),
(139302, 9893, 'Branding in Seongsu [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/294474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WP9b2HOWpKwPUlJcZWYNxAyueh.jpg'),
(139303, 9893, 'Branding in Seongsu [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/296438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WP9b2HOWpKwPUlJcZWYNxAyueh.jpg'),
(139304, 9893, 'Branding in Seongsu [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/299405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WP9b2HOWpKwPUlJcZWYNxAyueh.jpg'),
(139305, 9893, 'Branding in Seongsu [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/299406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WP9b2HOWpKwPUlJcZWYNxAyueh.jpg'),
(139306, 9893, 'Branding in Seongsu [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/300317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WP9b2HOWpKwPUlJcZWYNxAyueh.jpg'),
(139307, 9893, 'Branding in Seongsu [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/300318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6WP9b2HOWpKwPUlJcZWYNxAyueh.jpg'),
(139308, 9894, 'Bucchigiri [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pE1zPEUsc6N1XhhNRoJkGJdEbxI.jpg'),
(139309, 9894, 'Bucchigiri [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Hcmpg8g1azlbaK3FGMHpqIY3ho.jpg'),
(139310, 9894, 'Bucchigiri [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5qAO51ogDxKG8mtxsbHmnBx33H3.jpg'),
(139311, 9894, 'Bucchigiri [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8DFWAtxJqOz0MgNaIJCHyiVQdvb.jpg'),
(139312, 9894, 'Bucchigiri [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJjhJlA9MyI51KLy2PYMKivJfsO.jpg'),
(139313, 9894, 'Bucchigiri [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rofoNh84n3mOrs4QPD3JWABmMGl.jpg'),
(139314, 9894, 'Bucchigiri [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mTphiAP2vMMNcVSB5a1pWEMZuo3.jpg'),
(139315, 9894, 'Bucchigiri [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/298208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mTphiAP2vMMNcVSB5a1pWEMZuo3.jpg'),
(139316, 9894, 'Bucchigiri [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/309306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mTphiAP2vMMNcVSB5a1pWEMZuo3.jpg'),
(139317, 9894, 'Bucchigiri [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/309307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mTphiAP2vMMNcVSB5a1pWEMZuo3.jpg'),
(139318, 9894, 'Bucchigiri [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/316206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mTphiAP2vMMNcVSB5a1pWEMZuo3.jpg'),
(139319, 9894, 'Bucchigiri [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/323025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mTphiAP2vMMNcVSB5a1pWEMZuo3.jpg'),
(139320, 9895, 'Dra Emma Uma Questao de Pele S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139321, 9895, 'Dra Emma Uma Questao de Pele S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139322, 9895, 'Dra Emma Uma Questao de Pele S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139323, 9895, 'Dra Emma Uma Questao de Pele S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139324, 9895, 'Dra Emma Uma Questao de Pele S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139325, 9895, 'Dra Emma Uma Questao de Pele S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139326, 9895, 'Dra Emma Uma Questao de Pele S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139327, 9895, 'Dra Emma Uma Questao de Pele S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/274235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139328, 9896, 'Dra Emma Uma Questao de Pele S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139329, 9896, 'Dra Emma Uma Questao de Pele S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139330, 9896, 'Dra Emma Uma Questao de Pele S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139331, 9896, 'Dra Emma Uma Questao de Pele S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139332, 9896, 'Dra Emma Uma Questao de Pele S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139333, 9896, 'Dra Emma Uma Questao de Pele S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139334, 9896, 'Dra Emma Uma Questao de Pele S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139335, 9896, 'Dra Emma Uma Questao de Pele S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/274243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139336, 9896, 'Dra Emma Uma Questao de Pele S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/274244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139337, 9896, 'Dra Emma Uma Questao de Pele S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/274245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139338, 9896, 'Dra Emma Uma Questao de Pele S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/274246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139339, 9896, 'Dra Emma Uma Questao de Pele S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/274247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139340, 9897, 'Dra Emma Uma Questao de Pele S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139341, 9897, 'Dra Emma Uma Questao de Pele S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139342, 9897, 'Dra Emma Uma Questao de Pele S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139343, 9897, 'Dra Emma Uma Questao de Pele S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139344, 9897, 'Dra Emma Uma Questao de Pele S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139345, 9897, 'Dra Emma Uma Questao de Pele S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139346, 9897, 'Dra Emma Uma Questao de Pele S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139347, 9897, 'Dra Emma Uma Questao de Pele S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/274255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139348, 9897, 'Dra Emma Uma Questao de Pele S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/274256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139349, 9897, 'Dra Emma Uma Questao de Pele S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/274257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139350, 9897, 'Dra Emma Uma Questao de Pele S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/274258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139351, 9897, 'Dra Emma Uma Questao de Pele S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/274259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139352, 9898, 'Dra Emma Uma Questao de Pele S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139353, 9898, 'Dra Emma Uma Questao de Pele S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139354, 9898, 'Dra Emma Uma Questao de Pele S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139355, 9898, 'Dra Emma Uma Questao de Pele S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139356, 9898, 'Dra Emma Uma Questao de Pele S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139357, 9898, 'Dra Emma Uma Questao de Pele S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139358, 9898, 'Dra Emma Uma Questao de Pele S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139359, 9898, 'Dra Emma Uma Questao de Pele S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/274267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139360, 9898, 'Dra Emma Uma Questao de Pele S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/274268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139361, 9898, 'Dra Emma Uma Questao de Pele S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/274269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139362, 9898, 'Dra Emma Uma Questao de Pele S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/274270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139363, 9899, 'Dra Emma Uma Questao de Pele S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139364, 9899, 'Dra Emma Uma Questao de Pele S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139365, 9899, 'Dra Emma Uma Questao de Pele S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139366, 9899, 'Dra Emma Uma Questao de Pele S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139367, 9899, 'Dra Emma Uma Questao de Pele S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139368, 9899, 'Dra Emma Uma Questao de Pele S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/281394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139369, 9899, 'Dra Emma Uma Questao de Pele S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/287700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139370, 9899, 'Dra Emma Uma Questao de Pele S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/295758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139371, 9899, 'Dra Emma Uma Questao de Pele S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/302884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139372, 9899, 'Dra Emma Uma Questao de Pele S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/309065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139373, 9900, 'Dra Emma Uma Questao de Pele S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/665117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139374, 9900, 'Dra Emma Uma Questao de Pele S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/665118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139375, 9900, 'Dra Emma Uma Questao de Pele S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/665119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139376, 9900, 'Dra Emma Uma Questao de Pele S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/665120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139377, 9900, 'Dra Emma Uma Questao de Pele S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/665121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139378, 9900, 'Dra Emma Uma Questao de Pele S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/665122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139379, 9900, 'Dra Emma Uma Questao de Pele S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/665123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139380, 9900, 'Dra Emma Uma Questao de Pele S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/665124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139381, 9900, 'Dra Emma Uma Questao de Pele S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/665125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139382, 9900, 'Dra Emma Uma Questao de Pele S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/665126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139383, 9901, 'Dra Emma Uma Questao de Pele S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/794925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139384, 9901, 'Dra Emma Uma Questao de Pele S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/794926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139385, 9901, 'Dra Emma Uma Questao de Pele S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/794927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139386, 9901, 'Dra Emma Uma Questao de Pele S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/794928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139387, 9901, 'Dra Emma Uma Questao de Pele S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/794929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139388, 9901, 'Dra Emma Uma Questao de Pele S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/794930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139389, 9901, 'Dra Emma Uma Questao de Pele S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/794931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139390, 9901, 'Dra Emma Uma Questao de Pele S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/794932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139391, 9901, 'Dra Emma Uma Questao de Pele S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/794933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139392, 9901, 'Dra Emma Uma Questao de Pele S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/794934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQwhhkgAnlblUBH02X96cI5RhJ.jpg'),
(139393, 9902, 'Ernesto O Exterminador de Seres Monstruosos e Outras Porcarias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imVhoxngjaWm4ip5T3zhk3dIdqZ.jpg'),
(139394, 9902, 'Ernesto O Exterminador de Seres Monstruosos e Outras Porcarias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imVhoxngjaWm4ip5T3zhk3dIdqZ.jpg'),
(139395, 9902, 'Ernesto O Exterminador de Seres Monstruosos e Outras Porcarias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imVhoxngjaWm4ip5T3zhk3dIdqZ.jpg'),
(139396, 9902, 'Ernesto O Exterminador de Seres Monstruosos e Outras Porcarias S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imVhoxngjaWm4ip5T3zhk3dIdqZ.jpg'),
(139397, 9902, 'Ernesto O Exterminador de Seres Monstruosos e Outras Porcarias S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imVhoxngjaWm4ip5T3zhk3dIdqZ.jpg'),
(139398, 9902, 'Ernesto O Exterminador de Seres Monstruosos e Outras Porcarias S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imVhoxngjaWm4ip5T3zhk3dIdqZ.jpg'),
(139399, 9902, 'Ernesto O Exterminador de Seres Monstruosos e Outras Porcarias S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imVhoxngjaWm4ip5T3zhk3dIdqZ.jpg'),
(139400, 9902, 'Ernesto O Exterminador de Seres Monstruosos e Outras Porcarias S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/274222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imVhoxngjaWm4ip5T3zhk3dIdqZ.jpg'),
(139401, 9902, 'Ernesto O Exterminador de Seres Monstruosos e Outras Porcarias S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/274223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imVhoxngjaWm4ip5T3zhk3dIdqZ.jpg'),
(139402, 9902, 'Ernesto O Exterminador de Seres Monstruosos e Outras Porcarias S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/274224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imVhoxngjaWm4ip5T3zhk3dIdqZ.jpg'),
(139403, 9902, 'Ernesto O Exterminador de Seres Monstruosos e Outras Porcarias S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/274225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imVhoxngjaWm4ip5T3zhk3dIdqZ.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(139404, 9902, 'Ernesto O Exterminador de Seres Monstruosos e Outras Porcarias S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/274226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imVhoxngjaWm4ip5T3zhk3dIdqZ.jpg'),
(139405, 9902, 'Ernesto O Exterminador de Seres Monstruosos e Outras Porcarias S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/274227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/imVhoxngjaWm4ip5T3zhk3dIdqZ.jpg'),
(139406, 9903, 'Irmaos a Obra Lar Sempre Lar S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/322618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139407, 9903, 'Irmaos a Obra Lar Sempre Lar S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/322619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139408, 9903, 'Irmaos a Obra Lar Sempre Lar S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/322620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139409, 9903, 'Irmaos a Obra Lar Sempre Lar S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/322621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139410, 9903, 'Irmaos a Obra Lar Sempre Lar S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/322622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139411, 9903, 'Irmaos a Obra Lar Sempre Lar S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/322623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139412, 9903, 'Irmaos a Obra Lar Sempre Lar S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/322624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139413, 9904, 'Irmaos a Obra Lar Sempre Lar S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/322625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139414, 9904, 'Irmaos a Obra Lar Sempre Lar S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/322626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139415, 9904, 'Irmaos a Obra Lar Sempre Lar S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/322627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139416, 9904, 'Irmaos a Obra Lar Sempre Lar S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/322628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139417, 9904, 'Irmaos a Obra Lar Sempre Lar S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/322629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139418, 9904, 'Irmaos a Obra Lar Sempre Lar S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/322630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139419, 9904, 'Irmaos a Obra Lar Sempre Lar S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/322631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139420, 9904, 'Irmaos a Obra Lar Sempre Lar S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/322632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139421, 9904, 'Irmaos a Obra Lar Sempre Lar S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/322633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139422, 9904, 'Irmaos a Obra Lar Sempre Lar S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/322634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139423, 9905, 'Irmaos a Obra Lar Sempre Lar S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/322635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139424, 9905, 'Irmaos a Obra Lar Sempre Lar S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/322636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139425, 9905, 'Irmaos a Obra Lar Sempre Lar S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/322637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139426, 9905, 'Irmaos a Obra Lar Sempre Lar S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/322638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139427, 9905, 'Irmaos a Obra Lar Sempre Lar S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/322639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139428, 9905, 'Irmaos a Obra Lar Sempre Lar S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/322640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139429, 9905, 'Irmaos a Obra Lar Sempre Lar S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/322641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139430, 9905, 'Irmaos a Obra Lar Sempre Lar S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/322642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139431, 9905, 'Irmaos a Obra Lar Sempre Lar S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/322643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139432, 9905, 'Irmaos a Obra Lar Sempre Lar S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/322644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139433, 9905, 'Irmaos a Obra Lar Sempre Lar S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/322645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139434, 9905, 'Irmaos a Obra Lar Sempre Lar S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/322646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139435, 9905, 'Irmaos a Obra Lar Sempre Lar S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/322647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139436, 9905, 'Irmaos a Obra Lar Sempre Lar S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/322648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139437, 9906, 'Irmaos a Obra Lar Sempre Lar S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t2Mrm6O5euMbr1okerlJPXwTI6.jpg'),
(139438, 9906, 'Irmaos a Obra Lar Sempre Lar S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/280872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139439, 9906, 'Irmaos a Obra Lar Sempre Lar S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/287165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139440, 9906, 'Irmaos a Obra Lar Sempre Lar S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/295517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139441, 9906, 'Irmaos a Obra Lar Sempre Lar S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/304580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139442, 9906, 'Irmaos a Obra Lar Sempre Lar S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/304581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139443, 9906, 'Irmaos a Obra Lar Sempre Lar S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/313279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139444, 9906, 'Irmaos a Obra Lar Sempre Lar S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/322656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139445, 9906, 'Irmaos a Obra Lar Sempre Lar S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/352197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139446, 9906, 'Irmaos a Obra Lar Sempre Lar S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/319576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139447, 9907, 'Irmaos a Obra Lar Sempre Lar S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/352199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139448, 9907, 'Irmaos a Obra Lar Sempre Lar S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/352200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139449, 9907, 'Irmaos a Obra Lar Sempre Lar S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/352201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139450, 9907, 'Irmaos a Obra Lar Sempre Lar S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/352202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139451, 9907, 'Irmaos a Obra Lar Sempre Lar S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/359622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139452, 9907, 'Irmaos a Obra Lar Sempre Lar S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/368381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139453, 9907, 'Irmaos a Obra Lar Sempre Lar S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/377882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139454, 9907, 'Irmaos a Obra Lar Sempre Lar S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/467371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139455, 9907, 'Irmaos a Obra Lar Sempre Lar S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/467372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139456, 9907, 'Irmaos a Obra Lar Sempre Lar S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/467373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jH2SIzJY0m0PnnfYgTqRLeMNyDb.jpg'),
(139457, 9908, 'Knight Flower [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4xStwFO7bU3ZgM5N94ATx70CEQh.jpg'),
(139458, 9908, 'Knight Flower [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dm1PGGxZT6F0p7xGclFVJdfMn5D.jpg'),
(139459, 9908, 'Knight Flower [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qnyslL2r8HYZmerLS6AhORVcuSt.jpg'),
(139460, 9908, 'Knight Flower [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fToXAqIsI1hEfw0yKmZXjy4KSC.jpg'),
(139461, 9908, 'Knight Flower [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mlb8hBRyf4BoilmJcvRCXUcX3Vw.jpg'),
(139462, 9908, 'Knight Flower [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/287156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjisUQj5QcvlcnXEp9fsE0rVum9.jpg'),
(139463, 9908, 'Knight Flower [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/287157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjisUQj5QcvlcnXEp9fsE0rVum9.jpg'),
(139464, 9908, 'Knight Flower [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/274211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3lCzdarExtvU0TqYVnMWuFRNbyD.jpg'),
(139465, 9908, 'Knight Flower [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/593646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjisUQj5QcvlcnXEp9fsE0rVum9.jpg'),
(139466, 9908, 'Knight Flower [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/593647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjisUQj5QcvlcnXEp9fsE0rVum9.jpg'),
(139467, 9908, 'Knight Flower [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjisUQj5QcvlcnXEp9fsE0rVum9.jpg'),
(139468, 9908, 'Knight Flower [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/280870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjisUQj5QcvlcnXEp9fsE0rVum9.jpg'),
(139469, 9909, 'Midnight Sun [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ecOa45X66OWz7AELx1jwUpxiZqE.jpg'),
(139470, 9909, 'Midnight Sun [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sGTe4Ko9bTIHjegm8suXRodXGKV.jpg'),
(139471, 9909, 'Midnight Sun [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kcOSitCENjhDdvGm3vK1UiNXbT7.jpg'),
(139472, 9909, 'Midnight Sun [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aOdMEpOS7lxSnI9FEuRhD092lC6.jpg'),
(139473, 9909, 'Midnight Sun [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pjKUB0l4Aen7rb6cYt4yYSDwPVv.jpg'),
(139474, 9909, 'Midnight Sun [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hCl84CiHL0QpNfl0hPL9LD5215f.jpg'),
(139475, 9909, 'Midnight Sun [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rBV0CFcIUY1QznIjygjKap8trpW.jpg'),
(139476, 9909, 'Midnight Sun [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/274205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zK60zJQ8Us60QBE6qGXY4KWRPJn.jpg'),
(139477, 9910, 'Ninja Kamui S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vDXciMhwGDeWeNAYjmUBBdloQk4.jpg'),
(139478, 9910, 'Ninja Kamui S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2RquvU36FyfxoHD2rV6Dkcuonqr.jpg'),
(139479, 9910, 'Ninja Kamui S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/282607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z9HK4DEBhF5YX7AdiEvSOq5yfZW.jpg'),
(139480, 9910, 'Ninja Kamui S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/291959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z9HK4DEBhF5YX7AdiEvSOq5yfZW.jpg'),
(139481, 9910, 'Ninja Kamui S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/297489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z9HK4DEBhF5YX7AdiEvSOq5yfZW.jpg'),
(139482, 9910, 'Ninja Kamui S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/308536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z9HK4DEBhF5YX7AdiEvSOq5yfZW.jpg'),
(139483, 9910, 'Ninja Kamui S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/325520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z9HK4DEBhF5YX7AdiEvSOq5yfZW.jpg'),
(139484, 9910, 'Ninja Kamui S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/345072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z9HK4DEBhF5YX7AdiEvSOq5yfZW.jpg'),
(139485, 9910, 'Ninja Kamui S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/322459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z9HK4DEBhF5YX7AdiEvSOq5yfZW.jpg'),
(139486, 9910, 'Ninja Kamui S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/325523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z9HK4DEBhF5YX7AdiEvSOq5yfZW.jpg'),
(139487, 9910, 'Ninja Kamui S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/330536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z9HK4DEBhF5YX7AdiEvSOq5yfZW.jpg'),
(139488, 9910, 'Ninja Kamui S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/338516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z9HK4DEBhF5YX7AdiEvSOq5yfZW.jpg'),
(139489, 9910, 'Ninja Kamui S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/345077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z9HK4DEBhF5YX7AdiEvSOq5yfZW.jpg'),
(139490, 9911, 'Pagan Peak S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xiX92UKcwDyu9abu98XeHJKbitx.jpg'),
(139491, 9911, 'Pagan Peak S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qanU4k99ZPe3yzj5YPDiQuPhWA1.jpg'),
(139492, 9911, 'Pagan Peak S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shMXmeWtuVJf3yhec5YMeeB8AFE.jpg'),
(139493, 9911, 'Pagan Peak S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gyFf8MnEb1v5Vw7jf4K5sqXsh0O.jpg'),
(139494, 9911, 'Pagan Peak S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fTxLiGxcjWRg7fjpxhIzHpKNbJj.jpg'),
(139495, 9911, 'Pagan Peak S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8r46rYahwLSFe8sV8cbjS2KTuoj.jpg'),
(139496, 9911, 'Pagan Peak S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vikiwxRw4jT8T3EzrNoJNp9nMDN.jpg'),
(139497, 9911, 'Pagan Peak S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/274179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bFQJuozSycP2VmWxrxUtNLKTFZG.jpg'),
(139498, 9912, 'Pagan Peak S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uTHMeE7Ij6JZStzQ7cFcODBspNM.jpg'),
(139499, 9912, 'Pagan Peak S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3J9quY9slLbeGKE6M88actFlpa6.jpg'),
(139500, 9912, 'Pagan Peak S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6yn8KaMVBpC9kXXI6FIXGp0qZdv.jpg'),
(139501, 9912, 'Pagan Peak S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFnoZOzBe9AnOQtYU3mlIphBLph.jpg'),
(139502, 9912, 'Pagan Peak S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tVzrcG9ShhtIQIMc7CgYMcfiDJU.jpg'),
(139503, 9912, 'Pagan Peak S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cl6WaA7PEmGOP2gWzRjAWvbEOPl.jpg'),
(139504, 9912, 'Pagan Peak S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u0262H4nsnQdXp6ECnfEEc5rxCu.jpg'),
(139505, 9912, 'Pagan Peak S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/274187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yU2J319roXsAoK1meJ2c2lFmTMr.jpg'),
(139506, 9913, 'Pagan Peak S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nXxvA35qqoO41CGmq8S9ARUWqGY.jpg'),
(139507, 9913, 'Pagan Peak S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m8jWChvKhmJr6Le88eNm08N4VB4.jpg'),
(139508, 9913, 'Pagan Peak S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2T3gCTvybIcBao56xHG7Sv7LuqF.jpg'),
(139509, 9913, 'Pagan Peak S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ygyIs88FTq8iygUJTvki1nTi0PZ.jpg'),
(139510, 9913, 'Pagan Peak S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kemiu5znWYvxjPiUvF9sguxqaeS.jpg'),
(139511, 9913, 'Pagan Peak S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/52AasXKN313qcKzn3ZyXunB1RJg.jpg'),
(139512, 9913, 'Pagan Peak S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qtclNu8Rf2ZFZqs1FFNV6SBcV78.jpg'),
(139513, 9913, 'Pagan Peak S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/274195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8YiRlX6Fu1UcslOW0OzGa1nFS3.jpg'),
(139514, 4891, 'Vivendo com o Inimigo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cnyHNArAVxYs8iq7pCHnUu7I5uj.jpg'),
(139515, 4891, 'Vivendo com o Inimigo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kcIo9ozbpbBTA2UeNmtMMhajepS.jpg'),
(139516, 4891, 'Vivendo com o Inimigo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y6jx4pbYsfzpx0a21y5lhiueHOa.jpg'),
(139517, 4891, 'Vivendo com o Inimigo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7uE2yNAGLwFLoZTeZOeoZ0sFGn.jpg'),
(139518, 4891, 'Vivendo com o Inimigo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmEgT2TeYva9viICgWdT5M4Snhe.jpg'),
(139519, 4891, 'Vivendo com o Inimigo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/42y0w54jW84jAitoEXhozdqqExk.jpg'),
(139520, 9914, 'Vivendo com o Inimigo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aa0wXR5uH2NM57jsDs0C5p8Z2vL.jpg'),
(139521, 9914, 'Vivendo com o Inimigo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mg9PEygyc2n3o8U7hYs9BHGnIBG.jpg'),
(139522, 9914, 'Vivendo com o Inimigo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5lq6fxNPzGBrUT9CLIlyju2QxZP.jpg'),
(139523, 9914, 'Vivendo com o Inimigo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uv6fyIsGcb92wExlUepQYIvG7GO.jpg'),
(139524, 9914, 'Vivendo com o Inimigo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8BpbQZLzqsMOZqsQZ3EJWFiCrLX.jpg'),
(139525, 9914, 'Vivendo com o Inimigo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wsB7XEnpLd0W4DMyi9Gz8MHggoi.jpg'),
(139526, 9914, 'Vivendo com o Inimigo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fMW707fdZ2T682Giaq2a5melZwx.jpg'),
(139527, 9914, 'Vivendo com o Inimigo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/274062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/PHq0pu5jucgxlJYArLy5qBLIXg.jpg'),
(139528, 9914, 'Vivendo com o Inimigo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/274063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ibG1lNgtw8WS46K1PUYY1ZzlP9i.jpg'),
(139529, 9914, 'Vivendo com o Inimigo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/274064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b96QVPON6jjWrAFpzU1xC0TbRcx.jpg'),
(139530, 9915, 'Vivendo com o Inimigo S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tRfJhgjo5aBPQvLPDB1KKE1FUjO.jpg'),
(139531, 9915, 'Vivendo com o Inimigo S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z1GOp5etg9EneAKy7Mh8uB4dbS7.jpg'),
(139532, 9915, 'Vivendo com o Inimigo S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jX0EXDmvB6JP44PtEp5XamQVvUz.jpg'),
(139533, 9915, 'Vivendo com o Inimigo S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iaHKudiUo0lmpQjCNLurjU9G8T.jpg'),
(139534, 9915, 'Vivendo com o Inimigo S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7M35206jX5uelzVRzKrmYLCWxjP.jpg'),
(139535, 9915, 'Vivendo com o Inimigo S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBv5Na7y2lIKwTLpe2cdqgFFk3o.jpg'),
(139536, 9915, 'Vivendo com o Inimigo S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kHrmk5UzodAptkLFNxTPzP5dVYa.jpg'),
(139537, 9915, 'Vivendo com o Inimigo S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/274072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ycAZG7UW9tVFuULh4wq0WDXmxkF.jpg'),
(139538, 9915, 'Vivendo com o Inimigo S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/274073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6NlVqC42jCUE2TdGa1hnVsXIpxQ.jpg'),
(139539, 9915, 'Vivendo com o Inimigo S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/274074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jUvBLeqhotcMMAByf6y86EK1Frk.jpg'),
(139540, 9915, 'Vivendo com o Inimigo S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/274075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wLd4TOXn3Sc2l29uBYJxaUhtr5Q.jpg'),
(139541, 9915, 'Vivendo com o Inimigo S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/274076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iH3vhmKdGPKHBquVKP4m38EPETr.jpg'),
(139542, 9916, 'Vivendo com o Inimigo S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xM63mHUhMDv0DDjFfGLW7J7aT4n.jpg'),
(139543, 9916, 'Vivendo com o Inimigo S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8sGMXbmaJOMDH4uAXLXHvd7DPEf.jpg'),
(139544, 9916, 'Vivendo com o Inimigo S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/alaVpLkaPYSsafOQrSkPf67XWl6.jpg'),
(139545, 9916, 'Vivendo com o Inimigo S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dLn1Yj4q3KdkjMIcbKtj1Mn8oNL.jpg'),
(139546, 9916, 'Vivendo com o Inimigo S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/umRiBiyBXCQ0lwKtABPxaztdiEp.jpg'),
(139547, 9916, 'Vivendo com o Inimigo S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3zsku7r2iMIZlZiMVjy57kHbgpK.jpg'),
(139548, 9916, 'Vivendo com o Inimigo S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/RwKHjclhkOQxEA0845E9TskfU7.jpg'),
(139549, 9916, 'Vivendo com o Inimigo S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/274084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pracEgveYkju2uWizZwkNta8qx5.jpg'),
(139550, 9917, 'Vivendo com o Inimigo S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/th78jWyCbpr52NVY6CNVVUjZLbg.jpg'),
(139551, 9917, 'Vivendo com o Inimigo S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bzMLlxxYIvAMnAvuB8EiJNxDaVD.jpg'),
(139552, 9917, 'Vivendo com o Inimigo S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JlJ90h5mx76JB1OyDBOuMnGCVJ.jpg'),
(139553, 9917, 'Vivendo com o Inimigo S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2pvKE1r8hwA7X8maKQwWFuV1Imo.jpg'),
(139554, 9917, 'Vivendo com o Inimigo S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7PX5LHnSPk7SC7V434hl7maATSp.jpg'),
(139555, 9917, 'Vivendo com o Inimigo S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zMyhcE1DlFNdendNFUE7fv38iRN.jpg'),
(139556, 9917, 'Vivendo com o Inimigo S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFfyhKT0wNZGv2BZKh8PINNj9DC.jpg'),
(139557, 9917, 'Vivendo com o Inimigo S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/274092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4DnYEUUoF7rl2J41gkn83cK3I6M.jpg'),
(139558, 9917, 'Vivendo com o Inimigo S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/274093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLk2NAMk1SRlgdNDfK9B5y62raQ.jpg'),
(139559, 9917, 'Vivendo com o Inimigo S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/274094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ghh8uOUG9kGqGv6OKXfjLQ0VoQN.jpg'),
(139560, 9917, 'Vivendo com o Inimigo S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/274095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cYUV7MMfJfGfNmwDDdfYZ2BlMZj.jpg'),
(139561, 9918, 'Vivendo com o Inimigo S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/EnPSObDiSBlBeJpLySebUgukwS.jpg'),
(139562, 9918, 'Vivendo com o Inimigo S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ov2Y34bCENReXH0FcO1Z6nSeebt.jpg'),
(139563, 9918, 'Vivendo com o Inimigo S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6r40SqG4ZdTPZWadTu889kLMGrn.jpg'),
(139564, 9918, 'Vivendo com o Inimigo S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/liqNgycYKVlTKgzzNL22FQoSVGC.jpg'),
(139565, 9918, 'Vivendo com o Inimigo S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bJcKKK9UUk8d2Gz69GfpdtIeOuN.jpg'),
(139566, 9918, 'Vivendo com o Inimigo S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e7yi8gVpdDhJ2E2RA4DdrKT4vEL.jpg'),
(139567, 9918, 'Vivendo com o Inimigo S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xVufAbzmJA1C0HJqZ8PBl7RtQkj.jpg'),
(139568, 9918, 'Vivendo com o Inimigo S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/274103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xsHpxNxkMONIINlPQ5B8Kb8f7U0.jpg'),
(139569, 9918, 'Vivendo com o Inimigo S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/274104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139570, 9919, 'Vivendo com o Inimigo S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tvR5uZmxDdgT75KUYNX7pguutla.jpg'),
(139571, 9919, 'Vivendo com o Inimigo S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zG0AvPaSjiewix91T8sWKFM3ryX.jpg'),
(139572, 9919, 'Vivendo com o Inimigo S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8es9PLMAWLsRUtz4XmrgSwQLpoM.jpg'),
(139573, 9919, 'Vivendo com o Inimigo S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k4kaFHOrEdFxTKnJdKR0CnPIiHt.jpg'),
(139574, 9919, 'Vivendo com o Inimigo S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8zcunAGbz2448rb1RntwOdmSCgf.jpg'),
(139575, 9919, 'Vivendo com o Inimigo S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jUjGuiMkpXUDDCEzDorJCVbXC4F.jpg'),
(139576, 9919, 'Vivendo com o Inimigo S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iIR0Gf0MJEdLlppB9gy6rsqnSA2.jpg'),
(139577, 9919, 'Vivendo com o Inimigo S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/274112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ycxDhaO1stjwnvbeRZzzHg2d8N.jpg'),
(139578, 9919, 'Vivendo com o Inimigo S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/274113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQCCkeTpMMv2wRtdqd6HB1eViHD.jpg'),
(139579, 9919, 'Vivendo com o Inimigo S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/274114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jax5m4eguWqTcvQx7VEWnHv1wP.jpg'),
(139580, 9919, 'Vivendo com o Inimigo S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/274115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o3bk2aUjeFdbJan5XGNgB5FnXkK.jpg'),
(139581, 9919, 'Vivendo com o Inimigo S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/274116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d8ry3SB6gjWIKuXWNwuEfalrtc4.jpg'),
(139582, 9920, 'Vivendo com o Inimigo S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4LikN2spwVUN350R86Cn6PQW31K.jpg'),
(139583, 9920, 'Vivendo com o Inimigo S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wiwzfHuoS8It7lNw6NC5DfnB5F0.jpg'),
(139584, 9920, 'Vivendo com o Inimigo S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hxJkEIxwWKfgrEKYpaL7p1ln3Qs.jpg'),
(139585, 9920, 'Vivendo com o Inimigo S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/reQKLOzw4ltQsYGjkToMutD2l9O.jpg'),
(139586, 9920, 'Vivendo com o Inimigo S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9xXPCzdh8pf9H1YtNNDyGYn4WI.jpg'),
(139587, 9920, 'Vivendo com o Inimigo S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/43f9s2UnT38FToZSr1fGTBls9I3.jpg'),
(139588, 9920, 'Vivendo com o Inimigo S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xGXhEjMf2ysoDvcSd5U2goZ8mCt.jpg'),
(139589, 9921, 'Vivendo com o Inimigo S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y0Itl0dsK4M3bEASFjpxFj9mliq.jpg'),
(139590, 9921, 'Vivendo com o Inimigo S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r95KOz9U0lmqaXbiZVneJtwtrxp.jpg'),
(139591, 9921, 'Vivendo com o Inimigo S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9r54yOG9DnKbcZ7Q7CqUP8uhjEk.jpg'),
(139592, 9921, 'Vivendo com o Inimigo S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nOTCTO8s5UkH6RQQqPagr3tLNCM.jpg'),
(139593, 9921, 'Vivendo com o Inimigo S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/by6wODkcb0cZyTBGhX0iY2uyPKQ.jpg'),
(139594, 9921, 'Vivendo com o Inimigo S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o1sIb1ZnREmTyHJYCTFB8VAYfZx.jpg'),
(139595, 9921, 'Vivendo com o Inimigo S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sOmXewsggF0fZS2vOign1o4HiuP.jpg'),
(139596, 9921, 'Vivendo com o Inimigo S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/274131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24LuYK1iAuilBzWejIb1nHYrWtA.jpg'),
(139597, 9922, 'Vivendo com o Inimigo S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v96kM3eEjuPZ8zIVjBQskiZ6pZu.jpg'),
(139598, 9922, 'Vivendo com o Inimigo S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u69N8bMszW57qZqgm6Fc0TO41zl.jpg'),
(139599, 9922, 'Vivendo com o Inimigo S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJObMVcPNZFCQpZdaMkQRFvDkZY.jpg'),
(139600, 9922, 'Vivendo com o Inimigo S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/27DMuZ7g0oJXE1SQS9d8e9qM50d.jpg'),
(139601, 9922, 'Vivendo com o Inimigo S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139602, 9922, 'Vivendo com o Inimigo S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r8aZ3CmabHrxcjcmpF11wlP6JUJ.jpg'),
(139603, 9922, 'Vivendo com o Inimigo S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/62H7tWk9kEoMIB2a4euKpK9wxJ3.jpg'),
(139604, 9922, 'Vivendo com o Inimigo S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/274139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7t3F7bAH5m8uK1daFY5elvObi9Z.jpg'),
(139605, 9922, 'Vivendo com o Inimigo S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/274140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9HZagO1a2Pgz6mPThwhIjikTeXx.jpg'),
(139606, 9922, 'Vivendo com o Inimigo S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/274141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mYDytMVOMflJtJUQOFUE9uDxq6w.jpg'),
(139607, 9922, 'Vivendo com o Inimigo S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/274142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tv2EZPlZZyIYwEFEJR6vxPPluSk.jpg'),
(139608, 9922, 'Vivendo com o Inimigo S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/274143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dh1IkyTEgvEqsPK4Y3TtyzHEqEi.jpg'),
(139609, 9922, 'Vivendo com o Inimigo S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/274144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tmHmfABMRIty6Ey4KuQyXsX9zp7.jpg'),
(139610, 9923, 'Vivendo com o Inimigo S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9HLQ5K3RZv49NMw0RiTnpzgpmKA.jpg'),
(139611, 9923, 'Vivendo com o Inimigo S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uzYLI5TfMEeJ7ix9VOgwCA5uiZZ.jpg'),
(139612, 9923, 'Vivendo com o Inimigo S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/npJZFqAVZTMQ0sVUfFDxYss2c9G.jpg'),
(139613, 9923, 'Vivendo com o Inimigo S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6gaz4qclsfML6oQplEvjajRAgnX.jpg'),
(139614, 9923, 'Vivendo com o Inimigo S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cqny72WcCNT2yr486fMbz5sZZiO.jpg'),
(139615, 9923, 'Vivendo com o Inimigo S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cCso1Rq2312JFILUyqzdkvebryS.jpg'),
(139616, 9923, 'Vivendo com o Inimigo S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/274151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qqMug3eyQRjn9db68bmbWNTiQQ5.jpg'),
(139617, 9923, 'Vivendo com o Inimigo S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/274152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jRhU54xi0XCWwmC6wpyRYYDUVFv.jpg'),
(139618, 9924, 'Vivendo com o Inimigo S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/274153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139619, 9924, 'Vivendo com o Inimigo S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/274154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ayZhJGSUHEEIPYeDDXGRxu1pRao.jpg'),
(139620, 9924, 'Vivendo com o Inimigo S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/274155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h8xuZTObRoaDWE4mvOFtf7VEACr.jpg'),
(139621, 9924, 'Vivendo com o Inimigo S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/274156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/knD02TlsD17kGqwwv9z1cQDV2Ry.jpg'),
(139622, 9924, 'Vivendo com o Inimigo S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/274157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5MX2lRMjM3ptQf2sRy5z9TNhixU.jpg'),
(139623, 9924, 'Vivendo com o Inimigo S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/274158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/22i6LyklBeS7k24OiqGyh1ra7YQ.jpg'),
(139624, 9925, 'Vivendo com o Inimigo S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/277375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h7h5tM3MEnBN5uQI1Hb3S5yuJIY.jpg'),
(139625, 9925, 'Vivendo com o Inimigo S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/277376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rIF9ZPcjn61c41E7WMaYj5GPA1.jpg'),
(139626, 9925, 'Vivendo com o Inimigo S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/277377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ec3t5HAIHIO1JLSkjAKNPN3exk0.jpg'),
(139627, 9925, 'Vivendo com o Inimigo S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/277378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oWihGvt098ccnBp5jTM87qH4rhn.jpg'),
(139628, 9925, 'Vivendo com o Inimigo S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/277379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ZzBMF8p0MwaKybzIUr1x302ZPM.jpg'),
(139629, 9925, 'Vivendo com o Inimigo S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/277380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1IQ6ZSJkZLGWptSIX9bJzurokr0.jpg'),
(139630, 9925, 'Vivendo com o Inimigo S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/277381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zAGSPfhHUStMHYfL0zD2uuHzhxm.jpg'),
(139631, 9925, 'Vivendo com o Inimigo S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/277382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2nP2E4hOD9mKiLQs78Lyewx211N.jpg'),
(139632, 9925, 'Vivendo com o Inimigo S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/277383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7HYFSTrxOjVonzeh75F7PTgxZRF.jpg'),
(139633, 9925, 'Vivendo com o Inimigo S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/277384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wIH7uNVV8IDpJbRF09xCCmx8pLO.jpg'),
(139634, 4892, 'Vivendo com o Inimigo S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/277385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/abfQ73Aab3u2fSDYGOSexs8EaRy.jpg'),
(139635, 4892, 'Vivendo com o Inimigo S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/277386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5H2I8Rvv628jA3ua9EDnmR6DsF9.jpg'),
(139636, 4892, 'Vivendo com o Inimigo S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/277387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/48SKkOEzPPF9T8cfmJTXg5xT51z.jpg'),
(139637, 9926, 'Vivendo com o Inimigo S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/722839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139638, 9926, 'Vivendo com o Inimigo S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/722840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139639, 9926, 'Vivendo com o Inimigo S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/722841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139640, 9926, 'Vivendo com o Inimigo S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/722842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139641, 9926, 'Vivendo com o Inimigo S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/722843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139642, 9926, 'Vivendo com o Inimigo S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/722844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139643, 9926, 'Vivendo com o Inimigo S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/722845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139644, 9926, 'Vivendo com o Inimigo S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/722846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139645, 9926, 'Vivendo com o Inimigo S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/722847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139646, 9926, 'Vivendo com o Inimigo S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/722848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139647, 9927, 'Vivendo com o Inimigo S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/722849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139648, 9927, 'Vivendo com o Inimigo S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/722850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139649, 9927, 'Vivendo com o Inimigo S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/722851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139650, 9927, 'Vivendo com o Inimigo S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/722852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139651, 9927, 'Vivendo com o Inimigo S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/722853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139652, 9927, 'Vivendo com o Inimigo S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/722854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139653, 9927, 'Vivendo com o Inimigo S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/722855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139654, 9927, 'Vivendo com o Inimigo S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/722856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139655, 9928, 'Vivendo com o Inimigo S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/852871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139656, 9928, 'Vivendo com o Inimigo S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/852872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139657, 9928, 'Vivendo com o Inimigo S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/852873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139658, 9928, 'Vivendo com o Inimigo S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/852874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139659, 9928, 'Vivendo com o Inimigo S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/852875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(139660, 9928, 'Vivendo com o Inimigo S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/852876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139661, 9928, 'Vivendo com o Inimigo S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/852877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139662, 9928, 'Vivendo com o Inimigo S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/852878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139663, 9928, 'Vivendo com o Inimigo S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/852879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139664, 9928, 'Vivendo com o Inimigo S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/852880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/asQuV7Nn0jS7NaF6HwbmYb66EHP.jpg'),
(139665, 9929, 'FBI Os Mais Procurados [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/taKmfRqnDrJQhUupIeqfAda3Ny5.jpg'),
(139666, 9929, 'FBI Os Mais Procurados [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3m0MTgMaiwGWtz4BrBJYntbbRXk.jpg'),
(139667, 9929, 'FBI Os Mais Procurados [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dlk6qSriJtJjqDlrB8ipxrVklO5.jpg'),
(139668, 9929, 'FBI Os Mais Procurados [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mXLUY07qS32eua8SbdzMl55xReq.jpg'),
(139669, 9929, 'FBI Os Mais Procurados [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8EJxTpK6iZEXB1dpQb34QwvqlZU.jpg'),
(139670, 9929, 'FBI Os Mais Procurados [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oPaZ67HJ1bHEk5Fp9cFJKYy9uik.jpg'),
(139671, 9929, 'FBI Os Mais Procurados [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8iK1ElnlIlRU1Wn7uYM6woxTpeT.jpg'),
(139672, 9929, 'FBI Os Mais Procurados [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Wlneg9crfWJAJ0Jw3pMhnn3IHm.jpg'),
(139673, 9929, 'FBI Os Mais Procurados [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n57fl5iAq7ajkXBspqzcfRXbwzK.jpg'),
(139674, 9929, 'FBI Os Mais Procurados [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5MdeimBqllmHuDJpOs0C0r6K8JX.jpg'),
(139675, 9929, 'FBI Os Mais Procurados [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oO9kFHHPy2Mie4x1e0tdxGh9BPn.jpg'),
(139676, 9929, 'FBI Os Mais Procurados [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/78pdPGWTEGibdyED6CDcszjMYVZ.jpg'),
(139677, 9929, 'FBI Os Mais Procurados [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p29JSxCk7fMbPRqyLvM2blaQ4QO.jpg'),
(139678, 9929, 'FBI Os Mais Procurados [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j5Ia7IwBwzZYdZUEtvl68IO4cwI.jpg'),
(139679, 9930, 'FBI Os Mais Procurados [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x1FZ2ySFZr9PxZSsMkpI0M1OPvb.jpg'),
(139680, 9930, 'FBI Os Mais Procurados [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1EgBq1XV6Qrc5PcUxVnDK9ORaOd.jpg'),
(139681, 9930, 'FBI Os Mais Procurados [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ySVjhC6EERp2bGyoB5W6mQEPQw4.jpg'),
(139682, 9930, 'FBI Os Mais Procurados [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fEHKJHYJydULuezViG54qIOmrBn.jpg'),
(139683, 9930, 'FBI Os Mais Procurados [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pbGZ9yDj6KxuzmvG2Fb04ooxTWS.jpg'),
(139684, 9930, 'FBI Os Mais Procurados [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ggRT8uS9txsiauuL3B6ZLjkfnZx.jpg'),
(139685, 9930, 'FBI Os Mais Procurados [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ap2RB7lIwdCkjX6OZTG5iHxjZNr.jpg'),
(139686, 9930, 'FBI Os Mais Procurados [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nOZmeqVONLyeGJNwi4xw1XV6y3c.jpg'),
(139687, 9930, 'FBI Os Mais Procurados [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tDXZv9PBk4SyLKuNxnei7ZqUorY.jpg'),
(139688, 9930, 'FBI Os Mais Procurados [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gmFbWSOxP5Pw3Lz794VlGXKRcoD.jpg'),
(139689, 9930, 'FBI Os Mais Procurados [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zfMgLXnobbdSXPY1M2nfEt2AEIn.jpg'),
(139690, 9930, 'FBI Os Mais Procurados [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b3zVwOTxBJX4IrqYV3eI5kR1crK.jpg'),
(139691, 9930, 'FBI Os Mais Procurados [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tcDa3VuTlg4ErcWyPTQZpfGW2st.jpg'),
(139692, 9930, 'FBI Os Mais Procurados [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lhoxbQOTzCmlAJenbrJMh8Z15CW.jpg'),
(139693, 9930, 'FBI Os Mais Procurados [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ygdTXJLDdyJtgurge0NK7XILrsL.jpg'),
(139694, 9931, 'FBI Os Mais Procurados [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwWj5AGyz5yCzBkXB3sXx1c4AGO.jpg'),
(139695, 9931, 'FBI Os Mais Procurados [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ih8n1SBeh5tRROtCXpXBQXJ18cL.jpg'),
(139696, 9931, 'FBI Os Mais Procurados [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6VisaR9aCh4AUsko2UNvF86NIuO.jpg'),
(139697, 9931, 'FBI Os Mais Procurados [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z9GsYjhFa0hYN0VnBxbBvCrPHtC.jpg'),
(139698, 9931, 'FBI Os Mais Procurados [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e95QcZVg44t0cbUt5ayNqvta6LP.jpg'),
(139699, 9931, 'FBI Os Mais Procurados [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vBpIHNuQtsrLasCMOrlJfjO5qjD.jpg'),
(139700, 9931, 'FBI Os Mais Procurados [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4GZc2WPhyGAOrFXyj04R9La7HDO.jpg'),
(139701, 9931, 'FBI Os Mais Procurados [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2UzUGrG23qyd4I9qxS8ntAHCauZ.jpg'),
(139702, 9931, 'FBI Os Mais Procurados [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lFVWEjJf7Ca5SKprFSYPkgksU2.jpg'),
(139703, 9931, 'FBI Os Mais Procurados [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pbXxp3WKSW8qJ1FX9GhtuSmT48O.jpg'),
(139704, 9931, 'FBI Os Mais Procurados [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/93LwBA3RNrmzpIVKibzZGtQ0D1m.jpg'),
(139705, 9931, 'FBI Os Mais Procurados [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hB39gR0AQOVXWNZE93IB6railDx.jpg'),
(139706, 9931, 'FBI Os Mais Procurados [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j2CswxOTJFhlOAnT0jtifQrOlwY.jpg'),
(139707, 9931, 'FBI Os Mais Procurados [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8KREKc8hVJz2UtiRzHs4w8Ac6bu.jpg'),
(139708, 9931, 'FBI Os Mais Procurados [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4J5RP4wIgG1oB4mRM5j4VO1Kdzj.jpg'),
(139709, 9931, 'FBI Os Mais Procurados [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d7xFlM4SDmL2naUNuJtzx0SWASB.jpg'),
(139710, 9931, 'FBI Os Mais Procurados [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/278377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dpxBCqv9WoD6WJV7y9lxj4i7FbD.jpg'),
(139711, 9931, 'FBI Os Mais Procurados [L] S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/278378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yHt64yJq0zGY0Q1lb9Qo6hIJi8o.jpg'),
(139712, 9931, 'FBI Os Mais Procurados [L] S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/278379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qJTaq2gbY0Zz0IMPQRU6tASoIdc.jpg'),
(139713, 9931, 'FBI Os Mais Procurados [L] S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/278380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4dyOdAophREkJeXJIyJPLN00SBi.jpg'),
(139714, 9931, 'FBI Os Mais Procurados [L] S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/278381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jJ32TttHW8Bdqg1qmIzX8ljY6d5.jpg'),
(139715, 9931, 'FBI Os Mais Procurados [L] S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/278382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1mlcdq4DqIeNpAuJZJm9LasvEzO.jpg'),
(139716, 9932, 'FBI Os Mais Procurados [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gY8DpneBHdQqeW9RAbS4tdCotvi.jpg'),
(139717, 9932, 'FBI Os Mais Procurados [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7qVmAYE0LRD7nUQsBSnSQbF7L57.jpg'),
(139718, 9932, 'FBI Os Mais Procurados [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Tf2a1zg7xsYX2miowzwhAipBhu.jpg'),
(139719, 9932, 'FBI Os Mais Procurados [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/haD2jUE52JSHY4kByijfy0kwWl6.jpg'),
(139720, 9932, 'FBI Os Mais Procurados [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqvp3oUCc44DxIZRCwgSl4rEdBm.jpg'),
(139721, 9932, 'FBI Os Mais Procurados [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/N6VNUMf5NpCpjIxZoKog7hPfJb.jpg'),
(139722, 9932, 'FBI Os Mais Procurados [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/KmAU3FJ29TKYr8ZpPnE14mOUAM.jpg'),
(139723, 9932, 'FBI Os Mais Procurados [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6SJwH3fJxQDan3iraifiv4DDkaj.jpg'),
(139724, 9932, 'FBI Os Mais Procurados [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ifM8fScmnrPG7OThaFGJxe3Qya9.jpg'),
(139725, 9932, 'FBI Os Mais Procurados [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8m0ROEA9j9wSA5Ekv3uSrMWwx0.jpg'),
(139726, 9932, 'FBI Os Mais Procurados [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uTqeGaMctN3Gb4c0BJbGj34rSW4.jpg'),
(139727, 9932, 'FBI Os Mais Procurados [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oRFyvWTjcRCGP5FQWXgE3dGNn4S.jpg'),
(139728, 9932, 'FBI Os Mais Procurados [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s7qz8y8Tlzd2mhdNnXXKf5NwVxk.jpg'),
(139729, 9932, 'FBI Os Mais Procurados [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4un4viKSmNAYjIM3ziyywBOdmn5.jpg'),
(139730, 9932, 'FBI Os Mais Procurados [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDrsVLniEQUgajAjEly7D3UB5bW.jpg'),
(139731, 9932, 'FBI Os Mais Procurados [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zGxQa1kP1dOtcS5K9XWBnp1AAXh.jpg'),
(139732, 9932, 'FBI Os Mais Procurados [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/278399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x1bnC7FiUWhSESpmwcySlPoCDlD.jpg'),
(139733, 9932, 'FBI Os Mais Procurados [L] S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/278400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wD8NzlQGvR8I8qZbWp0W3gFuV5H.jpg'),
(139734, 9932, 'FBI Os Mais Procurados [L] S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/278401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bH531IWAOXIoGQuZnnEdBFl0YIP.jpg'),
(139735, 9932, 'FBI Os Mais Procurados [L] S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/278402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hL5evYkbAE0gad5aiHh1RJxWHmN.jpg'),
(139736, 9932, 'FBI Os Mais Procurados [L] S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/278403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vcHbgf7GufK8Uc486idd5bzDpej.jpg'),
(139737, 9932, 'FBI Os Mais Procurados [L] S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/278404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cReVQLHHcuBykWda6ec2Cj3rI0d.jpg'),
(139738, 9933, 'FBI Os Mais Procurados [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/279034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139739, 9933, 'FBI Os Mais Procurados [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139740, 9933, 'FBI Os Mais Procurados [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139741, 9933, 'FBI Os Mais Procurados [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/305070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139742, 9933, 'FBI Os Mais Procurados [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/309004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139743, 9933, 'FBI Os Mais Procurados [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/315941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139744, 9933, 'FBI Os Mais Procurados [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/325885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139745, 9933, 'FBI Os Mais Procurados [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/328225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139746, 9933, 'FBI Os Mais Procurados [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/333125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139747, 9933, 'FBI Os Mais Procurados [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/338845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139748, 9933, 'FBI Os Mais Procurados [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/352571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139749, 9933, 'FBI Os Mais Procurados [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/360915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139750, 9933, 'FBI Os Mais Procurados [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/360916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139751, 9934, 'FBI Os Mais Procurados [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/485476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139752, 9934, 'FBI Os Mais Procurados [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/493734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139753, 9934, 'FBI Os Mais Procurados [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/496817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139754, 9934, 'FBI Os Mais Procurados [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/512444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139755, 9934, 'FBI Os Mais Procurados [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/512445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139756, 9934, 'FBI Os Mais Procurados [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/520351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139757, 9934, 'FBI Os Mais Procurados [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/521294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139758, 9934, 'FBI Os Mais Procurados [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/641839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139759, 9934, 'FBI Os Mais Procurados [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/684441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139760, 9934, 'FBI Os Mais Procurados [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/690583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139761, 9934, 'FBI Os Mais Procurados [L] S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/700264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139762, 9934, 'FBI Os Mais Procurados [L] S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/706338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139763, 9934, 'FBI Os Mais Procurados [L] S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/710464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139764, 9934, 'FBI Os Mais Procurados [L] S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/767388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139765, 9934, 'FBI Os Mais Procurados [L] S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/767389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139766, 9934, 'FBI Os Mais Procurados [L] S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/767390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139767, 9934, 'FBI Os Mais Procurados [L] S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/767391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139768, 9934, 'FBI Os Mais Procurados [L] S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/776769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139769, 9934, 'FBI Os Mais Procurados [L] S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/783448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139770, 9934, 'FBI Os Mais Procurados [L] S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/796647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139771, 9934, 'FBI Os Mais Procurados [L] S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/811155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vRoyQUWQIba6CVu2rhTGAHKgZRZ.jpg'),
(139772, 9935, 'Game of Thrones [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9hGF3WUkBf7cSjMg0cdMDHJkByd.jpg'),
(139773, 9935, 'Game of Thrones [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l0GJx3IR8YasbztTJi5uK0XqkEo.jpg'),
(139774, 9935, 'Game of Thrones [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8HjOlb4slc1xusMgOtoNpxuTgSI.jpg'),
(139775, 9935, 'Game of Thrones [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ai2UPMWv38xGjOgNBuA1o8w8dUI.jpg'),
(139776, 9935, 'Game of Thrones [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u7e1qSWE6v8jfY9vGNrckX47DGN.jpg'),
(139777, 9935, 'Game of Thrones [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AdhvrJxyYpINwYnGkBIf2krQKg.jpg'),
(139778, 9935, 'Game of Thrones [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o6ldSDhIINGNKZR62mHf2m64dD.jpg'),
(139779, 9935, 'Game of Thrones [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ZvT1IZPcC11eiCByOzqQvC3CCR.jpg'),
(139780, 9935, 'Game of Thrones [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAmBhmw1pQc6fucrdmnRM5FOpXD.jpg'),
(139781, 9935, 'Game of Thrones [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y1BXkhEqBQS3ewQeqqdHpjhTts0.jpg'),
(139782, 9936, 'Game of Thrones [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gGHtlTvHpSGZ8DIrxMyK3Ewkc1Y.jpg'),
(139783, 9936, 'Game of Thrones [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/de0UTpqFcGaVVO13sHqbjQ19c6I.jpg'),
(139784, 9936, 'Game of Thrones [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/neKkHgfX7dgi4E47GKT7bYciq93.jpg'),
(139785, 9936, 'Game of Thrones [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4j2j97GFao2NX4uAtMbr0Qhx2K2.jpg'),
(139786, 9936, 'Game of Thrones [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h7HHSQtEyf7cNBYR2G9DjQ78EgV.jpg'),
(139787, 9936, 'Game of Thrones [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zUgvLgKhI7XbjU4cAW9qffL6ImQ.jpg'),
(139788, 9936, 'Game of Thrones [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCDklRxVetx1COP4zXLLnXMS2S0.jpg'),
(139789, 9936, 'Game of Thrones [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4W90HbZcVG54m8HoxaZmXc8rzjy.jpg'),
(139790, 9936, 'Game of Thrones [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rX44Vfd0iiZDIJWHYZg9j4yLSP9.jpg'),
(139791, 9936, 'Game of Thrones [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u46jn12qEyaCOe1oqJBwPvL5d7R.jpg'),
(139792, 9937, 'Game of Thrones [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ZerJvXQXcM3tygHRkPTDbbK0hw.jpg'),
(139793, 9937, 'Game of Thrones [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ydrupjqBj6M68pUwJNJ5rbGmm1O.jpg'),
(139794, 9937, 'Game of Thrones [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i39Itkd76DOXxek0blIO6rI6zsa.jpg'),
(139795, 9937, 'Game of Thrones [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/veYx7AoKhxC8Pz8EThNpoOxeSGX.jpg'),
(139796, 9937, 'Game of Thrones [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/41CekEZyGvNLTJIJy7BqFDTitcC.jpg'),
(139797, 9937, 'Game of Thrones [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eJQ5vnNrlM28fpInn6uGM0xUZRX.jpg'),
(139798, 9937, 'Game of Thrones [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2RVD5pIIiv7ZH0qnazwVrsPEFpP.jpg'),
(139799, 9937, 'Game of Thrones [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2h0bTax0qB7cpY16uFecM5VeUal.jpg'),
(139800, 9937, 'Game of Thrones [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Cvg7NkvDPckIwPKWcyS25YcoSh.jpg'),
(139801, 9937, 'Game of Thrones [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wJbEFBLyogHR1GoxfDXNIoP4k1w.jpg'),
(139802, 9938, 'Game of Thrones [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mA7XXz9qHjsXqXHDDyFKPm4SOTv.jpg'),
(139803, 9938, 'Game of Thrones [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zOeaRpAKbrATuVe8Z5MtVJfair9.jpg'),
(139804, 9938, 'Game of Thrones [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pgwGxEDIv1XyB5TcJcJM7EMLWiX.jpg'),
(139805, 9938, 'Game of Thrones [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fbo6BnHrgr2wTc0m2gYPeylls8z.jpg'),
(139806, 9938, 'Game of Thrones [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bf0Z9votO2jqQLI0Y66TqfTjlyq.jpg'),
(139807, 9938, 'Game of Thrones [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vKt9b7HNYhwM91C7S53zPsAWfT3.jpg'),
(139808, 9938, 'Game of Thrones [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u1LNM3vEGX2SWmoDZZC6yxXZXu8.jpg'),
(139809, 9938, 'Game of Thrones [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cOcGpQmBvwuScHJjwQYlCreVl4x.jpg'),
(139810, 9938, 'Game of Thrones [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uDtXFnIKg9KqZkj1zVYYJFXPqwk.jpg'),
(139811, 9938, 'Game of Thrones [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dEvyoz6NrUGH3nyphu43hAzT1VE.jpg'),
(139812, 9939, 'Game of Thrones [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shIFxmFySt9CtGXMTXWBipsNOIs.jpg'),
(139813, 9939, 'Game of Thrones [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uCJpE0pfjn78uhr2TjvIrhyTcR8.jpg'),
(139814, 9939, 'Game of Thrones [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5b6eUi2w12ao24ug8cL5QqJFKig.jpg'),
(139815, 9939, 'Game of Thrones [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJK24ELjz04a05saADPXkYafa21.jpg'),
(139816, 9939, 'Game of Thrones [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/25HHLKWpNKiy6e7zBhaoysK9hzv.jpg'),
(139817, 9939, 'Game of Thrones [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/siGoOvAqTTyojNHpfR8wilIoBjf.jpg'),
(139818, 9939, 'Game of Thrones [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n4BFZfiqOX1l5l6uYtpDS4m19WX.jpg'),
(139819, 9939, 'Game of Thrones [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/58PgfiE8eIOdQ1iDvFnJG471RFB.jpg'),
(139820, 9939, 'Game of Thrones [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ymI7V3wsZRcRqLWgjJ59CTTGvh5.jpg'),
(139821, 9939, 'Game of Thrones [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5dIepsIO3robQSe18fWmsQe37R.jpg'),
(139822, 9940, 'Game of Thrones [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qEu20NFIbwxtyABtFvsyyPaCNDM.jpg'),
(139823, 9940, 'Game of Thrones [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JlZ6sOXf4nodwWYvoM5zCJIGm9.jpg'),
(139824, 9940, 'Game of Thrones [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dNp7HBQbwKlgX76fwqM6SWUo5tU.jpg'),
(139825, 9940, 'Game of Thrones [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dY2DbzgIjIatJJCVRgk1gKTJWez.jpg'),
(139826, 9940, 'Game of Thrones [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/96u7HuryCkPEIN3JkZP336KTSq3.jpg'),
(139827, 9940, 'Game of Thrones [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k01MUth8Xm2y79nvsQ3UF25SN9w.jpg'),
(139828, 9940, 'Game of Thrones [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ymjvIqw8GClvQpurBYMeyaYXTck.jpg'),
(139829, 9940, 'Game of Thrones [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xl2l1a3kXGxWwZqGDgjowBk4x46.jpg'),
(139830, 9940, 'Game of Thrones [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j2znyjFSe1ol26DeQWMB1yE5EDQ.jpg'),
(139831, 9940, 'Game of Thrones [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8qgIcKTOKeAHlJMjGyPHl3IHjcU.jpg'),
(139832, 9941, 'Game of Thrones [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3SB4PUzZAnY6HnZbVbktIZoopGs.jpg'),
(139833, 9941, 'Game of Thrones [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ZLuB2YZeXTCEETnbPe5MNKCsio.jpg'),
(139834, 9941, 'Game of Thrones [L] S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xSqdpR6qADmjsdlcJLX5LXRToQP.jpg'),
(139835, 9941, 'Game of Thrones [L] S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hH9gSHcisHqoux734Q2SdLPLmsL.jpg'),
(139836, 9941, 'Game of Thrones [L] S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3iaJDPtj75z1YpLDMKR17JRXQdP.jpg'),
(139837, 9941, 'Game of Thrones [L] S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jDMCK1E4iqH8ZJeZnv3ftpei0nm.jpg'),
(139838, 9941, 'Game of Thrones [L] S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w4N4xxFrfjUyk7wE5hgcoAy0tDc.jpg'),
(139839, 9942, 'Game of Thrones [L] S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o65qwX1aHJclJ36VDhD3VYzz5em.jpg'),
(139840, 9942, 'Game of Thrones [L] S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJ8H9WtzbJGfArfdycc4nagQVRU.jpg'),
(139841, 9942, 'Game of Thrones [L] S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mFtHbZenI5rRPqC5OFafoVmjEjq.jpg'),
(139842, 9942, 'Game of Thrones [L] S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qe508xwVVO7cF2oWzfJp52StkTk.jpg'),
(139843, 9942, 'Game of Thrones [L] S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xF9hOs5h9sc37oWdtF4RPHq8dXA.jpg'),
(139844, 9942, 'Game of Thrones [L] S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBi2O5EJfgTS6Ae0HdAYLm9o2nf.jpg'),
(139845, 9943, 'Skip Beat S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3nMbbEOiwYB8WAFQt2mRDM31TG9.jpg'),
(139846, 9943, 'Skip Beat S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/77oC6g3fYKW8lWWQsy9bYE2lMxA.jpg'),
(139847, 9943, 'Skip Beat S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j8KnxZiW5J06hRgoc7cuPgN8DnD.jpg'),
(139848, 9943, 'Skip Beat S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/279469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139849, 9943, 'Skip Beat S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/279470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139850, 9943, 'Skip Beat S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/285759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139851, 9943, 'Skip Beat S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/285760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139852, 9943, 'Skip Beat S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/343027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139853, 9943, 'Skip Beat S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/343028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139854, 9943, 'Skip Beat S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/343029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139855, 9943, 'Skip Beat S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/343030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139856, 9943, 'Skip Beat S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/343031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139857, 9943, 'Skip Beat S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/343032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139858, 9943, 'Skip Beat S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/343033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139859, 9943, 'Skip Beat S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/343034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139860, 9943, 'Skip Beat S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/343035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139861, 9943, 'Skip Beat S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/343036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139862, 9943, 'Skip Beat S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/343037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139863, 9943, 'Skip Beat S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/343038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139864, 9943, 'Skip Beat S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/343039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139865, 9943, 'Skip Beat S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/343040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139866, 9943, 'Skip Beat S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/343041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139867, 9943, 'Skip Beat S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/343042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139868, 9943, 'Skip Beat S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/343043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139869, 9943, 'Skip Beat S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/343044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9crmGhDGGJuXj1GKyqhPiFrUQr.jpg'),
(139870, 9944, 'Suits [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2GmJD80FGtMIcca1UuLIIuIm2c1.jpg'),
(139871, 9944, 'Suits [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n0bGqpX5jZaxG3vvw4Gq5InvxFF.jpg'),
(139872, 9944, 'Suits [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rohDcpKFJwRXvHrEuh3j6eGOuLw.jpg'),
(139873, 9944, 'Suits [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u7Ips46UxRF9F0BJAdSxa0aQeMj.jpg'),
(139874, 9944, 'Suits [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rmIh7NHAfreZgVoX7hG3EHEKIe6.jpg'),
(139875, 9944, 'Suits [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yT4t1HJEx2jJTEYeJIZnTN1Y8za.jpg'),
(139876, 9944, 'Suits [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZNVeetYoZo3JCPRu5oQbjsl3B5.jpg'),
(139877, 9944, 'Suits [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hsfEwCAPwdSJNqC4ADLYh57pal1.jpg'),
(139878, 9944, 'Suits [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fIynnH3wjc8ArqfCULBCYdyWCB8.jpg'),
(139879, 9944, 'Suits [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4PrnmETDQgH8mZQk1YE1aRVo3Qz.jpg'),
(139880, 9944, 'Suits [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4zPzCl3xqn1B6MCUdpnHyQAJHsf.jpg'),
(139881, 9944, 'Suits [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cssJ7NhSXYfWNHdDJYXmDGgGYEp.jpg'),
(139882, 9945, 'Suits [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gi1DQ0wSPkEbxSZReL73ESsS2XB.jpg'),
(139883, 9945, 'Suits [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/clxK6oT6F5FD8EWsg3J0CiQIXWx.jpg'),
(139884, 9945, 'Suits [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sQ6oD8xZ2lJwvhk01jQ5QPF6syI.jpg'),
(139885, 9945, 'Suits [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7VdwhntEMnIz1EhxkcRk09gv5ts.jpg'),
(139886, 9945, 'Suits [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/adxd0ppqT9zOynFvtSjl7Fq5knP.jpg'),
(139887, 9945, 'Suits [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bwTLLOML8VpuJ3ACrY3yHCqGJqc.jpg'),
(139888, 9945, 'Suits [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gv7yM01BPxu5IEyiOXAlriqKIV7.jpg'),
(139889, 9945, 'Suits [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cQ29XCZiAyiDpKnmB6hTAJSgR9u.jpg'),
(139890, 9945, 'Suits [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3bprO7iFRbHpjJzRsFjvjDjQIYm.jpg'),
(139891, 9945, 'Suits [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/muaurjvMczn6PZE2hOGKuh4EkqR.jpg'),
(139892, 9945, 'Suits [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mUJTSMmxpXL9hiDI0wCdAW39H81.jpg'),
(139893, 9945, 'Suits [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7fY3QJRQGtdYsMbteTw30GarU79.jpg'),
(139894, 9945, 'Suits [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dzyXiBetjvP4lAtvMzz5IDww1ae.jpg'),
(139895, 9945, 'Suits [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JsguU7Ehw6AuqB4z1s1dtRx9Ka.jpg'),
(139896, 9945, 'Suits [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jDzK1uE2ied6viZ98uDtx3xjJEw.jpg'),
(139897, 9945, 'Suits [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wqLV57rFhBS5LyWKf1koHKcwETd.jpg'),
(139898, 9946, 'Suits [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gIk9qBkpJDsVXdrU3kqtan2Ylg5.jpg'),
(139899, 9946, 'Suits [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xg8ehY3sTZ4b1cFgluhKBo0xSQo.jpg'),
(139900, 9946, 'Suits [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mSsRY3eSD5MwKz8TWZozQ9NNUfR.jpg'),
(139901, 9946, 'Suits [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6q2Dnx17Njeou2qFRDJ5rBG8zg.jpg'),
(139902, 9946, 'Suits [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yshzNsaOgDLWpejdWdNNppbk0SB.jpg'),
(139903, 9946, 'Suits [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kwENlbTx0aBGeLBuVLdsfqyZ1Zk.jpg'),
(139904, 9946, 'Suits [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tRfGHMLDpaYjJJkfNsIgyIg3E9u.jpg'),
(139905, 9946, 'Suits [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x4ajUguqfzg8AUsIwZNbpdcdXNe.jpg'),
(139906, 9946, 'Suits [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMOw6qCgSEJFl0zIjU76kQ7HqjJ.jpg'),
(139907, 9946, 'Suits [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/27ZFjhAkAxdwce2FghKFclsnuC.jpg'),
(139908, 9946, 'Suits [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/knOogYDCMqZN7uGzkJFXpaxY4fx.jpg'),
(139909, 9946, 'Suits [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Uwf4LB96caRnZbnvuJ7jzwg1Bt.jpg'),
(139910, 9946, 'Suits [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pjIgziIbRXWrqFbK3OQR7WjD1Zu.jpg'),
(139911, 9946, 'Suits [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sIKGRAOziNDS8rybExHCGd8fSi3.jpg'),
(139912, 9946, 'Suits [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7KP5lT3FTURpDG9qfs5la0GnjSq.jpg'),
(139913, 9946, 'Suits [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4fsur7I6snUigEJJMXJ9jdDZSE8.jpg'),
(139914, 9947, 'Suits [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ciKysHwQJh92yIWwaGPg43gvlO6.jpg'),
(139915, 9947, 'Suits [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjvT0ZMO8L6fNy62ks5xFKarbYc.jpg'),
(139916, 9947, 'Suits [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cCg3mOxnmxRiaNEoXOVvqkPxzTp.jpg'),
(139917, 9947, 'Suits [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqekTyHGOfrAnjfL6sgDBZeRt5N.jpg'),
(139918, 9947, 'Suits [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAvhkJ6HbYItMQDEdFfOuzvZU58.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(139919, 9947, 'Suits [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nqjxboVKeAfCxxpff4SEZdPxqFF.jpg'),
(139920, 9947, 'Suits [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mKEjEBxUwUcTdNzWYAIwJsgVeez.jpg'),
(139921, 9947, 'Suits [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wgpo4C1pFwbcXrWkHI55t5Q67ad.jpg'),
(139922, 9947, 'Suits [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AfUwY3Z7z2gigfCdKgdy8288C3G.jpg'),
(139923, 9947, 'Suits [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yZohnbfPBKvxT1EbLpU48JjoZI7.jpg'),
(139924, 9947, 'Suits [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5SCOpxT0rhIQ82PKWTdIVVazm3S.jpg'),
(139925, 9947, 'Suits [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rKah4oW2kJtoITjfm9YdEcpOvGk.jpg'),
(139926, 9947, 'Suits [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/piMpSiiGorqeBwhD0gHsI9ud9Hu.jpg'),
(139927, 9947, 'Suits [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yKP8CNDvqTJLkeuOBlSUIsmPIrp.jpg'),
(139928, 9947, 'Suits [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qTzosMjl1hLp2kqcIMBsdQb3yRc.jpg'),
(139929, 9947, 'Suits [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cguNLf9MFmO7Y1OCLdX6Pgq4WOX.jpg'),
(139930, 9948, 'Suits [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Pw2OFFGxv34Szk8rlWIa5st31J.jpg'),
(139931, 9948, 'Suits [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lojXDaWy3gHJjQSEjkzJf1f0QsH.jpg'),
(139932, 9948, 'Suits [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZ0YmsvDdcXDQ3P3yEBRQeb3K4J.jpg'),
(139933, 9948, 'Suits [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QmG1eUy3kCdn1IsCzuWoo85CJl.jpg'),
(139934, 9948, 'Suits [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m0ZiRkogS58WfS5OMMmRQDSwGmk.jpg'),
(139935, 9948, 'Suits [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tKT8uiYxRVDy83NN94J4MR9Z7Rf.jpg'),
(139936, 9948, 'Suits [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/liMoUzLWN7a3aXKDWiFsJ2sOzLB.jpg'),
(139937, 9948, 'Suits [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9WMmNJ5zER6oXtTlP44AdUQKp6C.jpg'),
(139938, 9948, 'Suits [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fMQFvQPZR3j6NijOJDdwGXi8Wfb.jpg'),
(139939, 9948, 'Suits [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qHW94gwiuA7rgxo4tWWlnBkr3UO.jpg'),
(139940, 9948, 'Suits [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2j1VqVJe9zjKvr5IYk2sFuE7Rcl.jpg'),
(139941, 9948, 'Suits [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mg42HN3qlxYXLdSF6J2FQMlTs36.jpg'),
(139942, 9948, 'Suits [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/76RsiytPkQtFEBctLu3smkzHdGr.jpg'),
(139943, 9948, 'Suits [L] S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1OIfK2nPDwEWWVgky0xzGdN8oc.jpg'),
(139944, 9948, 'Suits [L] S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/804cu6b3SJt7BQJb6mb4Ow9H0UL.jpg'),
(139945, 9948, 'Suits [L] S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gkq4vJQe0xqidAU1vtIvZvx34mc.jpg'),
(139946, 9949, 'Suits [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nV6C5FRfE7Tmgn4G1GKuTc9Gxvy.jpg'),
(139947, 9949, 'Suits [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sAkyfHORZroNF1u4jmc4cD1moDI.jpg'),
(139948, 9949, 'Suits [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aqblt3WGz6gRu5XXZVfczW7hYKp.jpg'),
(139949, 9949, 'Suits [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sF4FtIDgZT6ltoaXa5Ro0xNYm8r.jpg'),
(139950, 9949, 'Suits [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3J2qyH2yGN2vWN311G2NNE4JQq.jpg'),
(139951, 9949, 'Suits [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jJyEmjxP5DIVsByEedkdOtKKP9U.jpg'),
(139952, 9949, 'Suits [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jwItyuXvPwqcfhNOvhuSrz1FnG1.jpg'),
(139953, 9949, 'Suits [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w7aD7nC0erVIzc0fhBUL895hX8N.jpg'),
(139954, 9949, 'Suits [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yYFgCbyLHvOE6J8m64Cm8if6Zad.jpg'),
(139955, 9949, 'Suits [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hjBHm4U2G8QFJg3ZDammtbxTAxY.jpg'),
(139956, 9949, 'Suits [L] S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tZDrPV71Hk0LM1HnmP5WoVSOhE0.jpg'),
(139957, 9949, 'Suits [L] S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7GwHT34t4z8IDMa3E84Cu6ygF3B.jpg'),
(139958, 9949, 'Suits [L] S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xUzHmGVWzyGeZ5hBA5VfRxq6JuV.jpg'),
(139959, 9949, 'Suits [L] S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9hBLzwWXRnsvvhcfgFrDzs4wjBw.jpg'),
(139960, 9949, 'Suits [L] S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xpki3bupVGw1QdwTimzRqYZ0WS3.jpg'),
(139961, 9949, 'Suits [L] S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ihBiINNEG6mgmjAvXfs3HckkAPT.jpg'),
(139962, 9950, 'Suits [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6yXn3wrebhbZ8DYhO1MflQ8ycjV.jpg'),
(139963, 9950, 'Suits [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r10NvlwUAqgfldrokUWsA0Ilw5c.jpg'),
(139964, 9950, 'Suits [L] S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4AWhUkpbAATkHr9wz43eO6l6Ii.jpg'),
(139965, 9950, 'Suits [L] S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1F36le7YYNfTlkIMxAZFZlxWEBZ.jpg'),
(139966, 9950, 'Suits [L] S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dc3oOcsVrMRkTByKQVVbGFF0gm3.jpg'),
(139967, 9950, 'Suits [L] S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zm0IQRnKoGc7SrevCuS56srAfAV.jpg'),
(139968, 9950, 'Suits [L] S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tGbcJL68jSrGnXv50sqVwLMx408.jpg'),
(139969, 9950, 'Suits [L] S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5c08FKCd2zpNYiRw5ObFRFDE0is.jpg'),
(139970, 9950, 'Suits [L] S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nEeFEpDmwOVpMXdBhrMro18j6GC.jpg'),
(139971, 9950, 'Suits [L] S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/PWKluQslULQ761vNXi3yJyWkem.jpg'),
(139972, 9950, 'Suits [L] S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/95pNVpSVFERZ799ZYdoBfM60TK9.jpg'),
(139973, 9950, 'Suits [L] S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vh1839CG79zJMF4ThoXfm8IHG4O.jpg'),
(139974, 9950, 'Suits [L] S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yYO4pJRoROezxB9FtOm7qdXtvJg.jpg'),
(139975, 9950, 'Suits [L] S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p0dhZyJKdIVQfSIGQPWc8XMvhmd.jpg'),
(139976, 9950, 'Suits [L] S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nXiraJqOApHb07KM5VUSs7wgi6N.jpg'),
(139977, 9950, 'Suits [L] S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Tf11LtXCMJELjhw1KjSBYpN3d5.jpg'),
(139978, 9951, 'Suits [L] S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/irMbpaKsh9ZMUfc1gfFxUQVUsOV.jpg'),
(139979, 9951, 'Suits [L] S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eR3fEt9tDFAMdCeGj0ecYWGwHVl.jpg'),
(139980, 9951, 'Suits [L] S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/debMKpLwQOjMw4pGGw0UTYj5Zp0.jpg'),
(139981, 9951, 'Suits [L] S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dizq553p2WL3PQymokOvvdQQDF.jpg'),
(139982, 9951, 'Suits [L] S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOFgHXnUJ20fxRNrVdTw1qYuoeq.jpg'),
(139983, 9951, 'Suits [L] S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h5a19IndgRfP8tA7u1CBUiLDKLX.jpg'),
(139984, 9951, 'Suits [L] S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s9LtHmKQVjzhm8omPGtdUsW1FAp.jpg'),
(139985, 9951, 'Suits [L] S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vAJx24Sg9wPcDl6P4qa3BIQeqxr.jpg'),
(139986, 9951, 'Suits [L] S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3JIccjqkciZkGFtm3QyjYrdFKX6.jpg'),
(139987, 9951, 'Suits [L] S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pf5ItXUnV1UyGwBBUcEkGbtWMl.jpg'),
(139988, 9951, 'Suits [L] S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dSZ0eSWUtgCQwIA5NEa6OKzstDo.jpg'),
(139989, 9951, 'Suits [L] S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8d16O500ai9w5ZyKpY3d5OC39n6.jpg'),
(139990, 9951, 'Suits [L] S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLvIqkeXMfaHCPwOcXwa2Rr6xzN.jpg'),
(139991, 9951, 'Suits [L] S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZcZgsgR90e5JTSPKyRd7Cc6in.jpg'),
(139992, 9951, 'Suits [L] S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hfPrIhegS0p6UDoi0eSllsoEmsP.jpg'),
(139993, 9951, 'Suits [L] S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aLu4shQMUrEQWE2MTXD9gKw4g0m.jpg'),
(139994, 9952, 'Suits [L] S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iiBwtxBWyHrBFIYZp7aNKEo83eD.jpg'),
(139995, 9952, 'Suits [L] S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b3aP6N0rhZ7VCzdeulBJWpuIBXg.jpg'),
(139996, 9952, 'Suits [L] S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8iwNv3f0An0OTmsPIxibKlHgdgk.jpg'),
(139997, 9952, 'Suits [L] S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nl7p18DqW1O17EBvaNRoFWJs7Dj.jpg'),
(139998, 9952, 'Suits [L] S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fk94OjmPBl9pCLeGzBf14GvRhtA.jpg'),
(139999, 9952, 'Suits [L] S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qjrunQjCbktH5YkxyklBPjJZ8Z.jpg'),
(140000, 9952, 'Suits [L] S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/An3IqeNWwE1RExEb24LXQzG1Jcv.jpg'),
(140001, 9952, 'Suits [L] S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/viFjooW4tDBSpLPDrs5oiN2CB8W.jpg'),
(140002, 9952, 'Suits [L] S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rZIXY9OFwrJnVri1ECFHOgWdnIm.jpg'),
(140003, 9952, 'Suits [L] S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e7BhlfSF2DHkTAbi7OGJes347PS.jpg'),
(140004, 9953, 'Gigantes da Industria Uma Geracao de Titas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fhBaRTa234o2JcIXW0k4E2tWTJ2.jpg'),
(140005, 9953, 'Gigantes da Industria Uma Geracao de Titas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/60mh0xjjiMHW4ipXnHrdoz1vu1L.jpg'),
(140006, 9953, 'Gigantes da Industria Uma Geracao de Titas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gcOIyqxlJ5xt53VtUwvjbzgY8sC.jpg'),
(140007, 9954, 'A Copa do Mundo de Messi A Ascensao da Lenda [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yOQ6t8dB7TPBKY6pVJcUKXaRY3K.jpg'),
(140008, 9954, 'A Copa do Mundo de Messi A Ascensao da Lenda [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4UxrpvoWSjP5to2lY6kBlU3KUJl.jpg'),
(140009, 9954, 'A Copa do Mundo de Messi A Ascensao da Lenda [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3U6mdycxla8k8SdTiZ6ZjMukGi3.jpg'),
(140010, 9954, 'A Copa do Mundo de Messi A Ascensao da Lenda [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rvUh1VodFdX5FLCOHYyAtknHnQi.jpg'),
(140011, 9955, 'A Reinvencao da China [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gIqxnGT0zzsMFKcZYQeUWljIFrC.jpg'),
(140012, 9955, 'A Reinvencao da China [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nzZPZGXycY4tk0n5ZsQSeamlj2r.jpg'),
(140013, 9956, 'Aria The Animation S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wla7uMxdmk6iJpAlJ9m3dUYSx7i.jpg'),
(140014, 9956, 'Aria The Animation S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kojSHeTELzdZ0Ivg1knC62lP49F.jpg'),
(140015, 9956, 'Aria The Animation S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gm0bm9Qnd2k7qVSZcqTbYV6fu8i.jpg'),
(140016, 9956, 'Aria The Animation S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7JMPSPto098Y8rnIdIGDIsk7vT3.jpg'),
(140017, 9956, 'Aria The Animation S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qwcIYcF4IIr75Uq9jllSgBOqWNK.jpg'),
(140018, 9956, 'Aria The Animation S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dLK4lhhKcqBOxrqcPkhoADn2MAW.jpg'),
(140019, 9956, 'Aria The Animation S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sWlwujY5GKvQ2nYww3TRPUvHPux.jpg'),
(140020, 9956, 'Aria The Animation S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4kQwaHXGGai8l0O8KGpGKJVTOtp.jpg'),
(140021, 9956, 'Aria The Animation S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/289370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140022, 9956, 'Aria The Animation S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/289371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140023, 9956, 'Aria The Animation S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/289372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140024, 9956, 'Aria The Animation S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/289373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140025, 9956, 'Aria The Animation S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/296451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140026, 9957, 'Aria The Animation S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140027, 9957, 'Aria The Animation S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140028, 9957, 'Aria The Animation S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/405368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140029, 9957, 'Aria The Animation S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/405369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140030, 9957, 'Aria The Animation S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/405370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140031, 9957, 'Aria The Animation S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/405371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140032, 9957, 'Aria The Animation S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/405372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140033, 9957, 'Aria The Animation S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/405373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140034, 9957, 'Aria The Animation S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/405374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140035, 9957, 'Aria The Animation S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/405375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140036, 9957, 'Aria The Animation S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/405376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140037, 9957, 'Aria The Animation S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/405377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140038, 9957, 'Aria The Animation S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/405378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140039, 9957, 'Aria The Animation S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/405379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140040, 9957, 'Aria The Animation S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/405380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140041, 9957, 'Aria The Animation S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/405381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140042, 9957, 'Aria The Animation S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/405382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140043, 9957, 'Aria The Animation S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/405383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140044, 9957, 'Aria The Animation S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/405384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140045, 9957, 'Aria The Animation S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/405385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140046, 9957, 'Aria The Animation S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/405386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140047, 9957, 'Aria The Animation S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/405387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140048, 9957, 'Aria The Animation S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/405388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140049, 9957, 'Aria The Animation S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/405389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140050, 9957, 'Aria The Animation S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/405390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140051, 9957, 'Aria The Animation S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/405391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140052, 9958, 'Aria The Animation S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140053, 9958, 'Aria The Animation S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140054, 9958, 'Aria The Animation S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/405394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140055, 9958, 'Aria The Animation S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/405395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140056, 9958, 'Aria The Animation S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/405396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140057, 9958, 'Aria The Animation S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/405397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140058, 9958, 'Aria The Animation S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/405398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140059, 9958, 'Aria The Animation S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/405399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140060, 9958, 'Aria The Animation S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/405400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140061, 9958, 'Aria The Animation S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/405401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140062, 9958, 'Aria The Animation S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/405402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140063, 9958, 'Aria The Animation S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/405403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140064, 9958, 'Aria The Animation S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/405404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140065, 9958, 'Aria The Animation S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/405405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5g6Tv4VnmEYgw23N4xw6unPYukX.jpg'),
(140066, 9959, 'Avatar O Ultimo Mestre do Ar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3eLPQfIOva0RSAoviRgNqBtqPck.jpg'),
(140067, 9959, 'Avatar O Ultimo Mestre do Ar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fBg3ih6klXw61XGMAhaXucHhomo.jpg'),
(140068, 9959, 'Avatar O Ultimo Mestre do Ar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k05PJk3Ym75fWZ43TzWwA6KZ202.jpg'),
(140069, 9959, 'Avatar O Ultimo Mestre do Ar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zEKE4WLjHImmn9xAl1OCFxSroVQ.jpg'),
(140070, 9959, 'Avatar O Ultimo Mestre do Ar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cVbAWz6K87JgF8iYjzZL1DA3BEl.jpg'),
(140071, 9959, 'Avatar O Ultimo Mestre do Ar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ydSEm8QnzgMDWYz4Z3dvhbsmhZH.jpg'),
(140072, 9959, 'Avatar O Ultimo Mestre do Ar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l5n5OwFQPH0NyuBA4NEySAoO8hL.jpg'),
(140073, 9959, 'Avatar O Ultimo Mestre do Ar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ms2trhGJv7yWUe8doDMa9EHccAS.jpg'),
(140074, 9960, 'Boku no Kokoro no Yabai Yatsu [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5s4C8FRYuz7XyH1mvoBHpTn9HeY.jpg'),
(140075, 9960, 'Boku no Kokoro no Yabai Yatsu [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/db5YmNNbbFBq7mk7aL7EunsKYh6.jpg'),
(140076, 9960, 'Boku no Kokoro no Yabai Yatsu [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ggTUCJvzRmhPM5ooD42U39xmxwg.jpg'),
(140077, 9960, 'Boku no Kokoro no Yabai Yatsu [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zCCLuL4NM2LJcfD0Q7OFZ0zttXy.jpg'),
(140078, 9960, 'Boku no Kokoro no Yabai Yatsu [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/38krNuHMvZUPEkLXHRO5CZCsQUh.jpg'),
(140079, 9960, 'Boku no Kokoro no Yabai Yatsu [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7qFGFcHkYhmOLM0KYz4TM1Mas6b.jpg'),
(140080, 9960, 'Boku no Kokoro no Yabai Yatsu [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xO9aHj6z9sR5vzGwmaFk0MGibXM.jpg'),
(140081, 9960, 'Boku no Kokoro no Yabai Yatsu [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/if743UronMcJjQKy0Aczjf2Ufs7.jpg'),
(140082, 9960, 'Boku no Kokoro no Yabai Yatsu [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vCAzl2OhRThAAaqDsrQeNRwWCJz.jpg'),
(140083, 9960, 'Boku no Kokoro no Yabai Yatsu [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s4JFcmqDB0PdJOxVaWNwgk9VykQ.jpg'),
(140084, 9960, 'Boku no Kokoro no Yabai Yatsu [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/htpCCMuxrMZc50AoqQfNLaMA1rq.jpg'),
(140085, 9960, 'Boku no Kokoro no Yabai Yatsu [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xeO6zQOOLZ0I4QyjL3pHuBjWPiz.jpg'),
(140086, 9961, 'Boku no Kokoro no Yabai Yatsu [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkzRP40C6yhBxZ63Z7pBHNhqdAs.jpg'),
(140087, 9961, 'Boku no Kokoro no Yabai Yatsu [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkzRP40C6yhBxZ63Z7pBHNhqdAs.jpg'),
(140088, 9961, 'Boku no Kokoro no Yabai Yatsu [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkzRP40C6yhBxZ63Z7pBHNhqdAs.jpg'),
(140089, 9961, 'Boku no Kokoro no Yabai Yatsu [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkzRP40C6yhBxZ63Z7pBHNhqdAs.jpg'),
(140090, 9961, 'Boku no Kokoro no Yabai Yatsu [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkzRP40C6yhBxZ63Z7pBHNhqdAs.jpg'),
(140091, 9961, 'Boku no Kokoro no Yabai Yatsu [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkzRP40C6yhBxZ63Z7pBHNhqdAs.jpg'),
(140092, 9961, 'Boku no Kokoro no Yabai Yatsu [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkzRP40C6yhBxZ63Z7pBHNhqdAs.jpg'),
(140093, 9961, 'Boku no Kokoro no Yabai Yatsu [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/295827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkzRP40C6yhBxZ63Z7pBHNhqdAs.jpg'),
(140094, 9961, 'Boku no Kokoro no Yabai Yatsu [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/305455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkzRP40C6yhBxZ63Z7pBHNhqdAs.jpg'),
(140095, 9961, 'Boku no Kokoro no Yabai Yatsu [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/323054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkzRP40C6yhBxZ63Z7pBHNhqdAs.jpg'),
(140096, 9961, 'Boku no Kokoro no Yabai Yatsu [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/323055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkzRP40C6yhBxZ63Z7pBHNhqdAs.jpg'),
(140097, 9961, 'Boku no Kokoro no Yabai Yatsu [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/330792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkzRP40C6yhBxZ63Z7pBHNhqdAs.jpg'),
(140098, 9961, 'Boku no Kokoro no Yabai Yatsu [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/333886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkzRP40C6yhBxZ63Z7pBHNhqdAs.jpg'),
(140099, 9962, 'Brave Bang Bravern [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tsRxJm1Q2947xC9YOOxuyrOErRn.jpg'),
(140100, 9962, 'Brave Bang Bravern [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zdGTICVaWAvSM07hNPfJkBMbIIC.jpg'),
(140101, 9962, 'Brave Bang Bravern [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7pfQ3htYdkHnoL3HCJzWTsDd9oG.jpg'),
(140102, 9962, 'Brave Bang Bravern [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ghkEU8CJzYlxzbPk2jy9jGo3ePF.jpg'),
(140103, 9962, 'Brave Bang Bravern [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2pLp003JMc45HaQw2apeDBWL6t.jpg'),
(140104, 9962, 'Brave Bang Bravern [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/deeSqI2NixrXSKI8XJC2TbToNKP.jpg'),
(140105, 9962, 'Brave Bang Bravern [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tlVA52PhtLndDkr0kSraFlThpLQ.jpg'),
(140106, 9962, 'Brave Bang Bravern [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tlVA52PhtLndDkr0kSraFlThpLQ.jpg'),
(140107, 9962, 'Brave Bang Bravern [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/295807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tlVA52PhtLndDkr0kSraFlThpLQ.jpg'),
(140108, 9962, 'Brave Bang Bravern [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/303018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tlVA52PhtLndDkr0kSraFlThpLQ.jpg'),
(140109, 9962, 'Brave Bang Bravern [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/306227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tlVA52PhtLndDkr0kSraFlThpLQ.jpg'),
(140110, 9962, 'Brave Bang Bravern [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/312628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tlVA52PhtLndDkr0kSraFlThpLQ.jpg'),
(140111, 9963, 'Charles O Novo Rei S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m8Q4JLt08ylecsRxz71SUELHtJU.jpg'),
(140112, 9963, 'Charles O Novo Rei S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kQtM0klVemog4A6nem7dtTlirvP.jpg'),
(140113, 9964, 'Cherry Magic Thirty Years of Virginity Can Make You a Wizard [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sUIuYKbUltHadVE3NeYl3TB1TLI.jpg'),
(140114, 9964, 'Cherry Magic Thirty Years of Virginity Can Make You a Wizard [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/elSj0l8lzvulF6J544uOCsKA6iN.jpg'),
(140115, 9964, 'Cherry Magic Thirty Years of Virginity Can Make You a Wizard [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mFaijZtbryx519CtSvGV9ZawBR.jpg'),
(140116, 9964, 'Cherry Magic Thirty Years of Virginity Can Make You a Wizard [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gP6vHQexiPAaloYubeWU1BBzusx.jpg'),
(140117, 9964, 'Cherry Magic Thirty Years of Virginity Can Make You a Wizard [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2zS731XnGJyJ4baqQVMb8Ib04QM.jpg'),
(140118, 9964, 'Cherry Magic Thirty Years of Virginity Can Make You a Wizard [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ijAik0nSKRjgPF8xyxbp7SU8Pm.jpg'),
(140119, 9964, 'Cherry Magic Thirty Years of Virginity Can Make You a Wizard [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rv6Lw43ARlUaHXyCQASkcM43Uk.jpg'),
(140120, 9964, 'Cherry Magic Thirty Years of Virginity Can Make You a Wizard [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/298032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rv6Lw43ARlUaHXyCQASkcM43Uk.jpg'),
(140121, 9964, 'Cherry Magic Thirty Years of Virginity Can Make You a Wizard [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/298033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rv6Lw43ARlUaHXyCQASkcM43Uk.jpg'),
(140122, 9964, 'Cherry Magic Thirty Years of Virginity Can Make You a Wizard [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/309123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rv6Lw43ARlUaHXyCQASkcM43Uk.jpg'),
(140123, 9964, 'Cherry Magic Thirty Years of Virginity Can Make You a Wizard [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/309124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rv6Lw43ARlUaHXyCQASkcM43Uk.jpg'),
(140124, 9964, 'Cherry Magic Thirty Years of Virginity Can Make You a Wizard [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/313380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rv6Lw43ARlUaHXyCQASkcM43Uk.jpg'),
(140125, 9965, 'Constelacao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nKJQlltyBk3WSKtyJmJbeyhdTRq.jpg'),
(140126, 9965, 'Constelacao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cXAzW1SwRybTjlkgf7jycXRJRhW.jpg'),
(140127, 9965, 'Constelacao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2vGnwnpjknakCTaY6cBV3TbM9Rk.jpg'),
(140128, 9965, 'Constelacao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/288736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nfEeRzbjl5OC6loVnaQir4GX7ju.jpg'),
(140129, 9965, 'Constelacao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nfEeRzbjl5OC6loVnaQir4GX7ju.jpg'),
(140130, 9965, 'Constelacao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/300220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nfEeRzbjl5OC6loVnaQir4GX7ju.jpg'),
(140131, 9965, 'Constelacao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/305284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nfEeRzbjl5OC6loVnaQir4GX7ju.jpg'),
(140132, 9965, 'Constelacao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/310622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nfEeRzbjl5OC6loVnaQir4GX7ju.jpg'),
(140133, 9966, 'Dois em Cena Encontro de Geracoes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zkaTDR94pKsgdb09DmFwBQfd2K3.jpg'),
(140134, 9966, 'Dois em Cena Encontro de Geracoes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wplkbgSr4TteGPuvXwKt6KxrRVe.jpg'),
(140135, 9966, 'Dois em Cena Encontro de Geracoes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/56avrwfdpk9kgOhxYxj6avAs2i9.jpg'),
(140136, 9966, 'Dois em Cena Encontro de Geracoes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5u5q6DdZzFc09SsIm6p2YIWWG5g.jpg'),
(140137, 9966, 'Dois em Cena Encontro de Geracoes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8PY7JSfFX2ZcTCJEpJVFXX4NpLM.jpg'),
(140138, 9966, 'Dois em Cena Encontro de Geracoes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hVo0nbqIQgnEbPWdJIHoz1KRK5x.jpg'),
(140139, 9966, 'Dois em Cena Encontro de Geracoes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2VJErEg8lFbGgkJMbIQox1Matir.jpg'),
(140140, 9966, 'Dois em Cena Encontro de Geracoes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3h9irDE3U0PxqUQJQwfuf9WaRcg.jpg'),
(140141, 9966, 'Dois em Cena Encontro de Geracoes S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g84X2yvn1lRd44uQe9NE2I6BuyA.jpg'),
(140142, 9966, 'Dois em Cena Encontro de Geracoes S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dENYpdOBzjr9l7FfHdcuVsdGg6W.jpg'),
(140143, 9967, 'Eu Nao Gosto Nem um Pouco do Meu Maninho [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k16tr4pOdPUttXBwzCDxFbeYlZS.jpg'),
(140144, 9967, 'Eu Nao Gosto Nem um Pouco do Meu Maninho [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iR46eBSMl47q4m6V9Xen29yXfEZ.jpg'),
(140145, 9967, 'Eu Nao Gosto Nem um Pouco do Meu Maninho [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ap7cNj7rJ3Uy8cvVCyAVv0UVf3.jpg'),
(140146, 9967, 'Eu Nao Gosto Nem um Pouco do Meu Maninho [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hdKPzD5TofBemlMFNrlzi9SL7Lt.jpg'),
(140147, 9967, 'Eu Nao Gosto Nem um Pouco do Meu Maninho [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tENLUZhxf3jhjkwsOq84AOUobvB.jpg'),
(140148, 9967, 'Eu Nao Gosto Nem um Pouco do Meu Maninho [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2RvktXecA4KYP20eSW5EwBlpqd6.jpg'),
(140149, 9967, 'Eu Nao Gosto Nem um Pouco do Meu Maninho [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/OE8qIAHYm66Rw2PLoUAHPwUeRD.jpg'),
(140150, 9967, 'Eu Nao Gosto Nem um Pouco do Meu Maninho [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cPMmQRdAfElpgynWcUiusW610w4.jpg'),
(140151, 9967, 'Eu Nao Gosto Nem um Pouco do Meu Maninho [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/288854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jYGxv6CzlwktaepdEjYmyz61H6s.jpg'),
(140152, 9967, 'Eu Nao Gosto Nem um Pouco do Meu Maninho [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/288855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jYGxv6CzlwktaepdEjYmyz61H6s.jpg'),
(140153, 9967, 'Eu Nao Gosto Nem um Pouco do Meu Maninho [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/288856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jYGxv6CzlwktaepdEjYmyz61H6s.jpg'),
(140154, 9967, 'Eu Nao Gosto Nem um Pouco do Meu Maninho [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/318043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jYGxv6CzlwktaepdEjYmyz61H6s.jpg'),
(140155, 9967, 'Eu Nao Gosto Nem um Pouco do Meu Maninho [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/318044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jYGxv6CzlwktaepdEjYmyz61H6s.jpg'),
(140156, 9968, 'FBI Internacional [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDaO3bEcQ3gFg3AIyOZLFuXqhWn.jpg'),
(140157, 9968, 'FBI Internacional [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ouKP7I9Lp8sJz7Y1pF9nDBfoeXg.jpg'),
(140158, 9968, 'FBI Internacional [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n8pCuNraS9Rgj0yWzg0BwJ0XgJn.jpg'),
(140159, 9968, 'FBI Internacional [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oyqCIo9q3tG5WBrFhTWUMRxJfy5.jpg'),
(140160, 9968, 'FBI Internacional [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9mEpYmM0tuZ2sOXt2qEKvkOPetA.jpg'),
(140161, 9968, 'FBI Internacional [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4HVi9ogGPzZPBWT77CWqdYuinx0.jpg'),
(140162, 9968, 'FBI Internacional [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cOa8Dad4XqBFTne0xXEXV7YnPSb.jpg'),
(140163, 9968, 'FBI Internacional [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rruZAr5ANXDLkccfIbTjnCDHTWu.jpg'),
(140164, 9968, 'FBI Internacional [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lcDv0IStnYFM1F8CayR257EGA7P.jpg'),
(140165, 9968, 'FBI Internacional [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pQ0nlK8Qemd39htZCCwjEy7y9zK.jpg'),
(140166, 9968, 'FBI Internacional [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/igtuCD1a14SNCV046DSXtUUU69y.jpg'),
(140167, 9968, 'FBI Internacional [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/txbGYQID8EjDi52Ma4gGUCSYeg1.jpg'),
(140168, 9968, 'FBI Internacional [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p0iFvRduiPtHGrO1qb1Fhd5f2na.jpg'),
(140169, 9968, 'FBI Internacional [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xRhov4cQfFS2wkSvGVNuUvMoGEE.jpg'),
(140170, 9968, 'FBI Internacional [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kXdnuzLNfR9tv4voeijAdmn4Pi.jpg'),
(140171, 9968, 'FBI Internacional [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/22sFb7wX9hnX6StsybEIuZbAFVp.jpg'),
(140172, 9968, 'FBI Internacional [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/278728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mG2oRUcqIP0mBbRoCQBZDeL5zCe.jpg'),
(140173, 9968, 'FBI Internacional [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/278729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xMBt6qwsQin5Z5YJQjlow48z4MN.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(140174, 9968, 'FBI Internacional [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/278730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3eiTkPZdc2FDsid4bVmAfHLc29q.jpg'),
(140175, 9968, 'FBI Internacional [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/278731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n0uoI5MSIpG566n42K5n7cSdu7T.jpg'),
(140176, 9968, 'FBI Internacional [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/278732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cl1Vq7QhTIqtxvIEhGrr1D4RSZI.jpg'),
(140177, 9969, 'FBI Internacional [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bWKd2urjukUKgWXAba1EiCXtvmi.jpg'),
(140178, 9969, 'FBI Internacional [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mH9usEz0L0mHzHGI6F4rQlLxbWm.jpg'),
(140179, 9969, 'FBI Internacional [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mjdfxTOVDB4fibax3npWKSkNa6s.jpg'),
(140180, 9969, 'FBI Internacional [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z9XmrOSkUHMfRoXqPRDdN5HSPGi.jpg'),
(140181, 9969, 'FBI Internacional [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ig1Ddc9mpLIeld6BBLAPfmIngI.jpg'),
(140182, 9969, 'FBI Internacional [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2kG9KvnE9UBod6WQjTnqbPs3nEa.jpg'),
(140183, 9969, 'FBI Internacional [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfcnH6G0MxIhytvhwFLybKEe3bX.jpg'),
(140184, 9969, 'FBI Internacional [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zRqoTcGxQAbZiBQnyrpWpfDtAdC.jpg'),
(140185, 9969, 'FBI Internacional [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nLTO76yhGLgBM5LuIazA1Z9Xgz0.jpg'),
(140186, 9969, 'FBI Internacional [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bi5SKc6xyXpUELEIBu8Ie8KBYvP.jpg'),
(140187, 9969, 'FBI Internacional [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wxDSQE9g98tEIJjcKmnggA9zJ1V.jpg'),
(140188, 9969, 'FBI Internacional [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jkvjND6cHPysBzgpXP79YMaou8h.jpg'),
(140189, 9969, 'FBI Internacional [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/51IN4qPO65PKf6eaV2b0bH0iU48.jpg'),
(140190, 9969, 'FBI Internacional [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lu9PQa9DxisdlBsYUt9YFQatrig.jpg'),
(140191, 9969, 'FBI Internacional [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xv8pC97hfFBwPTglPbl5eaNK1yg.jpg'),
(140192, 9969, 'FBI Internacional [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2dGGr3MqMUxi4g47hEkRMDwWDp.jpg'),
(140193, 9969, 'FBI Internacional [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/278749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hc0AUjJEVyR4cx9f76TLBOa55fN.jpg'),
(140194, 9969, 'FBI Internacional [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/278750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rIjYOV86els8OcOuTcGq5UQ0uG0.jpg'),
(140195, 9969, 'FBI Internacional [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/278751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/frI1ZAC9uK1Y5Ble9Mrk29WLo60.jpg'),
(140196, 9969, 'FBI Internacional [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/278752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v0zVTi21G6djPW0dsDDTi3ouMxk.jpg'),
(140197, 9969, 'FBI Internacional [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/278753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g79KZ0yBJNXxZEzQJkr3ULgAmYI.jpg'),
(140198, 9969, 'FBI Internacional [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/278754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eDfpeLYIdYf9ay7HeqlmR95x3bf.jpg'),
(140199, 9970, 'FBI [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mMOncfXEFJfElWcheWij6u7AE2c.jpg'),
(140200, 9970, 'FBI [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r6rff95Y29TWJbfdPtB2gfoG9C7.jpg'),
(140201, 9970, 'FBI [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/GbX8HW1nzxAruRAqeMN8xSsgiT.jpg'),
(140202, 9970, 'FBI [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i637xszD8CeAWOGQA26z73DWQ1.jpg'),
(140203, 9970, 'FBI [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e8mpqoj3SFemghwV4rpHmi0ngNC.jpg'),
(140204, 9970, 'FBI [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mkiHvoJEvYSL0grebyxwQvHSMll.jpg'),
(140205, 9970, 'FBI [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ljEnoNDsSfMGrexNKhIeL1KqBh1.jpg'),
(140206, 9970, 'FBI [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f44W23UAvD9RGrMDjWVaa7dfp0T.jpg'),
(140207, 9970, 'FBI [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nFcc2b0m5gH0DAdapZcyVZPSlzL.jpg'),
(140208, 9970, 'FBI [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xS6QGE0rngK5h5Ymh7pqTvQfb4P.jpg'),
(140209, 9970, 'FBI [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7k6iG66RKyYK4Gz4euytnLp5nqd.jpg'),
(140210, 9970, 'FBI [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4XYHY1mcKwfmkQVd3oxNS7Kh03E.jpg'),
(140211, 9970, 'FBI [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJEU7SMTcLUvCJ0Dno5pzEB2ZWO.jpg'),
(140212, 9970, 'FBI [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gnYFS7ZqowgZQw2eVeMKBhRp98H.jpg'),
(140213, 9970, 'FBI [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uGobsvyNFAh4oPtozuaxRHSahUO.jpg'),
(140214, 9970, 'FBI [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqSUjdCOPKDda2u6LHAxhxaCnVD.jpg'),
(140215, 9970, 'FBI [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/278628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ycmESddaHoz0d444Je8sJntDYPo.jpg'),
(140216, 9970, 'FBI [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/278629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9G4WfT0QQl0q8bq3Ocy4tsl3qI0.jpg'),
(140217, 9970, 'FBI [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/278630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sbNGvlufr6KYxVHxjZqfqubLzQ4.jpg'),
(140218, 9970, 'FBI [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/278631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nh8usUbe85oIQ76NVpEO0NWMyXI.jpg'),
(140219, 9970, 'FBI [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/278632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1krh3fLIpNTVEYMGMpIgYZuEdMs.jpg'),
(140220, 9970, 'FBI [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/278633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h8YVPEEvnoMpEE80Shp614tpkNE.jpg'),
(140221, 9971, 'FBI [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kNvVj90gS4NFD9n3E9UwAOmETOG.jpg'),
(140222, 9971, 'FBI [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wUJOXeCYqJkWqMtKME09xQGnda5.jpg'),
(140223, 9971, 'FBI [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q1oFhcQuDKGvHdILbueTdAdkXj4.jpg'),
(140224, 9971, 'FBI [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvHSFZGznXnzCwUDBVIntgcfWi.jpg'),
(140225, 9971, 'FBI [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y58NRyT1lKkswOlDUB39DstQYyG.jpg'),
(140226, 9971, 'FBI [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dE7GyjoxlY9HYFpiv5bDgM9T4Tj.jpg'),
(140227, 9971, 'FBI [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Adgj8AQ7nihaPqmSaXyeuFaIIBw.jpg'),
(140228, 9971, 'FBI [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dIN9UNQKgp7p7oj2KFowVknwbmm.jpg'),
(140229, 9971, 'FBI [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cyUPi5wpnDYt8oWtBfmBIc4uF6w.jpg'),
(140230, 9971, 'FBI [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dbhktw6JWsqfi4FqiTjU09gSbgf.jpg'),
(140231, 9971, 'FBI [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wYszs3LRvWsyEkP2LJNvkT705GQ.jpg'),
(140232, 9971, 'FBI [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Phnw2LxiIKGqOBsfA8zgw54kZS.jpg'),
(140233, 9971, 'FBI [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9B3JYlRkyIqm9V3nwOpqH9VSZS0.jpg'),
(140234, 9971, 'FBI [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fjKm3goxnBvFc2mz5FEfmkOx5AE.jpg'),
(140235, 9971, 'FBI [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4an2vi6pTVIDTF6Yc5cXlSNTUFb.jpg'),
(140236, 9971, 'FBI [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pNNseLV4MSdLMXPVCS5VOH3mhRr.jpg'),
(140237, 9971, 'FBI [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/278650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZip0M3lEaxbQg4GIdu8BHe7XJ3.jpg'),
(140238, 9971, 'FBI [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/278651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1DwSXjzWrgSJN5YFz2CuxRHsyz2.jpg'),
(140239, 9971, 'FBI [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/278652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jKfzU4CNrLxlADR21cxRyATZc1j.jpg'),
(140240, 9972, 'FBI [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6HBEzwrdtpOjXxfEcodUP6dOfWI.jpg'),
(140241, 9972, 'FBI [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/btOzigEZkemIThkxmVF9tuxgdb2.jpg'),
(140242, 9972, 'FBI [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z54VW558GZ3jkw7Gvw44nwG3DIZ.jpg'),
(140243, 9972, 'FBI [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Go9WBIVEsFENby5awiOwJDdVfJ.jpg'),
(140244, 9972, 'FBI [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ayf1RTTvcQoAnjlAt05YWZghWva.jpg'),
(140245, 9972, 'FBI [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wr2C6eogWzL1mSs5BZvSHRYbBjE.jpg'),
(140246, 9972, 'FBI [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/flGM90EllhP69KXuTY4IMZejSMc.jpg'),
(140247, 9972, 'FBI [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5fc9PTuvavStHR1BLPd85nlm2Px.jpg'),
(140248, 9972, 'FBI [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kotNoyBSqHdwPnR20KVLvCxDWv8.jpg'),
(140249, 9972, 'FBI [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/brijiNSl0NlImyvpF09HM3tg1hz.jpg'),
(140250, 9972, 'FBI [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uDA6WeiaiuIrplIOIlZt3J31gNO.jpg'),
(140251, 9972, 'FBI [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tWawugYuAIWBYPoa7DNJtfUjhRl.jpg'),
(140252, 9972, 'FBI [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7BxlydYqdZht7KMsqZvqJRStINw.jpg'),
(140253, 9972, 'FBI [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gLyIhrZihE6dytlbCrzyFW0FXB7.jpg'),
(140254, 9972, 'FBI [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ufluNHfprHvOZDEPaUa1gCurVMv.jpg'),
(140255, 9973, 'FBI [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1GCOme9j3PXXnsKlrJTPOXkZBs2.jpg'),
(140256, 9973, 'FBI [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9dcRYcpDYIYPBWOSDtFbkR9kDpV.jpg'),
(140257, 9973, 'FBI [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ga8fcSW7dVjVLp23pQMGhnWhAbx.jpg'),
(140258, 9973, 'FBI [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1GUgZjxr4gpuAwmaVrQyHesuoVw.jpg'),
(140259, 9973, 'FBI [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQCEJWusVkVQ5soh8rT1jcFPz5k.jpg'),
(140260, 9973, 'FBI [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4dZ2u7bmCsSjqUvq0IZJBYSrPZA.jpg'),
(140261, 9973, 'FBI [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vLxJYWZeB9r1VvydS0JVOfsELWp.jpg'),
(140262, 9973, 'FBI [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iGE7CgRP07LEjCs4SOEclSvJoVl.jpg'),
(140263, 9973, 'FBI [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/brI6RrD5xA6XnJaBCXpVvs3hWFP.jpg'),
(140264, 9973, 'FBI [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Qvajw1K8aUHf1YLgkRmkL8wZot.jpg'),
(140265, 9973, 'FBI [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3onYzkHtjK1ZwgH42WOasQDcpBq.jpg'),
(140266, 9973, 'FBI [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6l6hUMwlTootUrlrNssYLqZsvPF.jpg'),
(140267, 9973, 'FBI [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwd3Jmm7hHV3WhhxHeFBts2AoUa.jpg'),
(140268, 9973, 'FBI [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zSZBqie1KBxwtvv7oNfVqjY4VWJ.jpg'),
(140269, 9973, 'FBI [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/icduphzKsJ41lsN8UIjwpaRckax.jpg'),
(140270, 9973, 'FBI [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qeWIcCbUNo1IJcIrzh2pQIt8b3r.jpg'),
(140271, 9973, 'FBI [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/278684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aj2ugfMhD2k80fb7kKz9XnneZzQ.jpg'),
(140272, 9973, 'FBI [L] S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/278685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pDRYmP3KfDKviGSskn1aLOzg1WK.jpg'),
(140273, 9973, 'FBI [L] S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/278686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hb5F2pc6EOXtpBytGvhNOZqIXaM.jpg'),
(140274, 9973, 'FBI [L] S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/278687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9F6kEB8tLHPowcE5CN3KKN3BqWc.jpg'),
(140275, 9973, 'FBI [L] S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/278688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qDQ3sEfinVOzVag990tXfZ37V8N.jpg'),
(140276, 9974, 'FBI [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4knxgyJ882BbMgWFU9O3jequrCi.jpg'),
(140277, 9974, 'FBI [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvvSSCrQKczmQkfjov6S8R7VydM.jpg'),
(140278, 9974, 'FBI [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qX1eYZFkofQlhY2tv2hsociR0L3.jpg'),
(140279, 9974, 'FBI [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lYwHSP54xcqipoMqmq17Q3MRMJG.jpg'),
(140280, 9974, 'FBI [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fzmnHkjqERJTN2PMew9PC2WYJPH.jpg'),
(140281, 9974, 'FBI [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2AqGghJUOBw0YKKpk1mRkGEJU9w.jpg'),
(140282, 9974, 'FBI [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vQYh6KEhWd8bDm2UXfcXkebMR1n.jpg'),
(140283, 9974, 'FBI [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ydUn3EvfG7BHHNRxN5Q1nhNwxJT.jpg'),
(140284, 9974, 'FBI [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZhixAJ9EaTpGFM9OHt1hqRwtkh.jpg'),
(140285, 9974, 'FBI [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7xanzxOyQCW8A1v8FNjYqkPKl4j.jpg'),
(140286, 9974, 'FBI [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ggplXtiaCaG3YYLr7U2vVHipdf4.jpg'),
(140287, 9974, 'FBI [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Vl6HTmuE6dEw4QmN46Yex2OsC3.jpg'),
(140288, 9974, 'FBI [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xSiAowldVUDPTB7hsKhIiUFgX7E.jpg'),
(140289, 9974, 'FBI [L] S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5lNfcK9bIJxBnYJN59M0fQwJ2vh.jpg'),
(140290, 9974, 'FBI [L] S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xUO3VmBPiD10bGYjLG3wZzeG1a0.jpg'),
(140291, 9974, 'FBI [L] S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mXYr5z5kBRT1hQeuWDG65CgM0KR.jpg'),
(140292, 9974, 'FBI [L] S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/278705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wuvniu34Nez4qh1GufD1d2gqYjd.jpg'),
(140293, 9974, 'FBI [L] S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/278706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/arL7lM3tNMch9iM0PFO0aeqKHhz.jpg'),
(140294, 9974, 'FBI [L] S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/278707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/76APcyhd5RudNrW7Vo9JzRdVSWX.jpg'),
(140295, 9974, 'FBI [L] S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/278708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4zgaqiMJaeeCUdSRP3UWgHJPr7d.jpg'),
(140296, 9974, 'FBI [L] S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/278709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lqembmcm9ko3EAhMvwEM3wWrC0Y.jpg'),
(140297, 9974, 'FBI [L] S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/278710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6zAuxGjjPy1rf8vRvoKFrh8TnHr.jpg'),
(140298, 9974, 'FBI [L] S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/278711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/teLAUtXiJdr0ceR9aHbq2SZZs7J.jpg'),
(140299, 9975, 'Feud S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wkhXCZZlppJx32siiYW1HoLmKAz.jpg'),
(140300, 9975, 'Feud S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5EHlxIsJHUtn8Coi26EjxV9p14b.jpg'),
(140301, 9975, 'Feud S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1TrXIZNisOXoRW1YzcquuBVK1lt.jpg'),
(140302, 9975, 'Feud S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tIjRupWhOImvdSvaNuiDIF2ohGn.jpg'),
(140303, 9975, 'Feud S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9VK0aPr1pLCU7GpIEUuxnoO86eZ.jpg'),
(140304, 9975, 'Feud S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kqFsGol26hngH08iOK1PX4kRchJ.jpg'),
(140305, 9975, 'Feud S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tAvcVu6cfI31WyzJQKT82jv7t9r.jpg'),
(140306, 9975, 'Feud S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/crFsxO6f31MzMTSMIIjrZQILfqg.jpg'),
(140307, 9976, 'Feud S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/295549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c5wn2eLRN3naOB1JxEbDIApRN2T.jpg'),
(140308, 9976, 'Feud S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/295550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c5wn2eLRN3naOB1JxEbDIApRN2T.jpg'),
(140309, 9976, 'Feud S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/327906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c5wn2eLRN3naOB1JxEbDIApRN2T.jpg'),
(140310, 9976, 'Feud S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/327907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c5wn2eLRN3naOB1JxEbDIApRN2T.jpg'),
(140311, 9976, 'Feud S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/327908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c5wn2eLRN3naOB1JxEbDIApRN2T.jpg'),
(140312, 9976, 'Feud S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/327909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c5wn2eLRN3naOB1JxEbDIApRN2T.jpg'),
(140313, 9976, 'Feud S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/327910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c5wn2eLRN3naOB1JxEbDIApRN2T.jpg'),
(140314, 9976, 'Feud S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/327911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c5wn2eLRN3naOB1JxEbDIApRN2T.jpg'),
(140315, 9977, 'Feud [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wkhXCZZlppJx32siiYW1HoLmKAz.jpg'),
(140316, 9977, 'Feud [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5EHlxIsJHUtn8Coi26EjxV9p14b.jpg'),
(140317, 9977, 'Feud [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1TrXIZNisOXoRW1YzcquuBVK1lt.jpg'),
(140318, 9977, 'Feud [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tIjRupWhOImvdSvaNuiDIF2ohGn.jpg'),
(140319, 9977, 'Feud [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9VK0aPr1pLCU7GpIEUuxnoO86eZ.jpg'),
(140320, 9977, 'Feud [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kqFsGol26hngH08iOK1PX4kRchJ.jpg'),
(140321, 9977, 'Feud [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tAvcVu6cfI31WyzJQKT82jv7t9r.jpg'),
(140322, 9977, 'Feud [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/crFsxO6f31MzMTSMIIjrZQILfqg.jpg'),
(140323, 9978, 'Feud [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ie8f5AfHp1TPjGWIjqBLgsS53L2.jpg'),
(140324, 9978, 'Feud [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qcTOsiVRY2DZ74Bpg9O72txLXWv.jpg'),
(140325, 9978, 'Feud [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2E9FZXkfuJnGr9mT4ytnQRB7sTX.jpg'),
(140326, 9978, 'Feud [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c5wn2eLRN3naOB1JxEbDIApRN2T.jpg'),
(140327, 9978, 'Feud [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c5wn2eLRN3naOB1JxEbDIApRN2T.jpg'),
(140328, 9978, 'Feud [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c5wn2eLRN3naOB1JxEbDIApRN2T.jpg'),
(140329, 9978, 'Feud [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/299980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c5wn2eLRN3naOB1JxEbDIApRN2T.jpg'),
(140330, 9978, 'Feud [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/304718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c5wn2eLRN3naOB1JxEbDIApRN2T.jpg'),
(140331, 9979, 'Hikaru no Go S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZdA1k6XaM2M2LwFCrT0C35bBO2.jpg'),
(140332, 9979, 'Hikaru no Go S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/292525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140333, 9979, 'Hikaru no Go S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/292526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140334, 9979, 'Hikaru no Go S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/292527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140335, 9979, 'Hikaru no Go S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/296359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140336, 9979, 'Hikaru no Go S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/296360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140337, 9979, 'Hikaru no Go S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/302686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140338, 9979, 'Hikaru no Go S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/302687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140339, 9979, 'Hikaru no Go S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/304616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140340, 9979, 'Hikaru no Go S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/306118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140341, 9979, 'Hikaru no Go S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/310070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140342, 9979, 'Hikaru no Go S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/312450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140343, 9979, 'Hikaru no Go S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/317616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140344, 9979, 'Hikaru no Go S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/322672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140345, 9979, 'Hikaru no Go S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/323909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140346, 9979, 'Hikaru no Go S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/325710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140347, 9979, 'Hikaru no Go S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/327765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140348, 9979, 'Hikaru no Go S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/331409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140349, 9979, 'Hikaru no Go S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/332627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140350, 9979, 'Hikaru no Go S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/332628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140351, 9979, 'Hikaru no Go S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/340924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140352, 9979, 'Hikaru no Go S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/345310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140353, 9979, 'Hikaru no Go S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/412247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140354, 9979, 'Hikaru no Go S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/412248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140355, 9979, 'Hikaru no Go S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/412249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140356, 9979, 'Hikaru no Go S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/412250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140357, 9979, 'Hikaru no Go S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/412251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140358, 9979, 'Hikaru no Go S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/412252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140359, 9979, 'Hikaru no Go S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/412253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140360, 9979, 'Hikaru no Go S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/412254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140361, 9979, 'Hikaru no Go S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/412255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140362, 9979, 'Hikaru no Go S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/412256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140363, 9979, 'Hikaru no Go S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/412257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140364, 9979, 'Hikaru no Go S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/412258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140365, 9979, 'Hikaru no Go S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/412259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140366, 9979, 'Hikaru no Go S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/412260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140367, 9979, 'Hikaru no Go S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/412261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140368, 9979, 'Hikaru no Go S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/412262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140369, 9979, 'Hikaru no Go S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/412263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140370, 9979, 'Hikaru no Go S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/412264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140371, 9979, 'Hikaru no Go S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/412265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140372, 9979, 'Hikaru no Go S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/412266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140373, 9979, 'Hikaru no Go S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/412267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140374, 9979, 'Hikaru no Go S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/412268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140375, 9979, 'Hikaru no Go S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/412269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140376, 9979, 'Hikaru no Go S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/412270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140377, 9979, 'Hikaru no Go S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/412271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140378, 9979, 'Hikaru no Go S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/412272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140379, 9979, 'Hikaru no Go S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/412273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140380, 9979, 'Hikaru no Go S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/412274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140381, 9979, 'Hikaru no Go S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/412275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140382, 9979, 'Hikaru no Go S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/412276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140383, 9979, 'Hikaru no Go S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/412277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140384, 9979, 'Hikaru no Go S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/412278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140385, 9979, 'Hikaru no Go S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/412279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140386, 9979, 'Hikaru no Go S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/415812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140387, 9979, 'Hikaru no Go S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/415813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140388, 9979, 'Hikaru no Go S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/415814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140389, 9979, 'Hikaru no Go S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/419565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140390, 9979, 'Hikaru no Go S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/419566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140391, 9979, 'Hikaru no Go S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/419567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140392, 9979, 'Hikaru no Go S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/419568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140393, 9979, 'Hikaru no Go S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/419569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140394, 9979, 'Hikaru no Go S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/421673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140395, 9979, 'Hikaru no Go S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/421674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140396, 9979, 'Hikaru no Go S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/421675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140397, 9979, 'Hikaru no Go S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/421676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140398, 9979, 'Hikaru no Go S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/424812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140399, 9979, 'Hikaru no Go S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/424813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140400, 9979, 'Hikaru no Go S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/424814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140401, 9979, 'Hikaru no Go S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/427706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140402, 9979, 'Hikaru no Go S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/427707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140403, 9979, 'Hikaru no Go S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/427708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140404, 9979, 'Hikaru no Go S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/427709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140405, 9979, 'Hikaru no Go S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/427710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/muZEsyRHVS8A5SJbPr0oxsQdYKe.jpg'),
(140406, 9980, 'Jovem Sheldon [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yspLJDIxVq2fQhmy3nxsAh8hyjQ.jpg'),
(140407, 9980, 'Jovem Sheldon [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yxAFfzQgOJmrnxYQ60O8rt0ktAI.jpg'),
(140408, 9980, 'Jovem Sheldon [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mfMGjkiiOEkjDQRkuW9DTjIHeHI.jpg'),
(140409, 9980, 'Jovem Sheldon [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qyta8FZA4QTeVnjmWImDrHSOlHi.jpg'),
(140410, 9980, 'Jovem Sheldon [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBmCuDXXizQ0LYZlVK3jszOotSJ.jpg'),
(140411, 9980, 'Jovem Sheldon [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wF33TQKGDgpEprJOpfFc3DrgnlN.jpg'),
(140412, 9980, 'Jovem Sheldon [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cZ9RfJyQWUvU9fbx2uw9Ie7T2OM.jpg'),
(140413, 9980, 'Jovem Sheldon [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jC7ruV49S0jZLXWvmTTosBOzQy2.jpg'),
(140414, 9980, 'Jovem Sheldon [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bd61PwY1Gz0GVNxuEd0QkxGA2EW.jpg'),
(140415, 9980, 'Jovem Sheldon [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eP9CEcriqAGxXT5H3loOhhjHnM9.jpg'),
(140416, 9980, 'Jovem Sheldon [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dShnl52EiYU3QiVIu88ouQs9j8M.jpg'),
(140417, 9980, 'Jovem Sheldon [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8GJ6Be4XWQn58q8xFbLzzFOCO3M.jpg'),
(140418, 9980, 'Jovem Sheldon [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qUKl6sXDE9KzMr692wID4r211le.jpg'),
(140419, 9980, 'Jovem Sheldon [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4TivpGw3gtOHrdK57enFcQuxYOn.jpg'),
(140420, 9980, 'Jovem Sheldon [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m5ljEPv4PlVtqsdK5Q9lnxGqcKF.jpg'),
(140421, 9980, 'Jovem Sheldon [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2Wr9zbA1yEMZxBVRGp2Xu6C7CG.jpg'),
(140422, 9980, 'Jovem Sheldon [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/278480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n97tsdKQm8DdLFaVkpDCrS48Ybv.jpg'),
(140423, 9980, 'Jovem Sheldon [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/278481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2auQWVF3aOms8SrdCV9Yhteq4Q.jpg'),
(140424, 9980, 'Jovem Sheldon [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/278482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/27Bnl5w3dgQKClk94x4XMH0Rtic.jpg'),
(140425, 9980, 'Jovem Sheldon [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/278483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ltWFTgU75BOhvx0Ux0Vi1NfQwu.jpg'),
(140426, 9980, 'Jovem Sheldon [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/278484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bO8838Z3y7uIM7B5Oh5qrbHQ5Ym.jpg'),
(140427, 9980, 'Jovem Sheldon [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/278485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLpcJUh4nNsyNfRpXchqr0VjfVT.jpg'),
(140428, 9981, 'Jovem Sheldon [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wO0Y0sGuBrAyacU7EBk4zk6oaU1.jpg'),
(140429, 9981, 'Jovem Sheldon [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uj0JUOLokZoyiRXDVuuiptmdnKi.jpg'),
(140430, 9981, 'Jovem Sheldon [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/huJYmKmQ6Kgo2LDU0UNCNQp7hW9.jpg'),
(140431, 9981, 'Jovem Sheldon [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3WPuigW7zlG4JmP5AEkR3zObw1N.jpg'),
(140432, 9981, 'Jovem Sheldon [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Xsj1jiTQ2RleHHzc0iXpa8nMR0.jpg'),
(140433, 9981, 'Jovem Sheldon [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyPMnyJNzqCxWWDjyB4FcItCPTx.jpg'),
(140434, 9981, 'Jovem Sheldon [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q5GaJiGqwNoRJwiffFi2jCIhbZL.jpg'),
(140435, 9981, 'Jovem Sheldon [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lrh6Qto8yE8UwVDdggvTYkkNYsg.jpg'),
(140436, 9981, 'Jovem Sheldon [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sviITu8w6hqkbOgiiVZOwYwInn3.jpg'),
(140437, 9981, 'Jovem Sheldon [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dQOjQhijJ4c9ldGRta7Gl6SkzXP.jpg'),
(140438, 9981, 'Jovem Sheldon [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7pbNfDOltHTcr6rkvdI7Avr0m2t.jpg'),
(140439, 9981, 'Jovem Sheldon [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3nXXvakupNfxbI2HQyThn9cYfiE.jpg'),
(140440, 9981, 'Jovem Sheldon [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/txtRlModP5BCTVtZxLG9ZLe2bFA.jpg'),
(140441, 9981, 'Jovem Sheldon [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSDAGm0TJnM3Bbzvv4sKXYH2XGK.jpg'),
(140442, 9981, 'Jovem Sheldon [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/27hi7pEsmQkycZuKvHmdOji11rV.jpg'),
(140443, 9981, 'Jovem Sheldon [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eDIk9yc1f2PZhHXqRVHDJF00ZSF.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(140444, 9981, 'Jovem Sheldon [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/278502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zyhDZowbWZdwQuaJGok8TmKgUrs.jpg'),
(140445, 9981, 'Jovem Sheldon [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/278503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mHWkcoO1c8JTFunSj6WUoZeqH0I.jpg'),
(140446, 9981, 'Jovem Sheldon [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/278504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1stUdS0Kt3Nt12X2ShdQIj6fuq1.jpg'),
(140447, 9981, 'Jovem Sheldon [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/278505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f3h46DenmOwF0WV82GrNk5qzWDS.jpg'),
(140448, 9981, 'Jovem Sheldon [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/278506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z9IzNMveeRkYVQlwOZBugki1hQ3.jpg'),
(140449, 9981, 'Jovem Sheldon [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/278507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ai4obiLc0XD46XeSO2j7IykMOFw.jpg'),
(140450, 9982, 'Jovem Sheldon [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ByHZndMiJ77tOEKwxz6DeXBye3.jpg'),
(140451, 9982, 'Jovem Sheldon [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7qddDT5k5i4HyH5T4r2BoNWgelk.jpg'),
(140452, 9982, 'Jovem Sheldon [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/638NC1cVAOSUfbeVHR4iK4cCXux.jpg'),
(140453, 9982, 'Jovem Sheldon [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8D4p69gNW2lEainBu7Egf1HlO7c.jpg'),
(140454, 9982, 'Jovem Sheldon [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yPAgQFgmEF2zlr3cf53Ey6lMD54.jpg'),
(140455, 9982, 'Jovem Sheldon [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f3uaDAChb558lSisNOpHC8igDRZ.jpg'),
(140456, 9982, 'Jovem Sheldon [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/859vq94V8uMzjXg8m1OihMO1Fsu.jpg'),
(140457, 9982, 'Jovem Sheldon [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5D0hw7Se5PeUAxnQ4B9ff712wGr.jpg'),
(140458, 9982, 'Jovem Sheldon [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4xr8k0QUYGBRFYNdN53KJmjHoY.jpg'),
(140459, 9982, 'Jovem Sheldon [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/87Tiwm5qKdvOmySOtKwpL2spfFj.jpg'),
(140460, 9982, 'Jovem Sheldon [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/idvcJdGR7JT4BxLf1XhA0R1HZMV.jpg'),
(140461, 9982, 'Jovem Sheldon [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5UDctDo6n6QPzz32azUrRue6o2J.jpg'),
(140462, 9982, 'Jovem Sheldon [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rrkhE4VjJF4Lq9XZkuY0K5mut84.jpg'),
(140463, 9982, 'Jovem Sheldon [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ffmY6JWnSmgneuAnrawCy0fKSSR.jpg'),
(140464, 9982, 'Jovem Sheldon [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mWx1FUwf5ulRrixxA6Eddp6Myce.jpg'),
(140465, 9982, 'Jovem Sheldon [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/swuoIREnAm6MJH1TRyZblmsNq56.jpg'),
(140466, 9982, 'Jovem Sheldon [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/278524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Rrmq4qQ1T0Y8xa3D2CdGQ4iFLf.jpg'),
(140467, 9982, 'Jovem Sheldon [L] S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/278525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ktX1ZU8HvbD9EceeUlAmLBRB.jpg'),
(140468, 9982, 'Jovem Sheldon [L] S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/278526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fGu9yvTgeeXGDRVl3sr2IjAnM6u.jpg'),
(140469, 9982, 'Jovem Sheldon [L] S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/278527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3wPSFugXo8O542qBx5HFbxiMM1u.jpg'),
(140470, 9982, 'Jovem Sheldon [L] S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/278528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/juh2LVL5p3GBtOPbxPVMCsJFIbj.jpg'),
(140471, 9983, 'Jovem Sheldon [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nOEJ4hxRN0yPwSOHawxzkRIVTQn.jpg'),
(140472, 9983, 'Jovem Sheldon [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/epTLno8bRQ5xG8Iz06snzPeNWUQ.jpg'),
(140473, 9983, 'Jovem Sheldon [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLZr5UkwTbVclpRZdmxfLumDHQf.jpg'),
(140474, 9983, 'Jovem Sheldon [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1UND6MCKQnV8TAyUkDpnwmfNegO.jpg'),
(140475, 9983, 'Jovem Sheldon [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5gaPTaX5BMnFMnykjIqZfKP4N3m.jpg'),
(140476, 9983, 'Jovem Sheldon [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1nyUlX21gqSAnjRyXGIyeiVJDZq.jpg'),
(140477, 9983, 'Jovem Sheldon [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v9RpMSvEjoxCkmTlI0XSQn26VAc.jpg'),
(140478, 9983, 'Jovem Sheldon [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUTsIInX006TJNoRDbai76vjg4a.jpg'),
(140479, 9983, 'Jovem Sheldon [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/beJZsBcFLeymWAWrUYzJB2whEZd.jpg'),
(140480, 9983, 'Jovem Sheldon [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/12XmP3IROkBf9vMCRayhMfRxhDP.jpg'),
(140481, 9983, 'Jovem Sheldon [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sSznIGboC4K6OYgMXdBlYLfkJSc.jpg'),
(140482, 9983, 'Jovem Sheldon [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eDkrlIkO2Rd5NarQdyw9nAezAAx.jpg'),
(140483, 9983, 'Jovem Sheldon [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hKLGawxjBxrNqOj43cAbynwuk5L.jpg'),
(140484, 9983, 'Jovem Sheldon [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sJcExhKovQHs9xW6fM7FALrvhcL.jpg'),
(140485, 9983, 'Jovem Sheldon [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fyLiNSN4nIhh4jKmSTV9IuV2rPD.jpg'),
(140486, 9983, 'Jovem Sheldon [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uYKlHXEEo91xVmjrNmGrVqoog6p.jpg'),
(140487, 9983, 'Jovem Sheldon [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/278545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oPyKHlwBnaX6zWcCb2xMulCmW3p.jpg'),
(140488, 9983, 'Jovem Sheldon [L] S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/278546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gE3ikYKsBo5s6nHJqdzm9HRNj1g.jpg'),
(140489, 9984, 'Jovem Sheldon [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gG5LaaxH0uZUWIZUWnKLNsNqmye.jpg'),
(140490, 9984, 'Jovem Sheldon [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5wyW5bhCMLjgSIzRS4JTOR4a7Ak.jpg'),
(140491, 9984, 'Jovem Sheldon [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uMPNSoA5bKLPkyIOG8KWVitz4Fz.jpg'),
(140492, 9984, 'Jovem Sheldon [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8YL0EF1nSHHkeoJPaDoOJuHME3d.jpg'),
(140493, 9984, 'Jovem Sheldon [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iWwUiQL1aUvjegT5GEb9SDK3T2t.jpg'),
(140494, 9984, 'Jovem Sheldon [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cviIge26xfT7ZdC80tD744SedmK.jpg'),
(140495, 9984, 'Jovem Sheldon [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n4uSGuTgk98c4llSOmRsxuUXzGF.jpg'),
(140496, 9984, 'Jovem Sheldon [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xklR0JG5HMS5zgBtHoAEcFthsgv.jpg'),
(140497, 9984, 'Jovem Sheldon [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iu8F3aPhCA8Qk8U2Kp72gcTPBtj.jpg'),
(140498, 9984, 'Jovem Sheldon [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ysc9uzSiCHOAKMxrOy2VLPpe2DA.jpg'),
(140499, 9984, 'Jovem Sheldon [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tIY0kJ0PwdAiaUzDUbGgP1dvkPj.jpg'),
(140500, 9984, 'Jovem Sheldon [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p4Cr870S99jAbWX4GZTTO9KOKuK.jpg'),
(140501, 9984, 'Jovem Sheldon [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kRNR8gh7akLy4GAYMjAc7ZRtBfK.jpg'),
(140502, 9984, 'Jovem Sheldon [L] S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pD2kcX1cDDXTTZFMZfD09n9AFzF.jpg'),
(140503, 9984, 'Jovem Sheldon [L] S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i8JD0k8KaWrJ6NEXBZtpIDB0xU0.jpg'),
(140504, 9984, 'Jovem Sheldon [L] S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ToDAPDHY4rNw4BrNZbpFNcwYlI.jpg'),
(140505, 9984, 'Jovem Sheldon [L] S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/278563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hVG5JKY6rxDQVOnqkuLByWFNt2r.jpg'),
(140506, 9984, 'Jovem Sheldon [L] S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/278564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nl6cOufYzrucF5NbJj4NhokUgT.jpg'),
(140507, 9984, 'Jovem Sheldon [L] S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/278565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lgz6Ck2PwYUzSx8TpoWNz0fTgvx.jpg'),
(140508, 9984, 'Jovem Sheldon [L] S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/278566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ktSRd6ckTCLsEHJI7HqRrnFXirf.jpg'),
(140509, 9984, 'Jovem Sheldon [L] S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/278567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3V8rnun4WswjH1TTdqNNVp76s5o.jpg'),
(140510, 9984, 'Jovem Sheldon [L] S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/278568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fVt68Wmhrr38Z7WgyXbX6N1KPls.jpg'),
(140511, 9985, 'Jovem Sheldon [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qhWHAa2vIN42Ua8zDRU9x98bkMn.jpg'),
(140512, 9985, 'Jovem Sheldon [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6uPBQPtEZg6cVQO6OD9CvT9yOHv.jpg'),
(140513, 9985, 'Jovem Sheldon [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u3IOqCoq8cabk1x2AVU5auRGToP.jpg'),
(140514, 9985, 'Jovem Sheldon [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aNEEmmjNhbhZzomJnjzsCdHi4VV.jpg'),
(140515, 9985, 'Jovem Sheldon [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qlQD3Sztrv0C3QgiZEgAnVcyhTZ.jpg'),
(140516, 9985, 'Jovem Sheldon [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mzUQnRmSTwpRXwS4ir8K8SwF0me.jpg'),
(140517, 9985, 'Jovem Sheldon [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZJLi6QxqSMZDIJiLOSyqBu8Xmj.jpg'),
(140518, 9985, 'Jovem Sheldon [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eA3L4JjohZQ3SUWsthJPhD8M9Xc.jpg'),
(140519, 9985, 'Jovem Sheldon [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m1oJhHrr8STFggTO8pL11tv3J23.jpg'),
(140520, 9985, 'Jovem Sheldon [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g5LmrOYGuWh9YNAGWN5JGdwz93w.jpg'),
(140521, 9985, 'Jovem Sheldon [L] S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/snBaRTSYkWglHBpSi51Om10ADOm.jpg'),
(140522, 9985, 'Jovem Sheldon [L] S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lGwTCqFCKbvqLnQRzTjuQ8hY6Md.jpg'),
(140523, 9985, 'Jovem Sheldon [L] S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/278581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cPA8ZkRH5XGu43gzDt7gsYsXGi1.jpg'),
(140524, 9985, 'Jovem Sheldon [L] S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/278582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7tvyDOU9il87vcYDpcr0jqYvVFd.jpg'),
(140525, 9985, 'Jovem Sheldon [L] S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/278583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A84jd0hy2HknvhedvANm39NMiPZ.jpg'),
(140526, 9985, 'Jovem Sheldon [L] S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/278584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yrKOxPKm4gbx2jxRT4MfeEJApyt.jpg'),
(140527, 9985, 'Jovem Sheldon [L] S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/278585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n8jKdyadKzMxgcs2vVYdOeB09Te.jpg'),
(140528, 9985, 'Jovem Sheldon [L] S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/278586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8c7ATGdluYgGVuThzipAHJnq9Gt.jpg'),
(140529, 9985, 'Jovem Sheldon [L] S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/278587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zXrtCtXysMFZRxEdUm6gWgKZULR.jpg'),
(140530, 9985, 'Jovem Sheldon [L] S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/278588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/owDGDWt7lymFbWxmPIBAR7c6q39.jpg'),
(140531, 9985, 'Jovem Sheldon [L] S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/278589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iIsAhVXpjLfxBSuNv6smxxIFGX9.jpg'),
(140532, 9985, 'Jovem Sheldon [L] S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/278590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/75uR97IR3wNViz9P61j2NYPFzKc.jpg'),
(140533, 9986, 'Jovem Sheldon [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/292518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/deWAA6Fnt1bM5BaZvKrDMFw6oyp.jpg'),
(140534, 9986, 'Jovem Sheldon [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/292519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/deWAA6Fnt1bM5BaZvKrDMFw6oyp.jpg'),
(140535, 9986, 'Jovem Sheldon [L] S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/292520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/deWAA6Fnt1bM5BaZvKrDMFw6oyp.jpg'),
(140536, 9986, 'Jovem Sheldon [L] S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/297842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/deWAA6Fnt1bM5BaZvKrDMFw6oyp.jpg'),
(140537, 9987, 'Kami Kuzu Idol [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/FGPMaMEl3NIqv3Ub4LHa9vdcoP.jpg'),
(140538, 9987, 'Kami Kuzu Idol [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4tM55U3gec6wcxjYsvE5mJM9NU4.jpg'),
(140539, 9987, 'Kami Kuzu Idol [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wLSE2KTpkBDM0SHD1kRLtFOvYn7.jpg'),
(140540, 9987, 'Kami Kuzu Idol [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mjzIpi2F1O2ctFYhgB5PBA8oHUG.jpg'),
(140541, 9987, 'Kami Kuzu Idol [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xxbobqaFO9W9PVFtMkqW5fXT7la.jpg'),
(140542, 9987, 'Kami Kuzu Idol [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tYKo04JGbJccdgvvGW2T246XjIm.jpg'),
(140543, 9987, 'Kami Kuzu Idol [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hV1QI0WDElO6V4RwGjMU9AKJdyP.jpg'),
(140544, 9987, 'Kami Kuzu Idol [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pF25HvU2QTyvbh0gAcmh3sjWMxQ.jpg'),
(140545, 9987, 'Kami Kuzu Idol [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/59SMywF95nRtdhuWm7xJxx6vaPo.jpg'),
(140546, 9987, 'Kami Kuzu Idol [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iP2iyN35mCYA1HwLKr5ItEvokED.jpg'),
(140547, 9988, 'Marte [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r0fdGalw1ivg7Hug4nMxv9toeGP.jpg'),
(140548, 9988, 'Marte [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zTjffaG8K4IH5MdmQ7DWyXAjBh9.jpg'),
(140549, 9988, 'Marte [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gtM5RfeuRuqRSKPx2KCepDj1JNK.jpg'),
(140550, 9988, 'Marte [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/299165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ughSvOEPZE6CCMRIPPhEaKNG2mV.jpg'),
(140551, 9989, 'Nabari no Ou [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Pa5bYAhFRbBOz3RrVYYsSFur8W.jpg'),
(140552, 9989, 'Nabari no Ou [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vPZyPpuQcncw99gLVZRfzkkGJxK.jpg'),
(140553, 9989, 'Nabari no Ou [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/muPouuzdbU7iL80ncHLWNqj2DPY.jpg'),
(140554, 9989, 'Nabari no Ou [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gULSkxEv16m5AiiHrIJ7D8iFs8N.jpg'),
(140555, 9989, 'Nabari no Ou [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kOd9fNH0k7mYcYtczk8nH5y6X1A.jpg'),
(140556, 9989, 'Nabari no Ou [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iDSSvwnsD3QAr0JDY71LWbwmhYw.jpg'),
(140557, 9989, 'Nabari no Ou [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2pQOvot3YBZxzyM4SRKPSMcdYXQ.jpg'),
(140558, 9989, 'Nabari no Ou [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rkH0meNn2m6Ymap0HzjgkcDqbGM.jpg'),
(140559, 9989, 'Nabari no Ou [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s47huplSxSiYMMjLZxhTHH80xoW.jpg'),
(140560, 9989, 'Nabari no Ou [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ognDbqXDE0fTpsxVJwpswxT9cce.jpg'),
(140561, 9989, 'Nabari no Ou [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jRVJI41uKO0iLIB130EWiXHL7Ot.jpg'),
(140562, 9989, 'Nabari no Ou [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/291971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vOVXKLEEVUbOjQfQA2kTqbSmkGh.jpg'),
(140563, 9989, 'Nabari no Ou [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/291972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vOVXKLEEVUbOjQfQA2kTqbSmkGh.jpg'),
(140564, 9989, 'Nabari no Ou [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/291973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vOVXKLEEVUbOjQfQA2kTqbSmkGh.jpg'),
(140565, 9989, 'Nabari no Ou [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/291974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vOVXKLEEVUbOjQfQA2kTqbSmkGh.jpg'),
(140566, 9989, 'Nabari no Ou [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/291975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vOVXKLEEVUbOjQfQA2kTqbSmkGh.jpg'),
(140567, 9989, 'Nabari no Ou [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/296234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vOVXKLEEVUbOjQfQA2kTqbSmkGh.jpg'),
(140568, 9989, 'Nabari no Ou [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/309999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vOVXKLEEVUbOjQfQA2kTqbSmkGh.jpg'),
(140569, 9989, 'Nabari no Ou [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/310000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vOVXKLEEVUbOjQfQA2kTqbSmkGh.jpg'),
(140570, 9989, 'Nabari no Ou [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/310001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vOVXKLEEVUbOjQfQA2kTqbSmkGh.jpg'),
(140571, 9989, 'Nabari no Ou [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/310002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vOVXKLEEVUbOjQfQA2kTqbSmkGh.jpg'),
(140572, 9989, 'Nabari no Ou [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/310003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vOVXKLEEVUbOjQfQA2kTqbSmkGh.jpg'),
(140573, 9989, 'Nabari no Ou [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/310004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vOVXKLEEVUbOjQfQA2kTqbSmkGh.jpg'),
(140574, 9989, 'Nabari no Ou [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/312338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vOVXKLEEVUbOjQfQA2kTqbSmkGh.jpg'),
(140575, 9989, 'Nabari no Ou [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/317543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vOVXKLEEVUbOjQfQA2kTqbSmkGh.jpg'),
(140576, 9989, 'Nabari no Ou [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/322485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vOVXKLEEVUbOjQfQA2kTqbSmkGh.jpg'),
(140577, 9990, 'RFDS Royal Flying Doctor Service [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8NCnRVxmE4Q10olTvi2VEGRN6aV.jpg'),
(140578, 9990, 'RFDS Royal Flying Doctor Service [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfAkGj9NUrMpsFxYfftkquwYlKk.jpg'),
(140579, 9990, 'RFDS Royal Flying Doctor Service [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/81tE6C3LKzaHM13YUVKn28CVVHr.jpg'),
(140580, 9990, 'RFDS Royal Flying Doctor Service [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7FkEqD31HVzsdtJiyLjkjgVRiVO.jpg'),
(140581, 9990, 'RFDS Royal Flying Doctor Service [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DZ7aQTriSraVU8T1ruJN0KgxQw.jpg'),
(140582, 9990, 'RFDS Royal Flying Doctor Service [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/282604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DZ7aQTriSraVU8T1ruJN0KgxQw.jpg'),
(140583, 9990, 'RFDS Royal Flying Doctor Service [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/288608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DZ7aQTriSraVU8T1ruJN0KgxQw.jpg'),
(140584, 9990, 'RFDS Royal Flying Doctor Service [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/295307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DZ7aQTriSraVU8T1ruJN0KgxQw.jpg'),
(140585, 9991, 'RFDS Royal Flying Doctor Service [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/299132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DZ7aQTriSraVU8T1ruJN0KgxQw.jpg'),
(140586, 9991, 'RFDS Royal Flying Doctor Service [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/304117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DZ7aQTriSraVU8T1ruJN0KgxQw.jpg'),
(140587, 9991, 'RFDS Royal Flying Doctor Service [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/309758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DZ7aQTriSraVU8T1ruJN0KgxQw.jpg'),
(140588, 9991, 'RFDS Royal Flying Doctor Service [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/317338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DZ7aQTriSraVU8T1ruJN0KgxQw.jpg'),
(140589, 9992, 'Rainha do Divorcio [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aDghG1QQ3jJxN02NPCSA7aYD5Ws.jpg'),
(140590, 9992, 'Rainha do Divorcio [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/buzt0U9PcfSwE2RfFp3RE7itF3k.jpg'),
(140591, 9992, 'Rainha do Divorcio [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dPMb8Snr8gYzTfWyMukuODo9la0.jpg'),
(140592, 9992, 'Rainha do Divorcio [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7m8emuhEA77Bhsne8kMpvQAHYVN.jpg'),
(140593, 9992, 'Rainha do Divorcio [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r6MOiHKwxnzMzTGAAX9soVaZSJk.jpg'),
(140594, 9992, 'Rainha do Divorcio [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tKS8obg9hBEiYlaoIO8ZhmeTIq8.jpg'),
(140595, 9992, 'Rainha do Divorcio [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJDJ2OsdxAmdG3cX3PKicueoY8y.jpg'),
(140596, 9992, 'Rainha do Divorcio [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/290704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/41rT3VEAZmQcfCeIxfJnwBvRkDm.jpg'),
(140597, 9992, 'Rainha do Divorcio [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/290705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/41rT3VEAZmQcfCeIxfJnwBvRkDm.jpg'),
(140598, 9992, 'Rainha do Divorcio [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/290706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/41rT3VEAZmQcfCeIxfJnwBvRkDm.jpg'),
(140599, 9992, 'Rainha do Divorcio [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/296714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/41rT3VEAZmQcfCeIxfJnwBvRkDm.jpg'),
(140600, 9992, 'Rainha do Divorcio [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/296715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/41rT3VEAZmQcfCeIxfJnwBvRkDm.jpg'),
(140601, 9993, 'The Qwaser of Stigmata II [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yRdYUfw1QRE7ww2OfEjbZEZlXs.jpg'),
(140602, 9993, 'The Qwaser of Stigmata II [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yRdYUfw1QRE7ww2OfEjbZEZlXs.jpg'),
(140603, 9993, 'The Qwaser of Stigmata II [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yRdYUfw1QRE7ww2OfEjbZEZlXs.jpg'),
(140604, 9993, 'The Qwaser of Stigmata II [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yRdYUfw1QRE7ww2OfEjbZEZlXs.jpg'),
(140605, 9993, 'The Qwaser of Stigmata II [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yRdYUfw1QRE7ww2OfEjbZEZlXs.jpg'),
(140606, 9993, 'The Qwaser of Stigmata II [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yRdYUfw1QRE7ww2OfEjbZEZlXs.jpg'),
(140607, 9993, 'The Qwaser of Stigmata II [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/278423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yRdYUfw1QRE7ww2OfEjbZEZlXs.jpg'),
(140608, 9993, 'The Qwaser of Stigmata II [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/278424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yRdYUfw1QRE7ww2OfEjbZEZlXs.jpg'),
(140609, 9993, 'The Qwaser of Stigmata II [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/278425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yRdYUfw1QRE7ww2OfEjbZEZlXs.jpg'),
(140610, 9993, 'The Qwaser of Stigmata II [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/278426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yRdYUfw1QRE7ww2OfEjbZEZlXs.jpg'),
(140611, 9993, 'The Qwaser of Stigmata II [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/278427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yRdYUfw1QRE7ww2OfEjbZEZlXs.jpg'),
(140612, 9993, 'The Qwaser of Stigmata II [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/278428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8yRdYUfw1QRE7ww2OfEjbZEZlXs.jpg'),
(140613, 9994, 'The Weakest Tamer Began a Journey to Pick Up Trash S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jFAQcd7JFQJ6Oif0jCoWSHeSMr3.jpg'),
(140614, 9994, 'The Weakest Tamer Began a Journey to Pick Up Trash S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWj4kPKRQJ0f3QfBc09FvGL6Yw1.jpg'),
(140615, 9994, 'The Weakest Tamer Began a Journey to Pick Up Trash S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/830WMp6257OFhsVqQLjBY85Sf4C.jpg'),
(140616, 9994, 'The Weakest Tamer Began a Journey to Pick Up Trash S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kMGUtmtGyOOJV50JGtZigFiIRF.jpg'),
(140617, 9994, 'The Weakest Tamer Began a Journey to Pick Up Trash S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6lk8WIkQOM4ERKsPLvJXGGUZbTR.jpg'),
(140618, 9994, 'The Weakest Tamer Began a Journey to Pick Up Trash S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/278416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbIwF8lpanG24Hto8YeyQmtFONk.jpg'),
(140619, 9994, 'The Weakest Tamer Began a Journey to Pick Up Trash S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/290488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pWrBCMA1Z2OaUNRy8UNMjg3SjDv.jpg'),
(140620, 9994, 'The Weakest Tamer Began a Journey to Pick Up Trash S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/290489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pWrBCMA1Z2OaUNRy8UNMjg3SjDv.jpg'),
(140621, 9994, 'The Weakest Tamer Began a Journey to Pick Up Trash S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/295159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pWrBCMA1Z2OaUNRy8UNMjg3SjDv.jpg'),
(140622, 9994, 'The Weakest Tamer Began a Journey to Pick Up Trash S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/300951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pWrBCMA1Z2OaUNRy8UNMjg3SjDv.jpg'),
(140623, 9994, 'The Weakest Tamer Began a Journey to Pick Up Trash S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/305758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pWrBCMA1Z2OaUNRy8UNMjg3SjDv.jpg'),
(140624, 9994, 'The Weakest Tamer Began a Journey to Pick Up Trash S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/311975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pWrBCMA1Z2OaUNRy8UNMjg3SjDv.jpg'),
(140625, 9995, 'Tonagura [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/278406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g4ykkJ39bd6zCVEXxvUvXaUCRKg.jpg'),
(140626, 9995, 'Tonagura [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/278407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wAl3gl4bsAOWWr8ltvv29vltrd2.jpg'),
(140627, 9995, 'Tonagura [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/278408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bxkbJ79reGuuxaGEOCYNPsM6DMV.jpg'),
(140628, 9995, 'Tonagura [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/278409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lcW0BCb2aJuQxH0vzKMEcQTAb7A.jpg'),
(140629, 9995, 'Tonagura [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/278410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wg1DcfMPyJRKYyQhG7pNeD3EqwA.jpg'),
(140630, 9995, 'Tonagura [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/327363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jQNpxTYxmhdxtS94MMPYcFZxooG.jpg'),
(140631, 9995, 'Tonagura [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/327364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jQNpxTYxmhdxtS94MMPYcFZxooG.jpg'),
(140632, 9995, 'Tonagura [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/327365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jQNpxTYxmhdxtS94MMPYcFZxooG.jpg'),
(140633, 9995, 'Tonagura [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/327366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jQNpxTYxmhdxtS94MMPYcFZxooG.jpg'),
(140634, 9995, 'Tonagura [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/327367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jQNpxTYxmhdxtS94MMPYcFZxooG.jpg'),
(140635, 9995, 'Tonagura [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/327368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jQNpxTYxmhdxtS94MMPYcFZxooG.jpg'),
(140636, 9995, 'Tonagura [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/327369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jQNpxTYxmhdxtS94MMPYcFZxooG.jpg'),
(140637, 9995, 'Tonagura [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/327370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jQNpxTYxmhdxtS94MMPYcFZxooG.jpg'),
(140638, 9996, 'Chip e Potato S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/279238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/df2OtvZdUgiNhxRoB9cvwTBttrm.jpg'),
(140639, 9996, 'Chip e Potato S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/279239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/df2OtvZdUgiNhxRoB9cvwTBttrm.jpg'),
(140640, 9996, 'Chip e Potato S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/279240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/df2OtvZdUgiNhxRoB9cvwTBttrm.jpg'),
(140641, 9996, 'Chip e Potato S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/279241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/df2OtvZdUgiNhxRoB9cvwTBttrm.jpg'),
(140642, 9996, 'Chip e Potato S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/279242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/df2OtvZdUgiNhxRoB9cvwTBttrm.jpg'),
(140643, 9996, 'Chip e Potato S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/279243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/df2OtvZdUgiNhxRoB9cvwTBttrm.jpg'),
(140644, 9996, 'Chip e Potato S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/279244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/df2OtvZdUgiNhxRoB9cvwTBttrm.jpg'),
(140645, 9996, 'Chip e Potato S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/279245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/df2OtvZdUgiNhxRoB9cvwTBttrm.jpg'),
(140646, 9996, 'Chip e Potato S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/279246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/df2OtvZdUgiNhxRoB9cvwTBttrm.jpg'),
(140647, 9996, 'Chip e Potato S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/279247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/df2OtvZdUgiNhxRoB9cvwTBttrm.jpg'),
(140648, 9997, 'Ed Stafford Contra Todos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/279219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lZKc6FFoKVKCjTMTTtcJVGlNO8l.jpg'),
(140649, 9997, 'Ed Stafford Contra Todos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/279220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lR023Qka52Cdgyip5MPdUHZEFKz.jpg'),
(140650, 9997, 'Ed Stafford Contra Todos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/279221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rKmbDvRm5VbEyJHzWYyuPA7WYfM.jpg'),
(140651, 9997, 'Ed Stafford Contra Todos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/279222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n19xBCpErqNb4Mn70OChTS5ggJZ.jpg'),
(140652, 9997, 'Ed Stafford Contra Todos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/279223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6XYy8sdbBwKdIpDBMR4ZgkWrxvq.jpg'),
(140653, 9997, 'Ed Stafford Contra Todos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/279224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k1M4cugVnxI0CCvxToFWBLA9Sg1.jpg'),
(140654, 9998, 'Ed Stafford Contra Todos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/279225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzUUWLmxaPi40bU3TaGCQzx85rm.jpg'),
(140655, 9998, 'Ed Stafford Contra Todos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/279226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qJy4HY2OrN8nuvNe9TyciJcOtPo.jpg'),
(140656, 9998, 'Ed Stafford Contra Todos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/279227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hUCRjORDDYv1fZ1iW4TNUrmp4bf.jpg'),
(140657, 9998, 'Ed Stafford Contra Todos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/279228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/YLg5avekFU4BKEAaVufPUizV8a.jpg'),
(140658, 9998, 'Ed Stafford Contra Todos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/279229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2TKC6aMns2VAxHiJVugvAnEKYMG.jpg'),
(140659, 9998, 'Ed Stafford Contra Todos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/279230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ld3rcrpCNEcSpJtK2VTnMFEobrW.jpg'),
(140660, 9999, 'Ed Stafford Contra Todos S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/279231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCJ4JUMZrpLSYj629Cv35K2YdZG.jpg'),
(140661, 9999, 'Ed Stafford Contra Todos S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/279232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Cz5GjEYGhpspkGURB7WBoVvsif.jpg'),
(140662, 9999, 'Ed Stafford Contra Todos S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/279233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JSM93APPdZ35330wEyMA9QF5K1.jpg'),
(140663, 9999, 'Ed Stafford Contra Todos S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/279234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qmtty6PoWKwNDVKo2k8uLIly7vs.jpg'),
(140664, 9999, 'Ed Stafford Contra Todos S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/279235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i8QoH42tAF6CLJuOB54Nfj3HGde.jpg'),
(140665, 9999, 'Ed Stafford Contra Todos S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/279236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aANiIKGCnSxGDIV4NMdsJZu7hoq.jpg'),
(140666, 9999, 'Ed Stafford Contra Todos S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/279237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bUPS1l0nwzp4EgInhBk9HuSpbyv.jpg'),
(140667, 10000, 'Smile Precure [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/279171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgG8ZlhNbJ4b2sFhozD5oq1mOrI.jpg'),
(140668, 10000, 'Smile Precure [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/279172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d144Z9Vu4GUzdmjNVjk5IqLNrxd.jpg'),
(140669, 10000, 'Smile Precure [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/279173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rlmYdFrlGz3gPI7PhiMoTrv8bci.jpg'),
(140670, 10000, 'Smile Precure [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/279174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dLbxHraAHoxSecjhJklzdCjEV27.jpg'),
(140671, 10000, 'Smile Precure [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/279175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qiCucSNjWwC41d3xWpZnh6NucTO.jpg'),
(140672, 10000, 'Smile Precure [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/279176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a0yOM8IEC7CC5A6uXnV1WSaUOYg.jpg'),
(140673, 10000, 'Smile Precure [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/279177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ffDyxNauRUaYT24ERIBu1mO9jkA.jpg'),
(140674, 10000, 'Smile Precure [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/279178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gRkhYbFsTPcbDgLNH88Vfpuuk1x.jpg'),
(140675, 10000, 'Smile Precure [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/279179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1XerYvGwc4D4VfOi7HD6msmAaUn.jpg'),
(140676, 10000, 'Smile Precure [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/279180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pEXaKHNZ952D2w2m6wEU46ZsS3u.jpg'),
(140677, 10000, 'Smile Precure [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/279181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y5INnhqMmOemeuVxYh7Xd2jf2rC.jpg'),
(140678, 10000, 'Smile Precure [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/279182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/25iL6FZ6bSALG04NNlc3WQtSxQr.jpg'),
(140679, 10000, 'Smile Precure [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/279183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lpMldUqMnu7lKrr6VbNsNuyaoKB.jpg'),
(140680, 10000, 'Smile Precure [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/279184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iOj72iHj7HpNonBK5I2D8wvLbwW.jpg'),
(140681, 10000, 'Smile Precure [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/279185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/82CI3r5zj7GirztDiizsbFLsSNI.jpg'),
(140682, 10000, 'Smile Precure [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/279186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2DqCAC2SixfU3DbwTqG6gsKSQ3s.jpg'),
(140683, 10000, 'Smile Precure [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/279187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jUFd5yJC67tlxyCg41P82vIHn9Z.jpg'),
(140684, 10000, 'Smile Precure [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/279188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hUl8mtzvPvjU0bt7wydBqXOzmLR.jpg'),
(140685, 10000, 'Smile Precure [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/279189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/teliXDQzsgwctMUAQ6GX79QCJ5z.jpg'),
(140686, 10000, 'Smile Precure [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/279190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4oKhD9qliOdhXfZfECkx1S6w16Y.jpg'),
(140687, 10000, 'Smile Precure [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/279191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ode7b0wmzsmmztAQvE6pk2fusQN.jpg'),
(140688, 10000, 'Smile Precure [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/279192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bVd9yfSfH5c3GrWQHeNFwKNK987.jpg'),
(140689, 10000, 'Smile Precure [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/279193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ho1s7T3ZV08WKPej8pSb29GmaC.jpg'),
(140690, 10000, 'Smile Precure [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/279194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/owIXjgBYcV5uXjOBdZyoBHSeBSb.jpg'),
(140691, 10000, 'Smile Precure [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/279195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9pEeOWyZEWMQ9lzI9a6P6ss5znj.jpg'),
(140692, 10000, 'Smile Precure [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/279196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Tt52GSLB7tTWml41SSDuxoXQ0l.jpg'),
(140693, 10000, 'Smile Precure [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/279197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g170bO4Z5VP58nstMwbOzQ3YnBR.jpg'),
(140694, 10000, 'Smile Precure [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/279198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p1Hf9dMR7su58YQXjCjzk15aMQ9.jpg'),
(140695, 10000, 'Smile Precure [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/279199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/koVzGHbO8uYVGaAAsBQ0mGdj34g.jpg'),
(140696, 10000, 'Smile Precure [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/279200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7UTAdk4uVn4hxEBBvtVpyJUFg1f.jpg'),
(140697, 10000, 'Smile Precure [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/279201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/55x5hTgyhPqj3WXBympAHUDCCfQ.jpg'),
(140698, 10000, 'Smile Precure [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/279202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Orpyz8vbJMgpWTkHQ6SP1yrXF2.jpg'),
(140699, 10000, 'Smile Precure [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/279203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t0x2m3mRQcnUWvOx8QzGGYgNpg0.jpg'),
(140700, 10000, 'Smile Precure [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/279204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uE8CVCDzfPNnK3IloxEIL5y3qhj.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(140701, 10000, 'Smile Precure [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/279205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1pM3mbND1v66Sja3qKrvjCmRBXR.jpg'),
(140702, 10000, 'Smile Precure [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/279206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eeqRQTiGaYmzegqqRZe3YBR0BkM.jpg'),
(140703, 10000, 'Smile Precure [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/279207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n2g7gh6drxNenrql0SRZVdQIg9O.jpg'),
(140704, 10000, 'Smile Precure [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/279208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p1eq1IKLZleUdvfWDlcrc8WBWw3.jpg'),
(140705, 10000, 'Smile Precure [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/279209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jkD2wN35DyxgpvuCVUAWbMxIvYJ.jpg'),
(140706, 10000, 'Smile Precure [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/279210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ciGhgYFKT2hmSKmDfZK7BXeD136.jpg'),
(140707, 10000, 'Smile Precure [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/279211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zXYBgpeHzoarzG8tChbPuIp767M.jpg'),
(140708, 10000, 'Smile Precure [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/279212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e3JFE9TAM1zf5VhHi8593qjS1jD.jpg'),
(140709, 10000, 'Smile Precure [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/279213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f1Eaf5YbKps8vGTHhhH0H82q2gP.jpg'),
(140710, 10000, 'Smile Precure [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/279214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3DMqCzncpUByj6DZHRi6pSgYmZ.jpg'),
(140711, 10000, 'Smile Precure [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/279215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oH3MFJVzjNVXLHXVUAaf4QwkdTP.jpg'),
(140712, 10000, 'Smile Precure [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/279216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qJeVCEGpXaUo6wx0E2spa4mfo99.jpg'),
(140713, 10000, 'Smile Precure [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/279217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p0yMwTHke2e8MEpkRdtkj4531jh.jpg'),
(140714, 10000, 'Smile Precure [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/279218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCwsEVYvNPUGZYMUGJbaMVKf8q0.jpg'),
(140715, 10001, 'Alem de Skinwalker S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zKiuPqOJL8azwoWEtRzOBCtRbqW.jpg'),
(140716, 10001, 'Alem de Skinwalker S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7PT5XDqnWsAbfcx6BkfGE00H1zz.jpg'),
(140717, 10001, 'Alem de Skinwalker S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7PT5XDqnWsAbfcx6BkfGE00H1zz.jpg'),
(140718, 10001, 'Alem de Skinwalker S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/303082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7PT5XDqnWsAbfcx6BkfGE00H1zz.jpg'),
(140719, 10001, 'Alem de Skinwalker S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/309405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7PT5XDqnWsAbfcx6BkfGE00H1zz.jpg'),
(140720, 10001, 'Alem de Skinwalker S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/334008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7PT5XDqnWsAbfcx6BkfGE00H1zz.jpg'),
(140721, 10001, 'Alem de Skinwalker S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/334009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7PT5XDqnWsAbfcx6BkfGE00H1zz.jpg'),
(140722, 10001, 'Alem de Skinwalker S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/334010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7PT5XDqnWsAbfcx6BkfGE00H1zz.jpg'),
(140723, 10001, 'Alem de Skinwalker S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/334011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7PT5XDqnWsAbfcx6BkfGE00H1zz.jpg'),
(140724, 10002, 'Alem de Skinwalker S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/881259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7PT5XDqnWsAbfcx6BkfGE00H1zz.jpg'),
(140725, 10002, 'Alem de Skinwalker S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/881260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7PT5XDqnWsAbfcx6BkfGE00H1zz.jpg'),
(140726, 10002, 'Alem de Skinwalker S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/881261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7PT5XDqnWsAbfcx6BkfGE00H1zz.jpg'),
(140727, 10002, 'Alem de Skinwalker S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/881262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7PT5XDqnWsAbfcx6BkfGE00H1zz.jpg'),
(140728, 10002, 'Alem de Skinwalker S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/881263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7PT5XDqnWsAbfcx6BkfGE00H1zz.jpg'),
(140729, 10002, 'Alem de Skinwalker S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/881264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7PT5XDqnWsAbfcx6BkfGE00H1zz.jpg'),
(140730, 10002, 'Alem de Skinwalker S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/881265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7PT5XDqnWsAbfcx6BkfGE00H1zz.jpg'),
(140731, 10002, 'Alem de Skinwalker S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/881266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7PT5XDqnWsAbfcx6BkfGE00H1zz.jpg'),
(140732, 10003, 'Fichados Primeira Vez Na Prisao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cBLAfByMqBqqCxxgrWIDIajEIUq.jpg'),
(140733, 10003, 'Fichados Primeira Vez Na Prisao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aY23Iacj5wKPYKF3y92UuhhH4A2.jpg'),
(140734, 10003, 'Fichados Primeira Vez Na Prisao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/282862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pavqvb2RpdoMK9Et7Kz9cI6gIXW.jpg'),
(140735, 10003, 'Fichados Primeira Vez Na Prisao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/282863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ni9gAlLg1vGfJyxdAof28s3MNPu.jpg'),
(140736, 10003, 'Fichados Primeira Vez Na Prisao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lyRNMU4cxKYSiHEZLEB2kW8bIRu.jpg'),
(140737, 10003, 'Fichados Primeira Vez Na Prisao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/282865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z9HHj4JApudjxhTEMHIWGarnBd0.jpg'),
(140738, 10003, 'Fichados Primeira Vez Na Prisao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yKv7yP8fZRjiie5Ab6HVbKh5TQ0.jpg'),
(140739, 10003, 'Fichados Primeira Vez Na Prisao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/282867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/877JCdBX3FFjIDHigGFEuhHEPTw.jpg'),
(140740, 10003, 'Fichados Primeira Vez Na Prisao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/282868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/knxlQPe1cCZEwy4RV4BtiAneSRL.jpg'),
(140741, 10003, 'Fichados Primeira Vez Na Prisao S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/282869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uOYJb16mAHfFJe6WaqRDWABkgrU.jpg'),
(140742, 10003, 'Fichados Primeira Vez Na Prisao S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/282870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7aG6lWWCPP3v4nEs55i07hoRGWD.jpg'),
(140743, 10003, 'Fichados Primeira Vez Na Prisao S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/282871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/whGy5CySl5DwrtfUvcTOx6RmxfL.jpg'),
(140744, 10003, 'Fichados Primeira Vez Na Prisao S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/297954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCwlmWiLAwIy7KpqSDZRvFNFg94.jpg'),
(140745, 10003, 'Fichados Primeira Vez Na Prisao S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/297955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xCwlmWiLAwIy7KpqSDZRvFNFg94.jpg'),
(140746, 10004, 'MC Daleste Mataram o Pobre Loco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bpCfooUXA3aV7YdwV7GnsfEiyQ5.jpg'),
(140747, 10004, 'MC Daleste Mataram o Pobre Loco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gxrflYedD0kxvwRcIP8SMuqcnAd.jpg'),
(140748, 10004, 'MC Daleste Mataram o Pobre Loco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/282858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/75q2jTomUpJCnxBI3ER5loDA8KN.jpg'),
(140749, 10004, 'MC Daleste Mataram o Pobre Loco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/282859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lod4t6TbzBDPFuXlfCJbGihnwkA.jpg'),
(140750, 10005, 'Medicos em Colapso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JeVNBBqrt8CgL4jWd3z4mslQ6Q.jpg'),
(140751, 10005, 'Medicos em Colapso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7r2rRR2uYxTp01rpvyKcPJ65VUa.jpg'),
(140752, 10005, 'Medicos em Colapso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/291993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8pNUabN9eV4to3vm2jG7aWVXp2.jpg'),
(140753, 10005, 'Medicos em Colapso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/291994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8pNUabN9eV4to3vm2jG7aWVXp2.jpg'),
(140754, 10005, 'Medicos em Colapso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/297494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8pNUabN9eV4to3vm2jG7aWVXp2.jpg'),
(140755, 10005, 'Medicos em Colapso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/297495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8pNUabN9eV4to3vm2jG7aWVXp2.jpg'),
(140756, 10005, 'Medicos em Colapso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/302499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8pNUabN9eV4to3vm2jG7aWVXp2.jpg'),
(140757, 10005, 'Medicos em Colapso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/302500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8pNUabN9eV4to3vm2jG7aWVXp2.jpg'),
(140758, 10005, 'Medicos em Colapso S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/308560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8pNUabN9eV4to3vm2jG7aWVXp2.jpg'),
(140759, 10005, 'Medicos em Colapso S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/308561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8pNUabN9eV4to3vm2jG7aWVXp2.jpg'),
(140760, 10005, 'Medicos em Colapso S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/315599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8pNUabN9eV4to3vm2jG7aWVXp2.jpg'),
(140761, 10005, 'Medicos em Colapso S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/315600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8pNUabN9eV4to3vm2jG7aWVXp2.jpg'),
(140762, 10005, 'Medicos em Colapso S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/322498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8pNUabN9eV4to3vm2jG7aWVXp2.jpg'),
(140763, 10005, 'Medicos em Colapso S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/322499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8pNUabN9eV4to3vm2jG7aWVXp2.jpg'),
(140764, 10005, 'Medicos em Colapso S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/325553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8pNUabN9eV4to3vm2jG7aWVXp2.jpg'),
(140765, 10005, 'Medicos em Colapso S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/325554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q8pNUabN9eV4to3vm2jG7aWVXp2.jpg'),
(140766, 7342, 'Motel Valkirias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eZWZ8zSsdbzI3aCAYvB12kepsXH.jpg'),
(140767, 7342, 'Motel Valkirias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hs1TKX5bE7IIKsL2QkaDRMci0u4.jpg'),
(140768, 7342, 'Motel Valkirias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/282848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8cx3v7awtk3ffQVVFZKsyICl6NO.jpg'),
(140769, 7342, 'Motel Valkirias S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/282849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7eKvWwm2AzMzSpOxWh95Nd05pqK.jpg'),
(140770, 7342, 'Motel Valkirias S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fhF9TAmyhUSnA3kC29EEau7depP.jpg'),
(140771, 7342, 'Motel Valkirias S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/282851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sILDChm72mEOSwUVJTzB5J4yoWA.jpg'),
(140772, 7342, 'Motel Valkirias S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s4HWlm2tbOw8C5UbaOlXjooxhmB.jpg'),
(140773, 7342, 'Motel Valkirias S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/282853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3BkLnOdTm7gdX4rxAKm2B83CJOw.jpg'),
(140774, 10006, 'O Segundo Melhor Hospital da Galaxia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bos87NA9PAhkGYb744P8dLzVxOQ.jpg'),
(140775, 10006, 'O Segundo Melhor Hospital da Galaxia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fT42evAaXcbdThmvZFS4uFliwPv.jpg'),
(140776, 10006, 'O Segundo Melhor Hospital da Galaxia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/282840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvPinvZE0RBp9aIhakCimfFXTAb.jpg'),
(140777, 10006, 'O Segundo Melhor Hospital da Galaxia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/282841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5WvIAHwnNR70cfjXV5LrpwgYmJn.jpg'),
(140778, 10006, 'O Segundo Melhor Hospital da Galaxia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8QChmbMIpI0dTsuaEeJDlwNIaWi.jpg'),
(140779, 10006, 'O Segundo Melhor Hospital da Galaxia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/282843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3lRpaQM6r2PwClqHkamg2RGfr4b.jpg'),
(140780, 10006, 'O Segundo Melhor Hospital da Galaxia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ogmcJ6HCMUuxGUGNA6ZLaqAtn6.jpg'),
(140781, 10006, 'O Segundo Melhor Hospital da Galaxia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/282845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oODY5Zw8cpeHcCGpBNe0EXHItle.jpg'),
(140782, 10007, 'Rumo ao Desconhecido Misterios Paranormais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oduFrSHOggnsgmxWEtCwefvj5OB.jpg'),
(140783, 10007, 'Rumo ao Desconhecido Misterios Paranormais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mvDMOzUPzqDIbUYAZrOt05X6ddS.jpg'),
(140784, 10007, 'Rumo ao Desconhecido Misterios Paranormais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/282806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1wDS2rMOOC1ATMHdqxLlvDsPzHY.jpg'),
(140785, 10007, 'Rumo ao Desconhecido Misterios Paranormais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/282807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cM28h6yvKW7Sdrwlx1hVFDH2AnA.jpg'),
(140786, 10007, 'Rumo ao Desconhecido Misterios Paranormais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sCPdOR4uFaZkxrOk1VmmCiDAqN7.jpg'),
(140787, 10007, 'Rumo ao Desconhecido Misterios Paranormais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/282809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3xzLSc3lq9PDVOSKEKRfQc5xk5c.jpg'),
(140788, 10007, 'Rumo ao Desconhecido Misterios Paranormais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jvN3aG5UzcnRVNxziE5hT2NWMnm.jpg'),
(140789, 10008, 'Rumo ao Desconhecido Misterios Paranormais S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/olzgrY1SCJqxrz2cXcSGmFJdWjS.jpg'),
(140790, 10008, 'Rumo ao Desconhecido Misterios Paranormais S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqI8BZWDPy15k87ZxthYHkX9vAF.jpg'),
(140791, 10008, 'Rumo ao Desconhecido Misterios Paranormais S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/282813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eysxnNHN4DmfYrvkc0xsb8sB2lp.jpg'),
(140792, 10008, 'Rumo ao Desconhecido Misterios Paranormais S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/282814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nMz2dRMA4IjCLUtHLVrgC2rLMxH.jpg'),
(140793, 10008, 'Rumo ao Desconhecido Misterios Paranormais S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ISPrjjqCz3GiBZFvXPjgvrKPqw.jpg'),
(140794, 10008, 'Rumo ao Desconhecido Misterios Paranormais S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/282816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3RiEZiTRFOzEpRbEwd93PV8jzrP.jpg'),
(140795, 10009, 'Rumo ao Desconhecido Misterios Paranormais S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7hn9yUw9i6KmzxZNVQYGyoqM2UK.jpg'),
(140796, 10009, 'Rumo ao Desconhecido Misterios Paranormais S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yYwxShOb3NX0TiQ6VgATq1gFr6W.jpg'),
(140797, 10009, 'Rumo ao Desconhecido Misterios Paranormais S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/282819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7UxMuVJTRaMGJkFsCTSt5pq5yGe.jpg'),
(140798, 10009, 'Rumo ao Desconhecido Misterios Paranormais S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/282820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oEZn2yvXt1t5Y4wS4UpkuQCLPjK.jpg'),
(140799, 10009, 'Rumo ao Desconhecido Misterios Paranormais S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hOV8OOrK2NaTRldrO6jfifvXqDx.jpg'),
(140800, 10009, 'Rumo ao Desconhecido Misterios Paranormais S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/282822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c9wrc9C10NsTXzF0ZIdB3nk23VZ.jpg'),
(140801, 10009, 'Rumo ao Desconhecido Misterios Paranormais S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/acTg2DBT4sP5yHwdnCotfHJCCPG.jpg'),
(140802, 10010, 'Rumo ao Desconhecido Misterios Paranormais S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aGR5YktYpzBS6r1HPymfsrZwIxf.jpg'),
(140803, 10010, 'Rumo ao Desconhecido Misterios Paranormais S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u5sfwmpmfRTDT9cEq3r61tCRHIm.jpg'),
(140804, 10010, 'Rumo ao Desconhecido Misterios Paranormais S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/282826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7hdzgOq7Xe0HzHyHaEMsZPT43hp.jpg'),
(140805, 10010, 'Rumo ao Desconhecido Misterios Paranormais S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/282827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Y9XJrVOOisVbCCLGeHS6wm1FH9.jpg'),
(140806, 10010, 'Rumo ao Desconhecido Misterios Paranormais S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/626501.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tzg9hFKSmLTVznkbXc7YAymVhbQ.jpg'),
(140807, 10011, 'Rumo ao Desconhecido Misterios Paranormais S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wtj6MGhJp8TJJhbNISauemwWDkw.jpg'),
(140808, 10011, 'Rumo ao Desconhecido Misterios Paranormais S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4sTFDiiOQKtMyuVmooV7XH1dvPr.jpg'),
(140809, 10011, 'Rumo ao Desconhecido Misterios Paranormais S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/282831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xUAVKfxAh6SHa2e4DNMrj1AQams.jpg'),
(140810, 10011, 'Rumo ao Desconhecido Misterios Paranormais S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/282832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/66zlpIg2dCcJ02kKl3HgxrfRTM.jpg'),
(140811, 10011, 'Rumo ao Desconhecido Misterios Paranormais S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140812, 10011, 'Rumo ao Desconhecido Misterios Paranormais S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/282834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140813, 10011, 'Rumo ao Desconhecido Misterios Paranormais S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140814, 10012, 'Rumo ao Desconhecido Misterios Paranormais S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140815, 10012, 'Rumo ao Desconhecido Misterios Paranormais S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140816, 10012, 'Rumo ao Desconhecido Misterios Paranormais S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/295234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140817, 10012, 'Rumo ao Desconhecido Misterios Paranormais S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/301079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140818, 10012, 'Rumo ao Desconhecido Misterios Paranormais S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/307266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140819, 10012, 'Rumo ao Desconhecido Misterios Paranormais S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/307267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140820, 10012, 'Rumo ao Desconhecido Misterios Paranormais S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/321196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140821, 10012, 'Rumo ao Desconhecido Misterios Paranormais S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/321197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140822, 10013, 'Rumo ao Desconhecido Misterios Paranormais S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/414446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140823, 10013, 'Rumo ao Desconhecido Misterios Paranormais S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/414447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140824, 10013, 'Rumo ao Desconhecido Misterios Paranormais S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/414448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140825, 10013, 'Rumo ao Desconhecido Misterios Paranormais S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/414449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140826, 10013, 'Rumo ao Desconhecido Misterios Paranormais S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/414450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140827, 10013, 'Rumo ao Desconhecido Misterios Paranormais S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/503017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140828, 10013, 'Rumo ao Desconhecido Misterios Paranormais S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/503018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140829, 10013, 'Rumo ao Desconhecido Misterios Paranormais S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/503019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140830, 10014, 'Rumo ao Desconhecido Misterios Paranormais S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/503020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140831, 10014, 'Rumo ao Desconhecido Misterios Paranormais S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140832, 10014, 'Rumo ao Desconhecido Misterios Paranormais S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140833, 10014, 'Rumo ao Desconhecido Misterios Paranormais S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140834, 10014, 'Rumo ao Desconhecido Misterios Paranormais S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140835, 10014, 'Rumo ao Desconhecido Misterios Paranormais S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140836, 10014, 'Rumo ao Desconhecido Misterios Paranormais S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140837, 10014, 'Rumo ao Desconhecido Misterios Paranormais S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/656612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zZ9qdkcg7sMGk6cV8EwxLsy5wtc.jpg'),
(140838, 10015, 'Sons do Planeta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s1N3njFG4JN4KqXN9aBarm7cPnU.jpg'),
(140839, 10015, 'Sons do Planeta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3O8euJ2dYY7rb2kx5FRh9B6Am51.jpg'),
(140840, 10015, 'Sons do Planeta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/282794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rC1JmwAVOOxlxWraTd8inVl9cZV.jpg'),
(140841, 10015, 'Sons do Planeta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/282795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lcXPaOifzNUG8nXTbzqorZeUjyX.jpg'),
(140842, 10015, 'Sons do Planeta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/de38qPrH8XqHbHkkm3Jfzs8aIpC.jpg'),
(140843, 10015, 'Sons do Planeta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/282797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zmSZOHI2wcS4IhyzGRkIfsAXOuB.jpg'),
(140844, 10015, 'Sons do Planeta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nHmjZ7z9GiRLFRFwMKMseCvPOTK.jpg'),
(140845, 10015, 'Sons do Planeta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/282799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hpEW9Lbry6xg2V7pOhkWrVow9Kl.jpg'),
(140846, 10015, 'Sons do Planeta S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/282800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ymVPMhobTQI5fru6FnGAGXg4vE.jpg'),
(140847, 10015, 'Sons do Planeta S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/282801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4j99YddxIKp8NAt6IB5IOLSyxQL.jpg'),
(140848, 10015, 'Sons do Planeta S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/282802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rqClFJdkvJLPdj5Hmiy8YY7ml6I.jpg'),
(140849, 10015, 'Sons do Planeta S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/282803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p8jcIFBH0lufwDWRRZsdoObWfBN.jpg'),
(140850, 10016, 'Kingdom [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pockLHjj00wSxzcZR4oGgXSfWO1.jpg'),
(140851, 10016, 'Kingdom [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hN9n59vsEWVCu16EX0DSORUMhac.jpg'),
(140852, 10016, 'Kingdom [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/282657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xtQsxhJPiE2cLwlk76VUpfXsORt.jpg'),
(140853, 10016, 'Kingdom [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/282658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vr3BFlbgdB1zUqM9bwT3UFTwFD7.jpg'),
(140854, 10016, 'Kingdom [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9YEgiJZisZ0jx44GWab2pUEb606.jpg'),
(140855, 10016, 'Kingdom [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/282660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13hF0KrNYJlM4UAAWsfuxO9MGdx.jpg'),
(140856, 10016, 'Kingdom [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6etlFDpGuD62GGeL2yu4ZBrxToe.jpg'),
(140857, 10016, 'Kingdom [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/282662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gjXjSmnYDduabO3lzesuUZT4fcx.jpg'),
(140858, 10016, 'Kingdom [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/282663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Dfg2WHhGfWPuhc0nVFem1gLlq0.jpg'),
(140859, 10016, 'Kingdom [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/282664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1TXMqA271UymrT41oAplbtombCH.jpg'),
(140860, 10016, 'Kingdom [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/282665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9O0xeBym43IxRVepqa7IL3tSsr8.jpg'),
(140861, 10016, 'Kingdom [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/282666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m0jW0K9c298YgjPdOYYdrmwhIYu.jpg'),
(140862, 10016, 'Kingdom [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/282667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/du6c6O3VsZb4Qzgmiw4CR8y5in1.jpg'),
(140863, 10016, 'Kingdom [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/282668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xyNtEsvd8wDMmAuvgbgK6nTXGTG.jpg'),
(140864, 10016, 'Kingdom [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/282669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4xDkQrNghNOGdavzLfl1NxznCKT.jpg'),
(140865, 10016, 'Kingdom [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/282670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDvE4MvasdjuAPJuaOOMbz3nk36.jpg'),
(140866, 10016, 'Kingdom [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/282671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7cLQsbtoZMyFrO7Py7WjQDvoGI0.jpg'),
(140867, 10016, 'Kingdom [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/282672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rFAyqBKmShGJW0rdCIsjNehPj5r.jpg'),
(140868, 10016, 'Kingdom [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/282673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6woEbpz7U2bE5ytcD9TjylAHRh.jpg'),
(140869, 10016, 'Kingdom [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/282674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sX9jsR7w9BWfcYmEszOTsOXLCKs.jpg'),
(140870, 10016, 'Kingdom [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/282675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ddTUfleyP9dITUebfpYMhINgzho.jpg'),
(140871, 10016, 'Kingdom [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/282676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q19pFbhSYmYXZcQzJNK4yLY6YtB.jpg'),
(140872, 10016, 'Kingdom [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/282677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qD82oa1W8gT4CD6hBSHZ4nzfZ3N.jpg'),
(140873, 10016, 'Kingdom [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/282678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q8OWgXlXlut4VPbYGjOu4fe8ooH.jpg'),
(140874, 10016, 'Kingdom [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/282679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pf5c1nxCGpqnnpM6U44TstyfnXZ.jpg'),
(140875, 10016, 'Kingdom [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/282680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8XNr7DJdx3CgIDZLt7bkS1LPHWb.jpg'),
(140876, 10016, 'Kingdom [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/282681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/feXqIRISJEYzcxBrbZwdXecOV9l.jpg'),
(140877, 10016, 'Kingdom [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/282682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fV3kv1GRzOb3YvCnKET8xaktHgW.jpg'),
(140878, 10016, 'Kingdom [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/282683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bAalxMhUlv0rSW4wswuXaJvSnfa.jpg'),
(140879, 10016, 'Kingdom [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/282684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cINI0sCgQ4lU7EaJbzHc96Dmg82.jpg'),
(140880, 10016, 'Kingdom [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/282685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/84Py3LUpiGVead9wGtCVK0QKu1E.jpg'),
(140881, 10016, 'Kingdom [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/282686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBMDCmw26MWdvCHU9NAr8WawOJs.jpg'),
(140882, 10016, 'Kingdom [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/282687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xx5mMMf9mPW8nRWqt4IjDoo56iG.jpg'),
(140883, 10016, 'Kingdom [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/282688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Qf3zsCXghCsxpdWbacDanupUO6.jpg'),
(140884, 10016, 'Kingdom [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/282689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cfKp4VyOgQ5Giz9UmMzz2jQ5TTj.jpg'),
(140885, 10016, 'Kingdom [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/282690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/srsy02RNiYsprkbRhUdelj2EcQZ.jpg'),
(140886, 10016, 'Kingdom [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/282691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9vgAojMZy3XSLRNwNPUQ6gb6yiN.jpg'),
(140887, 10016, 'Kingdom [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/282692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iNjDLzag5ILlVr6859xA4lUYL4l.jpg'),
(140888, 10017, 'Kingdom [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AkFBzMwcBxkAIYFy6s1YbppOhUU.jpg'),
(140889, 10017, 'Kingdom [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rMhnmCUs7vhPc4F48xjoCeeT5k1.jpg'),
(140890, 10017, 'Kingdom [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/282695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zEEcbBeD6bATFm87c3GiujA3Jpz.jpg'),
(140891, 10017, 'Kingdom [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/282696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fsIzkuLRiJpJssu91byk48R2IeG.jpg'),
(140892, 10017, 'Kingdom [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6KPVVhUlIqucn1V9tu0PoXjvxRl.jpg'),
(140893, 10017, 'Kingdom [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/282698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bSQ2lo1dsy0451ZNnPv9tlAOMIT.jpg'),
(140894, 10017, 'Kingdom [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mIEoyynP9ljxr6DcaQ1O3mBEHyS.jpg'),
(140895, 10017, 'Kingdom [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/282700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kyolUCxch9BIOzooGPTiz5VgxOr.jpg'),
(140896, 10017, 'Kingdom [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/282701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/btfjfe6ZTTWb19h5jwDqhMVOxZW.jpg'),
(140897, 10017, 'Kingdom [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/282702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sVkYrSxUIURX8nSt7ZKmbkBdaHQ.jpg'),
(140898, 10017, 'Kingdom [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/282703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wmdUgwtKzdW0qnulAg4ynYhLsbg.jpg'),
(140899, 10017, 'Kingdom [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/282704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ei8AxFzBYpvUbr0tpvkC2jGYY42.jpg'),
(140900, 10017, 'Kingdom [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/282705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zmpuVZTe5zLv7MecIrFPKn07VpN.jpg'),
(140901, 10017, 'Kingdom [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/282706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4QJffo1AMX8EmlZMjAjrrAVsL3x.jpg'),
(140902, 10017, 'Kingdom [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/282707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Liu50zgXBEPm7CClr0I0wm4xzU.jpg'),
(140903, 10017, 'Kingdom [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/282708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wvJVefXBbF931RtztPt431XIUxt.jpg'),
(140904, 10017, 'Kingdom [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/282709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lMaxO1ujGIB7uXe7RqIB7yHO493.jpg'),
(140905, 10017, 'Kingdom [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/282710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fq0pJT6hIglI3RYARvTv0ihhnH4.jpg'),
(140906, 10017, 'Kingdom [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/282711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMri0GuWN7KJGOuEc1O2gFfVupW.jpg'),
(140907, 10017, 'Kingdom [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/282712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dBS7PU6Bh3GTlHixpqmvGGqOTkf.jpg'),
(140908, 10017, 'Kingdom [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/282713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/41PXyubfIioTlMKibKvmHA2xJoj.jpg'),
(140909, 10017, 'Kingdom [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/282714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/TYCfrH6vb4XwxrYgF31WQ1agIb.jpg'),
(140910, 10017, 'Kingdom [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/282715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vB0Pjp3kAy0bqS884T2cCWLzz3H.jpg'),
(140911, 10017, 'Kingdom [L] S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/282716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/JzIYu0oVysmSEWdGhPcVaHuyvJ.jpg'),
(140912, 10017, 'Kingdom [L] S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/282717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pGid40DHzY5mRkOf3W2hLwaQQx0.jpg'),
(140913, 10017, 'Kingdom [L] S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/282718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ppDDPXUzSktrYvobnbSjri8Xb3S.jpg'),
(140914, 10017, 'Kingdom [L] S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/282719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6JenAFidJC3WXpkzGnVAASRkQk.jpg'),
(140915, 10017, 'Kingdom [L] S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/282720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c3zQM0lLv7zomgyQCs1H9IUtOrs.jpg'),
(140916, 10017, 'Kingdom [L] S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/282721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gNIH2ABr9xDizqnR6mem9aBOisH.jpg'),
(140917, 10017, 'Kingdom [L] S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/282722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUKhvFeQxSeQ6v49PqMx00f1j4U.jpg'),
(140918, 10017, 'Kingdom [L] S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/282723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aKcNCteL0DlsScoe9eLapBWXmMW.jpg'),
(140919, 10017, 'Kingdom [L] S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/282724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d2LoZ80QFX6J2dv1Eh84CM8a5H3.jpg'),
(140920, 10017, 'Kingdom [L] S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/282725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m9bxwG6B5xozkn0OjxKQdXTzjBe.jpg'),
(140921, 10017, 'Kingdom [L] S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/282726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bBJbAu7fZHs2dNXdpuH1koWCkNG.jpg'),
(140922, 10017, 'Kingdom [L] S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/282727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wfhf8rM1kPgBjagcvMNk4qK3itA.jpg'),
(140923, 10017, 'Kingdom [L] S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/282728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oGSNZKWfes4pUaleWPHExeQPpQF.jpg'),
(140924, 10017, 'Kingdom [L] S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/282729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2F5KV6dx79NhboOzeJAnmNVKeoz.jpg'),
(140925, 10017, 'Kingdom [L] S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/282730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dINCvVq1ikePAXt49i3l0EISLUW.jpg'),
(140926, 10017, 'Kingdom [L] S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/282731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bTg0iMfWGKOYd9cbnZELo4QLW52.jpg'),
(140927, 10018, 'Kingdom [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qn9LwFPdoRFW5Vv9cu9Y4xlwVaI.jpg'),
(140928, 10018, 'Kingdom [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mWurmPaP6s6wxmQlvlwM4afy7gX.jpg'),
(140929, 10018, 'Kingdom [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/282734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uCBzPz3cJlczW52NlY0YxiHSk45.jpg'),
(140930, 10018, 'Kingdom [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/282735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xnXoOJNkYv3aI943aYPpp4bF9Hr.jpg'),
(140931, 10018, 'Kingdom [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MGH56X5TdOVQd13FmRMHi3WymW.jpg'),
(140932, 10018, 'Kingdom [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/282737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xdCKpJTPh51z0yWgnoILyjdAsTm.jpg'),
(140933, 10018, 'Kingdom [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBXgRArrrA7h8Jrl1ZP9dTjfe4M.jpg'),
(140934, 10018, 'Kingdom [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/282739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/discqMSZ7nTk1BcHqr3pTRLBZhl.jpg'),
(140935, 10018, 'Kingdom [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/282740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yYzcQAdHUEl2pYkYFPC37XNhtYL.jpg'),
(140936, 10018, 'Kingdom [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/282741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gMSDcV5aQ52YDNs2cdpwgqgQYyL.jpg'),
(140937, 10018, 'Kingdom [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/282742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o1NV09Nnv0Wx8MGIBIpjtG1rU3u.jpg'),
(140938, 10018, 'Kingdom [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/282743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKXaBlipVvdwy7SxkZlPu8OM0k9.jpg'),
(140939, 10018, 'Kingdom [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/282744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vYKgP1Xw8FLfnZCjwdr9FJ3OZe.jpg'),
(140940, 10018, 'Kingdom [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/282745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9HW9MYtXKMItPxNz9HUuNxOP4kF.jpg'),
(140941, 10018, 'Kingdom [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/282746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iIwsZ4oXDoH7Vql2jbMNgLP3Ex.jpg'),
(140942, 10018, 'Kingdom [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/282747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wvkGzeVFI7wAy7Ke6b4QCWUDsAx.jpg'),
(140943, 10018, 'Kingdom [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/282748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBolGeatRDz5kY2SV8EtJ6FXBys.jpg'),
(140944, 10018, 'Kingdom [L] S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/282749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i015ucHiHwyqbgs4LIVosg7Phi4.jpg'),
(140945, 10018, 'Kingdom [L] S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/282750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZBp9Qwfl0lOpQdL5EpVk4xSU95.jpg'),
(140946, 10018, 'Kingdom [L] S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/282751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rFqato1FB6BJ8pnlP8g00W37TZA.jpg'),
(140947, 10018, 'Kingdom [L] S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/282752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJLaVfItvi9RBqrENpFrBTRPPbY.jpg'),
(140948, 10018, 'Kingdom [L] S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/282753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVEJiNa6qp1aEGtMT6f1JVUbfqm.jpg'),
(140949, 10018, 'Kingdom [L] S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/282754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o42luESWDblD8xRQajV0gKA1XTr.jpg'),
(140950, 10018, 'Kingdom [L] S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/282755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aY0doUKJJshywrOpAbOx0C925jO.jpg'),
(140951, 10018, 'Kingdom [L] S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/282756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MofTH4CLvJIjwJlQ7GAgjm4yeU.jpg'),
(140952, 10018, 'Kingdom [L] S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/282757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dALn1TG96d8U7AXPZINey93nWzb.jpg'),
(140953, 10019, 'Kingdom [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4dBclYVy9JTKMmOn7W1M1swYqDE.jpg'),
(140954, 10019, 'Kingdom [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uNpVAbxVmz5GRN1yXPAv5Qe7ghA.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(140955, 10019, 'Kingdom [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/282760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e9SoWJWfhOGHv4yCYI15HtrfuKj.jpg'),
(140956, 10019, 'Kingdom [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/282761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lYCS81h1rZtj2XCJ93A3pmep55.jpg'),
(140957, 10019, 'Kingdom [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iAXJvYhzxsoQ4hQykZHaqzrrq7F.jpg'),
(140958, 10019, 'Kingdom [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/282763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0u5gkHvcrTZ6fJkHJf0HYHIzHx.jpg'),
(140959, 10019, 'Kingdom [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1taU0cXUKG24HhPBaCnqxhq2K1i.jpg'),
(140960, 10019, 'Kingdom [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/282765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bqRa73hvKjLEEcJcApGTvjqqdE3.jpg'),
(140961, 10019, 'Kingdom [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/282766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNZ0vurB5xHFwzVlx3Vl9cXsSgd.jpg'),
(140962, 10019, 'Kingdom [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/282767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/14couZHbVx8MFoFCRcR7BMDiBdU.jpg'),
(140963, 10019, 'Kingdom [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/282768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnpc93CYaxN9hZej8j9wS24Ojsd.jpg'),
(140964, 10019, 'Kingdom [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/282769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nHUywHSmNtScfsp6d75SZ1QmGj2.jpg'),
(140965, 10019, 'Kingdom [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/282770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mVR3qeaLBxYYq6brucIW3h3xxYn.jpg'),
(140966, 10019, 'Kingdom [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/282771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXrSORYUd0CshNBDfKpREtAzwTu.jpg'),
(140967, 10019, 'Kingdom [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/282772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qLWr08JzBkYU7KVinxaGTYVHkEA.jpg'),
(140968, 10019, 'Kingdom [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/282773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j0v0emhCKZ0ZLzpgks347qARc5f.jpg'),
(140969, 10019, 'Kingdom [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/282774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXi8bFbKa1Evpvx6pppiHTrZh01.jpg'),
(140970, 10019, 'Kingdom [L] S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/282775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ibJrT7bfI1C1GCTEWwqFQLT6pxC.jpg'),
(140971, 10019, 'Kingdom [L] S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/282776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t1oqT3bXvA34NME9SHiuYHLEHeQ.jpg'),
(140972, 10019, 'Kingdom [L] S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/282777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/776t758Fm9PwoUinG76I8JGBUJS.jpg'),
(140973, 10019, 'Kingdom [L] S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/282778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/474IBUWFsHIAMllq6mJvHgslNUS.jpg'),
(140974, 10019, 'Kingdom [L] S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/282779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMp6fHYY0VFyPQ53id1XsoJP2i9.jpg'),
(140975, 10019, 'Kingdom [L] S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/282780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hnzrqDcaE1vx8ri2BQNL7aBrCxf.jpg'),
(140976, 10019, 'Kingdom [L] S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/282781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nXKV7flvU8plS0m7ZhZgUbjpr4X.jpg'),
(140977, 10019, 'Kingdom [L] S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/282782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4nqPYomZQxeUZZhlL22i3UeyTt7.jpg'),
(140978, 10019, 'Kingdom [L] S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/282783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sdBtRs7v6ACq1x991TxEVaRMKEv.jpg'),
(140979, 10020, 'Kingdom [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ooWxOAjk51eOJlyoG8KEEWLklzN.jpg'),
(140980, 10020, 'Kingdom [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gTdbHkA3aQ87Qgj24K93iK1vXgI.jpg'),
(140981, 10020, 'Kingdom [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/282786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wsPFjN9dlucR9aXoThihlO8XWx5.jpg'),
(140982, 10020, 'Kingdom [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/282787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8BZgFDv6Ebwl4dYKVx2s0pQ5Lso.jpg'),
(140983, 10020, 'Kingdom [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A0DzfR50cyz2Mn0MIVgAspkpF5R.jpg'),
(140984, 10020, 'Kingdom [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/282789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ug0x3myiMBPZhmapEBq1lEJMsAf.jpg'),
(140985, 10020, 'Kingdom [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/597341.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/heUqEo0bIsUh9gVstpCqNtLY4Dp.jpg'),
(140986, 10020, 'Kingdom [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/292390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aGjh41os09tVW9VG9lwxWScPXsm.jpg'),
(140987, 10020, 'Kingdom [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/297685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aGjh41os09tVW9VG9lwxWScPXsm.jpg'),
(140988, 10020, 'Kingdom [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/304511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aGjh41os09tVW9VG9lwxWScPXsm.jpg'),
(140989, 10020, 'Kingdom [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/308821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aGjh41os09tVW9VG9lwxWScPXsm.jpg'),
(140990, 10020, 'Kingdom [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/315790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aGjh41os09tVW9VG9lwxWScPXsm.jpg'),
(140991, 10020, 'Kingdom [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/315791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aGjh41os09tVW9VG9lwxWScPXsm.jpg'),
(140992, 10021, 'Kingdom [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/887713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aGjh41os09tVW9VG9lwxWScPXsm.jpg'),
(140993, 10021, 'Kingdom [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/888104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aGjh41os09tVW9VG9lwxWScPXsm.jpg'),
(140994, 10021, 'Kingdom [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/889673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aGjh41os09tVW9VG9lwxWScPXsm.jpg'),
(140995, 10021, 'Kingdom [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/889993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aGjh41os09tVW9VG9lwxWScPXsm.jpg'),
(140996, 10021, 'Kingdom [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/890971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aGjh41os09tVW9VG9lwxWScPXsm.jpg'),
(140997, 10021, 'Kingdom [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/892174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aGjh41os09tVW9VG9lwxWScPXsm.jpg'),
(140998, 10021, 'Kingdom [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/892584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aGjh41os09tVW9VG9lwxWScPXsm.jpg'),
(140999, 10021, 'Kingdom [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/893302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aGjh41os09tVW9VG9lwxWScPXsm.jpg'),
(141000, 10021, 'Kingdom [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/893528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aGjh41os09tVW9VG9lwxWScPXsm.jpg'),
(141001, 10021, 'Kingdom [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/894813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aGjh41os09tVW9VG9lwxWScPXsm.jpg'),
(141002, 10021, 'Kingdom [L] S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/896200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aGjh41os09tVW9VG9lwxWScPXsm.jpg'),
(141003, 10021, 'Kingdom [L] S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/896903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aGjh41os09tVW9VG9lwxWScPXsm.jpg'),
(141004, 10021, 'Kingdom [L] S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/897381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aGjh41os09tVW9VG9lwxWScPXsm.jpg'),
(141005, 10022, 'Kennedy [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iTdTS1qTothsYFWprD7z6pQ7h9V.jpg'),
(141006, 10022, 'Kennedy [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1THk7DUHzqUHF6LT12kodtx7Om1.jpg'),
(141007, 10022, 'Kennedy [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/282448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ejTp5JDdBis0Agwp8sm8KrMt4IB.jpg'),
(141008, 10022, 'Kennedy [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/282449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uWDw5KJGlpv8y3CBkCBjSmW1Je2.jpg'),
(141009, 10022, 'Kennedy [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sbpqTIo6CU8fYfWxfLFPxElIHOa.jpg'),
(141010, 10022, 'Kennedy [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/282451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cn4vwhsp8dDT0Oq2ctSHJSXaPf3.jpg'),
(141011, 10022, 'Kennedy [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBbeysjRcyFGxqBIg1fLXEDm85.jpg'),
(141012, 10022, 'Kennedy [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/282453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLHZuOufh6U7X9SS5WAQ0PKMRmK.jpg'),
(141013, 10023, 'Island [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/282434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hErewZ9uVqXzgi6CkzF37i091Uq.jpg'),
(141014, 10023, 'Island [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/282435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ap9zUDHYimIZuPP5oSdBtEcsjtc.jpg'),
(141015, 10023, 'Island [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/282436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vT836PKyhUi13diJ7JqmiRKLbwd.jpg'),
(141016, 10023, 'Island [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/282437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xDiDNruLuX5xVyxSZL2X7UX84Bs.jpg'),
(141017, 10023, 'Island [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/282438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bJLjb3McTS1IUOxQCPmqpmJ3J5L.jpg'),
(141018, 10023, 'Island [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/282439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1feBRzddV25MMEksffumQAlF1n8.jpg'),
(141019, 10023, 'Island [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/282440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LE3d33TK48mkoSq0TjKAp24qiP.jpg'),
(141020, 10023, 'Island [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/282441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTbz3RI26iiFfM2VoyAI4WGeeer.jpg'),
(141021, 10023, 'Island [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/282442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hkl2TUnVSzkVunT7Ibs1wSac1BZ.jpg'),
(141022, 10023, 'Island [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/282443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/efizIeRLmj0H51WM4vr4pzrthTE.jpg'),
(141023, 10023, 'Island [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/282444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yoqs0PdMKZFhW8PTGGvdI35fCNw.jpg'),
(141024, 10023, 'Island [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/282445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ax2FzrdVNAtgtGyJr6zmopBf3mP.jpg'),
(141025, 10024, 'Arquivos Alienigenas Reabertos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lWfPEm1NCCWb0CeyU5eDqDixas2.jpg'),
(141026, 10024, 'Arquivos Alienigenas Reabertos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lWfPEm1NCCWb0CeyU5eDqDixas2.jpg'),
(141027, 10024, 'Arquivos Alienigenas Reabertos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/295890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lWfPEm1NCCWb0CeyU5eDqDixas2.jpg'),
(141028, 10024, 'Arquivos Alienigenas Reabertos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/300684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lWfPEm1NCCWb0CeyU5eDqDixas2.jpg'),
(141029, 10024, 'Arquivos Alienigenas Reabertos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/309391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lWfPEm1NCCWb0CeyU5eDqDixas2.jpg'),
(141030, 10024, 'Arquivos Alienigenas Reabertos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/325208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lWfPEm1NCCWb0CeyU5eDqDixas2.jpg'),
(141031, 10024, 'Arquivos Alienigenas Reabertos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/325209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lWfPEm1NCCWb0CeyU5eDqDixas2.jpg'),
(141032, 10024, 'Arquivos Alienigenas Reabertos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/333967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lWfPEm1NCCWb0CeyU5eDqDixas2.jpg'),
(141033, 10025, 'Bebidas Apostas e Sexo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/288377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vYNWi1xH9nG46lRga4eZMRgIF2n.jpg'),
(141034, 10025, 'Bebidas Apostas e Sexo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/288378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/haWhGmaH5dB6J3TCb5PsYmtnRMC.jpg'),
(141035, 10025, 'Bebidas Apostas e Sexo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/288379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8VqfmnxjlC3hUi2ci0hEiKrlE9u.jpg'),
(141036, 10026, 'Franjinha e Milena Em Busca da Ciencia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/288369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tC3xl3EEd92Wz3dntK3pTjBb9vz.jpg'),
(141037, 10026, 'Franjinha e Milena Em Busca da Ciencia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/288370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mLVLOmHEEwPS4p7ucBFX86yy4jR.jpg'),
(141038, 10026, 'Franjinha e Milena Em Busca da Ciencia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/288371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tC3xl3EEd92Wz3dntK3pTjBb9vz.jpg'),
(141039, 10026, 'Franjinha e Milena Em Busca da Ciencia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/288372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2zMCIC1Lzmt7nk9E7ee3RupcJFg.jpg'),
(141040, 10026, 'Franjinha e Milena Em Busca da Ciencia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/288373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tC3xl3EEd92Wz3dntK3pTjBb9vz.jpg'),
(141041, 10026, 'Franjinha e Milena Em Busca da Ciencia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/288374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tC3xl3EEd92Wz3dntK3pTjBb9vz.jpg'),
(141042, 10026, 'Franjinha e Milena Em Busca da Ciencia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/288375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tC3xl3EEd92Wz3dntK3pTjBb9vz.jpg'),
(141043, 10026, 'Franjinha e Milena Em Busca da Ciencia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/288376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qXv1pNv6gC7JEJqLkHJnW2Q7kD7.jpg'),
(141044, 10027, 'Franjinha e Milena Em Busca da Ciencia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/419578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tC3xl3EEd92Wz3dntK3pTjBb9vz.jpg'),
(141045, 10027, 'Franjinha e Milena Em Busca da Ciencia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/419579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tC3xl3EEd92Wz3dntK3pTjBb9vz.jpg'),
(141046, 10027, 'Franjinha e Milena Em Busca da Ciencia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/419580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tC3xl3EEd92Wz3dntK3pTjBb9vz.jpg'),
(141047, 10027, 'Franjinha e Milena Em Busca da Ciencia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/419581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tC3xl3EEd92Wz3dntK3pTjBb9vz.jpg'),
(141048, 10027, 'Franjinha e Milena Em Busca da Ciencia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/419582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tC3xl3EEd92Wz3dntK3pTjBb9vz.jpg'),
(141049, 10027, 'Franjinha e Milena Em Busca da Ciencia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/419583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tC3xl3EEd92Wz3dntK3pTjBb9vz.jpg'),
(141050, 10027, 'Franjinha e Milena Em Busca da Ciencia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/419584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tC3xl3EEd92Wz3dntK3pTjBb9vz.jpg'),
(141051, 10027, 'Franjinha e Milena Em Busca da Ciencia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/419585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tC3xl3EEd92Wz3dntK3pTjBb9vz.jpg'),
(141052, 10028, 'Iwaju S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/288363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b35JOB5xtdtrr2GojdKpmX3zRqa.jpg'),
(141053, 10028, 'Iwaju S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/288364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rbL9svAGiz5AbTVDpQz0my0UFuy.jpg'),
(141054, 10028, 'Iwaju S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/288365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uv5AcbWuK86wCb67bBQqnFp1fUJ.jpg'),
(141055, 10028, 'Iwaju S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/288366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yK0y2DmCPrDf6baY8k1Y8t1VVNX.jpg'),
(141056, 10028, 'Iwaju S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/288367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkKpaQ5lkO3NeVNFjUkmgNt3Q1x.jpg'),
(141057, 10028, 'Iwaju S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/288368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7fIDzR74CNZpYnrEvnEBF1wNSlH.jpg'),
(141058, 10029, 'Jogo de Espioes Historias da Guerra Fria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/288360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zvV2IRIV4Cc10f9lZp0wHEDsPla.jpg'),
(141059, 10029, 'Jogo de Espioes Historias da Guerra Fria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/288361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/siNEJDnwXjrWT46qJRkss5G31nh.jpg'),
(141060, 10029, 'Jogo de Espioes Historias da Guerra Fria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/288362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/brRdMyj0ru5Cb5DY5dy7D3f7CG0.jpg'),
(141061, 10030, 'STM Seja Voce Mesma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4RLKB9zX2jLxxiD5ky3U0JPYXOP.jpg'),
(141062, 10030, 'STM Seja Voce Mesma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2iXAZ46e0qN34r78VRvVV2hYZna.jpg'),
(141063, 10030, 'STM Seja Voce Mesma S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5hDVKBf2cvfwwfhgp2JYUq8UUo8.jpg'),
(141064, 10030, 'STM Seja Voce Mesma S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5hDVKBf2cvfwwfhgp2JYUq8UUo8.jpg'),
(141065, 10030, 'STM Seja Voce Mesma S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/290614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5hDVKBf2cvfwwfhgp2JYUq8UUo8.jpg'),
(141066, 10030, 'STM Seja Voce Mesma S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/290615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5hDVKBf2cvfwwfhgp2JYUq8UUo8.jpg'),
(141067, 10030, 'STM Seja Voce Mesma S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/290616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5hDVKBf2cvfwwfhgp2JYUq8UUo8.jpg'),
(141068, 10030, 'STM Seja Voce Mesma S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/290617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5hDVKBf2cvfwwfhgp2JYUq8UUo8.jpg'),
(141069, 10030, 'STM Seja Voce Mesma S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/290618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5hDVKBf2cvfwwfhgp2JYUq8UUo8.jpg'),
(141070, 10030, 'STM Seja Voce Mesma S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/290619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5hDVKBf2cvfwwfhgp2JYUq8UUo8.jpg'),
(141071, 10030, 'STM Seja Voce Mesma S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/290620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5hDVKBf2cvfwwfhgp2JYUq8UUo8.jpg'),
(141072, 10030, 'STM Seja Voce Mesma S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/290621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5hDVKBf2cvfwwfhgp2JYUq8UUo8.jpg'),
(141073, 10030, 'STM Seja Voce Mesma S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/290622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5hDVKBf2cvfwwfhgp2JYUq8UUo8.jpg'),
(141074, 10030, 'STM Seja Voce Mesma S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/290623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5hDVKBf2cvfwwfhgp2JYUq8UUo8.jpg'),
(141075, 10030, 'STM Seja Voce Mesma S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/290624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5hDVKBf2cvfwwfhgp2JYUq8UUo8.jpg'),
(141076, 10031, 'Xogum A Gloriosa Saga do Japao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/288358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b3EqbFk0DD2nqz7JCHxYO3y9uq3.jpg'),
(141077, 10031, 'Xogum A Gloriosa Saga do Japao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/288359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Y6KFhwabAYONwCBzHnXDelK2U4.jpg'),
(141078, 10031, 'Xogum A Gloriosa Saga do Japao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/293926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gaOb9hyCDUcbZiTYcHy7mIFmNo.jpg'),
(141079, 10031, 'Xogum A Gloriosa Saga do Japao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/298948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gaOb9hyCDUcbZiTYcHy7mIFmNo.jpg'),
(141080, 10031, 'Xogum A Gloriosa Saga do Japao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/303709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gaOb9hyCDUcbZiTYcHy7mIFmNo.jpg'),
(141081, 10031, 'Xogum A Gloriosa Saga do Japao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/309492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gaOb9hyCDUcbZiTYcHy7mIFmNo.jpg'),
(141082, 10031, 'Xogum A Gloriosa Saga do Japao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/316502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gaOb9hyCDUcbZiTYcHy7mIFmNo.jpg'),
(141083, 10031, 'Xogum A Gloriosa Saga do Japao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/323429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gaOb9hyCDUcbZiTYcHy7mIFmNo.jpg'),
(141084, 10031, 'Xogum A Gloriosa Saga do Japao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/330953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gaOb9hyCDUcbZiTYcHy7mIFmNo.jpg'),
(141085, 10031, 'Xogum A Gloriosa Saga do Japao S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/335185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gaOb9hyCDUcbZiTYcHy7mIFmNo.jpg'),
(141086, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kyNoyUigu9q4bFjAaisrcnC8mYv.jpg'),
(141087, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUdjzFaLNojJCCcGO3PHl2usYpW.jpg'),
(141088, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZYuuNRVJNZBj5KENkh6FQmi9kx.jpg'),
(141089, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzfl710zDWC2IRWMWJ1alhmB7J4.jpg'),
(141090, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ykPZ7NBCyVBriTT7s3tzDlrnKl9.jpg'),
(141091, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y0uRMXZydtElTMox6O5tVZaLFU7.jpg'),
(141092, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gikx8urb1WWntZksRD2REmnu2r2.jpg'),
(141093, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ownxgXEEPfhlBdgHfyzymooUnTU.jpg'),
(141094, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/289827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l7Q0cCfROTmcTJEnBaZu3DnC7yS.jpg'),
(141095, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/289828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yPdLCVsxcOsZaUFV0et8kyXMooY.jpg'),
(141096, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/289829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wkXmqJXTaNEC1iASx6Pvfh3XOiF.jpg'),
(141097, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/289830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sxhwilhrPQyPUql7CU7pX6BpBp9.jpg'),
(141098, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/289831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aux0JEgW2wq8j90xWlqnJUtcFE1.jpg'),
(141099, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/289832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ed8xke6I8O76jfTimFDh1ur3FT.jpg'),
(141100, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/289833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4z5WfXS2GtdyLPDvbgeAxD5DZFP.jpg'),
(141101, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/289834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Pv79nfFZ3qDgqnUwFSCgctNgRy.jpg'),
(141102, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/289835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fv4VCeVNXFAiCKnUQt4EyI64DdB.jpg'),
(141103, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/289836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/upt00b26axEPTrmaBUWrjMFc1ie.jpg'),
(141104, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/289837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kxiA27f7mvMmdtTyOlewZsIPet6.jpg'),
(141105, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/289838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sAfFXehsPOdhgJISTynfmjPFHYR.jpg'),
(141106, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/289839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cjvBC0UGCjUNy68MHQCRmqk1S2M.jpg'),
(141107, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/289840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDqCfzvRbLXThjgVryZqYsi19MA.jpg'),
(141108, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/289841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6suKTeT5t6ofryuPlPRRflviEBG.jpg'),
(141109, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/289842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6YBqgVR2rCTmiikJqNTMzviUKFY.jpg'),
(141110, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/289843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rPOCZkrvy4RngFvSF2ckNhWa5lN.jpg'),
(141111, 10032, '100 Lobo A Lenda da Pedra da Lua S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/289844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGoPFAG7oqM56Wk0TCAX3VOMsOV.jpg'),
(141112, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141113, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141114, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141115, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141116, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141117, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141118, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141119, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141120, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/289853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141121, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/289854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141122, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/289855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141123, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/289856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141124, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/289857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141125, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/289858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141126, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/289859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141127, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/289860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141128, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/289861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141129, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/289862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141130, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/289863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141131, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/289864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141132, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/289865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141133, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/289866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141134, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/289867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141135, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/289868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141136, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/289869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141137, 10033, '100 Lobo A Lenda da Pedra da Lua S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/289870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ahVX2SGDT5jwIX0PTuevLLSAeLB.jpg'),
(141138, 10034, '1968 O Despertar [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rq70c1BU23XkeYkGh3k1kjOwgfk.jpg'),
(141139, 10034, '1968 O Despertar [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rq70c1BU23XkeYkGh3k1kjOwgfk.jpg'),
(141140, 10034, '1968 O Despertar [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rq70c1BU23XkeYkGh3k1kjOwgfk.jpg'),
(141141, 10034, '1968 O Despertar [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rq70c1BU23XkeYkGh3k1kjOwgfk.jpg'),
(141142, 10035, 'As Confissoes de Gypsy Rose S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oQiU01FOpFeCQdNc6kyjaUOE9Gi.jpg'),
(141143, 10035, 'As Confissoes de Gypsy Rose S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJbOa4b4d46c0GGWFkrR94sWvIK.jpg'),
(141144, 10035, 'As Confissoes de Gypsy Rose S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZRFDjyLkvkManX2HC1MnBZIwBR.jpg'),
(141145, 10035, 'As Confissoes de Gypsy Rose S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/997g67zuD1hwsgohQAdPPpFaOda.jpg'),
(141146, 10035, 'As Confissoes de Gypsy Rose S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lTy2us4ujqBnRFj2OWSQfEY41LL.jpg'),
(141147, 10035, 'As Confissoes de Gypsy Rose S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f7a0PfMqNj0HH6AOSEHFJzbEUKP.jpg'),
(141148, 10036, 'Conspiracao Americana Os Crimes da Octopus S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7b56mOkHrbyGRgAsLctzEJvge22.jpg'),
(141149, 10036, 'Conspiracao Americana Os Crimes da Octopus S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d5Pl46bInDjDyNK4uBuBRQNWy2A.jpg'),
(141150, 10036, 'Conspiracao Americana Os Crimes da Octopus S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sCditvVi1uZFsPTOFAmGFEizKIX.jpg'),
(141151, 10036, 'Conspiracao Americana Os Crimes da Octopus S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3AxYNojApibcmE0NF11XKjqA3oB.jpg'),
(141152, 10037, 'Doc Investigacao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8kfkToenvz6TgxiepJWmWJ1b8m.jpg'),
(141153, 10037, 'Doc Investigacao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wPLru9UtFzsB6Zy6KS9cyVg3j6p.jpg'),
(141154, 10037, 'Doc Investigacao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/em8UOMAUiM0lqPN8uD2qXdyKfqK.jpg'),
(141155, 10037, 'Doc Investigacao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pifkLvfAfo8aaKa1Fp0MrDYZ3xh.jpg'),
(141156, 10037, 'Doc Investigacao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/swzhRivMdylVCbVSbqy9h90aRwH.jpg'),
(141157, 10037, 'Doc Investigacao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3fwf2OeHMgNoWyc8Lv2Tn47l90M.jpg'),
(141158, 10037, 'Doc Investigacao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ktakzShOhHsQYSmddSf8ke2UABB.jpg'),
(141159, 10037, 'Doc Investigacao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZF8IhpRGoRIp0jVrenC6WQxwh0.jpg'),
(141160, 10037, 'Doc Investigacao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/289723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4xmzOGdRhrUb19Ug6hV5tM4DpfG.jpg'),
(141161, 10038, 'Espada e Fada [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dykM8zMjgJefvso1OJTEQkwDFWZ.jpg'),
(141162, 10038, 'Espada e Fada [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yn3HrIdu2uhzBAW86JDzMTS0r89.jpg'),
(141163, 10038, 'Espada e Fada [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sIXqaqIxKk1FzDzDuDpZhYxpiA.jpg'),
(141164, 10038, 'Espada e Fada [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/clyPnlYE2wP5euWFO6WsV7YnocE.jpg'),
(141165, 10038, 'Espada e Fada [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2jr2Ux6L3BErBRDTD5oio5MsfYD.jpg'),
(141166, 10038, 'Espada e Fada [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s8xbfgpttPjz8wC5oFXUiURT2Fv.jpg'),
(141167, 10038, 'Espada e Fada [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bXiPNGBXanevIXmTaMLnlnpvLX1.jpg'),
(141168, 10038, 'Espada e Fada [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hd6jMph6CbLnSF92VkWw0acIco4.jpg'),
(141169, 10038, 'Espada e Fada [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/289687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oAIr0DuqkuChtYkY0f9zSVAqA1m.jpg'),
(141170, 10038, 'Espada e Fada [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/289688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yMmrwqfVRNPqtvwgb4QIzq6G6Vg.jpg'),
(141171, 10038, 'Espada e Fada [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/289689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rcKm748TALEBpTNUTgSkOyj3vXg.jpg'),
(141172, 10038, 'Espada e Fada [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/289690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQ6ehD8CcklUDPaGOd92nWqmUp3.jpg'),
(141173, 10038, 'Espada e Fada [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/289691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dP8jftZobN8XqkFTdJwvdRS4FaO.jpg'),
(141174, 10038, 'Espada e Fada [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/289692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ssRxoUTBQPGBN3JstWSNAIxVxUk.jpg'),
(141175, 10038, 'Espada e Fada [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/289693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1COdZECWkYXk2uWiUSXnKK0Y8of.jpg'),
(141176, 10038, 'Espada e Fada [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/289694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5E2BhsctZPiEQ673W2PfIIWUeCV.jpg'),
(141177, 10038, 'Espada e Fada [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/289695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uUrxWEFeTSrb5O901KCOkuUlhP1.jpg'),
(141178, 10038, 'Espada e Fada [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/289696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6fgyo1azYuX0y2r7UbkVWWOfRjq.jpg'),
(141179, 10038, 'Espada e Fada [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/289697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wx6hPsjAnse5ABEy4nSq5dliMh4.jpg'),
(141180, 10038, 'Espada e Fada [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/289698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8OckfyanYkVP043GIomqTVFhbOk.jpg'),
(141181, 10038, 'Espada e Fada [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/289699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qLuGezvTGdDUFgqFEPm1fmpSlo4.jpg'),
(141182, 10038, 'Espada e Fada [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/289700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tnICovG5cvoRgfCu71hDMPdmEM1.jpg'),
(141183, 10038, 'Espada e Fada [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/289701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aFUO5ik6ioBvUZchOeS3nsM8GCq.jpg'),
(141184, 10038, 'Espada e Fada [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/289702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dnC1Uz5StjgnuwVrn2LPWBVlVxv.jpg'),
(141185, 10038, 'Espada e Fada [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/289703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hV9CGDWmaX85fSX4shGDziy8lL5.jpg'),
(141186, 10038, 'Espada e Fada [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/289704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zRbuX1D03UxFTdKy2XeegedYzR7.jpg'),
(141187, 10038, 'Espada e Fada [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/289705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5kXhyl2FC0dG3CIl5DQLEAtL2PL.jpg'),
(141188, 10038, 'Espada e Fada [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/289706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jx9na9noOuwMnIfPKzQ4XICmCh3.jpg'),
(141189, 10038, 'Espada e Fada [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/289707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9LC4JQ8b8Ly5ih9OKlnPH3Vyruo.jpg'),
(141190, 10038, 'Espada e Fada [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/289708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/unxSxsOu39gNyrDAavIDrQJyvJP.jpg'),
(141191, 10038, 'Espada e Fada [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/289709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/440IFdGlZoAHVr0gbiTFf6Sx9WK.jpg'),
(141192, 10038, 'Espada e Fada [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/289710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNgRRvLUnKUBcdHzK7YEQiOItCX.jpg'),
(141193, 10038, 'Espada e Fada [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/289711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wRkaiXZLtwmh9lgX8OuF3K0bkGH.jpg'),
(141194, 10038, 'Espada e Fada [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/289712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ieFqo22CVHIfPYstOyNyK0Qs88I.jpg'),
(141195, 10038, 'Espada e Fada [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/289713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x6yxlErIodwfoxHGKkQ2quFTWfI.jpg'),
(141196, 10038, 'Espada e Fada [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/289714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/567WmU7xt5douVLgzv4iOvMkXTC.jpg'),
(141197, 10039, 'Guerra Korea Khitan War [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v8mVirFh7ScS0Yh7exEwQlIEsyo.jpg'),
(141198, 10039, 'Guerra Korea Khitan War [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oT9RiycgNSBDlT8AWhZBwHxEmrK.jpg'),
(141199, 10039, 'Guerra Korea Khitan War [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qGPB9jduzIs9VoG9UgmW0i3tqjm.jpg'),
(141200, 10039, 'Guerra Korea Khitan War [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0REMiotTty5mA5u0iOAkkPcw56.jpg'),
(141201, 10039, 'Guerra Korea Khitan War [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/290056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rplERRkKmNeBhWyXVZQWTskcV2q.jpg'),
(141202, 10039, 'Guerra Korea Khitan War [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/290057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/22OdtUN0pHwbPROI10HCCsnrtjf.jpg'),
(141203, 10039, 'Guerra Korea Khitan War [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/290058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tCiVccUdNTPgIgrlSCzzRWbuFZy.jpg'),
(141204, 10039, 'Guerra Korea Khitan War [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/290059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9oGXi89xtZ1QRntcdP0KmuIyoCl.jpg'),
(141205, 10039, 'Guerra Korea Khitan War [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/290060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eNXRM28N7vXrYsvUc4DpX1A3s71.jpg'),
(141206, 10039, 'Guerra Korea Khitan War [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/290061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8hwIVX8KynovH680UU8ejSmFoKz.jpg'),
(141207, 10039, 'Guerra Korea Khitan War [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/290062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y2QeqmBQhnzzq4c57p2qXB81JtI.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(141208, 10039, 'Guerra Korea Khitan War [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/290063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nr303Q33JkMxAmp90ljNFo5Inyw.jpg'),
(141209, 10039, 'Guerra Korea Khitan War [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/290064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ezfJAfJEtisREIHXyMXpFil5A6T.jpg'),
(141210, 10039, 'Guerra Korea Khitan War [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/290065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5h4NR826WErSVi9iQDZ8Ba0hjY3.jpg'),
(141211, 10039, 'Guerra Korea Khitan War [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/290066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mhS5N9ynoDblxHjgWBYVmhzaQzv.jpg'),
(141212, 10039, 'Guerra Korea Khitan War [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/290067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/blhsMBeqecP1h6X71si99aAS0ky.jpg'),
(141213, 10039, 'Guerra Korea Khitan War [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/290068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k3eSWNzr0J409xHxWQkDz47WB3i.jpg'),
(141214, 10039, 'Guerra Korea Khitan War [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/290069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZ5wtMXmUDifXSEd9ryQ5xd7dLD.jpg'),
(141215, 10039, 'Guerra Korea Khitan War [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/290070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sciLaPwGUWs3nQ5xMgDUjIHy1ZK.jpg'),
(141216, 10039, 'Guerra Korea Khitan War [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/290071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Jq9J1qa0DagEeVMSljVWngps7S.jpg'),
(141217, 10039, 'Guerra Korea Khitan War [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/290072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pNk7uPiQXqzYGOGh8SIjpulJCmV.jpg'),
(141218, 10039, 'Guerra Korea Khitan War [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/290073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tt1zDKWYHHaxvUQy1xWtHJKy22E.jpg'),
(141219, 10039, 'Guerra Korea Khitan War [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/290074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dVdleZVwQYvropV2rKMjvYmobVz.jpg'),
(141220, 10039, 'Guerra Korea Khitan War [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/290075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/86H9LY652RWDbjrmw97g4zw7bkm.jpg'),
(141221, 10039, 'Guerra Korea Khitan War [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/290076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ntWJx3zcrGVghOeYzb8ZPgyNTtD.jpg'),
(141222, 10039, 'Guerra Korea Khitan War [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/290077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/br5w96xZ5fenyKIstuMsFBIvwa4.jpg'),
(141223, 10039, 'Guerra Korea Khitan War [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/290078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2tsQthobxdAz4WVntteuHRRZsXz.jpg'),
(141224, 10039, 'Guerra Korea Khitan War [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/290079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wmdoaglJrXVKNc4zPuIKvvZ34yd.jpg'),
(141225, 10039, 'Guerra Korea Khitan War [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/290080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPoDBoAn8aFCSskE6ExhVAxxeSq.jpg'),
(141226, 10039, 'Guerra Korea Khitan War [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/294156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPoDBoAn8aFCSskE6ExhVAxxeSq.jpg'),
(141227, 10039, 'Guerra Korea Khitan War [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/299228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPoDBoAn8aFCSskE6ExhVAxxeSq.jpg'),
(141228, 10039, 'Guerra Korea Khitan War [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/299229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPoDBoAn8aFCSskE6ExhVAxxeSq.jpg'),
(141229, 10040, 'O Herdeiro Impossivel [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rgtnHrT16CO7JARVer97nh0qkzY.jpg'),
(141230, 10040, 'O Herdeiro Impossivel [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b947X2jn4sEabd3kZ65pebT7sNi.jpg'),
(141231, 10040, 'O Herdeiro Impossivel [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/297483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1GXVDn8Dfvf2sjNXkL4Z8st8O6W.jpg'),
(141232, 10040, 'O Herdeiro Impossivel [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/297484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1GXVDn8Dfvf2sjNXkL4Z8st8O6W.jpg'),
(141233, 10040, 'O Herdeiro Impossivel [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/299860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1GXVDn8Dfvf2sjNXkL4Z8st8O6W.jpg'),
(141234, 10040, 'O Herdeiro Impossivel [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/299861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1GXVDn8Dfvf2sjNXkL4Z8st8O6W.jpg'),
(141235, 10040, 'O Herdeiro Impossivel [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/304280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1GXVDn8Dfvf2sjNXkL4Z8st8O6W.jpg'),
(141236, 10040, 'O Herdeiro Impossivel [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/304281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1GXVDn8Dfvf2sjNXkL4Z8st8O6W.jpg'),
(141237, 10040, 'O Herdeiro Impossivel [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/309980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1GXVDn8Dfvf2sjNXkL4Z8st8O6W.jpg'),
(141238, 10040, 'O Herdeiro Impossivel [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/309981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1GXVDn8Dfvf2sjNXkL4Z8st8O6W.jpg'),
(141239, 10040, 'O Herdeiro Impossivel [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/317517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1GXVDn8Dfvf2sjNXkL4Z8st8O6W.jpg'),
(141240, 10040, 'O Herdeiro Impossivel [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/317518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1GXVDn8Dfvf2sjNXkL4Z8st8O6W.jpg'),
(141241, 10041, 'Porta dos Fundos no Mercado Play S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141242, 10041, 'Porta dos Fundos no Mercado Play S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141243, 10041, 'Porta dos Fundos no Mercado Play S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141244, 10041, 'Porta dos Fundos no Mercado Play S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141245, 10041, 'Porta dos Fundos no Mercado Play S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141246, 10041, 'Porta dos Fundos no Mercado Play S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141247, 10041, 'Porta dos Fundos no Mercado Play S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141248, 10041, 'Porta dos Fundos no Mercado Play S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141249, 10041, 'Porta dos Fundos no Mercado Play S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/289646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141250, 10041, 'Porta dos Fundos no Mercado Play S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/289647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141251, 10041, 'Porta dos Fundos no Mercado Play S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/289648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141252, 10041, 'Porta dos Fundos no Mercado Play S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/289649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141253, 10041, 'Porta dos Fundos no Mercado Play S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/289650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141254, 10041, 'Porta dos Fundos no Mercado Play S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/289651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141255, 10041, 'Porta dos Fundos no Mercado Play S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/289652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141256, 10041, 'Porta dos Fundos no Mercado Play S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/289653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141257, 10041, 'Porta dos Fundos no Mercado Play S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/289654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141258, 10041, 'Porta dos Fundos no Mercado Play S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/289655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141259, 10041, 'Porta dos Fundos no Mercado Play S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/289656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141260, 10041, 'Porta dos Fundos no Mercado Play S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/289657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141261, 10041, 'Porta dos Fundos no Mercado Play S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/289658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141262, 10041, 'Porta dos Fundos no Mercado Play S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/289659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141263, 10041, 'Porta dos Fundos no Mercado Play S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/289660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141264, 10041, 'Porta dos Fundos no Mercado Play S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/289661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141265, 10041, 'Porta dos Fundos no Mercado Play S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/289662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141266, 10041, 'Porta dos Fundos no Mercado Play S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/289663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141267, 10041, 'Porta dos Fundos no Mercado Play S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/289664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141268, 10041, 'Porta dos Fundos no Mercado Play S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/289665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141269, 10041, 'Porta dos Fundos no Mercado Play S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/289666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141270, 10041, 'Porta dos Fundos no Mercado Play S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/289667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141271, 10041, 'Porta dos Fundos no Mercado Play S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/289668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141272, 10041, 'Porta dos Fundos no Mercado Play S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/289669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141273, 10041, 'Porta dos Fundos no Mercado Play S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/289670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141274, 10041, 'Porta dos Fundos no Mercado Play S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/289671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141275, 10041, 'Porta dos Fundos no Mercado Play S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/289672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141276, 10041, 'Porta dos Fundos no Mercado Play S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/289673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141277, 10041, 'Porta dos Fundos no Mercado Play S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/289674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141278, 10041, 'Porta dos Fundos no Mercado Play S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/289675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141279, 10041, 'Porta dos Fundos no Mercado Play S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/289676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ygTEhOo49RAENfq9NTZ7RQ0MTq.jpg'),
(141280, 10042, 'Rainha Vermelha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nYXOgfLcgI40wcm2T6JGrdzhhpH.jpg'),
(141281, 10042, 'Rainha Vermelha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ouSYqVhqqvZ3RdbVi0mNpHBZt3k.jpg'),
(141282, 10042, 'Rainha Vermelha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8OYQZwUxz0U0ArHcOnwgFa9rN9n.jpg'),
(141283, 10042, 'Rainha Vermelha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/icjBqLbzF7Tq94ct4BVQbyG1LvJ.jpg'),
(141284, 10042, 'Rainha Vermelha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/niWL6o8mmHO5Cwu4qr6Gtmv9Iux.jpg'),
(141285, 10042, 'Rainha Vermelha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kbfjMahP3Pt8siDAXqoC4w4QxLi.jpg'),
(141286, 10042, 'Rainha Vermelha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1gC56UELmnnl6JJV0ZESmBh8IIm.jpg'),
(141287, 6357, 'Reyka S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qq0AfGkoZ9elPbwR5iKakeZPExO.jpg'),
(141288, 6357, 'Reyka S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8QBcXkDXDv1IaPmxhB2vKbWIa2F.jpg'),
(141289, 6357, 'Reyka S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4FdNfFtgrQO1YJVJw4tHMo3FQBX.jpg'),
(141290, 6357, 'Reyka S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xnmPnXI6zGzPZum92C6FLqPQfBn.jpg'),
(141291, 6357, 'Reyka S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8ueiqddCWzwlRHz8Pd8de1iHmm.jpg'),
(141292, 6357, 'Reyka S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1iuCTKEMFPbL7r9efrWnAq167d7.jpg'),
(141293, 6357, 'Reyka S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zGotkdCYjwjoK8Gdv2tADiykpQj.jpg'),
(141294, 6357, 'Reyka S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yfgwOJSzisst9TeURs7Sk1wudaL.jpg'),
(141295, 10043, 'Reyka S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1aNw7x7YrXxyG1aPmXKGTuo0rJ.jpg'),
(141296, 10043, 'Reyka S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1aNw7x7YrXxyG1aPmXKGTuo0rJ.jpg'),
(141297, 10043, 'Reyka S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1aNw7x7YrXxyG1aPmXKGTuo0rJ.jpg'),
(141298, 10043, 'Reyka S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1aNw7x7YrXxyG1aPmXKGTuo0rJ.jpg'),
(141299, 10043, 'Reyka S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1aNw7x7YrXxyG1aPmXKGTuo0rJ.jpg'),
(141300, 10043, 'Reyka S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1aNw7x7YrXxyG1aPmXKGTuo0rJ.jpg'),
(141301, 10043, 'Reyka S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1aNw7x7YrXxyG1aPmXKGTuo0rJ.jpg'),
(141302, 10043, 'Reyka S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t1aNw7x7YrXxyG1aPmXKGTuo0rJ.jpg'),
(141303, 10044, 'Sons do Planeta [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s1N3njFG4JN4KqXN9aBarm7cPnU.jpg'),
(141304, 10044, 'Sons do Planeta [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3O8euJ2dYY7rb2kx5FRh9B6Am51.jpg'),
(141305, 10044, 'Sons do Planeta [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rC1JmwAVOOxlxWraTd8inVl9cZV.jpg'),
(141306, 10044, 'Sons do Planeta [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lcXPaOifzNUG8nXTbzqorZeUjyX.jpg'),
(141307, 10044, 'Sons do Planeta [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/de38qPrH8XqHbHkkm3Jfzs8aIpC.jpg'),
(141308, 10044, 'Sons do Planeta [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zmSZOHI2wcS4IhyzGRkIfsAXOuB.jpg'),
(141309, 10044, 'Sons do Planeta [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nHmjZ7z9GiRLFRFwMKMseCvPOTK.jpg'),
(141310, 10044, 'Sons do Planeta [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hpEW9Lbry6xg2V7pOhkWrVow9Kl.jpg'),
(141311, 10044, 'Sons do Planeta [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/289611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ymVPMhobTQI5fru6FnGAGXg4vE.jpg'),
(141312, 10044, 'Sons do Planeta [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/289612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4j99YddxIKp8NAt6IB5IOLSyxQL.jpg'),
(141313, 10044, 'Sons do Planeta [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/289613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rqClFJdkvJLPdj5Hmiy8YY7ml6I.jpg'),
(141314, 10044, 'Sons do Planeta [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/289614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p8jcIFBH0lufwDWRRZsdoObWfBN.jpg'),
(141315, 10045, 'The Town Doctor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/adYdNNuI7CrdAPfQnC2VNdJAsYv.jpg'),
(141316, 10045, 'The Town Doctor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/czXPyccrqTP2GkrprROKU2IQJlD.jpg'),
(141317, 10045, 'The Town Doctor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDKBq4YAZ9yg5T0yG6VdqZ3AMQi.jpg'),
(141318, 10045, 'The Town Doctor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gx8lPlcFokYv3eBYSOElyoQ4ToY.jpg'),
(141319, 10045, 'The Town Doctor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bQNDzvhY45g5GTqFZWPd3P5uDKi.jpg'),
(141320, 10045, 'The Town Doctor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sYFCuNvLC2bqNFdcABraLnCQqyI.jpg'),
(141321, 10045, 'The Town Doctor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13zBmU0nyAz0zptrXPKlKdOpAy8.jpg'),
(141322, 10045, 'The Town Doctor [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jDJYvJan6sIl68BycrvslpNnZnf.jpg'),
(141323, 10045, 'The Town Doctor [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/289600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7M6yF8S9q11l2gHzHpDETawMnf4.jpg'),
(141324, 10045, 'The Town Doctor [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/289601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kkHOUHqDmJVc2kW5S58cuicLD0e.jpg'),
(141325, 10045, 'The Town Doctor [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/289602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5EF1qdypfqC61ZQszbkmcCoupXh.jpg'),
(141326, 10045, 'The Town Doctor [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/296987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141327, 10045, 'The Town Doctor [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/296988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141328, 10045, 'The Town Doctor [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/296989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141329, 10045, 'The Town Doctor [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/296990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141330, 10045, 'The Town Doctor [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/303806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141331, 10045, 'The Town Doctor [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/303807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141332, 10045, 'The Town Doctor [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/309558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141333, 10045, 'The Town Doctor [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/309559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141334, 10045, 'The Town Doctor [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/316984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141335, 10045, 'The Town Doctor [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/316985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141336, 10045, 'The Town Doctor [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/323474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141337, 10045, 'The Town Doctor [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/323475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141338, 10045, 'The Town Doctor [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/327084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141339, 10045, 'The Town Doctor [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/327085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141340, 10045, 'The Town Doctor [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/335734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141341, 10045, 'The Town Doctor [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/335735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141342, 10045, 'The Town Doctor [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/336880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141343, 10045, 'The Town Doctor [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/336881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141344, 10045, 'The Town Doctor [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/342770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141345, 10045, 'The Town Doctor [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/342771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141346, 10045, 'The Town Doctor [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/354008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141347, 10045, 'The Town Doctor [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/354009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141348, 10045, 'The Town Doctor [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/354010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141349, 10045, 'The Town Doctor [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/354011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141350, 10045, 'The Town Doctor [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/358338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141351, 10045, 'The Town Doctor [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/358339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141352, 10045, 'The Town Doctor [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/607274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(141353, 10046, 'The Walking Dead The Ones Who Live [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8WrLYjzukBMeeSN9QYPw28qVA6h.jpg'),
(141354, 10046, 'The Walking Dead The Ones Who Live [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/296969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywbacot78IuNhGW4uVZPxxxVTkm.jpg'),
(141355, 10046, 'The Walking Dead The Ones Who Live [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/296970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywbacot78IuNhGW4uVZPxxxVTkm.jpg'),
(141356, 10046, 'The Walking Dead The Ones Who Live [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/300955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywbacot78IuNhGW4uVZPxxxVTkm.jpg'),
(141357, 10046, 'The Walking Dead The Ones Who Live [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/307002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywbacot78IuNhGW4uVZPxxxVTkm.jpg'),
(141358, 10046, 'The Walking Dead The Ones Who Live [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/313435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ywbacot78IuNhGW4uVZPxxxVTkm.jpg'),
(141359, 10047, 'Um Crush de Primeira [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s8g0BQYwYhNw6mKHU7gbtm4AU59.jpg'),
(141360, 10047, 'Um Crush de Primeira [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zKOIIaUZtq9N8vuCNnxGJfXgvk0.jpg'),
(141361, 10047, 'Um Crush de Primeira [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sTPCtXRJjUemmZony6DNQXEA00j.jpg'),
(141362, 10047, 'Um Crush de Primeira [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eyM33LcZLHODZThUkjWo7QHkUy7.jpg'),
(141363, 10047, 'Um Crush de Primeira [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2rDvKHCPCaf62jGjD1tvtwvZm08.jpg'),
(141364, 10047, 'Um Crush de Primeira [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vDs6QhU6YE1r9pi7nj4oIJ0ZQXs.jpg'),
(141365, 10047, 'Um Crush de Primeira [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dtpKNk5H0yu4jFOWD2NQwWBlPFW.jpg'),
(141366, 10047, 'Um Crush de Primeira [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ArXhChcVILTLv5IcMLNTV5Okd3g.jpg'),
(141367, 10047, 'Um Crush de Primeira [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/289579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y9hbHgdIXaA1M2BXqbDp0jWIJpx.jpg'),
(141368, 10047, 'Um Crush de Primeira [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/289580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zjXVvyUB3sTp1FbBu3u3jDq20W.jpg'),
(141369, 10047, 'Um Crush de Primeira [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/289581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kHXNYbmBaYdFPZS6HfGRYXExHod.jpg'),
(141370, 10047, 'Um Crush de Primeira [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/289582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mO3SeyUEARxbXBBPLlTCuTuC0xX.jpg'),
(141371, 10047, 'Um Crush de Primeira [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/289583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5pfSgcePtnojIa9Cv4fUyu9Fth9.jpg'),
(141372, 10047, 'Um Crush de Primeira [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/289584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUk8spZyvFS3XNCuwhCynbBiWyg.jpg'),
(141373, 10047, 'Um Crush de Primeira [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/289585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6YoZpFNCYmnm53crEzFG23PwnPa.jpg'),
(141374, 10047, 'Um Crush de Primeira [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/289586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8ZttXesSLtcJRSG0nImcnxuLuN.jpg'),
(141375, 10047, 'Um Crush de Primeira [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/289587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/orDeMMHYJ2KYcvPQKC9jUZxv2hG.jpg'),
(141376, 10047, 'Um Crush de Primeira [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/289588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Q7kJWzx8MN14IxtRDk2lDYZYJw.jpg'),
(141377, 10047, 'Um Crush de Primeira [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/289589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xpd7tRLp1roaCLoECERbBHy3i8h.jpg'),
(141378, 10047, 'Um Crush de Primeira [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/289590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jqIfiPFBnFnFMfwVeQZR5skFUsl.jpg'),
(141379, 10048, 'Vizinhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dRxW0xiJqjfO1eDmW1N5bkxpe01.jpg'),
(141380, 10048, 'Vizinhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dRxW0xiJqjfO1eDmW1N5bkxpe01.jpg'),
(141381, 10048, 'Vizinhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dRxW0xiJqjfO1eDmW1N5bkxpe01.jpg'),
(141382, 10048, 'Vizinhos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dRxW0xiJqjfO1eDmW1N5bkxpe01.jpg'),
(141383, 10048, 'Vizinhos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dRxW0xiJqjfO1eDmW1N5bkxpe01.jpg'),
(141384, 10048, 'Vizinhos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dRxW0xiJqjfO1eDmW1N5bkxpe01.jpg'),
(141385, 10048, 'Vizinhos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dRxW0xiJqjfO1eDmW1N5bkxpe01.jpg'),
(141386, 10048, 'Vizinhos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dRxW0xiJqjfO1eDmW1N5bkxpe01.jpg'),
(141387, 10048, 'Vizinhos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/289566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dRxW0xiJqjfO1eDmW1N5bkxpe01.jpg'),
(141388, 10048, 'Vizinhos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/289567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dRxW0xiJqjfO1eDmW1N5bkxpe01.jpg'),
(141389, 10048, 'Vizinhos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/289568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dRxW0xiJqjfO1eDmW1N5bkxpe01.jpg'),
(141390, 10048, 'Vizinhos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/289569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dRxW0xiJqjfO1eDmW1N5bkxpe01.jpg'),
(141391, 10048, 'Vizinhos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/289570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dRxW0xiJqjfO1eDmW1N5bkxpe01.jpg'),
(141392, 10049, 'Casamento Impossivel [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2Tmt5i4HdCUicgFahtZ309GRlN.jpg'),
(141393, 10049, 'Casamento Impossivel [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mssnnqcVD7oa2ekwoH3pbb4bXOf.jpg'),
(141394, 10049, 'Casamento Impossivel [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/299382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pwYE1YcUXYPKnXbAQNv4NVvYTGs.jpg'),
(141395, 10049, 'Casamento Impossivel [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/299383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pwYE1YcUXYPKnXbAQNv4NVvYTGs.jpg'),
(141396, 10049, 'Casamento Impossivel [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/299384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pwYE1YcUXYPKnXbAQNv4NVvYTGs.jpg'),
(141397, 10049, 'Casamento Impossivel [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/300294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pwYE1YcUXYPKnXbAQNv4NVvYTGs.jpg'),
(141398, 10049, 'Casamento Impossivel [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/305361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pwYE1YcUXYPKnXbAQNv4NVvYTGs.jpg'),
(141399, 10049, 'Casamento Impossivel [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/305362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pwYE1YcUXYPKnXbAQNv4NVvYTGs.jpg'),
(141400, 10049, 'Casamento Impossivel [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/310641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pwYE1YcUXYPKnXbAQNv4NVvYTGs.jpg'),
(141401, 10049, 'Casamento Impossivel [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/310642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pwYE1YcUXYPKnXbAQNv4NVvYTGs.jpg'),
(141402, 10049, 'Casamento Impossivel [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/318876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pwYE1YcUXYPKnXbAQNv4NVvYTGs.jpg'),
(141403, 10049, 'Casamento Impossivel [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/318877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pwYE1YcUXYPKnXbAQNv4NVvYTGs.jpg'),
(141404, 10050, 'Wild Cards [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cvtXzIrk3yOQkyrq38xcyQ8dW4P.jpg'),
(141405, 10050, 'Wild Cards [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rcRenhr9p0CuEvn6Qp2iekVdlEH.jpg'),
(141406, 10050, 'Wild Cards [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sy3mJQc1cAbl8ehdY1f3gGZEqSK.jpg'),
(141407, 10050, 'Wild Cards [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/296956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIhkV9LNwViVD2bylPTFQvDD21e.jpg'),
(141408, 10050, 'Wild Cards [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/296957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIhkV9LNwViVD2bylPTFQvDD21e.jpg'),
(141409, 10050, 'Wild Cards [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/296958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIhkV9LNwViVD2bylPTFQvDD21e.jpg'),
(141410, 10050, 'Wild Cards [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/299663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIhkV9LNwViVD2bylPTFQvDD21e.jpg'),
(141411, 10050, 'Wild Cards [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/303717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIhkV9LNwViVD2bylPTFQvDD21e.jpg'),
(141412, 10050, 'Wild Cards [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/309504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIhkV9LNwViVD2bylPTFQvDD21e.jpg'),
(141413, 10050, 'Wild Cards [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/320917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIhkV9LNwViVD2bylPTFQvDD21e.jpg'),
(141414, 10051, 'Wild Cards [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/667144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIhkV9LNwViVD2bylPTFQvDD21e.jpg'),
(141415, 10051, 'Wild Cards [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/671081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIhkV9LNwViVD2bylPTFQvDD21e.jpg'),
(141416, 10051, 'Wild Cards [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/684977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIhkV9LNwViVD2bylPTFQvDD21e.jpg'),
(141417, 10051, 'Wild Cards [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/684978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIhkV9LNwViVD2bylPTFQvDD21e.jpg'),
(141418, 10051, 'Wild Cards [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/692678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIhkV9LNwViVD2bylPTFQvDD21e.jpg'),
(141419, 10051, 'Wild Cards [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/700404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIhkV9LNwViVD2bylPTFQvDD21e.jpg'),
(141420, 10051, 'Wild Cards [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/708214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIhkV9LNwViVD2bylPTFQvDD21e.jpg'),
(141421, 10051, 'Wild Cards [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/722700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIhkV9LNwViVD2bylPTFQvDD21e.jpg'),
(141422, 10051, 'Wild Cards [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/727612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lIhkV9LNwViVD2bylPTFQvDD21e.jpg'),
(141423, 10052, 'Yumekui Merry [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ETFb32TpIgJwsYW4CUmDACrXUi.jpg'),
(141424, 10052, 'Yumekui Merry [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/77LBkwgJlGlhtzbXDeyXi4ofm0Q.jpg'),
(141425, 10052, 'Yumekui Merry [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i8QtEQOt7CbYZdqIGXZxAZYaJji.jpg'),
(141426, 10052, 'Yumekui Merry [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pKocBWSuIdkuJQgSceQQI1iWBBS.jpg'),
(141427, 10052, 'Yumekui Merry [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJS6s4VQc6OESl9vbIuRiEkqxqv.jpg'),
(141428, 10052, 'Yumekui Merry [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A2jzkpl8i8Vzg7lWvKCcRTabFr3.jpg'),
(141429, 10052, 'Yumekui Merry [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/358188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uqZ0VbMY0bdWxJgwva8ELhPaXZk.jpg'),
(141430, 10052, 'Yumekui Merry [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/358189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uqZ0VbMY0bdWxJgwva8ELhPaXZk.jpg'),
(141431, 10052, 'Yumekui Merry [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/358190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uqZ0VbMY0bdWxJgwva8ELhPaXZk.jpg'),
(141432, 10052, 'Yumekui Merry [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/358191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uqZ0VbMY0bdWxJgwva8ELhPaXZk.jpg'),
(141433, 10052, 'Yumekui Merry [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/358192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uqZ0VbMY0bdWxJgwva8ELhPaXZk.jpg'),
(141434, 10052, 'Yumekui Merry [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/358193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uqZ0VbMY0bdWxJgwva8ELhPaXZk.jpg'),
(141435, 10052, 'Yumekui Merry [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/358194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uqZ0VbMY0bdWxJgwva8ELhPaXZk.jpg'),
(141436, 10053, 'Armazem 13 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jqEz3ii25NAoC3uY1IFFD40sVO3.jpg'),
(141437, 10053, 'Armazem 13 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5grnIgBHuEki43E986GxF7xJGP1.jpg'),
(141438, 10053, 'Armazem 13 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xaAy6bepnQKRV1rVCevfXneiUfQ.jpg'),
(141439, 10053, 'Armazem 13 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qlCtbvVWaA7jEMUcnaiI220HcbK.jpg'),
(141440, 10053, 'Armazem 13 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5zZtaQf4Qb2xJ0GoN5XRVrve084.jpg'),
(141441, 10053, 'Armazem 13 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7tHY5tWqenTzocAaL7n9J5gkRup.jpg'),
(141442, 10053, 'Armazem 13 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gqQ8g2XGoYPsPItTZT7q8nIl9Zm.jpg'),
(141443, 10053, 'Armazem 13 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/smhcAaVjyh1LUul1URbbSdovGXN.jpg'),
(141444, 10053, 'Armazem 13 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/289491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gkOBftpCAqZduARP2qmBiRrwlxZ.jpg'),
(141445, 10053, 'Armazem 13 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/289492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i62Wmii11RfkUspdmdvrW5I0OeF.jpg'),
(141446, 10053, 'Armazem 13 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/289493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vKtVWgoW9s5hTyJukGv6KZtyDqF.jpg'),
(141447, 10053, 'Armazem 13 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/289494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/20aWx04dPhxFvicEw39qjLT6Vnu.jpg'),
(141448, 10054, 'Armazem 13 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mD0kML4IGBePmyMNk4ST7rlhUjH.jpg'),
(141449, 10054, 'Armazem 13 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/UvfbwGMWkiynM0Gihvjjm3Tiq.jpg'),
(141450, 10054, 'Armazem 13 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jJn2UFoDku5PQSpx9h8iWtFYkpZ.jpg'),
(141451, 10054, 'Armazem 13 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qmWuvHe3mgdkGebL58N7IyliRkx.jpg'),
(141452, 10054, 'Armazem 13 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBH8TWeEqisyxmUTYfGYmsHbHyN.jpg'),
(141453, 10054, 'Armazem 13 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AwvuOCFCWuQbhgS9iOuxoEdRuEF.jpg'),
(141454, 10054, 'Armazem 13 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mKYejFQIEFIREjf7nL8vBO6G628.jpg'),
(141455, 10054, 'Armazem 13 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dGQTI2Ubb8Qr1cR50OyutgqPewF.jpg'),
(141456, 10054, 'Armazem 13 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/289503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1mjkNKgg4icWpKSzD5brpR7dcFg.jpg'),
(141457, 10054, 'Armazem 13 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/289504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glJofJ1oaLs61wH6RedyLF2FdCK.jpg'),
(141458, 10054, 'Armazem 13 S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/289505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aM7my0KCWfKmhIoxDomLocRz8mf.jpg'),
(141459, 10054, 'Armazem 13 S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/289506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/77XAxyhq5HC4JZaqVYvFztYoyvA.jpg'),
(141460, 10054, 'Armazem 13 S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/289507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6QImRcAIJZ6HA6jyUnwfvtS0E0T.jpg'),
(141461, 10055, 'Armazem 13 S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w1kQz7EKM9OcWX5NCmUhFm21zue.jpg'),
(141462, 10055, 'Armazem 13 S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQLqMRvVldJWGZofHlBEjQ5Pcfe.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(141463, 10055, 'Armazem 13 S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zgFhS02qtTLUoN1WnZmA3E9Mp7B.jpg'),
(141464, 10055, 'Armazem 13 S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4vW1PPPO2DkWYNgCOhBsCfl9tra.jpg'),
(141465, 10055, 'Armazem 13 S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hx8BRuuQFRJnQFoBpDXEXuINZ32.jpg'),
(141466, 10055, 'Armazem 13 S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oKGUoR07hD2cI48MCkpL2vzXmXE.jpg'),
(141467, 10055, 'Armazem 13 S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2CrgVJMn7QHW8pQX1tBOJXOZIPl.jpg'),
(141468, 10055, 'Armazem 13 S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3QhZpU88Ci8TGNW92OWMNRgUoE8.jpg'),
(141469, 10055, 'Armazem 13 S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/289516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oLGegEn27AhBCVfKECxMPQxcaVj.jpg'),
(141470, 10055, 'Armazem 13 S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/289517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/twUxKr69PzuFmgZJg9pWMFHSN78.jpg'),
(141471, 10055, 'Armazem 13 S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/289518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7u7JifIFBd9ZNVEOCXkuAYkUSP.jpg'),
(141472, 10055, 'Armazem 13 S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/289519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nz180ovEogrpYBEv2kTKykDCRH9.jpg'),
(141473, 10055, 'Armazem 13 S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/289520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2B7OLXvWfuDzMh0lsEaPON0RxAX.jpg'),
(141474, 10056, 'Armazem 13 S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wf9BNbHqBOR08fYkdYIZDEStYyI.jpg'),
(141475, 10056, 'Armazem 13 S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ewxbNtlEd15jRKJKniBTRI50RiR.jpg'),
(141476, 10056, 'Armazem 13 S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wI6NXuPyWgK9JX5IqZl4P0T0k4M.jpg'),
(141477, 10056, 'Armazem 13 S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cfMjRLPjdiyUrb1HWQB9Ahf9rph.jpg'),
(141478, 10056, 'Armazem 13 S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Wd8HjBq23mOsgExpEnIbdlNvk0.jpg'),
(141479, 10056, 'Armazem 13 S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yBfCBsY6wJRXKQNzxjPW2FegoHN.jpg'),
(141480, 10056, 'Armazem 13 S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9fZRpJgArM2nLCGiDFTTCxywxvS.jpg'),
(141481, 10056, 'Armazem 13 S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cFR1zwIxyaragE7poDS32OhD5VC.jpg'),
(141482, 10056, 'Armazem 13 S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/289529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBWMaQDxPGbe16b7V0ybs7pZY5P.jpg'),
(141483, 10056, 'Armazem 13 S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/289530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kcQwBCtkeshEWwQCWQluG3YPVXB.jpg'),
(141484, 10056, 'Armazem 13 S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/289531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5GedPEcbR6QpeVfTlRH3WzJ9Y0t.jpg'),
(141485, 10056, 'Armazem 13 S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/289532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wLnp9iCUcqJjQIAdbF0obPorcyU.jpg'),
(141486, 10056, 'Armazem 13 S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/289533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z7YtcFebeXlSsC6JV0j0Q0sj67d.jpg'),
(141487, 10056, 'Armazem 13 S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/289534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n9x6x5rFSk7WxpPDOJGNF8Lx1JG.jpg'),
(141488, 10056, 'Armazem 13 S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/289535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Tf2lEiWCOJLQmaDRr6WDm5iLMU.jpg'),
(141489, 10056, 'Armazem 13 S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/289536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oJMdwdooeKusWvLSKBroBq9qF5a.jpg'),
(141490, 10056, 'Armazem 13 S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/289537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lGxmEJM5PeWheAA7wZqZbn2o3wg.jpg'),
(141491, 10056, 'Armazem 13 S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/289538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k40x39Y0qVWNKiMkZxfl4uiRl35.jpg'),
(141492, 10056, 'Armazem 13 S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/289539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/plQMuIKguSnHTdjJ9PSdL6zgf7S.jpg'),
(141493, 10056, 'Armazem 13 S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/289540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xjc3yhM2NoDFI1vBRBGZWbpYCUw.jpg'),
(141494, 10057, 'Armazem 13 S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sX6nuSCISDpm6N3bkHTaKUifFBg.jpg'),
(141495, 10057, 'Armazem 13 S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uhab3Cz3L9gqmKJKLf1zFfFeLRF.jpg'),
(141496, 10057, 'Armazem 13 S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZsx0vOZHrBcHcPPO5ft2gNBCXN.jpg'),
(141497, 10057, 'Armazem 13 S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ZJ5fNa3KCCJlvFsPiqrX3f7cMU.jpg'),
(141498, 10057, 'Armazem 13 S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g2ZpLvJbl6db8XKDfBAh4oK5KFy.jpg'),
(141499, 10057, 'Armazem 13 S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yhv9SvKZ1gH7DkRlENvcWAwbuKJ.jpg'),
(141500, 10058, 'A Furia de Paris S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jyaYKFc7lINKcIHLCWu51p9q5a8.jpg'),
(141501, 10058, 'A Furia de Paris S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ylB9LIQ8ooctA2E6geTy3H6yBkq.jpg'),
(141502, 10058, 'A Furia de Paris S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7C88wD4Ma1O2qtqjZ4BILVEyvbe.jpg'),
(141503, 10058, 'A Furia de Paris S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vbCemHYSDSsg23Fknl2OJqLKf2J.jpg'),
(141504, 10058, 'A Furia de Paris S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8EOn1dEQs5X7IgGawgzpacVC5Ia.jpg'),
(141505, 10058, 'A Furia de Paris S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ov8kow0vCq1IBhYxN0YGZKdn88.jpg'),
(141506, 10058, 'A Furia de Paris S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ApaHzA0wuM2oURrYkfoNpcIyNhY.jpg'),
(141507, 10058, 'A Furia de Paris S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwWnadMR5pLVmCqaMmVcpG4lyhB.jpg'),
(141508, 10059, 'As Aventuras Inventadas de Dick Turpin S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5VbGYXmg5U91erKVtDoCEtCiq5Z.jpg'),
(141509, 10059, 'As Aventuras Inventadas de Dick Turpin S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gdwoSzBrT3LBxlnXzLEFPDjeMRL.jpg'),
(141510, 10059, 'As Aventuras Inventadas de Dick Turpin S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Abw2GfxvCdzg2w2tp9rx6X8jH2l.jpg'),
(141511, 10059, 'As Aventuras Inventadas de Dick Turpin S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/303070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Abw2GfxvCdzg2w2tp9rx6X8jH2l.jpg'),
(141512, 10059, 'As Aventuras Inventadas de Dick Turpin S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Abw2GfxvCdzg2w2tp9rx6X8jH2l.jpg'),
(141513, 10059, 'As Aventuras Inventadas de Dick Turpin S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/312645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Abw2GfxvCdzg2w2tp9rx6X8jH2l.jpg'),
(141514, 10060, 'Cinco Dias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/VEAyqYtYYugpGXVsYJEnPiNo98.jpg'),
(141515, 10060, 'Cinco Dias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zj10juQhp4AyQHMr1rmEKnVfONx.jpg'),
(141516, 10060, 'Cinco Dias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kwXYGkw5npOF1Ny8krl2E9mjajv.jpg'),
(141517, 10060, 'Cinco Dias S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3kQUn3OVIREQD6YyYnIaIBm6Uu4.jpg'),
(141518, 10060, 'Cinco Dias S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cikqGl2eex2igS0ohpDRnJOOLTx.jpg'),
(141519, 10061, 'E Tudo Meu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bptKL9ovLVqdMuNXVBlzVlTcYcj.jpg'),
(141520, 10061, 'E Tudo Meu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/FnmimL4O31hWm6FV35YPXpvS0P.jpg'),
(141521, 10061, 'E Tudo Meu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gjtfVbt1ftLj7LF1bhvq26eZn7F.jpg'),
(141522, 10061, 'E Tudo Meu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ehXiJG9n5nQIufyoakpNg5PEjR2.jpg'),
(141523, 10061, 'E Tudo Meu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dLdL4t2u1gxVN0PSYGzYG13TkRm.jpg'),
(141524, 10061, 'E Tudo Meu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xeDJtmzzxoD6emBKHjdmpDSHPlS.jpg'),
(141525, 10061, 'E Tudo Meu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zipOSFPacUCE1Yd6J1XBkNnksHB.jpg'),
(141526, 10061, 'E Tudo Meu S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mSONwG5CTkH7jgGKZRdvWR9GvaL.jpg'),
(141527, 10061, 'E Tudo Meu S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/289460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mzFp25sr8f1KqmfJCATUkSPutCt.jpg'),
(141528, 10061, 'E Tudo Meu S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/289461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h4yydifOIvORvkSaJf13kesgjrQ.jpg'),
(141529, 10061, 'E Tudo Meu S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/289462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aIdCrIlrjIUSIcyJOR9AvDqgxPZ.jpg'),
(141530, 10061, 'E Tudo Meu S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/289463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ktfv721UiHQvGeSabrIIAbgIAf.jpg'),
(141531, 10061, 'E Tudo Meu S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/289464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sxwOwZzInOc51NPGaEQb8sDZdcI.jpg'),
(141532, 10061, 'E Tudo Meu S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/289465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e0NZHTqLbOXw2IhMAhhkytC2wZl.jpg'),
(141533, 10061, 'E Tudo Meu S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/289466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFIpAibwHG1sbkjYlRgwPSMSLmR.jpg'),
(141534, 10061, 'E Tudo Meu S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/289467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MuvfftVS01gGIEDMpKm6AuOMKS.jpg'),
(141535, 10062, 'Feed the Beast S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3lnrLnDMcj5JdDL2y2Rwmy4JVJ.jpg'),
(141536, 10062, 'Feed the Beast S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7fKA34G583Ps4zRMpzotQWPb2bw.jpg'),
(141537, 10062, 'Feed the Beast S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p4lWcbUFGcKN3oiF8Y5h84Ssx8I.jpg'),
(141538, 10062, 'Feed the Beast S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Avcyq8UYri2L5H9BPpbKlIwFltp.jpg'),
(141539, 10062, 'Feed the Beast S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vZUiLKq0yDkTaxL2SvHHTwL3G6.jpg'),
(141540, 10062, 'Feed the Beast S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/96Mddn0ezTJEWdAGknLpYtBBMTM.jpg'),
(141541, 10062, 'Feed the Beast S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OotrRGbAb8yVhaMjJAmxZXZXXR.jpg'),
(141542, 10062, 'Feed the Beast S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hm2kPrLFNQ41TraF5C484bqPJkG.jpg'),
(141543, 10062, 'Feed the Beast S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/289450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3uQ73VS7vwdFayjB6F91pRAuQ7X.jpg'),
(141544, 10062, 'Feed the Beast S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/289451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eO85lOd7vy0lewFU1QKfNzhXZM1.jpg'),
(141545, 10063, 'Misterios da Arquitetura S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3fMiXNorwXnqZ32LIPZq6SwuTeU.jpg'),
(141546, 10063, 'Misterios da Arquitetura S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x31qKBLTis4aylAR1oK1Y19Mi2p.jpg'),
(141547, 10063, 'Misterios da Arquitetura S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tOHL0IBwAxa1pXVfPDfq5ZjwMvr.jpg'),
(141548, 10063, 'Misterios da Arquitetura S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cX2GPrZCWSNmy3h3qXN2Z2kBGvp.jpg'),
(141549, 10063, 'Misterios da Arquitetura S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1J8d3VoL0s8BSkhZ4QtR2qzJpmh.jpg'),
(141550, 10063, 'Misterios da Arquitetura S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/luLz8tkeqSXZZx7dCRhw9bI0F4s.jpg'),
(141551, 10064, 'Reformas Criativas com Britt e Annie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kZ6oe7k62ihQyPetpLBtGICkOrq.jpg'),
(141552, 10064, 'Reformas Criativas com Britt e Annie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nCHymB62uPPYDUf0fZq9NvqTEWq.jpg'),
(141553, 10064, 'Reformas Criativas com Britt e Annie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/unJNrQvuSqQBJPkSC30tKOyKvMC.jpg'),
(141554, 10064, 'Reformas Criativas com Britt e Annie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7vlUEEeHF0spabsweVBOXDAJFPO.jpg'),
(141555, 10064, 'Reformas Criativas com Britt e Annie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fNsidXCCEakSRFfEW5Jgj7aT1uV.jpg'),
(141556, 10064, 'Reformas Criativas com Britt e Annie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ebuZguy0MbmiWF1kHYrwn1adIS9.jpg'),
(141557, 10064, 'Reformas Criativas com Britt e Annie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/289434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pe6tPCnbYtarifYWNhaRjXww54X.jpg'),
(141558, 10064, 'Reformas Criativas com Britt e Annie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/289435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qFk9m6N6dnIUTTH0YOqk4ZuIQqO.jpg'),
(141559, 10065, 'Rojst S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udEazlmcDYQugYt5idVX60fghXO.jpg'),
(141560, 10065, 'Rojst S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9lOJ7ovpCxoM6LQxSN4xhnvCGkt.jpg'),
(141561, 10065, 'Rojst S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7f7zzKONKczjyIudMJCVmZwMng9.jpg'),
(141562, 10065, 'Rojst S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/si4xYKhwUPC1eK5EiLlvJUQl3s4.jpg'),
(141563, 10065, 'Rojst S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uiDQ5x9ixeTaqmlHEJ7kZjPnQDO.jpg'),
(141564, 10066, 'Rojst S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kfO8CWX3FfBJZixn1MHYCPHA3ms.jpg'),
(141565, 10066, 'Rojst S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wO5mVUMhqyH7Rxtk6IVbey6UW4t.jpg'),
(141566, 10066, 'Rojst S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3W5Z3OAljT7AOEL9O7oMf25DxYJ.jpg'),
(141567, 10066, 'Rojst S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q5jS8iuSwMRCUJchSiWelSOa3gi.jpg'),
(141568, 10066, 'Rojst S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/F6QP486IcD69KB737nkQanbTcb.jpg'),
(141569, 10066, 'Rojst S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tdG0X3moWZs525rls9SdfPGUWwV.jpg'),
(141570, 10067, 'Rojst S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mwb0wH3uCHYCMire8bOy7igtCc5.jpg'),
(141571, 10067, 'Rojst S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iXTgnxL7YGrPaqfKZjlXTNOunWa.jpg'),
(141572, 10067, 'Rojst S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ypdkam3Dcspdi0wFQbITnKVaaog.jpg'),
(141573, 10067, 'Rojst S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jCg0NANkj4Yj8F4imqVzV9pdL1M.jpg'),
(141574, 10067, 'Rojst S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6m49xTuomr4dRolC8oLoXyqHAo.jpg'),
(141575, 10067, 'Rojst S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p8kNfkkpW6O28gtlvl3qyzbliaL.jpg'),
(141576, 10068, 'Batalha das Solteiras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rAJcHhuxKoS1lAlbjim7QTH7Dr8.jpg'),
(141577, 10068, 'Batalha das Solteiras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6GdREr0sgioikZhQR9LChSAr0Ca.jpg'),
(141578, 10068, 'Batalha das Solteiras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xurqlKP6jRSMwa7golAlnGnOmSs.jpg'),
(141579, 10068, 'Batalha das Solteiras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3siX6pRl5RcfcBKGpC63QroXg03.jpg'),
(141580, 10068, 'Batalha das Solteiras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aY0Ji6lDYOikMcN3F5itZjQR9fa.jpg'),
(141581, 10068, 'Batalha das Solteiras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OuLv6T09QO0a6q9L9PsO3Ip2FV.jpg'),
(141582, 10069, 'O Que Estou Comendo Com Zooey Deschanel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rv4rQcG3wnRO9wVHlnATu1EHvJC.jpg'),
(141583, 10069, 'O Que Estou Comendo Com Zooey Deschanel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gmuTBOt12pNSLjpRK7VpR02chRT.jpg'),
(141584, 10069, 'O Que Estou Comendo Com Zooey Deschanel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JydcEwsDBSywqfwuK0QAgcJzhg.jpg'),
(141585, 10069, 'O Que Estou Comendo Com Zooey Deschanel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9R2C7ePxJ1aqymcn4d86ixEgR1C.jpg'),
(141586, 10069, 'O Que Estou Comendo Com Zooey Deschanel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hwAatDCLl9Ih83nT5iRXe79bHaH.jpg'),
(141587, 10069, 'O Que Estou Comendo Com Zooey Deschanel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/289404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fMMGIu0lAoXM7Zj1j41pyyhEgq2.jpg'),
(141588, 10070, 'The Vince Staples Show S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQLJtX0XPQeFrdy5LNmouKfkfGL.jpg'),
(141589, 10070, 'The Vince Staples Show S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kQIF6Sqsz0ipFRlVNhBRa3LNRIz.jpg'),
(141590, 10070, 'The Vince Staples Show S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cy4FmrWIW0YzUv8J1lboQddaTQs.jpg'),
(141591, 10070, 'The Vince Staples Show S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yBicEDIhPa30oN1VwURNYHjhBu5.jpg'),
(141592, 10070, 'The Vince Staples Show S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/289398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zwDzocfoXgBDxiUVFS8RfnykmmJ.jpg'),
(141593, 10071, 'A Dinastia New England Patriots [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2zESLrlcKFG5QYmh1Zb5hYAZ7JY.jpg'),
(141594, 10071, 'A Dinastia New England Patriots [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ncl8TuRfsuSf0QIUOEk5uzYpTxn.jpg'),
(141595, 10071, 'A Dinastia New England Patriots [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k4sx3ItDtCKjHs9RwI2a9pqk1FM.jpg'),
(141596, 10071, 'A Dinastia New England Patriots [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xOIohSBpvPOLFCPTgDKUWTuZQai.jpg'),
(141597, 10071, 'A Dinastia New England Patriots [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/290463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e2baPGXwl4KNcjXAvWglZZB4Hfr.jpg'),
(141598, 10071, 'A Dinastia New England Patriots [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/290464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7FlYWFCzwSfWqcjqK0FUY28PodL.jpg'),
(141599, 10071, 'A Dinastia New England Patriots [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/298782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u9W7zs3DTY233mfJJfUsmB0PInf.jpg'),
(141600, 10071, 'A Dinastia New England Patriots [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/298783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u9W7zs3DTY233mfJJfUsmB0PInf.jpg'),
(141601, 10071, 'A Dinastia New England Patriots [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/303143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u9W7zs3DTY233mfJJfUsmB0PInf.jpg'),
(141602, 10071, 'A Dinastia New England Patriots [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/303144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u9W7zs3DTY233mfJJfUsmB0PInf.jpg'),
(141603, 10072, 'Anti Reset [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/at5MC3EowM2qL9mXjYa3E1qxT35.jpg'),
(141604, 10072, 'Anti Reset [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1mhBP7iPtIff4PjNi2XvfI85Whu.jpg'),
(141605, 10072, 'Anti Reset [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ktPMhdknT5qorqR1lbOp8LwvP82.jpg'),
(141606, 10072, 'Anti Reset [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xUcr5n8Uv4j4YK6we4CfmB9r4ZL.jpg'),
(141607, 10072, 'Anti Reset [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/290457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rdHBtINsaUjZFsDolRKgMqVKwRb.jpg'),
(141608, 10072, 'Anti Reset [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/290458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ioiC5rjlZERlB3vcUuO0CN3zzKx.jpg'),
(141609, 10072, 'Anti Reset [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/298513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bAgU7AXQuOTXxLTgXjDVj7rmzGS.jpg'),
(141610, 10072, 'Anti Reset [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/303078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bAgU7AXQuOTXxLTgXjDVj7rmzGS.jpg'),
(141611, 10072, 'Anti Reset [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/309400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bAgU7AXQuOTXxLTgXjDVj7rmzGS.jpg'),
(141612, 10072, 'Anti Reset [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/316305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bAgU7AXQuOTXxLTgXjDVj7rmzGS.jpg'),
(141613, 10073, 'Capitalismo Americano O Culto a Riqueza [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aBSU6PDZr0azrgUCWSGh2zbw4rS.jpg'),
(141614, 10073, 'Capitalismo Americano O Culto a Riqueza [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aBSU6PDZr0azrgUCWSGh2zbw4rS.jpg'),
(141615, 10073, 'Capitalismo Americano O Culto a Riqueza [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aBSU6PDZr0azrgUCWSGh2zbw4rS.jpg'),
(141616, 10074, 'Detetive Meena [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lgs1HCIsp13msaaoR8dYMhk7hLO.jpg'),
(141617, 10074, 'Detetive Meena [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kEFJ9o7SJa3QBoqmKN9g8kgfqA.jpg'),
(141618, 10074, 'Detetive Meena [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yrq6gelsjbU1OkfNjKjHIIxGk8a.jpg'),
(141619, 10074, 'Detetive Meena [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gU6Bfhj9XfsfB37vkPKpGDzou5l.jpg'),
(141620, 10074, 'Detetive Meena [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/290446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2XqwvRItXXcVTBG4r0pjwfAmliG.jpg'),
(141621, 10074, 'Detetive Meena [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/290447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/FMFnT3LahRKV2IWEniplwJCXBw.jpg'),
(141622, 10074, 'Detetive Meena [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/290448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tpbKZPJAMmINzgVWP9L5Z1H6gm0.jpg'),
(141623, 10074, 'Detetive Meena [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/290449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qe2GIpLJ98rIb7yEhcak3M0Xjoa.jpg'),
(141624, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bvqmsqr5K0wJCyMTlzSDbb7VAPx.jpg'),
(141625, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rAkztOaSRAe5mQyZkMSDpYlkmxO.jpg'),
(141626, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eXAkyTrrtsgZrFGLPGWA288XN1x.jpg'),
(141627, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wZgC1RkoIEmYSYwpNJE257RNYVi.jpg'),
(141628, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/290416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vw2RH3J5nmbu0UDUBmw73l5J4hw.jpg'),
(141629, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/290417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wGIFIikdLJI0A8TV5FXq7vNyWQU.jpg'),
(141630, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/290418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kW32rYgobVy7055Zk8W1AxJaHIl.jpg'),
(141631, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/290419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQBpla8JjxUOLvYyf4SEfL7iuBk.jpg'),
(141632, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/290420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ild6mjEyhj43U7lO9y3Z50BtSyv.jpg'),
(141633, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/290421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qP6iTlKfwwPTvdhT5Mt7hRF2EFP.jpg'),
(141634, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/290422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kWuXk6bYMW4HJjDbRwkmO4rYQqV.jpg'),
(141635, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/290423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/usqjfkXUu0hh86qvXNhA716qwvT.jpg'),
(141636, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/290424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7DpfKHIw8r3VxWf8aBrwnKi2Jt.jpg'),
(141637, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/290425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wCeoI1Z9GLE9AdrfwFw6IMb7juq.jpg'),
(141638, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/290426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6SyCzzzkK0W23wrrmf1kmEmem6H.jpg'),
(141639, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/290427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xbXWOeBbPQKRneE3one6XK05Qr6.jpg'),
(141640, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/290428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g2KofwbgaILyciJnN9wlxiP1MEx.jpg'),
(141641, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/290429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4qZAIcx8XwI9r2n2zbhMEOyBrvo.jpg'),
(141642, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/290430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wCRNcdN9pWjfQpgXLDj00unmDjn.jpg'),
(141643, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/290431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gMZBykkELY2N80aUu66FbHIqRrd.jpg'),
(141644, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/290432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iuMmZW5u4xUTJgy7DFYHN1zrUXl.jpg'),
(141645, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/290433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ZcJaBnCZhcyDBlqXHicioEZo8g.jpg'),
(141646, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/290434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1gIOccu2P28WWPzr35RXXEncgp9.jpg'),
(141647, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/290435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glqfdQR8OwmBBcHHkBMZbSvXz82.jpg'),
(141648, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/290436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/opuhlJYiaQfznnd1bsV0EozJHmV.jpg'),
(141649, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/290437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ntUkoc7jiktgp6nyofN5IAkvW8G.jpg'),
(141650, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/290438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cup46bmFt6lLPOfLHfTEgOAVryj.jpg'),
(141651, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/290439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/moGOFgcLUhTjummQs8aUC2suXoR.jpg'),
(141652, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/290440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yECbRTj830ysC7vAUFA671I78O9.jpg'),
(141653, 10075, 'Em Meio a Uma Nevasca de Amor [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/290441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8GgPj4Ubqh22WWYRUXZRtRfUhHJ.jpg'),
(141654, 10076, 'Ghost Doctor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gsLlzKp1ec4zJsN0VWVl8xxfKuq.jpg'),
(141655, 10076, 'Ghost Doctor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tortwdYw5vLP2XYG3nVAI0Y0ckv.jpg'),
(141656, 10076, 'Ghost Doctor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mSFbTg0zDb4D334sXL6C5RoS1gR.jpg'),
(141657, 10076, 'Ghost Doctor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/305VoVrAQYRmMbot4drnHKaLGwb.jpg'),
(141658, 10076, 'Ghost Doctor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/290400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fivIpR9l7JDsAZ2NxRKTo1MotWl.jpg'),
(141659, 10076, 'Ghost Doctor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/290401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ZgRPbGBbsYLhQXfacnC3ESDgdC.jpg'),
(141660, 10076, 'Ghost Doctor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/290402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v4pBoBWY1cMhtBSRNeukpXiPPhS.jpg'),
(141661, 10076, 'Ghost Doctor [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/290403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWDcHN5PJTxgZwX5LuLEyZeNkZ6.jpg'),
(141662, 10076, 'Ghost Doctor [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/290404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/geoe1Rt2ihStbIYBX6GktqhluV.jpg'),
(141663, 10076, 'Ghost Doctor [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/290405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vATR9FAiyR93EUWggIUhgu1f8vL.jpg'),
(141664, 10076, 'Ghost Doctor [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/290406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/82z53JOiFkjBemTFNigDF73IXDP.jpg'),
(141665, 10076, 'Ghost Doctor [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/290407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wkKWdDUNAyWwOPSJpvvPwVMVoha.jpg'),
(141666, 10076, 'Ghost Doctor [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/290408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yGEFVsNsvTvxojk0BQMHL61P9Rx.jpg'),
(141667, 10076, 'Ghost Doctor [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/290409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qwjv1YmW0dLga9I5f4ZJtkuVBkw.jpg'),
(141668, 10076, 'Ghost Doctor [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/290410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nuMATQMCxCYsXGtM8GxH8TB1Fod.jpg'),
(141669, 10076, 'Ghost Doctor [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/290411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uq1LkfXRUGopDM8a93BSHLFHdBM.jpg'),
(141670, 10077, 'Law e Order Toronto Criminal Intent [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i3t253Vb5oH8tFEE87VB75mVZTB.jpg'),
(141671, 10077, 'Law e Order Toronto Criminal Intent [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/297546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rF1pmsY41NsaBc4xiUbXPX1AtjL.jpg'),
(141672, 10077, 'Law e Order Toronto Criminal Intent [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/302679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rF1pmsY41NsaBc4xiUbXPX1AtjL.jpg'),
(141673, 10077, 'Law e Order Toronto Criminal Intent [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/308620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rF1pmsY41NsaBc4xiUbXPX1AtjL.jpg'),
(141674, 10077, 'Law e Order Toronto Criminal Intent [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/312438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rF1pmsY41NsaBc4xiUbXPX1AtjL.jpg'),
(141675, 10077, 'Law e Order Toronto Criminal Intent [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/336323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rF1pmsY41NsaBc4xiUbXPX1AtjL.jpg'),
(141676, 10077, 'Law e Order Toronto Criminal Intent [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/338652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rF1pmsY41NsaBc4xiUbXPX1AtjL.jpg'),
(141677, 10077, 'Law e Order Toronto Criminal Intent [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/356288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rF1pmsY41NsaBc4xiUbXPX1AtjL.jpg'),
(141678, 10077, 'Law e Order Toronto Criminal Intent [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/356289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rF1pmsY41NsaBc4xiUbXPX1AtjL.jpg'),
(141679, 10078, 'Me Encontre Depois da Escola [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lt0WhIabuOJHBEDkQVQguTBIUJj.jpg'),
(141680, 10078, 'Me Encontre Depois da Escola [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tiV89nOiE4inGiVrunbfrmgKJYO.jpg'),
(141681, 10078, 'Me Encontre Depois da Escola [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9rv3593iOyfpAGzcDg6RP6cxgol.jpg'),
(141682, 10078, 'Me Encontre Depois da Escola [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4tkIsGCLTLvPFvDIeV7zRRuemW.jpg'),
(141683, 10078, 'Me Encontre Depois da Escola [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/290388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUnesyDRZJYyzK092bqNNVFACuu.jpg'),
(141684, 10078, 'Me Encontre Depois da Escola [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/290389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/32CC691DDPaX9GDLcJiZU6hR7Le.jpg'),
(141685, 10078, 'Me Encontre Depois da Escola [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/290390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fV5oSrHPQSwt1vRoF2P1RKntuL2.jpg'),
(141686, 10078, 'Me Encontre Depois da Escola [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/290391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ancrh3yPSXj7FMIc0SfVnmvo6Xl.jpg'),
(141687, 10078, 'Me Encontre Depois da Escola [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/290392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tg8Yz8E7D1pDdb9vsL3j98E36Fa.jpg'),
(141688, 10078, 'Me Encontre Depois da Escola [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/290393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yJgTCerGW5JKseHkSJcjE5UvGZe.jpg'),
(141689, 10078, 'Me Encontre Depois da Escola [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/290394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fG4nGCeqxRqJ7353YyNgbSUFr2C.jpg'),
(141690, 10079, 'Me Hereafter [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kRhiKeTFZQkHgd47f0EDO5wIY8m.jpg'),
(141691, 10079, 'Me Hereafter [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kAjVn5ZHHwqIMqhDwkWvi2xCzt5.jpg'),
(141692, 10079, 'Me Hereafter [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oNdNa3dErwgu3VmZdTY5hI6R9YC.jpg'),
(141693, 10079, 'Me Hereafter [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xlI3vWwACZRB4g4DtmkHiXcj6Zi.jpg'),
(141694, 10080, 'No Mundo Novamente [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c1osJooDBwAULM4Nd5d7LOL1v9Q.jpg'),
(141695, 10080, 'No Mundo Novamente [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AtSCv9W7Qt51CXO2vXiNC7WENgH.jpg'),
(141696, 10080, 'No Mundo Novamente [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bl3sQavP2vAw9PHBlwdxIlDLEgG.jpg'),
(141697, 10080, 'No Mundo Novamente [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/meIiQOGyvsw9JZQ1ClZO2HkdkNq.jpg'),
(141698, 10080, 'No Mundo Novamente [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/290344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1zGddKnuj8Eu81Arl4z47n7pvJu.jpg'),
(141699, 10080, 'No Mundo Novamente [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/290345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yIQTvuMhMwwx2B9hCy9DDNk62QQ.jpg'),
(141700, 10080, 'No Mundo Novamente [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/290346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eFhVp0UW3OktL6Ag69zkrVfdUZ1.jpg'),
(141701, 10080, 'No Mundo Novamente [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/290347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iKeSXemLnxhR1QFrDUrfUYizvnQ.jpg'),
(141702, 10080, 'No Mundo Novamente [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/290348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wg9p9B6UuI49hC3TBILs20KJYwF.jpg'),
(141703, 10080, 'No Mundo Novamente [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/290349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4e6RGza0JgPpg8YGraMjwxHEwdL.jpg'),
(141704, 10080, 'No Mundo Novamente [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/290350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yoH6NarB3koaE8IbSNaM4ynWEFj.jpg'),
(141705, 10080, 'No Mundo Novamente [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/290351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a3YzHmtXfafsrbhOWph2BCI1hOs.jpg'),
(141706, 10080, 'No Mundo Novamente [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/290352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ekKc5EnQYDQ5SdzrgEUrZxuBwsK.jpg'),
(141707, 10080, 'No Mundo Novamente [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/290353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUP3MJXSnt53M5wxutiph2N3Tom.jpg'),
(141708, 10080, 'No Mundo Novamente [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/290354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hAsfrZOEb3JjsL8IYZDa7b4VUbv.jpg'),
(141709, 10080, 'No Mundo Novamente [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/290355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBbUlmceKDOowQvGE3AA4bSmQ9f.jpg'),
(141710, 10080, 'No Mundo Novamente [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/290356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qOfVRRsrFN9uoYm28LkrXYtPUYV.jpg'),
(141711, 10080, 'No Mundo Novamente [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/290357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AiI7NnuZZNzNnT87LV0CO5j1rlT.jpg'),
(141712, 10080, 'No Mundo Novamente [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/290358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qWrMMGnXWqq3R5KP81rLHFsqLmN.jpg'),
(141713, 10080, 'No Mundo Novamente [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/290359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1HuuKKjvZKt3ez4E4lCyqcJBsN3.jpg'),
(141714, 10080, 'No Mundo Novamente [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/290360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3eZ6wR3GMZyvEDUKczkRAViCK2d.jpg'),
(141715, 10080, 'No Mundo Novamente [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/290361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rVhmhGdA5TV3KlwUFWpoQB4a4Xr.jpg'),
(141716, 10080, 'No Mundo Novamente [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/290362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xAYfCP7FoxU7UhQHMTxg9Z6zDVB.jpg'),
(141717, 10080, 'No Mundo Novamente [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/290363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6Uwk1kXQrX7Hhuo9c5XXme9kie.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(141718, 10080, 'No Mundo Novamente [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/290364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fINe6W0ySiCVtIgOlQjEkmzfCCo.jpg'),
(141719, 10080, 'No Mundo Novamente [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/290365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7kF6gS0nbQExuDPX2En5r3AxCLc.jpg'),
(141720, 10080, 'No Mundo Novamente [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/290366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/umff5OBalC3Zd61IV3hQIBzdOMi.jpg'),
(141721, 10080, 'No Mundo Novamente [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/290367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/J7PrBNWGxtpTsNWtKbvetrHBCS.jpg'),
(141722, 10080, 'No Mundo Novamente [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/290368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fBVLbN9RR8qaK5zUVhnkF5Gj2io.jpg'),
(141723, 10080, 'No Mundo Novamente [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/290369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gNdbiInc96wqFPwyL7vCSw5NcUA.jpg'),
(141724, 10080, 'No Mundo Novamente [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/290370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/reWsTXtM3ZSr9Zm12MwoaqIlXDa.jpg'),
(141725, 10080, 'No Mundo Novamente [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/290371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fB0SnKdO0CTQUg1uZ4psbYQ92Wf.jpg'),
(141726, 10080, 'No Mundo Novamente [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/290372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pQbFLgfbYKsTWdL0rC6XtKDYQCr.jpg'),
(141727, 10080, 'No Mundo Novamente [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/290373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/knqLvYDqlHW6NnAKBO9k7lCfGM9.jpg'),
(141728, 10080, 'No Mundo Novamente [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/290374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nBiwzciS7M8KGCnnL5Sa92FWbce.jpg'),
(141729, 10080, 'No Mundo Novamente [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/290375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kWNEFqsKImFKcuu6e67BLXzg3tO.jpg'),
(141730, 10080, 'No Mundo Novamente [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/290376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dnVIWTTEZ8NIA8UIriEJN2hxnHo.jpg'),
(141731, 10080, 'No Mundo Novamente [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/290377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hzew07pUIAtROO2FXgQISEHScWT.jpg'),
(141732, 10080, 'No Mundo Novamente [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/290378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2sRye9c275zl9wcB9zi0kUh3Kc.jpg'),
(141733, 10080, 'No Mundo Novamente [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/290379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/70P7xL3IeYJArLAZPvWa5ughwIu.jpg'),
(141734, 10081, 'O Regime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7V5xmSPUCMNZvUXHFPTx6ljcB6.jpg'),
(141735, 10081, 'O Regime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/297480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WivXX7DTXjUhlC465tgnkMC0aN.jpg'),
(141736, 10081, 'O Regime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/300568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WivXX7DTXjUhlC465tgnkMC0aN.jpg'),
(141737, 10081, 'O Regime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/308530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WivXX7DTXjUhlC465tgnkMC0aN.jpg'),
(141738, 10081, 'O Regime S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/315588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WivXX7DTXjUhlC465tgnkMC0aN.jpg'),
(141739, 10081, 'O Regime S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1WivXX7DTXjUhlC465tgnkMC0aN.jpg'),
(141740, 10082, 'Perdida no Tempo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/soRlD7gsDgU91OzjVbUuLCu6YRl.jpg'),
(141741, 10082, 'Perdida no Tempo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9M9Svr8yD1mr8ijGGXoyiBDKhrN.jpg'),
(141742, 10082, 'Perdida no Tempo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1CeRDVSHvxEvlbdNNFqi1Y9inve.jpg'),
(141743, 10082, 'Perdida no Tempo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bMRU2XLhKnuExnISNTcftTmlH4q.jpg'),
(141744, 10082, 'Perdida no Tempo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/290313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4eX95MNgvtkJZLjVfzjhpRQIt2d.jpg'),
(141745, 10082, 'Perdida no Tempo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/290314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9wVOEL745SOpMTtoRUjb7TR4t1K.jpg'),
(141746, 10082, 'Perdida no Tempo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/290315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cTKD3oRDBPyk47GNhhITpocCCXY.jpg'),
(141747, 10082, 'Perdida no Tempo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/290316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fQbli7GeGXtB7RXBGvaUM1rlW6g.jpg'),
(141748, 10082, 'Perdida no Tempo [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/290317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fZ0I6MiuZbOIPgmYdgox5GFkUAP.jpg'),
(141749, 10082, 'Perdida no Tempo [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/290318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4CIjxOnzrF4LY2Vur2z8j2IM2OJ.jpg'),
(141750, 10082, 'Perdida no Tempo [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/290319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6soIlyRwvJlR9zXRnsG4RRxOzet.jpg'),
(141751, 10082, 'Perdida no Tempo [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/290320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k7XspiYS9o29isINhTvqViwXM3k.jpg'),
(141752, 10082, 'Perdida no Tempo [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/290321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wrMvLETyylEw4H82yErqXgTYmRY.jpg'),
(141753, 10082, 'Perdida no Tempo [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/290322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bPvmEGjHuIUj3UFxE6wFgDjAVYm.jpg'),
(141754, 10082, 'Perdida no Tempo [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/290323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rDLGRHV7oSUMUMUJSEVyuGrhUQ8.jpg'),
(141755, 10082, 'Perdida no Tempo [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/290324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kpANyqz3LS4R0KGaSoS94Azo2LQ.jpg'),
(141756, 10082, 'Perdida no Tempo [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/290325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wAajZRtLEb7qh7LbV0Z56U3wbOk.jpg'),
(141757, 10082, 'Perdida no Tempo [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/290326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ardhZwVqBt0AwCDuHgPEeQTzp34.jpg'),
(141758, 10082, 'Perdida no Tempo [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/290327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2MXBKvdC4TqHL8VD5Et99BJbcqq.jpg'),
(141759, 10082, 'Perdida no Tempo [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/290328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rdr3bavHr7g4RrTsffBNU9J6Z5x.jpg'),
(141760, 10082, 'Perdida no Tempo [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/290329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fVsBvPDiLXFxOJgenttGjqq8i2C.jpg'),
(141761, 10082, 'Perdida no Tempo [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/290330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6BuxXtsAN91yustwd21h53EAtiq.jpg'),
(141762, 10082, 'Perdida no Tempo [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/290331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AhpZJ9kbMxUMedgkFXr8NAy9aM2.jpg'),
(141763, 10082, 'Perdida no Tempo [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/290332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/99QU6p8mL8YXiMSj3TfGQtfNYnw.jpg'),
(141764, 10082, 'Perdida no Tempo [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/290333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v0CeFvNwfg4RVjdJSHAKUsbu8f0.jpg'),
(141765, 10082, 'Perdida no Tempo [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/290334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/36ZS7T4SKR9bRha6asiIcl8R2xK.jpg'),
(141766, 10082, 'Perdida no Tempo [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/290335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nVcnscCXKpfy0YdI5XoatRudNFK.jpg'),
(141767, 10082, 'Perdida no Tempo [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/290336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zlcQ4R5CccU72WQPrnjAb95IvS6.jpg'),
(141768, 10082, 'Perdida no Tempo [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/290337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lE16Q2M8qR7KqaHE0S42japlDEO.jpg'),
(141769, 10082, 'Perdida no Tempo [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/290338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iee5yHuk2s7XWPBCAM6WeOZqTtG.jpg'),
(141770, 10083, 'Perfume [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1nHN2aJYdGUE7AURWQUyyR5oao5.jpg'),
(141771, 10083, 'Perfume [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qw1owjhovU6qNUjbF571yB5PqOR.jpg'),
(141772, 10083, 'Perfume [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vd7xdZLiy79ewlCy6OFX0m2Htqz.jpg'),
(141773, 10083, 'Perfume [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5tYHS4n7B10pF28NGMrvnn3Mp6R.jpg'),
(141774, 10083, 'Perfume [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/290281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKI2IKnOe07jJ7aF0oOoWtDugXv.jpg'),
(141775, 10083, 'Perfume [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/290282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sh98TUAJ6j2U13SmgadplisTsBG.jpg'),
(141776, 10083, 'Perfume [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/290283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gAd4qzFkyQXCnZz7pnFfSnubaUc.jpg'),
(141777, 10083, 'Perfume [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/290284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mPfEa3H4KuaN47jrrKkrfW9CjI7.jpg'),
(141778, 10083, 'Perfume [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/290285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZTkcu7oXwgjcnlOeIohOFvob0o.jpg'),
(141779, 10083, 'Perfume [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/290286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qQvbiDDJFqqoNzon1bBU3YUpPQd.jpg'),
(141780, 10083, 'Perfume [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/290287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1GcrYQVPWPhcK9XdftVRM9aFILE.jpg'),
(141781, 10083, 'Perfume [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/290288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jpaF1REEMT618cZZEWLTeQ02AJZ.jpg'),
(141782, 10083, 'Perfume [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/290289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQXTVo0KXLpQ4q9QFgGWNDw09L2.jpg'),
(141783, 10083, 'Perfume [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/290290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vYzcUpTLhfS78DVtV44wLtKsi3f.jpg'),
(141784, 10083, 'Perfume [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/290291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jAJYWj43UZR3uNEYvTqJgxr6e5h.jpg'),
(141785, 10083, 'Perfume [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/290292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zODD6OkKRp5bblXYETvgQeReUvK.jpg'),
(141786, 10083, 'Perfume [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/290293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2X46JIbjHF83I6RiovwXrwAfcNG.jpg'),
(141787, 10083, 'Perfume [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/290294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jh31ZgzEZaROLNrbzVOvOdQTyC1.jpg'),
(141788, 10083, 'Perfume [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/290295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qiYEtZQI3AJWqEWwv35uxT1EsFM.jpg'),
(141789, 10083, 'Perfume [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/290296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1NmUsPFSNYeeXg9R2PTlDkxZ0Ke.jpg'),
(141790, 10083, 'Perfume [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/290297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jE0fpbEMLYzOKxcy9Zh6epaQrTR.jpg'),
(141791, 10083, 'Perfume [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/290298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bfFLcqNcVWvCAHVfb4rGC4PWfYd.jpg'),
(141792, 10083, 'Perfume [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/290299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5IkUXuvfFIDVE3BqeX4rrH5VWxe.jpg'),
(141793, 10083, 'Perfume [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/290300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nIyY24SHcvBv4FvCseGMizt8fTZ.jpg'),
(141794, 10083, 'Perfume [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/290301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/85ChRAqkxDW59BIiIj3NuwPRa5T.jpg'),
(141795, 10083, 'Perfume [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/290302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gr0JbUZFCR7NjKaBxCm4rcGEj9b.jpg'),
(141796, 10083, 'Perfume [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/290303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eniSpygWhs79osOmUlWPL47lbRC.jpg'),
(141797, 10083, 'Perfume [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/290304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5MGIgzQm9oT4r7igVpcHxM3o4Zf.jpg'),
(141798, 10083, 'Perfume [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/290305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pOKTzPTqENEYhMRuiwska2Afbmt.jpg'),
(141799, 10083, 'Perfume [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/290306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i2neJdaFN8Vw08zczvj6jITpfNt.jpg'),
(141800, 10083, 'Perfume [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/290307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cJVnSMKOZUQoBK61iLHTzN4lFJ4.jpg'),
(141801, 10083, 'Perfume [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/290308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mCdBTevhIjrjJNv9YbnvVeJHKmC.jpg'),
(141802, 10084, 'Catastrofes da Engenharia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OCVjy5GcCbirUsEs43z187Ejo6.jpg'),
(141803, 10084, 'Catastrofes da Engenharia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fiH7digY3PBJ1HjxmR9xzKqPN7Q.jpg'),
(141804, 10084, 'Catastrofes da Engenharia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2GJsalMwDq8bPCaKjg8YfUFLHV.jpg'),
(141805, 10084, 'Catastrofes da Engenharia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lI4hcakHqaKLeITU9u64mex72AT.jpg'),
(141806, 10084, 'Catastrofes da Engenharia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/290275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/upKYZSyRAKsACfxjH4NPh4n8AAu.jpg'),
(141807, 10084, 'Catastrofes da Engenharia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/290276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hckza8x0GUj0sqWvBlqOb9FJ6bF.jpg'),
(141808, 10085, 'Misterios da natureza S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A6RVaB1dK9LLLBCd9I6SDZ7gTXA.jpg'),
(141809, 10085, 'Misterios da natureza S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/py7aRq4LCw3fixYBKMm1EShIScs.jpg'),
(141810, 10085, 'Misterios da natureza S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141811, 10085, 'Misterios da natureza S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141812, 10085, 'Misterios da natureza S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/290249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141813, 10085, 'Misterios da natureza S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/290250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141814, 10085, 'Misterios da natureza S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/290251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141815, 10085, 'Misterios da natureza S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/290252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141816, 10085, 'Misterios da natureza S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/290253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141817, 10085, 'Misterios da natureza S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/290254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141818, 10085, 'Misterios da natureza S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/290255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141819, 10085, 'Misterios da natureza S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/290256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141820, 10085, 'Misterios da natureza S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/290257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141821, 10085, 'Misterios da natureza S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/290258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141822, 10085, 'Misterios da natureza S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/290259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141823, 10085, 'Misterios da natureza S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/290260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141824, 10085, 'Misterios da natureza S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/290261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141825, 10085, 'Misterios da natureza S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/290262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141826, 10085, 'Misterios da natureza S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/290263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141827, 10085, 'Misterios da natureza S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/290264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141828, 10085, 'Misterios da natureza S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/290265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141829, 10085, 'Misterios da natureza S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/290266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141830, 10085, 'Misterios da natureza S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/290267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141831, 10085, 'Misterios da natureza S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/290268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141832, 10085, 'Misterios da natureza S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/290269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141833, 10085, 'Misterios da natureza S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/290270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMglvB7IansN1sl4TSfs4T4FyOS.jpg'),
(141834, 10086, 'O Jogo da Morte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xBQHNp0GeFVo7AkMPqW4pgIPfNT.jpg'),
(141835, 10086, 'O Jogo da Morte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNX1ciVORz3XoX33VGh9oFZQiXy.jpg'),
(141836, 10086, 'O Jogo da Morte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PMtPqi76pds24v7MTU1uHjIFzj.jpg'),
(141837, 10086, 'O Jogo da Morte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/290240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qfFgizHPVUlPSFapUCzYZ6sjkQ2.jpg'),
(141838, 10086, 'O Jogo da Morte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/290241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7y1PxmDZUCqFkKeo9lFTxVRkKU.jpg'),
(141839, 10086, 'O Jogo da Morte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/290242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tN5lUukhXBqRIf7UEE15BDYufhA.jpg'),
(141840, 10086, 'O Jogo da Morte S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/290243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kfTURRWFBhbucWLQP4N3K3T3U1X.jpg'),
(141841, 10086, 'O Jogo da Morte S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/290244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/89VeSJn2KwaFD6nfwGVMfFCX25N.jpg'),
(141842, 10087, 'The Wrong Way to Use Healing Magic S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/289872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tbJPb2oQIw7gFozF2BKdPyXppKD.jpg'),
(141843, 10087, 'The Wrong Way to Use Healing Magic S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/289873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBlDm2L6ZCd4dKmbo6w8DVyhrlG.jpg'),
(141844, 10087, 'The Wrong Way to Use Healing Magic S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/289874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jDKZlPhV14UPePQ60ENdOtWoXCz.jpg'),
(141845, 10087, 'The Wrong Way to Use Healing Magic S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/289875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z3VJtZZdmtUYuMzOsvikZFVinWn.jpg'),
(141846, 10087, 'The Wrong Way to Use Healing Magic S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/598720.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q8flNxa1vc0LMIRanVaSq7XmLcn.jpg'),
(141847, 10087, 'The Wrong Way to Use Healing Magic S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/598722.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sA9MCWAUmBDigdVWCfw8ylTEOqi.jpg'),
(141848, 10087, 'The Wrong Way to Use Healing Magic S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/295140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmnScbX505dKwpRGKoGhCsVBUw.jpg'),
(141849, 10087, 'The Wrong Way to Use Healing Magic S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/300930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmnScbX505dKwpRGKoGhCsVBUw.jpg'),
(141850, 10087, 'The Wrong Way to Use Healing Magic S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/305725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmnScbX505dKwpRGKoGhCsVBUw.jpg'),
(141851, 10087, 'The Wrong Way to Use Healing Magic S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/316951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmnScbX505dKwpRGKoGhCsVBUw.jpg'),
(141852, 10087, 'The Wrong Way to Use Healing Magic S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/320966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmnScbX505dKwpRGKoGhCsVBUw.jpg'),
(141853, 10087, 'The Wrong Way to Use Healing Magic S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/327034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmnScbX505dKwpRGKoGhCsVBUw.jpg'),
(141854, 10087, 'The Wrong Way to Use Healing Magic S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/332062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmnScbX505dKwpRGKoGhCsVBUw.jpg'),
(141855, 10088, 'Tumulos que Falam S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/290234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aWT2xfI33Ypgy6GgozunzdUNKkA.jpg'),
(141856, 10088, 'Tumulos que Falam S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/290235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aWT2xfI33Ypgy6GgozunzdUNKkA.jpg'),
(141857, 10088, 'Tumulos que Falam S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/290236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aWT2xfI33Ypgy6GgozunzdUNKkA.jpg'),
(141858, 10089, 'No Ano Que Vem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fiU3vVF6Xcsp9thXy9eCHOhtACB.jpg'),
(141859, 10089, 'No Ano Que Vem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fiU3vVF6Xcsp9thXy9eCHOhtACB.jpg'),
(141860, 10089, 'No Ano Que Vem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fiU3vVF6Xcsp9thXy9eCHOhtACB.jpg'),
(141861, 10089, 'No Ano Que Vem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fiU3vVF6Xcsp9thXy9eCHOhtACB.jpg'),
(141862, 10089, 'No Ano Que Vem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fiU3vVF6Xcsp9thXy9eCHOhtACB.jpg'),
(141863, 10090, 'Magnatas do Crime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aFko0du20Rrn7lWYF2gxAQSfrt5.jpg'),
(141864, 10090, 'Magnatas do Crime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aFko0du20Rrn7lWYF2gxAQSfrt5.jpg'),
(141865, 10090, 'Magnatas do Crime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aFko0du20Rrn7lWYF2gxAQSfrt5.jpg'),
(141866, 10090, 'Magnatas do Crime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aFko0du20Rrn7lWYF2gxAQSfrt5.jpg'),
(141867, 10090, 'Magnatas do Crime S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aFko0du20Rrn7lWYF2gxAQSfrt5.jpg'),
(141868, 10090, 'Magnatas do Crime S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aFko0du20Rrn7lWYF2gxAQSfrt5.jpg'),
(141869, 10090, 'Magnatas do Crime S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aFko0du20Rrn7lWYF2gxAQSfrt5.jpg'),
(141870, 10090, 'Magnatas do Crime S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aFko0du20Rrn7lWYF2gxAQSfrt5.jpg'),
(141871, 10091, 'Na Mira dos Sequestradores S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tQiw8f8v09lBqQWJVU7r4I319qn.jpg'),
(141872, 10091, 'Na Mira dos Sequestradores S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3bGw61pvvDSw9mEBsmFCEgT27hv.jpg'),
(141873, 10091, 'Na Mira dos Sequestradores S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/303486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5tz0oVYP8B3hRrloRRxx8epdBvh.jpg'),
(141874, 10091, 'Na Mira dos Sequestradores S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/308540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5tz0oVYP8B3hRrloRRxx8epdBvh.jpg'),
(141875, 10091, 'Na Mira dos Sequestradores S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5tz0oVYP8B3hRrloRRxx8epdBvh.jpg'),
(141876, 10091, 'Na Mira dos Sequestradores S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5tz0oVYP8B3hRrloRRxx8epdBvh.jpg'),
(141877, 10091, 'Na Mira dos Sequestradores S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/325538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5tz0oVYP8B3hRrloRRxx8epdBvh.jpg'),
(141878, 10091, 'Na Mira dos Sequestradores S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/338524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5tz0oVYP8B3hRrloRRxx8epdBvh.jpg'),
(141879, 10092, 'O Estrangulador de HillsideO Estrangulador de Hillside S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMEyboN5HgsE0uJ5haQgubr25SK.jpg'),
(141880, 10092, 'O Estrangulador de HillsideO Estrangulador de Hillside S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMEyboN5HgsE0uJ5haQgubr25SK.jpg'),
(141881, 10092, 'O Estrangulador de HillsideO Estrangulador de Hillside S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMEyboN5HgsE0uJ5haQgubr25SK.jpg'),
(141882, 10092, 'O Estrangulador de HillsideO Estrangulador de Hillside S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMEyboN5HgsE0uJ5haQgubr25SK.jpg'),
(141883, 10093, 'Rainhas do Reino Animal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7OyNqYY6rd7lDTJipVyRKaGVCV9.jpg'),
(141884, 10093, 'Rainhas do Reino Animal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tvNs3WlRpwj4YEmjILmJCfXb51m.jpg'),
(141885, 10093, 'Rainhas do Reino Animal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ZfxmUzJgzRKzIWLZKcN6cXAInx.jpg'),
(141886, 10093, 'Rainhas do Reino Animal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZnwztsj2ALzqdOQRy2trQnk51M.jpg'),
(141887, 10093, 'Rainhas do Reino Animal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xAnzySxI1Z30yXnpz1mFWwZ2TZx.jpg'),
(141888, 10093, 'Rainhas do Reino Animal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6XGGCDgAJmVWzm6uZwDHQBr9Fat.jpg'),
(141889, 10093, 'Rainhas do Reino Animal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zsBZY15zwsn3jO2CC6IgzCvJITl.jpg'),
(141890, 10094, 'Segredos que Mudaram o Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMf2M0S7wPp3wFVBysr1eNBHvUX.jpg'),
(141891, 10094, 'Segredos que Mudaram o Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMf2M0S7wPp3wFVBysr1eNBHvUX.jpg'),
(141892, 10094, 'Segredos que Mudaram o Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMf2M0S7wPp3wFVBysr1eNBHvUX.jpg'),
(141893, 10094, 'Segredos que Mudaram o Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zMf2M0S7wPp3wFVBysr1eNBHvUX.jpg'),
(141894, 10095, 'The Walking Dead Daryl Dixon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3oebI0Euvz8C4IPMAu346RcV2Gh.jpg'),
(141895, 10095, 'The Walking Dead Daryl Dixon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCTcN8Wl9Pn3BuU6sJX2fqdxomb.jpg'),
(141896, 10095, 'The Walking Dead Daryl Dixon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wSdflUF8nlcgDb6WFXRd1R7tPTC.jpg'),
(141897, 10095, 'The Walking Dead Daryl Dixon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l7Xj2excN8Ffx31qt3KTa68KKot.jpg'),
(141898, 10095, 'The Walking Dead Daryl Dixon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/296975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iuorrLyDwiOOwsCeEwtCyMOZFh8.jpg'),
(141899, 10095, 'The Walking Dead Daryl Dixon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/300961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iuorrLyDwiOOwsCeEwtCyMOZFh8.jpg'),
(141900, 10096, 'The Walking Dead Daryl Dixon S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/511028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iuorrLyDwiOOwsCeEwtCyMOZFh8.jpg'),
(141901, 10096, 'The Walking Dead Daryl Dixon S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/511029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iuorrLyDwiOOwsCeEwtCyMOZFh8.jpg'),
(141902, 10096, 'The Walking Dead Daryl Dixon S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/511030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iuorrLyDwiOOwsCeEwtCyMOZFh8.jpg'),
(141903, 10096, 'The Walking Dead Daryl Dixon S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/511031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iuorrLyDwiOOwsCeEwtCyMOZFh8.jpg'),
(141904, 10096, 'The Walking Dead Daryl Dixon S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/511032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iuorrLyDwiOOwsCeEwtCyMOZFh8.jpg'),
(141905, 10096, 'The Walking Dead Daryl Dixon S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/511033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iuorrLyDwiOOwsCeEwtCyMOZFh8.jpg'),
(141906, 10097, 'The Walking Dead Daryl Dixon S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/889714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iuorrLyDwiOOwsCeEwtCyMOZFh8.jpg'),
(141907, 10097, 'The Walking Dead Daryl Dixon S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/889715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iuorrLyDwiOOwsCeEwtCyMOZFh8.jpg'),
(141908, 10097, 'The Walking Dead Daryl Dixon S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/889716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iuorrLyDwiOOwsCeEwtCyMOZFh8.jpg'),
(141909, 10097, 'The Walking Dead Daryl Dixon S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/889717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iuorrLyDwiOOwsCeEwtCyMOZFh8.jpg'),
(141910, 10097, 'The Walking Dead Daryl Dixon S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/889718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iuorrLyDwiOOwsCeEwtCyMOZFh8.jpg'),
(141911, 10097, 'The Walking Dead Daryl Dixon S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/889719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iuorrLyDwiOOwsCeEwtCyMOZFh8.jpg'),
(141912, 10097, 'The Walking Dead Daryl Dixon S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/889720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iuorrLyDwiOOwsCeEwtCyMOZFh8.jpg'),
(141913, 10098, 'Entrevista com o Vampiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/296475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xzMasPgVLHRV3r5ulcr7Gj6JLsM.jpg'),
(141914, 10098, 'Entrevista com o Vampiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/296476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/826BuvFzp8gDyQ6UiugZ4R7Y64q.jpg'),
(141915, 10098, 'Entrevista com o Vampiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/296477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/37VEWjT1SZ4fFyxECvd0pHyn8TS.jpg'),
(141916, 10098, 'Entrevista com o Vampiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/296478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2baC5GWvP0M1iAiT4B8hI3deugx.jpg'),
(141917, 10098, 'Entrevista com o Vampiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/296479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gp6lAkvq1IkNAAPlbE6ESvVvW0b.jpg'),
(141918, 10098, 'Entrevista com o Vampiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/296480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jox3b3NTPBL9OQzmhFLayssgd79.jpg'),
(141919, 10098, 'Entrevista com o Vampiro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/296481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svpDXGC16n5RMWsBU8uSogwSsrA.jpg'),
(141920, 10099, 'Entrevista com o Vampiro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/419613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqGvWXI2kV99ejEh25AUiAHGSk9.jpg'),
(141921, 10099, 'Entrevista com o Vampiro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/419614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqGvWXI2kV99ejEh25AUiAHGSk9.jpg'),
(141922, 10099, 'Entrevista com o Vampiro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/419615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqGvWXI2kV99ejEh25AUiAHGSk9.jpg'),
(141923, 10099, 'Entrevista com o Vampiro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/419616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqGvWXI2kV99ejEh25AUiAHGSk9.jpg'),
(141924, 10099, 'Entrevista com o Vampiro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/419617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqGvWXI2kV99ejEh25AUiAHGSk9.jpg'),
(141925, 10099, 'Entrevista com o Vampiro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/419618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqGvWXI2kV99ejEh25AUiAHGSk9.jpg'),
(141926, 10099, 'Entrevista com o Vampiro S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/419619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqGvWXI2kV99ejEh25AUiAHGSk9.jpg'),
(141927, 10099, 'Entrevista com o Vampiro S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/419620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bqGvWXI2kV99ejEh25AUiAHGSk9.jpg'),
(141928, 10100, 'O Sinal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/296471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kDEyOLDecaVXdE1qgCd1Ou1tcXf.jpg'),
(141929, 10100, 'O Sinal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/296472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k89SqSaSz1HUMQ5BEydfy4OfVuh.jpg'),
(141930, 10100, 'O Sinal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/296473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3gf5TLW6GvZBtcF0cVvb4Wne5VR.jpg'),
(141931, 10100, 'O Sinal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/296474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hNTlhSmQvOPS570KqcUX0S8ZQ6Z.jpg'),
(141932, 10101, 'Supersex S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/296464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ym9W8TZH6qaLws3yXrTShZ8KGvo.jpg'),
(141933, 10101, 'Supersex S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/296465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ioHyruv7n4e0RXu1IJZobscm7Ek.jpg'),
(141934, 10101, 'Supersex S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/296466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xXFyBGfrHTpM36vNvxgRUcW8Z48.jpg'),
(141935, 10101, 'Supersex S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/296467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/prMz9B4halVgw7v0slwkt6bw1m0.jpg'),
(141936, 10101, 'Supersex S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/296468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tBJPUGN1S6lk9NgE2UJEwyPTsCX.jpg'),
(141937, 10101, 'Supersex S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/296469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fptGhyNjqKZRz5pxg6XaJNiVDLI.jpg'),
(141938, 10101, 'Supersex S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/296470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8wBPgcNPsJfPHXQE2u5fj6nmVhn.jpg'),
(141939, 10102, 'Tales of the Walking Dead S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/296458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rBVCcT5xeZAaQmaUBSmifa1JHr5.jpg'),
(141940, 10102, 'Tales of the Walking Dead S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/296459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r21wqLIHsH7KgzPpYv34tqaQAoJ.jpg'),
(141941, 10102, 'Tales of the Walking Dead S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/296460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/345CzD4b8EGvlH3WCEPr42vp0XK.jpg'),
(141942, 10102, 'Tales of the Walking Dead S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/296461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rimvdpf4wpZnZ9VhjZOUaTDU8jo.jpg'),
(141943, 10102, 'Tales of the Walking Dead S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/296462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hqC7tlqASbuKK4Mbx4Kdwbuj6Is.jpg'),
(141944, 10102, 'Tales of the Walking Dead S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/296463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dyp5SF5uVoqXD4ZVhRhwbDVRCdM.jpg'),
(141945, 10103, 'The Walking Dead Dead City S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/296452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8JuBpsni3lU3uO5gvAkqKEg8S59.jpg'),
(141946, 10103, 'The Walking Dead Dead City S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/296453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hmViAo2LyHiWIJEkLcJc15H13hn.jpg'),
(141947, 10103, 'The Walking Dead Dead City S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/296454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h0TJtfHJ2GhMZbob2smz5tR8iVX.jpg'),
(141948, 10103, 'The Walking Dead Dead City S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/296455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mkfjQfryyj2ho3LRxqt9uIIn0bk.jpg'),
(141949, 10103, 'The Walking Dead Dead City S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/296456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6mKPFdhvgYq5KGEPoWJqTTY7PUu.jpg'),
(141950, 10103, 'The Walking Dead Dead City S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/296457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tH3jltWYhKgzeQze1gqJfJtT6VO.jpg'),
(141951, 10104, 'The Walking Dead Dead City S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/789206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oC4SG9TXM0C6KUoAUv76WOvQ103.jpg'),
(141952, 10104, 'The Walking Dead Dead City S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/801948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oC4SG9TXM0C6KUoAUv76WOvQ103.jpg'),
(141953, 10104, 'The Walking Dead Dead City S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/811214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oC4SG9TXM0C6KUoAUv76WOvQ103.jpg'),
(141954, 10104, 'The Walking Dead Dead City S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/823253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oC4SG9TXM0C6KUoAUv76WOvQ103.jpg'),
(141955, 10104, 'The Walking Dead Dead City S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/823254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oC4SG9TXM0C6KUoAUv76WOvQ103.jpg'),
(141956, 10104, 'The Walking Dead Dead City S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/834998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oC4SG9TXM0C6KUoAUv76WOvQ103.jpg'),
(141957, 10104, 'The Walking Dead Dead City S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/842882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oC4SG9TXM0C6KUoAUv76WOvQ103.jpg'),
(141958, 10104, 'The Walking Dead Dead City S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/853166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oC4SG9TXM0C6KUoAUv76WOvQ103.jpg'),
(141959, 10105, 'A Igreja Oculta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPw1le71B8hFhl4onAyLIoYbn2.jpg'),
(141960, 10105, 'A Igreja Oculta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPw1le71B8hFhl4onAyLIoYbn2.jpg'),
(141961, 10105, 'A Igreja Oculta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPw1le71B8hFhl4onAyLIoYbn2.jpg'),
(141962, 10105, 'A Igreja Oculta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPw1le71B8hFhl4onAyLIoYbn2.jpg'),
(141963, 10105, 'A Igreja Oculta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPw1le71B8hFhl4onAyLIoYbn2.jpg'),
(141964, 10105, 'A Igreja Oculta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/303133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPw1le71B8hFhl4onAyLIoYbn2.jpg'),
(141965, 10105, 'A Igreja Oculta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/303134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPw1le71B8hFhl4onAyLIoYbn2.jpg'),
(141966, 10105, 'A Igreja Oculta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/305587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPw1le71B8hFhl4onAyLIoYbn2.jpg'),
(141967, 10106, 'A Troca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qL74VHbXIIIJhUi3HvpfmI6cF4m.jpg'),
(141968, 10106, 'A Troca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3sK0K9Sfr4Nd8mhvbKhFuB7twST.jpg'),
(141969, 10106, 'A Troca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qRQ3EFjtZ5GLcOQh0PS99BcUvj1.jpg'),
(141970, 10106, 'A Troca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5rW4lArV4IFZCrCCjBdfkAkcTw1.jpg'),
(141971, 10106, 'A Troca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQ6vjy28EvjtO5XwCTKxK2hd3Nz.jpg'),
(141972, 10106, 'A Troca S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m5iX086qkPAsdpygxGzBZRi2DHm.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(141973, 10106, 'A Troca S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xb7EpfwgxHV7cyhbglfP1EVHc5n.jpg'),
(141974, 10106, 'A Troca S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zsepyHV4NELQEFB2kyC14SEicpF.jpg'),
(141975, 10106, 'A Troca S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/294957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4eNJEyqbhAr8OBU82ddp9rijbwa.jpg'),
(141976, 10106, 'A Troca S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/294958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s9z59YMWxKf3Xto20Z0116D8Cz1.jpg'),
(141977, 10106, 'A Troca S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/294959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gt1YfUHrKEoMRTzRgWvy39oAWC3.jpg'),
(141978, 10106, 'A Troca S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/294960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q3s5JUuO9misB1WbqTriNrh4Xh4.jpg'),
(141979, 10106, 'A Troca S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/294961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lDubPQ1H9EehlBiKIZpShFzST4k.jpg'),
(141980, 10107, 'A Troca S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vsj2CvQT9mNm3JYXY7RisXix0Ho.jpg'),
(141981, 10107, 'A Troca S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vsj2CvQT9mNm3JYXY7RisXix0Ho.jpg'),
(141982, 10107, 'A Troca S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vsj2CvQT9mNm3JYXY7RisXix0Ho.jpg'),
(141983, 10107, 'A Troca S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vsj2CvQT9mNm3JYXY7RisXix0Ho.jpg'),
(141984, 10107, 'A Troca S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vsj2CvQT9mNm3JYXY7RisXix0Ho.jpg'),
(141985, 10107, 'A Troca S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vsj2CvQT9mNm3JYXY7RisXix0Ho.jpg'),
(141986, 10107, 'A Troca S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vsj2CvQT9mNm3JYXY7RisXix0Ho.jpg'),
(141987, 10107, 'A Troca S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vsj2CvQT9mNm3JYXY7RisXix0Ho.jpg'),
(141988, 10107, 'A Troca S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/294970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vsj2CvQT9mNm3JYXY7RisXix0Ho.jpg'),
(141989, 10107, 'A Troca S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/294971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vsj2CvQT9mNm3JYXY7RisXix0Ho.jpg'),
(141990, 10107, 'A Troca S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/294972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vsj2CvQT9mNm3JYXY7RisXix0Ho.jpg'),
(141991, 10107, 'A Troca S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/294973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vsj2CvQT9mNm3JYXY7RisXix0Ho.jpg'),
(141992, 10107, 'A Troca S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/303554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vsj2CvQT9mNm3JYXY7RisXix0Ho.jpg'),
(141993, 10108, 'Brave 10 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ww0RILQhGeQ2CFOhUhWFNpDu90j.jpg'),
(141994, 10108, 'Brave 10 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6hKmlDVH6uLS7iIdlSYWw3a9eB1.jpg'),
(141995, 10108, 'Brave 10 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r2YEvFQfCOMlFteOiGMC3yTfDI5.jpg'),
(141996, 10108, 'Brave 10 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/303512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r2YEvFQfCOMlFteOiGMC3yTfDI5.jpg'),
(141997, 10108, 'Brave 10 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/309312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r2YEvFQfCOMlFteOiGMC3yTfDI5.jpg'),
(141998, 10108, 'Brave 10 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/316212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r2YEvFQfCOMlFteOiGMC3yTfDI5.jpg'),
(141999, 10108, 'Brave 10 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/323032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r2YEvFQfCOMlFteOiGMC3yTfDI5.jpg'),
(142000, 10108, 'Brave 10 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/330767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r2YEvFQfCOMlFteOiGMC3yTfDI5.jpg'),
(142001, 10108, 'Brave 10 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/330768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r2YEvFQfCOMlFteOiGMC3yTfDI5.jpg'),
(142002, 10108, 'Brave 10 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/338989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r2YEvFQfCOMlFteOiGMC3yTfDI5.jpg'),
(142003, 10108, 'Brave 10 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/345814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r2YEvFQfCOMlFteOiGMC3yTfDI5.jpg'),
(142004, 10108, 'Brave 10 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r2YEvFQfCOMlFteOiGMC3yTfDI5.jpg'),
(142005, 10109, 'Brave 10 [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ww0RILQhGeQ2CFOhUhWFNpDu90j.jpg'),
(142006, 10109, 'Brave 10 [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6hKmlDVH6uLS7iIdlSYWw3a9eB1.jpg'),
(142007, 10109, 'Brave 10 [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r2YEvFQfCOMlFteOiGMC3yTfDI5.jpg'),
(142008, 10109, 'Brave 10 [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/303516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r2YEvFQfCOMlFteOiGMC3yTfDI5.jpg'),
(142009, 10110, 'Clas Sangue e Poder S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qQyHIYSAEseXC6B400ltyYiXLez.jpg'),
(142010, 10110, 'Clas Sangue e Poder S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9OSneLKct7VmGhOcyHBgact1ld9.jpg'),
(142011, 10110, 'Clas Sangue e Poder S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uNUGayokYWt88DaLyGxdxCDNTLe.jpg'),
(142012, 10111, 'Falas Femininas Apresenta Louca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ys6GD10iMpjhg7nLTSeV9OkJD71.jpg'),
(142013, 10112, 'Loucos por Churrasco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142014, 10112, 'Loucos por Churrasco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142015, 10112, 'Loucos por Churrasco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142016, 10112, 'Loucos por Churrasco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142017, 10112, 'Loucos por Churrasco S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142018, 10112, 'Loucos por Churrasco S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142019, 10112, 'Loucos por Churrasco S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142020, 10112, 'Loucos por Churrasco S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142021, 10112, 'Loucos por Churrasco S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/294894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142022, 10112, 'Loucos por Churrasco S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/294895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142023, 10112, 'Loucos por Churrasco S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/294896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142024, 10112, 'Loucos por Churrasco S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/294897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142025, 10112, 'Loucos por Churrasco S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/294898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142026, 10112, 'Loucos por Churrasco S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/294899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142027, 10112, 'Loucos por Churrasco S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/294900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142028, 10112, 'Loucos por Churrasco S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/294901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142029, 10113, 'Loucos por Churrasco S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142030, 10113, 'Loucos por Churrasco S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142031, 10113, 'Loucos por Churrasco S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142032, 10113, 'Loucos por Churrasco S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142033, 10113, 'Loucos por Churrasco S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142034, 10113, 'Loucos por Churrasco S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142035, 10113, 'Loucos por Churrasco S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142036, 10113, 'Loucos por Churrasco S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142037, 10113, 'Loucos por Churrasco S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/294910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142038, 10113, 'Loucos por Churrasco S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/294911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142039, 10113, 'Loucos por Churrasco S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/294912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142040, 10113, 'Loucos por Churrasco S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/294913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142041, 10114, 'Loucos por Churrasco S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142042, 10114, 'Loucos por Churrasco S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142043, 10114, 'Loucos por Churrasco S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142044, 10114, 'Loucos por Churrasco S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142045, 10114, 'Loucos por Churrasco S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142046, 10114, 'Loucos por Churrasco S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142047, 10114, 'Loucos por Churrasco S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142048, 10114, 'Loucos por Churrasco S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142049, 10114, 'Loucos por Churrasco S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/294922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142050, 10114, 'Loucos por Churrasco S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/294923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142051, 10114, 'Loucos por Churrasco S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/294924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142052, 10114, 'Loucos por Churrasco S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/294925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142053, 10114, 'Loucos por Churrasco S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/294926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142054, 10115, 'Loucos por Churrasco S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142055, 10115, 'Loucos por Churrasco S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142056, 10115, 'Loucos por Churrasco S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142057, 10115, 'Loucos por Churrasco S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142058, 10115, 'Loucos por Churrasco S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142059, 10115, 'Loucos por Churrasco S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142060, 10115, 'Loucos por Churrasco S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142061, 10115, 'Loucos por Churrasco S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142062, 10115, 'Loucos por Churrasco S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/294935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142063, 10115, 'Loucos por Churrasco S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/294936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142064, 10115, 'Loucos por Churrasco S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/294937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142065, 10115, 'Loucos por Churrasco S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/294938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142066, 10115, 'Loucos por Churrasco S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/294939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142067, 10115, 'Loucos por Churrasco S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/294940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/17gqLGN95JnxkJIeu1YAJqPu1QQ.jpg'),
(142068, 10116, 'Me Apaixonei pela Vila S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7WP8CbkK5344IpUYc37wtfMcGos.jpg'),
(142069, 10116, 'Me Apaixonei pela Vila S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqqih7kZ9EUEEGTjSeUYGyuDiWn.jpg'),
(142070, 10116, 'Me Apaixonei pela Vila S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5LqVplYNaXrLq0dyarR4jue7Hoj.jpg'),
(142071, 10116, 'Me Apaixonei pela Vila S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5fHQgRzNfIpKvCOeIZGLlFsmu3x.jpg'),
(142072, 10116, 'Me Apaixonei pela Vila S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/504IkH4SCkvWP26LrUzyOAjVzfZ.jpg'),
(142073, 10116, 'Me Apaixonei pela Vila S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/te0Rt3106tmzZNLqv7uBGlsYubv.jpg'),
(142074, 10116, 'Me Apaixonei pela Vila S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hY8LBzapQWDvdYnmi9HLhNsAqqP.jpg'),
(142075, 10116, 'Me Apaixonei pela Vila S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w4qRrwauf8cMjnYVI34sPTNZq1.jpg'),
(142076, 10116, 'Me Apaixonei pela Vila S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/294882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j72Sc1jlRRRJhZ7ssfSLi6W7bRc.jpg'),
(142077, 10116, 'Me Apaixonei pela Vila S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/294883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i70E4enuYS10j6GNLLTihrbdyi0.jpg'),
(142078, 10116, 'Me Apaixonei pela Vila S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/294884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tFCjastvaFbypsmkaaDedU3GfF.jpg'),
(142079, 10116, 'Me Apaixonei pela Vila S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/294885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f7UZSM8UL5FfGtvCAm3nyE6PRsx.jpg'),
(142080, 10117, 'Misterios no Alasca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vsHmET7A8YGXH0M1ucyDOOTvpg2.jpg'),
(142081, 10117, 'Misterios no Alasca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c6NzUAnYJHAAmlk5oc1qSx7bhGh.jpg'),
(142082, 10117, 'Misterios no Alasca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkNaIJc7zhKwXlRi2axH3b91wC9.jpg'),
(142083, 10117, 'Misterios no Alasca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iiBNCi1V5xXHpmJ4hPduMobjRlc.jpg'),
(142084, 10117, 'Misterios no Alasca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v6jehgEbKZWzwIUwZeT9Gh1L5Z7.jpg'),
(142085, 10117, 'Misterios no Alasca S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qNeFcGGf82NJy1O0G6GYhh40eVI.jpg'),
(142086, 10117, 'Misterios no Alasca S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f7GaFjnTL0euMbNuWf1RpFgF2Y0.jpg'),
(142087, 10117, 'Misterios no Alasca S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z2L3Aw9RDmpMcruij7tODi8mGnq.jpg'),
(142088, 10118, 'Mulher S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142089, 10118, 'Mulher S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142090, 10118, 'Mulher S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142091, 10118, 'Mulher S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142092, 10118, 'Mulher S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142093, 10118, 'Mulher S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142094, 10118, 'Mulher S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142095, 10118, 'Mulher S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142096, 10118, 'Mulher S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/294812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142097, 10118, 'Mulher S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/294813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142098, 10118, 'Mulher S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/294814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142099, 10118, 'Mulher S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/294815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142100, 10118, 'Mulher S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/294816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142101, 10118, 'Mulher S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/294817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142102, 10118, 'Mulher S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/294818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142103, 10118, 'Mulher S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/294819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142104, 10118, 'Mulher S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/294820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142105, 10118, 'Mulher S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/294821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142106, 10118, 'Mulher S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/294822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142107, 10118, 'Mulher S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/294823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142108, 10118, 'Mulher S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/294824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142109, 10118, 'Mulher S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/294825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142110, 10118, 'Mulher S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/294826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142111, 10118, 'Mulher S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/294827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142112, 10118, 'Mulher S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/294828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142113, 10118, 'Mulher S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/294829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142114, 10118, 'Mulher S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/294830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142115, 10118, 'Mulher S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/294831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142116, 10118, 'Mulher S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/294832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142117, 10118, 'Mulher S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/294833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142118, 10118, 'Mulher S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/294834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142119, 10118, 'Mulher S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/294835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142120, 10118, 'Mulher S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/294836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142121, 10118, 'Mulher S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/294837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142122, 10118, 'Mulher S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/294838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142123, 10118, 'Mulher S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/294839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142124, 10118, 'Mulher S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/294840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142125, 10118, 'Mulher S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/294841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142126, 10118, 'Mulher S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/294842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142127, 10118, 'Mulher S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/294843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142128, 10118, 'Mulher S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/294844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142129, 10118, 'Mulher S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/294845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142130, 10118, 'Mulher S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/294846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142131, 10118, 'Mulher S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/294847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142132, 10118, 'Mulher S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/294848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142133, 10118, 'Mulher S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/294849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142134, 10118, 'Mulher S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/294850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142135, 10118, 'Mulher S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/294851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142136, 10118, 'Mulher S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/294852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142137, 10118, 'Mulher S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/294853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142138, 10118, 'Mulher S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/294854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142139, 10118, 'Mulher S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/294855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142140, 10118, 'Mulher S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/294856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142141, 10118, 'Mulher S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/294857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142142, 10118, 'Mulher S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/294858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142143, 10118, 'Mulher S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/294859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142144, 10118, 'Mulher S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/294860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142145, 10118, 'Mulher S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/294861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142146, 10118, 'Mulher S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/294862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142147, 10118, 'Mulher S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/294863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142148, 10118, 'Mulher S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/294864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142149, 10118, 'Mulher S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/294865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sdx9SuKgmb4xXCz2tHc3pSDEocd.jpg'),
(142150, 10119, 'Operacao Fronteira Italia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oysYZcJdMC5l8OEWiSW5wJf0gyC.jpg'),
(142151, 10119, 'Operacao Fronteira Italia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/303483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oysYZcJdMC5l8OEWiSW5wJf0gyC.jpg'),
(142152, 10119, 'Operacao Fronteira Italia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/307381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oysYZcJdMC5l8OEWiSW5wJf0gyC.jpg'),
(142153, 10119, 'Operacao Fronteira Italia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/312261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oysYZcJdMC5l8OEWiSW5wJf0gyC.jpg'),
(142154, 10119, 'Operacao Fronteira Italia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/321290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oysYZcJdMC5l8OEWiSW5wJf0gyC.jpg'),
(142155, 10119, 'Operacao Fronteira Italia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/327325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oysYZcJdMC5l8OEWiSW5wJf0gyC.jpg'),
(142156, 10119, 'Operacao Fronteira Italia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/329422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oysYZcJdMC5l8OEWiSW5wJf0gyC.jpg'),
(142157, 10119, 'Operacao Fronteira Italia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/406363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oysYZcJdMC5l8OEWiSW5wJf0gyC.jpg'),
(142158, 10119, 'Operacao Fronteira Italia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/411728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oysYZcJdMC5l8OEWiSW5wJf0gyC.jpg'),
(142159, 10119, 'Operacao Fronteira Italia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/415571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oysYZcJdMC5l8OEWiSW5wJf0gyC.jpg'),
(142160, 10119, 'Operacao Fronteira Italia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/476073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oysYZcJdMC5l8OEWiSW5wJf0gyC.jpg'),
(142161, 10119, 'Operacao Fronteira Italia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/476074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oysYZcJdMC5l8OEWiSW5wJf0gyC.jpg'),
(142162, 10119, 'Operacao Fronteira Italia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/476075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oysYZcJdMC5l8OEWiSW5wJf0gyC.jpg'),
(142163, 10119, 'Operacao Fronteira Italia S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/476076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oysYZcJdMC5l8OEWiSW5wJf0gyC.jpg'),
(142164, 10120, 'Predadores do Universo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6eXhPCvJQmfx2qp9ENjjnOuSIPO.jpg'),
(142165, 10120, 'Predadores do Universo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f6KjAQ5l9EylqfW1eZGQiyLTYB9.jpg'),
(142166, 10120, 'Predadores do Universo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3bt4D68oZ8qoizHrz8CmZSTsKp.jpg'),
(142167, 10120, 'Predadores do Universo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/25KN1tPy59FYKyjUW1o4sNMBTyf.jpg'),
(142168, 10120, 'Predadores do Universo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uocpDDpRMVfB0JZtDRtuV4jR1yL.jpg'),
(142169, 10120, 'Predadores do Universo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mlG6GqsrB7vAkIr6ld4XDxuwNxZ.jpg'),
(142170, 10121, 'Shaman King Flowers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Ow8M51fsIqt21yBjxAW0OSgn9j.jpg'),
(142171, 10121, 'Shaman King Flowers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A87Yi7EpSKrCWPLL7mJIUy3X1yf.jpg'),
(142172, 10121, 'Shaman King Flowers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r4LWumhtHXu8dOIeNUPLuPtMlv9.jpg'),
(142173, 10121, 'Shaman King Flowers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ondPncSeh3yRT19fPPKLVEclepY.jpg'),
(142174, 10121, 'Shaman King Flowers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rli96cUz0uWYAYvdrssgsKsuUYd.jpg'),
(142175, 10121, 'Shaman King Flowers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/301031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wxVkoCshNRJyB9vfKVHTXOIQQeF.jpg'),
(142176, 10121, 'Shaman King Flowers S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/301032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wxVkoCshNRJyB9vfKVHTXOIQQeF.jpg'),
(142177, 10121, 'Shaman King Flowers S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/304010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wxVkoCshNRJyB9vfKVHTXOIQQeF.jpg'),
(142178, 10121, 'Shaman King Flowers S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/304011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wxVkoCshNRJyB9vfKVHTXOIQQeF.jpg'),
(142179, 10121, 'Shaman King Flowers S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/313118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wxVkoCshNRJyB9vfKVHTXOIQQeF.jpg'),
(142180, 10121, 'Shaman King Flowers S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/313119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wxVkoCshNRJyB9vfKVHTXOIQQeF.jpg'),
(142181, 10121, 'Shaman King Flowers S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/321156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wxVkoCshNRJyB9vfKVHTXOIQQeF.jpg'),
(142182, 10121, 'Shaman King Flowers S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/321157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wxVkoCshNRJyB9vfKVHTXOIQQeF.jpg'),
(142183, 10122, 'Tudo na Panela S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/294782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9WJMQVuuVVtHQXSj8v0s1UwyMWQ.jpg'),
(142184, 10122, 'Tudo na Panela S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/294783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/otgnWKQGiRkljHqYXeqqAdi7Gpz.jpg'),
(142185, 10122, 'Tudo na Panela S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/294784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dRU54XfF50XVQsI9pAMrXKTB49w.jpg'),
(142186, 10122, 'Tudo na Panela S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/294785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqdKKmGN3YwXOqPmAfJ3dtKkM6E.jpg'),
(142187, 10122, 'Tudo na Panela S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/294786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3z2Ne64TqLntKIfjNnksPk35Up1.jpg'),
(142188, 10122, 'Tudo na Panela S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/294787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dN2L3wXwSetZ3Otsc1840aPjaMi.jpg'),
(142189, 10122, 'Tudo na Panela S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/294788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/DbJF9LOiX5vduOCLGhOsfWPRls.jpg'),
(142190, 10122, 'Tudo na Panela S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/294789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/my0z0z6iOtyrfa6qAmYALHa2ugE.jpg'),
(142191, 10122, 'Tudo na Panela S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/294790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pP1p5wgBAfvONN21yaFtvLFpQc0.jpg'),
(142192, 10122, 'Tudo na Panela S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/294791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aPFRjF26WrGR314wTxDkxrf0CPk.jpg'),
(142193, 10123, 'Dragoes de Wonderhatch S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/298941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4uoxNcQpxzW70gZs8O6cyNrN0hg.jpg'),
(142194, 10123, 'Dragoes de Wonderhatch S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/298942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jRsrrxHw15cPenYhDgEMAM1OxO5.jpg'),
(142195, 10123, 'Dragoes de Wonderhatch S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mPc1QOPGgIdRHZh573BpdOKJN28.jpg'),
(142196, 10123, 'Dragoes de Wonderhatch S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/302830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5DBQgY7nqJeTudCeRH2oEZk6Av1.jpg'),
(142197, 10123, 'Dragoes de Wonderhatch S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/302831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5DBQgY7nqJeTudCeRH2oEZk6Av1.jpg'),
(142198, 10123, 'Dragoes de Wonderhatch S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/302832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5DBQgY7nqJeTudCeRH2oEZk6Av1.jpg'),
(142199, 10123, 'Dragoes de Wonderhatch S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/309011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5DBQgY7nqJeTudCeRH2oEZk6Av1.jpg'),
(142200, 10123, 'Dragoes de Wonderhatch S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/309012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5DBQgY7nqJeTudCeRH2oEZk6Av1.jpg'),
(142201, 10124, 'Segredos da NASA S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/298887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/elez6NIaKrOHebfGudrKgurbIMR.jpg'),
(142202, 10124, 'Segredos da NASA S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/298888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eP3nKAMT6PK7Ers8cxk9B4VSrlB.jpg'),
(142203, 10124, 'Segredos da NASA S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eTmEu1q761nCvjq3KvKgrgMW96S.jpg'),
(142204, 10124, 'Segredos da NASA S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/298890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j2l1Swrkq4sCFGUTwqR1BWJo0Mk.jpg'),
(142205, 10124, 'Segredos da NASA S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/298891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWbf4JAMwSBEbCon15OxHDnBhPt.jpg'),
(142206, 10124, 'Segredos da NASA S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/298892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o59nR7mrrLhLK0UPT9bRdcnEhqT.jpg'),
(142207, 10124, 'Segredos da NASA S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/298893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a1vSwHPaayK27HQ2OWCTps4hAfa.jpg'),
(142208, 10125, 'Segredos da NASA S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/298894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWEvxIkM80Bc1LHNBLlEdvecCFp.jpg'),
(142209, 10125, 'Segredos da NASA S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/298895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sGEkoqbu8l1QUtRumMWDwu1E1rW.jpg'),
(142210, 10125, 'Segredos da NASA S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7P7ob3RKlEbGrnk9wDz4js2cFjc.jpg'),
(142211, 10125, 'Segredos da NASA S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/298897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2YTl7ggcqVgtMQeOoNo2NyC0NT0.jpg'),
(142212, 10125, 'Segredos da NASA S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/298898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vPRBVNBkbQgL86QPiPlZtqIfRTe.jpg'),
(142213, 10125, 'Segredos da NASA S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/298899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4b2uzGFs91Dt9ZNKBySo0IfQDMj.jpg'),
(142214, 10125, 'Segredos da NASA S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/298900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nMQOZizDa87TTRoMGyoU4JDYbif.jpg'),
(142215, 10125, 'Segredos da NASA S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/298901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kggX0vj1xI1iYY3QGmKulnyHUMM.jpg'),
(142216, 10126, 'Segredos da NASA S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/298902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/GsfMHNRofTH4ZtGNyAxFyl7J5G.jpg'),
(142217, 10126, 'Segredos da NASA S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/298903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tlfFnTqQAMpnwllQEQcdDjBunxJ.jpg'),
(142218, 10126, 'Segredos da NASA S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k0mNCqERyrKAMI0E2JXHuUIbHhc.jpg'),
(142219, 10126, 'Segredos da NASA S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/298905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a7xnY04YzvPWpoN43HmwIxYUWyv.jpg'),
(142220, 10126, 'Segredos da NASA S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/298906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDfw25DLMqDltFPOJFFaoXszYId.jpg'),
(142221, 10126, 'Segredos da NASA S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/298907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4v9yNbzAgl5JULtwByOr79EWti5.jpg'),
(142222, 10126, 'Segredos da NASA S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/298908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDpuQAb8lRBPmhubMzbbeIFDbzr.jpg'),
(142223, 10126, 'Segredos da NASA S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/298909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t60wNuwH1jJj0S9eq0Fsoz1YecF.jpg'),
(142224, 10127, 'Segredos da NASA S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/298910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2z1xhV3e6Fn7rYIARvmZDLA7bQf.jpg'),
(142225, 10127, 'Segredos da NASA S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/298911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lvrar50dPrCjgTMI4NH44ddNqYn.jpg'),
(142226, 10127, 'Segredos da NASA S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pWnaHdeO7NxiAl978aD4RbRpnoo.jpg'),
(142227, 10127, 'Segredos da NASA S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/298913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z0LKmGIrclsKVtWIeDHYGRkJSVa.jpg'),
(142228, 10127, 'Segredos da NASA S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/298914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wANZ2QOg68qxXUym9O7cy7ucLeF.jpg'),
(142229, 10127, 'Segredos da NASA S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/298915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cq4giL0YVBGeG9Zy42BbNGClYNu.jpg'),
(142230, 10127, 'Segredos da NASA S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/298916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nBJMGPfuHrmwxbw47VkDBScwdR8.jpg'),
(142231, 10127, 'Segredos da NASA S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/298917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/znwy9I0n11dFTsKFxNt1YTu9VvM.jpg'),
(142232, 10127, 'Segredos da NASA S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/298918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6w5zVDc6YyiSQZPtJXnboZ2lKfq.jpg'),
(142233, 10127, 'Segredos da NASA S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/298919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6w5zVDc6YyiSQZPtJXnboZ2lKfq.jpg'),
(142234, 10127, 'Segredos da NASA S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/298920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6w5zVDc6YyiSQZPtJXnboZ2lKfq.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(142235, 10127, 'Segredos da NASA S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/298921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6w5zVDc6YyiSQZPtJXnboZ2lKfq.jpg'),
(142236, 10127, 'Segredos da NASA S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/298922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6w5zVDc6YyiSQZPtJXnboZ2lKfq.jpg'),
(142237, 10127, 'Segredos da NASA S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/298923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6w5zVDc6YyiSQZPtJXnboZ2lKfq.jpg'),
(142238, 10127, 'Segredos da NASA S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/298924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6w5zVDc6YyiSQZPtJXnboZ2lKfq.jpg'),
(142239, 10128, 'Segredos da NASA S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/298925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/geeWmbPyKHkCBr5OboFPUkoUShC.jpg'),
(142240, 10128, 'Segredos da NASA S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/298926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mQ06bDRUqiVEesbYzydTzHtYNv1.jpg'),
(142241, 10128, 'Segredos da NASA S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9DjFT4LHHDEtOuIwu2XHl95DLwt.jpg'),
(142242, 10128, 'Segredos da NASA S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/298928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/geTxEH4bq9M3odRe0UA9akrfyDT.jpg'),
(142243, 10128, 'Segredos da NASA S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/298929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fa3S4i4M04dh4i0Uo2weq7bWcIU.jpg'),
(142244, 10128, 'Segredos da NASA S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/298930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8PLrIFQ7l0uGSmYNYeky5mbALZw.jpg'),
(142245, 10128, 'Segredos da NASA S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/298931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kUdBjVxPl6xDxdmBvIT7hilfQFb.jpg'),
(142246, 10128, 'Segredos da NASA S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/298932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xvJmhnfrNEZue250zYNUQKCsUK9.jpg'),
(142247, 10129, 'Segredos da NASA S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/298933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zagmL1pPldmhPFQ0ineiL4TdVcW.jpg'),
(142248, 10129, 'Segredos da NASA S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/298934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/95I0yV4ClwVTnzQIJ2GcSTftTYX.jpg'),
(142249, 10129, 'Segredos da NASA S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1aEpnFsBMsBNkswskuqzV7mkwOf.jpg'),
(142250, 10129, 'Segredos da NASA S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/298936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gAQXJXMY4pVEYFttZf0BSrkGa8s.jpg'),
(142251, 10129, 'Segredos da NASA S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/298937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xbsVM1TwCSLdsy99ewRkAxIlOim.jpg'),
(142252, 10129, 'Segredos da NASA S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/298938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zS8wfnfV3tLnFGOnAQcKORHpSeV.jpg'),
(142253, 10129, 'Segredos da NASA S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/298939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ixApHskxGhuwlJDjTdiQe9wnZ4.jpg'),
(142254, 10129, 'Segredos da NASA S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/298940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gAwKochpWOHxzNUr3dpoDGz1F55.jpg'),
(142255, 6534, 'Som na Faixa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/298881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pP6u0HG51wMMcZCiOK6MYY3i6X1.jpg'),
(142256, 6534, 'Som na Faixa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/298882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2F3Eigy89prvfMBSOAnuaX6dp5e.jpg'),
(142257, 6534, 'Som na Faixa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dfw2XQNUIAELcyFEnfzjL4wHMUq.jpg'),
(142258, 6534, 'Som na Faixa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/298884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTlZcanUgr9GOtvPEz5hp75xGym.jpg'),
(142259, 6534, 'Som na Faixa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/298885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wDbdRblRzqwv0q8MpVHYoA1Dd64.jpg'),
(142260, 6534, 'Som na Faixa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/298886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6uNcShUM0XB74w7gfdffBXnYpAs.jpg'),
(142261, 10130, 'Assassinato no Campus [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/298870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7FXdkbhUZ9hseTpmzrc9FcB85It.jpg'),
(142262, 10130, 'Assassinato no Campus [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/298871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/15a96TWGS6NzkcSkWWYNGgsqcm.jpg'),
(142263, 10130, 'Assassinato no Campus [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3c2pU8t94jJWF83xfTTOTEZpqCt.jpg'),
(142264, 10130, 'Assassinato no Campus [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/298873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1IfplYtoxesFN40mWBVgwv02QMT.jpg'),
(142265, 10130, 'Assassinato no Campus [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/298874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4gV97SY2HpCnLv0UOYpdISFytKt.jpg'),
(142266, 10130, 'Assassinato no Campus [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/298875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/atqkcr5b6y1gG2XqbW9SUO8143X.jpg'),
(142267, 10131, 'Assassinato no Campus [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/298876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5aNw7mcGJqNUKBVx2ITOSEqSbga.jpg'),
(142268, 10131, 'Assassinato no Campus [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/298877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5aNw7mcGJqNUKBVx2ITOSEqSbga.jpg'),
(142269, 10131, 'Assassinato no Campus [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5aNw7mcGJqNUKBVx2ITOSEqSbga.jpg'),
(142270, 10131, 'Assassinato no Campus [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/298879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5aNw7mcGJqNUKBVx2ITOSEqSbga.jpg'),
(142271, 10131, 'Assassinato no Campus [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/298880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5aNw7mcGJqNUKBVx2ITOSEqSbga.jpg'),
(142272, 10132, 'Bakuage Sentai Boonboomger [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/298869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3UCbcl6RluNyIOzVlXKWPFQNUP.jpg'),
(142273, 10132, 'Bakuage Sentai Boonboomger [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/303518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142274, 10132, 'Bakuage Sentai Boonboomger [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/305579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142275, 10132, 'Bakuage Sentai Boonboomger [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/310784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142276, 10132, 'Bakuage Sentai Boonboomger [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/319989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142277, 10132, 'Bakuage Sentai Boonboomger [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/325202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142278, 10132, 'Bakuage Sentai Boonboomger [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/329059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142279, 10132, 'Bakuage Sentai Boonboomger [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/333947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142280, 10132, 'Bakuage Sentai Boonboomger [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/341890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142281, 10132, 'Bakuage Sentai Boonboomger [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142282, 10132, 'Bakuage Sentai Boonboomger [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142283, 10132, 'Bakuage Sentai Boonboomger [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/360363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142284, 10132, 'Bakuage Sentai Boonboomger [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/375421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142285, 10132, 'Bakuage Sentai Boonboomger [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/375422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142286, 10132, 'Bakuage Sentai Boonboomger [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/383338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142287, 10132, 'Bakuage Sentai Boonboomger [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/385078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142288, 10132, 'Bakuage Sentai Boonboomger [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/398059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142289, 10132, 'Bakuage Sentai Boonboomger [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/403713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142290, 10132, 'Bakuage Sentai Boonboomger [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/406441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142291, 10132, 'Bakuage Sentai Boonboomger [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/413001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142292, 10132, 'Bakuage Sentai Boonboomger [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/422391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142293, 10132, 'Bakuage Sentai Boonboomger [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/422392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142294, 10132, 'Bakuage Sentai Boonboomger [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/427904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142295, 10132, 'Bakuage Sentai Boonboomger [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/437543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142296, 10132, 'Bakuage Sentai Boonboomger [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/437544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142297, 10132, 'Bakuage Sentai Boonboomger [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/442839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142298, 10132, 'Bakuage Sentai Boonboomger [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/448709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142299, 10132, 'Bakuage Sentai Boonboomger [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/452816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142300, 10132, 'Bakuage Sentai Boonboomger [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/462011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142301, 10132, 'Bakuage Sentai Boonboomger [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/464701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142302, 10132, 'Bakuage Sentai Boonboomger [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/470793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142303, 10132, 'Bakuage Sentai Boonboomger [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/478958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142304, 10132, 'Bakuage Sentai Boonboomger [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/483368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142305, 10132, 'Bakuage Sentai Boonboomger [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/491561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142306, 10132, 'Bakuage Sentai Boonboomger [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/492984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142307, 10132, 'Bakuage Sentai Boonboomger [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/506411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142308, 10132, 'Bakuage Sentai Boonboomger [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/509614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142309, 10132, 'Bakuage Sentai Boonboomger [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/515736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142310, 10132, 'Bakuage Sentai Boonboomger [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/518925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142311, 10132, 'Bakuage Sentai Boonboomger [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/521387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142312, 10132, 'Bakuage Sentai Boonboomger [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/641139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142313, 10132, 'Bakuage Sentai Boonboomger [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/641140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142314, 10132, 'Bakuage Sentai Boonboomger [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/663149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142315, 10132, 'Bakuage Sentai Boonboomger [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/672229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142316, 10132, 'Bakuage Sentai Boonboomger [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/672230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142317, 10132, 'Bakuage Sentai Boonboomger [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/676115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142318, 10132, 'Bakuage Sentai Boonboomger [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/684173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142319, 10132, 'Bakuage Sentai Boonboomger [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/692425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sF4iozfFt9R6PgPPmhM16i0PLGy.jpg'),
(142320, 10133, 'Bamboo Blade [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/298865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3uxC77li6IK7A2MXB90Vm2CR7od.jpg'),
(142321, 10133, 'Bamboo Blade [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/298866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/KuNjL8HHqyY03wzU1WdHqjFiuB.jpg'),
(142322, 10133, 'Bamboo Blade [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3h92XD8iw7beRBxfVyjgNni9xA2.jpg'),
(142323, 10133, 'Bamboo Blade [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/298868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/akUCA2HBRFFr546T3Rj91HtqfGh.jpg'),
(142324, 10133, 'Bamboo Blade [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/310775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142325, 10133, 'Bamboo Blade [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/310776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142326, 10133, 'Bamboo Blade [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/310777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142327, 10133, 'Bamboo Blade [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/310778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142328, 10133, 'Bamboo Blade [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/310779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142329, 10133, 'Bamboo Blade [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/310780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142330, 10133, 'Bamboo Blade [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/312639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142331, 10133, 'Bamboo Blade [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/319039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142332, 10133, 'Bamboo Blade [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/350396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142333, 10133, 'Bamboo Blade [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/350397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142334, 10133, 'Bamboo Blade [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/350398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142335, 10133, 'Bamboo Blade [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/350399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142336, 10133, 'Bamboo Blade [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/350400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142337, 10133, 'Bamboo Blade [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/350401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142338, 10133, 'Bamboo Blade [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/350402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142339, 10133, 'Bamboo Blade [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/350403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142340, 10133, 'Bamboo Blade [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/350404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142341, 10133, 'Bamboo Blade [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/350405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142342, 10133, 'Bamboo Blade [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/350406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142343, 10133, 'Bamboo Blade [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/350407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142344, 10133, 'Bamboo Blade [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/350408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142345, 10133, 'Bamboo Blade [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/350409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dH8eCmfiYZiTmrpw412goPm7xpC.jpg'),
(142346, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/298840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tO9nDuDZFAYpe7gsmltxemfdwAC.jpg'),
(142347, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/298841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9yhwfBCXZH4n2vUL9Ru6l68KyDB.jpg'),
(142348, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cMcnBaKgPdA4mOHDJ3o7ck30J4B.jpg'),
(142349, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/298843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2jaDvYEdYDLDXfVuYqXF2LL2tSk.jpg'),
(142350, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/298844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u9A1gmE99SnQ267A25U5T7YI9Rt.jpg'),
(142351, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/298845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2zx4gPB4SpKXLWQFm1AV6fLORzR.jpg'),
(142352, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/298846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1a8x2DaL7UbGj6FH2ZaEpYzF5Ru.jpg'),
(142353, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/298847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/umbHBuuzQ8GtmPsFPmrTLnqk9pc.jpg'),
(142354, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/298848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/BOAmxyqOcNw6cHaCCafmMfa1V6.jpg'),
(142355, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/298849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QWEGtJ8RFMbsZ27EeStlW1hVfw.jpg'),
(142356, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/298850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zwHnz1VTwjI3ysbkfietFy7ufi8.jpg'),
(142357, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/298851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iaLFnQuo6ebVNtGJUrxiTXSyEtW.jpg'),
(142358, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/298852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fMX4QdS9vf33XFLTpXbKikvC7oE.jpg'),
(142359, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/298853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o0q15Mqm4RuorI5CXFR4UIRzeve.jpg'),
(142360, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/298854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xKyBWFup1HPa8aLn3V84SqGF2kt.jpg'),
(142361, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/298855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJRNhOdN9SnrCOjxm8hc1rZBkFw.jpg'),
(142362, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/298856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dQPb7yw7KyeTtnh2xhM63Ugwkj4.jpg'),
(142363, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/298857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/seCBSXRV09cdsprqBFo6a3YwoNJ.jpg'),
(142364, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/298858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gX8W4ks5BpSjpzhtEgwp2yhzarX.jpg'),
(142365, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/298859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tS8rbDjqk2hcJqoaQg1TJFVOGPJ.jpg'),
(142366, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/298860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QKCr8K2KBnQvGXbe86uJkQjNNO.jpg'),
(142367, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/298861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vVBLD9oqeE6Ql5ROkBk9vkTVwyS.jpg'),
(142368, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/298862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rzJpeVw9g8nZUrF0oMSm0uleiLS.jpg'),
(142369, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/298863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m8dsRtrAbgkZXAJtTzsb0VvYtBz.jpg'),
(142370, 10134, 'Gifuu Doudou Kanetsugu to Keiji [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/298864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hYuxANtwHt5NV4kuxfmMvTt2bsC.jpg'),
(142371, 10135, 'Minha Vez de Amar [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/298832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cERSs9la6RBALFEiUui5V2dpdpQ.jpg'),
(142372, 10135, 'Minha Vez de Amar [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/298833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZOkrkm7seRlDRiDKThOXicOH40.jpg'),
(142373, 10135, 'Minha Vez de Amar [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cs45FtCW64V4mNODmE1w6EsgUBg.jpg'),
(142374, 10135, 'Minha Vez de Amar [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/298835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1HBw5jvOYJiEuK3TH3uWKPIrSg3.jpg'),
(142375, 10135, 'Minha Vez de Amar [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/298836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LEN3RMqMi2GczMpCPO1BYrcerH.jpg'),
(142376, 10135, 'Minha Vez de Amar [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/298837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nLSdj7cI2cGMKPifQ4fH784MMWI.jpg'),
(142377, 10135, 'Minha Vez de Amar [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/298838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tbnOnyYRBQYgZSlJLVGpERfEmTC.jpg'),
(142378, 10135, 'Minha Vez de Amar [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/298839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cQIwb1QqP86tQfokQb0KxwVnt0q.jpg'),
(142379, 10136, 'Neuland [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/298826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x38EtrfN0TI5m0LNZY7b0xiNeFr.jpg'),
(142380, 10136, 'Neuland [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/298827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/erJayjAwF05AdyBz7ZN8JZTsnN3.jpg'),
(142381, 10136, 'Neuland [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1l0K6TBq1IIyxu5UeoGU536SHcm.jpg'),
(142382, 10136, 'Neuland [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/298829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sBzWD8CznqaVR1LPhozM4H05oI2.jpg'),
(142383, 10136, 'Neuland [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/298830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xPr5RZovCEXGp9roW0CZNUjuMnn.jpg'),
(142384, 10136, 'Neuland [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/298831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6pxaAkqPDVJs8f0rS2gUzTAJrrh.jpg'),
(142385, 10137, 'RuPauls Drag Race UK [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/298815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s85JCmcTKgrBuPlHEpFjJBacSud.jpg'),
(142386, 10137, 'RuPauls Drag Race UK [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/298816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4HT1B0ozCUJAcwRtI0JvVoIA5eV.jpg'),
(142387, 10137, 'RuPauls Drag Race UK [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dmpZllLtm11fyu3z0IRyIpeKlzE.jpg'),
(142388, 10137, 'RuPauls Drag Race UK [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/298818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8NtW2TWGpgwKMPOQhUPgmGZSO3T.jpg'),
(142389, 10137, 'RuPauls Drag Race UK [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/298819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t2rdgHpAfiSranle6nYVI2zDAKm.jpg'),
(142390, 10137, 'RuPauls Drag Race UK [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/298820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iRQN9vl52bNDnbtst0fao3IfuOH.jpg'),
(142391, 10138, 'RuPauls Drag Race UK [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/298821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWPsu8VyiS8B2kOOJpC0ntEcGCh.jpg'),
(142392, 10138, 'RuPauls Drag Race UK [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/298822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5bpEJFnVa2HyUJLvMmYuMei57Gr.jpg'),
(142393, 10138, 'RuPauls Drag Race UK [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eDUyaZli9U7A67MK2qWDygYqd35.jpg'),
(142394, 10138, 'RuPauls Drag Race UK [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/298824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/solwYwD3syQHRC0SsNO0gpPVm7i.jpg'),
(142395, 10138, 'RuPauls Drag Race UK [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/298825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odmedvSj62F24RILzE4RnRpKn0C.jpg'),
(142396, 10138, 'RuPauls Drag Race UK [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/317258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qpAiM1Wfd3K3jLWbPmDT2FEPxbS.jpg'),
(142397, 10138, 'RuPauls Drag Race UK [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/317259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qpAiM1Wfd3K3jLWbPmDT2FEPxbS.jpg'),
(142398, 10138, 'RuPauls Drag Race UK [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/317260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qpAiM1Wfd3K3jLWbPmDT2FEPxbS.jpg'),
(142399, 10139, 'Will Trent Agente Especial [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/298799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v2fvaiSeVejCtciYjaCldwBZ4bq.jpg'),
(142400, 10139, 'Will Trent Agente Especial [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/298800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5iczZOCmBmwphl6rTzWKKBB5Exz.jpg'),
(142401, 10139, 'Will Trent Agente Especial [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bkRXlWIBhUk5IDBt9LjCqsuI5YY.jpg'),
(142402, 10139, 'Will Trent Agente Especial [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/298802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4orG6eEy9HUs7p729XTClOUfWat.jpg'),
(142403, 10139, 'Will Trent Agente Especial [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/298803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6100vg8A7PmG3GF0liK3aIsMkHf.jpg'),
(142404, 10139, 'Will Trent Agente Especial [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/298804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jpJcJ3GpUhVpoFRK1BiSoOCgcZA.jpg'),
(142405, 10139, 'Will Trent Agente Especial [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/298805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r9fwQZ8CYdT49dGT8bSJFTodqqH.jpg'),
(142406, 10139, 'Will Trent Agente Especial [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/298806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5rvrMTvadtMCmyEPQXg8OL8owIy.jpg'),
(142407, 10139, 'Will Trent Agente Especial [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/298807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fqsShUnwLHHgdcWgXbfPpmUVq7l.jpg'),
(142408, 10139, 'Will Trent Agente Especial [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/298808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7QCdOVlyfoP7nsUYeur0SianswI.jpg'),
(142409, 10139, 'Will Trent Agente Especial [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/298809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uFyoijHofEAKxOHhVmP6bQ5FWdu.jpg'),
(142410, 10139, 'Will Trent Agente Especial [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/298810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c0tCSvo2HGylV8nO6QI1nYRvyFM.jpg'),
(142411, 10139, 'Will Trent Agente Especial [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/298811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ytFKmZT5xRItelMns3bYMqfEwPv.jpg'),
(142412, 10140, 'Will Trent Agente Especial [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/298812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vdYeQxK5CUoLfBfD39bb85UkISA.jpg'),
(142413, 10140, 'Will Trent Agente Especial [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/298813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mBSxHKqzMMWJugFPIO23uAk4kTP.jpg'),
(142414, 10140, 'Will Trent Agente Especial [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t6tkKpZpdz7etADOuD8wuI2Tk7U.jpg'),
(142415, 10140, 'Will Trent Agente Especial [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/316523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142416, 10140, 'Will Trent Agente Especial [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/327006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142417, 10140, 'Will Trent Agente Especial [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/332024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142418, 10140, 'Will Trent Agente Especial [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/342308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142419, 10140, 'Will Trent Agente Especial [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142420, 10140, 'Will Trent Agente Especial [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142421, 10140, 'Will Trent Agente Especial [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/372718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142422, 10141, 'Will Trent Agente Especial [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/667133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142423, 10141, 'Will Trent Agente Especial [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/674565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142424, 10141, 'Will Trent Agente Especial [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/686404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142425, 10141, 'Will Trent Agente Especial [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/692602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142426, 10141, 'Will Trent Agente Especial [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/715130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142427, 10141, 'Will Trent Agente Especial [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/722682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142428, 10141, 'Will Trent Agente Especial [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/752425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142429, 10141, 'Will Trent Agente Especial [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/757716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142430, 10141, 'Will Trent Agente Especial [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/769025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142431, 10141, 'Will Trent Agente Especial [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/777163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142432, 10141, 'Will Trent Agente Especial [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/777164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142433, 10141, 'Will Trent Agente Especial [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/796358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142434, 10141, 'Will Trent Agente Especial [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/863303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142435, 10141, 'Will Trent Agente Especial [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/863304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142436, 10141, 'Will Trent Agente Especial [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/863305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142437, 10141, 'Will Trent Agente Especial [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/863306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/moRgWLfWo7MlnI7rZVZxe0tkNZR.jpg'),
(142438, 10142, 'Young David [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/298794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vPgFIZO1A3uMJEZMRy6KujA26QX.jpg'),
(142439, 10142, 'Young David [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/298795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tI3ejG265yRsZV6ziiZyh4xx1Av.jpg'),
(142440, 10142, 'Young David [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/298796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g4tAhLDLRyk3joC8qxHT66v0uKT.jpg'),
(142441, 10142, 'Young David [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/298797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pxUQ4qyPCcZFy96W6WHSX6313zr.jpg'),
(142442, 10142, 'Young David [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/298798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pBv79cRVoTSLUEGNrnQblmtLgjg.jpg'),
(142443, 10143, 'Corpos Extraordinarios S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/296949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kHfGsekW6AP3QPuDKZF64ERi84r.jpg'),
(142444, 10143, 'Corpos Extraordinarios S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/296950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kHfGsekW6AP3QPuDKZF64ERi84r.jpg'),
(142445, 10143, 'Corpos Extraordinarios S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/296951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kHfGsekW6AP3QPuDKZF64ERi84r.jpg'),
(142446, 10143, 'Corpos Extraordinarios S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/296952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kHfGsekW6AP3QPuDKZF64ERi84r.jpg'),
(142447, 10144, 'Shaman King Flowers [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/296940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Ow8M51fsIqt21yBjxAW0OSgn9j.jpg'),
(142448, 10144, 'Shaman King Flowers [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/296941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A87Yi7EpSKrCWPLL7mJIUy3X1yf.jpg'),
(142449, 10144, 'Shaman King Flowers [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/296942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r4LWumhtHXu8dOIeNUPLuPtMlv9.jpg'),
(142450, 10144, 'Shaman King Flowers [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/296943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ondPncSeh3yRT19fPPKLVEclepY.jpg'),
(142451, 10144, 'Shaman King Flowers [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/296944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rli96cUz0uWYAYvdrssgsKsuUYd.jpg'),
(142452, 10144, 'Shaman King Flowers [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/296945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/csiaIPTMuqh3YNABTUILdtamNU4.jpg'),
(142453, 10144, 'Shaman King Flowers [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/296946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6460z1RZxxOBHjjApd8Fa8EamWW.jpg'),
(142454, 10144, 'Shaman King Flowers [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/296947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A0tf68w2sGao9gzYb5377Z6H1NZ.jpg'),
(142455, 10144, 'Shaman King Flowers [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/296948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBej7NTSGfhcVkNakmnTemNtDAv.jpg'),
(142456, 10144, 'Shaman King Flowers [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/303391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wxVkoCshNRJyB9vfKVHTXOIQQeF.jpg'),
(142457, 10144, 'Shaman King Flowers [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/304022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wxVkoCshNRJyB9vfKVHTXOIQQeF.jpg'),
(142458, 10144, 'Shaman King Flowers [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/313131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wxVkoCshNRJyB9vfKVHTXOIQQeF.jpg'),
(142459, 10145, 'Desafio dos Corretores S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/296939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMmublWNrNUbSYHDkd4I4bvibts.jpg'),
(142460, 10145, 'Desafio dos Corretores S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/302909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMmublWNrNUbSYHDkd4I4bvibts.jpg'),
(142461, 10145, 'Desafio dos Corretores S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/319849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMmublWNrNUbSYHDkd4I4bvibts.jpg'),
(142462, 10145, 'Desafio dos Corretores S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/319850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMmublWNrNUbSYHDkd4I4bvibts.jpg'),
(142463, 10145, 'Desafio dos Corretores S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/319851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMmublWNrNUbSYHDkd4I4bvibts.jpg'),
(142464, 10145, 'Desafio dos Corretores S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/324435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vMmublWNrNUbSYHDkd4I4bvibts.jpg'),
(142465, 10146, 'O Programa A Industria dos Internatos Abusivos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/296936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gsSYkfLleSOLspb6kR1DrQDxcWG.jpg'),
(142466, 10146, 'O Programa A Industria dos Internatos Abusivos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/296937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3VtE5loIYRRVjn7nq0yiaS5GI2.jpg'),
(142467, 10146, 'O Programa A Industria dos Internatos Abusivos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/296938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uhgx412V7mlaLVEWaaCrfDcJOYE.jpg'),
(142468, 10147, 'Odd Mom Out S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/296906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cIBNc3640Y4leCK3gBLS4Ng7Hvs.jpg'),
(142469, 10147, 'Odd Mom Out S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/296907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/auIFTKmTUAaPNsSo6mZ97RhaWD7.jpg'),
(142470, 10147, 'Odd Mom Out S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/296908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ay5bXkd55cU8o99KPc6F1SLXy1.jpg'),
(142471, 10147, 'Odd Mom Out S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/296909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AtyIoGRe1yZhsDNyQ9UwCzXZdkZ.jpg'),
(142472, 10147, 'Odd Mom Out S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/296910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oCkX4O2vf7zWTcvbp9zbvBE64xN.jpg'),
(142473, 10147, 'Odd Mom Out S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/296911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/siNC8vU8ZRgEPo9E3pqPuchCRhs.jpg'),
(142474, 10147, 'Odd Mom Out S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/296912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uRuRADdB6aVgZc2frgVIUWqGHhn.jpg'),
(142475, 10147, 'Odd Mom Out S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/296913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cHm5xly9rBCzYZ6tB4t7M7vv1Vb.jpg'),
(142476, 10147, 'Odd Mom Out S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/296914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/DCECWvTURhWQcAATwI4IxdPlxe.jpg'),
(142477, 10147, 'Odd Mom Out S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/296915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/khOUqHfRajqjcdIQyFdgMSjKBmY.jpg'),
(142478, 10148, 'Odd Mom Out S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/296916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5cXkAGKKBBkE2puVuyUXA4V4sKs.jpg'),
(142479, 10148, 'Odd Mom Out S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/296917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pBkzXUJlAr0lBlNxHnKa7asLqOK.jpg'),
(142480, 10148, 'Odd Mom Out S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/296918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8dX1QX6zL4eOyXZ18aUSrGSqKVM.jpg'),
(142481, 10148, 'Odd Mom Out S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/296919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lNS4G1DalcR1dxySAEqbMFxMtt5.jpg'),
(142482, 10148, 'Odd Mom Out S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/296920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6oMFoJKjOXkDyksV0dm8cs7SZ4.jpg'),
(142483, 10148, 'Odd Mom Out S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/296921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/D62d432odpXEJkNkF8SF9g2aaR.jpg'),
(142484, 10148, 'Odd Mom Out S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/296922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3E7ouNp7CPr7U64WGg619RHQdIZ.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(142485, 10148, 'Odd Mom Out S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/296923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzshvLekCqvdBuQonjzd1lrGMjx.jpg'),
(142486, 10148, 'Odd Mom Out S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/296924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Bi7cLkjb0QLZ7Ua5oGmyzMVv0Y.jpg'),
(142487, 10148, 'Odd Mom Out S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/296925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDVxawhG2DX39jNAgjmJhC8V8np.jpg'),
(142488, 10149, 'Odd Mom Out S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/296926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bJNBnAkTLPhaepyBkFe7iGQJlOK.jpg'),
(142489, 10149, 'Odd Mom Out S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/296927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k2mh5mjEhr5LpWHA39WB1jpignp.jpg'),
(142490, 10149, 'Odd Mom Out S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/296928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k2mh5mjEhr5LpWHA39WB1jpignp.jpg'),
(142491, 10149, 'Odd Mom Out S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/296929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k2mh5mjEhr5LpWHA39WB1jpignp.jpg'),
(142492, 10149, 'Odd Mom Out S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/296930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k2mh5mjEhr5LpWHA39WB1jpignp.jpg'),
(142493, 10149, 'Odd Mom Out S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/296931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k2mh5mjEhr5LpWHA39WB1jpignp.jpg'),
(142494, 10149, 'Odd Mom Out S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/296932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k2mh5mjEhr5LpWHA39WB1jpignp.jpg'),
(142495, 10149, 'Odd Mom Out S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/296933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k2mh5mjEhr5LpWHA39WB1jpignp.jpg'),
(142496, 10149, 'Odd Mom Out S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/296934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k2mh5mjEhr5LpWHA39WB1jpignp.jpg'),
(142497, 10149, 'Odd Mom Out S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/296935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k2mh5mjEhr5LpWHA39WB1jpignp.jpg'),
(142498, 10150, 'Irracional A Ciencia do Crime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/296899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bB8x9solwoMnsZayLM6iz4iiGG9.jpg'),
(142499, 10150, 'Irracional A Ciencia do Crime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/296900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fxxae5GLbVvOglBPZDbK3UDavwi.jpg'),
(142500, 10150, 'Irracional A Ciencia do Crime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/296901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oRhzLQIXCjX46MkfDKWUUPJV8nr.jpg'),
(142501, 10150, 'Irracional A Ciencia do Crime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/296902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gPt431A5nRZtavsAx26cAaHQusZ.jpg'),
(142502, 10150, 'Irracional A Ciencia do Crime S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/296903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rnDgv1H54mMn7UcTWjUkAR1g4Ll.jpg'),
(142503, 10150, 'Irracional A Ciencia do Crime S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/296904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ie6ZyV7TYQylCAjI35vBZ9jkofd.jpg'),
(142504, 10150, 'Irracional A Ciencia do Crime S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/296905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4eAlh90UdRq5CRRexlxh9E6qQWl.jpg'),
(142505, 10150, 'Irracional A Ciencia do Crime S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/349289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fWeFeaUvM3WZPxRoIyggfoiosFP.jpg'),
(142506, 10150, 'Irracional A Ciencia do Crime S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/349290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fWeFeaUvM3WZPxRoIyggfoiosFP.jpg'),
(142507, 10150, 'Irracional A Ciencia do Crime S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/349291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fWeFeaUvM3WZPxRoIyggfoiosFP.jpg'),
(142508, 10150, 'Irracional A Ciencia do Crime S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/349292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fWeFeaUvM3WZPxRoIyggfoiosFP.jpg'),
(142509, 10151, 'Academia de Giuseppe S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/299514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKdSA5YHKfFgNmEX7fgaObzprLZ.jpg'),
(142510, 10151, 'Academia de Giuseppe S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/299515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKdSA5YHKfFgNmEX7fgaObzprLZ.jpg'),
(142511, 10151, 'Academia de Giuseppe S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/299516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKdSA5YHKfFgNmEX7fgaObzprLZ.jpg'),
(142512, 10151, 'Academia de Giuseppe S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/299517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKdSA5YHKfFgNmEX7fgaObzprLZ.jpg'),
(142513, 10151, 'Academia de Giuseppe S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/299518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKdSA5YHKfFgNmEX7fgaObzprLZ.jpg'),
(142514, 10151, 'Academia de Giuseppe S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/299519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKdSA5YHKfFgNmEX7fgaObzprLZ.jpg'),
(142515, 10151, 'Academia de Giuseppe S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/299520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKdSA5YHKfFgNmEX7fgaObzprLZ.jpg'),
(142516, 10151, 'Academia de Giuseppe S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/299521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKdSA5YHKfFgNmEX7fgaObzprLZ.jpg'),
(142517, 10151, 'Academia de Giuseppe S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/299522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKdSA5YHKfFgNmEX7fgaObzprLZ.jpg'),
(142518, 10151, 'Academia de Giuseppe S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/299523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKdSA5YHKfFgNmEX7fgaObzprLZ.jpg'),
(142519, 10151, 'Academia de Giuseppe S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/299524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKdSA5YHKfFgNmEX7fgaObzprLZ.jpg'),
(142520, 10151, 'Academia de Giuseppe S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/299525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKdSA5YHKfFgNmEX7fgaObzprLZ.jpg'),
(142521, 10151, 'Academia de Giuseppe S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/299526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rKdSA5YHKfFgNmEX7fgaObzprLZ.jpg'),
(142522, 10152, 'As Garotas do Onibus Jornalistas de Campanha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/299512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vRrnzDjL4t8RGmFeB5woTcEPNMX.jpg'),
(142523, 10152, 'As Garotas do Onibus Jornalistas de Campanha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/299513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cesfccqj8ct2iakPNAMZaUlYBs1.jpg'),
(142524, 10152, 'As Garotas do Onibus Jornalistas de Campanha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c75gEMVMws14EvBiCpjXltSjxtp.jpg'),
(142525, 10152, 'As Garotas do Onibus Jornalistas de Campanha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/313404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c75gEMVMws14EvBiCpjXltSjxtp.jpg'),
(142526, 10152, 'As Garotas do Onibus Jornalistas de Campanha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/319994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c75gEMVMws14EvBiCpjXltSjxtp.jpg'),
(142527, 10152, 'As Garotas do Onibus Jornalistas de Campanha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/326323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c75gEMVMws14EvBiCpjXltSjxtp.jpg'),
(142528, 10152, 'As Garotas do Onibus Jornalistas de Campanha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c75gEMVMws14EvBiCpjXltSjxtp.jpg'),
(142529, 10152, 'As Garotas do Onibus Jornalistas de Campanha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/333959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c75gEMVMws14EvBiCpjXltSjxtp.jpg'),
(142530, 10152, 'As Garotas do Onibus Jornalistas de Campanha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/345828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c75gEMVMws14EvBiCpjXltSjxtp.jpg'),
(142531, 10152, 'As Garotas do Onibus Jornalistas de Campanha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/349624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c75gEMVMws14EvBiCpjXltSjxtp.jpg'),
(142532, 10153, 'Bandidos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/299505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rzMMbl0WnKjIeXE0zMIGvHR1oE.jpg'),
(142533, 10153, 'Bandidos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/299506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tg1QInqPq3oigc8fLeIs9kCXoaF.jpg'),
(142534, 10153, 'Bandidos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/299507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cSUsE4tTCioCFZxpqZInLCUPY2N.jpg'),
(142535, 10153, 'Bandidos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/299508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVMFMwDRgUYTHzABKqlcbXA0SQR.jpg'),
(142536, 10153, 'Bandidos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/299509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qGDFt2xsofn9pnjtlvlWnJqdBkG.jpg'),
(142537, 10153, 'Bandidos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/299510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i4CGkVfsH8aEefp2BbzOLVYdU32.jpg'),
(142538, 10153, 'Bandidos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/299511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p94yAd8ruNCjUAD7jFw9tKbeJ3B.jpg'),
(142539, 10154, 'Bandidos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/659784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uc3hkNY2bsmeE3omhcbZzoCe1vv.jpg'),
(142540, 10154, 'Bandidos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/659785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uc3hkNY2bsmeE3omhcbZzoCe1vv.jpg'),
(142541, 10154, 'Bandidos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/659786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uc3hkNY2bsmeE3omhcbZzoCe1vv.jpg'),
(142542, 10154, 'Bandidos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/659787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uc3hkNY2bsmeE3omhcbZzoCe1vv.jpg'),
(142543, 10154, 'Bandidos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/659788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uc3hkNY2bsmeE3omhcbZzoCe1vv.jpg'),
(142544, 10154, 'Bandidos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/659789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uc3hkNY2bsmeE3omhcbZzoCe1vv.jpg'),
(142545, 10154, 'Bandidos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/659790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uc3hkNY2bsmeE3omhcbZzoCe1vv.jpg'),
(142546, 10155, 'Justica Criminal Estados Unidos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/299503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2U7LnhTydxKIFMx3wXVmajucSy.jpg'),
(142547, 10155, 'Justica Criminal Estados Unidos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/299504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2U7LnhTydxKIFMx3wXVmajucSy.jpg'),
(142548, 10155, 'Justica Criminal Estados Unidos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2U7LnhTydxKIFMx3wXVmajucSy.jpg'),
(142549, 10155, 'Justica Criminal Estados Unidos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2U7LnhTydxKIFMx3wXVmajucSy.jpg'),
(142550, 10155, 'Justica Criminal Estados Unidos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/315825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2U7LnhTydxKIFMx3wXVmajucSy.jpg'),
(142551, 10155, 'Justica Criminal Estados Unidos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/315826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2U7LnhTydxKIFMx3wXVmajucSy.jpg'),
(142552, 10156, 'No Caminho S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/299499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/snndRuDXQyctRLwhu6nPujVc1kl.jpg'),
(142553, 10156, 'No Caminho S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/299500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f16LLfVGch33uaK31xuowoeqLvQ.jpg'),
(142554, 10156, 'No Caminho S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/299502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oTeP4vP2CAC7dmmIjaasA1SmKqQ.jpg'),
(142555, 10157, 'Ponto de Virada A Bomba e a Guerra Fria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/299490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5xwHKwDlmy8TUndwCRx6TU1w6m.jpg'),
(142556, 10157, 'Ponto de Virada A Bomba e a Guerra Fria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/299491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b9s1u4rIUqwcrK2cj0ti4WEgcVV.jpg'),
(142557, 10157, 'Ponto de Virada A Bomba e a Guerra Fria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/299492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8dtzoScqpb346qtfrTiQZVM9mIg.jpg'),
(142558, 10157, 'Ponto de Virada A Bomba e a Guerra Fria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/299493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3eazdRmYDhFrrwp9BVV28plkm3x.jpg'),
(142559, 10157, 'Ponto de Virada A Bomba e a Guerra Fria S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/299494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vr7y21Y5SVYqiYWhbJiDcIUDrHH.jpg'),
(142560, 10157, 'Ponto de Virada A Bomba e a Guerra Fria S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/299495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dbRwKMiL5T5TZSj3UdqGuMMU0vG.jpg'),
(142561, 10157, 'Ponto de Virada A Bomba e a Guerra Fria S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/299496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mlwzJYEvMhtiFn5tUbFcNeOVOV2.jpg'),
(142562, 10157, 'Ponto de Virada A Bomba e a Guerra Fria S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/299497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wxW106wuHocRthQFwxavRYDI6oS.jpg'),
(142563, 10157, 'Ponto de Virada A Bomba e a Guerra Fria S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/299498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gesRIJ7rT3skFzKKcuOl9pdCaw4.jpg'),
(142564, 10158, 'Projeto Lazaro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/299487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kIu4vbVZTSJBwhHoz5z5RESP9hk.jpg'),
(142565, 10158, 'Projeto Lazaro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/299488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ppF4b7rmPN49T1QZrJlaTwae63m.jpg'),
(142566, 10158, 'Projeto Lazaro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/299489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1eQaBJUBDoxivm3uiiiEzyiFT9d.jpg'),
(142567, 10158, 'Projeto Lazaro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/303395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xw7GkWtmPQDU8qzfKshFEN038sj.jpg'),
(142568, 10158, 'Projeto Lazaro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/307334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xw7GkWtmPQDU8qzfKshFEN038sj.jpg'),
(142569, 10158, 'Projeto Lazaro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xw7GkWtmPQDU8qzfKshFEN038sj.jpg'),
(142570, 10158, 'Projeto Lazaro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/320711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xw7GkWtmPQDU8qzfKshFEN038sj.jpg'),
(142571, 10158, 'Projeto Lazaro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/329345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xw7GkWtmPQDU8qzfKshFEN038sj.jpg'),
(142572, 10159, 'Projeto Lazaro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/411690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xw7GkWtmPQDU8qzfKshFEN038sj.jpg'),
(142573, 10159, 'Projeto Lazaro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/414634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xw7GkWtmPQDU8qzfKshFEN038sj.jpg'),
(142574, 10159, 'Projeto Lazaro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/423296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xw7GkWtmPQDU8qzfKshFEN038sj.jpg'),
(142575, 10159, 'Projeto Lazaro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/426890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xw7GkWtmPQDU8qzfKshFEN038sj.jpg'),
(142576, 10159, 'Projeto Lazaro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/429188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xw7GkWtmPQDU8qzfKshFEN038sj.jpg'),
(142577, 10159, 'Projeto Lazaro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xw7GkWtmPQDU8qzfKshFEN038sj.jpg'),
(142578, 10159, 'Projeto Lazaro S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/441543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xw7GkWtmPQDU8qzfKshFEN038sj.jpg'),
(142579, 10159, 'Projeto Lazaro S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/451240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xw7GkWtmPQDU8qzfKshFEN038sj.jpg'),
(142580, 10160, 'Supernatural Academy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/299471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gFT2J1I4saZZ4dNND0fkPSjwOn6.jpg'),
(142581, 10160, 'Supernatural Academy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/299472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cy7fvOVqpdgd5ajOt7IaYoQFmmM.jpg'),
(142582, 10160, 'Supernatural Academy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/299473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vIwjdwGNCyFGwGokPM4IuC22uTG.jpg'),
(142583, 10160, 'Supernatural Academy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/299474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5eFBE7wb7kNaH1D04s3nCoaMDRP.jpg'),
(142584, 10160, 'Supernatural Academy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/299475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/65GwIYmlKHm8AYdcCqgGrUr9MoH.jpg'),
(142585, 10160, 'Supernatural Academy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/299476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2qHKeVZrEg5javOqzxSAkDuvWMk.jpg'),
(142586, 10160, 'Supernatural Academy S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/299477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/buihVu6hO9gkzOy2O61oK4X9bhz.jpg'),
(142587, 10160, 'Supernatural Academy S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/299478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyqGDqz82t8yCsayEklTMJteeuC.jpg'),
(142588, 10160, 'Supernatural Academy S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/299479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1uvwhrG2SoBG4ApE0rSdpP68p4A.jpg'),
(142589, 10160, 'Supernatural Academy S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/299480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hkTj9xs69q5FgmsW3eUWOCioGvA.jpg'),
(142590, 10160, 'Supernatural Academy S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/299481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9hwLLMUgtF2b4XES2YTcdYFc6dh.jpg'),
(142591, 10160, 'Supernatural Academy S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/299482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/93kbgUBz180j6SJQkKBVLHkaYQX.jpg'),
(142592, 10160, 'Supernatural Academy S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/299483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1XQNNnc6vOMDE7CS34ihoelWpYJ.jpg'),
(142593, 10160, 'Supernatural Academy S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/299484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7RRxmxhAGfxmdtb4db1hydK1P0l.jpg'),
(142594, 10160, 'Supernatural Academy S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/299485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hp02Nnai3ucVgkjGxgZfr0aClqz.jpg'),
(142595, 10160, 'Supernatural Academy S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/299486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nwBOGYJYagGdXqjOhpLc8bpSc80.jpg'),
(142596, 10161, 'Anjos caem as vezes [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gYcbA1ztVAxlrshJDPIBUSt6aqL.jpg'),
(142597, 10161, 'Anjos caem as vezes [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/300533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bo7TsqRzj1Q4teUVbMlpFatvMW9.jpg'),
(142598, 10161, 'Anjos caem as vezes [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/300534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pbQxSvvkbgKbxLriPNbADuuzgx2.jpg'),
(142599, 10161, 'Anjos caem as vezes [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/300535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hg9hnF5t6YTfNXnfhJ3zO0eXPWD.jpg'),
(142600, 10161, 'Anjos caem as vezes [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/300536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vdDE24tzbUwYkKvkcKjrjst7aMX.jpg'),
(142601, 10161, 'Anjos caem as vezes [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/300537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fr3jte1v1go6qVDexgR9Eo1xd6O.jpg'),
(142602, 10161, 'Anjos caem as vezes [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/300538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j0U5i1GTjcRATrjEtKUHHYa9XZU.jpg'),
(142603, 10161, 'Anjos caem as vezes [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/300539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qrGs1gMyxxnbh60QZj4miFP9F5P.jpg'),
(142604, 10161, 'Anjos caem as vezes [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/300540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lSaFtsLiKj1GMDRpxhZa0oLBcx0.jpg'),
(142605, 10161, 'Anjos caem as vezes [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/300541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o1fY6gFrWsJGOrHgdPVxLvRW4Ws.jpg'),
(142606, 10161, 'Anjos caem as vezes [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/300542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/981SQ5NtkszTQvgi07vOfffmTmL.jpg'),
(142607, 10161, 'Anjos caem as vezes [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/300543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8nqGu6lMYNtrAaRVpvfUA2bW5D.jpg'),
(142608, 10161, 'Anjos caem as vezes [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/300544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aOPWjFCXp2ZOGKLsYpHesrjSjKx.jpg'),
(142609, 10161, 'Anjos caem as vezes [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/300545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i27aa3vvnx5NTmeNAup5x2Q68Mh.jpg'),
(142610, 10161, 'Anjos caem as vezes [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/300546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bI6YFgca7oJvWvlD0VV9UOXd6Ee.jpg'),
(142611, 10161, 'Anjos caem as vezes [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/306324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQcBzOUuYYAINOIoOIBxl2Y2qyO.jpg'),
(142612, 10161, 'Anjos caem as vezes [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/306325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQcBzOUuYYAINOIoOIBxl2Y2qyO.jpg'),
(142613, 10161, 'Anjos caem as vezes [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/306326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQcBzOUuYYAINOIoOIBxl2Y2qyO.jpg'),
(142614, 10161, 'Anjos caem as vezes [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/306327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQcBzOUuYYAINOIoOIBxl2Y2qyO.jpg'),
(142615, 10161, 'Anjos caem as vezes [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/306328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQcBzOUuYYAINOIoOIBxl2Y2qyO.jpg'),
(142616, 10161, 'Anjos caem as vezes [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/306329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQcBzOUuYYAINOIoOIBxl2Y2qyO.jpg'),
(142617, 10161, 'Anjos caem as vezes [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/306330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQcBzOUuYYAINOIoOIBxl2Y2qyO.jpg'),
(142618, 10161, 'Anjos caem as vezes [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/306331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQcBzOUuYYAINOIoOIBxl2Y2qyO.jpg'),
(142619, 10161, 'Anjos caem as vezes [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/306332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tQcBzOUuYYAINOIoOIBxl2Y2qyO.jpg'),
(142620, 10162, 'Arctic Ascent with Alex Honnold S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zAiCdg0dipMisrt20IPO9gCU02k.jpg'),
(142621, 10162, 'Arctic Ascent with Alex Honnold S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/300530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bjXgQBxC7v9sug3PwJxTJHwmwTc.jpg'),
(142622, 10162, 'Arctic Ascent with Alex Honnold S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/300531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dlPGp0ktfGY2Z71AkkHvaM8ZAso.jpg'),
(142623, 10163, 'Chicken Nugget S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x98wkGz96AGJ9olSZVjIpP2Uxn1.jpg'),
(142624, 10163, 'Chicken Nugget S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/300520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xmqbV2eiRHz0F1UO5L5Bxt3RGpE.jpg'),
(142625, 10163, 'Chicken Nugget S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/300521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mRkPYYyuai1z1u7Szn54dt9bv74.jpg'),
(142626, 10163, 'Chicken Nugget S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/300522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rtJQtIWVdgWJQ2UesVI9Mtg5Bg3.jpg'),
(142627, 10163, 'Chicken Nugget S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/300523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sMUWyfJB3uD8cceMImARZoysdy2.jpg'),
(142628, 10163, 'Chicken Nugget S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/300524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3zHCgvjIcEPMCBIgMHGjBT3McPi.jpg'),
(142629, 10163, 'Chicken Nugget S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/300525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nfL3mtEizs7E3dMimito2doftN6.jpg'),
(142630, 10163, 'Chicken Nugget S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/300526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uP0yszHVdCab8YcOuQHWAxbGrwl.jpg'),
(142631, 10163, 'Chicken Nugget S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/300527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/PmPnryDZN1YEjbYlpPYnVoeNhP.jpg'),
(142632, 10163, 'Chicken Nugget S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/300528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a1IO7Oy3NJKqvQwLXuk78HgmPdp.jpg'),
(142633, 10164, 'Crime em Tempo Real S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rWzz7pF5s768NE5FcXnnnkHLyrd.jpg'),
(142634, 10164, 'Crime em Tempo Real S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/300514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/prWppOYroZawAsVDH74TwMGllyP.jpg'),
(142635, 10164, 'Crime em Tempo Real S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/300515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/omMRxj3gxa0aFd0vjXlWVoi9JSJ.jpg'),
(142636, 10164, 'Crime em Tempo Real S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/300516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rVXGRxV5DNcVJuUsAcvwZJkq6qG.jpg'),
(142637, 10164, 'Crime em Tempo Real S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/300517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7S9xmLmUGkwpL31QfW9Yp9TAdns.jpg'),
(142638, 10164, 'Crime em Tempo Real S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/300518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/90iTP1bHdsAaNR36zeqP00rfpt6.jpg'),
(142639, 10165, 'Enigmas da Historia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jNFYavzZDZllMqinomct9mY3N4O.jpg'),
(142640, 10165, 'Enigmas da Historia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/300509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jNFYavzZDZllMqinomct9mY3N4O.jpg'),
(142641, 10165, 'Enigmas da Historia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/300510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jNFYavzZDZllMqinomct9mY3N4O.jpg'),
(142642, 10165, 'Enigmas da Historia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/300511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jNFYavzZDZllMqinomct9mY3N4O.jpg'),
(142643, 10165, 'Enigmas da Historia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/300512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jNFYavzZDZllMqinomct9mY3N4O.jpg'),
(142644, 10165, 'Enigmas da Historia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jNFYavzZDZllMqinomct9mY3N4O.jpg'),
(142645, 10165, 'Enigmas da Historia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jNFYavzZDZllMqinomct9mY3N4O.jpg'),
(142646, 10165, 'Enigmas da Historia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/313303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jNFYavzZDZllMqinomct9mY3N4O.jpg'),
(142647, 10165, 'Enigmas da Historia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/313304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jNFYavzZDZllMqinomct9mY3N4O.jpg'),
(142648, 10165, 'Enigmas da Historia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/313305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jNFYavzZDZllMqinomct9mY3N4O.jpg'),
(142649, 10165, 'Enigmas da Historia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/313306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jNFYavzZDZllMqinomct9mY3N4O.jpg'),
(142650, 10165, 'Enigmas da Historia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/313307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jNFYavzZDZllMqinomct9mY3N4O.jpg'),
(142651, 10166, 'Gwed [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kramNlrNO7mUUEBKc2et7626OuN.jpg'),
(142652, 10166, 'Gwed [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hB4MZi1pVunt8yfkhkbAPAzVS3.jpg'),
(142653, 10166, 'Gwed [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hB4MZi1pVunt8yfkhkbAPAzVS3.jpg'),
(142654, 10166, 'Gwed [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hB4MZi1pVunt8yfkhkbAPAzVS3.jpg'),
(142655, 10166, 'Gwed [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hB4MZi1pVunt8yfkhkbAPAzVS3.jpg'),
(142656, 10166, 'Gwed [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/325716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hB4MZi1pVunt8yfkhkbAPAzVS3.jpg'),
(142657, 10167, 'Historia do Comunismo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eWfqKtpFOwfKkjBz8Psqsv9KYkM.jpg'),
(142658, 10167, 'Historia do Comunismo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/300505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eWfqKtpFOwfKkjBz8Psqsv9KYkM.jpg'),
(142659, 10167, 'Historia do Comunismo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/300506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eWfqKtpFOwfKkjBz8Psqsv9KYkM.jpg'),
(142660, 10167, 'Historia do Comunismo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eWfqKtpFOwfKkjBz8Psqsv9KYkM.jpg'),
(142661, 10167, 'Historia do Comunismo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eWfqKtpFOwfKkjBz8Psqsv9KYkM.jpg'),
(142662, 10167, 'Historia do Comunismo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/387409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eWfqKtpFOwfKkjBz8Psqsv9KYkM.jpg'),
(142663, 10168, 'Lucky Hank S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6BuGcpN7JKvrtOfb3O2x0SZSvXA.jpg'),
(142664, 10168, 'Lucky Hank S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/310019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eKYPaXerPYUhmCsGlk8KlGkrIc9.jpg'),
(142665, 10168, 'Lucky Hank S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/315648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eKYPaXerPYUhmCsGlk8KlGkrIc9.jpg'),
(142666, 10168, 'Lucky Hank S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/320727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eKYPaXerPYUhmCsGlk8KlGkrIc9.jpg'),
(142667, 10168, 'Lucky Hank S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/326787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eKYPaXerPYUhmCsGlk8KlGkrIc9.jpg'),
(142668, 10168, 'Lucky Hank S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/336297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eKYPaXerPYUhmCsGlk8KlGkrIc9.jpg'),
(142669, 10168, 'Lucky Hank S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/338537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eKYPaXerPYUhmCsGlk8KlGkrIc9.jpg'),
(142670, 10168, 'Lucky Hank S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/345113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eKYPaXerPYUhmCsGlk8KlGkrIc9.jpg'),
(142671, 10169, 'Mao de Ferro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glEVMnbb7VWocIic0tRFp1UAgSS.jpg'),
(142672, 10169, 'Mao de Ferro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/300496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l74QERtWLwuOIDcets6izALuyAi.jpg'),
(142673, 10169, 'Mao de Ferro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/300497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hD9EtLMF0OAJjHTo02awggHN5Ua.jpg'),
(142674, 10169, 'Mao de Ferro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/300498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bExE79cSRdCnmtbe4YMcePZnf3I.jpg'),
(142675, 10169, 'Mao de Ferro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/300499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/izGhj29gdK7uhRKDqh69WQQ5QSo.jpg'),
(142676, 10169, 'Mao de Ferro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/300500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1sMvPNjjVaJ4aTCETdav6Utn7GL.jpg'),
(142677, 10169, 'Mao de Ferro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/300501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0dWlFwbH2sH3JsARefamTP3V9z.jpg'),
(142678, 10169, 'Mao de Ferro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/300502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eTIHhZeIIVSY5sC1HiGbOsqerpg.jpg'),
(142679, 10170, 'Mary e George [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4EcbxAhHKBAIBHTFwzPcODzfsdl.jpg'),
(142680, 10170, 'Mary e George [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/317556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l8p9tZOjg7v5zwH7ReSKcgbJcBr.jpg'),
(142681, 10170, 'Mary e George [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/317557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l8p9tZOjg7v5zwH7ReSKcgbJcBr.jpg'),
(142682, 10170, 'Mary e George [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/317558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l8p9tZOjg7v5zwH7ReSKcgbJcBr.jpg'),
(142683, 10170, 'Mary e George [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/317559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l8p9tZOjg7v5zwH7ReSKcgbJcBr.jpg'),
(142684, 10170, 'Mary e George [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/402989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l8p9tZOjg7v5zwH7ReSKcgbJcBr.jpg'),
(142685, 10170, 'Mary e George [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/405098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l8p9tZOjg7v5zwH7ReSKcgbJcBr.jpg'),
(142686, 10171, 'Mina Settembre [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5H4Q4r4nK46kFcsVimX21HBXv92.jpg'),
(142687, 10171, 'Mina Settembre [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/300483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5H4Q4r4nK46kFcsVimX21HBXv92.jpg'),
(142688, 10171, 'Mina Settembre [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/300484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5H4Q4r4nK46kFcsVimX21HBXv92.jpg'),
(142689, 10171, 'Mina Settembre [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/300485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5H4Q4r4nK46kFcsVimX21HBXv92.jpg'),
(142690, 10171, 'Mina Settembre [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/300486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5H4Q4r4nK46kFcsVimX21HBXv92.jpg'),
(142691, 10171, 'Mina Settembre [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/300487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5H4Q4r4nK46kFcsVimX21HBXv92.jpg'),
(142692, 10171, 'Mina Settembre [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/300488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5H4Q4r4nK46kFcsVimX21HBXv92.jpg'),
(142693, 10171, 'Mina Settembre [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/300489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5H4Q4r4nK46kFcsVimX21HBXv92.jpg'),
(142694, 10171, 'Mina Settembre [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/300490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5H4Q4r4nK46kFcsVimX21HBXv92.jpg'),
(142695, 10171, 'Mina Settembre [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/300491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5H4Q4r4nK46kFcsVimX21HBXv92.jpg'),
(142696, 10171, 'Mina Settembre [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/300492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5H4Q4r4nK46kFcsVimX21HBXv92.jpg'),
(142697, 10171, 'Mina Settembre [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/300493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5H4Q4r4nK46kFcsVimX21HBXv92.jpg'),
(142698, 10172, 'O Agente de Futebol [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bnKY9EKrQ2qPDwuXPSU0X3eSTAU.jpg'),
(142699, 10172, 'O Agente de Futebol [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/300477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lFWQxP6aPiWcAsLeZijns7iaudF.jpg'),
(142700, 10172, 'O Agente de Futebol [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/300478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ogulKc1nhAY7o51G5a7qLcSoWML.jpg'),
(142701, 10172, 'O Agente de Futebol [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/300479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shRrCqPFlJhKxpVRn08ywmmBI7C.jpg'),
(142702, 10172, 'O Agente de Futebol [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/300480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vcuEInC2suYNjJEVFwbubWnKQ9B.jpg'),
(142703, 10172, 'O Agente de Futebol [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/300481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e97UNqWGlMTo3MqWuOoPSu7FwuR.jpg'),
(142704, 10173, 'O Caso Outreau Um Pesadelo Frances S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hhquLuwidzsjjg1mObyRlQVv0Tz.jpg'),
(142705, 10173, 'O Caso Outreau Um Pesadelo Frances S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/300473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/myQ67NVIf1jotXauFv5X8fNNIHc.jpg'),
(142706, 10173, 'O Caso Outreau Um Pesadelo Frances S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/300474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b2LH4HFumO2epdFW6Jb61u9c0if.jpg'),
(142707, 10173, 'O Caso Outreau Um Pesadelo Frances S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/300475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kjj84U2mdGLlQhacSf00rUA5dLe.jpg'),
(142708, 10174, 'O Ninho Futebol e Tragedia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/su3rLeJz6wngjv02HsWexObUChw.jpg'),
(142709, 10174, 'O Ninho Futebol e Tragedia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/300470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5kJcLAJXsI53sRqctaNwTfx7Wog.jpg'),
(142710, 10174, 'O Ninho Futebol e Tragedia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/300471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jGKB4kiMKgSbz4iPIZly74xuLTb.jpg'),
(142711, 10175, 'Objetos Amaldicoados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5NBsZOFm6FLyQZvVOrM5eOqdYi9.jpg'),
(142712, 10175, 'Objetos Amaldicoados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/300462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5asNhrUJ5Ibf3Ca0UDVm7b5krww.jpg'),
(142713, 10175, 'Objetos Amaldicoados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/300463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wb7xcn63ylSpzVf5txADgcK7v4Q.jpg'),
(142714, 10175, 'Objetos Amaldicoados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/300464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dVt7Y3r8nzQFDLKcmHSrRK6zkJC.jpg'),
(142715, 10175, 'Objetos Amaldicoados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/300465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gpNBATkOb67n9TNOW3ALp9vLKtb.jpg'),
(142716, 10175, 'Objetos Amaldicoados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/300466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dNL083jSfaB45BKgb9lP4EjNa8U.jpg'),
(142717, 10175, 'Objetos Amaldicoados S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/300467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u8rCC9MRWk4R3fsYFOgxz2OOUts.jpg'),
(142718, 10175, 'Objetos Amaldicoados S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/300468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eD2p7NrybmLtM3lEydhI7VEjbze.jpg'),
(142719, 7048, 'Prisioneira do Profeta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oYjejeSDOQNVo8E5uMHnlfoDyO0.jpg'),
(142720, 7048, 'Prisioneira do Profeta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/300459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/stR96mLJwkxbYNdkYcXaB9M1mAO.jpg'),
(142721, 7048, 'Prisioneira do Profeta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/300460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fHl2mUvJuyMZ9AbGMv5RoSWNHgB.jpg'),
(142722, 10176, 'Sobrevivendo a Jeffrey Epstein S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rTvihI5VG2VhWr9vAkqPAK48P9q.jpg'),
(142723, 10176, 'Sobrevivendo a Jeffrey Epstein S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/300455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJqRm1OL6kJnykIGWIXqxHKsgPW.jpg'),
(142724, 10176, 'Sobrevivendo a Jeffrey Epstein S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/300456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/buUIovLeuaZGjPu3KRA2ScVGzC7.jpg'),
(142725, 10176, 'Sobrevivendo a Jeffrey Epstein S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/300457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oA4XUQGydQWXnnKG5TKU58eheB.jpg'),
(142726, 10177, 'Tegami Bachi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hg5ziwyvXToajFm6EXFMsg5TQDN.jpg'),
(142727, 10177, 'Tegami Bachi S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/305822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142728, 10177, 'Tegami Bachi S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/311978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142729, 10177, 'Tegami Bachi S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/321131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142730, 10177, 'Tegami Bachi S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/327129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142731, 10177, 'Tegami Bachi S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/330999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142732, 10177, 'Tegami Bachi S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/335787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142733, 10177, 'Tegami Bachi S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/342979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142734, 10177, 'Tegami Bachi S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/354034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142735, 10177, 'Tegami Bachi S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/354035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142736, 10177, 'Tegami Bachi S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/354036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142737, 10177, 'Tegami Bachi S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/354037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142738, 10177, 'Tegami Bachi S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/354038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142739, 10177, 'Tegami Bachi S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/354039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142740, 10177, 'Tegami Bachi S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/362663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(142741, 10177, 'Tegami Bachi S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/362664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142742, 10177, 'Tegami Bachi S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/362665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142743, 10177, 'Tegami Bachi S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/390889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142744, 10177, 'Tegami Bachi S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/390890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142745, 10177, 'Tegami Bachi S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/613715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142746, 10177, 'Tegami Bachi S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/390893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142747, 10177, 'Tegami Bachi S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/390894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142748, 10177, 'Tegami Bachi S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/390895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142749, 10177, 'Tegami Bachi S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/390896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142750, 10177, 'Tegami Bachi S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/390897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142751, 10178, 'Tegami Bachi S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/404085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142752, 10178, 'Tegami Bachi S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/423045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142753, 10178, 'Tegami Bachi S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/423046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142754, 10178, 'Tegami Bachi S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/423047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142755, 10178, 'Tegami Bachi S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/423048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142756, 10178, 'Tegami Bachi S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/423049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142757, 10178, 'Tegami Bachi S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/423050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142758, 10178, 'Tegami Bachi S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/423051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142759, 10178, 'Tegami Bachi S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/423052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142760, 10178, 'Tegami Bachi S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/423053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142761, 10178, 'Tegami Bachi S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/423054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142762, 10178, 'Tegami Bachi S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/423055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142763, 10178, 'Tegami Bachi S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/423056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142764, 10178, 'Tegami Bachi S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/423057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142765, 10178, 'Tegami Bachi S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/423058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142766, 10178, 'Tegami Bachi S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/423059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142767, 10178, 'Tegami Bachi S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/423060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142768, 10178, 'Tegami Bachi S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/423061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142769, 10178, 'Tegami Bachi S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/423062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142770, 10178, 'Tegami Bachi S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/423063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142771, 10178, 'Tegami Bachi S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/423064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142772, 10178, 'Tegami Bachi S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/423065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142773, 10178, 'Tegami Bachi S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/423066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142774, 10178, 'Tegami Bachi S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/423067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142775, 10178, 'Tegami Bachi S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/423068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8kgG2MmEgzqeI3buqrpxebOnc6e.jpg'),
(142776, 10179, 'The Famous Five [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zONpMnA3Trs89fKrNh6VGhYiVWB.jpg'),
(142777, 10180, 'Ultimo Ato S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6CAcjm6WD4KDPqY70qegc1sOncV.jpg'),
(142778, 10180, 'Ultimo Ato S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/300451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6QkGcpYzbrVeSJMW203vZsJp90U.jpg'),
(142779, 10180, 'Ultimo Ato S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/305714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cLOsuWCyMexP2Mz2WLXx7ClfDPN.jpg'),
(142780, 10180, 'Ultimo Ato S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/311923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cLOsuWCyMexP2Mz2WLXx7ClfDPN.jpg'),
(142781, 10180, 'Ultimo Ato S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cLOsuWCyMexP2Mz2WLXx7ClfDPN.jpg'),
(142782, 10180, 'Ultimo Ato S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/327020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cLOsuWCyMexP2Mz2WLXx7ClfDPN.jpg'),
(142783, 10180, 'Ultimo Ato S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/330960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cLOsuWCyMexP2Mz2WLXx7ClfDPN.jpg'),
(142784, 10181, 'Unknown [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1O1be15TSjlRD4tyOh2xwKRJWAK.jpg'),
(142785, 10181, 'Unknown [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/300448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2wTGJBHqTZmTtnDGhYFU0vugQLo.jpg'),
(142786, 10181, 'Unknown [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/300449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7kPK7XYO9deMJGvruP8ld6n8BrN.jpg'),
(142787, 10181, 'Unknown [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/305711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p7eMPPQI3Ft0baPjH46ULWMLqUz.jpg'),
(142788, 10181, 'Unknown [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p7eMPPQI3Ft0baPjH46ULWMLqUz.jpg'),
(142789, 10181, 'Unknown [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p7eMPPQI3Ft0baPjH46ULWMLqUz.jpg'),
(142790, 10181, 'Unknown [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/320948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p7eMPPQI3Ft0baPjH46ULWMLqUz.jpg'),
(142791, 10181, 'Unknown [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/327014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p7eMPPQI3Ft0baPjH46ULWMLqUz.jpg'),
(142792, 10181, 'Unknown [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/332047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p7eMPPQI3Ft0baPjH46ULWMLqUz.jpg'),
(142793, 10181, 'Unknown [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/336847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p7eMPPQI3Ft0baPjH46ULWMLqUz.jpg'),
(142794, 10181, 'Unknown [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/342327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p7eMPPQI3Ft0baPjH46ULWMLqUz.jpg'),
(142795, 10181, 'Unknown [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p7eMPPQI3Ft0baPjH46ULWMLqUz.jpg'),
(142796, 10182, 'Whindersson Verso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/300445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9h2Q2D5Dzi0u602Q6Iuyzc8YwOz.jpg'),
(142797, 10182, 'Whindersson Verso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/300446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9h2Q2D5Dzi0u602Q6Iuyzc8YwOz.jpg'),
(142798, 10182, 'Whindersson Verso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/305706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9h2Q2D5Dzi0u602Q6Iuyzc8YwOz.jpg'),
(142799, 10182, 'Whindersson Verso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/305707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9h2Q2D5Dzi0u602Q6Iuyzc8YwOz.jpg'),
(142800, 10182, 'Whindersson Verso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/313067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9h2Q2D5Dzi0u602Q6Iuyzc8YwOz.jpg'),
(142801, 10182, 'Whindersson Verso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/313068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9h2Q2D5Dzi0u602Q6Iuyzc8YwOz.jpg'),
(142802, 10182, 'Whindersson Verso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/320924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9h2Q2D5Dzi0u602Q6Iuyzc8YwOz.jpg'),
(142803, 10182, 'Whindersson Verso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/320925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9h2Q2D5Dzi0u602Q6Iuyzc8YwOz.jpg'),
(142804, 10183, 'A Tropa da Roca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/305651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/680uOMiriFk0zLpEOoxTI9AvuNG.jpg'),
(142805, 10183, 'A Tropa da Roca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/305652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFl9onbhjuP4q2ZLwMCYoaTiwx8.jpg'),
(142806, 10183, 'A Tropa da Roca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/305653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/czBlBGHGWWigq56STPdGn5R9EUt.jpg'),
(142807, 10183, 'A Tropa da Roca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/305654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Vzx5Mc4VYY5rVM85jYrEwjFtUg.jpg'),
(142808, 10183, 'A Tropa da Roca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/305655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tHSsWKI4KspByf4pbZ8oEyE3E9i.jpg'),
(142809, 10183, 'A Tropa da Roca S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/305656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zrfqsCZ4vo1SHf2eeFG9PIw8F0S.jpg'),
(142810, 10183, 'A Tropa da Roca S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/305657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hjvxRGTnKuLn4C2o6efh3IvmdI0.jpg'),
(142811, 10183, 'A Tropa da Roca S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/305658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/prLmNDZsv5SrFjgXZhEKW8eLmbm.jpg'),
(142812, 10183, 'A Tropa da Roca S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/305659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zh2xvpaBTKVr7mkocdBo00p5jjg.jpg'),
(142813, 10183, 'A Tropa da Roca S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/305660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lG3pXRvZIJ4woRmtzrGPa5vV13z.jpg'),
(142814, 10183, 'A Tropa da Roca S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/305661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AgPq6XBn4YwcDqxolBnGueQBD6T.jpg'),
(142815, 10183, 'A Tropa da Roca S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/305662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4z88ArW1Ulnr5DLdFCOjPAB9AUC.jpg'),
(142816, 10183, 'A Tropa da Roca S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/305663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1orqEZkxesRxOMO1pVxOkXHa2VE.jpg'),
(142817, 10183, 'A Tropa da Roca S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/305664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jlYyHYZxhf3Q8PKauRaMlGXGs5G.jpg'),
(142818, 10183, 'A Tropa da Roca S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/305665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqfDkL6G8CxBflG7tpreI7zI0Fs.jpg'),
(142819, 10183, 'A Tropa da Roca S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/305666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hKkk80iOo5FXWTluiOiSr3C0RBM.jpg'),
(142820, 10183, 'A Tropa da Roca S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/305667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pIxOozQCH1dE2SLOSb3KM1y6kfL.jpg'),
(142821, 10183, 'A Tropa da Roca S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/305668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142822, 10183, 'A Tropa da Roca S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/305669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142823, 10183, 'A Tropa da Roca S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/305670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142824, 10183, 'A Tropa da Roca S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/305671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142825, 10183, 'A Tropa da Roca S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/305672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142826, 10183, 'A Tropa da Roca S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/305673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142827, 10183, 'A Tropa da Roca S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/305674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142828, 10183, 'A Tropa da Roca S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/305675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142829, 10183, 'A Tropa da Roca S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/305676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142830, 10183, 'A Tropa da Roca S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/305677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142831, 10183, 'A Tropa da Roca S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/305678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tTFlEryRk0y6SGneYKHMKs1aH0R.jpg'),
(142832, 10183, 'A Tropa da Roca S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/305679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bisfug43l2NcA3KA2PCNAzBuBqT.jpg'),
(142833, 10183, 'A Tropa da Roca S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/305680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/evnb6JS9rPllNB8iLpH6yAd5Nhx.jpg'),
(142834, 10183, 'A Tropa da Roca S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/305681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mN0nbH7CxlnTYKyxgWDDYrDTj7h.jpg'),
(142835, 10183, 'A Tropa da Roca S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/305682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Isc8ywVRClI2UaotCzJGJ9dOvQ.jpg'),
(142836, 10183, 'A Tropa da Roca S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/305683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7lNTVTQTGX795TBHwvpSG4qcCci.jpg'),
(142837, 10183, 'A Tropa da Roca S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/305684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ywTRa6p0CFapuFk0mc9Kj6zriHQ.jpg'),
(142838, 10183, 'A Tropa da Roca S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/305685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142839, 10183, 'A Tropa da Roca S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/305686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142840, 10183, 'A Tropa da Roca S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/305687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142841, 10183, 'A Tropa da Roca S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/305688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142842, 10183, 'A Tropa da Roca S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/305689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142843, 10183, 'A Tropa da Roca S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/305690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142844, 10183, 'A Tropa da Roca S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/305691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142845, 10183, 'A Tropa da Roca S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/305692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142846, 10183, 'A Tropa da Roca S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/305693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142847, 10183, 'A Tropa da Roca S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/305694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142848, 10183, 'A Tropa da Roca S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/305695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142849, 10183, 'A Tropa da Roca S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/305696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142850, 10183, 'A Tropa da Roca S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/305697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142851, 10183, 'A Tropa da Roca S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/305698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142852, 10183, 'A Tropa da Roca S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/305699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142853, 10183, 'A Tropa da Roca S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/305700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142854, 10183, 'A Tropa da Roca S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/305701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142855, 10183, 'A Tropa da Roca S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/305702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aYE1K7GbrW6nNm0aJPdATdyN6Im.jpg'),
(142856, 10184, 'O Problema dos 3 Corpos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/305643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ciNZIztg9QcTyqhAdTKOq5M0tK.jpg'),
(142857, 10184, 'O Problema dos 3 Corpos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/305644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4e3G8KuF9uJre9lJMy8EfnNolyl.jpg'),
(142858, 10184, 'O Problema dos 3 Corpos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/305645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pZmK0DIhQ6A7so08lpJaZwrIHXN.jpg'),
(142859, 10184, 'O Problema dos 3 Corpos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/305646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sE91yBe3Ho0WIQiG3ceAoFP9xKz.jpg'),
(142860, 10184, 'O Problema dos 3 Corpos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/305647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gITyAjLsCcyCsID5iOnQJPNADJb.jpg'),
(142861, 10184, 'O Problema dos 3 Corpos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/305648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6zqcQWWeo3ZSd4hGgogkaU1OCWq.jpg'),
(142862, 10184, 'O Problema dos 3 Corpos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/305649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rYq2Euo5F4DOsJVBv8DykTyYv1a.jpg'),
(142863, 10184, 'O Problema dos 3 Corpos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/305650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bXQgkpS4TV6FottbpKjv82AJunG.jpg'),
(142864, 10185, 'Palm Royale S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/305640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3x0Kr2xQviQ3QCsYP2x5inkFbKI.jpg'),
(142865, 10185, 'Palm Royale S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/305641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6nw7wA91L59IvGLwxSUfylY3Fn9.jpg'),
(142866, 10185, 'Palm Royale S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/305642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Z6eKPY8jMXQOFNIKGAw4yWioCW.jpg'),
(142867, 10185, 'Palm Royale S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/309971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WcJLCS31BiVYgvnh19lOjZoiiZ.jpg'),
(142868, 10185, 'Palm Royale S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/317501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WcJLCS31BiVYgvnh19lOjZoiiZ.jpg'),
(142869, 10185, 'Palm Royale S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/323849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WcJLCS31BiVYgvnh19lOjZoiiZ.jpg'),
(142870, 10185, 'Palm Royale S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/327630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WcJLCS31BiVYgvnh19lOjZoiiZ.jpg'),
(142871, 10185, 'Palm Royale S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/336274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WcJLCS31BiVYgvnh19lOjZoiiZ.jpg'),
(142872, 10185, 'Palm Royale S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/340721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WcJLCS31BiVYgvnh19lOjZoiiZ.jpg'),
(142873, 10185, 'Palm Royale S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/348523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WcJLCS31BiVYgvnh19lOjZoiiZ.jpg'),
(142874, 10186, 'Palm Royale S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/892430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WcJLCS31BiVYgvnh19lOjZoiiZ.jpg'),
(142875, 10186, 'Palm Royale S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/893102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WcJLCS31BiVYgvnh19lOjZoiiZ.jpg'),
(142876, 10186, 'Palm Royale S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/893461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WcJLCS31BiVYgvnh19lOjZoiiZ.jpg'),
(142877, 10186, 'Palm Royale S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/894205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WcJLCS31BiVYgvnh19lOjZoiiZ.jpg'),
(142878, 10186, 'Palm Royale S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/895866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WcJLCS31BiVYgvnh19lOjZoiiZ.jpg'),
(142879, 10186, 'Palm Royale S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/896395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WcJLCS31BiVYgvnh19lOjZoiiZ.jpg'),
(142880, 10186, 'Palm Royale S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/897412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7WcJLCS31BiVYgvnh19lOjZoiiZ.jpg'),
(142881, 10187, 'X Men 97 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/305638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLXRYta8yBVXvl1Hr6jjgL6Ofxh.jpg'),
(142882, 10187, 'X Men 97 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/305639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/28IFCY8Ac2DBSwMNiN9JG0KcYWf.jpg'),
(142883, 10187, 'X Men 97 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/309495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dn7u5KuUeuNSnGxCSGmw7U2mOeg.jpg'),
(142884, 10187, 'X Men 97 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/316506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dn7u5KuUeuNSnGxCSGmw7U2mOeg.jpg'),
(142885, 10187, 'X Men 97 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/323434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dn7u5KuUeuNSnGxCSGmw7U2mOeg.jpg'),
(142886, 10187, 'X Men 97 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/327332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dn7u5KuUeuNSnGxCSGmw7U2mOeg.jpg'),
(142887, 10187, 'X Men 97 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/335192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dn7u5KuUeuNSnGxCSGmw7U2mOeg.jpg'),
(142888, 10187, 'X Men 97 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/339395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dn7u5KuUeuNSnGxCSGmw7U2mOeg.jpg'),
(142889, 10187, 'X Men 97 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/350921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dn7u5KuUeuNSnGxCSGmw7U2mOeg.jpg'),
(142890, 10187, 'X Men 97 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/350922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dn7u5KuUeuNSnGxCSGmw7U2mOeg.jpg'),
(142891, 10188, '90 Dias para Casar Do Outro Lado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qt4rP4fyx5x8HrF5OOkTkxXPFXm.jpg'),
(142892, 10188, '90 Dias para Casar Do Outro Lado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ltuDA519WH76APy0TY5d4VG3rx3.jpg'),
(142893, 10188, '90 Dias para Casar Do Outro Lado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzBny0qP2sF9hDgT6EMwl1td5nm.jpg'),
(142894, 10188, '90 Dias para Casar Do Outro Lado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t9h7uzAVZZSrfd0ift85lO9GT6L.jpg'),
(142895, 10188, '90 Dias para Casar Do Outro Lado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2UXiifKvEMkhKyJcfN4GKdvB14H.jpg'),
(142896, 10188, '90 Dias para Casar Do Outro Lado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63olq0u6JDZKyYwlipktppwnCR1.jpg'),
(142897, 10188, '90 Dias para Casar Do Outro Lado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fm8WCSc1j6riBReCIG8R317aHZD.jpg'),
(142898, 10188, '90 Dias para Casar Do Outro Lado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/306899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xayg8uuxfpuPO9IPb9LRfs61ZWR.jpg'),
(142899, 10188, '90 Dias para Casar Do Outro Lado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/306900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yI2anGu5JmZ2xd25gKp7v8g6bUU.jpg'),
(142900, 10188, '90 Dias para Casar Do Outro Lado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/306901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wHq568L4jUpEDGl59dmlSZVyPMR.jpg'),
(142901, 10188, '90 Dias para Casar Do Outro Lado S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/306902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzfCKUZdZ7Vr7c3lAJm9TNfMQ6q.jpg'),
(142902, 10188, '90 Dias para Casar Do Outro Lado S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/306903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7e8q1626bnRyACR1LyS523xIC6L.jpg'),
(142903, 10188, '90 Dias para Casar Do Outro Lado S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/306904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c89Mkh6Xasa7BvFW2KZb2Wliv3w.jpg'),
(142904, 10188, '90 Dias para Casar Do Outro Lado S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/306905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a58dhXA57ZJSqqUPHV7gGS1Ypgo.jpg'),
(142905, 10188, '90 Dias para Casar Do Outro Lado S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/306906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2I0WQUWt8YEnF42OiKFHQsGvKNV.jpg'),
(142906, 10188, '90 Dias para Casar Do Outro Lado S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/306907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QDZOrLHRVxprcevIxsBpAxKO26.jpg'),
(142907, 10188, '90 Dias para Casar Do Outro Lado S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/306908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gopGcbr4Z8hy93NIF7le2Gco32r.jpg'),
(142908, 10188, '90 Dias para Casar Do Outro Lado S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/306909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uKaRU4bYe5lGPRIxRBH1CKgxiwF.jpg'),
(142909, 10188, '90 Dias para Casar Do Outro Lado S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/306910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qMDtIqZBq1mShyR19KfvYIdXlpd.jpg'),
(142910, 10188, '90 Dias para Casar Do Outro Lado S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/306911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A1jqCxWloXAVskWDHYLMLErohZe.jpg'),
(142911, 10188, '90 Dias para Casar Do Outro Lado S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/306912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ndMTDijdMHVTiDuwTPSdj6qZ4u.jpg'),
(142912, 10188, '90 Dias para Casar Do Outro Lado S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/306913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z03codm40AabuP2i0M4MhiYeS1u.jpg'),
(142913, 10189, '90 Dias para Casar Do Outro Lado S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iBDVJhCpH1sprYOwfs5ZE1LFfPM.jpg'),
(142914, 10189, '90 Dias para Casar Do Outro Lado S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1zZIfgrp9jowvHf26Us7dUMmJDY.jpg'),
(142915, 10189, '90 Dias para Casar Do Outro Lado S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glnBh1sVIMg9ZVmur3j8kXfAwJx.jpg'),
(142916, 10189, '90 Dias para Casar Do Outro Lado S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/er9d6K4ydxY5RVFe2lk65cdAGI1.jpg'),
(142917, 10189, '90 Dias para Casar Do Outro Lado S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/85XUD6Rw3ZUiJOX5DjVHPp5Gahj.jpg'),
(142918, 10189, '90 Dias para Casar Do Outro Lado S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tB1NgQzbXQBSDPpBWwRzggUZlyj.jpg'),
(142919, 10189, '90 Dias para Casar Do Outro Lado S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2UD1AtvGxVUEwsL2jRx1M19BOiU.jpg'),
(142920, 10189, '90 Dias para Casar Do Outro Lado S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/306921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1nOCyhacXpCVKgtVrqmbsTsC6lL.jpg'),
(142921, 10189, '90 Dias para Casar Do Outro Lado S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/306922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uKNqQuiLDKIOBCTHufFJzZlMnWi.jpg'),
(142922, 10189, '90 Dias para Casar Do Outro Lado S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/306923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sB3nhJhD5bdNv5DC9WJMs01VGQK.jpg'),
(142923, 10189, '90 Dias para Casar Do Outro Lado S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/306924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yghHBHsLANCsFDzJbxTUTu1ScPm.jpg'),
(142924, 10189, '90 Dias para Casar Do Outro Lado S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/306925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n4xyR3uD03TbJhzY0XwIcwyL6Bp.jpg'),
(142925, 10189, '90 Dias para Casar Do Outro Lado S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/306926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jnmm7LgObyqyyFarv8Vpuj3LB1a.jpg'),
(142926, 10189, '90 Dias para Casar Do Outro Lado S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/306927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5UgqywU3PA9SJbvCBbB8Mohnsod.jpg'),
(142927, 10189, '90 Dias para Casar Do Outro Lado S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/306928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Om3LtgA0TVouPIFWyq8kiJJryv.jpg'),
(142928, 10189, '90 Dias para Casar Do Outro Lado S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/306929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJQ1ZGYOmNPXpXLdgF6bPpCmaLg.jpg'),
(142929, 10189, '90 Dias para Casar Do Outro Lado S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/306930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/phwwj17bBM6itPtYqVb4QznKNsB.jpg'),
(142930, 10189, '90 Dias para Casar Do Outro Lado S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/306931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cGBAMCcmLBOTQkcdYRolRB64jMz.jpg'),
(142931, 10189, '90 Dias para Casar Do Outro Lado S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/306932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/unAGGk5c5JACOAL31N9pKSi3gz.jpg'),
(142932, 10189, '90 Dias para Casar Do Outro Lado S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/306933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTD5MrP9pfuhtP1o5sA4JNILXDO.jpg'),
(142933, 10189, '90 Dias para Casar Do Outro Lado S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/306934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aEovOaeK0anoVXro1NOKIpakbd1.jpg'),
(142934, 10189, '90 Dias para Casar Do Outro Lado S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/306935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/55HOSxGB9YXUXPnIgLUKQOZwgDd.jpg'),
(142935, 10190, '90 Dias para Casar Do Outro Lado S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z87OSuIOZMzLFk2w1ydxwXhtFUv.jpg'),
(142936, 10190, '90 Dias para Casar Do Outro Lado S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vdP86yczGV4FOLeIvQobceczx2r.jpg'),
(142937, 10190, '90 Dias para Casar Do Outro Lado S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwd7yY4ZFN2ZFfhfdgGaWH3I4kC.jpg'),
(142938, 10190, '90 Dias para Casar Do Outro Lado S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2HcxHTfw4s2QRworQJKFEQDh7Q8.jpg'),
(142939, 10190, '90 Dias para Casar Do Outro Lado S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x9Adm14r2xLrO40WU4D1jdY1aB4.jpg'),
(142940, 10190, '90 Dias para Casar Do Outro Lado S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6a3G3PSGImj0vHA09cVLLuU4h4Y.jpg'),
(142941, 10190, '90 Dias para Casar Do Outro Lado S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k8yFKqGg2AZq1XPBNPcmixlYtHn.jpg'),
(142942, 10190, '90 Dias para Casar Do Outro Lado S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/306943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/seU3FNQ8v8K7x3a70rZ9dr6VOTQ.jpg'),
(142943, 10190, '90 Dias para Casar Do Outro Lado S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/306944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tgjxTQKoyo7G6GSe8QAfLHk3GwS.jpg'),
(142944, 10190, '90 Dias para Casar Do Outro Lado S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/306945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sepu5UFleblfl8JQU2UgdXTwvd2.jpg'),
(142945, 10190, '90 Dias para Casar Do Outro Lado S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/306946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/W1N11kw0tDMswK8PGwcoDlpXwl.jpg'),
(142946, 10190, '90 Dias para Casar Do Outro Lado S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/306947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOlrDVD7LXfczQQEFLBYwW2Q5sC.jpg'),
(142947, 10190, '90 Dias para Casar Do Outro Lado S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/306948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j5PmKRvhokB02UELHmBCoo6Vgk3.jpg'),
(142948, 10190, '90 Dias para Casar Do Outro Lado S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/306949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSEOwVRY6VjK05cS03zTmtiKIke.jpg'),
(142949, 10190, '90 Dias para Casar Do Outro Lado S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/306950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A1LWpNgi78s4tCHPixEcAyJ6IFx.jpg'),
(142950, 10190, '90 Dias para Casar Do Outro Lado S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/306951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142951, 10190, '90 Dias para Casar Do Outro Lado S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/306952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142952, 10190, '90 Dias para Casar Do Outro Lado S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/306953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142953, 10190, '90 Dias para Casar Do Outro Lado S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/306954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142954, 10190, '90 Dias para Casar Do Outro Lado S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/306955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142955, 10190, '90 Dias para Casar Do Outro Lado S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/306956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142956, 10190, '90 Dias para Casar Do Outro Lado S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/306957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142957, 10190, '90 Dias para Casar Do Outro Lado S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/306958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142958, 10190, '90 Dias para Casar Do Outro Lado S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/306959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142959, 10190, '90 Dias para Casar Do Outro Lado S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/306960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142960, 10190, '90 Dias para Casar Do Outro Lado S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/306961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142961, 10190, '90 Dias para Casar Do Outro Lado S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/306962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142962, 10191, '90 Dias para Casar Do Outro Lado S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Md0l8LAu5dgwO2otMT2RFBaG0O.jpg'),
(142963, 10191, '90 Dias para Casar Do Outro Lado S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8tiOecXsAvyzqVSaeAf1HksKMoh.jpg'),
(142964, 10191, '90 Dias para Casar Do Outro Lado S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gwRjrc15meCbraiDXC44kIkXpLq.jpg'),
(142965, 10191, '90 Dias para Casar Do Outro Lado S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AfNOiQNuXkRDgagojyTTAXL2YYh.jpg'),
(142966, 10191, '90 Dias para Casar Do Outro Lado S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cZE7ubJLlBynAsiWawqUjbSlrWD.jpg'),
(142967, 10191, '90 Dias para Casar Do Outro Lado S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3WII90Bf4945WxIMNWzGJqjlX12.jpg'),
(142968, 10191, '90 Dias para Casar Do Outro Lado S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j8uzdjYAy0VDFGdaw1c8i9YgWt6.jpg'),
(142969, 10191, '90 Dias para Casar Do Outro Lado S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/306970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f3WZkruewXEtjkAi0ORRrrvCeaB.jpg'),
(142970, 10191, '90 Dias para Casar Do Outro Lado S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/306971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JJjb4EOQ3KnBoN6luFXpvATMnh.jpg'),
(142971, 10191, '90 Dias para Casar Do Outro Lado S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/306972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qSYJzF6NmfkwRdivyollZTE8wmE.jpg'),
(142972, 10191, '90 Dias para Casar Do Outro Lado S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/306973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkeQvHKCpC3dtWxSDz7Hmd6iLzj.jpg'),
(142973, 10191, '90 Dias para Casar Do Outro Lado S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/306974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iDQ1UJLpuh61XhPyMGYZlOIhwbS.jpg'),
(142974, 10191, '90 Dias para Casar Do Outro Lado S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/306975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ycp5pKqCbIzn5Ds69eLTCbZ2O4j.jpg'),
(142975, 10191, '90 Dias para Casar Do Outro Lado S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/306976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rW7PMSP9mZY6RCEJihDo4aOD9UI.jpg'),
(142976, 10191, '90 Dias para Casar Do Outro Lado S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/306977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sR4rAWWXZ4akATq85gvWCP7x4Ia.jpg'),
(142977, 10191, '90 Dias para Casar Do Outro Lado S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/456927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142978, 10191, '90 Dias para Casar Do Outro Lado S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/456928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142979, 10192, '90 Dias para Casar Do Outro Lado S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/456929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142980, 10192, '90 Dias para Casar Do Outro Lado S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/456930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142981, 10192, '90 Dias para Casar Do Outro Lado S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/456931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142982, 10192, '90 Dias para Casar Do Outro Lado S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/456932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142983, 10192, '90 Dias para Casar Do Outro Lado S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/456933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142984, 10192, '90 Dias para Casar Do Outro Lado S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/456934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142985, 10192, '90 Dias para Casar Do Outro Lado S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/456935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142986, 10192, '90 Dias para Casar Do Outro Lado S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/456936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142987, 10192, '90 Dias para Casar Do Outro Lado S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/456937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142988, 10192, '90 Dias para Casar Do Outro Lado S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142989, 10192, '90 Dias para Casar Do Outro Lado S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/468495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142990, 10192, '90 Dias para Casar Do Outro Lado S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/475485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142991, 10192, '90 Dias para Casar Do Outro Lado S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/479414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142992, 10192, '90 Dias para Casar Do Outro Lado S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/486176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142993, 10192, '90 Dias para Casar Do Outro Lado S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/494112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142994, 10192, '90 Dias para Casar Do Outro Lado S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/497364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(142995, 10192, '90 Dias para Casar Do Outro Lado S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/503541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142996, 10192, '90 Dias para Casar Do Outro Lado S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/508308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142997, 10192, '90 Dias para Casar Do Outro Lado S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/516347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142998, 10192, '90 Dias para Casar Do Outro Lado S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/642276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(142999, 10192, '90 Dias para Casar Do Outro Lado S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/642278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(143000, 10192, '90 Dias para Casar Do Outro Lado S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/642279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(143001, 10192, '90 Dias para Casar Do Outro Lado S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/642280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(143002, 10192, '90 Dias para Casar Do Outro Lado S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/656838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aQbWIZIa4F5BlpQscG6BLyYEzD3.jpg'),
(143003, 10193, 'ARA San Juan O Submarino que Desapareceu [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lKySAlmCjLHeETCeWKQkoFDkbwG.jpg'),
(143004, 10193, 'ARA San Juan O Submarino que Desapareceu [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bRfqJsMj6ceGrtlMh36km0vEUgm.jpg'),
(143005, 10193, 'ARA San Juan O Submarino que Desapareceu [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4zVwB7mmYJWQuqtxCzYmkGpfTxJ.jpg'),
(143006, 10193, 'ARA San Juan O Submarino que Desapareceu [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2xIPLi7rX53LQNgL3IBaYNFLcSW.jpg'),
(143007, 10193, 'ARA San Juan O Submarino que Desapareceu [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pafSOy40fDGLjn1UpumzCs65st9.jpg'),
(143008, 10193, 'ARA San Juan O Submarino que Desapareceu [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t70Banb89rtQhi6VyI01T4i2OpE.jpg'),
(143009, 10193, 'ARA San Juan O Submarino que Desapareceu [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ytSXvexCmLl0Hj59GBcAhRdpA9B.jpg'),
(143010, 10193, 'ARA San Juan O Submarino que Desapareceu [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/306891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9nQpbcM09sbWdlx2ZflsmMY9wiP.jpg'),
(143011, 10194, 'Apples Never Fall [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y0ItvtlpBA2ni5E4uuUnljB4jxf.jpg'),
(143012, 10194, 'Apples Never Fall [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/29c8d8oL1RqyXZ8zBpwWFbLQY6w.jpg'),
(143013, 10194, 'Apples Never Fall [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Qcfj915LuyUMJOYjgdPLDmon8C.jpg'),
(143014, 10194, 'Apples Never Fall [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ldaqA6OMYZ9HMwjKwdTHTNVTHvk.jpg'),
(143015, 10194, 'Apples Never Fall [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/319044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/goa4saZkf8r4zmBNgS6IiiPxEEN.jpg'),
(143016, 10194, 'Apples Never Fall [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/319045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/goa4saZkf8r4zmBNgS6IiiPxEEN.jpg'),
(143017, 10195, 'As Aventuras de Bernie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6jNFWiMIvJNmVORmwVy36c0EkSF.jpg'),
(143018, 10195, 'As Aventuras de Bernie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xWAq7bZ6vO6EW6iL7l6NPp3KI7k.jpg'),
(143019, 10195, 'As Aventuras de Bernie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ycVnyfffKqv8ylZWCKS5e8P5Yww.jpg'),
(143020, 10195, 'As Aventuras de Bernie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hByCzCqprDZR2Uu6GqQurXyyWaK.jpg'),
(143021, 10195, 'As Aventuras de Bernie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3lxU7YHA1bMcvpdQV1iq5qG5kzi.jpg'),
(143022, 10195, 'As Aventuras de Bernie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/808ymfmH2BvdjQS2JaaUbSOK85r.jpg'),
(143023, 10195, 'As Aventuras de Bernie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rFmfuWsq9Nec0ypqjTgNZZC4jo2.jpg'),
(143024, 10195, 'As Aventuras de Bernie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/306877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uLwQ0gwebqJgvgsmOtxVaoA4OyW.jpg'),
(143025, 10195, 'As Aventuras de Bernie S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/306878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5uCVpfcV0TYkyPYOhXKumhKVXgj.jpg'),
(143026, 10195, 'As Aventuras de Bernie S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/306879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7XqbqQJeZt1LcWfSaRffbXJXmsh.jpg'),
(143027, 10196, 'Crise em Seis Cenas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mpIgVOHEELqGWoZtBZq7ntcpp13.jpg'),
(143028, 10196, 'Crise em Seis Cenas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aWcs48mAgpPuv8ISMn3GLsVMRjI.jpg'),
(143029, 10196, 'Crise em Seis Cenas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9jpMr884k8g5ALN6cfq4lIMv3KM.jpg'),
(143030, 10196, 'Crise em Seis Cenas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/euUpymp0jJFeJZpMow7eGIq0YqD.jpg'),
(143031, 10196, 'Crise em Seis Cenas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCCO8aEUEgI6jMLjrNlkwjA8ctU.jpg'),
(143032, 10196, 'Crise em Seis Cenas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k4xNsZMxkyGRO4xMvPMA5pqX7WX.jpg'),
(143033, 10197, 'Design Fora da Curva com Lil Jon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27U6jIaK4vOtADIVY3iR4xRjI7c.jpg'),
(143034, 10197, 'Design Fora da Curva com Lil Jon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27U6jIaK4vOtADIVY3iR4xRjI7c.jpg'),
(143035, 10197, 'Design Fora da Curva com Lil Jon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27U6jIaK4vOtADIVY3iR4xRjI7c.jpg'),
(143036, 10197, 'Design Fora da Curva com Lil Jon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27U6jIaK4vOtADIVY3iR4xRjI7c.jpg'),
(143037, 10197, 'Design Fora da Curva com Lil Jon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27U6jIaK4vOtADIVY3iR4xRjI7c.jpg'),
(143038, 10197, 'Design Fora da Curva com Lil Jon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27U6jIaK4vOtADIVY3iR4xRjI7c.jpg'),
(143039, 10198, 'Design Fora da Curva com Lil Jon S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27U6jIaK4vOtADIVY3iR4xRjI7c.jpg'),
(143040, 10198, 'Design Fora da Curva com Lil Jon S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27U6jIaK4vOtADIVY3iR4xRjI7c.jpg'),
(143041, 10198, 'Design Fora da Curva com Lil Jon S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27U6jIaK4vOtADIVY3iR4xRjI7c.jpg'),
(143042, 10198, 'Design Fora da Curva com Lil Jon S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/318215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27U6jIaK4vOtADIVY3iR4xRjI7c.jpg'),
(143043, 10198, 'Design Fora da Curva com Lil Jon S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/322926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/27U6jIaK4vOtADIVY3iR4xRjI7c.jpg'),
(143044, 10199, 'Febre do Ouro Minas Reativadas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jxMInocd5lL1VILqHtQuBzlXXRW.jpg'),
(143045, 10199, 'Febre do Ouro Minas Reativadas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jxMInocd5lL1VILqHtQuBzlXXRW.jpg'),
(143046, 10199, 'Febre do Ouro Minas Reativadas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3yCKjBhki62nhNdW9aZYEnpipv.jpg'),
(143047, 10199, 'Febre do Ouro Minas Reativadas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AgyDRL9Vqvg5fESK1xHGs0eFAUo.jpg'),
(143048, 10200, 'Febre do Ouro Minas Reativadas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jxMInocd5lL1VILqHtQuBzlXXRW.jpg'),
(143049, 10200, 'Febre do Ouro Minas Reativadas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jxMInocd5lL1VILqHtQuBzlXXRW.jpg'),
(143050, 10200, 'Febre do Ouro Minas Reativadas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jxMInocd5lL1VILqHtQuBzlXXRW.jpg'),
(143051, 10200, 'Febre do Ouro Minas Reativadas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jxMInocd5lL1VILqHtQuBzlXXRW.jpg'),
(143052, 10200, 'Febre do Ouro Minas Reativadas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jxMInocd5lL1VILqHtQuBzlXXRW.jpg'),
(143053, 10200, 'Febre do Ouro Minas Reativadas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jxMInocd5lL1VILqHtQuBzlXXRW.jpg'),
(143054, 10200, 'Febre do Ouro Minas Reativadas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jxMInocd5lL1VILqHtQuBzlXXRW.jpg'),
(143055, 10200, 'Febre do Ouro Minas Reativadas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/306822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jxMInocd5lL1VILqHtQuBzlXXRW.jpg'),
(143056, 10201, 'Febre do Ouro Minas Reativadas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fnuIiPNi1oWq2hBI54yDZX3JZUp.jpg'),
(143057, 10201, 'Febre do Ouro Minas Reativadas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tPJ87KICa4qVDiiRlSbZQRybkQN.jpg'),
(143058, 10201, 'Febre do Ouro Minas Reativadas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iBiYo5jJt21SMXH6nOogLBCdkD9.jpg'),
(143059, 10201, 'Febre do Ouro Minas Reativadas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yuFI1bF05hJitQ3tfXd0y0Q9x7r.jpg'),
(143060, 10201, 'Febre do Ouro Minas Reativadas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/swIAIm95Zv8z4Rsh2XLdr6A3pxl.jpg'),
(143061, 10201, 'Febre do Ouro Minas Reativadas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1qCQ2PQGq3C74ugegvTJwURg9h7.jpg'),
(143062, 10201, 'Febre do Ouro Minas Reativadas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y7PHltORxuTNlkBlkMHItz1jI4R.jpg'),
(143063, 10201, 'Febre do Ouro Minas Reativadas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/306830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1dCIzX81RItlPlu7K3hpnLzNZmP.jpg'),
(143064, 10201, 'Febre do Ouro Minas Reativadas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/306831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xsef7RMYh6dOszjfqDqQiUUfYzQ.jpg'),
(143065, 10201, 'Febre do Ouro Minas Reativadas S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/306832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oBs8Tj08CUocW3urWGINw4KmsCc.jpg'),
(143066, 10201, 'Febre do Ouro Minas Reativadas S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/306833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/muuVTV5eawDQhFNNV1VmRrdDrsZ.jpg'),
(143067, 10201, 'Febre do Ouro Minas Reativadas S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/306834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s0d3NjSkIyO1o6QJE4w5CYbkFMq.jpg'),
(143068, 10201, 'Febre do Ouro Minas Reativadas S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/306835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/37HyNdSv89iurOo7jtG45I3WQJ2.jpg'),
(143069, 10201, 'Febre do Ouro Minas Reativadas S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/306836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nsf6R63vHRwXUVeRQDwEi5yAlRU.jpg'),
(143070, 10201, 'Febre do Ouro Minas Reativadas S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/306837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2XvGHo1rB6Q1NKPfS0UIgKeBcUk.jpg'),
(143071, 10201, 'Febre do Ouro Minas Reativadas S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/306838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7G6PGcJK0lBWgpp0008s7eWuovr.jpg'),
(143072, 10202, 'Febre do Ouro Minas Reativadas S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lXW1dKpIUAtZzKMIKTAE5DOTC6d.jpg'),
(143073, 10202, 'Febre do Ouro Minas Reativadas S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vXQa6jGmsWFTivvqyjAn2hqTnGm.jpg'),
(143074, 10202, 'Febre do Ouro Minas Reativadas S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vcHaFP9Ni2fs4xpSYoVPHgID0LG.jpg'),
(143075, 10202, 'Febre do Ouro Minas Reativadas S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rTx7K1VRZxBEbdtcuPrc6gc6G7P.jpg'),
(143076, 10202, 'Febre do Ouro Minas Reativadas S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mpGsFwDLThJZNWpF6lN6809OlJj.jpg'),
(143077, 10202, 'Febre do Ouro Minas Reativadas S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7dB2shIUKLxOoOfajM0minmh95x.jpg'),
(143078, 10202, 'Febre do Ouro Minas Reativadas S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5mJt6JEUeEAUAmGTpAO14rfxcp0.jpg'),
(143079, 10202, 'Febre do Ouro Minas Reativadas S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/306846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vXbzrPU35hy3WVzYnx6Lk3KVPTy.jpg'),
(143080, 10202, 'Febre do Ouro Minas Reativadas S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/306847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dj8CWEr7iMWpKRUAvMeaovZH3rM.jpg'),
(143081, 10202, 'Febre do Ouro Minas Reativadas S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/306848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n2faoFRPo1NcPI6RSsZmJAhiJqw.jpg'),
(143082, 10202, 'Febre do Ouro Minas Reativadas S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/306849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOP1Aashk7HHuR0IpllaGouzuML.jpg'),
(143083, 10202, 'Febre do Ouro Minas Reativadas S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/306850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bjebjubuQS5RAZcloHpuqZ6XWJw.jpg'),
(143084, 10202, 'Febre do Ouro Minas Reativadas S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/306851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mhwqsf80lfj81CAPQ2enSduzYFP.jpg'),
(143085, 10202, 'Febre do Ouro Minas Reativadas S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/306852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Dm2ZKFTPyxlGTZavBH7alshQ6s.jpg'),
(143086, 10202, 'Febre do Ouro Minas Reativadas S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/306853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ty3vCTbi8oL7D6iSa6wiOarpHlg.jpg'),
(143087, 10202, 'Febre do Ouro Minas Reativadas S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/306854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tlGw7s8506IABHtGzn2iyWatKiK.jpg'),
(143088, 10203, 'Ghost Hound S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4KgCGIhtjEWNizrwXRr0JFO9dKS.jpg'),
(143089, 10203, 'Ghost Hound S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1JCrgveoLYi6u3ARS1SGCSNHdid.jpg'),
(143090, 10203, 'Ghost Hound S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/waodhX6wLhZAWKOgjD61ScWDSB9.jpg'),
(143091, 10203, 'Ghost Hound S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mqKrzkApGipibpkvC6ThkBxQtpt.jpg'),
(143092, 10203, 'Ghost Hound S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oUujOzkXqc5gDYAqXCg70WbH0g.jpg'),
(143093, 10203, 'Ghost Hound S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vePRISQdJvWIiiyOpi9GahPF6AM.jpg'),
(143094, 10203, 'Ghost Hound S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/52qWL7tK2DvCh9fJypmOFGLb2xO.jpg'),
(143095, 10203, 'Ghost Hound S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/306796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6DGVxMAb8InrpNtaMwaixpNDr7z.jpg'),
(143096, 10203, 'Ghost Hound S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/306797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/51OPZmXI3cvJvsh6hwceDF3Mtrq.jpg'),
(143097, 10203, 'Ghost Hound S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/306798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uyhCkRkRDsTADIlpfurBknxR3Sp.jpg'),
(143098, 10203, 'Ghost Hound S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/306799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9v2q5BU0QTUqQwsLcYAjwtlOjiE.jpg'),
(143099, 10203, 'Ghost Hound S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/306800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/thYDKrv8oGHg75dz9mlx8VTfjjR.jpg'),
(143100, 10203, 'Ghost Hound S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/306801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9HU3WrP9G8xaQgwf8kEbVIGCrVU.jpg'),
(143101, 10203, 'Ghost Hound S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/306802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/93Wj2qFlDqdzoxjMBoRjRbuQJVZ.jpg'),
(143102, 10203, 'Ghost Hound S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/306803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6VVIeMrzkp7QfQNfxGF0wq9Y3a.jpg'),
(143103, 10203, 'Ghost Hound S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/306804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gb6HTXc6SQawFTh5JPdQ6XPm9Iw.jpg'),
(143104, 10203, 'Ghost Hound S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/306805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ct7jiJxchxtSQdocFVRt1rbiihg.jpg'),
(143105, 10203, 'Ghost Hound S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/306806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oLtk21akHwCXfLXUQamTn2VGUqj.jpg'),
(143106, 10203, 'Ghost Hound S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/306807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4LMdjHqlzlBCtfwF3giRw3Quusm.jpg'),
(143107, 10203, 'Ghost Hound S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/306808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/blzgVsAGztvjc28PFIzdzdFwZaN.jpg'),
(143108, 10203, 'Ghost Hound S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/306809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lAK71l7gRBrgxZAEOVUAlcpDcUt.jpg'),
(143109, 10203, 'Ghost Hound S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/306810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gwDWKlpO7yrtkKJvTKKnqicDc9Y.jpg'),
(143110, 10204, 'Humanos Extraordinarios [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4zLq8GX6a2dF9PgSpQLTdw9ZaU8.jpg'),
(143111, 10204, 'Humanos Extraordinarios [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4zLq8GX6a2dF9PgSpQLTdw9ZaU8.jpg'),
(143112, 10204, 'Humanos Extraordinarios [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4zLq8GX6a2dF9PgSpQLTdw9ZaU8.jpg'),
(143113, 10204, 'Humanos Extraordinarios [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4zLq8GX6a2dF9PgSpQLTdw9ZaU8.jpg'),
(143114, 10204, 'Humanos Extraordinarios [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4zLq8GX6a2dF9PgSpQLTdw9ZaU8.jpg'),
(143115, 10204, 'Humanos Extraordinarios [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4zLq8GX6a2dF9PgSpQLTdw9ZaU8.jpg'),
(143116, 10204, 'Humanos Extraordinarios [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4zLq8GX6a2dF9PgSpQLTdw9ZaU8.jpg'),
(143117, 10204, 'Humanos Extraordinarios [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/306776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4zLq8GX6a2dF9PgSpQLTdw9ZaU8.jpg'),
(143118, 10204, 'Humanos Extraordinarios [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/306777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4zLq8GX6a2dF9PgSpQLTdw9ZaU8.jpg'),
(143119, 10204, 'Humanos Extraordinarios [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/306778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4zLq8GX6a2dF9PgSpQLTdw9ZaU8.jpg'),
(143120, 10205, 'Humanos Extraordinarios [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4zLq8GX6a2dF9PgSpQLTdw9ZaU8.jpg'),
(143121, 10205, 'Humanos Extraordinarios [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4zLq8GX6a2dF9PgSpQLTdw9ZaU8.jpg'),
(143122, 10205, 'Humanos Extraordinarios [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4zLq8GX6a2dF9PgSpQLTdw9ZaU8.jpg'),
(143123, 10205, 'Humanos Extraordinarios [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4zLq8GX6a2dF9PgSpQLTdw9ZaU8.jpg'),
(143124, 10205, 'Humanos Extraordinarios [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4zLq8GX6a2dF9PgSpQLTdw9ZaU8.jpg'),
(143125, 10205, 'Humanos Extraordinarios [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4zLq8GX6a2dF9PgSpQLTdw9ZaU8.jpg'),
(143126, 10205, 'Humanos Extraordinarios [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4zLq8GX6a2dF9PgSpQLTdw9ZaU8.jpg'),
(143127, 10205, 'Humanos Extraordinarios [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/306786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4zLq8GX6a2dF9PgSpQLTdw9ZaU8.jpg'),
(143128, 10205, 'Humanos Extraordinarios [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/306787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4zLq8GX6a2dF9PgSpQLTdw9ZaU8.jpg'),
(143129, 10205, 'Humanos Extraordinarios [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/306788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4zLq8GX6a2dF9PgSpQLTdw9ZaU8.jpg'),
(143130, 8008, 'Ilha dos Desafios S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ifvRJ1AIhdd0w4NpQsnyhKgQxtf.jpg'),
(143131, 8008, 'Ilha dos Desafios S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i3vxr4TQKIRawWkkkgfK5jkzLvK.jpg'),
(143132, 8008, 'Ilha dos Desafios S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZDW5a3TaP3j2ly2RYKHKnxKv38.jpg'),
(143133, 8008, 'Ilha dos Desafios S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tSA2RgoVLMYjg6nH9YtrvqI3fyw.jpg'),
(143134, 8008, 'Ilha dos Desafios S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gHZ479ETt4n0tE0zxzCgs70KDzY.jpg'),
(143135, 8008, 'Ilha dos Desafios S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sP07emK3DXxj8d3JDzrQvywKbhy.jpg'),
(143136, 8008, 'Ilha dos Desafios S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUZuCzQB6vzh2oUdJP8KpPotMiE.jpg'),
(143137, 8008, 'Ilha dos Desafios S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/306750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNrAXXDG7hhxTr194vgek5TBhXH.jpg'),
(143138, 8008, 'Ilha dos Desafios S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/306751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/slwyGB3BrW5FaEz4T1wn5B4NFd8.jpg'),
(143139, 8008, 'Ilha dos Desafios S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/306752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zlsTNJZA9tlgdIyUosQEicYnscb.jpg'),
(143140, 8008, 'Ilha dos Desafios S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/306753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AucMJPetcaUXxlB87vRDCw31UHH.jpg'),
(143141, 8008, 'Ilha dos Desafios S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/306754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qXYodovLGsHWMDcqR9IGbsmn7In.jpg'),
(143142, 8008, 'Ilha dos Desafios S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/306755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1BOnrgd0NUOMCsWSIEOCGJ6Ftmf.jpg'),
(143143, 10206, 'Ilha dos Desafios S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chocqjoV6JjMQgu0Bh0edVURgXT.jpg'),
(143144, 10206, 'Ilha dos Desafios S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chocqjoV6JjMQgu0Bh0edVURgXT.jpg'),
(143145, 10206, 'Ilha dos Desafios S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chocqjoV6JjMQgu0Bh0edVURgXT.jpg'),
(143146, 10206, 'Ilha dos Desafios S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chocqjoV6JjMQgu0Bh0edVURgXT.jpg'),
(143147, 10206, 'Ilha dos Desafios S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chocqjoV6JjMQgu0Bh0edVURgXT.jpg'),
(143148, 10206, 'Ilha dos Desafios S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chocqjoV6JjMQgu0Bh0edVURgXT.jpg'),
(143149, 10206, 'Ilha dos Desafios S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chocqjoV6JjMQgu0Bh0edVURgXT.jpg'),
(143150, 10206, 'Ilha dos Desafios S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/306763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chocqjoV6JjMQgu0Bh0edVURgXT.jpg'),
(143151, 10206, 'Ilha dos Desafios S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/306764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chocqjoV6JjMQgu0Bh0edVURgXT.jpg'),
(143152, 10206, 'Ilha dos Desafios S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/306765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chocqjoV6JjMQgu0Bh0edVURgXT.jpg'),
(143153, 10206, 'Ilha dos Desafios S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/306766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chocqjoV6JjMQgu0Bh0edVURgXT.jpg'),
(143154, 10206, 'Ilha dos Desafios S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/306767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chocqjoV6JjMQgu0Bh0edVURgXT.jpg'),
(143155, 10206, 'Ilha dos Desafios S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/306768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/chocqjoV6JjMQgu0Bh0edVURgXT.jpg'),
(143156, 10207, 'Nos Campos Do Holocausto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jo4JhWsEiapJPcpuEgcIjOj0CCl.jpg'),
(143157, 10207, 'Nos Campos Do Holocausto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/coafCri5GK3Mqev8vrxRAxeiPoL.jpg'),
(143158, 10207, 'Nos Campos Do Holocausto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h2ZwiC2JkwFti0jp6FXV7hPTeXd.jpg'),
(143159, 10207, 'Nos Campos Do Holocausto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e7ZwXUpxXsvll9pu7rWE2JRN9cE.jpg'),
(143160, 10207, 'Nos Campos Do Holocausto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nIi2UrzBJ9TEncZSUZmuLoeFmUx.jpg'),
(143161, 10207, 'Nos Campos Do Holocausto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vZYQzFlnrNVZ0PaK9RgggfzB7n9.jpg'),
(143162, 10207, 'Nos Campos Do Holocausto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBPZWiEBEmqgY5InI5qL7ShAM0Y.jpg'),
(143163, 10207, 'Nos Campos Do Holocausto S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/306739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3GFMS1g9zxXFnC1FyngtQRaqzjv.jpg'),
(143164, 10208, 'Nos Campos Do Holocausto S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4C4Mai6eLUFjB7W1uDffON5J0SR.jpg'),
(143165, 10208, 'Nos Campos Do Holocausto S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4C4Mai6eLUFjB7W1uDffON5J0SR.jpg'),
(143166, 10208, 'Nos Campos Do Holocausto S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4C4Mai6eLUFjB7W1uDffON5J0SR.jpg'),
(143167, 10209, 'O Rastreador [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v0f1co8p7V9L7EXm0cjKQisecAU.jpg'),
(143168, 10209, 'O Rastreador [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/317506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143169, 10209, 'O Rastreador [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/322444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143170, 10209, 'O Rastreador [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/323857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143171, 10209, 'O Rastreador [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/336279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143172, 10209, 'O Rastreador [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/340727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143173, 10209, 'O Rastreador [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143174, 10209, 'O Rastreador [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/358930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143175, 10209, 'O Rastreador [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/367273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143176, 10209, 'O Rastreador [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/373405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143177, 10209, 'O Rastreador [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/381941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143178, 10210, 'O Rastreador [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/482479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143179, 10210, 'O Rastreador [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/490609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143180, 10210, 'O Rastreador [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/523276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143181, 10210, 'O Rastreador [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/523277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143182, 10210, 'O Rastreador [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/523278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143183, 10210, 'O Rastreador [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/523279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143184, 10210, 'O Rastreador [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/523280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143185, 10210, 'O Rastreador [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/658871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143186, 10210, 'O Rastreador [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/701395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143187, 10210, 'O Rastreador [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/708945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143188, 10210, 'O Rastreador [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/717898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143189, 10210, 'O Rastreador [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/751073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143190, 10210, 'O Rastreador [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/753746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143191, 10210, 'O Rastreador [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/759886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143192, 10210, 'O Rastreador [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/759887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143193, 10210, 'O Rastreador [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/769518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143194, 10210, 'O Rastreador [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/796403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143195, 10210, 'O Rastreador [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/784953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143196, 10210, 'O Rastreador [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/796405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143197, 10210, 'O Rastreador [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/810986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143198, 10211, 'O Rastreador [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/889984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143199, 10211, 'O Rastreador [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/891775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143200, 10211, 'O Rastreador [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/892379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143201, 10211, 'O Rastreador [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/892572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143202, 10211, 'O Rastreador [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/893431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143203, 10211, 'O Rastreador [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/894168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143204, 10211, 'O Rastreador [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/895787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143205, 10211, 'O Rastreador [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/896893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143206, 10211, 'O Rastreador [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/896894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143207, 10212, 'Os Reis da Selva S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kPyPsHRv6kHcXGrwfWGtkRaPG1u.jpg'),
(143208, 10212, 'Os Reis da Selva S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kPyPsHRv6kHcXGrwfWGtkRaPG1u.jpg'),
(143209, 10212, 'Os Reis da Selva S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kPyPsHRv6kHcXGrwfWGtkRaPG1u.jpg'),
(143210, 10212, 'Os Reis da Selva S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kPyPsHRv6kHcXGrwfWGtkRaPG1u.jpg'),
(143211, 10212, 'Os Reis da Selva S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kPyPsHRv6kHcXGrwfWGtkRaPG1u.jpg'),
(143212, 10213, 'Rainha das Lagrimas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/euFZLQEqvZVz74Okt8iuKNI4RpU.jpg'),
(143213, 10213, 'Rainha das Lagrimas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJf4H6JLlgL1OVzfekAdX1RgUhc.jpg'),
(143214, 10213, 'Rainha das Lagrimas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/317325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6ehtxO71VhHegE3A3Uwi4A3TDwz.jpg'),
(143215, 10213, 'Rainha das Lagrimas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/317326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6ehtxO71VhHegE3A3Uwi4A3TDwz.jpg'),
(143216, 10213, 'Rainha das Lagrimas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/321284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6ehtxO71VhHegE3A3Uwi4A3TDwz.jpg'),
(143217, 10213, 'Rainha das Lagrimas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/321285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6ehtxO71VhHegE3A3Uwi4A3TDwz.jpg'),
(143218, 10213, 'Rainha das Lagrimas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/327318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6ehtxO71VhHegE3A3Uwi4A3TDwz.jpg'),
(143219, 10213, 'Rainha das Lagrimas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/327319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6ehtxO71VhHegE3A3Uwi4A3TDwz.jpg'),
(143220, 10213, 'Rainha das Lagrimas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/329336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6ehtxO71VhHegE3A3Uwi4A3TDwz.jpg'),
(143221, 10213, 'Rainha das Lagrimas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/329337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6ehtxO71VhHegE3A3Uwi4A3TDwz.jpg'),
(143222, 10213, 'Rainha das Lagrimas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/337269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6ehtxO71VhHegE3A3Uwi4A3TDwz.jpg'),
(143223, 10213, 'Rainha das Lagrimas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/337270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6ehtxO71VhHegE3A3Uwi4A3TDwz.jpg'),
(143224, 10213, 'Rainha das Lagrimas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/343751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6ehtxO71VhHegE3A3Uwi4A3TDwz.jpg'),
(143225, 10213, 'Rainha das Lagrimas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/343752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6ehtxO71VhHegE3A3Uwi4A3TDwz.jpg'),
(143226, 10213, 'Rainha das Lagrimas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/348505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6ehtxO71VhHegE3A3Uwi4A3TDwz.jpg'),
(143227, 10213, 'Rainha das Lagrimas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/348506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6ehtxO71VhHegE3A3Uwi4A3TDwz.jpg'),
(143228, 10214, 'Raw Terror S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/luAMx7V27gbIGFlWRB7c0kp5hEW.jpg'),
(143229, 10214, 'Raw Terror S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/luAMx7V27gbIGFlWRB7c0kp5hEW.jpg'),
(143230, 10214, 'Raw Terror S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/luAMx7V27gbIGFlWRB7c0kp5hEW.jpg'),
(143231, 10214, 'Raw Terror S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/luAMx7V27gbIGFlWRB7c0kp5hEW.jpg'),
(143232, 10214, 'Raw Terror S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/luAMx7V27gbIGFlWRB7c0kp5hEW.jpg'),
(143233, 10214, 'Raw Terror S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/luAMx7V27gbIGFlWRB7c0kp5hEW.jpg'),
(143234, 10215, 'SAND LAND A SERIE [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AiwqyIw2yBRphSvXbUZmbwf3FV1.jpg'),
(143235, 10215, 'SAND LAND A SERIE [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/89oSmm3vgYZOa66WkIc0zTqXlX0.jpg'),
(143236, 10215, 'SAND LAND A SERIE [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/61TsGXNx8Of5lQLWqCx79cWvu9k.jpg'),
(143237, 10215, 'SAND LAND A SERIE [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m7YakbK37GWkrMljSRT1HNkZ74k.jpg'),
(143238, 10215, 'SAND LAND A SERIE [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyBalsaIfmkljhrsMFqwqctP4z0.jpg'),
(143239, 10215, 'SAND LAND A SERIE [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qdLsHWIqBmEfwuSi4E2n1qbKibH.jpg'),
(143240, 10215, 'SAND LAND A SERIE [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r74IHKMIaGLmsfUwVLrtEjwt4Dr.jpg'),
(143241, 10215, 'SAND LAND A SERIE [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/317246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ttjlPYnxLQ48pEFGVFFmz4ukcM8.jpg'),
(143242, 10215, 'SAND LAND A SERIE [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/319381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ttjlPYnxLQ48pEFGVFFmz4ukcM8.jpg'),
(143243, 10215, 'SAND LAND A SERIE [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/327213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ttjlPYnxLQ48pEFGVFFmz4ukcM8.jpg'),
(143244, 10215, 'SAND LAND A SERIE [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/327606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ttjlPYnxLQ48pEFGVFFmz4ukcM8.jpg'),
(143245, 10215, 'SAND LAND A SERIE [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/335974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ttjlPYnxLQ48pEFGVFFmz4ukcM8.jpg'),
(143246, 10215, 'SAND LAND A SERIE [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/340135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ttjlPYnxLQ48pEFGVFFmz4ukcM8.jpg'),
(143247, 10216, 'Stranger [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r3NkW4kkOmumFVxZLfPmb6LPZ8h.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(143248, 10216, 'Stranger [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6cGVTwRafIKkzgv4QXIOSGTTm5M.jpg'),
(143249, 10216, 'Stranger [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pzmCCYq7vb630qpvTMQ2mLT4klQ.jpg'),
(143250, 10216, 'Stranger [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fwETChQZ0NWF57RUB86bKRxZG5C.jpg'),
(143251, 10216, 'Stranger [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/denwWyvMYaBf7K0OYqXyLc8R4ZB.jpg'),
(143252, 10216, 'Stranger [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6n4itbfzgCXr1qF30UZjggorvY3.jpg'),
(143253, 10216, 'Stranger [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n7C5zTiSRMVLYs9Gbjt5lcBjU8W.jpg'),
(143254, 10216, 'Stranger [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/306686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dYL1RV0OndKyrSffjFM6mUe55Ii.jpg'),
(143255, 10216, 'Stranger [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/306687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oq5O32xe9Ybi7iYbqj9bII3aAsb.jpg'),
(143256, 10216, 'Stranger [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/306688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n0BDZeeA1vAVQp4Xq6lSJJeIAoj.jpg'),
(143257, 10216, 'Stranger [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/306689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c7yjkVFhaeBqeWhHU1O3K2pBjb5.jpg'),
(143258, 10216, 'Stranger [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/306690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/end0rZrWymWUp6VTlnsSWsuBTfY.jpg'),
(143259, 10216, 'Stranger [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/306691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fgFg6HMZtCR3MtoutJfJhk1Ojtw.jpg'),
(143260, 10216, 'Stranger [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/306692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bXwzYEgZ286q4RcuAsblsWT9zgY.jpg'),
(143261, 10216, 'Stranger [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/306693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/31igDa6IkLzhQIH0dTlOSuJfutg.jpg'),
(143262, 10216, 'Stranger [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/306694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mL1EH1NzsFTiwkRZxCGizmunvTX.jpg'),
(143263, 10217, 'Stranger [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3xwBEO0vcU1ZE55wNHm72OwKIEI.jpg'),
(143264, 10217, 'Stranger [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2r7jMWWBGhaRi1kOp04sOqXmoTE.jpg'),
(143265, 10217, 'Stranger [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dGtlsURbgcX89OYbH2G3JwZf1tt.jpg'),
(143266, 10217, 'Stranger [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/atQcVjcF14HdhAxXKdk2AobIZSa.jpg'),
(143267, 10217, 'Stranger [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nUABAHUQ4ddfzDUoHEvj04jKDfb.jpg'),
(143268, 10217, 'Stranger [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qQzpKfWTSlFcrROqs6J2LOa4HK1.jpg'),
(143269, 10217, 'Stranger [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1VC2MmGghaAN5Mu98zlDixF2Fam.jpg'),
(143270, 10217, 'Stranger [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/306702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rySzipw0i1QHYxFArYgHlRxxYz3.jpg'),
(143271, 10217, 'Stranger [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/306703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FTH0EJrQRbOeRTCwEngQIoMmiN.jpg'),
(143272, 10217, 'Stranger [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/306704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vigmkobTpyd2VcX2eDmVJ1lKX2g.jpg'),
(143273, 10217, 'Stranger [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/306705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wz4yQ54SYGdAG9j0wez9OPoPnH1.jpg'),
(143274, 10217, 'Stranger [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/306706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9VkZb4tWnNIhmwImhHiUsilQNGO.jpg'),
(143275, 10217, 'Stranger [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/306707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpRdPqdd0DkIZipZwkd9Wl6PKo5.jpg'),
(143276, 10217, 'Stranger [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/306708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mp16B0Iunbpg9O6yO2KWQSEABIP.jpg'),
(143277, 10217, 'Stranger [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/306709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pWz1bHmtC1teYEYJOuhSh8Ow2Up.jpg'),
(143278, 10217, 'Stranger [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/306710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwcFzY5d8UM1USH3S8Bb8r32muJ.jpg'),
(143279, 10218, 'The Disappearance [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nhhcyIqxpHtr3Shi5qruIzAZ14D.jpg'),
(143280, 10218, 'The Disappearance [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDD9kC37m3dULk0WRJlhynpmjcX.jpg'),
(143281, 10218, 'The Disappearance [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tukWHaEyyA3mFWx7ztV0O1iZyNm.jpg'),
(143282, 10218, 'The Disappearance [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7WJLmr5lpAb3oSQDuiRhSvVF0Xu.jpg'),
(143283, 10218, 'The Disappearance [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j4ZdrqLtLEPEucIVs6UDOmKklGh.jpg'),
(143284, 10218, 'The Disappearance [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AlIWNKp1xj4Q1buPvZuBnYAgRe8.jpg'),
(143285, 10218, 'The Disappearance [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wDw0ItLofAmLoMUYxVyhdK4lI0p.jpg'),
(143286, 10219, 'Tico e Teco Vida no Parque S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hYGwNvHAwB0AlcZ0DumdlUp7NWD.jpg'),
(143287, 10219, 'Tico e Teco Vida no Parque S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7P2khCtSgOH5tHT10uqIy3wYkGo.jpg'),
(143288, 10219, 'Tico e Teco Vida no Parque S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iO83CX44WnO6DknijRLVeIKVsRq.jpg'),
(143289, 10219, 'Tico e Teco Vida no Parque S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ysYbzfA3PZIOAIVQlxicgc4SQ1b.jpg'),
(143290, 10219, 'Tico e Teco Vida no Parque S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mo7oaON4ykKAtsPtJrnFAiNBbvN.jpg'),
(143291, 10219, 'Tico e Teco Vida no Parque S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jLTay3FzVdQtZPpuVB6kzTrHwT5.jpg'),
(143292, 10219, 'Tico e Teco Vida no Parque S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aIi5HdwYb5bxLUk7u75XF5jnZyc.jpg'),
(143293, 10219, 'Tico e Teco Vida no Parque S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/306654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZlkOVqOME4fZ9mTmCeYvXj8zcB.jpg'),
(143294, 10219, 'Tico e Teco Vida no Parque S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/306655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wJbPRc2E1KT6w0Ze4DpO0N3gCNy.jpg'),
(143295, 10219, 'Tico e Teco Vida no Parque S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/306656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5zrADeJXPG1vaK0z5sG1XnOyvrW.jpg'),
(143296, 10219, 'Tico e Teco Vida no Parque S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/306657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rNzqbdaorEaoOM2sh3ajuVay20.jpg'),
(143297, 10219, 'Tico e Teco Vida no Parque S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/306658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dVVs3JLw5dRK7fNFNd4tWFIXJPL.jpg'),
(143298, 10220, 'Tico e Teco Vida no Parque S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tdgF72AK4BJpKN9kLsz6UKcyPXN.jpg'),
(143299, 10220, 'Tico e Teco Vida no Parque S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fHYh4nSf8wZFQVMhxztNsTsg0Fc.jpg'),
(143300, 10220, 'Tico e Teco Vida no Parque S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPGc03BgTc2OwJThojMxOeCVOsq.jpg'),
(143301, 10220, 'Tico e Teco Vida no Parque S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iW69aboivk6Mas6qkcW99Jxoa0y.jpg'),
(143302, 10220, 'Tico e Teco Vida no Parque S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b7Th8CYIQKvqqI4EQlspUQa7SgT.jpg'),
(143303, 10220, 'Tico e Teco Vida no Parque S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i2v8k4ImQlRfycFgEvEqcbzlG2T.jpg'),
(143304, 10220, 'Tico e Teco Vida no Parque S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXrdr6zutJyr0r2yDWOlhYqIk5t.jpg'),
(143305, 10220, 'Tico e Teco Vida no Parque S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/306666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXrdr6zutJyr0r2yDWOlhYqIk5t.jpg'),
(143306, 10220, 'Tico e Teco Vida no Parque S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/306667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXrdr6zutJyr0r2yDWOlhYqIk5t.jpg'),
(143307, 10220, 'Tico e Teco Vida no Parque S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/306668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXrdr6zutJyr0r2yDWOlhYqIk5t.jpg'),
(143308, 10220, 'Tico e Teco Vida no Parque S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/306669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXrdr6zutJyr0r2yDWOlhYqIk5t.jpg'),
(143309, 10220, 'Tico e Teco Vida no Parque S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/306670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXrdr6zutJyr0r2yDWOlhYqIk5t.jpg'),
(143310, 10220, 'Tico e Teco Vida no Parque S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/306671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXrdr6zutJyr0r2yDWOlhYqIk5t.jpg'),
(143311, 10221, 'Time S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n1kaMJ2XZNMX8HydArJu6bT13OB.jpg'),
(143312, 10221, 'Time S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/93Vo85d0IifFFjwUW5CvmRvGIzW.jpg'),
(143313, 10221, 'Time S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sRoDMH722blLSPBB5Sfvwldjjlm.jpg'),
(143314, 10221, 'Time S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nSxE6STKTRWb5XLNJgH6q2AKGas.jpg'),
(143315, 10222, 'Time S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rQhVK6ru4vtLuhECTVqX62xDCV.jpg'),
(143316, 10222, 'Time S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUSeRzX6ow9JX3ZvSH1BxHZtEDW.jpg'),
(143317, 10222, 'Time S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ij8OTsE8MZJisUUnEM3UMwwzaHT.jpg'),
(143318, 10222, 'Time S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nSxE6STKTRWb5XLNJgH6q2AKGas.jpg'),
(143319, 10223, 'Viva a Sua Propria Vida [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j96Vur8iAjEwuOjJRAaJOGpLqEb.jpg'),
(143320, 10223, 'Viva a Sua Propria Vida [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oUBkPtBsQcU1OvRY7juULTDTtT2.jpg'),
(143321, 10223, 'Viva a Sua Propria Vida [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z9Qj0WzWkXjM25b4wiHHPw6B0yh.jpg'),
(143322, 10223, 'Viva a Sua Propria Vida [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Q1J2dH7GBZEY8fvHb4sDpuI8pK.jpg'),
(143323, 10223, 'Viva a Sua Propria Vida [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7WVSvgfppNTkG2FwqFMitju5A3P.jpg'),
(143324, 10223, 'Viva a Sua Propria Vida [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/36V3OCmGfT2ZWinzMP3FFwV1R93.jpg'),
(143325, 10223, 'Viva a Sua Propria Vida [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LGrvp8LMRbAKXVkEtUxOU6GvnK.jpg'),
(143326, 10223, 'Viva a Sua Propria Vida [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/306595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/atQ86Xgyl09Iw7xtNPHOs0XVpt0.jpg'),
(143327, 10223, 'Viva a Sua Propria Vida [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/306596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l5s5OZ0DZfoJhzzxDk5rH5dErho.jpg'),
(143328, 10223, 'Viva a Sua Propria Vida [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/306597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zKdQXbDPcPvCV9LGbwioU1z470O.jpg'),
(143329, 10223, 'Viva a Sua Propria Vida [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/306598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o85tQwtsdZSOkSzE0OU4ZwvJRpu.jpg'),
(143330, 10223, 'Viva a Sua Propria Vida [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/306599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ggZtHi7i9Fw2piD9K0U3jTwRgP.jpg'),
(143331, 10223, 'Viva a Sua Propria Vida [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/306600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qEiZt9Gve11uCkt557OwzqJ3DtL.jpg'),
(143332, 10223, 'Viva a Sua Propria Vida [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/306601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iAH43xrevjfNpzEWJkA8AnCR0Ka.jpg'),
(143333, 10223, 'Viva a Sua Propria Vida [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/306602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8DfVgnwDM2Dwrt6FNw5X6cZWf8P.jpg'),
(143334, 10223, 'Viva a Sua Propria Vida [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/306603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/krkVDfuBSzIyN6yvzv26BI0aCQY.jpg'),
(143335, 10223, 'Viva a Sua Propria Vida [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/306604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nyY5vRlOhS0BCStDRw0MwQ7vF61.jpg'),
(143336, 10223, 'Viva a Sua Propria Vida [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/306605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCmPzwTqLEGrXFWmKRckfJIV2ck.jpg'),
(143337, 10223, 'Viva a Sua Propria Vida [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/306606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4v9FsxoG5pwJP6mVVMFbXyKYI3L.jpg'),
(143338, 10223, 'Viva a Sua Propria Vida [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/306607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ilKLReXWzOk22SBUczGIh9n2RYO.jpg'),
(143339, 10223, 'Viva a Sua Propria Vida [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/306608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7WgfbEO8kzSPPuRQLzzsTpXbRAY.jpg'),
(143340, 10223, 'Viva a Sua Propria Vida [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/306609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKOkGtFPVMUBZpLlSGgrj8z7I3E.jpg'),
(143341, 10223, 'Viva a Sua Propria Vida [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/306610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nbcLkthS0rHktyMqYhQvD6Ieoka.jpg'),
(143342, 10223, 'Viva a Sua Propria Vida [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/306611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6dZW0uYUDCYy2vSEaLyqxSkoUf.jpg'),
(143343, 10223, 'Viva a Sua Propria Vida [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/306612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/esuv3g1ny9BDOV3ez5DrgUVTjLx.jpg'),
(143344, 10223, 'Viva a Sua Propria Vida [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/306613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pohmHlyfZCzc026SBilsnD0hW4o.jpg'),
(143345, 10223, 'Viva a Sua Propria Vida [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/306614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8gle2pA9FiLgldVHGMeTMwgCnBI.jpg'),
(143346, 10223, 'Viva a Sua Propria Vida [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/306615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2otsUPSvMqE6RFntfYrQfTCvcOo.jpg'),
(143347, 10223, 'Viva a Sua Propria Vida [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/306616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eExK1KIzidG5wmIN0l5o7UpzlTH.jpg'),
(143348, 10223, 'Viva a Sua Propria Vida [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/306617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6jfM7hlpNpPG1AtFfW1zKP77CTf.jpg'),
(143349, 10223, 'Viva a Sua Propria Vida [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/306618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2kUEFBdQaW9Vw3qdim8x1SzDsXy.jpg'),
(143350, 10223, 'Viva a Sua Propria Vida [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/306619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gyz8M75EbteDYVkNvs23KKXHYbE.jpg'),
(143351, 10223, 'Viva a Sua Propria Vida [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/306620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9I6HAMWFrsXCIWD6KgwZ37mcAdl.jpg'),
(143352, 10223, 'Viva a Sua Propria Vida [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/306621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n0ckHiwbOdRnN4BjtWd0wvef30t.jpg'),
(143353, 10223, 'Viva a Sua Propria Vida [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/306622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qq3IQ8zyiBzZYxGOhvMXEzKr7RB.jpg'),
(143354, 10223, 'Viva a Sua Propria Vida [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/306623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uspFEB7KbQcVccMe7nRTpdO1fH7.jpg'),
(143355, 10223, 'Viva a Sua Propria Vida [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/306624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5dMjgY4LqHYqlyq0w6zXsy1gH3v.jpg'),
(143356, 10223, 'Viva a Sua Propria Vida [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/306625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nxw2nPwD9nVzoYUEatTJIk9L5fy.jpg'),
(143357, 10223, 'Viva a Sua Propria Vida [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/306626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/196jyRdVjWmWF66aL0SO0WLSH9x.jpg'),
(143358, 10223, 'Viva a Sua Propria Vida [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/306627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63QpH0AYhKMrV0C8BXBs97PguOI.jpg'),
(143359, 10223, 'Viva a Sua Propria Vida [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/306628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dSTFOJuTv7ccOkcCipvbHbFKO9x.jpg'),
(143360, 10223, 'Viva a Sua Propria Vida [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/306629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1eFV781pxbz9s7P82MHs1lvcSNL.jpg'),
(143361, 10223, 'Viva a Sua Propria Vida [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/306630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1MQVU0Q0AXCtWkty88CAbfy4MlF.jpg'),
(143362, 10223, 'Viva a Sua Propria Vida [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/306631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eJz3L8AiJmDL9nxhRUMhcJcu9TJ.jpg'),
(143363, 10223, 'Viva a Sua Propria Vida [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/306632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2VpIcQZX7kO3IEkXmHa47DO6Lz9.jpg'),
(143364, 10223, 'Viva a Sua Propria Vida [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/306633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dLcpYhgDtvsp7BoPQeCgWMgUGBd.jpg'),
(143365, 10223, 'Viva a Sua Propria Vida [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/306634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kDQKC6ATlVXWZbHgKQ9zq2fwU3B.jpg'),
(143366, 10223, 'Viva a Sua Propria Vida [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/306635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Pt1BpFuwRz1GEzOVWJ5vdATlaN.jpg'),
(143367, 10223, 'Viva a Sua Propria Vida [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/306636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r4LZFge43tCHXCj9NPS9Q3NbBMD.jpg'),
(143368, 10223, 'Viva a Sua Propria Vida [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/306637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wmfjoTro2oRLPKsvqaOazR8hqbJ.jpg'),
(143369, 10223, 'Viva a Sua Propria Vida [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/306638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zmk3zmgFYdOHHyX3wtCnQQOfviU.jpg'),
(143370, 10224, 'Wotakoi O Amor e Dificil para Otaku [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/306577.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/m3bGZApoBomEwpp0mUEUn4NCVHV.jpg'),
(143371, 10224, 'Wotakoi O Amor e Dificil para Otaku [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/306578.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/m3bGZApoBomEwpp0mUEUn4NCVHV.jpg'),
(143372, 10224, 'Wotakoi O Amor e Dificil para Otaku [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/306579.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/m3bGZApoBomEwpp0mUEUn4NCVHV.jpg'),
(143373, 10224, 'Wotakoi O Amor e Dificil para Otaku [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/306580.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/m3bGZApoBomEwpp0mUEUn4NCVHV.jpg'),
(143374, 10224, 'Wotakoi O Amor e Dificil para Otaku [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/306581.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/m3bGZApoBomEwpp0mUEUn4NCVHV.jpg'),
(143375, 10224, 'Wotakoi O Amor e Dificil para Otaku [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/306582.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/m3bGZApoBomEwpp0mUEUn4NCVHV.jpg'),
(143376, 10224, 'Wotakoi O Amor e Dificil para Otaku [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/306583.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/m3bGZApoBomEwpp0mUEUn4NCVHV.jpg'),
(143377, 10224, 'Wotakoi O Amor e Dificil para Otaku [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/306584.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/m3bGZApoBomEwpp0mUEUn4NCVHV.jpg'),
(143378, 10224, 'Wotakoi O Amor e Dificil para Otaku [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/306585.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/m3bGZApoBomEwpp0mUEUn4NCVHV.jpg'),
(143379, 10224, 'Wotakoi O Amor e Dificil para Otaku [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/306586.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/m3bGZApoBomEwpp0mUEUn4NCVHV.jpg'),
(143380, 10224, 'Wotakoi O Amor e Dificil para Otaku [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/306587.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/m3bGZApoBomEwpp0mUEUn4NCVHV.jpg'),
(143381, 10225, 'O Proximo Empreendedor com Gordon Ramsay S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/312311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yBY9imhVmCC8jqh1xMeBD5ngZ8c.jpg'),
(143382, 10225, 'O Proximo Empreendedor com Gordon Ramsay S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/312312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOk9rWeomm63XpbGlncPUMvinTF.jpg'),
(143383, 10225, 'O Proximo Empreendedor com Gordon Ramsay S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/312313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGkwYB8wAtK6tBnENipSWYu10CR.jpg'),
(143384, 10225, 'O Proximo Empreendedor com Gordon Ramsay S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/312314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGkwYB8wAtK6tBnENipSWYu10CR.jpg'),
(143385, 10225, 'O Proximo Empreendedor com Gordon Ramsay S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/322449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGkwYB8wAtK6tBnENipSWYu10CR.jpg'),
(143386, 10225, 'O Proximo Empreendedor com Gordon Ramsay S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/322450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGkwYB8wAtK6tBnENipSWYu10CR.jpg'),
(143387, 10225, 'O Proximo Empreendedor com Gordon Ramsay S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/325512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGkwYB8wAtK6tBnENipSWYu10CR.jpg'),
(143388, 10225, 'O Proximo Empreendedor com Gordon Ramsay S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/325513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGkwYB8wAtK6tBnENipSWYu10CR.jpg'),
(143389, 10225, 'O Proximo Empreendedor com Gordon Ramsay S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/467081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGkwYB8wAtK6tBnENipSWYu10CR.jpg'),
(143390, 10225, 'O Proximo Empreendedor com Gordon Ramsay S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/467082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGkwYB8wAtK6tBnENipSWYu10CR.jpg'),
(143391, 10226, 'O Proximo Empreendedor com Gordon Ramsay S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/467083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGkwYB8wAtK6tBnENipSWYu10CR.jpg'),
(143392, 10226, 'O Proximo Empreendedor com Gordon Ramsay S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/473888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGkwYB8wAtK6tBnENipSWYu10CR.jpg'),
(143393, 10226, 'O Proximo Empreendedor com Gordon Ramsay S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/477299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGkwYB8wAtK6tBnENipSWYu10CR.jpg'),
(143394, 10226, 'O Proximo Empreendedor com Gordon Ramsay S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/488496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGkwYB8wAtK6tBnENipSWYu10CR.jpg'),
(143395, 10226, 'O Proximo Empreendedor com Gordon Ramsay S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/514270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGkwYB8wAtK6tBnENipSWYu10CR.jpg'),
(143396, 10226, 'O Proximo Empreendedor com Gordon Ramsay S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/514271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGkwYB8wAtK6tBnENipSWYu10CR.jpg'),
(143397, 10226, 'O Proximo Empreendedor com Gordon Ramsay S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/514272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGkwYB8wAtK6tBnENipSWYu10CR.jpg'),
(143398, 10226, 'O Proximo Empreendedor com Gordon Ramsay S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/514273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGkwYB8wAtK6tBnENipSWYu10CR.jpg'),
(143399, 10226, 'O Proximo Empreendedor com Gordon Ramsay S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/514274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGkwYB8wAtK6tBnENipSWYu10CR.jpg'),
(143400, 10226, 'O Proximo Empreendedor com Gordon Ramsay S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/514275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tGkwYB8wAtK6tBnENipSWYu10CR.jpg'),
(143401, 10227, 'A Esposa do Meu Marido S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/309471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nVRML7uH6G8lFGfSGle83tj7h58.jpg'),
(143402, 10227, 'A Esposa do Meu Marido S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/309472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sdE9Hy22F65glApLVzjhLW6L20q.jpg'),
(143403, 10227, 'A Esposa do Meu Marido S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/309473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iMP9iL1swusvq37KX7KknHHLnqE.jpg'),
(143404, 10227, 'A Esposa do Meu Marido S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/309474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kwjhSxIONMkurKVcrE7BrdVvngH.jpg'),
(143405, 10227, 'A Esposa do Meu Marido S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/309475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i60dhE7IyM9WWMmKg5feySm44Tv.jpg'),
(143406, 10227, 'A Esposa do Meu Marido S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/309476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1ILrGUH1xXRJJ5vzdLhXSiR0iq.jpg'),
(143407, 10227, 'A Esposa do Meu Marido S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/309477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eCKYXbGvmlcPeuLs3axhQr6vphz.jpg'),
(143408, 10227, 'A Esposa do Meu Marido S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/309478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bMK9OG2uTMKFEuGKjh8CKDcH5W6.jpg'),
(143409, 10227, 'A Esposa do Meu Marido S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/309479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tORlOQ8lDpAfCe5zuNnzzO3fGNL.jpg'),
(143410, 10227, 'A Esposa do Meu Marido S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/309480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Idt6zXquBBBI7IwpGI3y6jgqQn.jpg'),
(143411, 10227, 'A Esposa do Meu Marido S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/309481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/asnxhHjXNveBi99gBLzNeFuPsMQ.jpg'),
(143412, 10227, 'A Esposa do Meu Marido S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/309482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mt2jVse54EjBGk3mKRVwOewjlQh.jpg'),
(143413, 10227, 'A Esposa do Meu Marido S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/309483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBmTJSuPTLmeOy0eLgR5QW9lzD.jpg'),
(143414, 10227, 'A Esposa do Meu Marido S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/309484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lQrtAhqvleWA5CNv0YR1e0tU96T.jpg'),
(143415, 10227, 'A Esposa do Meu Marido S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/309485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kHSv09qrPLccwexoX0xGmtOx2Qt.jpg'),
(143416, 10227, 'A Esposa do Meu Marido S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/309486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mAqCmdKDFNcujU79g9465VKBiL8.jpg'),
(143417, 10228, 'Absoluta Conviccao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/597651.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xBKKNTmj2ejABQ2SvIRrCMNmmqA.jpg'),
(143418, 10228, 'Absoluta Conviccao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/597652.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3BYk8oppn0xGtGk85jdmV3HUOMT.jpg'),
(143419, 10228, 'Absoluta Conviccao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/597653.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pVmmqHZTRtRjEaIbhhdPsTaYchs.jpg'),
(143420, 10228, 'Absoluta Conviccao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/309458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xtavQHKPu81WSGLuVA1MUCBWURx.jpg'),
(143421, 10228, 'Absoluta Conviccao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/309459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l6mJ1ZnmspPah5SYtLhU2945GkF.jpg'),
(143422, 10228, 'Absoluta Conviccao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/309460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bl0AC63dBDfq7Plm4gzGV7NgI1A.jpg'),
(143423, 10229, 'Absoluta Conviccao S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/309461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ejpdhlD4nNjRKME1sNiio30Id43.jpg'),
(143424, 10229, 'Absoluta Conviccao S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/309462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bt0EhPRyziTmnZuPB8jEw5Nz575.jpg'),
(143425, 10229, 'Absoluta Conviccao S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/309463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vIgp4zocV6pjQ8vpUQkNZKRilUc.jpg'),
(143426, 10229, 'Absoluta Conviccao S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/309464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aAHcWWnVVqIFh166jsvJdWtQNDE.jpg'),
(143427, 10229, 'Absoluta Conviccao S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/309465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vMRD8jz7SwaCwNpVTEcIBDJqkf6.jpg'),
(143428, 10229, 'Absoluta Conviccao S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/309466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eWrNc5UxOzUZ1vdimAfHoImoYt8.jpg'),
(143429, 10229, 'Absoluta Conviccao S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/309467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n1cb54yd4RDKGw45sbKe9BfpkSH.jpg'),
(143430, 10229, 'Absoluta Conviccao S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/309468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4FToAsp3Nhbn4ZJiAgPmkVZNq13.jpg'),
(143431, 10229, 'Absoluta Conviccao S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/309469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4iNH4zarPwA4DvXGYB6IHfelgqx.jpg'),
(143432, 10229, 'Absoluta Conviccao S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/309470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pWXUFDUXa55dkVkpPNY1XI5NIuc.jpg'),
(143433, 10230, 'Desejos SA S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/309449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AuVe8DcIAxOlsJIhLMsISa8wVxc.jpg'),
(143434, 10230, 'Desejos SA S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/309450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AuVe8DcIAxOlsJIhLMsISa8wVxc.jpg'),
(143435, 10230, 'Desejos SA S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/309451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AuVe8DcIAxOlsJIhLMsISa8wVxc.jpg'),
(143436, 10230, 'Desejos SA S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/309452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AuVe8DcIAxOlsJIhLMsISa8wVxc.jpg'),
(143437, 10230, 'Desejos SA S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/309453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AuVe8DcIAxOlsJIhLMsISa8wVxc.jpg'),
(143438, 10230, 'Desejos SA S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/309454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AuVe8DcIAxOlsJIhLMsISa8wVxc.jpg'),
(143439, 10231, 'Happy Tree Friends S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/309436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mLJv1qDarvfbc83mqHWYMaUKZHU.jpg'),
(143440, 10231, 'Happy Tree Friends S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/309437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qJCGVBbVIAWrvr9R2b2HG7YEwdR.jpg'),
(143441, 10231, 'Happy Tree Friends S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/309438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pdgwmzLEx4NxeL3drVi2mq64vbt.jpg'),
(143442, 10231, 'Happy Tree Friends S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/309439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/OxYiceYDPAl59ONaDusR1BbPIm.jpg'),
(143443, 10231, 'Happy Tree Friends S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/309440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kPMtcPZNZqCVOq5N5iOtsZmGuJW.jpg'),
(143444, 10231, 'Happy Tree Friends S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/309441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e4XwVppBNStdSrRssKhaTQSnTrJ.jpg'),
(143445, 10231, 'Happy Tree Friends S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/309442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ynd86mahU8OUNsmPThl89nlEZTA.jpg'),
(143446, 10231, 'Happy Tree Friends S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/309443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7EVyzrF7IOcrffkH3ypCdzb7YsT.jpg'),
(143447, 10231, 'Happy Tree Friends S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/309444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u7OvnCPSBMVIaU0A9k2YCWDVuol.jpg'),
(143448, 10231, 'Happy Tree Friends S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/309445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3P8yB7bPlbEjJHDLSGnYfmT9H6X.jpg'),
(143449, 10231, 'Happy Tree Friends S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/309446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4XQ0BzXzF3uS3slthKBkw1aBFEv.jpg'),
(143450, 10231, 'Happy Tree Friends S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/309447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aIKi8ctpGTwwzDxUm0JOlETzOW4.jpg'),
(143451, 10231, 'Happy Tree Friends S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/309448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rAz0hZtXbkbUrPdv43gmmdIdfR0.jpg'),
(143452, 10232, 'Largados em Alto Mar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/309435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gkbBb5AuH1IptGR53gRhWgQPD2k.jpg'),
(143453, 10232, 'Largados em Alto Mar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/317574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gkbBb5AuH1IptGR53gRhWgQPD2k.jpg'),
(143454, 10232, 'Largados em Alto Mar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/327709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gkbBb5AuH1IptGR53gRhWgQPD2k.jpg'),
(143455, 10232, 'Largados em Alto Mar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/332534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gkbBb5AuH1IptGR53gRhWgQPD2k.jpg'),
(143456, 10232, 'Largados em Alto Mar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/352095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gkbBb5AuH1IptGR53gRhWgQPD2k.jpg'),
(143457, 10232, 'Largados em Alto Mar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/352096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gkbBb5AuH1IptGR53gRhWgQPD2k.jpg'),
(143458, 10232, 'Largados em Alto Mar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/352097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gkbBb5AuH1IptGR53gRhWgQPD2k.jpg'),
(143459, 10232, 'Largados em Alto Mar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/352098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gkbBb5AuH1IptGR53gRhWgQPD2k.jpg'),
(143460, 10232, 'Largados em Alto Mar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/359512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gkbBb5AuH1IptGR53gRhWgQPD2k.jpg'),
(143461, 10233, 'Um Dia Qualquer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/309430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yKIKmbqixkt9ax6g7Z0aG8NoHzv.jpg'),
(143462, 10233, 'Um Dia Qualquer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/309431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dKKQizLwHU2YzvVREN9e5rsz8aX.jpg'),
(143463, 10233, 'Um Dia Qualquer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/309432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dNRb1WBPYjdxFefmwRkzId1AkkM.jpg'),
(143464, 10233, 'Um Dia Qualquer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/309433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iejUdq2yn83T0SWMqPfeW4DlUAY.jpg'),
(143465, 10233, 'Um Dia Qualquer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/309434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o0zrinhkbgUwAguJGnUkgwDAgE7.jpg'),
(143466, 10234, 'Um Dia Qualquer S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/629344.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yoEyw9e6TxrDJbPuDX3zH7ziWeH.jpg'),
(143467, 10234, 'Um Dia Qualquer S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506750.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uk9gIOwxfnAqEgbVHc2hp9ishqi.jpg'),
(143468, 10234, 'Um Dia Qualquer S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/629346.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hvVykwZ1FuNLCbh1vp0HaxojtfU.jpg'),
(143469, 10234, 'Um Dia Qualquer S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506752.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1QW9c1jFnLT7LOzGRAdkLIlSZ3u.jpg'),
(143470, 10234, 'Um Dia Qualquer S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506753.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ibBMBFyzGdQW9gANdPxuLqcyalW.jpg'),
(143471, 10234, 'Um Dia Qualquer S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/629349.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3pcuxzc58qMYkrMGgdqckWj6srO.jpg'),
(143472, 10235, 'Dra Colon A Rainha dos Estalos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/312928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cDHQRzQpH7XKwq1mYWgII6j0t9r.jpg'),
(143473, 10235, 'Dra Colon A Rainha dos Estalos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/312929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vkAaZVZIzU8rg3ysYeLgx1vZmK9.jpg'),
(143474, 10235, 'Dra Colon A Rainha dos Estalos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/312930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8S8A4Zgb3Vu9YTfKYhMcGYd1Yet.jpg'),
(143475, 10236, 'Largados e Pelados Latinos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/312914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yzHyxjjLDOSLqsrPOkMWYRNTbDM.jpg'),
(143476, 10236, 'Largados e Pelados Latinos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/312915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zoSnEupIj4B4p7qPfmKA1uZeymS.jpg'),
(143477, 10236, 'Largados e Pelados Latinos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/312916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/21wnoJ4E1bLoK0OLx1RoFtVjXz6.jpg'),
(143478, 10236, 'Largados e Pelados Latinos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/312917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6sgLWFaBYrB4j3V4Vn0gDTYXvUr.jpg'),
(143479, 10236, 'Largados e Pelados Latinos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/312918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aN4I6Nn03u2Wt9k2w0dVvXdkWL7.jpg'),
(143480, 10236, 'Largados e Pelados Latinos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/312919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5McjgEPhCvnFvmsaEyO0uKW6JGl.jpg'),
(143481, 10236, 'Largados e Pelados Latinos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/312920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2k3FTO0QGHNLvXYSaOveRqMWQC.jpg'),
(143482, 10237, 'Largados e Pelados Latinos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/312921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/haX5JWo1IViABq2hMQ5AiJhFatV.jpg'),
(143483, 10237, 'Largados e Pelados Latinos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/312922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/haX5JWo1IViABq2hMQ5AiJhFatV.jpg'),
(143484, 10237, 'Largados e Pelados Latinos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/312923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/haX5JWo1IViABq2hMQ5AiJhFatV.jpg'),
(143485, 10237, 'Largados e Pelados Latinos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/312924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/haX5JWo1IViABq2hMQ5AiJhFatV.jpg'),
(143486, 10237, 'Largados e Pelados Latinos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/312925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/haX5JWo1IViABq2hMQ5AiJhFatV.jpg'),
(143487, 10237, 'Largados e Pelados Latinos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/312926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/haX5JWo1IViABq2hMQ5AiJhFatV.jpg'),
(143488, 10237, 'Largados e Pelados Latinos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/312927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/haX5JWo1IViABq2hMQ5AiJhFatV.jpg'),
(143489, 10238, 'Largados e Pelados Latinos S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/751886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/haX5JWo1IViABq2hMQ5AiJhFatV.jpg'),
(143490, 10238, 'Largados e Pelados Latinos S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/751887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/haX5JWo1IViABq2hMQ5AiJhFatV.jpg'),
(143491, 10238, 'Largados e Pelados Latinos S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/751888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/haX5JWo1IViABq2hMQ5AiJhFatV.jpg'),
(143492, 10238, 'Largados e Pelados Latinos S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/751889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/haX5JWo1IViABq2hMQ5AiJhFatV.jpg'),
(143493, 10238, 'Largados e Pelados Latinos S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/751890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/haX5JWo1IViABq2hMQ5AiJhFatV.jpg'),
(143494, 10238, 'Largados e Pelados Latinos S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/751891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/haX5JWo1IViABq2hMQ5AiJhFatV.jpg'),
(143495, 10238, 'Largados e Pelados Latinos S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/751892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/haX5JWo1IViABq2hMQ5AiJhFatV.jpg'),
(143496, 10239, 'Maes E Filhos Assassinato em Familia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/312907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4rcxmYDA1UGFjTkt6dGgpsT8kaE.jpg'),
(143497, 10239, 'Maes E Filhos Assassinato em Familia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/312908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPpKeb96544F2bqXuQgn5kKRHIS.jpg'),
(143498, 10239, 'Maes E Filhos Assassinato em Familia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/312909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pD5gGdhHlp4qu6sKGopXBm4sSuS.jpg'),
(143499, 10239, 'Maes E Filhos Assassinato em Familia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/312910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pGzPWTbiU0WLIgNJtOJBaLuyfU.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(143500, 10239, 'Maes E Filhos Assassinato em Familia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/312911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bwusWyiZ7zQuYs3O9a9fP6H4Hea.jpg'),
(143501, 10239, 'Maes E Filhos Assassinato em Familia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/312912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Jv42hh2sqfx2njHLrCnQPdlFvv.jpg'),
(143502, 10239, 'Maes E Filhos Assassinato em Familia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/312913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6emTjj1sSlPtX7VStYRLRk9ofw.jpg'),
(143503, 10240, 'Nell a Renegada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/312899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ugI6baOIpcA5nCDXHDLmZ2IQVg6.jpg'),
(143504, 10240, 'Nell a Renegada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/312900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pgBBy9pQjTGDV6ZAliGilsgyoQv.jpg'),
(143505, 10240, 'Nell a Renegada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/312901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jap6MgI7ZCh5W3wCw0iREmMLoEL.jpg'),
(143506, 10240, 'Nell a Renegada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/312902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c9Q3xOGTMhUmhVrCsd3afoJ78Ep.jpg'),
(143507, 10240, 'Nell a Renegada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/312903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kIj7J8IqXyQIQCLyrVLbLrbns0d.jpg'),
(143508, 10240, 'Nell a Renegada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/312904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hVVDZRwLDdU6DOtxnVn8ymHPkGA.jpg'),
(143509, 10240, 'Nell a Renegada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/312905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qoPMBoFAqh7MN4twARxcBO9m2Eg.jpg'),
(143510, 10240, 'Nell a Renegada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/312906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wWrbT3JrqD8Nylblh5BmsAg6g4T.jpg'),
(143511, 10241, 'Ourika Cidade em Chamas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/312892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/olEVPWx1s4728KXP39XNC8CO7NA.jpg'),
(143512, 10241, 'Ourika Cidade em Chamas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/312893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/afGOcNzfaaT8nGcFVXmb30r5s8B.jpg'),
(143513, 10241, 'Ourika Cidade em Chamas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/312894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aCHO1vqURQq9V30bHgcGQ7dSvmK.jpg'),
(143514, 10241, 'Ourika Cidade em Chamas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/312895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dAQfaqY57hw8reysRxDEy58SC6H.jpg'),
(143515, 10241, 'Ourika Cidade em Chamas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/312896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j34YVlqpz3mGyhBqRI7yDIwxHFt.jpg'),
(143516, 10241, 'Ourika Cidade em Chamas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/312897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/92gn2V0FgwQkE0AKxV88nXmspaR.jpg'),
(143517, 10241, 'Ourika Cidade em Chamas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/312898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9rTDnqGnDU60NUhGnNfl08jfiQQ.jpg'),
(143518, 10242, 'Fritada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/319186.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143519, 10242, 'Fritada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/319187.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143520, 10242, 'Fritada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/319188.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143521, 10242, 'Fritada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/319189.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143522, 10242, 'Fritada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/319190.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143523, 10242, 'Fritada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/319191.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143524, 10242, 'Fritada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/319192.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143525, 10242, 'Fritada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/319193.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143526, 10242, 'Fritada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/319194.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143527, 10242, 'Fritada S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/319195.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143528, 10242, 'Fritada S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/319196.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143529, 10242, 'Fritada S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/319197.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143530, 10242, 'Fritada S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/319198.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143531, 10242, 'Fritada S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/319199.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143532, 10242, 'Fritada S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/319200.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143533, 10242, 'Fritada S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/319201.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143534, 10242, 'Fritada S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/319202.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143535, 10242, 'Fritada S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/319203.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143536, 10242, 'Fritada S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/319204.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143537, 10242, 'Fritada S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/319205.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143538, 10242, 'Fritada S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/319206.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143539, 10242, 'Fritada S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/319207.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143540, 10242, 'Fritada S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/597088.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143541, 10242, 'Fritada S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/319210.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143542, 10242, 'Fritada S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/319211.mp4', 'https://i.ibb.co/0C5b9jF/maxresdefault-1.jpg'),
(143543, 10243, 'Adivinhe quem eu sou [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/319179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rXiQw1K4P2ICdtBXHcC5us7cCa.jpg'),
(143544, 10243, 'Adivinhe quem eu sou [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/319180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6bOsCEILuoSpefnksEbpAOzmbhu.jpg'),
(143545, 10243, 'Adivinhe quem eu sou [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/319181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7da8NiLrKzwOpbkpvBdFrgoNo51.jpg'),
(143546, 10243, 'Adivinhe quem eu sou [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/319182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pvqtmZwRlIVYy7yfUGVbQOi5nJQ.jpg'),
(143547, 10243, 'Adivinhe quem eu sou [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/319183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2D5aYpuv6YfM6LMv08JjgFvq6n.jpg'),
(143548, 10243, 'Adivinhe quem eu sou [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/319184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4CtX5jii8fyyYBTYoICoSFfrzn0.jpg'),
(143549, 10243, 'Adivinhe quem eu sou [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/319185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/stZv5Vfhbsa8N0EpY7VKXnTtsl1.jpg'),
(143550, 10243, 'Adivinhe quem eu sou [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/320002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdZUhbCLqPYh3UZ2qYO1giM7o54.jpg'),
(143551, 10243, 'Adivinhe quem eu sou [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/320003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdZUhbCLqPYh3UZ2qYO1giM7o54.jpg'),
(143552, 10243, 'Adivinhe quem eu sou [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/320004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdZUhbCLqPYh3UZ2qYO1giM7o54.jpg'),
(143553, 10243, 'Adivinhe quem eu sou [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/320005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdZUhbCLqPYh3UZ2qYO1giM7o54.jpg'),
(143554, 10243, 'Adivinhe quem eu sou [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/320006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdZUhbCLqPYh3UZ2qYO1giM7o54.jpg'),
(143555, 10243, 'Adivinhe quem eu sou [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/320007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdZUhbCLqPYh3UZ2qYO1giM7o54.jpg'),
(143556, 10243, 'Adivinhe quem eu sou [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/323069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdZUhbCLqPYh3UZ2qYO1giM7o54.jpg'),
(143557, 10244, 'Boku to Roboko [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/319151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nS9lPMBAstH7sMlJVdgHQrfZQLU.jpg'),
(143558, 10244, 'Boku to Roboko [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/319152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xGxRQSgyXR1VzeOw7FL6bbfl7Xz.jpg'),
(143559, 10244, 'Boku to Roboko [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/319153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yqPmPtLjUeSOb0KdVME3mh7BuP2.jpg'),
(143560, 10244, 'Boku to Roboko [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/319154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzUudI0q8xJChnr0PYqqal8YxtV.jpg'),
(143561, 10244, 'Boku to Roboko [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/319155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8SRdvQ2BrD2Bp7LA8YlSjO9IoO1.jpg'),
(143562, 10244, 'Boku to Roboko [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/319156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2MeKsp82cLOlRk3WZdRShvJOlfm.jpg'),
(143563, 10244, 'Boku to Roboko [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/319157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mlqzp1tvy39zN0jGgriYe0YyZHY.jpg'),
(143564, 10244, 'Boku to Roboko [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/319158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/BlPhPFYtYeprTuZnO5hm9CejWb.jpg'),
(143565, 10244, 'Boku to Roboko [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/319159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pwVk4rR8AftaMgkbuMaLNRVbtIt.jpg'),
(143566, 10244, 'Boku to Roboko [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/319160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9kHOIj5wjX2CVgoHE3j6NPdXeFK.jpg'),
(143567, 10244, 'Boku to Roboko [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/319161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5iN8DZDoMNLcEOnARJbSfb7b5nb.jpg'),
(143568, 10244, 'Boku to Roboko [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/319162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u5fRalR1th79p6I7pSPOFSQLpAF.jpg'),
(143569, 10244, 'Boku to Roboko [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/319163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Agl8UAN1aG4jRbINgHSjsX9aS6.jpg'),
(143570, 10244, 'Boku to Roboko [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/319164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/axWUDDyTxml2qCj4HycxMcC13wn.jpg'),
(143571, 10244, 'Boku to Roboko [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/319165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mIsU0JIvhJd5Qverwp0YixazWUX.jpg'),
(143572, 10244, 'Boku to Roboko [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/319166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pldDHw7r7ia0ew0QKq5xnHLwCju.jpg'),
(143573, 10244, 'Boku to Roboko [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/319167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oF235tKhWQXfnMYQBuf0tOSLHpr.jpg'),
(143574, 10244, 'Boku to Roboko [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/319168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uFanICBO0lfjFzYoMHcfNxlsoz5.jpg'),
(143575, 10244, 'Boku to Roboko [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/319169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i62n1wv7d7ybIrJd0qxUl2HzueK.jpg'),
(143576, 10244, 'Boku to Roboko [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/319170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xePjyOKj3ak1jMW8WbUdGguaYgn.jpg'),
(143577, 10244, 'Boku to Roboko [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/319171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jCeM9JZQSLifUAYxx9xWCYJUM3h.jpg'),
(143578, 10244, 'Boku to Roboko [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/319172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8zrptZQ6Y3gWLhowWBwl2ZxL1I.jpg'),
(143579, 10244, 'Boku to Roboko [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/319173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o4ri7yNpG7ZFGe5mHNoq8Gv7cY1.jpg'),
(143580, 10244, 'Boku to Roboko [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/319174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vmnW71jObaM7ki2lNL097jU74Ex.jpg'),
(143581, 10244, 'Boku to Roboko [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/319175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSYwbCIa0GkAiyuTioxYU3mkGvm.jpg'),
(143582, 10244, 'Boku to Roboko [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/319176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r0AoSCQiapd0wDWn34GVVrBGoQP.jpg'),
(143583, 10244, 'Boku to Roboko [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/319177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7wtvrWOMJAkLPh5dDnQZ5byI4Us.jpg'),
(143584, 10244, 'Boku to Roboko [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/319178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/buZUnU5DmLMGo6jz5Sx959J8lyf.jpg'),
(143585, 10245, 'Esconda se [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/319147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oWchbgTDPIEnXtql0JicAwAGmMg.jpg'),
(143586, 10245, 'Esconda se [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/319148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c2Zc750ItumklhyfUkSeH9JD5yh.jpg'),
(143587, 10245, 'Esconda se [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/319149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hiaRCXarePgQmg8gPfmq39LT2it.jpg'),
(143588, 10245, 'Esconda se [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/319150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9pEwPtfqmIqZLFOAxV1f3i0QIDh.jpg'),
(143589, 10245, 'Esconda se [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/326799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mOtqwb3RITlcJlN5oxQrEx35cqy.jpg'),
(143590, 10245, 'Esconda se [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/326800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mOtqwb3RITlcJlN5oxQrEx35cqy.jpg'),
(143591, 10245, 'Esconda se [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/326801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mOtqwb3RITlcJlN5oxQrEx35cqy.jpg'),
(143592, 10245, 'Esconda se [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/326802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mOtqwb3RITlcJlN5oxQrEx35cqy.jpg'),
(143593, 10245, 'Esconda se [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/330663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mOtqwb3RITlcJlN5oxQrEx35cqy.jpg'),
(143594, 10245, 'Esconda se [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/338960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mOtqwb3RITlcJlN5oxQrEx35cqy.jpg'),
(143595, 10245, 'Esconda se [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/338961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mOtqwb3RITlcJlN5oxQrEx35cqy.jpg'),
(143596, 10245, 'Esconda se [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/338962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mOtqwb3RITlcJlN5oxQrEx35cqy.jpg'),
(143597, 10246, 'Gods Game We Play S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/319146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7o7cAhtrQ7y3QX9EDkHradJUWhx.jpg'),
(143598, 10246, 'Gods Game We Play S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/323985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uBVxIofgBq2Tp36F1ggcNUfy6VG.jpg'),
(143599, 10246, 'Gods Game We Play S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uBVxIofgBq2Tp36F1ggcNUfy6VG.jpg'),
(143600, 10246, 'Gods Game We Play S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/332736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uBVxIofgBq2Tp36F1ggcNUfy6VG.jpg'),
(143601, 10246, 'Gods Game We Play S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/338662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uBVxIofgBq2Tp36F1ggcNUfy6VG.jpg'),
(143602, 10246, 'Gods Game We Play S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/345316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uBVxIofgBq2Tp36F1ggcNUfy6VG.jpg'),
(143603, 10246, 'Gods Game We Play S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/356360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uBVxIofgBq2Tp36F1ggcNUfy6VG.jpg'),
(143604, 10246, 'Gods Game We Play S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/356361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uBVxIofgBq2Tp36F1ggcNUfy6VG.jpg'),
(143605, 10246, 'Gods Game We Play S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/368399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uBVxIofgBq2Tp36F1ggcNUfy6VG.jpg'),
(143606, 10246, 'Gods Game We Play S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/374433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uBVxIofgBq2Tp36F1ggcNUfy6VG.jpg'),
(143607, 10246, 'Gods Game We Play S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/383030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uBVxIofgBq2Tp36F1ggcNUfy6VG.jpg'),
(143608, 10246, 'Gods Game We Play S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uBVxIofgBq2Tp36F1ggcNUfy6VG.jpg'),
(143609, 10246, 'Gods Game We Play S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/390227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uBVxIofgBq2Tp36F1ggcNUfy6VG.jpg'),
(143610, 10247, 'Historias de Animais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/319141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/elqgCyu8bPtXDrPt3dIcChVDwFE.jpg'),
(143611, 10247, 'Historias de Animais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/319142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/elqgCyu8bPtXDrPt3dIcChVDwFE.jpg'),
(143612, 10247, 'Historias de Animais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/319143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/elqgCyu8bPtXDrPt3dIcChVDwFE.jpg'),
(143613, 10247, 'Historias de Animais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/319144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/elqgCyu8bPtXDrPt3dIcChVDwFE.jpg'),
(143614, 10247, 'Historias de Animais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/319145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/elqgCyu8bPtXDrPt3dIcChVDwFE.jpg'),
(143615, 10248, 'Love is Like a Cat  [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/319139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUW8q2oozgIj7jq5Ztr9ORP9cCU.jpg'),
(143616, 10248, 'Love is Like a Cat  [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/319140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yXom3YVYeAAy4jg7fOiuuYGNIj6.jpg'),
(143617, 10248, 'Love is Like a Cat  [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkcAiTsl2MIVIQoepQzAuWhfyK3.jpg'),
(143618, 10248, 'Love is Like a Cat  [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/326791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkcAiTsl2MIVIQoepQzAuWhfyK3.jpg'),
(143619, 10248, 'Love is Like a Cat  [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/327644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkcAiTsl2MIVIQoepQzAuWhfyK3.jpg'),
(143620, 10248, 'Love is Like a Cat  [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/327645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkcAiTsl2MIVIQoepQzAuWhfyK3.jpg'),
(143621, 10248, 'Love is Like a Cat  [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/336304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkcAiTsl2MIVIQoepQzAuWhfyK3.jpg'),
(143622, 10248, 'Love is Like a Cat  [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/336305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkcAiTsl2MIVIQoepQzAuWhfyK3.jpg'),
(143623, 10248, 'Love is Like a Cat  [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/340857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkcAiTsl2MIVIQoepQzAuWhfyK3.jpg'),
(143624, 10248, 'Love is Like a Cat  [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/340858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkcAiTsl2MIVIQoepQzAuWhfyK3.jpg'),
(143625, 10248, 'Love is Like a Cat  [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/345124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkcAiTsl2MIVIQoepQzAuWhfyK3.jpg'),
(143626, 10248, 'Love is Like a Cat  [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/345125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hkcAiTsl2MIVIQoepQzAuWhfyK3.jpg'),
(143627, 10249, 'Nada descoberto [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/319135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bPIC0e1cfchtse7vbMfzSPtH3li.jpg'),
(143628, 10249, 'Nada descoberto [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/319136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5lmjZfI1Ti48CpYtgSMFOY0FyR.jpg'),
(143629, 10249, 'Nada descoberto [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/319137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8GzDp60d8OO20LII1CrFUox2OVs.jpg'),
(143630, 10249, 'Nada descoberto [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/319138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hz6eNwKXTsKOYSXByeRQgojyvdp.jpg'),
(143631, 10249, 'Nada descoberto [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/319449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lN7KbEDSXEQHW5sflACWxfyrR4a.jpg'),
(143632, 10249, 'Nada descoberto [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/319450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lN7KbEDSXEQHW5sflACWxfyrR4a.jpg'),
(143633, 10249, 'Nada descoberto [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/323864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lN7KbEDSXEQHW5sflACWxfyrR4a.jpg'),
(143634, 10249, 'Nada descoberto [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/325531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lN7KbEDSXEQHW5sflACWxfyrR4a.jpg'),
(143635, 10249, 'Nada descoberto [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/327639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lN7KbEDSXEQHW5sflACWxfyrR4a.jpg'),
(143636, 10249, 'Nada descoberto [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lN7KbEDSXEQHW5sflACWxfyrR4a.jpg'),
(143637, 10249, 'Nada descoberto [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/336290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lN7KbEDSXEQHW5sflACWxfyrR4a.jpg'),
(143638, 10249, 'Nada descoberto [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/336291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lN7KbEDSXEQHW5sflACWxfyrR4a.jpg'),
(143639, 10249, 'Nada descoberto [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/340847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lN7KbEDSXEQHW5sflACWxfyrR4a.jpg'),
(143640, 10249, 'Nada descoberto [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/340848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lN7KbEDSXEQHW5sflACWxfyrR4a.jpg'),
(143641, 10249, 'Nada descoberto [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/347219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lN7KbEDSXEQHW5sflACWxfyrR4a.jpg'),
(143642, 10249, 'Nada descoberto [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/347220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lN7KbEDSXEQHW5sflACWxfyrR4a.jpg'),
(143643, 10250, 'O Rastreador S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/317502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v0f1co8p7V9L7EXm0cjKQisecAU.jpg'),
(143644, 10250, 'O Rastreador S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/317503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sKGkfzQ8MqiINvnLMcPILtjnerD.jpg'),
(143645, 10250, 'O Rastreador S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/317504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143646, 10250, 'O Rastreador S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/323853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143647, 10250, 'O Rastreador S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/349280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143648, 10250, 'O Rastreador S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/349281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143649, 10250, 'O Rastreador S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/367263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143650, 10250, 'O Rastreador S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/367264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143651, 10250, 'O Rastreador S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/373395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143652, 10250, 'O Rastreador S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/388949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143653, 10250, 'O Rastreador S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/381929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143654, 10250, 'O Rastreador S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/388951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143655, 10250, 'O Rastreador S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/388952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143656, 10251, 'O Rastreador S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/517790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143657, 10251, 'O Rastreador S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/517791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143658, 10251, 'O Rastreador S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/523261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143659, 10251, 'O Rastreador S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/639091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143660, 10251, 'O Rastreador S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/640786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143661, 10251, 'O Rastreador S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/658851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143662, 10251, 'O Rastreador S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/661808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143663, 10251, 'O Rastreador S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/667970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143664, 10251, 'O Rastreador S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/769487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143665, 10251, 'O Rastreador S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/759860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143666, 10251, 'O Rastreador S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/769489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143667, 10251, 'O Rastreador S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/769490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143668, 10251, 'O Rastreador S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/779117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143669, 10251, 'O Rastreador S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/789514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143670, 10251, 'O Rastreador S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/809162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143671, 10251, 'O Rastreador S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/809163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143672, 10251, 'O Rastreador S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/824603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143673, 10251, 'O Rastreador S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/841400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143674, 10251, 'O Rastreador S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/845371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143675, 10251, 'O Rastreador S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/848545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143676, 10252, 'O Rastreador S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/897437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143677, 10252, 'O Rastreador S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/895867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143678, 10252, 'O Rastreador S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/897438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ivhqGQa4ndqDatKiASIfSMJIJuh.jpg'),
(143679, 10253, 'Re Monster S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/319134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AfHsEK0dB4rtMvTlaQ41r8wYaw0.jpg'),
(143680, 10253, 'Re Monster S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/323684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tg2VXsEyeuexAayn1hma8AVLglz.jpg'),
(143681, 10253, 'Re Monster S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tg2VXsEyeuexAayn1hma8AVLglz.jpg'),
(143682, 10253, 'Re Monster S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/336090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tg2VXsEyeuexAayn1hma8AVLglz.jpg'),
(143683, 10253, 'Re Monster S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/340534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tg2VXsEyeuexAayn1hma8AVLglz.jpg'),
(143684, 10253, 'Re Monster S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/343738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tg2VXsEyeuexAayn1hma8AVLglz.jpg'),
(143685, 10253, 'Re Monster S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/354907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tg2VXsEyeuexAayn1hma8AVLglz.jpg'),
(143686, 10253, 'Re Monster S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/354908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tg2VXsEyeuexAayn1hma8AVLglz.jpg'),
(143687, 10253, 'Re Monster S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/365158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tg2VXsEyeuexAayn1hma8AVLglz.jpg'),
(143688, 10253, 'Re Monster S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/373170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tg2VXsEyeuexAayn1hma8AVLglz.jpg'),
(143689, 10253, 'Re Monster S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/380934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tg2VXsEyeuexAayn1hma8AVLglz.jpg'),
(143690, 10253, 'Re Monster S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/388714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tg2VXsEyeuexAayn1hma8AVLglz.jpg'),
(143691, 10254, 'Restaurando Casas com Dave e Jenny S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/319091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/half7mTx5BxXwR06GxJWOnLXvaH.jpg'),
(143692, 10254, 'Restaurando Casas com Dave e Jenny S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/319092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pRQwQRGrTcnbPy0PApnnRQO7iPT.jpg'),
(143693, 10254, 'Restaurando Casas com Dave e Jenny S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/319093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/malPQgw6sn5sxySVJpIBBU8q77F.jpg'),
(143694, 10254, 'Restaurando Casas com Dave e Jenny S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/319094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rB2QZtxpi0nY51P2dkxnPDQqhJm.jpg'),
(143695, 10254, 'Restaurando Casas com Dave e Jenny S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/319095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dOOMLVLU3eTVob9doTq13aKknP7.jpg'),
(143696, 10254, 'Restaurando Casas com Dave e Jenny S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/319096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nBCPwoWLbddrzliGZs7BCs5G9Ss.jpg'),
(143697, 10254, 'Restaurando Casas com Dave e Jenny S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/319097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8MQfbP2JJ52dJZdSqRhvZFFVQdc.jpg'),
(143698, 10254, 'Restaurando Casas com Dave e Jenny S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/319098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSlBC9cpXBEov64Fcwgmm9GYELg.jpg'),
(143699, 10254, 'Restaurando Casas com Dave e Jenny S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/319099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/VzIrghTmijZ9rUbKlSdAiyedUA.jpg'),
(143700, 10254, 'Restaurando Casas com Dave e Jenny S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/319100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aehmctCTzWIIekOrsepRgEwNloN.jpg'),
(143701, 10254, 'Restaurando Casas com Dave e Jenny S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/319101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gaTYkOEa3D43NMChsdZTrA6f9Rh.jpg'),
(143702, 10254, 'Restaurando Casas com Dave e Jenny S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/319102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xB5h7GP07tOicmQVZPq8HcwwC25.jpg'),
(143703, 10254, 'Restaurando Casas com Dave e Jenny S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/319103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nU8dkQCHDOIpPkgGK8crxy92m8q.jpg'),
(143704, 10255, 'Restaurando Casas com Dave e Jenny S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/319104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143705, 10255, 'Restaurando Casas com Dave e Jenny S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/319105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143706, 10255, 'Restaurando Casas com Dave e Jenny S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/319106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143707, 10255, 'Restaurando Casas com Dave e Jenny S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/319107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143708, 10255, 'Restaurando Casas com Dave e Jenny S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/319108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143709, 10255, 'Restaurando Casas com Dave e Jenny S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/319109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143710, 10255, 'Restaurando Casas com Dave e Jenny S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/319110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143711, 10255, 'Restaurando Casas com Dave e Jenny S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/319111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143712, 10255, 'Restaurando Casas com Dave e Jenny S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/319112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143713, 10255, 'Restaurando Casas com Dave e Jenny S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/319113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143714, 10255, 'Restaurando Casas com Dave e Jenny S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/319114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143715, 10256, 'Restaurando Casas com Dave e Jenny S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/319115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9V29CdrGlnloWTU8NDGEkqi1k7Y.jpg'),
(143716, 10256, 'Restaurando Casas com Dave e Jenny S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/319116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wII6ju8hhT2HLozlYE2C8dS4ygd.jpg'),
(143717, 10256, 'Restaurando Casas com Dave e Jenny S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/319117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ijMK1SiDqZHpXExYfxCC5NrSRej.jpg'),
(143718, 10256, 'Restaurando Casas com Dave e Jenny S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/319118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ttsWrSCsqO5rdjdPT8yEPsi7ecb.jpg'),
(143719, 10256, 'Restaurando Casas com Dave e Jenny S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/319119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/abPlZeHdbKA9sZJGO0lSf3dJZ7D.jpg'),
(143720, 10256, 'Restaurando Casas com Dave e Jenny S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/319120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lXtd5r4HHzEGCin24GeHSD9d3Ur.jpg'),
(143721, 10256, 'Restaurando Casas com Dave e Jenny S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/319121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kWuRS2SZPoCT8MIFbycMtmH5DGK.jpg'),
(143722, 10256, 'Restaurando Casas com Dave e Jenny S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/319122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ou7eIRmLSHsNkklM5nI6dpZC039.jpg'),
(143723, 10256, 'Restaurando Casas com Dave e Jenny S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/319123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gNdFmwYaHvL9tkN17NMJyc9X38K.jpg'),
(143724, 10256, 'Restaurando Casas com Dave e Jenny S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/319124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vVtDX65zgdpe7ZiuZK8pFiZ3JiV.jpg'),
(143725, 10256, 'Restaurando Casas com Dave e Jenny S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/319125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bOfJjYXnn4CLATFKoWowAoyP2oh.jpg'),
(143726, 10256, 'Restaurando Casas com Dave e Jenny S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/319126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pbIptYnhkZzNHoun6L4s2i7EFPD.jpg'),
(143727, 10256, 'Restaurando Casas com Dave e Jenny S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/319127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9FPlTZzfnPLwAsQJwVhaeiiKya.jpg'),
(143728, 10256, 'Restaurando Casas com Dave e Jenny S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/319128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Am40LYLeq3wX934v8rUsNcDh524.jpg'),
(143729, 10256, 'Restaurando Casas com Dave e Jenny S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/319129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sRw4fpImFn92iR34qDp2FntquGH.jpg'),
(143730, 10256, 'Restaurando Casas com Dave e Jenny S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/319130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4oV1AXaX6bysTp4FrSLCO61Yi7V.jpg'),
(143731, 10257, 'Restaurando Casas com Dave e Jenny S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/319131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143732, 10257, 'Restaurando Casas com Dave e Jenny S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/319132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143733, 10257, 'Restaurando Casas com Dave e Jenny S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/319133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143734, 10257, 'Restaurando Casas com Dave e Jenny S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/323614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143735, 10257, 'Restaurando Casas com Dave e Jenny S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/603220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143736, 10257, 'Restaurando Casas com Dave e Jenny S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/603221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143737, 10257, 'Restaurando Casas com Dave e Jenny S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/603222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143738, 10257, 'Restaurando Casas com Dave e Jenny S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/603223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143739, 10257, 'Restaurando Casas com Dave e Jenny S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/603224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143740, 10257, 'Restaurando Casas com Dave e Jenny S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/603225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143741, 10257, 'Restaurando Casas com Dave e Jenny S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/603226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143742, 10257, 'Restaurando Casas com Dave e Jenny S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/603227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143743, 10258, 'Restaurando Casas com Dave e Jenny S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/805215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143744, 10258, 'Restaurando Casas com Dave e Jenny S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/805216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143745, 10258, 'Restaurando Casas com Dave e Jenny S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/805217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143746, 10258, 'Restaurando Casas com Dave e Jenny S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/805218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143747, 10258, 'Restaurando Casas com Dave e Jenny S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/805219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143748, 10258, 'Restaurando Casas com Dave e Jenny S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/805220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143749, 10258, 'Restaurando Casas com Dave e Jenny S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/805221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143750, 10258, 'Restaurando Casas com Dave e Jenny S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/805222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143751, 10258, 'Restaurando Casas com Dave e Jenny S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/805223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143752, 10258, 'Restaurando Casas com Dave e Jenny S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/805224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143753, 10258, 'Restaurando Casas com Dave e Jenny S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/805225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143754, 10258, 'Restaurando Casas com Dave e Jenny S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/805226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143755, 10258, 'Restaurando Casas com Dave e Jenny S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/805227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143756, 10258, 'Restaurando Casas com Dave e Jenny S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/805228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uQ17KEGQiH1gpXuQCWK8tPwXwBH.jpg'),
(143757, 10259, 'STEVE (martin) documentario em 2 partes [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/319089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2fZAVTPMnr4sRgA4AlEqBIp1sZ2.jpg'),
(143758, 10259, 'STEVE (martin) documentario em 2 partes [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/319090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gPDygtBaRmm7Z76LPCGwntsG4MG.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(143759, 10260, 'Testamento A Historia de Moises S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/319086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6cgEYR9g7UN6G1V4B7UuPcq1JLH.jpg'),
(143760, 10260, 'Testamento A Historia de Moises S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/319087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u0GMJpwMOojGpk0Yz9ibdK4qEco.jpg'),
(143761, 10260, 'Testamento A Historia de Moises S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/319088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zjOVE3MEh3sRmla0YTlNJfyDkVI.jpg'),
(143762, 10261, 'Vanderpump Villa Luxos e Segredos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/319083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5zY5XRt0Pxom026UMWB1Q0d0DU.jpg'),
(143763, 10261, 'Vanderpump Villa Luxos e Segredos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/319084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yPwINFlztdWEx6fVeafLcgsv91K.jpg'),
(143764, 10261, 'Vanderpump Villa Luxos e Segredos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/319085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hIKcgRo0MJbhaUV7161r61NyAJL.jpg'),
(143765, 10261, 'Vanderpump Villa Luxos e Segredos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/323438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hcA5tQ3fvQ71emxNCWwKJCNCky.jpg'),
(143766, 10261, 'Vanderpump Villa Luxos e Segredos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/326599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hcA5tQ3fvQ71emxNCWwKJCNCky.jpg'),
(143767, 10261, 'Vanderpump Villa Luxos e Segredos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/332038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hcA5tQ3fvQ71emxNCWwKJCNCky.jpg'),
(143768, 10261, 'Vanderpump Villa Luxos e Segredos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/336837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hcA5tQ3fvQ71emxNCWwKJCNCky.jpg'),
(143769, 10261, 'Vanderpump Villa Luxos e Segredos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/342316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hcA5tQ3fvQ71emxNCWwKJCNCky.jpg'),
(143770, 10261, 'Vanderpump Villa Luxos e Segredos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hcA5tQ3fvQ71emxNCWwKJCNCky.jpg'),
(143771, 10261, 'Vanderpump Villa Luxos e Segredos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hcA5tQ3fvQ71emxNCWwKJCNCky.jpg'),
(143772, 10262, 'Vanderpump Villa Luxos e Segredos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/778369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hcA5tQ3fvQ71emxNCWwKJCNCky.jpg'),
(143773, 10262, 'Vanderpump Villa Luxos e Segredos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/778370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hcA5tQ3fvQ71emxNCWwKJCNCky.jpg'),
(143774, 10262, 'Vanderpump Villa Luxos e Segredos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/778371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hcA5tQ3fvQ71emxNCWwKJCNCky.jpg'),
(143775, 10262, 'Vanderpump Villa Luxos e Segredos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/778372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hcA5tQ3fvQ71emxNCWwKJCNCky.jpg'),
(143776, 10262, 'Vanderpump Villa Luxos e Segredos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/778373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hcA5tQ3fvQ71emxNCWwKJCNCky.jpg'),
(143777, 10262, 'Vanderpump Villa Luxos e Segredos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/778374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hcA5tQ3fvQ71emxNCWwKJCNCky.jpg'),
(143778, 10262, 'Vanderpump Villa Luxos e Segredos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/778375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hcA5tQ3fvQ71emxNCWwKJCNCky.jpg'),
(143779, 10262, 'Vanderpump Villa Luxos e Segredos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/778376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hcA5tQ3fvQ71emxNCWwKJCNCky.jpg'),
(143780, 10262, 'Vanderpump Villa Luxos e Segredos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/778377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hcA5tQ3fvQ71emxNCWwKJCNCky.jpg'),
(143781, 10262, 'Vanderpump Villa Luxos e Segredos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/778378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hcA5tQ3fvQ71emxNCWwKJCNCky.jpg'),
(143782, 10263, 'Fe nos Negocios S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/319074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1cGZGsPRQQiJf6t23XCNonkZkxV.jpg'),
(143783, 10263, 'Fe nos Negocios S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/319075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rb38Xs1QzCOLbSvMkt9CeBsQIWQ.jpg'),
(143784, 10263, 'Fe nos Negocios S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/319076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xEfxiJ9aZSz8nfo4ZdBOU8zr5rX.jpg'),
(143785, 10263, 'Fe nos Negocios S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/319077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uFQWP1RoRNNXikqyZ1MduigviAY.jpg'),
(143786, 10263, 'Fe nos Negocios S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/319078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kWVpyv5B1QWPOenjE0Gv1ic9Rx5.jpg'),
(143787, 10263, 'Fe nos Negocios S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/319079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hOfTcNA31kgDYc0gVHn6KpyCM24.jpg'),
(143788, 10263, 'Fe nos Negocios S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/319080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Qkf5fIIigAtiUDxgTkqDfHbEwm.jpg'),
(143789, 10263, 'Fe nos Negocios S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/319081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3W26O3FZPOfkXZRkOxd5f7AXShv.jpg'),
(143790, 10263, 'Fe nos Negocios S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/319082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/futtUGy48xVHv3A4XhQYL8fShmm.jpg'),
(143791, 10264, 'Keep Your Hands Off Eizouken S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oPG8dqazVRXdTHNByjhYBGma2uO.jpg'),
(143792, 10264, 'Keep Your Hands Off Eizouken S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vuL87iVUo0QpW51jYk1dhiOvGWY.jpg'),
(143793, 10264, 'Keep Your Hands Off Eizouken S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/geBmnb1Z8BWzOf4bQKp6H1nfrqn.jpg'),
(143794, 10264, 'Keep Your Hands Off Eizouken S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/320297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOI8CZRN2ExTuQfG65t8l5Qkc8A.jpg'),
(143795, 10264, 'Keep Your Hands Off Eizouken S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3VB70TtKp24xFp6iK8WTAKG4DDV.jpg'),
(143796, 10264, 'Keep Your Hands Off Eizouken S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sLyfhUUGiC8Gn47Ujv0CtCgeXYS.jpg'),
(143797, 10264, 'Keep Your Hands Off Eizouken S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/320300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwTKuzbg3unM9KpybespNAW8hx0.jpg'),
(143798, 10264, 'Keep Your Hands Off Eizouken S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/320301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kmTlPClgh4VvmmSbBGbD4AwQqlE.jpg'),
(143799, 10264, 'Keep Your Hands Off Eizouken S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/320302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kLSxTmOFnskeJRtcgfcb0T2UMCf.jpg'),
(143800, 10264, 'Keep Your Hands Off Eizouken S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/320303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oKQKxEGMU5EwHxM6exFKvJfHANK.jpg'),
(143801, 10264, 'Keep Your Hands Off Eizouken S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/320304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u9a1zzxHRfMLnppiaH2NiTFdC4q.jpg'),
(143802, 10264, 'Keep Your Hands Off Eizouken S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/320305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5SZ3cmF4AGrWFrR80jMbSHgB0Df.jpg'),
(143803, 10265, 'Misterios Biblicos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jXfPZgXURWBNRj7EB07QYTVZvaj.jpg'),
(143804, 10265, 'Misterios Biblicos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jXfPZgXURWBNRj7EB07QYTVZvaj.jpg'),
(143805, 10265, 'Misterios Biblicos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jXfPZgXURWBNRj7EB07QYTVZvaj.jpg'),
(143806, 10265, 'Misterios Biblicos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/320291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jXfPZgXURWBNRj7EB07QYTVZvaj.jpg'),
(143807, 10265, 'Misterios Biblicos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jXfPZgXURWBNRj7EB07QYTVZvaj.jpg'),
(143808, 10265, 'Misterios Biblicos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jXfPZgXURWBNRj7EB07QYTVZvaj.jpg'),
(143809, 10266, 'Sob Nova Direcao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143810, 10266, 'Sob Nova Direcao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143811, 10266, 'Sob Nova Direcao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143812, 10266, 'Sob Nova Direcao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/320166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143813, 10266, 'Sob Nova Direcao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143814, 10266, 'Sob Nova Direcao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143815, 10266, 'Sob Nova Direcao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/320169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143816, 10266, 'Sob Nova Direcao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/320170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143817, 10266, 'Sob Nova Direcao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/320171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143818, 10266, 'Sob Nova Direcao S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/320172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143819, 10266, 'Sob Nova Direcao S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/320173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143820, 10266, 'Sob Nova Direcao S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/320174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143821, 10266, 'Sob Nova Direcao S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/320175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143822, 10266, 'Sob Nova Direcao S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/320176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143823, 10266, 'Sob Nova Direcao S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/320177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143824, 10266, 'Sob Nova Direcao S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/320178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143825, 10266, 'Sob Nova Direcao S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/320179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143826, 10266, 'Sob Nova Direcao S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/320180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143827, 10266, 'Sob Nova Direcao S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/320181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143828, 10266, 'Sob Nova Direcao S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/320182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143829, 10266, 'Sob Nova Direcao S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/320183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143830, 10266, 'Sob Nova Direcao S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/320184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143831, 10266, 'Sob Nova Direcao S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/320185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143832, 10266, 'Sob Nova Direcao S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/320186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143833, 10266, 'Sob Nova Direcao S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/320187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143834, 10266, 'Sob Nova Direcao S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/320188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143835, 10266, 'Sob Nova Direcao S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/320189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143836, 10266, 'Sob Nova Direcao S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/320190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143837, 10266, 'Sob Nova Direcao S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/320191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143838, 10266, 'Sob Nova Direcao S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/320192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143839, 10266, 'Sob Nova Direcao S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/320193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143840, 10266, 'Sob Nova Direcao S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/320194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143841, 10266, 'Sob Nova Direcao S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/320195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143842, 10266, 'Sob Nova Direcao S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/320196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143843, 10266, 'Sob Nova Direcao S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/320197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143844, 10266, 'Sob Nova Direcao S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/320198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143845, 10267, 'Sob Nova Direcao S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143846, 10267, 'Sob Nova Direcao S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143847, 10267, 'Sob Nova Direcao S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143848, 10267, 'Sob Nova Direcao S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/320202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143849, 10267, 'Sob Nova Direcao S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143850, 10267, 'Sob Nova Direcao S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143851, 10267, 'Sob Nova Direcao S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/320205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143852, 10267, 'Sob Nova Direcao S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/320206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143853, 10267, 'Sob Nova Direcao S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/320207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143854, 10267, 'Sob Nova Direcao S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/320208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143855, 10267, 'Sob Nova Direcao S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/320209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143856, 10267, 'Sob Nova Direcao S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/320210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143857, 10267, 'Sob Nova Direcao S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/320211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143858, 10267, 'Sob Nova Direcao S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/320212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143859, 10267, 'Sob Nova Direcao S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/320213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143860, 10267, 'Sob Nova Direcao S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/320214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143861, 10267, 'Sob Nova Direcao S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/320215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143862, 10267, 'Sob Nova Direcao S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/320216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143863, 10267, 'Sob Nova Direcao S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/320217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143864, 10267, 'Sob Nova Direcao S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/320218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143865, 10267, 'Sob Nova Direcao S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/320219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143866, 10267, 'Sob Nova Direcao S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/320220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143867, 10267, 'Sob Nova Direcao S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/320221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143868, 10267, 'Sob Nova Direcao S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/320222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143869, 10267, 'Sob Nova Direcao S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/320223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143870, 10267, 'Sob Nova Direcao S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/320224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143871, 10267, 'Sob Nova Direcao S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/320225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143872, 10267, 'Sob Nova Direcao S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/320226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143873, 10267, 'Sob Nova Direcao S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/320227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143874, 10267, 'Sob Nova Direcao S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/320228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143875, 10267, 'Sob Nova Direcao S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/320229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143876, 10267, 'Sob Nova Direcao S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/320230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143877, 10267, 'Sob Nova Direcao S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/320231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143878, 10267, 'Sob Nova Direcao S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/320232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143879, 10267, 'Sob Nova Direcao S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/320233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143880, 10267, 'Sob Nova Direcao S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/320234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143881, 10267, 'Sob Nova Direcao S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/320235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143882, 10267, 'Sob Nova Direcao S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/320236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143883, 10268, 'Sob Nova Direcao S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143884, 10268, 'Sob Nova Direcao S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143885, 10268, 'Sob Nova Direcao S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143886, 10268, 'Sob Nova Direcao S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/320240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143887, 10268, 'Sob Nova Direcao S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143888, 10268, 'Sob Nova Direcao S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143889, 10268, 'Sob Nova Direcao S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/320243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143890, 10268, 'Sob Nova Direcao S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/320244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143891, 10268, 'Sob Nova Direcao S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/320245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143892, 10268, 'Sob Nova Direcao S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/320246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143893, 10268, 'Sob Nova Direcao S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/320247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143894, 10268, 'Sob Nova Direcao S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/320248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143895, 10268, 'Sob Nova Direcao S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/320249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143896, 10268, 'Sob Nova Direcao S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/320250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143897, 10268, 'Sob Nova Direcao S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/320251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143898, 10268, 'Sob Nova Direcao S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/320252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143899, 10268, 'Sob Nova Direcao S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/320253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143900, 10268, 'Sob Nova Direcao S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/320254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143901, 10268, 'Sob Nova Direcao S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/320255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143902, 10268, 'Sob Nova Direcao S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/320256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143903, 10268, 'Sob Nova Direcao S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/320257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143904, 10268, 'Sob Nova Direcao S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/320258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143905, 10268, 'Sob Nova Direcao S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/320259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143906, 10268, 'Sob Nova Direcao S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/320260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143907, 10268, 'Sob Nova Direcao S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/320261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143908, 10268, 'Sob Nova Direcao S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/320262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143909, 10268, 'Sob Nova Direcao S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/320263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143910, 10268, 'Sob Nova Direcao S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/320264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143911, 10268, 'Sob Nova Direcao S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/320265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143912, 10268, 'Sob Nova Direcao S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/320266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143913, 10268, 'Sob Nova Direcao S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/320267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143914, 10268, 'Sob Nova Direcao S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/320268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143915, 10268, 'Sob Nova Direcao S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/320269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143916, 10268, 'Sob Nova Direcao S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/320270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143917, 10268, 'Sob Nova Direcao S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/320271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143918, 10268, 'Sob Nova Direcao S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/320272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143919, 10268, 'Sob Nova Direcao S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/320273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143920, 10268, 'Sob Nova Direcao S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/320274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143921, 10269, 'Sob Nova Direcao S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143922, 10269, 'Sob Nova Direcao S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143923, 10269, 'Sob Nova Direcao S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143924, 10269, 'Sob Nova Direcao S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/320278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143925, 10269, 'Sob Nova Direcao S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143926, 10269, 'Sob Nova Direcao S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143927, 10269, 'Sob Nova Direcao S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/320281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143928, 10269, 'Sob Nova Direcao S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/320282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143929, 10269, 'Sob Nova Direcao S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/320283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143930, 10269, 'Sob Nova Direcao S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/320284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143931, 10269, 'Sob Nova Direcao S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/320285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143932, 10269, 'Sob Nova Direcao S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/320286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143933, 10269, 'Sob Nova Direcao S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/320287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mVFS2lTxpPjbhGO1hWr8ZghcLLm.jpg'),
(143934, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hlVdsYrLsmDJB3uBuyFrpMZJUvf.jpg'),
(143935, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/323570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143936, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/327595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143937, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/335952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143938, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/340109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143939, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/351394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143940, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/351395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143941, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/358725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143942, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/618584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143943, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/372982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143944, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/384055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143945, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/388567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143946, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/394183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143947, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/400278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143948, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/404147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143949, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/411340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143950, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/414358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143951, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/420727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143952, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/428639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143953, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/438675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143954, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/440805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143955, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/449978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143956, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/449979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143957, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/457154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143958, 10270, 'Spice and Wolf MERCHANT MEETS THE WISE WOLF [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/463654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfhyqA6n8WWiDhHXdVRBMHAqQw.jpg'),
(143959, 10271, 'A Condition Called Love [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2v9s5BdL4lJW60wRrtHypPqz36M.jpg'),
(143960, 10271, 'A Condition Called Love [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/la02YfwYaD4AWtJDiAgvdt5pGJh.jpg'),
(143961, 10271, 'A Condition Called Love [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/330811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/la02YfwYaD4AWtJDiAgvdt5pGJh.jpg'),
(143962, 10271, 'A Condition Called Love [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/334305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/la02YfwYaD4AWtJDiAgvdt5pGJh.jpg'),
(143963, 10271, 'A Condition Called Love [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/346531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/la02YfwYaD4AWtJDiAgvdt5pGJh.jpg'),
(143964, 10271, 'A Condition Called Love [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/la02YfwYaD4AWtJDiAgvdt5pGJh.jpg'),
(143965, 10271, 'A Condition Called Love [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/360473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/la02YfwYaD4AWtJDiAgvdt5pGJh.jpg'),
(143966, 10271, 'A Condition Called Love [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/605205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/la02YfwYaD4AWtJDiAgvdt5pGJh.jpg'),
(143967, 10271, 'A Condition Called Love [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/605206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/la02YfwYaD4AWtJDiAgvdt5pGJh.jpg'),
(143968, 10271, 'A Condition Called Love [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/375848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/la02YfwYaD4AWtJDiAgvdt5pGJh.jpg'),
(143969, 10271, 'A Condition Called Love [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/385253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/la02YfwYaD4AWtJDiAgvdt5pGJh.jpg'),
(143970, 10271, 'A Condition Called Love [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/385254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/la02YfwYaD4AWtJDiAgvdt5pGJh.jpg'),
(143971, 10272, 'A Fabrica de ETs [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gnH4GNDwPR3Y2t7eLeBQ4m7jHmw.jpg'),
(143972, 10272, 'A Fabrica de ETs [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gnH4GNDwPR3Y2t7eLeBQ4m7jHmw.jpg'),
(143973, 10272, 'A Fabrica de ETs [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gnH4GNDwPR3Y2t7eLeBQ4m7jHmw.jpg'),
(143974, 10272, 'A Fabrica de ETs [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/320154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gnH4GNDwPR3Y2t7eLeBQ4m7jHmw.jpg'),
(143975, 10272, 'A Fabrica de ETs [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gnH4GNDwPR3Y2t7eLeBQ4m7jHmw.jpg'),
(143976, 10272, 'A Fabrica de ETs [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gnH4GNDwPR3Y2t7eLeBQ4m7jHmw.jpg'),
(143977, 10272, 'A Fabrica de ETs [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/320157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gnH4GNDwPR3Y2t7eLeBQ4m7jHmw.jpg'),
(143978, 10272, 'A Fabrica de ETs [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/320158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gnH4GNDwPR3Y2t7eLeBQ4m7jHmw.jpg'),
(143979, 10272, 'A Fabrica de ETs [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/320159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gnH4GNDwPR3Y2t7eLeBQ4m7jHmw.jpg'),
(143980, 10272, 'A Fabrica de ETs [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/320160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gnH4GNDwPR3Y2t7eLeBQ4m7jHmw.jpg'),
(143981, 10273, 'A Fuga dos Sete Ressurreicao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bUNHCww8E7SDe4gyq6gcO8BYdpo.jpg'),
(143982, 10273, 'A Fuga dos Sete Ressurreicao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bUNHCww8E7SDe4gyq6gcO8BYdpo.jpg'),
(143983, 10273, 'A Fuga dos Sete Ressurreicao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bUNHCww8E7SDe4gyq6gcO8BYdpo.jpg'),
(143984, 10273, 'A Fuga dos Sete Ressurreicao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/326327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bUNHCww8E7SDe4gyq6gcO8BYdpo.jpg'),
(143985, 10274, 'A Fuga dos Sete [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOcVDPtwY7iCsl8svjHim3vgU8B.jpg'),
(143986, 10274, 'A Fuga dos Sete [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Q5hp6ySua8N1BlgVi7F3GFVLoO.jpg'),
(143987, 10274, 'A Fuga dos Sete [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u9vtC7ZdOBGIpZL7R4e7YnR2zP7.jpg'),
(143988, 10274, 'A Fuga dos Sete [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/320135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mMORNLKjQ70PbIiYaBev6JoXaJG.jpg'),
(143989, 10274, 'A Fuga dos Sete [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wrq6uctGZVP8LqYqMUdE8Ba0EWP.jpg'),
(143990, 10274, 'A Fuga dos Sete [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m7bjsjg1C6Hvl0Uc5NtR2ZLec08.jpg'),
(143991, 10274, 'A Fuga dos Sete [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/320138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xus5EJ5lKPuHkfHtfGfRYrOmoSU.jpg'),
(143992, 10274, 'A Fuga dos Sete [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/320139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/guu8G9Ky75MtYtUfH6zkoXHtUwe.jpg'),
(143993, 10274, 'A Fuga dos Sete [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/320140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lEIfB2wVcrrT0OE9lSjGctd6tAb.jpg'),
(143994, 10274, 'A Fuga dos Sete [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/320141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rmPhzRHyxe9qpaJWpVaNOvCQrnT.jpg'),
(143995, 10274, 'A Fuga dos Sete [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/320142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sT8xelwsktQv3kmoGPa5rP07Y87.jpg'),
(143996, 10274, 'A Fuga dos Sete [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/320143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4CQ1heUxbUfZYzIkkQok1aNTDea.jpg'),
(143997, 10274, 'A Fuga dos Sete [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/320144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hVcXxValLCgRxulso6XVQJUKFZ.jpg'),
(143998, 10274, 'A Fuga dos Sete [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/320145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yC1oY63bPUonQoNXMpLegvCbF1T.jpg'),
(143999, 10274, 'A Fuga dos Sete [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/320146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pKIoDGpBkdGZjsvzGDUvyZkRzMy.jpg'),
(144000, 10274, 'A Fuga dos Sete [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/320147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8CV6Z4CVjsITazKV560kUKRM5zk.jpg'),
(144001, 10274, 'A Fuga dos Sete [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/320148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l6NLTSQs6kubFktokHsoMTGGv9Q.jpg'),
(144002, 10275, 'A Fuga dos Sete [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/451372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfO0GgcdSqHKgz3nIxe7xAPrFLn.jpg'),
(144003, 10275, 'A Fuga dos Sete [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/451373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfO0GgcdSqHKgz3nIxe7xAPrFLn.jpg'),
(144004, 10275, 'A Fuga dos Sete [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/451374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfO0GgcdSqHKgz3nIxe7xAPrFLn.jpg'),
(144005, 10275, 'A Fuga dos Sete [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/451375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfO0GgcdSqHKgz3nIxe7xAPrFLn.jpg'),
(144006, 10275, 'A Fuga dos Sete [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/451376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfO0GgcdSqHKgz3nIxe7xAPrFLn.jpg'),
(144007, 10275, 'A Fuga dos Sete [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/451377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfO0GgcdSqHKgz3nIxe7xAPrFLn.jpg'),
(144008, 10275, 'A Fuga dos Sete [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/451378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfO0GgcdSqHKgz3nIxe7xAPrFLn.jpg'),
(144009, 10275, 'A Fuga dos Sete [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/451379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfO0GgcdSqHKgz3nIxe7xAPrFLn.jpg'),
(144010, 10275, 'A Fuga dos Sete [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/451380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfO0GgcdSqHKgz3nIxe7xAPrFLn.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(144011, 10275, 'A Fuga dos Sete [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/451381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfO0GgcdSqHKgz3nIxe7xAPrFLn.jpg'),
(144012, 10275, 'A Fuga dos Sete [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/451382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfO0GgcdSqHKgz3nIxe7xAPrFLn.jpg'),
(144013, 10275, 'A Fuga dos Sete [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/451383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfO0GgcdSqHKgz3nIxe7xAPrFLn.jpg'),
(144014, 10275, 'A Fuga dos Sete [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/451384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfO0GgcdSqHKgz3nIxe7xAPrFLn.jpg'),
(144015, 10275, 'A Fuga dos Sete [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/451385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfO0GgcdSqHKgz3nIxe7xAPrFLn.jpg'),
(144016, 10275, 'A Fuga dos Sete [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/451386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfO0GgcdSqHKgz3nIxe7xAPrFLn.jpg'),
(144017, 10275, 'A Fuga dos Sete [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/451387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zfO0GgcdSqHKgz3nIxe7xAPrFLn.jpg'),
(144018, 10276, 'ARK The Animated Series [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvpBM4acTJH283Omd70fUqq2bCN.jpg'),
(144019, 10276, 'ARK The Animated Series [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3qzBCXJLifxund1QMa8BiXmH3xp.jpg'),
(144020, 10276, 'ARK The Animated Series [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3qzBCXJLifxund1QMa8BiXmH3xp.jpg'),
(144021, 10276, 'ARK The Animated Series [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/326983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3qzBCXJLifxund1QMa8BiXmH3xp.jpg'),
(144022, 10276, 'ARK The Animated Series [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/326984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3qzBCXJLifxund1QMa8BiXmH3xp.jpg'),
(144023, 10276, 'ARK The Animated Series [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/326985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3qzBCXJLifxund1QMa8BiXmH3xp.jpg'),
(144024, 10277, 'Ace Attorney [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oMNSc1RuG8YET6a8Uw0XFGFHOrX.jpg'),
(144025, 10277, 'Ace Attorney [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9psBghlaFM2u7zm876YzdMaba2.jpg'),
(144026, 10277, 'Ace Attorney [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vy1y3eILLqRoyzO6zfkfzayP8fM.jpg'),
(144027, 10277, 'Ace Attorney [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/320087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8zq96FvqqNTbp8SvIYZHJ21C2K6.jpg'),
(144028, 10277, 'Ace Attorney [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w0ikUN8InXwoOmCENblx9oWTB2H.jpg'),
(144029, 10277, 'Ace Attorney [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eULi8dWvRg9VkELL7dfcaiuUZCQ.jpg'),
(144030, 10277, 'Ace Attorney [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/320090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9lFSDqvX8XgwbA6G6TtmOqTXDOR.jpg'),
(144031, 10277, 'Ace Attorney [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/320091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vbK8Gez2PIY6dTMxZc07EUVMWvi.jpg'),
(144032, 10277, 'Ace Attorney [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/320092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4u015ZkmsRC0hGgUTPA07sPc5sM.jpg'),
(144033, 10277, 'Ace Attorney [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/320093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/slE9jQzcEb69cMad09NvlNprSnq.jpg'),
(144034, 10277, 'Ace Attorney [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/320094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2tPdglUFgtKURmFk0F3oM4GA4tj.jpg'),
(144035, 10277, 'Ace Attorney [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/320095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t5ijT58P29LIQZ8JfZ2Otbu5CCu.jpg'),
(144036, 10277, 'Ace Attorney [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/320096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/26FC6dpyT62VLuE62oNlMe3vq8f.jpg'),
(144037, 10277, 'Ace Attorney [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/320097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zoHpcM9gJm7FWZaqfFrOBUzSzSz.jpg'),
(144038, 10277, 'Ace Attorney [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/320098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lIwwfYURPo3nHOBffq3YoXDgglc.jpg'),
(144039, 10277, 'Ace Attorney [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/320099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6qe0H7VCvLKqoEuTIAL6XBDvLqU.jpg'),
(144040, 10277, 'Ace Attorney [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/320100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zl4bcQL6y2FF9FeFyb3dm0jA9qE.jpg'),
(144041, 10277, 'Ace Attorney [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/320101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v0JBnsyRHtEoDJYZWCYIAqIU3yW.jpg'),
(144042, 10277, 'Ace Attorney [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/320102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/azUywGtIBa0GZbjJ8M2Iqo5lHWS.jpg'),
(144043, 10277, 'Ace Attorney [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/320103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Abpt8HyEEmTmkE7uoUlmfvMDtZa.jpg'),
(144044, 10277, 'Ace Attorney [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/320104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qGWDfz6D7Q2zwzV1XDO491MyFcC.jpg'),
(144045, 10277, 'Ace Attorney [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/320105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cxAEXQAUV0PXYveoSrvBGvlVM0J.jpg'),
(144046, 10277, 'Ace Attorney [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/320106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/31KlH8qWjO8t2HQmwsmh3EWqEK9.jpg'),
(144047, 10277, 'Ace Attorney [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/320107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eXwqQeLf6lMRFGz7v11AMIMseNs.jpg'),
(144048, 10278, 'Ace Attorney [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g6mufwKFe0HL0Km7yqkURZMVdrQ.jpg'),
(144049, 10278, 'Ace Attorney [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sseSCGvDwiYjHSJUR0GEYPtLiYe.jpg'),
(144050, 10278, 'Ace Attorney [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbMLjeJBevn6KcHIUWBUoTIymjL.jpg'),
(144051, 10278, 'Ace Attorney [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/320111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyVwNOBysdoMCTnNLU51CuNKgKB.jpg'),
(144052, 10278, 'Ace Attorney [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wqD1amnvCOx6q0F7XbkYASZzfGJ.jpg'),
(144053, 10278, 'Ace Attorney [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mBBKSQyU6CO83qVC7cuRh954HPB.jpg'),
(144054, 10278, 'Ace Attorney [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/320114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5MRUZIbgMvtSrvwAjeGq7Pu7YVo.jpg'),
(144055, 10278, 'Ace Attorney [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/320115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8lA3drAy2kEt9abMdS55awniTmX.jpg'),
(144056, 10278, 'Ace Attorney [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/320116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gKnNbaHzfXZi7LyN9NjOkkBKxXt.jpg'),
(144057, 10278, 'Ace Attorney [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/320117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5e303fBVIbc9CGjZ9YWhigeEG28.jpg'),
(144058, 10278, 'Ace Attorney [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/320118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AmT7d6Mu4ys4SZzbtTSbiwvi89w.jpg'),
(144059, 10278, 'Ace Attorney [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/320119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AmT7d6Mu4ys4SZzbtTSbiwvi89w.jpg'),
(144060, 10278, 'Ace Attorney [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/320120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kfHXRym3HC2EFXtvMdZrMGrkhSQ.jpg'),
(144061, 10278, 'Ace Attorney [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/320121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9wqqRbBbIuJmcmtrpdaSjXQyxds.jpg'),
(144062, 10278, 'Ace Attorney [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/320122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3mujanF4syqXlKE6rI7WNfh3L2N.jpg'),
(144063, 10278, 'Ace Attorney [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/320123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2b1WQb6vGQliPffnrHEQKTsPqon.jpg'),
(144064, 10278, 'Ace Attorney [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/320124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dlxSvcvu7PswO2mMboMkotuiTQ0.jpg'),
(144065, 10278, 'Ace Attorney [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/320125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iqb9h4twsrvIMetYJWaAuurFnFF.jpg'),
(144066, 10278, 'Ace Attorney [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/320126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2zB2zlc1HVc10Ni63Fq7v1yRv08.jpg'),
(144067, 10278, 'Ace Attorney [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/320127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6113MEDzgEzmilnEkgTtRCHBwtq.jpg'),
(144068, 10278, 'Ace Attorney [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/320128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jcbv3pTf7ghf0rC7JwdZbnvUE8K.jpg'),
(144069, 10278, 'Ace Attorney [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/320129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rxpmMm9SirTBrMImIEoyadup038.jpg'),
(144070, 10278, 'Ace Attorney [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/320130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kfu7RsEelWDJYEOGq9iUZuL0QBg.jpg'),
(144071, 10279, 'Ayakashi Triangle [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWvePjdr44GxFGZEOlrd36m1Alx.jpg'),
(144072, 10279, 'Ayakashi Triangle [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cu4NpgLHGkgDxHaQYUZ5fhvjePV.jpg'),
(144073, 10279, 'Ayakashi Triangle [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6v4EIB3mhISmPFcrXeQzJnPS2jy.jpg'),
(144074, 10279, 'Ayakashi Triangle [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/320075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aayWCIVwlXRGxAcFBhPSssXLIA.jpg'),
(144075, 10279, 'Ayakashi Triangle [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8wWVLgqEQ5MPvfUwhRJfR8Mqk8.jpg'),
(144076, 10279, 'Ayakashi Triangle [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zEJkOjh3nVz9quCs6wVMjYYX2EU.jpg'),
(144077, 10279, 'Ayakashi Triangle [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/320078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n8aiigXd5McKiRhYVziNusTbau9.jpg'),
(144078, 10279, 'Ayakashi Triangle [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/320079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6RwvHsDH1vZTduKkqcxkz3Ujt6j.jpg'),
(144079, 10279, 'Ayakashi Triangle [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/320080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4LWBxs44X5perNv3HZg9XFscySP.jpg'),
(144080, 10279, 'Ayakashi Triangle [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/320081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kkfrma4lLv5vJQObBvRSZMJcgA1.jpg'),
(144081, 10279, 'Ayakashi Triangle [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/320082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tso7ry1vVyPiuQNExrQ1TP1HuRq.jpg'),
(144082, 10279, 'Ayakashi Triangle [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/320083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bvU3xQ2o4UuGhdHUXqALrhBv4Tf.jpg'),
(144083, 10280, 'BARTENDER Glass of God [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dzBjBDKgalScwUYpdHJ69HtLjQk.jpg'),
(144084, 10280, 'BARTENDER Glass of God [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mglsK2WEYWNYSODSzTjO5eoHHQ1.jpg'),
(144085, 10280, 'BARTENDER Glass of God [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/329062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mglsK2WEYWNYSODSzTjO5eoHHQ1.jpg'),
(144086, 10280, 'BARTENDER Glass of God [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/333951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mglsK2WEYWNYSODSzTjO5eoHHQ1.jpg'),
(144087, 10280, 'BARTENDER Glass of God [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/345819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mglsK2WEYWNYSODSzTjO5eoHHQ1.jpg'),
(144088, 10280, 'BARTENDER Glass of God [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mglsK2WEYWNYSODSzTjO5eoHHQ1.jpg'),
(144089, 10280, 'BARTENDER Glass of God [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mglsK2WEYWNYSODSzTjO5eoHHQ1.jpg'),
(144090, 10280, 'BARTENDER Glass of God [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/360371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mglsK2WEYWNYSODSzTjO5eoHHQ1.jpg'),
(144091, 10280, 'BARTENDER Glass of God [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/375431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mglsK2WEYWNYSODSzTjO5eoHHQ1.jpg'),
(144092, 10280, 'BARTENDER Glass of God [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/375432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mglsK2WEYWNYSODSzTjO5eoHHQ1.jpg'),
(144093, 10280, 'BARTENDER Glass of God [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/383349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mglsK2WEYWNYSODSzTjO5eoHHQ1.jpg'),
(144094, 10280, 'BARTENDER Glass of God [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/385090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mglsK2WEYWNYSODSzTjO5eoHHQ1.jpg'),
(144095, 10281, 'Hokuto no Ken Legends of the Dark King S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zkuG3WHswXq83A8QXJB1GYF50LQ.jpg'),
(144096, 10281, 'Hokuto no Ken Legends of the Dark King S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2pUAwyjxOQ4xorXPlEPY0GQ0gWb.jpg'),
(144097, 10281, 'Hokuto no Ken Legends of the Dark King S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2alBiXY02X1W542aXJlBWCogrCW.jpg'),
(144098, 10281, 'Hokuto no Ken Legends of the Dark King S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p4Jimz8z4d1RJwaHFfA8TtFWOMB.jpg'),
(144099, 10281, 'Hokuto no Ken Legends of the Dark King S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/327748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p4Jimz8z4d1RJwaHFfA8TtFWOMB.jpg'),
(144100, 10281, 'Hokuto no Ken Legends of the Dark King S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/332608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p4Jimz8z4d1RJwaHFfA8TtFWOMB.jpg'),
(144101, 10281, 'Hokuto no Ken Legends of the Dark King S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/340903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p4Jimz8z4d1RJwaHFfA8TtFWOMB.jpg'),
(144102, 10281, 'Hokuto no Ken Legends of the Dark King S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/352223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p4Jimz8z4d1RJwaHFfA8TtFWOMB.jpg'),
(144103, 10281, 'Hokuto no Ken Legends of the Dark King S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/352224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p4Jimz8z4d1RJwaHFfA8TtFWOMB.jpg'),
(144104, 10281, 'Hokuto no Ken Legends of the Dark King S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/359647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p4Jimz8z4d1RJwaHFfA8TtFWOMB.jpg'),
(144105, 10281, 'Hokuto no Ken Legends of the Dark King S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/405152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p4Jimz8z4d1RJwaHFfA8TtFWOMB.jpg'),
(144106, 10281, 'Hokuto no Ken Legends of the Dark King S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/405153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p4Jimz8z4d1RJwaHFfA8TtFWOMB.jpg'),
(144107, 10281, 'Hokuto no Ken Legends of the Dark King S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/405154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p4Jimz8z4d1RJwaHFfA8TtFWOMB.jpg'),
(144108, 10282, 'Hokuto no Ken Legends of the Dark King [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zkuG3WHswXq83A8QXJB1GYF50LQ.jpg'),
(144109, 10282, 'Hokuto no Ken Legends of the Dark King [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2pUAwyjxOQ4xorXPlEPY0GQ0gWb.jpg'),
(144110, 10282, 'Hokuto no Ken Legends of the Dark King [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2alBiXY02X1W542aXJlBWCogrCW.jpg'),
(144111, 10282, 'Hokuto no Ken Legends of the Dark King [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/320058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/54LQn9WQ3ayWdPBg8IuWHYbuwKx.jpg'),
(144112, 10282, 'Hokuto no Ken Legends of the Dark King [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vh5x89LXFTBG8c66zVbLqxHOrMm.jpg'),
(144113, 10282, 'Hokuto no Ken Legends of the Dark King [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7IceukGlI867n04RBhp9Tyv7q0N.jpg'),
(144114, 10282, 'Hokuto no Ken Legends of the Dark King [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/320061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZHLu9IDfrqKoDAUEG37lwjaIgN.jpg'),
(144115, 10282, 'Hokuto no Ken Legends of the Dark King [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/320062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qy5K6tNUtrNwvCaNKvklCIaixU4.jpg'),
(144116, 10282, 'Hokuto no Ken Legends of the Dark King [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/320063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYKvdKibKYpAEZxK1GCalVSaTqd.jpg'),
(144117, 10282, 'Hokuto no Ken Legends of the Dark King [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/320064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zu8jN5O1YbRS0n0D4IVNVmbXver.jpg'),
(144118, 10282, 'Hokuto no Ken Legends of the Dark King [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/320065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vK964bhtTte97vzufHnrQyn6FQT.jpg'),
(144119, 10282, 'Hokuto no Ken Legends of the Dark King [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/320066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pr98L9bOHkTlvwniO0NTbjiuNcM.jpg'),
(144120, 10282, 'Hokuto no Ken Legends of the Dark King [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/320067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6p8GaEn8eXs5O0wUWZPImkO9ftg.jpg'),
(144121, 10283, 'Hope on the Street [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aFL0XXjrkglQyXEPrmTjvELsGQx.jpg'),
(144122, 10283, 'Hope on the Street [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/25OBxAedLMKGT421Gob07DrxW96.jpg'),
(144123, 10283, 'Hope on the Street [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tuEgLvnYyKFQYpAQhNuVZN3Fciu.jpg'),
(144124, 10283, 'Hope on the Street [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tuEgLvnYyKFQYpAQhNuVZN3Fciu.jpg'),
(144125, 10283, 'Hope on the Street [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tuEgLvnYyKFQYpAQhNuVZN3Fciu.jpg'),
(144126, 10283, 'Hope on the Street [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/325685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tuEgLvnYyKFQYpAQhNuVZN3Fciu.jpg'),
(144127, 10284, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1VZawiNOorcQWt1KnYBqA7iHzvJ.jpg'),
(144128, 10284, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144129, 10284, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/327743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144130, 10284, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/332602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144131, 10284, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/340896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144132, 10284, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/352214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144133, 10284, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/352215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144134, 10284, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/359630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144135, 10284, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/368390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144136, 10284, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/373974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144137, 10284, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/382595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144138, 10284, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/389634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144139, 10285, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/863554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144140, 10285, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/869443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144141, 10285, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/873254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144142, 10285, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/879384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144143, 10285, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/879870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144144, 10285, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/880533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144145, 10285, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/881150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144146, 10285, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/882064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144147, 10285, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/883019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144148, 10285, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/883749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144149, 10285, 'I Was Reincarnated as the 7th Prince so I Can Take My Time Perfecting My Magical Ability [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/885287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mWHmSXFrh3T39DcCt9eEVlFj59I.jpg'),
(144150, 10286, 'Magicas e Pegadinhas com Justin Willman S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9pGn4H8hZ3ZbtoQzJc42ouBk956.jpg'),
(144151, 10286, 'Magicas e Pegadinhas com Justin Willman S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e5XH3BxKg7hC7dueFJ4PE3zVm6p.jpg'),
(144152, 10286, 'Magicas e Pegadinhas com Justin Willman S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qPJ5W3carYqwXF3yXFJ1LBGlveo.jpg'),
(144153, 10286, 'Magicas e Pegadinhas com Justin Willman S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/320049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rdPczF5q1e0o2YaJuvX0MX79zT1.jpg'),
(144154, 10286, 'Magicas e Pegadinhas com Justin Willman S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pqdNDWznU2wmXnfkTzCyrCS1Kjz.jpg'),
(144155, 10286, 'Magicas e Pegadinhas com Justin Willman S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4YbmMHQ3av2pIOEqHpNVNw8VRfU.jpg'),
(144156, 10287, 'RoOT [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nsXn6onjOtgZcen5qgrrCIeYNQo.jpg'),
(144157, 10287, 'RoOT [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/327215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctvB5drGXLsAPIwpTZgnautxLxW.jpg'),
(144158, 10287, 'RoOT [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/327609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctvB5drGXLsAPIwpTZgnautxLxW.jpg'),
(144159, 10287, 'RoOT [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/335978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctvB5drGXLsAPIwpTZgnautxLxW.jpg'),
(144160, 10287, 'RoOT [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/340140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctvB5drGXLsAPIwpTZgnautxLxW.jpg'),
(144161, 10287, 'RoOT [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/606798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctvB5drGXLsAPIwpTZgnautxLxW.jpg'),
(144162, 10287, 'RoOT [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/351417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctvB5drGXLsAPIwpTZgnautxLxW.jpg'),
(144163, 10287, 'RoOT [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/358733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctvB5drGXLsAPIwpTZgnautxLxW.jpg'),
(144164, 10287, 'RoOT [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/373042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctvB5drGXLsAPIwpTZgnautxLxW.jpg'),
(144165, 10287, 'RoOT [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/373043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ctvB5drGXLsAPIwpTZgnautxLxW.jpg'),
(144166, 10288, 'Studio Apartment Good Lighting Angel Included [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fP3klK5lEATeozczZF6vIUJdU0j.jpg'),
(144167, 10288, 'Studio Apartment Good Lighting Angel Included [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/327134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jhCmZmFmHxb7z6qVy13bvCpCRPY.jpg'),
(144168, 10288, 'Studio Apartment Good Lighting Angel Included [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/327135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jhCmZmFmHxb7z6qVy13bvCpCRPY.jpg'),
(144169, 10288, 'Studio Apartment Good Lighting Angel Included [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/332134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jhCmZmFmHxb7z6qVy13bvCpCRPY.jpg'),
(144170, 10288, 'Studio Apartment Good Lighting Angel Included [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/336960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jhCmZmFmHxb7z6qVy13bvCpCRPY.jpg'),
(144171, 10288, 'Studio Apartment Good Lighting Angel Included [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/342991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jhCmZmFmHxb7z6qVy13bvCpCRPY.jpg'),
(144172, 10288, 'Studio Apartment Good Lighting Angel Included [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/354046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jhCmZmFmHxb7z6qVy13bvCpCRPY.jpg'),
(144173, 10288, 'Studio Apartment Good Lighting Angel Included [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/354047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jhCmZmFmHxb7z6qVy13bvCpCRPY.jpg'),
(144174, 10288, 'Studio Apartment Good Lighting Angel Included [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/361406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jhCmZmFmHxb7z6qVy13bvCpCRPY.jpg'),
(144175, 10288, 'Studio Apartment Good Lighting Angel Included [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/605510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jhCmZmFmHxb7z6qVy13bvCpCRPY.jpg'),
(144176, 10288, 'Studio Apartment Good Lighting Angel Included [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/384044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jhCmZmFmHxb7z6qVy13bvCpCRPY.jpg'),
(144177, 10288, 'Studio Apartment Good Lighting Angel Included [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/385707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jhCmZmFmHxb7z6qVy13bvCpCRPY.jpg'),
(144178, 10289, 'The Banished Former Hero Lives as He Pleases [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nK7TxWvojUwWXO4C7eCnejm6HpZ.jpg'),
(144179, 10289, 'The Banished Former Hero Lives as He Pleases [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fxKYPKBSXEFCo0fvrHlyKOCHdrI.jpg'),
(144180, 10289, 'The Banished Former Hero Lives as He Pleases [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/327124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tnvLM8R1xY7IRnhSZFIulCgJc2H.jpg'),
(144181, 10289, 'The Banished Former Hero Lives as He Pleases [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/327496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tnvLM8R1xY7IRnhSZFIulCgJc2H.jpg'),
(144182, 10289, 'The Banished Former Hero Lives as He Pleases [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/335780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tnvLM8R1xY7IRnhSZFIulCgJc2H.jpg'),
(144183, 10289, 'The Banished Former Hero Lives as He Pleases [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/339944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tnvLM8R1xY7IRnhSZFIulCgJc2H.jpg'),
(144184, 10289, 'The Banished Former Hero Lives as He Pleases [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/351260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tnvLM8R1xY7IRnhSZFIulCgJc2H.jpg'),
(144185, 10289, 'The Banished Former Hero Lives as He Pleases [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/351261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tnvLM8R1xY7IRnhSZFIulCgJc2H.jpg'),
(144186, 10289, 'The Banished Former Hero Lives as He Pleases [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/358595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tnvLM8R1xY7IRnhSZFIulCgJc2H.jpg'),
(144187, 10289, 'The Banished Former Hero Lives as He Pleases [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/605911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tnvLM8R1xY7IRnhSZFIulCgJc2H.jpg'),
(144188, 10289, 'The Banished Former Hero Lives as He Pleases [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/372907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tnvLM8R1xY7IRnhSZFIulCgJc2H.jpg'),
(144189, 10289, 'The Banished Former Hero Lives as He Pleases [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/383963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tnvLM8R1xY7IRnhSZFIulCgJc2H.jpg'),
(144190, 10290, 'The Garden Comunidade ou Seita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2BCknqgC7ywfD2kCos6Wl2LpZny.jpg'),
(144191, 10290, 'The Garden Comunidade ou Seita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/327089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2BCknqgC7ywfD2kCos6Wl2LpZny.jpg'),
(144192, 10290, 'The Garden Comunidade ou Seita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/335741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2BCknqgC7ywfD2kCos6Wl2LpZny.jpg'),
(144193, 10290, 'The Garden Comunidade ou Seita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/376223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2BCknqgC7ywfD2kCos6Wl2LpZny.jpg'),
(144194, 10290, 'The Garden Comunidade ou Seita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/376224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2BCknqgC7ywfD2kCos6Wl2LpZny.jpg'),
(144195, 10290, 'The Garden Comunidade ou Seita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/376225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2BCknqgC7ywfD2kCos6Wl2LpZny.jpg'),
(144196, 10291, 'The Synanon Fix Did the Cure Become a Cult [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wqSCqGc2cn4SkccZTAR3G2J8j6x.jpg'),
(144197, 10291, 'The Synanon Fix Did the Cure Become a Cult [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/327087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s8KJ86vspZIM69RA7EX3bspIIec.jpg'),
(144198, 10291, 'The Synanon Fix Did the Cure Become a Cult [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/335738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s8KJ86vspZIM69RA7EX3bspIIec.jpg'),
(144199, 10292, 'Pokemon Horizontes A Serie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qA7nU7QMlGMOuuVtCCLCixYbOuv.jpg'),
(144200, 10292, 'Pokemon Horizontes A Serie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5YcOiSb3E34um8FugYuL4Kl3YBC.jpg'),
(144201, 10292, 'Pokemon Horizontes A Serie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zG94LhboroFNOTDDt7ntqATcOTo.jpg'),
(144202, 10292, 'Pokemon Horizontes A Serie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/320030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rbrP3fkPcnJGLTITu4tacxM99Pm.jpg'),
(144203, 10292, 'Pokemon Horizontes A Serie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLYaUjI8tYBVeKniyOajTJvzpJv.jpg'),
(144204, 10292, 'Pokemon Horizontes A Serie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ltbmI7Fz11g8fKeLjORWfKRpOqa.jpg'),
(144205, 10292, 'Pokemon Horizontes A Serie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/320033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vH369Xd1mLuvjP9L0kPJGZRy6Ei.jpg'),
(144206, 10292, 'Pokemon Horizontes A Serie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/320034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/beO7wzNExoqcrEx8nWgHJFL2NXu.jpg'),
(144207, 10292, 'Pokemon Horizontes A Serie S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/320035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vD4okpDSDbz20yC4XdCqpMZCZru.jpg'),
(144208, 10292, 'Pokemon Horizontes A Serie S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/320036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/guKm9F41kXpfr1iiXm4Ti5imXuC.jpg'),
(144209, 10292, 'Pokemon Horizontes A Serie S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/320037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hdwEgtrSFtRKddpAnP6lnR9dHnp.jpg'),
(144210, 10292, 'Pokemon Horizontes A Serie S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/320038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4MgFqOD81y70G5O3A8HE4FBk7tE.jpg'),
(144211, 10292, 'Pokemon Horizontes A Serie S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/379721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144212, 10292, 'Pokemon Horizontes A Serie S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/379722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144213, 10292, 'Pokemon Horizontes A Serie S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/379723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144214, 10292, 'Pokemon Horizontes A Serie S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/379724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144215, 10292, 'Pokemon Horizontes A Serie S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/379725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144216, 10292, 'Pokemon Horizontes A Serie S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/379726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144217, 10292, 'Pokemon Horizontes A Serie S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/379727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144218, 10292, 'Pokemon Horizontes A Serie S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/379728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144219, 10292, 'Pokemon Horizontes A Serie S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/379729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144220, 10292, 'Pokemon Horizontes A Serie S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/379730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144221, 10292, 'Pokemon Horizontes A Serie S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/379731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144222, 10292, 'Pokemon Horizontes A Serie S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/513022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144223, 10292, 'Pokemon Horizontes A Serie S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/513023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144224, 10292, 'Pokemon Horizontes A Serie S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/513024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144225, 10292, 'Pokemon Horizontes A Serie S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/513025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144226, 10292, 'Pokemon Horizontes A Serie S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/513026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144227, 10292, 'Pokemon Horizontes A Serie S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/513027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144228, 10292, 'Pokemon Horizontes A Serie S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/513028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144229, 10292, 'Pokemon Horizontes A Serie S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/513029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144230, 10292, 'Pokemon Horizontes A Serie S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/513030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144231, 10292, 'Pokemon Horizontes A Serie S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/513031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144232, 10292, 'Pokemon Horizontes A Serie S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/513032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144233, 10292, 'Pokemon Horizontes A Serie S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/513033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144234, 10292, 'Pokemon Horizontes A Serie S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/513034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144235, 10292, 'Pokemon Horizontes A Serie S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/513035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144236, 10292, 'Pokemon Horizontes A Serie S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/513036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144237, 10292, 'Pokemon Horizontes A Serie S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/513037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144238, 10292, 'Pokemon Horizontes A Serie S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/513038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144239, 10292, 'Pokemon Horizontes A Serie S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/513039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144240, 10292, 'Pokemon Horizontes A Serie S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/513040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144241, 10292, 'Pokemon Horizontes A Serie S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/513041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144242, 10292, 'Pokemon Horizontes A Serie S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/513042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144243, 10292, 'Pokemon Horizontes A Serie S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/513043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144244, 10293, 'Pokemon Horizontes A Serie S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/692750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144245, 10293, 'Pokemon Horizontes A Serie S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/692751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144246, 10293, 'Pokemon Horizontes A Serie S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/692752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144247, 10293, 'Pokemon Horizontes A Serie S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/692753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144248, 10293, 'Pokemon Horizontes A Serie S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/692754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144249, 10293, 'Pokemon Horizontes A Serie S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/692755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(144250, 10293, 'Pokemon Horizontes A Serie S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/692756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144251, 10293, 'Pokemon Horizontes A Serie S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/692757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144252, 10293, 'Pokemon Horizontes A Serie S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/692758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144253, 10293, 'Pokemon Horizontes A Serie S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/692759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144254, 10293, 'Pokemon Horizontes A Serie S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/692760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144255, 10293, 'Pokemon Horizontes A Serie S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/778866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144256, 10293, 'Pokemon Horizontes A Serie S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/778867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144257, 10293, 'Pokemon Horizontes A Serie S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/778868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144258, 10293, 'Pokemon Horizontes A Serie S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/778869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144259, 10293, 'Pokemon Horizontes A Serie S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/778870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144260, 10293, 'Pokemon Horizontes A Serie S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/778871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144261, 10293, 'Pokemon Horizontes A Serie S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/778872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144262, 10293, 'Pokemon Horizontes A Serie S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/778873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144263, 10293, 'Pokemon Horizontes A Serie S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/778874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144264, 10293, 'Pokemon Horizontes A Serie S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/778875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144265, 10293, 'Pokemon Horizontes A Serie S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/778876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvT5IBN2syZjlJdPppd6LfxIX2D.jpg'),
(144266, 10294, 'Train to the End of the World [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4tQzuwCVt9VytdMQbB99aRZVGbi.jpg'),
(144267, 10294, 'Train to the End of the World [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jS0XEpSCBgWWpiiX6LjmrNt805K.jpg'),
(144268, 10294, 'Train to the End of the World [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jS0XEpSCBgWWpiiX6LjmrNt805K.jpg'),
(144269, 10294, 'Train to the End of the World [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/335668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jS0XEpSCBgWWpiiX6LjmrNt805K.jpg'),
(144270, 10294, 'Train to the End of the World [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/336852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jS0XEpSCBgWWpiiX6LjmrNt805K.jpg'),
(144271, 10294, 'Train to the End of the World [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/342740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jS0XEpSCBgWWpiiX6LjmrNt805K.jpg'),
(144272, 10294, 'Train to the End of the World [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jS0XEpSCBgWWpiiX6LjmrNt805K.jpg'),
(144273, 10294, 'Train to the End of the World [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jS0XEpSCBgWWpiiX6LjmrNt805K.jpg'),
(144274, 10294, 'Train to the End of the World [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/609102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jS0XEpSCBgWWpiiX6LjmrNt805K.jpg'),
(144275, 10294, 'Train to the End of the World [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/383850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jS0XEpSCBgWWpiiX6LjmrNt805K.jpg'),
(144276, 10294, 'Train to the End of the World [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/383851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jS0XEpSCBgWWpiiX6LjmrNt805K.jpg'),
(144277, 10294, 'Train to the End of the World [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/393990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jS0XEpSCBgWWpiiX6LjmrNt805K.jpg'),
(144278, 10295, 'Wind Breaker [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g84xbY09pycSbUHIf37ehvtruoL.jpg'),
(144279, 10295, 'Wind Breaker [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144280, 10295, 'Wind Breaker [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/332005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144281, 10295, 'Wind Breaker [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/335196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144282, 10295, 'Wind Breaker [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/342288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144283, 10295, 'Wind Breaker [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/350928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144284, 10295, 'Wind Breaker [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/350929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144285, 10295, 'Wind Breaker [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/609021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144286, 10295, 'Wind Breaker [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/609022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144287, 10295, 'Wind Breaker [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/372674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144288, 10295, 'Wind Breaker [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/383761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144289, 10295, 'Wind Breaker [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/388240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144290, 10295, 'Wind Breaker [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/393880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144291, 10296, 'Wind Breaker [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/757684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144292, 10296, 'Wind Breaker [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/762984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144293, 10296, 'Wind Breaker [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/777096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144294, 10296, 'Wind Breaker [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/778034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144295, 10296, 'Wind Breaker [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/791752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144296, 10296, 'Wind Breaker [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/795529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144297, 10296, 'Wind Breaker [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/799406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144298, 10296, 'Wind Breaker [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/807110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144299, 10296, 'Wind Breaker [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/818579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144300, 10296, 'Wind Breaker [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/826442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144301, 10296, 'Wind Breaker [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/834180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(144302, 10297, 'Confissoes Diabolicas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w44s5SYIKIE3fhHeHk2Xj13ktxR.jpg'),
(144303, 10297, 'Confissoes Diabolicas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w44s5SYIKIE3fhHeHk2Xj13ktxR.jpg'),
(144304, 10297, 'Confissoes Diabolicas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w44s5SYIKIE3fhHeHk2Xj13ktxR.jpg'),
(144305, 10297, 'Confissoes Diabolicas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/320899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w44s5SYIKIE3fhHeHk2Xj13ktxR.jpg'),
(144306, 10297, 'Confissoes Diabolicas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w44s5SYIKIE3fhHeHk2Xj13ktxR.jpg'),
(144307, 10297, 'Confissoes Diabolicas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w44s5SYIKIE3fhHeHk2Xj13ktxR.jpg'),
(144308, 10298, 'Confissoes Diabolicas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w44s5SYIKIE3fhHeHk2Xj13ktxR.jpg'),
(144309, 10298, 'Confissoes Diabolicas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w44s5SYIKIE3fhHeHk2Xj13ktxR.jpg'),
(144310, 10298, 'Confissoes Diabolicas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w44s5SYIKIE3fhHeHk2Xj13ktxR.jpg'),
(144311, 10298, 'Confissoes Diabolicas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/320905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w44s5SYIKIE3fhHeHk2Xj13ktxR.jpg'),
(144312, 10298, 'Confissoes Diabolicas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w44s5SYIKIE3fhHeHk2Xj13ktxR.jpg'),
(144313, 10298, 'Confissoes Diabolicas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w44s5SYIKIE3fhHeHk2Xj13ktxR.jpg'),
(144314, 10299, 'Criminosos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7G4UTtxN7aTjChHRAJMAbI34lts.jpg'),
(144315, 10299, 'Criminosos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qpCWyoUcCXTbWH3jGnyH9cwXX5L.jpg'),
(144316, 10299, 'Criminosos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iUlTZbIV3hGb8m4YNOrekxVXVml.jpg'),
(144317, 10299, 'Criminosos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/320891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zpeQVQYPqDJ8NW5oU7YT7eLgXzD.jpg'),
(144318, 10299, 'Criminosos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/frgs71CRd8pZio5n2fRMwwMIDgr.jpg'),
(144319, 10299, 'Criminosos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xIYVTgBbZxl1sxElckYQU4NTIdb.jpg'),
(144320, 10299, 'Criminosos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/320894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kRMwVZyXFqp5J2linSye73aifjo.jpg'),
(144321, 10299, 'Criminosos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/320895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z3EY8iIZcc0TQf1zntKGLIYfFnq.jpg'),
(144322, 10300, 'Da Ponte pra La S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kUBOa7OmgDAJtiWqEzFV8pWEw9x.jpg'),
(144323, 10300, 'Da Ponte pra La S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3fC6CJXcnosZA3ICkngAZ6JES9B.jpg'),
(144324, 10300, 'Da Ponte pra La S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yZYCoBMUL3347JqNaQlDD9JcTrg.jpg'),
(144325, 10300, 'Da Ponte pra La S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/326180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwfdwNNRorcvzWoSmvfD5UveNA1.jpg'),
(144326, 10300, 'Da Ponte pra La S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/326181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwfdwNNRorcvzWoSmvfD5UveNA1.jpg'),
(144327, 10300, 'Da Ponte pra La S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwfdwNNRorcvzWoSmvfD5UveNA1.jpg'),
(144328, 10300, 'Da Ponte pra La S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xwfdwNNRorcvzWoSmvfD5UveNA1.jpg'),
(144329, 10301, 'Parasyte The Grey S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wPY1prusshQWlw8ZUXRYvy2163c.jpg'),
(144330, 10301, 'Parasyte The Grey S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jJUU2vzfv4nO3g34ccFGzMLuZfA.jpg'),
(144331, 10301, 'Parasyte The Grey S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oieqOsgBMnaQWn3SECcjgkXQcF9.jpg'),
(144332, 10301, 'Parasyte The Grey S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/320882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2YT98VYtwxraHXUUN8ICvlW3UpQ.jpg'),
(144333, 10301, 'Parasyte The Grey S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/I7fJxDVF49JJa4RJuH0NOPW3h0.jpg'),
(144334, 10301, 'Parasyte The Grey S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gzArIKUreaXMzAKu0MZMzbbGW0y.jpg'),
(144335, 10302, 'RIPLEY S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFJIdH4aIrQbFgwyUt16YwTWx8M.jpg'),
(144336, 10302, 'RIPLEY S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mH6gBJWxP243PF68l8K8ynUcelX.jpg'),
(144337, 10302, 'RIPLEY S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/320873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pY15qUVSFD0i4n0OxB5HXkdVljH.jpg'),
(144338, 10302, 'RIPLEY S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/320874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rMWwWBfkrE9FSdZgsiqb0tcFrsH.jpg'),
(144339, 10302, 'RIPLEY S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/320875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jnuxXQknOi9kqzdTxqLBJz40Bnx.jpg'),
(144340, 10302, 'RIPLEY S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/320876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/og27CznmcDJTDOfFOpENuJwXZwt.jpg'),
(144341, 10302, 'RIPLEY S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/320877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gIkX2SNEuglDVqjvBZbWu2G5fkm.jpg'),
(144342, 10302, 'RIPLEY S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/320878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ei5povhsRZUKLXDAo9CW3qUMdZO.jpg'),
(144343, 10303, 'Sugar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/320869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqWAMIlH0Xm9TQc1qr36mHRhn73.jpg'),
(144344, 10303, 'Sugar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/320870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r6F32A5Pf6x1bngWFfPystXJlot.jpg'),
(144345, 10303, 'Sugar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/327132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dNrk52Rt13MxwahLneTZJezM6qD.jpg'),
(144346, 10303, 'Sugar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dNrk52Rt13MxwahLneTZJezM6qD.jpg'),
(144347, 10303, 'Sugar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/335845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dNrk52Rt13MxwahLneTZJezM6qD.jpg'),
(144348, 10303, 'Sugar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/342985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dNrk52Rt13MxwahLneTZJezM6qD.jpg'),
(144349, 10303, 'Sugar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/351327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dNrk52Rt13MxwahLneTZJezM6qD.jpg'),
(144350, 10303, 'Sugar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/351328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dNrk52Rt13MxwahLneTZJezM6qD.jpg'),
(144351, 10304, 'A Historia do Mundo Atraves dos Tempos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/325449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yIkuQQzNChmpXLKqAhS1DT34iOa.jpg'),
(144352, 10304, 'A Historia do Mundo Atraves dos Tempos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yIkuQQzNChmpXLKqAhS1DT34iOa.jpg'),
(144353, 10304, 'A Historia do Mundo Atraves dos Tempos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yIkuQQzNChmpXLKqAhS1DT34iOa.jpg'),
(144354, 10305, 'Construcoes que Mudaram o Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/325441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rzQcbjs6Fog1jsnh08Xftsq3yBo.jpg'),
(144355, 10305, 'Construcoes que Mudaram o Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9EmUpxWHctDjSn4UK8Z5OrnADVo.jpg'),
(144356, 10305, 'Construcoes que Mudaram o Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/abWetd8VbTivycYVj4tpvJNyz6B.jpg'),
(144357, 10305, 'Construcoes que Mudaram o Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k99utbQULSP5PByFLBVxcEkV29C.jpg'),
(144358, 10305, 'Construcoes que Mudaram o Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eI4Mr4qqG31lDRlTE5qqSJHT9Ss.jpg'),
(144359, 10305, 'Construcoes que Mudaram o Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/325446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97tk0bBHczWdQa2T84GaLYjczuH.jpg'),
(144360, 10305, 'Construcoes que Mudaram o Mundo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/325447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cD9r4BNHfnjNlcUsGSqp7ktVReP.jpg'),
(144361, 10305, 'Construcoes que Mudaram o Mundo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/325448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gTosvGdb2GMXlwnD7sJawvFmPC.jpg'),
(144362, 10306, 'Corpos no Porao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/325440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1eK3ZCpPMmmegqviZe4qH37CUDU.jpg'),
(144363, 10306, 'Corpos no Porao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNH7bdHp6oEfqQLbpKqJTKz0yAj.jpg'),
(144364, 10306, 'Corpos no Porao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/333204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nNH7bdHp6oEfqQLbpKqJTKz0yAj.jpg'),
(144365, 10307, 'Late Night Lockup Ronda Policial S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/325438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uF4Ytrt3XQrzgRJp93pmg6xsshl.jpg'),
(144366, 10307, 'Late Night Lockup Ronda Policial S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eQs4AGPuBjdDhqeYHK0QBg01IbA.jpg'),
(144367, 10307, 'Late Night Lockup Ronda Policial S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t8Xa7KKShuGsD13cK1LJoEto41J.jpg'),
(144368, 10307, 'Late Night Lockup Ronda Policial S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/338656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t8Xa7KKShuGsD13cK1LJoEto41J.jpg'),
(144369, 10307, 'Late Night Lockup Ronda Policial S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/338657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t8Xa7KKShuGsD13cK1LJoEto41J.jpg'),
(144370, 10307, 'Late Night Lockup Ronda Policial S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/345254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t8Xa7KKShuGsD13cK1LJoEto41J.jpg'),
(144371, 10308, 'Naked Attraction S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/325385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nUW0V7rsXuQHgMfnhJAJWBTRfYN.jpg'),
(144372, 10308, 'Naked Attraction S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oLHWkIrTDWYftNOqg7f92ML3Wq.jpg'),
(144373, 10308, 'Naked Attraction S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/faBNEDMsmLrW1pjpgPG862S82WJ.jpg'),
(144374, 10308, 'Naked Attraction S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBVpOLTCyW1j0hllQ6RazHt2PWi.jpg'),
(144375, 10308, 'Naked Attraction S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u5RZxRUFRXStuq15c0d3GMQdkss.jpg'),
(144376, 10309, 'Naked Attraction S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/325390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/70OpgZ0WXhMlEuY3IITv9XyYz7V.jpg'),
(144377, 10309, 'Naked Attraction S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A2SwiLPBK7tTJQfoSXci27TrFhQ.jpg'),
(144378, 10309, 'Naked Attraction S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7fzSW9yZX48ffa9ozIrhVnMvITd.jpg'),
(144379, 10309, 'Naked Attraction S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cQOJ0lX8b4nfWDq34tqIKYcuUUo.jpg'),
(144380, 10309, 'Naked Attraction S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dFUAoLG2jWop4e1Hq514zirpYVY.jpg'),
(144381, 10309, 'Naked Attraction S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/325395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Jk6TS5EVRQSW9Cu66aNl2mQ3F8.jpg'),
(144382, 10309, 'Naked Attraction S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/325396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ugsvM27zWl9JI0ne9pcbhgLn2i7.jpg'),
(144383, 10309, 'Naked Attraction S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/325397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d8vGd4GMlY0vW1HlJ1oYDwQIbdH.jpg'),
(144384, 10309, 'Naked Attraction S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/325398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oIf9Xs0n2RzUVME6fVxn1ZARCzF.jpg'),
(144385, 10309, 'Naked Attraction S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/325399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iOJIlfiKSGBMW1l35qSdjmIYhlE.jpg'),
(144386, 10310, 'Naked Attraction S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/325400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zI1LAYMkV8sUGIEoiUTCrsQyC3y.jpg'),
(144387, 10310, 'Naked Attraction S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rXGVp06YhHyHSwa821W1eh6qrSw.jpg'),
(144388, 10310, 'Naked Attraction S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nvTL6zxXTBlDU7fRVVTgp6WXSQr.jpg'),
(144389, 10310, 'Naked Attraction S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cY9DWlI5ivnPovLUk06zdM0TfbX.jpg'),
(144390, 10310, 'Naked Attraction S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uk6VXtXNlR7FmYn8SLPLZyvCM1U.jpg'),
(144391, 10310, 'Naked Attraction S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/325405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uk6VXtXNlR7FmYn8SLPLZyvCM1U.jpg'),
(144392, 10310, 'Naked Attraction S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/325406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uk6VXtXNlR7FmYn8SLPLZyvCM1U.jpg'),
(144393, 10310, 'Naked Attraction S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/325407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uk6VXtXNlR7FmYn8SLPLZyvCM1U.jpg'),
(144394, 10310, 'Naked Attraction S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/325408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uk6VXtXNlR7FmYn8SLPLZyvCM1U.jpg'),
(144395, 10310, 'Naked Attraction S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/325409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uk6VXtXNlR7FmYn8SLPLZyvCM1U.jpg'),
(144396, 10311, 'Naked Attraction S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/325410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3iLjwUJiWfRfW1rhTmcm9tE1Csq.jpg'),
(144397, 10311, 'Naked Attraction S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bIuv0to88picR2B01PcYymQbUsy.jpg'),
(144398, 10311, 'Naked Attraction S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lbItQTPvgSmqPLPrJ69UvOSPDWw.jpg'),
(144399, 10311, 'Naked Attraction S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/suwtCrFlX4Azou4xFBQcS3qjbj.jpg'),
(144400, 10311, 'Naked Attraction S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yPTlwb50s9Hm9LcTkZzVahbIU71.jpg'),
(144401, 10311, 'Naked Attraction S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/325415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lGMpDzoT8lcrKAbWd6G5RzDMUnj.jpg'),
(144402, 10311, 'Naked Attraction S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/325416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uk6VXtXNlR7FmYn8SLPLZyvCM1U.jpg'),
(144403, 10311, 'Naked Attraction S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/325417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uk6VXtXNlR7FmYn8SLPLZyvCM1U.jpg'),
(144404, 10311, 'Naked Attraction S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/325418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uk6VXtXNlR7FmYn8SLPLZyvCM1U.jpg'),
(144405, 10311, 'Naked Attraction S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/325419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uk6VXtXNlR7FmYn8SLPLZyvCM1U.jpg'),
(144406, 10312, 'Naked Attraction S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/325420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dGgCLFZgk7uYVKM2QtnxIw5nAR0.jpg'),
(144407, 10312, 'Naked Attraction S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Nx3SawxQAzui8LtNdLmBKJUpJB.jpg'),
(144408, 10312, 'Naked Attraction S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ali0CV2v42U1nWz17MK7CDkpCFo.jpg'),
(144409, 10312, 'Naked Attraction S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xyQnd4yVir0mvBcxycO8zFohexK.jpg'),
(144410, 10312, 'Naked Attraction S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lWI51BcHo6fEXH2E6EG9wHTS4eM.jpg'),
(144411, 10312, 'Naked Attraction S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/325425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uk6VXtXNlR7FmYn8SLPLZyvCM1U.jpg'),
(144412, 10312, 'Naked Attraction S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/325426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uk6VXtXNlR7FmYn8SLPLZyvCM1U.jpg'),
(144413, 10312, 'Naked Attraction S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/325427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uk6VXtXNlR7FmYn8SLPLZyvCM1U.jpg'),
(144414, 10312, 'Naked Attraction S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/325428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uk6VXtXNlR7FmYn8SLPLZyvCM1U.jpg'),
(144415, 10312, 'Naked Attraction S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/325429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uk6VXtXNlR7FmYn8SLPLZyvCM1U.jpg'),
(144416, 10313, 'Naked Attraction S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/325430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2S8ES4zTVuYVVYhLAp0RmxD5lk.jpg'),
(144417, 10313, 'Naked Attraction S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c9eadQsknQ3xvICBJMR2HW0D2rt.jpg'),
(144418, 10313, 'Naked Attraction S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gL7GGKOLGeagjfhmGlKfbQiAgx0.jpg'),
(144419, 10313, 'Naked Attraction S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9w2WEje416ouJwFGJQ3zmpDFEPp.jpg'),
(144420, 10313, 'Naked Attraction S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tBIAK6vNItW3scAxjElexFIErzR.jpg'),
(144421, 10313, 'Naked Attraction S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/325435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uk6VXtXNlR7FmYn8SLPLZyvCM1U.jpg'),
(144422, 10313, 'Naked Attraction S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/325436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uk6VXtXNlR7FmYn8SLPLZyvCM1U.jpg'),
(144423, 10313, 'Naked Attraction S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/325437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uk6VXtXNlR7FmYn8SLPLZyvCM1U.jpg'),
(144424, 10314, 'Quando As Luzes Se Apagam S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/325379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kiVZOMrNbQ28MGgS0p05VBOsMD9.jpg'),
(144425, 10314, 'Quando As Luzes Se Apagam S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Dke6GDdnS22LOZuUWnsnGYfu9P.jpg'),
(144426, 10314, 'Quando As Luzes Se Apagam S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mnKJexiOmyZR675C98wwdgjSuv5.jpg'),
(144427, 10314, 'Quando As Luzes Se Apagam S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1SnvJk3FD5iE9cXP3fzxWq8D4AK.jpg'),
(144428, 10314, 'Quando As Luzes Se Apagam S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/okA5BVCn4cWtc5mqAD6mINfLh5U.jpg'),
(144429, 10314, 'Quando As Luzes Se Apagam S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/325384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zDmZkW2D8dMspkKBtrpk9o3Jomh.jpg'),
(144430, 10315, 'The Town Doctor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/325355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/adYdNNuI7CrdAPfQnC2VNdJAsYv.jpg'),
(144431, 10315, 'The Town Doctor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/czXPyccrqTP2GkrprROKU2IQJlD.jpg'),
(144432, 10315, 'The Town Doctor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDKBq4YAZ9yg5T0yG6VdqZ3AMQi.jpg'),
(144433, 10315, 'The Town Doctor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y8BdCuOtPrml3HLnXK2RJQKAWhA.jpg'),
(144434, 10315, 'The Town Doctor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gx8lPlcFokYv3eBYSOElyoQ4ToY.jpg'),
(144435, 10315, 'The Town Doctor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/325360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bQNDzvhY45g5GTqFZWPd3P5uDKi.jpg'),
(144436, 10315, 'The Town Doctor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/325361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sYFCuNvLC2bqNFdcABraLnCQqyI.jpg'),
(144437, 10315, 'The Town Doctor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/325362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13zBmU0nyAz0zptrXPKlKdOpAy8.jpg'),
(144438, 10315, 'The Town Doctor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/325363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jDJYvJan6sIl68BycrvslpNnZnf.jpg'),
(144439, 10315, 'The Town Doctor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/325364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7M6yF8S9q11l2gHzHpDETawMnf4.jpg'),
(144440, 10315, 'The Town Doctor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/325365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kkHOUHqDmJVc2kW5S58cuicLD0e.jpg'),
(144441, 10315, 'The Town Doctor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/325366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5EF1qdypfqC61ZQszbkmcCoupXh.jpg'),
(144442, 10315, 'The Town Doctor S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/325367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cQTu3h59OApSHNJ31Dtw4uzBma8.jpg'),
(144443, 10315, 'The Town Doctor S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/325368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144444, 10315, 'The Town Doctor S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/325369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144445, 10315, 'The Town Doctor S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/325370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144446, 10315, 'The Town Doctor S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/325371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144447, 10315, 'The Town Doctor S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/325372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144448, 10315, 'The Town Doctor S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/325373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144449, 10315, 'The Town Doctor S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/325374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144450, 10315, 'The Town Doctor S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/325375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144451, 10315, 'The Town Doctor S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/325376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144452, 10315, 'The Town Doctor S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/325377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144453, 10315, 'The Town Doctor S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/325378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144454, 10315, 'The Town Doctor S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/327059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144455, 10315, 'The Town Doctor S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/327060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144456, 10315, 'The Town Doctor S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/335705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144457, 10315, 'The Town Doctor S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/335706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144458, 10315, 'The Town Doctor S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/335707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144459, 10315, 'The Town Doctor S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/335708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144460, 10315, 'The Town Doctor S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/339880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144461, 10315, 'The Town Doctor S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/339881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144462, 10315, 'The Town Doctor S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/351020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144463, 10315, 'The Town Doctor S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/351021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144464, 10315, 'The Town Doctor S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/351022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144465, 10315, 'The Town Doctor S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/351023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144466, 10315, 'The Town Doctor S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/358301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144467, 10315, 'The Town Doctor S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/358302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144468, 10315, 'The Town Doctor S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/607236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wFR883EIKf58gf3JZetSmLWbv7m.jpg'),
(144469, 10316, 'Unidos Manchester City Tricampeao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/325349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMGBDkV7Acj1j7zU7zkWcJ2otkG.jpg'),
(144470, 10316, 'Unidos Manchester City Tricampeao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3D59jHiXgft4CkeQfP6u6t9wA0b.jpg'),
(144471, 10316, 'Unidos Manchester City Tricampeao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ydko8KyRw3fLg1ibbvAGWJmwoms.jpg'),
(144472, 10316, 'Unidos Manchester City Tricampeao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p0jXl56Ie7c6Ncad9zfhdmV9f3F.jpg'),
(144473, 10316, 'Unidos Manchester City Tricampeao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gfpY01p4KyzqmG9aeZoHFgDrnvk.jpg'),
(144474, 10316, 'Unidos Manchester City Tricampeao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/325354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lSuXkK2mFqMcFNg63jjk5LmsL41.jpg'),
(144475, 10317, 'Antracite S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/325343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7aVnVs9Rh7fvgkpUWuvNw1TXF5a.jpg'),
(144476, 10317, 'Antracite S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7aVnVs9Rh7fvgkpUWuvNw1TXF5a.jpg'),
(144477, 10317, 'Antracite S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7aVnVs9Rh7fvgkpUWuvNw1TXF5a.jpg'),
(144478, 10317, 'Antracite S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7aVnVs9Rh7fvgkpUWuvNw1TXF5a.jpg'),
(144479, 10317, 'Antracite S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7aVnVs9Rh7fvgkpUWuvNw1TXF5a.jpg'),
(144480, 10317, 'Antracite S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/325348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7aVnVs9Rh7fvgkpUWuvNw1TXF5a.jpg'),
(144481, 10318, 'Emagreci e Agora S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/325310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144482, 10318, 'Emagreci e Agora S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144483, 10318, 'Emagreci e Agora S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144484, 10318, 'Emagreci e Agora S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144485, 10318, 'Emagreci e Agora S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144486, 10318, 'Emagreci e Agora S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/325315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144487, 10318, 'Emagreci e Agora S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/325316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144488, 10319, 'Emagreci e Agora S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/325317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144489, 10319, 'Emagreci e Agora S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144490, 10319, 'Emagreci e Agora S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144491, 10319, 'Emagreci e Agora S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144492, 10319, 'Emagreci e Agora S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144493, 10319, 'Emagreci e Agora S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/325322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144494, 10319, 'Emagreci e Agora S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/325323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144495, 10319, 'Emagreci e Agora S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/325324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144496, 10319, 'Emagreci e Agora S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/325325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144497, 10319, 'Emagreci e Agora S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/325326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144498, 10319, 'Emagreci e Agora S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/325327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144499, 10320, 'Emagreci e Agora S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/325328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144500, 10320, 'Emagreci e Agora S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144501, 10320, 'Emagreci e Agora S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144502, 10320, 'Emagreci e Agora S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144503, 10320, 'Emagreci e Agora S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144504, 10320, 'Emagreci e Agora S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/325333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144505, 10320, 'Emagreci e Agora S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/325334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144506, 10320, 'Emagreci e Agora S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/325335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144507, 10320, 'Emagreci e Agora S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/325336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(144508, 10320, 'Emagreci e Agora S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/325337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144509, 10320, 'Emagreci e Agora S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/325338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144510, 10320, 'Emagreci e Agora S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/325339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144511, 10320, 'Emagreci e Agora S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/325340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144512, 10320, 'Emagreci e Agora S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/325341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144513, 10320, 'Emagreci e Agora S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/325342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3e7HmbKrsiggPPsPQIVITg8zNhx.jpg'),
(144514, 10321, 'O Curioso Caso de Natalia Grace S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/325304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rRnahQiE5IiWBOWFctAwpukDQJ5.jpg'),
(144515, 10321, 'O Curioso Caso de Natalia Grace S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fCg3TmuxAMs9y8FarCMLFoubN33.jpg'),
(144516, 10321, 'O Curioso Caso de Natalia Grace S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nwcPHx4RRWqxAwDrC8LpIVhxXW5.jpg'),
(144517, 10321, 'O Curioso Caso de Natalia Grace S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rkM2ycvIDPbeQL8Hr0W1S0I1rU2.jpg'),
(144518, 10321, 'O Curioso Caso de Natalia Grace S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/er9V1AhvSbVqBLGVPIBtDvv6Fzt.jpg'),
(144519, 10321, 'O Curioso Caso de Natalia Grace S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/325309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/phTHpmXSbrP6nqZv3ZnZ22Jk91y.jpg'),
(144520, 10322, 'O Curioso Caso de Natalia Grace S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/868543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z3MfCahZ40oWmWQG3pwiYJlH3xp.jpg'),
(144521, 10322, 'O Curioso Caso de Natalia Grace S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/868544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aK7sxNtgcq6Vk914ss7Dl0ViZPr.jpg'),
(144522, 10322, 'O Curioso Caso de Natalia Grace S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/868545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ifbYVKk954CX8EIHVAW77ZDvjxU.jpg'),
(144523, 10322, 'O Curioso Caso de Natalia Grace S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/868546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uxq3OzzwgYNhLObm66pWrV2g0MR.jpg'),
(144524, 10322, 'O Curioso Caso de Natalia Grace S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/868547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w4VdR95Yx8yRroHN6xPd72xUqS9.jpg'),
(144525, 10322, 'O Curioso Caso de Natalia Grace S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/868548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4intBXvlEDKyQgfrMC3hkT8iNIf.jpg'),
(144526, 10323, 'O Curioso Caso de Natalia Grace S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/868549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3RoY5Mg7qYCDOyn69efCUJLTtFX.jpg'),
(144527, 10323, 'O Curioso Caso de Natalia Grace S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/868550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/huTdLE8AmrdrbRtqhP1c7YfJYCe.jpg'),
(144528, 10323, 'O Curioso Caso de Natalia Grace S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/868551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6cj1CJI68M5qR1xKQqqDaAErbD7.jpg'),
(144529, 10323, 'O Curioso Caso de Natalia Grace S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/868552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kZYqQLVST4qdPftYE5mNcxPFhWI.jpg'),
(144530, 10324, 'RFDS Royal Flying Doctor Service S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/325291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8NCnRVxmE4Q10olTvi2VEGRN6aV.jpg'),
(144531, 10324, 'RFDS Royal Flying Doctor Service S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfAkGj9NUrMpsFxYfftkquwYlKk.jpg'),
(144532, 10324, 'RFDS Royal Flying Doctor Service S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/81tE6C3LKzaHM13YUVKn28CVVHr.jpg'),
(144533, 10324, 'RFDS Royal Flying Doctor Service S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7FkEqD31HVzsdtJiyLjkjgVRiVO.jpg'),
(144534, 10324, 'RFDS Royal Flying Doctor Service S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/axwZdYnKiUDJsrp9hkDIdqo8qd0.jpg'),
(144535, 10324, 'RFDS Royal Flying Doctor Service S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/325296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nq3lPJucTiDRD1ikhsHhFt1UYj7.jpg'),
(144536, 10324, 'RFDS Royal Flying Doctor Service S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/325297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y1YxFnQJErUBXnB4nTBXGavMGg5.jpg'),
(144537, 10324, 'RFDS Royal Flying Doctor Service S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/325298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6rtVdOLI2xVgWf7Qjsu4i7RQPga.jpg'),
(144538, 10325, 'RFDS Royal Flying Doctor Service S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/325299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DZ7aQTriSraVU8T1ruJN0KgxQw.jpg'),
(144539, 10325, 'RFDS Royal Flying Doctor Service S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/325300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mMYXyMiCRzFPGPspZfYpHrj4l9x.jpg'),
(144540, 10325, 'RFDS Royal Flying Doctor Service S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/325301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/poH7XrvqcpTFzRD9yHuJBynCtmV.jpg'),
(144541, 10325, 'RFDS Royal Flying Doctor Service S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/325302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r5FPpPuEiUl0QutAt8YNIl5hQR9.jpg'),
(144542, 10325, 'RFDS Royal Flying Doctor Service S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/325303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q1AuZlHFM4fx44JU0Uq5jLaLDoA.jpg'),
(144543, 10325, 'RFDS Royal Flying Doctor Service S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/327623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DZ7aQTriSraVU8T1ruJN0KgxQw.jpg'),
(144544, 10325, 'RFDS Royal Flying Doctor Service S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/336105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DZ7aQTriSraVU8T1ruJN0KgxQw.jpg'),
(144545, 10325, 'RFDS Royal Flying Doctor Service S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/340550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1DZ7aQTriSraVU8T1ruJN0KgxQw.jpg'),
(144546, 10326, 'A Senhora Davis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tME8WLeS5HtA4aHQgLWO4f3BM3y.jpg'),
(144547, 10326, 'A Senhora Davis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTjhlpf99oLUiok6KhfF97NqLuj.jpg'),
(144548, 10326, 'A Senhora Davis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u0ADKppeVhGNd4hQ7OmLZZ6QzjI.jpg'),
(144549, 10326, 'A Senhora Davis S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u0ADKppeVhGNd4hQ7OmLZZ6QzjI.jpg'),
(144550, 10326, 'A Senhora Davis S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/334022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u0ADKppeVhGNd4hQ7OmLZZ6QzjI.jpg'),
(144551, 10326, 'A Senhora Davis S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/334023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u0ADKppeVhGNd4hQ7OmLZZ6QzjI.jpg'),
(144552, 10326, 'A Senhora Davis S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/345880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u0ADKppeVhGNd4hQ7OmLZZ6QzjI.jpg'),
(144553, 10326, 'A Senhora Davis S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/345881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u0ADKppeVhGNd4hQ7OmLZZ6QzjI.jpg'),
(144554, 10327, 'Bebe Rena S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cxZFsDNJYuXok0tbBr6wGRcHD8D.jpg'),
(144555, 10327, 'Bebe Rena S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dYsm3wxygwwb6mSBvgaEIgSxN6O.jpg'),
(144556, 10327, 'Bebe Rena S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/39YGnnlZisihAO5yJzo31StWWLm.jpg'),
(144557, 10327, 'Bebe Rena S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/326588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZBaF3biDBOxk7SzdsJF9EURWoq.jpg'),
(144558, 10327, 'Bebe Rena S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/326589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/juiYyuLtcaik792whB7jZYzWuAC.jpg'),
(144559, 10327, 'Bebe Rena S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/326590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pqQjoBNbE3VAZ6q3280zciI1Kmd.jpg'),
(144560, 10327, 'Bebe Rena S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/326591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/db23JLHDxQ4HSqlsuKFm3YWhlSA.jpg'),
(144561, 10328, 'Fallout S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sEQLaNLxV6zX22ESkTlbXFDROKK.jpg'),
(144562, 10328, 'Fallout S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zyEkugNM2IIlSyNWFc3sJpjaoFD.jpg'),
(144563, 10328, 'Fallout S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dj45nhpYWrLd3DhAewOxjdt2GuT.jpg'),
(144564, 10328, 'Fallout S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/326580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qHsYEQ8yZGomnVZT2rmpwz27r4l.jpg'),
(144565, 10328, 'Fallout S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/326581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5jFf0PjFocJ4V8SvC4FsnruQNWJ.jpg'),
(144566, 10328, 'Fallout S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/326582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aNWKd48GEEWgPjpnI5IwV5kRhIJ.jpg'),
(144567, 10328, 'Fallout S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/326583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qLXHRb2131kGo2AeTgegLI1BU3g.jpg'),
(144568, 10328, 'Fallout S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/326584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qChsq0i2LBQNd7v3T16T6PXhzH7.jpg'),
(144569, 10329, 'Massacre of the Mormons S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fntOVuaOLHC0vk0Sk6XE8yM19fy.jpg'),
(144570, 10329, 'Massacre of the Mormons S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fntOVuaOLHC0vk0Sk6XE8yM19fy.jpg'),
(144571, 10330, 'Naked Attraction Os Mais Atrevidos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dXmXz4Nm6Qh2YcHGygoVR2oU0bn.jpg'),
(144572, 10330, 'Naked Attraction Os Mais Atrevidos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dXmXz4Nm6Qh2YcHGygoVR2oU0bn.jpg'),
(144573, 10330, 'Naked Attraction Os Mais Atrevidos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dXmXz4Nm6Qh2YcHGygoVR2oU0bn.jpg'),
(144574, 10330, 'Naked Attraction Os Mais Atrevidos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/326573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dXmXz4Nm6Qh2YcHGygoVR2oU0bn.jpg'),
(144575, 10330, 'Naked Attraction Os Mais Atrevidos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/326574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dXmXz4Nm6Qh2YcHGygoVR2oU0bn.jpg'),
(144576, 10331, 'Noite de Verao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sXcQVWYhC6vvhG299EJyF84QvTz.jpg'),
(144577, 10331, 'Noite de Verao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5hH6QbExA8dCInYfpNAceh5XMQ0.jpg'),
(144578, 10331, 'Noite de Verao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qkhfUtZCwvKfPgX05ilpUMz2CQo.jpg'),
(144579, 10331, 'Noite de Verao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/326568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rhOqtZdaYxfAeyAbBVq0IyqgMaH.jpg'),
(144580, 10331, 'Noite de Verao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/326569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yjwK9bvB2LcRICh19UR6kNNpMpJ.jpg'),
(144581, 10332, 'Sabadou com Virginia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/327202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144582, 10332, 'Sabadou com Virginia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/327203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144583, 10332, 'Sabadou com Virginia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/332467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144584, 10332, 'Sabadou com Virginia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/337258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144585, 10332, 'Sabadou com Virginia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/343319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144586, 10332, 'Sabadou com Virginia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/354355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144587, 10332, 'Sabadou com Virginia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/354356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144588, 10332, 'Sabadou com Virginia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/362954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144589, 10332, 'Sabadou com Virginia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/373027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144590, 10332, 'Sabadou com Virginia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/379544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144591, 10332, 'Sabadou com Virginia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/385819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144592, 10332, 'Sabadou com Virginia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144593, 10332, 'Sabadou com Virginia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/400291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144594, 10332, 'Sabadou com Virginia S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/401420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144595, 10332, 'Sabadou com Virginia S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/407165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144596, 10332, 'Sabadou com Virginia S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/414389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144597, 10332, 'Sabadou com Virginia S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/418194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144598, 10332, 'Sabadou com Virginia S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/423086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144599, 10332, 'Sabadou com Virginia S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/430857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144600, 10332, 'Sabadou com Virginia S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/441136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144601, 10332, 'Sabadou com Virginia S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/450333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144602, 10332, 'Sabadou com Virginia S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/450334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144603, 10332, 'Sabadou com Virginia S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/454578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144604, 10332, 'Sabadou com Virginia S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/459296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144605, 10332, 'Sabadou com Virginia S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/466535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144606, 10332, 'Sabadou com Virginia S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/472256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144607, 10332, 'Sabadou com Virginia S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/490238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144608, 10332, 'Sabadou com Virginia S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/490239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3rxNTX7i0UmFe0gbvFeg4OCDzaM.jpg'),
(144609, 10333, 'As Lendas [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fD4KEc0A9TXfD2EJSvG7a4yaguC.jpg'),
(144610, 10333, 'As Lendas [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uzhAK5mI6SLKMcU8yaymoxwSL5s.jpg'),
(144611, 10333, 'As Lendas [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e2fxU6P47oU6MntXiPUofMrL2AM.jpg'),
(144612, 10333, 'As Lendas [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/326513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pNc8TvcnL5oVVB6rDHlDx9cX0zX.jpg'),
(144613, 10333, 'As Lendas [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/326514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/91tIcZ0jIobV8ytseCmYJx6wWvm.jpg'),
(144614, 10333, 'As Lendas [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/326515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3a2bsbmrZ89OiVMMbqhdUdklgV6.jpg'),
(144615, 10333, 'As Lendas [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/326516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4paNaGt8hswHAdsgRF6Dbupf0es.jpg'),
(144616, 10333, 'As Lendas [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/326517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bsXbl20zy5fZr7Tg9U9uNOX5Blc.jpg'),
(144617, 10333, 'As Lendas [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/326518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ov44AFnanKjhGtFG0wsoJCnsQo0.jpg'),
(144618, 10333, 'As Lendas [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/326519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJLzgIXD4LuymyhN9pURTM9ZUS0.jpg'),
(144619, 10333, 'As Lendas [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/326520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lsfMpsS40dnf601u2gAEJ55dUzS.jpg'),
(144620, 10333, 'As Lendas [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/326521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AkrEnF1hqYVwaxJK0UCqDFxOlcr.jpg'),
(144621, 10333, 'As Lendas [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/326522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4LutWw4fAXu8PhlTibTJPI645Os.jpg'),
(144622, 10333, 'As Lendas [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/326523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fD7nU2wX0NOky1GJtsI9Tzo10CC.jpg'),
(144623, 10333, 'As Lendas [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/326524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wy9Mx6cJomfmqAlMr950CuYM5mS.jpg'),
(144624, 10333, 'As Lendas [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/326525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ajhWh5y1qT4iGYqEh1e6Hfus7o0.jpg'),
(144625, 10333, 'As Lendas [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/326526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gfjGAcxWjm7R1RFZgTBhToVr4MZ.jpg'),
(144626, 10333, 'As Lendas [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/326527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xt1VffHlemaaIGKUsMsJjLUV1kF.jpg'),
(144627, 10333, 'As Lendas [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/326528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AvqmbJfHY74WHFBwRCjvSZSE02p.jpg'),
(144628, 10333, 'As Lendas [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/326529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xo2QCYsypkdNk4RqQEGOOnG1MtS.jpg'),
(144629, 10333, 'As Lendas [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/326530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3b3bJSDdklmjshdfv397LiDaX4.jpg'),
(144630, 10333, 'As Lendas [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/326531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tgyIpNqkbG2xaKNxnWXDBQQL02K.jpg'),
(144631, 10333, 'As Lendas [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/326532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/duPVqyIV9pqRhsSD6m6Bn323Qwc.jpg'),
(144632, 10333, 'As Lendas [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/326533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lB1EYYwQzC3XsAM4ijaDFpKqMVl.jpg'),
(144633, 10333, 'As Lendas [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/326534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mDaofmLSLp7s3iuTA7RaeKB9xV1.jpg'),
(144634, 10333, 'As Lendas [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/326535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j1Ur5GhhqZlFhVOrYMNhMQ2rzGi.jpg'),
(144635, 10333, 'As Lendas [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/326536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fIZr30DCo7H9qqydLRHZB8dlpfs.jpg'),
(144636, 10333, 'As Lendas [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/326537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jok52q02WkUHTeQI7EM0ONuWS8A.jpg'),
(144637, 10333, 'As Lendas [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/326538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sEF1BelDwRhUWTPApi0tiHbPayI.jpg'),
(144638, 10333, 'As Lendas [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/326539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1RlRA9bDl4tvFKxere2XRbAY7tf.jpg'),
(144639, 10333, 'As Lendas [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/326540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y3MrNXPKFuRJeYrqJGdHOWAePF4.jpg'),
(144640, 10333, 'As Lendas [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/326541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5iiGyNlaDbuY7PyWh3DXy0t92CR.jpg'),
(144641, 10333, 'As Lendas [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/326542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cPKqAQBBHTGrR7FziuiRPPOgq0P.jpg'),
(144642, 10333, 'As Lendas [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/326543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nYZz5ZrdbL4YwfSICGI4uy42ZfT.jpg'),
(144643, 10333, 'As Lendas [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/326544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cSvySu6xI0ix548pkFbF5XRvzJp.jpg'),
(144644, 10333, 'As Lendas [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/326545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dCsDS3M8Ki1VLuvSITmEYpl6aFA.jpg'),
(144645, 10333, 'As Lendas [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/326546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yYRtBaN1rC3Q2T3YwsoX1hfGjAM.jpg'),
(144646, 10333, 'As Lendas [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/326547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pcy8Jew0T1Lei0CAHxK69vp5cn9.jpg'),
(144647, 10333, 'As Lendas [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/326548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4C8ajjvQgV3a9lBjFkH4MB5vRSm.jpg'),
(144648, 10333, 'As Lendas [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/326549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ihBGc97sJhDXEv0U0TDuaEh55rC.jpg'),
(144649, 10333, 'As Lendas [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/326550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7VQQI3xWI7ytjpJzELV12KUNIch.jpg'),
(144650, 10333, 'As Lendas [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/326551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f5lGgqn5cxSP2QNvnRVq5rQmlwq.jpg'),
(144651, 10333, 'As Lendas [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/326552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o99LRQlRTKqAbMp9igrqw0SazvD.jpg'),
(144652, 10333, 'As Lendas [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/326553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q6XTCv6ABr3171Wwpz0NHuhbgav.jpg'),
(144653, 10333, 'As Lendas [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/326554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xxFaEYJdQhCPTAU7yqJLmGu0x6x.jpg'),
(144654, 10333, 'As Lendas [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/326555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2JtfnYU4zIn8kf56JsJze5j3Tw9.jpg'),
(144655, 10333, 'As Lendas [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/326556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s4dgg0FbUyaHdtUcujveROxDotE.jpg'),
(144656, 10333, 'As Lendas [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/326557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/msfcsSO2UgqM5XdvuxpUKrWYQkO.jpg'),
(144657, 10333, 'As Lendas [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/326558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2PlN6oD1XeJi0Ih0kbiINjAqXPg.jpg'),
(144658, 10333, 'As Lendas [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/326559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQNqN9mo85BYWlBMMT43zkc0Gvc.jpg'),
(144659, 10333, 'As Lendas [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/326560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gF6p2WkwIYFAI07WBNsLwaJUvdD.jpg'),
(144660, 10333, 'As Lendas [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/326561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4HzRBEIlbDKnWKOWRYCJkOU5XXr.jpg'),
(144661, 10333, 'As Lendas [L] S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/326562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ymIXyE5T7o97BorVIBvfZIkJERY.jpg'),
(144662, 10333, 'As Lendas [L] S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/326563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hCUjA6N0Y0ZKvTJwwWYxLoqO17N.jpg'),
(144663, 10333, 'As Lendas [L] S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/326564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/teYIaiS46dCDGKI7bP7gP6iO63V.jpg'),
(144664, 10334, 'DORA S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144665, 10334, 'DORA S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144666, 10334, 'DORA S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144667, 10334, 'DORA S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/326493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144668, 10334, 'DORA S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/326494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144669, 10334, 'DORA S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/326495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144670, 10334, 'DORA S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/326496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144671, 10334, 'DORA S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/326497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144672, 10334, 'DORA S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/326498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144673, 10334, 'DORA S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/326499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144674, 10334, 'DORA S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/326500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144675, 10334, 'DORA S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/326501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144676, 10334, 'DORA S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/326502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144677, 10334, 'DORA S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/326503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144678, 10334, 'DORA S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/326504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144679, 10334, 'DORA S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/326505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144680, 10334, 'DORA S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/326506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144681, 10334, 'DORA S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/326507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144682, 10334, 'DORA S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/326508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144683, 10334, 'DORA S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/326509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144684, 10334, 'DORA S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/518677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144685, 10334, 'DORA S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/518678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144686, 10334, 'DORA S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/518679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144687, 10334, 'DORA S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/518680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144688, 10334, 'DORA S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/518681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144689, 10335, 'DORA S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/518682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144690, 10335, 'DORA S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/518683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144691, 10335, 'DORA S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/518684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144692, 10335, 'DORA S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/518685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144693, 10335, 'DORA S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/518686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144694, 10335, 'DORA S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/518687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144695, 10335, 'DORA S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/518688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144696, 10335, 'DORA S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/518689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144697, 10335, 'DORA S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/518690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144698, 10335, 'DORA S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/518691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144699, 10335, 'DORA S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/518692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144700, 10335, 'DORA S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/518693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144701, 10335, 'DORA S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/518694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144702, 10335, 'DORA S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/518695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144703, 10335, 'DORA S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/518696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144704, 10335, 'DORA S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/518697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144705, 10335, 'DORA S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/518698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144706, 10335, 'DORA S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/518699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144707, 10335, 'DORA S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/518700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144708, 10335, 'DORA S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/518701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144709, 10335, 'DORA S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/518702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144710, 10335, 'DORA S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/518703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144711, 10335, 'DORA S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/518704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144712, 10335, 'DORA S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/518705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144713, 10335, 'DORA S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/518706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144714, 10335, 'DORA S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/518707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bDKiaNOzNgVykHOrWgAwsjzmZbr.jpg'),
(144715, 10336, 'Good Times S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJ9f8coNSGXEBKzJlt9mGrdbQIZ.jpg'),
(144716, 10336, 'Good Times S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fiddLQGqlyRTL1JOAADa8rcWlGo.jpg'),
(144717, 10336, 'Good Times S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q5LwW1aVuhGQolYNJjd36cZpNuw.jpg'),
(144718, 10336, 'Good Times S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/326483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3gx7bOnBDOmc32JyyaudZ174v2r.jpg'),
(144719, 10336, 'Good Times S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/326484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aKF2qpSx5c2RnvQ6oPsv7Vdf6oe.jpg'),
(144720, 10336, 'Good Times S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/326485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8VsOb1gcAu2M3LN7qB14cmZMTk6.jpg'),
(144721, 10336, 'Good Times S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/326486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z3qoZR00iBSI2S90MRx7lxTw0CG.jpg'),
(144722, 10336, 'Good Times S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/326487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZtqxGfrxBQztXdavKHUe2Gzj3T.jpg'),
(144723, 10336, 'Good Times S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/326488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wXCCH9UHSZc5Ayhgy7uxGg2Mc3g.jpg'),
(144724, 10336, 'Good Times S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/326489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8wZjznf95qi2VzbSEJrJjoqYZff.jpg'),
(144725, 10337, 'Miss Monochrome [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bJ1v1g4Y0sBtt2cS2S9GwQJKGdV.jpg'),
(144726, 10337, 'Miss Monochrome [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yBpXB5Y1KlwStm6FRTqyb0WKwPA.jpg'),
(144727, 10337, 'Miss Monochrome [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8LyCD1rXiVYo3kh77u0nyxDWerM.jpg'),
(144728, 10337, 'Miss Monochrome [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/326444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/spjF8rTrwB3tUDwV8VQUdTQ6i9X.jpg'),
(144729, 10337, 'Miss Monochrome [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/326445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ysJD4SAyY84suUNJMUlhNxBXKzU.jpg'),
(144730, 10337, 'Miss Monochrome [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/326446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ei73TglKPRZqUYSwEmBQs1hcRQH.jpg'),
(144731, 10337, 'Miss Monochrome [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/326447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTcyTnPEh5MLwxM8FiuDLNSwQNe.jpg'),
(144732, 10337, 'Miss Monochrome [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/326448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zudGMyaMHb2xZKuAZt1q5lfPmsX.jpg'),
(144733, 10337, 'Miss Monochrome [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/326449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kcEARK2rYQWHzLYnWvjBfWrXbfW.jpg'),
(144734, 10337, 'Miss Monochrome [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/326450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgl0EaVAMx6FP6I9TfiyQSruYBM.jpg'),
(144735, 10337, 'Miss Monochrome [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/326451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ak0iQihSIVZecu5vPZJacZ0C48P.jpg'),
(144736, 10337, 'Miss Monochrome [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/326452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y20jQJtsEPVNvo4uMQV2OuHUWZ0.jpg'),
(144737, 10337, 'Miss Monochrome [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/326453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d6xnkfupLkANi71BzPhHbS8cWs3.jpg'),
(144738, 10338, 'Miss Monochrome [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bhFiu0kDlbWhvzyAJy8b9XLlmfo.jpg'),
(144739, 10338, 'Miss Monochrome [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c3wkgnZqapP0rG2ovLTft0oK2Qg.jpg'),
(144740, 10338, 'Miss Monochrome [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uoD4npypBlBI7MNDDlnRAQnZv2w.jpg'),
(144741, 10338, 'Miss Monochrome [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/326457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tFFqx8FSXBze780jEynK0XnbPcX.jpg'),
(144742, 10338, 'Miss Monochrome [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/326458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3eYO9t0YV9gqsk2jElcm0IyqafH.jpg'),
(144743, 10338, 'Miss Monochrome [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/326459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Flmw7gMhnF7M2SUwYW9Ug8Fem.jpg'),
(144744, 10338, 'Miss Monochrome [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/326460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m3gDupbyvRCXCXv55kxFJFPHoKe.jpg'),
(144745, 10338, 'Miss Monochrome [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/326461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rduuHWWr1PhbApFs3w0FUsnmvoX.jpg'),
(144746, 10338, 'Miss Monochrome [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/326462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJnGooCtUb8Laae6t1BBoejKcXc.jpg'),
(144747, 10338, 'Miss Monochrome [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/326463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2QwB2nhzlPprfdql1FC2ke6QQ4.jpg'),
(144748, 10338, 'Miss Monochrome [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/326464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gDjXNVwgMsDb50EpuqkLqy8H56f.jpg'),
(144749, 10338, 'Miss Monochrome [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/326465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mSnuO0qUxuapZUWbho0WqtKKRwz.jpg'),
(144750, 10338, 'Miss Monochrome [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/326466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c7WOaVKgERgqb166e8DVOnSvgX8.jpg'),
(144751, 10339, 'Miss Monochrome [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gT2J0tAqzkZbvOMsGC8gtdjyPVf.jpg'),
(144752, 10339, 'Miss Monochrome [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ecEiyKoTGvTGZgdn7YHqesTV9G.jpg'),
(144753, 10339, 'Miss Monochrome [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k2RS1i1BJzYAsygZ5cJ6CM6t4x0.jpg'),
(144754, 10339, 'Miss Monochrome [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/326470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Y94Y2qNQAjpmTgQkPQIZi3iL2x.jpg'),
(144755, 10339, 'Miss Monochrome [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/326471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sGPUvhI0PN0HZPgyu2zLygg7p7C.jpg'),
(144756, 10339, 'Miss Monochrome [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/326472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYQohFAvXs6GDGHLC9L7LfCKZeY.jpg'),
(144757, 10339, 'Miss Monochrome [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/326473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6077TSvjJRC1tAv6JomQbGtbrFN.jpg'),
(144758, 10339, 'Miss Monochrome [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/326474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pwWLoufCr8WKCNtFeB15ZhALBaV.jpg'),
(144759, 10339, 'Miss Monochrome [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/326475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2kxzFZZhWzTdQJUQHUn0K7okbnV.jpg'),
(144760, 10339, 'Miss Monochrome [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/326476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zxSxfEw43BiStFygk68gV38SWmh.jpg'),
(144761, 10339, 'Miss Monochrome [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/326477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o6Kbcvlp27U9K2tRN1zGCm2j0L4.jpg'),
(144762, 10339, 'Miss Monochrome [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/326478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/19BdSxkneecAelLKxrYbqds5nI.jpg'),
(144763, 10339, 'Miss Monochrome [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/326479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4eBvcjDG6yFYHNdRp0rlAQCVaV1.jpg'),
(144764, 10340, 'Missing Crown Prince [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1vXqM6mN9dGlnhGqp6ujDFh3kxt.jpg'),
(144765, 10340, 'Missing Crown Prince [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o1kZ69LJLhLFcMdNNkdKbKUHQDI.jpg'),
(144766, 10340, 'Missing Crown Prince [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/330545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o1kZ69LJLhLFcMdNNkdKbKUHQDI.jpg'),
(144767, 10340, 'Missing Crown Prince [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/338528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o1kZ69LJLhLFcMdNNkdKbKUHQDI.jpg'),
(144768, 10340, 'Missing Crown Prince [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/338529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o1kZ69LJLhLFcMdNNkdKbKUHQDI.jpg'),
(144769, 10340, 'Missing Crown Prince [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/338530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o1kZ69LJLhLFcMdNNkdKbKUHQDI.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(144770, 10340, 'Missing Crown Prince [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/345104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o1kZ69LJLhLFcMdNNkdKbKUHQDI.jpg'),
(144771, 10340, 'Missing Crown Prince [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/345105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o1kZ69LJLhLFcMdNNkdKbKUHQDI.jpg'),
(144772, 10340, 'Missing Crown Prince [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/356277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o1kZ69LJLhLFcMdNNkdKbKUHQDI.jpg'),
(144773, 10340, 'Missing Crown Prince [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/356278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o1kZ69LJLhLFcMdNNkdKbKUHQDI.jpg'),
(144774, 10340, 'Missing Crown Prince [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/356279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o1kZ69LJLhLFcMdNNkdKbKUHQDI.jpg'),
(144775, 10340, 'Missing Crown Prince [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/356280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o1kZ69LJLhLFcMdNNkdKbKUHQDI.jpg'),
(144776, 10340, 'Missing Crown Prince [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/360616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o1kZ69LJLhLFcMdNNkdKbKUHQDI.jpg'),
(144777, 10340, 'Missing Crown Prince [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/360617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o1kZ69LJLhLFcMdNNkdKbKUHQDI.jpg'),
(144778, 10340, 'Missing Crown Prince [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/368011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o1kZ69LJLhLFcMdNNkdKbKUHQDI.jpg'),
(144779, 10340, 'Missing Crown Prince [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/368012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o1kZ69LJLhLFcMdNNkdKbKUHQDI.jpg'),
(144780, 10340, 'Missing Crown Prince [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/382508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o1kZ69LJLhLFcMdNNkdKbKUHQDI.jpg'),
(144781, 10340, 'Missing Crown Prince [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/382509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o1kZ69LJLhLFcMdNNkdKbKUHQDI.jpg'),
(144782, 10340, 'Missing Crown Prince [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/389512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o1kZ69LJLhLFcMdNNkdKbKUHQDI.jpg'),
(144783, 10340, 'Missing Crown Prince [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/389513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o1kZ69LJLhLFcMdNNkdKbKUHQDI.jpg'),
(144784, 10341, 'O Lado Sombrio da TV Infantil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ucsYs291UDxkrwmiqudJavYkJQx.jpg'),
(144785, 10341, 'O Lado Sombrio da TV Infantil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4wRsoXeKD6wYQVMRWOmdInkD5Gu.jpg'),
(144786, 10341, 'O Lado Sombrio da TV Infantil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t5sPZC9cHpNWpExVZnwbfpWOzF3.jpg'),
(144787, 10341, 'O Lado Sombrio da TV Infantil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/326439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gHEvSjA6OuVMiyaUIZHydFPVXuW.jpg'),
(144788, 10341, 'O Lado Sombrio da TV Infantil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/326440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A0YXgBR81EWOswmMAMKIBQQ8b2G.jpg'),
(144789, 10342, 'Revelacoes Pre Historicas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9mv9amDEk6mYIpnk30IppdTSMvR.jpg'),
(144790, 10342, 'Revelacoes Pre Historicas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a8DDXGIFp5SszjK21Sz78ff4Ol5.jpg'),
(144791, 10342, 'Revelacoes Pre Historicas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xUs8Zq8FZ17lwAtjCEPzJLDLlPr.jpg'),
(144792, 10342, 'Revelacoes Pre Historicas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/326431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eRtUzBPLbwf5Sa3skug9KaZTBsJ.jpg'),
(144793, 10342, 'Revelacoes Pre Historicas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/326432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/revfjQ4PclR7V8LlS4vcQlvojvy.jpg'),
(144794, 10342, 'Revelacoes Pre Historicas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/326433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3TqWgs1n5t84RttxtVxF5IOKXhU.jpg'),
(144795, 10342, 'Revelacoes Pre Historicas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/326434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpvQetPP2F2vJ0cu3kFzGXcFUnz.jpg'),
(144796, 10342, 'Revelacoes Pre Historicas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/326435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zvONr5Cr0RO8hzOsVSJMRoeN8XX.jpg'),
(144797, 10343, 'The Fable [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xarwsw24yOvec3XgGG8zRQK38Xr.jpg'),
(144798, 10343, 'The Fable [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lUMudxl7OdA5L1f5XN6OI8s8NIw.jpg'),
(144799, 10343, 'The Fable [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/332130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144800, 10343, 'The Fable [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/336951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144801, 10343, 'The Fable [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/342966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144802, 10343, 'The Fable [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/354017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144803, 10343, 'The Fable [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/354018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144804, 10343, 'The Fable [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/361397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144805, 10343, 'The Fable [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/626137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144806, 10343, 'The Fable [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/376235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144807, 10343, 'The Fable [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/385695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144808, 10343, 'The Fable [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144809, 10343, 'The Fable [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/394047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144810, 10343, 'The Fable [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/401368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144811, 10343, 'The Fable [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/407150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144812, 10343, 'The Fable [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/415524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144813, 10343, 'The Fable [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/418137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144814, 10343, 'The Fable [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/422993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144815, 10343, 'The Fable [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/432905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144816, 10343, 'The Fable [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/438620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144817, 10343, 'The Fable [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/438621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144818, 10343, 'The Fable [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/449946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144819, 10343, 'The Fable [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/454275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144820, 10343, 'The Fable [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/458934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144821, 10343, 'The Fable [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/466228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/baflpfvihSZCNsyTHZGBKkDIlXr.jpg'),
(144822, 10344, 'Um Cavalheiro em Moscou [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uo2Omt5GpPEjnTSNr40LoEHXDJw.jpg'),
(144823, 10344, 'Um Cavalheiro em Moscou [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBSavepmrFFWCh2spcU11P5B1bO.jpg'),
(144824, 10344, 'Um Cavalheiro em Moscou [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/327357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/awIufRN7dWaG813VWQWpKD2ErpP.jpg'),
(144825, 10344, 'Um Cavalheiro em Moscou [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/awIufRN7dWaG813VWQWpKD2ErpP.jpg'),
(144826, 10344, 'Um Cavalheiro em Moscou [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/358227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/awIufRN7dWaG813VWQWpKD2ErpP.jpg'),
(144827, 10345, 'Veronika [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qtXwvGvL2iXj2gElVsYY7iAr837.jpg'),
(144828, 10345, 'Veronika [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/smOvuoLjF5rVzu8pOktZwhLENO5.jpg'),
(144829, 10345, 'Veronika [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tstiVD7MRAoLQe6SoMSk9q1av8H.jpg'),
(144830, 10345, 'Veronika [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/326421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nRJPsgALq7duU0R8BAfRdMf3PDR.jpg'),
(144831, 10345, 'Veronika [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/326422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/igYImA3Lgvzr56z8LeSapD6lHw.jpg'),
(144832, 10345, 'Veronika [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/326423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yZhuJnWw2ig6v7wECrX6u7ESKPz.jpg'),
(144833, 10345, 'Veronika [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/327339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/958c86lW6I3DGD6288H9qVm4LhD.jpg'),
(144834, 10345, 'Veronika [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/332032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/958c86lW6I3DGD6288H9qVm4LhD.jpg'),
(144835, 10346, 'Veronika [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/895769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/958c86lW6I3DGD6288H9qVm4LhD.jpg'),
(144836, 10346, 'Veronika [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/896346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/958c86lW6I3DGD6288H9qVm4LhD.jpg'),
(144837, 10346, 'Veronika [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/896858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/958c86lW6I3DGD6288H9qVm4LhD.jpg'),
(144838, 10347, 'O Sequestro do Voo 601 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aIxIMOQw0IZhx3RZxlqZRT1LGyo.jpg'),
(144839, 10347, 'O Sequestro do Voo 601 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/326413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1WOjF9liZ8GQyLXsv80AUikHzqs.jpg'),
(144840, 10347, 'O Sequestro do Voo 601 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/326414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s11kgoyU0rhDROGYMKvRhzGN55V.jpg'),
(144841, 10347, 'O Sequestro do Voo 601 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/326415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oEJOzvMXsuej1SHUCoHNr7CrXKb.jpg'),
(144842, 10347, 'O Sequestro do Voo 601 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/326416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ul9oSAQJoUFpkayzf6fHRye9n0.jpg'),
(144843, 10347, 'O Sequestro do Voo 601 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/326417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vcNqLkiR0ouKVnQ9jtzYTkr1ngx.jpg'),
(144844, 10348, 'O Simpatizante S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/326986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uEaJMfwQ1HY2WyQn5OFRMJV7oN6.jpg'),
(144845, 10348, 'O Simpatizante S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/330525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCkFmproxlyCPSwpo2AQ8J1fp5e.jpg'),
(144846, 10348, 'O Simpatizante S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/338399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCkFmproxlyCPSwpo2AQ8J1fp5e.jpg'),
(144847, 10348, 'O Simpatizante S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/344932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCkFmproxlyCPSwpo2AQ8J1fp5e.jpg'),
(144848, 10348, 'O Simpatizante S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/356098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCkFmproxlyCPSwpo2AQ8J1fp5e.jpg'),
(144849, 10348, 'O Simpatizante S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/356099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCkFmproxlyCPSwpo2AQ8J1fp5e.jpg'),
(144850, 10348, 'O Simpatizante S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/360542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mCkFmproxlyCPSwpo2AQ8J1fp5e.jpg'),
(144851, 10349, 'Meu Lar Meu Destino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/329119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xV5S3P54Q7noh1CvCI47cjoCJTn.jpg'),
(144852, 10349, 'Meu Lar Meu Destino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/329120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sWHhqHvFFcBBrj5taUGXRvewlaa.jpg'),
(144853, 10349, 'Meu Lar Meu Destino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/329121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nmRaGO0iFfybPJjzbEESpDtzY0J.jpg'),
(144854, 10349, 'Meu Lar Meu Destino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/329122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cCTbDJgVhYMwrNC60fqEaD6QvxN.jpg'),
(144855, 10349, 'Meu Lar Meu Destino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/329123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/61NYmHwIczNvT5obqGqcL9HQLH6.jpg'),
(144856, 10349, 'Meu Lar Meu Destino S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/329124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Qo21FNq0lv7D64TBdZrxqrkXyU.jpg'),
(144857, 10349, 'Meu Lar Meu Destino S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/329125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uMZVypnck1JMTSXPGelYjx84Bl5.jpg'),
(144858, 10349, 'Meu Lar Meu Destino S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/329126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zuWLwxE04uuZm7Hiz5Mm6SNtASY.jpg'),
(144859, 10349, 'Meu Lar Meu Destino S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/329127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uuQKHnvi0jUZUCwIwe3tEPIp8n.jpg'),
(144860, 10349, 'Meu Lar Meu Destino S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/329128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uuQKHnvi0jUZUCwIwe3tEPIp8n.jpg'),
(144861, 10349, 'Meu Lar Meu Destino S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/329129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uuQKHnvi0jUZUCwIwe3tEPIp8n.jpg'),
(144862, 10349, 'Meu Lar Meu Destino S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/329130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uuQKHnvi0jUZUCwIwe3tEPIp8n.jpg'),
(144863, 10349, 'Meu Lar Meu Destino S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/329131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uuQKHnvi0jUZUCwIwe3tEPIp8n.jpg'),
(144864, 10349, 'Meu Lar Meu Destino S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/329132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uuQKHnvi0jUZUCwIwe3tEPIp8n.jpg'),
(144865, 10349, 'Meu Lar Meu Destino S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/329133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uuQKHnvi0jUZUCwIwe3tEPIp8n.jpg'),
(144866, 10349, 'Meu Lar Meu Destino S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/329134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uuQKHnvi0jUZUCwIwe3tEPIp8n.jpg'),
(144867, 10349, 'Meu Lar Meu Destino S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/329135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uuQKHnvi0jUZUCwIwe3tEPIp8n.jpg'),
(144868, 10349, 'Meu Lar Meu Destino S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/329136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uuQKHnvi0jUZUCwIwe3tEPIp8n.jpg'),
(144869, 10349, 'Meu Lar Meu Destino S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/329137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uuQKHnvi0jUZUCwIwe3tEPIp8n.jpg'),
(144870, 10349, 'Meu Lar Meu Destino S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/329138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uuQKHnvi0jUZUCwIwe3tEPIp8n.jpg'),
(144871, 10349, 'Meu Lar Meu Destino S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/329139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uuQKHnvi0jUZUCwIwe3tEPIp8n.jpg'),
(144872, 10349, 'Meu Lar Meu Destino S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/329140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uuQKHnvi0jUZUCwIwe3tEPIp8n.jpg'),
(144873, 10349, 'Meu Lar Meu Destino S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/329141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3uuQKHnvi0jUZUCwIwe3tEPIp8n.jpg'),
(144874, 10350, 'A Partitura Secreta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gH13WFXejNvwZg4KJEWkLPIkxNx.jpg'),
(144875, 10350, 'A Partitura Secreta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gH13WFXejNvwZg4KJEWkLPIkxNx.jpg'),
(144876, 10350, 'A Partitura Secreta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gH13WFXejNvwZg4KJEWkLPIkxNx.jpg'),
(144877, 10350, 'A Partitura Secreta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gH13WFXejNvwZg4KJEWkLPIkxNx.jpg'),
(144878, 10350, 'A Partitura Secreta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gH13WFXejNvwZg4KJEWkLPIkxNx.jpg'),
(144879, 10350, 'A Partitura Secreta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gH13WFXejNvwZg4KJEWkLPIkxNx.jpg'),
(144880, 10350, 'A Partitura Secreta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gH13WFXejNvwZg4KJEWkLPIkxNx.jpg'),
(144881, 10350, 'A Partitura Secreta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gH13WFXejNvwZg4KJEWkLPIkxNx.jpg'),
(144882, 10351, 'Jane S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dgBZQPjwSwnRTu42VLTqXEGnB15.jpg'),
(144883, 10351, 'Jane S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/84rErjMtk0mRxRviSAcJoMqpsVP.jpg'),
(144884, 10351, 'Jane S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gdOyM6mOobMb8brCIkn1NiG7BOZ.jpg'),
(144885, 10351, 'Jane S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vqPNqlULXgiscYUnsGN378y8TaK.jpg'),
(144886, 10351, 'Jane S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1XeyM1u5kpvLE7z6G9AQEQtjQKE.jpg'),
(144887, 10351, 'Jane S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zEUekPBjmiElXgXllQjvh1hb26U.jpg'),
(144888, 10351, 'Jane S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wzlRLDaPgfahLyrGy1P16Z3JrCO.jpg'),
(144889, 10351, 'Jane S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nV3KoGUUg6Mbjnn5reZoaR9iat5.jpg'),
(144890, 10351, 'Jane S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7w8UQaWEPdiCFl3HJDZZhwktoA.jpg'),
(144891, 10351, 'Jane S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c1q6wO3k5BKOFD9RTlF20mMDgPx.jpg'),
(144892, 10352, 'Jane S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7BTw7cNPLK0tOIFWq3jl5omLiDk.jpg'),
(144893, 10352, 'Jane S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7BTw7cNPLK0tOIFWq3jl5omLiDk.jpg'),
(144894, 10352, 'Jane S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7BTw7cNPLK0tOIFWq3jl5omLiDk.jpg'),
(144895, 10352, 'Jane S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7BTw7cNPLK0tOIFWq3jl5omLiDk.jpg'),
(144896, 10352, 'Jane S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7BTw7cNPLK0tOIFWq3jl5omLiDk.jpg'),
(144897, 10353, 'Planeta Vivo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ysPjKSUYnIBOhATefkNyhKWmvb0.jpg'),
(144898, 10353, 'Planeta Vivo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fru9RDmJHoaJIPznpcNy1KrHdjx.jpg'),
(144899, 10353, 'Planeta Vivo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oXB1qHJfmqphfxrMvI0UsvgrrKq.jpg'),
(144900, 10353, 'Planeta Vivo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mA9Di8EGbKvbmmBlI3hGlcIzZGv.jpg'),
(144901, 10354, 'Somos os Que Tiveram Sorte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pBFlX8mI2TxGQ3sDAvbrjrmBJ9b.jpg'),
(144902, 10354, 'Somos os Que Tiveram Sorte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u9js0kF2RuyhP1nRI4DCDpMcg6B.jpg'),
(144903, 10354, 'Somos os Que Tiveram Sorte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kiCNjFW4BVPazGLUWMFBxQhC5r3.jpg'),
(144904, 10354, 'Somos os Que Tiveram Sorte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/335956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Qk54WY8EWYJs6uNWgm3QJNOH9U.jpg'),
(144905, 10354, 'Somos os Que Tiveram Sorte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/340114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Qk54WY8EWYJs6uNWgm3QJNOH9U.jpg'),
(144906, 10354, 'Somos os Que Tiveram Sorte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/351401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Qk54WY8EWYJs6uNWgm3QJNOH9U.jpg'),
(144907, 10354, 'Somos os Que Tiveram Sorte S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/351402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Qk54WY8EWYJs6uNWgm3QJNOH9U.jpg'),
(144908, 10354, 'Somos os Que Tiveram Sorte S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/362673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Qk54WY8EWYJs6uNWgm3QJNOH9U.jpg'),
(144909, 10355, 'Turma da Monica Jovem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zOoA4HqlmNs3Ao9ul36Cro6LlRv.jpg'),
(144910, 10355, 'Turma da Monica Jovem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144911, 10355, 'Turma da Monica Jovem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144912, 10355, 'Turma da Monica Jovem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144913, 10355, 'Turma da Monica Jovem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144914, 10355, 'Turma da Monica Jovem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144915, 10355, 'Turma da Monica Jovem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144916, 10355, 'Turma da Monica Jovem S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144917, 10355, 'Turma da Monica Jovem S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144918, 10355, 'Turma da Monica Jovem S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144919, 10355, 'Turma da Monica Jovem S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/331547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144920, 10355, 'Turma da Monica Jovem S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/331548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144921, 10355, 'Turma da Monica Jovem S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/331549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144922, 10355, 'Turma da Monica Jovem S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/331550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144923, 10355, 'Turma da Monica Jovem S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/331551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144924, 10355, 'Turma da Monica Jovem S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/331552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144925, 10355, 'Turma da Monica Jovem S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/331553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144926, 10355, 'Turma da Monica Jovem S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/331554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144927, 10355, 'Turma da Monica Jovem S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/331555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144928, 10355, 'Turma da Monica Jovem S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/331556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144929, 10355, 'Turma da Monica Jovem S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/331557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144930, 10355, 'Turma da Monica Jovem S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/331558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144931, 10355, 'Turma da Monica Jovem S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/331559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144932, 10355, 'Turma da Monica Jovem S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/331560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144933, 10355, 'Turma da Monica Jovem S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/331561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144934, 10355, 'Turma da Monica Jovem S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/331562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iR41oTFfXFUqMFFUJpOQVlSgX29.jpg'),
(144935, 10356, 'A Bela e o Sr Romantico [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3fambN1jva95UM7UJHiJzQn8vZG.jpg'),
(144936, 10356, 'A Bela e o Sr Romantico [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5TUNCQNKjGIsmIjO3SRmorECwPr.jpg'),
(144937, 10356, 'A Bela e o Sr Romantico [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8v2wwMl1NxZ1wsxNG0tzsjTKaGA.jpg'),
(144938, 10356, 'A Bela e o Sr Romantico [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hAM2sWR92ZyLBgjuqbfK8vurtJt.jpg'),
(144939, 10356, 'A Bela e o Sr Romantico [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/332000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f5jMvCwy6g3aFbfEmJM6bHTq3oZ.jpg'),
(144940, 10356, 'A Bela e o Sr Romantico [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/332001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2gKPjpiVNsH0L3Rrzrt5NlfpG7y.jpg'),
(144941, 10356, 'A Bela e o Sr Romantico [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/332002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144942, 10356, 'A Bela e o Sr Romantico [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/339075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144943, 10356, 'A Bela e o Sr Romantico [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/339076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144944, 10356, 'A Bela e o Sr Romantico [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/339077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144945, 10356, 'A Bela e o Sr Romantico [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/339078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144946, 10356, 'A Bela e o Sr Romantico [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/339079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144947, 10356, 'A Bela e o Sr Romantico [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/346607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144948, 10356, 'A Bela e o Sr Romantico [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/350749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144949, 10356, 'A Bela e o Sr Romantico [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/350750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144950, 10356, 'A Bela e o Sr Romantico [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/350751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144951, 10356, 'A Bela e o Sr Romantico [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/350752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144952, 10356, 'A Bela e o Sr Romantico [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/361029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144953, 10356, 'A Bela e o Sr Romantico [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/361030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144954, 10356, 'A Bela e o Sr Romantico [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/369794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144955, 10356, 'A Bela e o Sr Romantico [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/369795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144956, 10356, 'A Bela e o Sr Romantico [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/375870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144957, 10356, 'A Bela e o Sr Romantico [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/383533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144958, 10356, 'A Bela e o Sr Romantico [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/383534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144959, 10356, 'A Bela e o Sr Romantico [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/385279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144960, 10356, 'A Bela e o Sr Romantico [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/385281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144961, 10356, 'A Bela e o Sr Romantico [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/393042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144962, 10356, 'A Bela e o Sr Romantico [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/393043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144963, 10356, 'A Bela e o Sr Romantico [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/399178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144964, 10356, 'A Bela e o Sr Romantico [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/401314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144965, 10356, 'A Bela e o Sr Romantico [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/406615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144966, 10356, 'A Bela e o Sr Romantico [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/406616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144967, 10356, 'A Bela e o Sr Romantico [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/409930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144968, 10356, 'A Bela e o Sr Romantico [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/413632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144969, 10356, 'A Bela e o Sr Romantico [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/415281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144970, 10356, 'A Bela e o Sr Romantico [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/415282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144971, 10356, 'A Bela e o Sr Romantico [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/430168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144972, 10356, 'A Bela e o Sr Romantico [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/430169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144973, 10356, 'A Bela e o Sr Romantico [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/437895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144974, 10356, 'A Bela e o Sr Romantico [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/437896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144975, 10356, 'A Bela e o Sr Romantico [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/443181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144976, 10356, 'A Bela e o Sr Romantico [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/443182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144977, 10356, 'A Bela e o Sr Romantico [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/449145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144978, 10356, 'A Bela e o Sr Romantico [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/449146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144979, 10356, 'A Bela e o Sr Romantico [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/453175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144980, 10356, 'A Bela e o Sr Romantico [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/453176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144981, 10356, 'A Bela e o Sr Romantico [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/462254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144982, 10356, 'A Bela e o Sr Romantico [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/462255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144983, 10356, 'A Bela e o Sr Romantico [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/464885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144984, 10356, 'A Bela e o Sr Romantico [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/464886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56KD4ov7Q73kz6oqB0HYNkb5Upb.jpg'),
(144985, 10357, 'A Boss and A Babe [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6oZy2gi3wH1cob7d7vgyfgGX56U.jpg'),
(144986, 10357, 'A Boss and A Babe [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xIvgpGdq2GX3gStdEX2PJnnI869.jpg'),
(144987, 10357, 'A Boss and A Babe [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e0pneupaMpH8e2mcTxEMVVL3oug.jpg'),
(144988, 10357, 'A Boss and A Babe [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nOFOoErDgTixwEw5SO1U0VPsKJd.jpg'),
(144989, 10357, 'A Boss and A Babe [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZlQNwOaex3BQwmdVZsEk2pvtkv.jpg'),
(144990, 10357, 'A Boss and A Babe [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zVs5LvCZ6qSr4mIi85mPwKmShN8.jpg'),
(144991, 10357, 'A Boss and A Babe [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fL4X3dKMzhnHF8bewSNHa4bVi3g.jpg'),
(144992, 10357, 'A Boss and A Babe [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYZH6Y2wA4A8BbqtXRRKVT7hn6i.jpg'),
(144993, 10357, 'A Boss and A Babe [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e3HLgju0Vhph2tsA1PoxEwjuK2b.jpg'),
(144994, 10357, 'A Boss and A Babe [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rmKAViVcW9viy0Qgq1YzGT9T4nr.jpg'),
(144995, 10357, 'A Boss and A Babe [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/331994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cbbuE13Ftdiid3ZpSAZDz6Gj34f.jpg'),
(144996, 10357, 'A Boss and A Babe [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/331995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dPJSXu4j6Jpt5KfLtBY1COJxDP3.jpg'),
(144997, 10358, 'A Familia Baxter [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/czTZt743KVMRXg6rkOl4xPs5xYv.jpg'),
(144998, 10358, 'A Familia Baxter [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2PTP77BIQzDoVjaDYxBJEESIcn6.jpg'),
(144999, 10358, 'A Familia Baxter [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tgqcZvvMPzHtriteBSy49TDa4p0.jpg'),
(145000, 10358, 'A Familia Baxter [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lK6pSsijunR0rl10MIGsEupRhmZ.jpg'),
(145001, 10358, 'A Familia Baxter [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vjwhQDyazft2so0w4yo51v5tdEE.jpg'),
(145002, 10358, 'A Familia Baxter [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AfNy4rjolhvLC4pU4fkbhSodWr6.jpg'),
(145003, 10358, 'A Familia Baxter [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xFGQFUeAVlUp5MAhtO9oLSTlUIO.jpg'),
(145004, 10358, 'A Familia Baxter [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7HmCSITLvCSdY51TRY9bqFp4qZy.jpg'),
(145005, 10358, 'A Familia Baxter [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/njtGtyLF7srHrs3NvwsZutjZzeA.jpg'),
(145006, 10358, 'A Familia Baxter [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uj494RCBKbzUbzu1uow5vnSAaFA.jpg'),
(145007, 10359, 'A Familia Baxter [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aDgCh3KsCAgIA9Q6MCCj9d5bQVP.jpg'),
(145008, 10359, 'A Familia Baxter [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/16QQOq47nLY77rdMljhyQp2rz4P.jpg'),
(145009, 10359, 'A Familia Baxter [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ttX70cqbgustkSTuDu8LIEbcP4q.jpg'),
(145010, 10359, 'A Familia Baxter [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dRRbnGltOsSBzkMe01R4UYGaKuT.jpg'),
(145011, 10359, 'A Familia Baxter [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d6fyKwUN5ncSsPNsMQ46goZpPO8.jpg'),
(145012, 10359, 'A Familia Baxter [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j2Dg2T7RDsVH4MCnEJWeGiMCfVJ.jpg'),
(145013, 10359, 'A Familia Baxter [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/klQoW5LA0LuGY2T2zaw4N855k3T.jpg'),
(145014, 10359, 'A Familia Baxter [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTfhNj9wn6zQYC7PZ2XVarR8T1F.jpg'),
(145015, 10359, 'A Familia Baxter [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bn3X5cWkAoqtjn9R0doUrdCWfxz.jpg'),
(145016, 10359, 'A Familia Baxter [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/67yRVY7QrJFm1SMPdrAS9O33B5c.jpg'),
(145017, 10359, 'A Familia Baxter [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/331970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4vAR9dYu4IycOfDdrYO31BRHAN3.jpg'),
(145018, 10359, 'A Familia Baxter [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/331971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dVW7W6sA1x0hH19QGEr495sRjsY.jpg'),
(145019, 10360, 'A Familia Baxter [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fyoABNvwXkmmcCSPBjp55CeXlTm.jpg'),
(145020, 10360, 'A Familia Baxter [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6LRqNpYTxVAp5XgI4TKrqWlJb5g.jpg'),
(145021, 10360, 'A Familia Baxter [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4zi14xzHgRXMTsA9POCVuRUiqeJ.jpg'),
(145022, 10360, 'A Familia Baxter [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1e4Ij5M4x7IFpb0CPp7jsadMzDl.jpg'),
(145023, 10360, 'A Familia Baxter [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lMVldLiG1GpvCdPpHp0GBV7RIzJ.jpg'),
(145024, 10360, 'A Familia Baxter [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vsIoWvHdBoCpeQxJLxiiYsVxwyi.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(145025, 10360, 'A Familia Baxter [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Y2V9WpkRwn9HW5GF4y0xNA8WeE.jpg'),
(145026, 10360, 'A Familia Baxter [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2v4YFSAfCMy4yQp4QxNibkSK75V.jpg'),
(145027, 10360, 'A Familia Baxter [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/emLL8jMkfKWvirme8oYTkmfY8aA.jpg'),
(145028, 10360, 'A Familia Baxter [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhpE9mq9ZlOcekovR9tHbbOhcwT.jpg'),
(145029, 10360, 'A Familia Baxter [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/331982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/myyfbwoM1ji9E5Olg16e3sqZR81.jpg'),
(145030, 10360, 'A Familia Baxter [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/331983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSNptquU9zNZcNAyN2OH2mT7jAU.jpg'),
(145031, 10361, 'Adoravel Corredora [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lsmsgTsbQXFxoQfnmoxqreVh9fi.jpg'),
(145032, 10361, 'Adoravel Corredora [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zeO3MQbSyQmQIGwDO71UJmUYQiC.jpg'),
(145033, 10361, 'Adoravel Corredora [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yoM2Po9a7zYuN0wUG6R0htsdwXB.jpg'),
(145034, 10361, 'Adoravel Corredora [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2pGeniJxxnt9y8VCwb83rA61Ohg.jpg'),
(145035, 10361, 'Adoravel Corredora [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/334016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gEp7Rs43Fi3eEEBsIMc8xGewNp.jpg'),
(145036, 10361, 'Adoravel Corredora [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/334017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gEp7Rs43Fi3eEEBsIMc8xGewNp.jpg'),
(145037, 10361, 'Adoravel Corredora [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/341897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gEp7Rs43Fi3eEEBsIMc8xGewNp.jpg'),
(145038, 10361, 'Adoravel Corredora [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/341898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gEp7Rs43Fi3eEEBsIMc8xGewNp.jpg'),
(145039, 10361, 'Adoravel Corredora [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gEp7Rs43Fi3eEEBsIMc8xGewNp.jpg'),
(145040, 10361, 'Adoravel Corredora [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gEp7Rs43Fi3eEEBsIMc8xGewNp.jpg'),
(145041, 10361, 'Adoravel Corredora [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gEp7Rs43Fi3eEEBsIMc8xGewNp.jpg'),
(145042, 10361, 'Adoravel Corredora [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gEp7Rs43Fi3eEEBsIMc8xGewNp.jpg'),
(145043, 10361, 'Adoravel Corredora [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/360423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gEp7Rs43Fi3eEEBsIMc8xGewNp.jpg'),
(145044, 10361, 'Adoravel Corredora [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/360424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gEp7Rs43Fi3eEEBsIMc8xGewNp.jpg'),
(145045, 10361, 'Adoravel Corredora [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/369729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gEp7Rs43Fi3eEEBsIMc8xGewNp.jpg'),
(145046, 10361, 'Adoravel Corredora [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/369730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gEp7Rs43Fi3eEEBsIMc8xGewNp.jpg'),
(145047, 10362, 'Amy e Tammy Irmas Contra o Peso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145048, 10362, 'Amy e Tammy Irmas Contra o Peso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145049, 10362, 'Amy e Tammy Irmas Contra o Peso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145050, 10362, 'Amy e Tammy Irmas Contra o Peso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145051, 10362, 'Amy e Tammy Irmas Contra o Peso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145052, 10362, 'Amy e Tammy Irmas Contra o Peso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145053, 10363, 'Amy e Tammy Irmas Contra o Peso S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145054, 10363, 'Amy e Tammy Irmas Contra o Peso S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145055, 10363, 'Amy e Tammy Irmas Contra o Peso S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145056, 10363, 'Amy e Tammy Irmas Contra o Peso S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145057, 10363, 'Amy e Tammy Irmas Contra o Peso S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145058, 10363, 'Amy e Tammy Irmas Contra o Peso S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145059, 10363, 'Amy e Tammy Irmas Contra o Peso S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145060, 10363, 'Amy e Tammy Irmas Contra o Peso S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145061, 10363, 'Amy e Tammy Irmas Contra o Peso S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145062, 10363, 'Amy e Tammy Irmas Contra o Peso S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145063, 10363, 'Amy e Tammy Irmas Contra o Peso S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/331920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145064, 10364, 'Amy e Tammy Irmas Contra o Peso S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145065, 10364, 'Amy e Tammy Irmas Contra o Peso S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145066, 10364, 'Amy e Tammy Irmas Contra o Peso S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145067, 10364, 'Amy e Tammy Irmas Contra o Peso S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145068, 10364, 'Amy e Tammy Irmas Contra o Peso S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145069, 10364, 'Amy e Tammy Irmas Contra o Peso S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145070, 10364, 'Amy e Tammy Irmas Contra o Peso S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145071, 10364, 'Amy e Tammy Irmas Contra o Peso S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145072, 10364, 'Amy e Tammy Irmas Contra o Peso S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145073, 10364, 'Amy e Tammy Irmas Contra o Peso S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145074, 10364, 'Amy e Tammy Irmas Contra o Peso S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/331931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145075, 10364, 'Amy e Tammy Irmas Contra o Peso S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/331932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145076, 10365, 'Amy e Tammy Irmas Contra o Peso S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145077, 10365, 'Amy e Tammy Irmas Contra o Peso S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145078, 10365, 'Amy e Tammy Irmas Contra o Peso S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145079, 10365, 'Amy e Tammy Irmas Contra o Peso S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145080, 10365, 'Amy e Tammy Irmas Contra o Peso S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145081, 10365, 'Amy e Tammy Irmas Contra o Peso S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145082, 10365, 'Amy e Tammy Irmas Contra o Peso S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145083, 10365, 'Amy e Tammy Irmas Contra o Peso S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145084, 10365, 'Amy e Tammy Irmas Contra o Peso S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145085, 10365, 'Amy e Tammy Irmas Contra o Peso S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145086, 10366, 'Amy e Tammy Irmas Contra o Peso S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145087, 10366, 'Amy e Tammy Irmas Contra o Peso S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145088, 10366, 'Amy e Tammy Irmas Contra o Peso S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145089, 10366, 'Amy e Tammy Irmas Contra o Peso S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/339059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145090, 10366, 'Amy e Tammy Irmas Contra o Peso S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/339060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145091, 10366, 'Amy e Tammy Irmas Contra o Peso S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/345873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145092, 10366, 'Amy e Tammy Irmas Contra o Peso S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145093, 10366, 'Amy e Tammy Irmas Contra o Peso S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/363757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145094, 10366, 'Amy e Tammy Irmas Contra o Peso S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/363758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fu2YJx75Yp3vIMmRXIupTzgW0ep.jpg'),
(145095, 10367, 'Aula de Amor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/grf5jfQZJBKy3sCSP0f8vOwI5WM.jpg'),
(145096, 10367, 'Aula de Amor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dtU7XF2FrTtl5uqtlC5cyrXCDMc.jpg'),
(145097, 10367, 'Aula de Amor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o8yuEWARr6HaZq4TxGgSxv9f0Z2.jpg'),
(145098, 10367, 'Aula de Amor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l7dFJMJCiFnnQnleZmj0Q130Owf.jpg'),
(145099, 10367, 'Aula de Amor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wj6rmsH7l565hInHs9yrNAB2SRT.jpg'),
(145100, 10367, 'Aula de Amor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSggbq26DKvbSikevc6su7NWYNE.jpg'),
(145101, 10368, 'Aula de Amor [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/360401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4PAXhpcVsqHXf2SqHlJGAN3IYF.jpg'),
(145102, 10368, 'Aula de Amor [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/360402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4PAXhpcVsqHXf2SqHlJGAN3IYF.jpg'),
(145103, 10368, 'Aula de Amor [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/360403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4PAXhpcVsqHXf2SqHlJGAN3IYF.jpg'),
(145104, 10368, 'Aula de Amor [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/360404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4PAXhpcVsqHXf2SqHlJGAN3IYF.jpg'),
(145105, 10368, 'Aula de Amor [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/360405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4PAXhpcVsqHXf2SqHlJGAN3IYF.jpg'),
(145106, 10368, 'Aula de Amor [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/360406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4PAXhpcVsqHXf2SqHlJGAN3IYF.jpg'),
(145107, 10368, 'Aula de Amor [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/360407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4PAXhpcVsqHXf2SqHlJGAN3IYF.jpg'),
(145108, 10368, 'Aula de Amor [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/360408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4PAXhpcVsqHXf2SqHlJGAN3IYF.jpg'),
(145109, 10368, 'Aula de Amor [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/360409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4PAXhpcVsqHXf2SqHlJGAN3IYF.jpg'),
(145110, 10368, 'Aula de Amor [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/360410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j4PAXhpcVsqHXf2SqHlJGAN3IYF.jpg'),
(145111, 10369, 'Behind Cut [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x0ti9nT0anIP40twemspUg8qseB.jpg'),
(145112, 10369, 'Behind Cut [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2bCI5oDwx3jFfJldxEY7hXAkVXX.jpg'),
(145113, 10369, 'Behind Cut [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOHy9wxO8YzdgHNAxpvFMisQJrS.jpg'),
(145114, 10369, 'Behind Cut [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8uYIqijJwDNRaOo7Yq7zJuc7Azx.jpg'),
(145115, 10369, 'Behind Cut [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zn9Vsno03hNwhqV6Lp3jgC7TFCg.jpg'),
(145116, 10369, 'Behind Cut [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uVBO9FtENOo9Ihi63SkQAQ9407m.jpg'),
(145117, 10369, 'Behind Cut [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8AJFZ1AvrOkvVewkQxOqC54gCk.jpg'),
(145118, 10369, 'Behind Cut [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/catEP1nLoR90pgKgzF4myFJw8tS.jpg'),
(145119, 10370, 'Chega Mais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dN6lkmUjiZhtc3Hx1Gc1shwVBpD.jpg'),
(145120, 10370, 'Chega Mais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dN6lkmUjiZhtc3Hx1Gc1shwVBpD.jpg'),
(145121, 10370, 'Chega Mais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dN6lkmUjiZhtc3Hx1Gc1shwVBpD.jpg'),
(145122, 10370, 'Chega Mais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dN6lkmUjiZhtc3Hx1Gc1shwVBpD.jpg'),
(145123, 10370, 'Chega Mais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dN6lkmUjiZhtc3Hx1Gc1shwVBpD.jpg'),
(145124, 10370, 'Chega Mais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dN6lkmUjiZhtc3Hx1Gc1shwVBpD.jpg'),
(145125, 10371, 'Cherry Blossoms After Winter [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qoyQfkWPqqGDrF4WEnSeJYno2QZ.jpg'),
(145126, 10371, 'Cherry Blossoms After Winter [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3o5yvjQbwngfgNsalJZbSP20Lx.jpg'),
(145127, 10371, 'Cherry Blossoms After Winter [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2aGMea36ts8TKkz0RM4OqzTY6Qa.jpg'),
(145128, 10371, 'Cherry Blossoms After Winter [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6yT5xe3qq0o0kibRZcGXbFU5dL.jpg'),
(145129, 10371, 'Cherry Blossoms After Winter [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1piRPrWDqyquwWtYKJZUfx9eYMF.jpg'),
(145130, 10371, 'Cherry Blossoms After Winter [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k85WCZqZ8ocn7Qh8HVIlVZZOBob.jpg'),
(145131, 10371, 'Cherry Blossoms After Winter [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f6Q6KcfXUflL3PDGGKed8GT5dG7.jpg'),
(145132, 10371, 'Cherry Blossoms After Winter [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ezjLVBIk1wQZ7qH0IPMlX5Oj8OQ.jpg'),
(145133, 10372, 'Coracao Alado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j5ivlvZeGETWlwr8PuZoqLx06zX.jpg'),
(145134, 10372, 'Coracao Alado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j5ivlvZeGETWlwr8PuZoqLx06zX.jpg'),
(145135, 10372, 'Coracao Alado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j5ivlvZeGETWlwr8PuZoqLx06zX.jpg'),
(145136, 10372, 'Coracao Alado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j5ivlvZeGETWlwr8PuZoqLx06zX.jpg'),
(145137, 10372, 'Coracao Alado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j5ivlvZeGETWlwr8PuZoqLx06zX.jpg'),
(145138, 10372, 'Coracao Alado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j5ivlvZeGETWlwr8PuZoqLx06zX.jpg'),
(145139, 10373, 'Dr Brain [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4iRtHoFXclcvhqgJiOW6ngjH0La.jpg'),
(145140, 10373, 'Dr Brain [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPQabFfdAhRJsebXonkJ3fbwopR.jpg'),
(145141, 10373, 'Dr Brain [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vZUacF7ytoH56NqgSlppVh7oL8z.jpg'),
(145142, 10373, 'Dr Brain [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lXu8L5QysSJ17pbrizOXCI4jJMk.jpg'),
(145143, 10373, 'Dr Brain [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mAf7ivbpNreUwUfvkZFRAAfMVoe.jpg'),
(145144, 10373, 'Dr Brain [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wr91J90oHBBUnaaM7FVwjcxlxh7.jpg'),
(145145, 10374, 'Fantasy Bishoujo Juniku Ojisan to [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4RZtEMAOyeEXJmaSJD8MwhaYYyl.jpg'),
(145146, 10374, 'Fantasy Bishoujo Juniku Ojisan to [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vo8ElkNjCbeW9FCIsEweD27WMbu.jpg'),
(145147, 10374, 'Fantasy Bishoujo Juniku Ojisan to [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oruc2biIkouZTXRMUJnpieMLKPC.jpg'),
(145148, 10374, 'Fantasy Bishoujo Juniku Ojisan to [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z0aUBbeZhjadimo83zQB2mDDDLa.jpg'),
(145149, 10374, 'Fantasy Bishoujo Juniku Ojisan to [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7miICVeHMKSq78iuypRyxIdCUmR.jpg'),
(145150, 10374, 'Fantasy Bishoujo Juniku Ojisan to [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ntxVe7hT9T3QLsFicCmkbXiBTKc.jpg'),
(145151, 10374, 'Fantasy Bishoujo Juniku Ojisan to [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LzP0XsP9WbjxzhNxn13kAiQ0r9.jpg'),
(145152, 10374, 'Fantasy Bishoujo Juniku Ojisan to [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iHGBd01zLIYp47bLqwavIquqHBM.jpg'),
(145153, 10374, 'Fantasy Bishoujo Juniku Ojisan to [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cNb4LKzsMjrQQB7eKWJbfVixIJs.jpg'),
(145154, 10374, 'Fantasy Bishoujo Juniku Ojisan to [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7zXEbwN35GvSr3YAPQYDEkekrKJ.jpg'),
(145155, 10374, 'Fantasy Bishoujo Juniku Ojisan to [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/331862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mnT3c41ictq8xZhSY7LSTPkJxUV.jpg'),
(145156, 10374, 'Fantasy Bishoujo Juniku Ojisan to [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/331863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBccRMC8ApW1xAPmnigZSHKlUW1.jpg'),
(145157, 10375, 'First love Again [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aB3EKA0VkcKDtdoOm0Oa3LaNRad.jpg'),
(145158, 10375, 'First love Again [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iXiGe6q0h0KKkP8FuOjgXdFuFdF.jpg'),
(145159, 10375, 'First love Again [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6uMAHi5CYQFSemF5FJVgRLdnrQc.jpg'),
(145160, 10375, 'First love Again [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fxQroW46YTYvjLU4fIPdYu825Y5.jpg'),
(145161, 10375, 'First love Again [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nBzc5nFeLUn0jwjH2lfX4ISd5ye.jpg'),
(145162, 10375, 'First love Again [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqq5EtDjIFHHyVZQxQ0RI5VmUly.jpg'),
(145163, 10376, 'Happy Ending Romance [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/10oIrMRMe5CiqwXrmuQjvxOFn7K.jpg'),
(145164, 10376, 'Happy Ending Romance [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t9RHD3sjMnpWPAql1KvKopyDfcb.jpg'),
(145165, 10376, 'Happy Ending Romance [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yVf4aOeoPbdNCFYMuXAVIrDNT0V.jpg'),
(145166, 10376, 'Happy Ending Romance [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ebtF89g3ZSDKvtuMOejW5oyJ3E6.jpg'),
(145167, 10376, 'Happy Ending Romance [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dnSznLqJUX0CGbHh8qdQCMdP0Ui.jpg'),
(145168, 10376, 'Happy Ending Romance [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hDOkMnF6ufnFVjAFOhR9yFJgUfV.jpg'),
(145169, 10376, 'Happy Ending Romance [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/br7EsBiO8bPBz3aFkGHs9oJzJZr.jpg'),
(145170, 10376, 'Happy Ending Romance [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zymJlQ80WHi0sQtdzQQ7hpTRwh2.jpg'),
(145171, 10377, 'Kissable Lips [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wfMway86qyrb3gBOnu48Xbch0Vx.jpg'),
(145172, 10377, 'Kissable Lips [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7H0LOPpCWA9b4sN0VOrv3ooB9Ym.jpg'),
(145173, 10377, 'Kissable Lips [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5cNpEL5yyhCUaV9hYv5LZrhes3o.jpg'),
(145174, 10377, 'Kissable Lips [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9K3wXOHGKNz8WINyPh185uzLr0O.jpg'),
(145175, 10377, 'Kissable Lips [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lGOJhQS8hHyOHkMqddJRWCMzqJ3.jpg'),
(145176, 10377, 'Kissable Lips [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e0EgetdgwbwpqsJ4jT6X60i7w2L.jpg'),
(145177, 10377, 'Kissable Lips [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8gHpuLAjBD2hK3mDryxh7R6nkgW.jpg'),
(145178, 10377, 'Kissable Lips [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gvMvXls9IZvpwoRtvINZbhqf0fp.jpg'),
(145179, 10378, 'Light On Me [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vQDjTi7llQmSZoPlL1XNCc3PZCt.jpg'),
(145180, 10378, 'Light On Me [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gwr6BIHac39XWmJHiVKUcqu4cbr.jpg'),
(145181, 10378, 'Light On Me [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wDXPkDZHMjVrcIM86mpDB0LcTcl.jpg'),
(145182, 10378, 'Light On Me [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pIPPc2JIzNJcbmw2oCOPL5KxIqt.jpg'),
(145183, 10378, 'Light On Me [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/egIAXf4bbIzTOLuHe05YdXiFjED.jpg'),
(145184, 10378, 'Light On Me [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sKIr6pp4l44tcPxECgOMn875QHo.jpg'),
(145185, 10378, 'Light On Me [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oToxEjTbTHxWesnUsAYCm9Jt9Rj.jpg'),
(145186, 10378, 'Light On Me [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/owFST2GrLIQ6zUkZfaiaIx3j7n2.jpg'),
(145187, 10378, 'Light On Me [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/81EthDRUvfVwEchgOXMBjdCa5zi.jpg'),
(145188, 10378, 'Light On Me [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2TZZz0XZQC4F78FjrELcX2SVvmh.jpg'),
(145189, 10378, 'Light On Me [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/331824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kAWtCHqgMkml2KR94NTwbD9lLsD.jpg'),
(145190, 10378, 'Light On Me [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/331825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jcxJTxc5oBZkbNcuwfSr2W9H0RE.jpg'),
(145191, 10378, 'Light On Me [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/331826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n45iZrEUGOTLSXmWwwbARPUhXBR.jpg'),
(145192, 10378, 'Light On Me [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/331827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yYLFizQ5Bhkj4EfXlzSJqB8BmGN.jpg'),
(145193, 10378, 'Light On Me [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/331828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4nSvQD2yuzWuRdmKtjEbBei7m2y.jpg'),
(145194, 10378, 'Light On Me [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/331829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7LEtjN2NfvXP65SP68Cy2qGiKs7.jpg'),
(145195, 10379, 'Mr Heart [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ztXnVqxDpJWb2nuVZhRJ5ZM0LrW.jpg'),
(145196, 10379, 'Mr Heart [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ny1Dcx9MGGdxed0xmrQxtaW413Y.jpg'),
(145197, 10379, 'Mr Heart [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1gUScZbihJIFSjfugUS1YOKgUz3.jpg'),
(145198, 10379, 'Mr Heart [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tRJFLgWakinGladtt6AZ9eH0V0O.jpg'),
(145199, 10379, 'Mr Heart [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uSu20xRbOsMk28fhF9EphHBUKuj.jpg'),
(145200, 10379, 'Mr Heart [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/utDEMhcSCqcPkOdWJs6lz2kvPDJ.jpg'),
(145201, 10379, 'Mr Heart [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jiBe5pzgZ2C9hnZJKbrR5UDNGe5.jpg'),
(145202, 10379, 'Mr Heart [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sKwBJuu655vVkj6ikMmK8SagxI7.jpg'),
(145203, 10379, 'Mr Heart [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ugb3scDQ291cAuvOvv8vwY3M4GR.jpg'),
(145204, 10380, 'My Sweet Dear [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gD5OtWUZqDEEsZ2Csty4VoiThHL.jpg'),
(145205, 10380, 'My Sweet Dear [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gD5OtWUZqDEEsZ2Csty4VoiThHL.jpg'),
(145206, 10380, 'My Sweet Dear [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gD5OtWUZqDEEsZ2Csty4VoiThHL.jpg'),
(145207, 10380, 'My Sweet Dear [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gD5OtWUZqDEEsZ2Csty4VoiThHL.jpg'),
(145208, 10380, 'My Sweet Dear [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gD5OtWUZqDEEsZ2Csty4VoiThHL.jpg'),
(145209, 10380, 'My Sweet Dear [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gD5OtWUZqDEEsZ2Csty4VoiThHL.jpg'),
(145210, 10380, 'My Sweet Dear [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gD5OtWUZqDEEsZ2Csty4VoiThHL.jpg'),
(145211, 10380, 'My Sweet Dear [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gD5OtWUZqDEEsZ2Csty4VoiThHL.jpg'),
(145212, 10381, 'Ocean Likes Me [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1BYBSq9pcoUjYy0kfPbOahcb2eg.jpg'),
(145213, 10381, 'Ocean Likes Me [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8IZiEKZKdi4Lj6QJgpqBKhOKCby.jpg'),
(145214, 10381, 'Ocean Likes Me [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eToVI6dWZ2g42NmUgBtvVPeEUHu.jpg'),
(145215, 10381, 'Ocean Likes Me [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4pqSAe50Pj0YAH9HRRoX6wae1ps.jpg'),
(145216, 10381, 'Ocean Likes Me [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v9sYg5Vp5Q2RdahnTY92Q9IvL1b.jpg'),
(145217, 10381, 'Ocean Likes Me [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rTW0tJL81CK82FABIUgY3Zg4qpb.jpg'),
(145218, 10381, 'Ocean Likes Me [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7XQfLseAXAoc3mm8hfH39dyOARB.jpg'),
(145219, 10381, 'Ocean Likes Me [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/phmWuZKtAZ14Bd6d8okEroiNvtB.jpg'),
(145220, 10382, 'Oh My Assistant [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7dg0atB5iQMetZkclTwnfrpwf7Q.jpg'),
(145221, 10382, 'Oh My Assistant [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tfkTLficVDmca9tBERWcxaghzh4.jpg'),
(145222, 10382, 'Oh My Assistant [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ZyeIVwBKB8KnuwwTdCdZlpYXMP.jpg'),
(145223, 10382, 'Oh My Assistant [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2li4UPJ2RqfqJvCjLe11Hki9LzT.jpg'),
(145224, 10382, 'Oh My Assistant [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n38OkluSlSZfFJAyfx1jNQrSDRj.jpg'),
(145225, 10382, 'Oh My Assistant [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eDjKY3u6HN7ABbtspVLhgKQvnnU.jpg'),
(145226, 10382, 'Oh My Assistant [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2pBnNY28yYXE3txSqYFj9DSph4L.jpg'),
(145227, 10382, 'Oh My Assistant [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9UsauqiVV1wijuZq2yNOQ7EtZDR.jpg'),
(145228, 10383, 'Once Again [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iNgpAsBLRXiS3lHhGGdc0J7crDw.jpg'),
(145229, 10383, 'Once Again [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dzUARwhp9nVr6gf8hyysmSSgRXL.jpg'),
(145230, 10383, 'Once Again [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBFdlYx0mZKd3zRKaeY7ojL8Cpm.jpg'),
(145231, 10383, 'Once Again [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w181gMWgrV0dKOaBLs6pc6gYlvn.jpg'),
(145232, 10383, 'Once Again [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhHCkpd4hRMJn50PCPGArzTzxnF.jpg'),
(145233, 10383, 'Once Again [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8koFKmGB2H8hNPF0WiR1E5AzkfE.jpg'),
(145234, 10383, 'Once Again [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AhlRkD0FcopTHSz5JtL0O6l5I3S.jpg'),
(145235, 10383, 'Once Again [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sQtgMWJv7UqOvTr8kgOF6XP4K1B.jpg'),
(145236, 10384, 'Os Gigantes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1iFq0sna4MGLwRBtTiWHd6rPtYi.jpg'),
(145237, 10384, 'Os Gigantes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1iFq0sna4MGLwRBtTiWHd6rPtYi.jpg'),
(145238, 10385, 'Roommates of Poongduck 304 [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cjUiiMAYDLJsRbLvexo819iSVTG.jpg'),
(145239, 10385, 'Roommates of Poongduck 304 [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wMbGTqs8FzlPXPxjF3sQsod43hp.jpg'),
(145240, 10385, 'Roommates of Poongduck 304 [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ws10fVszFAyPzkME5UJrvHPulc.jpg'),
(145241, 10385, 'Roommates of Poongduck 304 [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qqE8gfgfAQfbJ1eeMP6n4polPfa.jpg'),
(145242, 10385, 'Roommates of Poongduck 304 [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3q7J5jgV7PIQqVqY9hRCFRspttw.jpg'),
(145243, 10385, 'Roommates of Poongduck 304 [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfJrrMMgYzmdMuoBoAAPiXaEllJ.jpg'),
(145244, 10385, 'Roommates of Poongduck 304 [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30j5IWdw5u6XsVWmUUscOmpVUNu.jpg'),
(145245, 10385, 'Roommates of Poongduck 304 [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/30j5IWdw5u6XsVWmUUscOmpVUNu.jpg'),
(145246, 10386, 'Segredos dos Polvos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bre7VGiTfm7zkAGUV7nld5A1uXu.jpg'),
(145247, 10386, 'Segredos dos Polvos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kVIQ0Vl342ouxgijzPXgSWN7WiE.jpg'),
(145248, 10386, 'Segredos dos Polvos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dnsETim0mjRtiLkVGSmLaa5dBia.jpg'),
(145249, 10387, 'Sem Sangue [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Lq80W648OCp93eDdZ2lApXCeo8.jpg'),
(145250, 10387, 'Sem Sangue [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4XSi2D8FCFFmy5bVldyyNxAgbuQ.jpg'),
(145251, 10387, 'Sem Sangue [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m4Ro4Z2kJ3pEx9DZZe5BusIkjru.jpg'),
(145252, 10387, 'Sem Sangue [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eRHTg2OGTFSuRY1GJNzzlM9iNWG.jpg'),
(145253, 10387, 'Sem Sangue [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/335961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a8j6wfVl6DtPjMFk5LrdjhG458G.jpg'),
(145254, 10387, 'Sem Sangue [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/335962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a8j6wfVl6DtPjMFk5LrdjhG458G.jpg'),
(145255, 10387, 'Sem Sangue [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/340121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a8j6wfVl6DtPjMFk5LrdjhG458G.jpg'),
(145256, 10387, 'Sem Sangue [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/340122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a8j6wfVl6DtPjMFk5LrdjhG458G.jpg'),
(145257, 10387, 'Sem Sangue [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a8j6wfVl6DtPjMFk5LrdjhG458G.jpg'),
(145258, 10387, 'Sem Sangue [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a8j6wfVl6DtPjMFk5LrdjhG458G.jpg'),
(145259, 10388, 'Semantic Error [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4v7p2HsLixHzxQApdurkH2bASHR.jpg'),
(145260, 10388, 'Semantic Error [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tDdEmmclbvmspNfiDCO3OMMLuCX.jpg'),
(145261, 10388, 'Semantic Error [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/onIwbPso8IwCImzHOqyPq75RKdB.jpg'),
(145262, 10388, 'Semantic Error [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/roQy956yCPuSxi8SoamOhXe3BDn.jpg'),
(145263, 10388, 'Semantic Error [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ayXorQxKBTFowYNjdBOC6DTR8so.jpg'),
(145264, 10388, 'Semantic Error [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ZGOEzDYvQSGzWB7IBXBpRHlmKB.jpg'),
(145265, 10388, 'Semantic Error [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7FCiIHf1Nl0mwe3gqGfoeifq7vr.jpg'),
(145266, 10388, 'Semantic Error [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oJ9LeO347Yz5E0A27j76hrTKpJ.jpg'),
(145267, 10389, 'Sierra Madre Passagem Proibida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Ji0ByVxOWGiC9F8ajYN60z1V96.jpg'),
(145268, 10389, 'Sierra Madre Passagem Proibida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Ji0ByVxOWGiC9F8ajYN60z1V96.jpg'),
(145269, 10389, 'Sierra Madre Passagem Proibida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/360504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Ji0ByVxOWGiC9F8ajYN60z1V96.jpg'),
(145270, 10389, 'Sierra Madre Passagem Proibida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/360505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Ji0ByVxOWGiC9F8ajYN60z1V96.jpg'),
(145271, 10389, 'Sierra Madre Passagem Proibida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/360506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Ji0ByVxOWGiC9F8ajYN60z1V96.jpg'),
(145272, 10389, 'Sierra Madre Passagem Proibida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/360507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Ji0ByVxOWGiC9F8ajYN60z1V96.jpg'),
(145273, 10389, 'Sierra Madre Passagem Proibida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/605920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Ji0ByVxOWGiC9F8ajYN60z1V96.jpg'),
(145274, 10389, 'Sierra Madre Passagem Proibida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/605921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Ji0ByVxOWGiC9F8ajYN60z1V96.jpg'),
(145275, 10389, 'Sierra Madre Passagem Proibida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/384064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5Ji0ByVxOWGiC9F8ajYN60z1V96.jpg'),
(145276, 10390, 'Sol de Verao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pxumaRd8JOeqt7A71n1u4V0xCP9.jpg'),
(145277, 10390, 'Sol de Verao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pxumaRd8JOeqt7A71n1u4V0xCP9.jpg'),
(145278, 10390, 'Sol de Verao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pxumaRd8JOeqt7A71n1u4V0xCP9.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(145279, 10390, 'Sol de Verao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pxumaRd8JOeqt7A71n1u4V0xCP9.jpg'),
(145280, 10390, 'Sol de Verao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pxumaRd8JOeqt7A71n1u4V0xCP9.jpg'),
(145281, 10390, 'Sol de Verao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pxumaRd8JOeqt7A71n1u4V0xCP9.jpg'),
(145282, 10390, 'Sol de Verao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pxumaRd8JOeqt7A71n1u4V0xCP9.jpg'),
(145283, 10390, 'Sol de Verao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pxumaRd8JOeqt7A71n1u4V0xCP9.jpg'),
(145284, 10391, 'Somos os Que Tiveram Sorte [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pBFlX8mI2TxGQ3sDAvbrjrmBJ9b.jpg'),
(145285, 10391, 'Somos os Que Tiveram Sorte [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u9js0kF2RuyhP1nRI4DCDpMcg6B.jpg'),
(145286, 10391, 'Somos os Que Tiveram Sorte [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kiCNjFW4BVPazGLUWMFBxQhC5r3.jpg'),
(145287, 10391, 'Somos os Que Tiveram Sorte [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ba6aSVRkDVF9572h0f1F7vZNAzl.jpg'),
(145288, 10391, 'Somos os Que Tiveram Sorte [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vMCW4br2y3lFRQwwTJTOw8y5B9E.jpg'),
(145289, 10392, 'The Accidental Influencer [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a0MWgqXFhqdz4rk1J4UBvxhygB3.jpg'),
(145290, 10392, 'The Accidental Influencer [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/povyy31GGOKY86lEZKpW7ttYxfT.jpg'),
(145291, 10392, 'The Accidental Influencer [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3SBmHVygLKLzBPBcgh1LvSHrwDo.jpg'),
(145292, 10392, 'The Accidental Influencer [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g14tBzI8m8Lw2jAVZfWtN2IPfrN.jpg'),
(145293, 10392, 'The Accidental Influencer [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aw8piMSsTgf5oJpGdGHhKpYCKGo.jpg'),
(145294, 10392, 'The Accidental Influencer [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zFYz0Jt2GFhpMh5FmUA4wx2SrDt.jpg'),
(145295, 10392, 'The Accidental Influencer [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w4yBhU24oYQ1jTXXUAq4iM4PwhD.jpg'),
(145296, 10392, 'The Accidental Influencer [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h02j0M8SwWmOqGvcxtwRtoVeQJc.jpg'),
(145297, 10392, 'The Accidental Influencer [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4lsXE2MAkDRmVAPJfxxz1WZ0kq4.jpg'),
(145298, 10392, 'The Accidental Influencer [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m1P6cNyocVxvHEXVT6BqAUPlZ1N.jpg'),
(145299, 10392, 'The Accidental Influencer [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/331738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6vJRJD01cYr2M8g4Dtuzwb4E6Yh.jpg'),
(145300, 10392, 'The Accidental Influencer [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/331739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNlQCCGOKUyarrL8fL5FgjSs5cA.jpg'),
(145301, 10392, 'The Accidental Influencer [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/331740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3WwQR8nd6iN6ZkeyJ8wOju836yH.jpg'),
(145302, 10393, 'The New Employee [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3j8HVpqAjUat7DHerrDyp2ajynm.jpg'),
(145303, 10393, 'The New Employee [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a5dKWXjpTfqTd6ZYYpyvWql24MZ.jpg'),
(145304, 10393, 'The New Employee [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e6KDoXWJ9fBdXmTmulRhTtkvnr8.jpg'),
(145305, 10393, 'The New Employee [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gi7OqIKXl41haoWkwJXgcWHpNcv.jpg'),
(145306, 10393, 'The New Employee [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nFmFbVk6w77M2HOVf6mvj3gZZbO.jpg'),
(145307, 10393, 'The New Employee [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rZtGEwq3r0eIT26I92wbQ0lMTTJ.jpg'),
(145308, 10393, 'The New Employee [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dy0S1NAa1rRc5FDnxqNpsDUhCTX.jpg'),
(145309, 10394, 'The Tasty Florida [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z1ZyejmgeaqtzhdzaGDW9OqlwZ5.jpg'),
(145310, 10394, 'The Tasty Florida [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kRZAOVUBLXLS947IDkXU2NHPz0B.jpg'),
(145311, 10394, 'The Tasty Florida [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gmcZxFn47hAITOXclVWOSFPTL0e.jpg'),
(145312, 10394, 'The Tasty Florida [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iIQIAD2FRVFcxSUwVawEQi7bhaP.jpg'),
(145313, 10394, 'The Tasty Florida [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xtKFOZn08ZurATqOn1zzI1sw1MJ.jpg'),
(145314, 10394, 'The Tasty Florida [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3KuPe6Hwit1dPi1Id2KrvwfAc1D.jpg'),
(145315, 10394, 'The Tasty Florida [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aaiShvwl1WUxOLj5vWD6TuqFyxZ.jpg'),
(145316, 10394, 'The Tasty Florida [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Vmliq1ABAuxDSpvDRGA4TuxbYX.jpg'),
(145317, 10395, 'The Walking Dead The Ones Who Live S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8WrLYjzukBMeeSN9QYPw28qVA6h.jpg'),
(145318, 10395, 'The Walking Dead The Ones Who Live S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bcp6gmyQuoRdkpJFCHpJYDJVyO9.jpg'),
(145319, 10395, 'The Walking Dead The Ones Who Live S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o1Qw7o1ab4tAzMUh5esJ41TNpZF.jpg'),
(145320, 10395, 'The Walking Dead The Ones Who Live S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/93RqOHVclGyBoH4FIi3VmHnlxXe.jpg'),
(145321, 10395, 'The Walking Dead The Ones Who Live S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q6Vqo90TAbu9NbuIhPgxzgIZogh.jpg'),
(145322, 10395, 'The Walking Dead The Ones Who Live S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lJNkVYOsxOmEXcCvbC8SeQYjdL4.jpg'),
(145323, 10396, 'Tinted With You [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rEDSM7pjt6qeizlr5ojBlDCwN18.jpg'),
(145324, 10396, 'Tinted With You [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rEDSM7pjt6qeizlr5ojBlDCwN18.jpg'),
(145325, 10396, 'Tinted With You [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rEDSM7pjt6qeizlr5ojBlDCwN18.jpg'),
(145326, 10396, 'Tinted With You [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rEDSM7pjt6qeizlr5ojBlDCwN18.jpg'),
(145327, 10396, 'Tinted With You [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rEDSM7pjt6qeizlr5ojBlDCwN18.jpg'),
(145328, 10396, 'Tinted With You [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rEDSM7pjt6qeizlr5ojBlDCwN18.jpg'),
(145329, 10396, 'Tinted With You [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rEDSM7pjt6qeizlr5ojBlDCwN18.jpg'),
(145330, 10396, 'Tinted With You [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rEDSM7pjt6qeizlr5ojBlDCwN18.jpg'),
(145331, 10397, 'To My Star [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/te16C2LMXabNPMMRu2TpYFDpuJk.jpg'),
(145332, 10397, 'To My Star [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wP48RheJ0o82rq3IdqD9IsnJDoZ.jpg'),
(145333, 10397, 'To My Star [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5pTt9pVZ90JgX8zhWlrFRNBZql.jpg'),
(145334, 10397, 'To My Star [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Mj9P5UFSpZz1grGUvJ5gSzW9GE.jpg'),
(145335, 10397, 'To My Star [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1dNlODvnCgYBXmWCcLT2r2nNFP.jpg'),
(145336, 10397, 'To My Star [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cw8JcM8tRExW9bR9atnzpqWMR1M.jpg'),
(145337, 10397, 'To My Star [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3jVGx9VEhyFnYUZOMHklQ3rfcAF.jpg'),
(145338, 10397, 'To My Star [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oFkldaHNH553vx2V35lIng2t5Px.jpg'),
(145339, 10397, 'To My Star [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOo6WlrAOJqaKsoG8gbxgMJ7EVv.jpg'),
(145340, 10397, 'To My Star [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f42Y7h46ysNWex5xEuZjfvUbeHL.jpg'),
(145341, 10398, 'To My Star [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5pPoQ8OI7V22GHtydg1r2PQTpul.jpg'),
(145342, 10398, 'To My Star [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1O8BYqgt79Qa7prin10gc3lGSmn.jpg'),
(145343, 10398, 'To My Star [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rryll9CRzrfYKEgYst9bHL5HkrR.jpg'),
(145344, 10398, 'To My Star [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ucR0itJEAbq0S15hh8fSP888gq7.jpg'),
(145345, 10398, 'To My Star [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2MKNHAQnMLn6BktxgxvlOtBF4He.jpg'),
(145346, 10398, 'To My Star [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3t3Jy0SynEoGob9gyvbTz2ruEiV.jpg'),
(145347, 10398, 'To My Star [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t0pERL6ZeNLA5LwXGEwVD2J99qt.jpg'),
(145348, 10398, 'To My Star [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ohkXUchoYdmwmW2dtbCrX3WZDyr.jpg'),
(145349, 10398, 'To My Star [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ypMsMfEG7n12jkY781YmWTb8lbm.jpg'),
(145350, 10398, 'To My Star [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8jTIXDGtdoxdXbMzeQfsGEzuxwx.jpg'),
(145351, 10399, 'You Make Me Dance [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AncOyQaEgBVq4bQF2kJZ9Kg4uiE.jpg'),
(145352, 10399, 'You Make Me Dance [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2KH5MiQgYad8DMdBo9sOOyAmns2.jpg'),
(145353, 10399, 'You Make Me Dance [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4e0V10fIJEHzfoJWwBCJkgm2NkB.jpg'),
(145354, 10399, 'You Make Me Dance [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w9JJyxrUiMpMPh1PIOaBje7BTGq.jpg'),
(145355, 10399, 'You Make Me Dance [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/LvwcRZ5vQQmnIpdagsiiR8PXjm.jpg'),
(145356, 10399, 'You Make Me Dance [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBbKaptpSDg0J2yga6yfRwdg3Tw.jpg'),
(145357, 10399, 'You Make Me Dance [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3THB4owzuprxj1HO5Z4GfzOiULn.jpg'),
(145358, 10399, 'You Make Me Dance [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kcVXg3uOXdL58kAND59QB2XzT9K.jpg'),
(145359, 10400, 'Ben 10 Omniverse S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vRoennMrmny05OVLmNDjSL9qKqt.jpg'),
(145360, 10400, 'Ben 10 Omniverse S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1lDtg3wHVCJYZskPVGj5irx9EjW.jpg'),
(145361, 10400, 'Ben 10 Omniverse S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2O242fqZqEg9JrrP42HBzm2ikYw.jpg'),
(145362, 10400, 'Ben 10 Omniverse S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWIwv46CYuPdiONboN5Y5uwz2dD.jpg'),
(145363, 10400, 'Ben 10 Omniverse S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hE5gdHqf8rpKCdirM7Xl7CeQUvS.jpg'),
(145364, 10400, 'Ben 10 Omniverse S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xbuLk5EkRXJdhPNXvPHl3SDUQeO.jpg'),
(145365, 10400, 'Ben 10 Omniverse S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nj37FrOo4Wg6X5dzMmG1vXrxY63.jpg'),
(145366, 10400, 'Ben 10 Omniverse S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hmhT0SVj09iDZiR6KA3gxViOJCk.jpg'),
(145367, 10400, 'Ben 10 Omniverse S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2It4r1CnDsEPunJmDMq9sAGGYg6.jpg'),
(145368, 10400, 'Ben 10 Omniverse S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/amTJBg5AUXM1fPZUsHUtNoTDyj4.jpg'),
(145369, 10401, 'Ben 10 Omniverse S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uDPRro0ivTCR3XWbTKEYytYjooW.jpg'),
(145370, 10401, 'Ben 10 Omniverse S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aq0YEFIGWF29VQQhyVHL0B2badl.jpg'),
(145371, 10401, 'Ben 10 Omniverse S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fC62iiAVzxqfsGDU8tPHBVaBwgV.jpg'),
(145372, 10401, 'Ben 10 Omniverse S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r3vF0pLLOx7yaKaaL8vsEyT2ymH.jpg'),
(145373, 10401, 'Ben 10 Omniverse S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jEvKkpbVVUQUoSndfdtXNM6nSLo.jpg'),
(145374, 10401, 'Ben 10 Omniverse S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jeB83zlSwxEwAXeYBcVROWtwBfK.jpg'),
(145375, 10401, 'Ben 10 Omniverse S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3t7r1d5u1nHdbgDzWDIMuxkO5Tt.jpg'),
(145376, 10401, 'Ben 10 Omniverse S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tRjiH3xd2zvsGJMDjL6yYhPj8IQ.jpg'),
(145377, 10401, 'Ben 10 Omniverse S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oJKmD5gcvpPzz1c35Uqkp2et0D3.jpg'),
(145378, 10401, 'Ben 10 Omniverse S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sKjGr4rUCjWSAz5y5S7hVp9ReGm.jpg'),
(145379, 10402, 'Ben 10 Omniverse S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ptfewBy1j79fy4BWkkLX1fWs8TG.jpg'),
(145380, 10402, 'Ben 10 Omniverse S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ozHlcBD3uO4wiDgi4VUfZngRxnH.jpg'),
(145381, 10402, 'Ben 10 Omniverse S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvj4wEHXfh93W3IZRJGXl0WuUX7.jpg'),
(145382, 10402, 'Ben 10 Omniverse S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bayST5UvR8qxWesfQnPolyEZ4wf.jpg'),
(145383, 10402, 'Ben 10 Omniverse S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZWSl6YyDpyBM7BrRbnceEeckMl.jpg'),
(145384, 10402, 'Ben 10 Omniverse S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nHC9BBF2ycxP3FVY0H3jrcAeLSA.jpg'),
(145385, 10402, 'Ben 10 Omniverse S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kTElZBri1OTbdhNiva4KNvjwrhA.jpg'),
(145386, 10402, 'Ben 10 Omniverse S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j5jWpNQPsU3uWj7i47eSp6Xtura.jpg'),
(145387, 10402, 'Ben 10 Omniverse S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bamk6T8kZ5CiKwW3MKw6aBbbDlq.jpg'),
(145388, 10402, 'Ben 10 Omniverse S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A8GB6rVTSnWjdEh0ecHrOevXaYj.jpg'),
(145389, 10403, 'Ben 10 Omniverse S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mEw8xumzMprygulTfHM4WYNiriv.jpg'),
(145390, 10403, 'Ben 10 Omniverse S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hRSs70BKgMGQ3QH2DTXXQ4L6amj.jpg'),
(145391, 10403, 'Ben 10 Omniverse S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k67YnpAt8NGtNIXjmijw07UpbOi.jpg'),
(145392, 10403, 'Ben 10 Omniverse S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AsCXpLEm9pLF6OaLQJxTbAue41s.jpg'),
(145393, 10403, 'Ben 10 Omniverse S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Nxju8PKSk8OgW2DQSDbtI3BDE5.jpg'),
(145394, 10403, 'Ben 10 Omniverse S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b1WUzMtrtYLqNUTwmov2Wvu3432.jpg'),
(145395, 10403, 'Ben 10 Omniverse S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6GauxCJwiTSe9mah28vNjs4eb4q.jpg'),
(145396, 10403, 'Ben 10 Omniverse S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Aiwaz8uNrwP3w5GTbPi9xd98Gu.jpg'),
(145397, 10403, 'Ben 10 Omniverse S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x4QmbCKHJraLOiUEP98PrlP1bG6.jpg'),
(145398, 10403, 'Ben 10 Omniverse S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHTVbBHAVTJG7Y1XAapSAayiGGR.jpg'),
(145399, 10404, 'Ben 10 Omniverse S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q1QJlHwy6jMJl7fzIHe3QOxzBF5.jpg'),
(145400, 10404, 'Ben 10 Omniverse S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jUX8U2FrGMEcn5TgGwQf42VG5TX.jpg'),
(145401, 10404, 'Ben 10 Omniverse S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eGKNIKGId29pKLFrfrs4qH8J09Z.jpg'),
(145402, 10404, 'Ben 10 Omniverse S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2YHGnwqUcCfOuQibjimZ5PseBAt.jpg'),
(145403, 10404, 'Ben 10 Omniverse S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yxDMb1h1n8SNIWgxsNHGw86swLj.jpg'),
(145404, 10404, 'Ben 10 Omniverse S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rdwF5Fl6QltlXXL0qI81t0YE8zA.jpg'),
(145405, 10404, 'Ben 10 Omniverse S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/skdSVsRPbdcPVl0BGtt5pXBobIG.jpg'),
(145406, 10404, 'Ben 10 Omniverse S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/djgcycPfOfk9uadZRHlQfivaoKq.jpg'),
(145407, 10404, 'Ben 10 Omniverse S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/djgcycPfOfk9uadZRHlQfivaoKq.jpg'),
(145408, 10404, 'Ben 10 Omniverse S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x1tEXC9qHt4bfR6rXKeeY6TJQdW.jpg'),
(145409, 10405, 'Ben 10 Omniverse S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cyzjyzmbu2n9qVovbvuttmED7Dj.jpg'),
(145410, 10405, 'Ben 10 Omniverse S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2rKg6spARwM46ElAN7z73ro4Ra.jpg'),
(145411, 10405, 'Ben 10 Omniverse S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9DcCeGwbp51ZVYCh2gNN048fW90.jpg'),
(145412, 10405, 'Ben 10 Omniverse S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l0gYesAZeC45WgIaog0ZRNZn31i.jpg'),
(145413, 10405, 'Ben 10 Omniverse S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rUrxRkfQglln45JtB6xOUCLwOIK.jpg'),
(145414, 10405, 'Ben 10 Omniverse S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ogWKYKJzeFf6lDi6Mdx1kfQguYz.jpg'),
(145415, 10405, 'Ben 10 Omniverse S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kljwG5ikFtMNYLj4wEIbop4tM89.jpg'),
(145416, 10405, 'Ben 10 Omniverse S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bO0yPKhUk7iuxyesbphpVU4aUvc.jpg'),
(145417, 10405, 'Ben 10 Omniverse S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kHo560BRdQj4FHErXoFIxUa9i7k.jpg'),
(145418, 10405, 'Ben 10 Omniverse S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8drHF3Y1XklBmh2evybGboxfth2.jpg'),
(145419, 10406, 'Ben 10 Omniverse S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w4dqClzxpGWzzqkC3j2Xq5IhAU2.jpg'),
(145420, 10406, 'Ben 10 Omniverse S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zbKW08n06o94LbvcgKufkafpcrf.jpg'),
(145421, 10406, 'Ben 10 Omniverse S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fXzZEmtxm6fPtnKeeGIsWNqwKvS.jpg'),
(145422, 10406, 'Ben 10 Omniverse S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lfMJsluNmJIQcbDWKRL7Qle4oJx.jpg'),
(145423, 10406, 'Ben 10 Omniverse S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l5FVZAamXBbGRBDiEyUgmY0lgEL.jpg'),
(145424, 10406, 'Ben 10 Omniverse S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mnvV8EldGZagqakHC7Lv3kKYJ8p.jpg'),
(145425, 10406, 'Ben 10 Omniverse S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qhYZnFN1V2CfiWwcdKZaef4a6N8.jpg'),
(145426, 10406, 'Ben 10 Omniverse S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMoO8KV9uCIp2b0uQXscQMo4kLV.jpg'),
(145427, 10406, 'Ben 10 Omniverse S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k3wARQT330lmwS9HoUgqxqQwRQc.jpg'),
(145428, 10406, 'Ben 10 Omniverse S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ox7KC9CX6aEpacf3DrNYvu21SeK.jpg'),
(145429, 10407, 'Ben 10 Omniverse S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/331649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cdJhB8RGLPy6U9gSvAJSI7er3so.jpg'),
(145430, 10407, 'Ben 10 Omniverse S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/331650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/68jWMfeQTUXrKvHJAC7D16akPDK.jpg'),
(145431, 10407, 'Ben 10 Omniverse S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/331651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iV7JoL4wI0V9eYPLnUmGihUmENg.jpg'),
(145432, 10407, 'Ben 10 Omniverse S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/331652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8EMpDdYZCsAKrCbtxyuEbAKhjHz.jpg'),
(145433, 10407, 'Ben 10 Omniverse S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/331653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qOEJ2xdzQJG4mpQy54HF8sbJvfC.jpg'),
(145434, 10407, 'Ben 10 Omniverse S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/331654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jV2wiNtPieyX87og7RVQzzUtDZZ.jpg'),
(145435, 10407, 'Ben 10 Omniverse S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/331655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wAxhIXXunGGJ9o9oB9shihukBpL.jpg'),
(145436, 10407, 'Ben 10 Omniverse S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/331656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zfrr8gyu1IucUaBStdJr0mMU3D4.jpg'),
(145437, 10407, 'Ben 10 Omniverse S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/331657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tMnpiecUu35L8Aojit8ktLLUL6E.jpg'),
(145438, 10407, 'Ben 10 Omniverse S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/331658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/luopkTshNv911zbqVTrTXsyeOhq.jpg'),
(145439, 10408, 'A Grande Conquista S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/334298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145440, 10408, 'A Grande Conquista S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/334299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145441, 10408, 'A Grande Conquista S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/334300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145442, 10408, 'A Grande Conquista S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/334301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145443, 10408, 'A Grande Conquista S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/339065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145444, 10408, 'A Grande Conquista S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/339066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145445, 10408, 'A Grande Conquista S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/339067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145446, 10408, 'A Grande Conquista S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/341920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145447, 10408, 'A Grande Conquista S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/341921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145448, 10408, 'A Grande Conquista S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/341922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145449, 10408, 'A Grande Conquista S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/346523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145450, 10408, 'A Grande Conquista S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/346524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145451, 10408, 'A Grande Conquista S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/346525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145452, 10408, 'A Grande Conquista S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/346526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145453, 10408, 'A Grande Conquista S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/350722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145454, 10408, 'A Grande Conquista S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/350723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145455, 10408, 'A Grande Conquista S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/350724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145456, 10408, 'A Grande Conquista S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/350725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145457, 10408, 'A Grande Conquista S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/350726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145458, 10408, 'A Grande Conquista S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/350727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145459, 10408, 'A Grande Conquista S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/350728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145460, 10408, 'A Grande Conquista S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/350729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145461, 10408, 'A Grande Conquista S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/350730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145462, 10408, 'A Grande Conquista S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/350731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145463, 10408, 'A Grande Conquista S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/350732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145464, 10408, 'A Grande Conquista S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/350733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145465, 10408, 'A Grande Conquista S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/350734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145466, 10408, 'A Grande Conquista S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/350735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145467, 10408, 'A Grande Conquista S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/361005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145468, 10408, 'A Grande Conquista S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/361006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145469, 10408, 'A Grande Conquista S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/361007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145470, 10408, 'A Grande Conquista S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/361008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145471, 10408, 'A Grande Conquista S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/361009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145472, 10408, 'A Grande Conquista S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/361010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145473, 10408, 'A Grande Conquista S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/361011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145474, 10408, 'A Grande Conquista S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/610435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145475, 10408, 'A Grande Conquista S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/610436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145476, 10408, 'A Grande Conquista S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/610437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145477, 10408, 'A Grande Conquista S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/610438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145478, 10408, 'A Grande Conquista S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/610439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145479, 10408, 'A Grande Conquista S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/610440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145480, 10408, 'A Grande Conquista S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/610441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145481, 10408, 'A Grande Conquista S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/375837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145482, 10408, 'A Grande Conquista S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/378754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145483, 10408, 'A Grande Conquista S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/375838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145484, 10408, 'A Grande Conquista S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/378756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145485, 10408, 'A Grande Conquista S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/378757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145486, 10408, 'A Grande Conquista S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/378758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145487, 10408, 'A Grande Conquista S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/380195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145488, 10408, 'A Grande Conquista S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/383507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145489, 10408, 'A Grande Conquista S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/383508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145490, 10408, 'A Grande Conquista S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/383509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145491, 10408, 'A Grande Conquista S02 E53', 'http://sinalprivado.info:80/series/1533784/1533784/383510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145492, 10408, 'A Grande Conquista S02 E54', 'http://sinalprivado.info:80/series/1533784/1533784/385235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145493, 10408, 'A Grande Conquista S02 E55', 'http://sinalprivado.info:80/series/1533784/1533784/385236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145494, 10408, 'A Grande Conquista S02 E56', 'http://sinalprivado.info:80/series/1533784/1533784/385237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145495, 10408, 'A Grande Conquista S02 E57', 'http://sinalprivado.info:80/series/1533784/1533784/385238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145496, 10408, 'A Grande Conquista S02 E58', 'http://sinalprivado.info:80/series/1533784/1533784/385239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145497, 10408, 'A Grande Conquista S02 E59', 'http://sinalprivado.info:80/series/1533784/1533784/385240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145498, 10408, 'A Grande Conquista S02 E60', 'http://sinalprivado.info:80/series/1533784/1533784/385241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145499, 10408, 'A Grande Conquista S02 E61', 'http://sinalprivado.info:80/series/1533784/1533784/385242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145500, 10408, 'A Grande Conquista S02 E62', 'http://sinalprivado.info:80/series/1533784/1533784/393001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145501, 10408, 'A Grande Conquista S02 E63', 'http://sinalprivado.info:80/series/1533784/1533784/393002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145502, 10408, 'A Grande Conquista S02 E64', 'http://sinalprivado.info:80/series/1533784/1533784/398178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145503, 10408, 'A Grande Conquista S02 E65', 'http://sinalprivado.info:80/series/1533784/1533784/398179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145504, 10408, 'A Grande Conquista S02 E66', 'http://sinalprivado.info:80/series/1533784/1533784/400000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145505, 10408, 'A Grande Conquista S02 E67', 'http://sinalprivado.info:80/series/1533784/1533784/400001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145506, 10408, 'A Grande Conquista S02 E68', 'http://sinalprivado.info:80/series/1533784/1533784/400002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145507, 10408, 'A Grande Conquista S02 E69', 'http://sinalprivado.info:80/series/1533784/1533784/400003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145508, 10408, 'A Grande Conquista S02 E70', 'http://sinalprivado.info:80/series/1533784/1533784/400004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145509, 10408, 'A Grande Conquista S02 E71', 'http://sinalprivado.info:80/series/1533784/1533784/400005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145510, 10408, 'A Grande Conquista S02 E72', 'http://sinalprivado.info:80/series/1533784/1533784/400006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145511, 10408, 'A Grande Conquista S02 E73', 'http://sinalprivado.info:80/series/1533784/1533784/400007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145512, 10408, 'A Grande Conquista S02 E74', 'http://sinalprivado.info:80/series/1533784/1533784/403853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145513, 10408, 'A Grande Conquista S02 E75', 'http://sinalprivado.info:80/series/1533784/1533784/403854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145514, 10408, 'A Grande Conquista S02 E76', 'http://sinalprivado.info:80/series/1533784/1533784/403855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145515, 10408, 'A Grande Conquista S02 E77', 'http://sinalprivado.info:80/series/1533784/1533784/403856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145516, 10408, 'A Grande Conquista S02 E78', 'http://sinalprivado.info:80/series/1533784/1533784/405529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145517, 10408, 'A Grande Conquista S02 E79', 'http://sinalprivado.info:80/series/1533784/1533784/405530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145518, 10408, 'A Grande Conquista S02 E80', 'http://sinalprivado.info:80/series/1533784/1533784/406579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145519, 10408, 'A Grande Conquista S02 E81', 'http://sinalprivado.info:80/series/1533784/1533784/409803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145520, 10408, 'A Grande Conquista S02 E82', 'http://sinalprivado.info:80/series/1533784/1533784/409804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145521, 10408, 'A Grande Conquista S02 E83', 'http://sinalprivado.info:80/series/1533784/1533784/409805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145522, 10408, 'A Grande Conquista S02 E84', 'http://sinalprivado.info:80/series/1533784/1533784/409806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145523, 10408, 'A Grande Conquista S02 E85', 'http://sinalprivado.info:80/series/1533784/1533784/413473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145524, 10408, 'A Grande Conquista S02 E86', 'http://sinalprivado.info:80/series/1533784/1533784/413474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145525, 10408, 'A Grande Conquista S02 E87', 'http://sinalprivado.info:80/series/1533784/1533784/413475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145526, 10408, 'A Grande Conquista S02 E88', 'http://sinalprivado.info:80/series/1533784/1533784/416212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9gW7j6XQBQC51C1FKks1q73e7zl.jpg'),
(145527, 10409, 'A Persistencia da Memoria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/334703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6sirrTgls3GIDU8RTeeWm2uuuR.jpg'),
(145528, 10409, 'A Persistencia da Memoria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/334704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6sirrTgls3GIDU8RTeeWm2uuuR.jpg'),
(145529, 10409, 'A Persistencia da Memoria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/334705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6sirrTgls3GIDU8RTeeWm2uuuR.jpg'),
(145530, 10409, 'A Persistencia da Memoria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/334706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6sirrTgls3GIDU8RTeeWm2uuuR.jpg'),
(145531, 10409, 'A Persistencia da Memoria S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/334707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6sirrTgls3GIDU8RTeeWm2uuuR.jpg'),
(145532, 10409, 'A Persistencia da Memoria S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/334708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6sirrTgls3GIDU8RTeeWm2uuuR.jpg'),
(145533, 10409, 'A Persistencia da Memoria S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/334709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6sirrTgls3GIDU8RTeeWm2uuuR.jpg'),
(145534, 10409, 'A Persistencia da Memoria S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/334710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6sirrTgls3GIDU8RTeeWm2uuuR.jpg'),
(145535, 10409, 'A Persistencia da Memoria S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/334711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6sirrTgls3GIDU8RTeeWm2uuuR.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(145536, 10409, 'A Persistencia da Memoria S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/334712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6sirrTgls3GIDU8RTeeWm2uuuR.jpg'),
(145537, 10409, 'A Persistencia da Memoria S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/334713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6sirrTgls3GIDU8RTeeWm2uuuR.jpg'),
(145538, 10409, 'A Persistencia da Memoria S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/334714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6sirrTgls3GIDU8RTeeWm2uuuR.jpg'),
(145539, 10409, 'A Persistencia da Memoria S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/334715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p6sirrTgls3GIDU8RTeeWm2uuuR.jpg'),
(145540, 10410, 'Love e Translation S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/334702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8WKi13VqHUb2amlaHdgAnn9MoKz.jpg'),
(145541, 10410, 'Love e Translation S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/338539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c7wMfUUNiJI638YfpfK0F4hR6L8.jpg'),
(145542, 10410, 'Love e Translation S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/345128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c7wMfUUNiJI638YfpfK0F4hR6L8.jpg'),
(145543, 10410, 'Love e Translation S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/368034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c7wMfUUNiJI638YfpfK0F4hR6L8.jpg'),
(145544, 10410, 'Love e Translation S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/368035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c7wMfUUNiJI638YfpfK0F4hR6L8.jpg'),
(145545, 10410, 'Love e Translation S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/368036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c7wMfUUNiJI638YfpfK0F4hR6L8.jpg'),
(145546, 10410, 'Love e Translation S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/373948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c7wMfUUNiJI638YfpfK0F4hR6L8.jpg'),
(145547, 10411, 'Na Rota do Ouro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/334696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5z4KsRs3dKz15q9rO9WIch25CIC.jpg'),
(145548, 10411, 'Na Rota do Ouro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/334697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6btlBOFqwEDgkP55oe2UXNuXdKP.jpg'),
(145549, 10411, 'Na Rota do Ouro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/334698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/huQRqGvMvcZUQwj22wxpdYg128Q.jpg'),
(145550, 10411, 'Na Rota do Ouro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/334699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mj8Q60SDaVRKJDwY0gCzKB3MSwg.jpg'),
(145551, 10411, 'Na Rota do Ouro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/334700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ds1fPbj8Bfyk7F025mUovoEEN01.jpg'),
(145552, 10411, 'Na Rota do Ouro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/334701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a03iNcGDqIEhc0J8COXZLOhsMKD.jpg'),
(145553, 10412, 'Entre a Amizade e o Amor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/334411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ycU5Ucx6pBz4GaAzdlPo3pNoeRI.jpg'),
(145554, 10412, 'Entre a Amizade e o Amor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/334412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ycU5Ucx6pBz4GaAzdlPo3pNoeRI.jpg'),
(145555, 10412, 'Entre a Amizade e o Amor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/360346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ycU5Ucx6pBz4GaAzdlPo3pNoeRI.jpg'),
(145556, 10412, 'Entre a Amizade e o Amor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/360347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ycU5Ucx6pBz4GaAzdlPo3pNoeRI.jpg'),
(145557, 10412, 'Entre a Amizade e o Amor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/360348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ycU5Ucx6pBz4GaAzdlPo3pNoeRI.jpg'),
(145558, 10412, 'Entre a Amizade e o Amor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/360349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ycU5Ucx6pBz4GaAzdlPo3pNoeRI.jpg'),
(145559, 10412, 'Entre a Amizade e o Amor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/360350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ycU5Ucx6pBz4GaAzdlPo3pNoeRI.jpg'),
(145560, 10412, 'Entre a Amizade e o Amor [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/360351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ycU5Ucx6pBz4GaAzdlPo3pNoeRI.jpg'),
(145561, 10413, 'Ciao House A Competicao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/334403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/scymlJX3hs6dLDAinRQDpZqjdVI.jpg'),
(145562, 10413, 'Ciao House A Competicao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/334404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/scymlJX3hs6dLDAinRQDpZqjdVI.jpg'),
(145563, 10413, 'Ciao House A Competicao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/334405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/scymlJX3hs6dLDAinRQDpZqjdVI.jpg'),
(145564, 10413, 'Ciao House A Competicao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/334406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/scymlJX3hs6dLDAinRQDpZqjdVI.jpg'),
(145565, 10413, 'Ciao House A Competicao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/334407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/scymlJX3hs6dLDAinRQDpZqjdVI.jpg'),
(145566, 10413, 'Ciao House A Competicao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/334408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/scymlJX3hs6dLDAinRQDpZqjdVI.jpg'),
(145567, 10413, 'Ciao House A Competicao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/334409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/scymlJX3hs6dLDAinRQDpZqjdVI.jpg'),
(145568, 10413, 'Ciao House A Competicao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/334410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/scymlJX3hs6dLDAinRQDpZqjdVI.jpg'),
(145569, 10414, 'Garotos Detetives Mortos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/334395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dmJbAJvE9CirMdg5bgh7ELdD3gp.jpg'),
(145570, 10414, 'Garotos Detetives Mortos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/334396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/GyoFHEEf0t2DTtxc2YBIh7eRkE.jpg'),
(145571, 10414, 'Garotos Detetives Mortos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/334397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yPRLW4yLuzN0GdT8oFDt3bDXdnL.jpg'),
(145572, 10414, 'Garotos Detetives Mortos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/334398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h6NT7wkujEe8ckDRqgt5OFTe2de.jpg'),
(145573, 10414, 'Garotos Detetives Mortos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/334399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mK04zxeVofAmoLz37iWuGm8PdH6.jpg'),
(145574, 10414, 'Garotos Detetives Mortos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/334400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hECDyaE3K7sfBwnFVb4SGmzT9vT.jpg'),
(145575, 10414, 'Garotos Detetives Mortos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/334401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ck71aRloYHvIdjRUj9xnImDE6FG.jpg'),
(145576, 10414, 'Garotos Detetives Mortos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/334402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zvQDCJSxhY1huUWFxQLnNz8t3mH.jpg'),
(145577, 10415, 'House of the Owl [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/334390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a9KG6KLHQYdsW8sM8zpto4myGow.jpg'),
(145578, 10415, 'House of the Owl [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/334391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gOxajZ6RVHbKOCJDRLHeR0cayts.jpg'),
(145579, 10415, 'House of the Owl [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/334392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kYK2xYlBt9R3MFCYV4BNHB8WRGO.jpg'),
(145580, 10415, 'House of the Owl [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/334393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w6zBpFliqr7y6lddmtXcrcYE1ZA.jpg'),
(145581, 10415, 'House of the Owl [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/334394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAfYTAdMNmBp5LRhP2sLpeNGHzK.jpg'),
(145582, 10415, 'House of the Owl [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/359636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b54fBL4omH49jUH1Vu7rXRDPsYd.jpg'),
(145583, 10415, 'House of the Owl [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/359637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b54fBL4omH49jUH1Vu7rXRDPsYd.jpg'),
(145584, 10416, 'Infancia Interrompida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/334385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p4U4u0RPWlhRCGoEjwP1vr84QYK.jpg'),
(145585, 10416, 'Infancia Interrompida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/334386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Q87LlbWhXe8uwMMmJpbtL49gQD.jpg'),
(145586, 10416, 'Infancia Interrompida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/334387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p4djYMFYupvAz9yd8N5cqU4Jtyw.jpg'),
(145587, 10416, 'Infancia Interrompida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/334388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iwtbcZ60DDtQQXgKielUzXfU5bH.jpg'),
(145588, 10416, 'Infancia Interrompida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/334389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3zVQ1ZEfkjl0cjVjQd7sWrQHFKY.jpg'),
(145589, 10417, 'Knuckles S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/334379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oavAE9ENSwFXswiO5FozUREftzG.jpg'),
(145590, 10417, 'Knuckles S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/334380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jV11mJfDdJOwMokzVyGHyjBFeiA.jpg'),
(145591, 10417, 'Knuckles S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/334381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vNZH7P192kBz7sBXWch4JnRApkA.jpg'),
(145592, 10417, 'Knuckles S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/334382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xItrifyZP2S1XDTnaPMZuzVmhg.jpg'),
(145593, 10417, 'Knuckles S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/334383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/toxeVznzxqSDZPCtueUEGoR9gNE.jpg'),
(145594, 10417, 'Knuckles S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/334384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8iFLLPhylhAkr91y3FJxWAzpH6V.jpg'),
(145595, 10418, 'Mil Maneiras de Morrer [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/334313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/scJnnvVKfUDCxT8YPdrIW2mTSQ9.jpg'),
(145596, 10418, 'Mil Maneiras de Morrer [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/334314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pB1JAk7GbNsD9DsHXfuUJpNztYb.jpg'),
(145597, 10418, 'Mil Maneiras de Morrer [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/334315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1HhKO8CmvL1kmbQOZSqQdOsqlXN.jpg'),
(145598, 10418, 'Mil Maneiras de Morrer [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/334316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kGGqbXCGUciIyDmD8LDgs4lmvOF.jpg'),
(145599, 10418, 'Mil Maneiras de Morrer [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/334317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tkLIG7uy1v0bBvIfYwjqNVGIGoc.jpg'),
(145600, 10418, 'Mil Maneiras de Morrer [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/334318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/urpjxkYr92PP5LfAXJnaoM9sYF2.jpg'),
(145601, 10418, 'Mil Maneiras de Morrer [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/334319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r0O2sD7u6frVwV4DkfLd90NN7lX.jpg'),
(145602, 10418, 'Mil Maneiras de Morrer [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/334320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3aw8VJxJsFCqI3mxr2vGj3WxYZv.jpg'),
(145603, 10418, 'Mil Maneiras de Morrer [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/334321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cz7yikU80oUtft9FIZMVKvx0Gjh.jpg'),
(145604, 10418, 'Mil Maneiras de Morrer [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/334322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hOXM7OtmeFDWtZgpyC2bUI6xUUY.jpg'),
(145605, 10418, 'Mil Maneiras de Morrer [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/334323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145606, 10418, 'Mil Maneiras de Morrer [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/334324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145607, 10419, 'Mil Maneiras de Morrer [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/334325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ir7oK5oLYPwner0RuD8htCF60O.jpg'),
(145608, 10419, 'Mil Maneiras de Morrer [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/334326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gWpwzG0ILwVsC3NVYdJgcV7usZL.jpg'),
(145609, 10419, 'Mil Maneiras de Morrer [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/334327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s28blXWGJZWjOBUOOpek5suGxwC.jpg'),
(145610, 10419, 'Mil Maneiras de Morrer [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/334328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eGsCepzIBs6rLvt88P9oUA8BEHu.jpg'),
(145611, 10419, 'Mil Maneiras de Morrer [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/334329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zDdf8jyrbLTB7kwKyyRi7S0YyVt.jpg'),
(145612, 10419, 'Mil Maneiras de Morrer [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/334330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bfOHs1R8gPCKaa6Y00Cb9Wn063H.jpg'),
(145613, 10419, 'Mil Maneiras de Morrer [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/334331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j029KdtzrUHStR7cObgHd2vxLuT.jpg'),
(145614, 10419, 'Mil Maneiras de Morrer [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/334332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgsZfpK7uzQRg8rMrKFiWg0sedT.jpg'),
(145615, 10419, 'Mil Maneiras de Morrer [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/334333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fsSCg3BiGVmDC4yuYAyOVhlHGKc.jpg'),
(145616, 10419, 'Mil Maneiras de Morrer [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/334334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gf0I40LXjtVRSt1PJ0ZFkCTcDAI.jpg'),
(145617, 10419, 'Mil Maneiras de Morrer [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/334335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNhwqFOZ11yLVluaVajqgfIq3ld.jpg'),
(145618, 10419, 'Mil Maneiras de Morrer [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/334336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/93NPBOoQbNyadbVqCpWG5SZi5um.jpg'),
(145619, 10420, 'Mil Maneiras de Morrer [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/334337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rz3LyvmHE5124VdmS6Hw7BujqJB.jpg'),
(145620, 10420, 'Mil Maneiras de Morrer [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/334338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wytt0AsJaCaBrEckcJqMDY5BgAM.jpg'),
(145621, 10420, 'Mil Maneiras de Morrer [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/334339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yrusv40INqVley1muDGihAgYe56.jpg'),
(145622, 10420, 'Mil Maneiras de Morrer [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/334340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4QSfed8Jb21KoUEDlza3K3TC4Id.jpg'),
(145623, 10420, 'Mil Maneiras de Morrer [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/334341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gOH2jSndesomsyZPhhawYrynDdI.jpg'),
(145624, 10420, 'Mil Maneiras de Morrer [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/334342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nfl5SD9zWZmEH8moOjntJEavsLK.jpg'),
(145625, 10420, 'Mil Maneiras de Morrer [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/334343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFxNzyLrp2XYSeu4K3JY2UYx1l1.jpg'),
(145626, 10420, 'Mil Maneiras de Morrer [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/334344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2FrZ2b2dfSsQIEabs8FNqZbqO1p.jpg'),
(145627, 10420, 'Mil Maneiras de Morrer [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/334345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QdfZL5U1YKBD9AZ9MlPg1Ao3yS.jpg'),
(145628, 10420, 'Mil Maneiras de Morrer [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/334346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j0O6ukwCjdZTulpbJ9ScURhIR55.jpg'),
(145629, 10420, 'Mil Maneiras de Morrer [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/334347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cwFdq7sWgakjefO1Nj32SPEG2c.jpg'),
(145630, 10420, 'Mil Maneiras de Morrer [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/334348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pYG717iwf5ZVSbTCAquGkUxbro6.jpg'),
(145631, 10420, 'Mil Maneiras de Morrer [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/334349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n73ofPxkvnmpjjhNErQXkvsKi0x.jpg'),
(145632, 10420, 'Mil Maneiras de Morrer [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/334350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fq4TRocDn2wMtBIHpeqdvQqNte7.jpg'),
(145633, 10421, 'Mil Maneiras de Morrer [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/334351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145634, 10421, 'Mil Maneiras de Morrer [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/334352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145635, 10421, 'Mil Maneiras de Morrer [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/334353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145636, 10421, 'Mil Maneiras de Morrer [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/334354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145637, 10421, 'Mil Maneiras de Morrer [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/334355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145638, 10421, 'Mil Maneiras de Morrer [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/334356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145639, 10421, 'Mil Maneiras de Morrer [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/334357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145640, 10421, 'Mil Maneiras de Morrer [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/334358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145641, 10421, 'Mil Maneiras de Morrer [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/334359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145642, 10421, 'Mil Maneiras de Morrer [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/334360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145643, 10421, 'Mil Maneiras de Morrer [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/334361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145644, 10421, 'Mil Maneiras de Morrer [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/334362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145645, 10421, 'Mil Maneiras de Morrer [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/334363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145646, 10421, 'Mil Maneiras de Morrer [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/334364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145647, 10421, 'Mil Maneiras de Morrer [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/334365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145648, 10421, 'Mil Maneiras de Morrer [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/334366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145649, 10422, 'Mil Maneiras de Morrer [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/334367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145650, 10422, 'Mil Maneiras de Morrer [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/334368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145651, 10422, 'Mil Maneiras de Morrer [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/334369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145652, 10422, 'Mil Maneiras de Morrer [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/334370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145653, 10422, 'Mil Maneiras de Morrer [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/334371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145654, 10422, 'Mil Maneiras de Morrer [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/334372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145655, 10422, 'Mil Maneiras de Morrer [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/334373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145656, 10422, 'Mil Maneiras de Morrer [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/334374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145657, 10422, 'Mil Maneiras de Morrer [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/334375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145658, 10422, 'Mil Maneiras de Morrer [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/334376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145659, 10422, 'Mil Maneiras de Morrer [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/334377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145660, 10422, 'Mil Maneiras de Morrer [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/334378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yKZYX4D30R7ywy6f5yQDuXagSCr.jpg'),
(145661, 10423, 'Reforma Inspirada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/334306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qXW4Vhut1Ob0VqnYopmVT5dK3gn.jpg'),
(145662, 10423, 'Reforma Inspirada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/334307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qXW4Vhut1Ob0VqnYopmVT5dK3gn.jpg'),
(145663, 10423, 'Reforma Inspirada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/334308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qXW4Vhut1Ob0VqnYopmVT5dK3gn.jpg'),
(145664, 10423, 'Reforma Inspirada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/334309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qXW4Vhut1Ob0VqnYopmVT5dK3gn.jpg'),
(145665, 10423, 'Reforma Inspirada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/334310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qXW4Vhut1Ob0VqnYopmVT5dK3gn.jpg'),
(145666, 10423, 'Reforma Inspirada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/334311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qXW4Vhut1Ob0VqnYopmVT5dK3gn.jpg'),
(145667, 10423, 'Reforma Inspirada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/334312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qXW4Vhut1Ob0VqnYopmVT5dK3gn.jpg'),
(145668, 10424, 'The Chi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/335032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cwOxSUuhUPJKDM0ZprEzBNZtrqc.jpg'),
(145669, 10424, 'The Chi S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/335033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gv8Mjy61ZjQzaTyAPUZg0jbB6He.jpg'),
(145670, 10424, 'The Chi S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/335034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g89W5Y9q7XFtHwVLhydGmy2Mr8o.jpg'),
(145671, 10424, 'The Chi S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/335035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ydVsxPniQQ7QjDGuNKgD4LYID.jpg'),
(145672, 10424, 'The Chi S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/335036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AbjLhRLcSnLHrb0e5KKhqfacn5h.jpg'),
(145673, 10424, 'The Chi S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/335037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6drT9Y7wwhTQrOMHcObH381z7At.jpg'),
(145674, 10424, 'The Chi S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/335038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAMj0eQPasWCpaoG20cIQBGfNzr.jpg'),
(145675, 10424, 'The Chi S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/335039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fGRil8F95eqjzJk0J5RlQo22BU.jpg'),
(145676, 10424, 'The Chi S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/335040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ov8PYIPTqaby8hlfBiotiyCTkWj.jpg'),
(145677, 10424, 'The Chi S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/335041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uxpfI3BtjeVntsooSjxh1OfqWDe.jpg'),
(145678, 10425, 'Adeus Terra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/334722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zK7inGe7UFIt2ikH37BDUjb4cEw.jpg'),
(145679, 10425, 'Adeus Terra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/334723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5HkFSVoYDv0Pwr1R7vTTeZzT3x8.jpg'),
(145680, 10425, 'Adeus Terra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/334724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/57b0NFbrcCFH9CcptAi6QZtTebe.jpg'),
(145681, 10425, 'Adeus Terra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/334725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udfUzxaldoT4h2VZHDoKqoWkj9R.jpg'),
(145682, 10425, 'Adeus Terra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/334726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h5uyr3gg1dgYct4HzGuVNq4Trgf.jpg'),
(145683, 10425, 'Adeus Terra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/334727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yCEL3HOQucX6RD6y6oFZpQ4Xalz.jpg'),
(145684, 10425, 'Adeus Terra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/334728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/acuqN2KHKJnSpPO2cPVT7JyhpU9.jpg'),
(145685, 10425, 'Adeus Terra S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/334729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r5Ff3OFVQYDgtZvRD6brJL2tHQy.jpg'),
(145686, 10425, 'Adeus Terra S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/334730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/558vs3VONhe7wtjSyp9mewZTHuN.jpg'),
(145687, 10425, 'Adeus Terra S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/334731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j7e0qj33XfFkWJVtP7wbEirL2Z3.jpg'),
(145688, 10425, 'Adeus Terra S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/334732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kw0wI2fX2vykXWUkWNINEf0uti5.jpg'),
(145689, 10425, 'Adeus Terra S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/334733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/za7ViFmOY0WslGhLZ75POWfIuJn.jpg'),
(145690, 10426, 'Franklin [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/334717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyHTAPQqGJEOjuqHHDiqxDw56hO.jpg'),
(145691, 10426, 'Franklin [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/334718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tDXrjmwWrRrwVx0W3H2k3Klozua.jpg'),
(145692, 10426, 'Franklin [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/334719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/apfr8EstPNZI94mCxT94oo7vzmt.jpg'),
(145693, 10426, 'Franklin [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/334720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSUrpqKo0ZvqhmZqTktsxrNojUI.jpg'),
(145694, 10426, 'Franklin [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/334721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3HSkvh91a4gcx1sAKuOM2vsXygE.jpg'),
(145695, 10426, 'Franklin [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/345322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a9YV5QCdg95Zp02rKzkVxLxDtUC.jpg'),
(145696, 10426, 'Franklin [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/352231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a9YV5QCdg95Zp02rKzkVxLxDtUC.jpg'),
(145697, 10426, 'Franklin [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/352232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a9YV5QCdg95Zp02rKzkVxLxDtUC.jpg'),
(145698, 10427, 'Viagem ao Fundo do Mar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/339278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/izRDmWH03EttKmNNSJdjWZdd9b9.jpg'),
(145699, 10427, 'Viagem ao Fundo do Mar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/339279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5VozLqQqqQuYM0oASc0ShS1i3aB.jpg'),
(145700, 10427, 'Viagem ao Fundo do Mar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/339280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fMlqmdZealxBbzToYSzlCYCDSdE.jpg'),
(145701, 10427, 'Viagem ao Fundo do Mar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/339281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/33RDup63pSY7ZiGyGo4ayallWV2.jpg'),
(145702, 10427, 'Viagem ao Fundo do Mar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/339282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7BPpGF7s7SiQKsvuCIz8VN648gt.jpg'),
(145703, 10427, 'Viagem ao Fundo do Mar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/339283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cHXdsFqzOL6YTEJiFrZCTr8IaP5.jpg'),
(145704, 10427, 'Viagem ao Fundo do Mar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/339284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/87n74FyC6QEiuYJINQOwaZnBKn9.jpg'),
(145705, 10427, 'Viagem ao Fundo do Mar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/339285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d0EWz8NzcMddNC8KwEpBKV2iblZ.jpg'),
(145706, 10427, 'Viagem ao Fundo do Mar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/339286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/16PDEJjZK8mGHCgRJqZqyW2Qyo0.jpg'),
(145707, 10427, 'Viagem ao Fundo do Mar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/339287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qVN3S5edTV0kUOR4UNgFHfJ2I2E.jpg'),
(145708, 10427, 'Viagem ao Fundo do Mar S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/339288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1KuRp0H0POBTJVyJDnAcO8PsyZI.jpg'),
(145709, 10427, 'Viagem ao Fundo do Mar S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/339289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bEBDxKwM7gaqxDs9wBJLCqIRW7S.jpg'),
(145710, 10427, 'Viagem ao Fundo do Mar S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/339290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1IyzyJqa4H3eN7qyfqWW4fu1HJt.jpg'),
(145711, 10427, 'Viagem ao Fundo do Mar S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/339291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lg7JKu5mBQ3OWBhtCTvft6k21lH.jpg'),
(145712, 10427, 'Viagem ao Fundo do Mar S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/339292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNX65USodlt1TBmKKsuM1OWmJVk.jpg'),
(145713, 10427, 'Viagem ao Fundo do Mar S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/339293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dA7XcWJhmErzH1X9CLKKtj0DOES.jpg'),
(145714, 10427, 'Viagem ao Fundo do Mar S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/339294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/coRmJF4NTl18mcYN89fHjXNp7US.jpg'),
(145715, 10427, 'Viagem ao Fundo do Mar S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/339295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oixWwEYfG5DN1wneJps5qhr1kcY.jpg'),
(145716, 10427, 'Viagem ao Fundo do Mar S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/339296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ue0CnyVnou5DB9gqrOlc88yXfMu.jpg'),
(145717, 10427, 'Viagem ao Fundo do Mar S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/339297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ccEBFxGNYqQoUeXhnZZhUxC7iub.jpg'),
(145718, 10427, 'Viagem ao Fundo do Mar S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/339298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/84u2EHYjJ3oIBwYNWkMUR1l1nvH.jpg'),
(145719, 10427, 'Viagem ao Fundo do Mar S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/339299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y1yPEGdjKmDqNrpV5bGLBlr15zV.jpg'),
(145720, 10427, 'Viagem ao Fundo do Mar S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/339300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pXIfMrigezRPiRX26fpEOjbOyYI.jpg'),
(145721, 10427, 'Viagem ao Fundo do Mar S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/339301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7j2kiuv5s0tVAJbydYc3CXTo7XF.jpg'),
(145722, 10427, 'Viagem ao Fundo do Mar S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/339302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qjvnPqi7HNiNrm3vF69LswXgb7c.jpg'),
(145723, 10427, 'Viagem ao Fundo do Mar S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/339303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kAWShtD6ySWMbJivSSzXWp2ZROF.jpg'),
(145724, 10427, 'Viagem ao Fundo do Mar S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/339304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8JGxNB8kw8zYFaHRl6glf4m4OGc.jpg'),
(145725, 10427, 'Viagem ao Fundo do Mar S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/339305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3950Rc8KZfcfmadptYL0eNBsCbZ.jpg'),
(145726, 10427, 'Viagem ao Fundo do Mar S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/339306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8KLWYMM0Eh32u5Q2D2O53JEFGkQ.jpg'),
(145727, 10427, 'Viagem ao Fundo do Mar S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/339307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7NjAoIb9fvylx07EKfu5LXUzHnI.jpg'),
(145728, 10427, 'Viagem ao Fundo do Mar S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/339308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bmRV1YAtPoSMdhyj1eQjWIrCzOz.jpg'),
(145729, 10427, 'Viagem ao Fundo do Mar S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/339309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1IpfBGp585PLTu17lDOD7qh29ld.jpg'),
(145730, 10428, 'Viagem ao Fundo do Mar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/339310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fS2Z1A7rG6mCETh6b7uALG9Tg1A.jpg'),
(145731, 10428, 'Viagem ao Fundo do Mar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/339311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4kV2FchTFghS6E36X0QwdcD2JiI.jpg'),
(145732, 10428, 'Viagem ao Fundo do Mar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/339312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u9MOfPCGAdbSlT3ISKTK2zgP0ox.jpg'),
(145733, 10428, 'Viagem ao Fundo do Mar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/339313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k87WWje3EUTtU2tfCF19u2ofQhf.jpg'),
(145734, 10428, 'Viagem ao Fundo do Mar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/339314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fcmKzL87x0fJ4teUTM0xwThzJl0.jpg'),
(145735, 10428, 'Viagem ao Fundo do Mar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/339315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ycmRq5H8c1zh3bx8Kdg2iF7eOge.jpg'),
(145736, 10428, 'Viagem ao Fundo do Mar S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/339316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ioVZbiT0vuC9PquvLcSvzINafh7.jpg'),
(145737, 10428, 'Viagem ao Fundo do Mar S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/339317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pbDbmtFiRN0BcSfwTeuxnEcR47D.jpg'),
(145738, 10428, 'Viagem ao Fundo do Mar S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/339318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Wn1EKLlOR05YKAo2xZB1WO3XgH.jpg'),
(145739, 10428, 'Viagem ao Fundo do Mar S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/339319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xAAyT2N9tuX5zpzx29WhuKsbHjA.jpg'),
(145740, 10428, 'Viagem ao Fundo do Mar S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/339320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gHMQglRbsLHII0QApyh0ubm9L2G.jpg'),
(145741, 10428, 'Viagem ao Fundo do Mar S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/339321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y2H2eXLD1HZ5XCl2MLkL38CR4Wc.jpg'),
(145742, 10428, 'Viagem ao Fundo do Mar S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/339322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ouMS7Ectk6X6S9GF4I5OZeZE6hx.jpg'),
(145743, 10428, 'Viagem ao Fundo do Mar S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/339323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7abZGZZcvs3A14U19CRs9nuKE4b.jpg'),
(145744, 10428, 'Viagem ao Fundo do Mar S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/339324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7dwyQk4PnQKvehtHh9rd8mtzz3s.jpg'),
(145745, 10428, 'Viagem ao Fundo do Mar S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/339325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kLnFJmtgp7i9kf7gd0EnQNTD4h.jpg'),
(145746, 10428, 'Viagem ao Fundo do Mar S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/339326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ixino44javRTFQtIcG74stdMx8H.jpg'),
(145747, 10428, 'Viagem ao Fundo do Mar S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/339327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8jiC0wtsft6RGsCpYs3yOh43AaF.jpg'),
(145748, 10428, 'Viagem ao Fundo do Mar S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/339328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8aOcnh9x7fp1XLD6JVbvjEDhRgc.jpg'),
(145749, 10428, 'Viagem ao Fundo do Mar S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/339329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hYOJVQ8w8w9wi7NmYJrj7kVCi6T.jpg'),
(145750, 10428, 'Viagem ao Fundo do Mar S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/339330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ycFpCrTpJCldS2EcaE8dvAmJoVD.jpg'),
(145751, 10428, 'Viagem ao Fundo do Mar S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/339331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9rvOx7EGhMgidEv4iuJDM3XBdCM.jpg'),
(145752, 10428, 'Viagem ao Fundo do Mar S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/339332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhVO7XVNsdeMwQ1oaIwgpmhJldO.jpg'),
(145753, 10428, 'Viagem ao Fundo do Mar S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/339333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6TmGXhVEWAiozJO7l6Dsmt3vni.jpg'),
(145754, 10428, 'Viagem ao Fundo do Mar S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/339334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8DUIejj7dooghHWvPWiorEgA6Zr.jpg'),
(145755, 10428, 'Viagem ao Fundo do Mar S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/339335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xIAmvIMCAVzV6ObpADr9v7Fh3Kk.jpg'),
(145756, 10429, 'Viagem ao Fundo do Mar S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/339336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/obZGEqhTM2tgFsQFLeYPOsYVIkm.jpg'),
(145757, 10429, 'Viagem ao Fundo do Mar S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/339337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tDMFlaqdv6boTbFsMrtSydtdvsd.jpg'),
(145758, 10429, 'Viagem ao Fundo do Mar S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/339338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nu4SkkUeucVzLAbXk0hGyQ9NzB3.jpg'),
(145759, 10429, 'Viagem ao Fundo do Mar S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/339339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s9Dx9lwDDBZRk0r2QaIGaOi2Pu3.jpg'),
(145760, 10429, 'Viagem ao Fundo do Mar S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/339340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w1tPMDE5djydIK1SSff4Qx2pYj6.jpg'),
(145761, 10429, 'Viagem ao Fundo do Mar S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/339341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3dUiGQfhPGIIBjmkVrTmd51GoAx.jpg'),
(145762, 10429, 'Viagem ao Fundo do Mar S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/339342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5TYBIy738kvj5rfaV2gUABIpQcx.jpg'),
(145763, 10429, 'Viagem ao Fundo do Mar S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/339343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jUXWxg5ycR4Up2TSmvlc3DYkvpr.jpg'),
(145764, 10429, 'Viagem ao Fundo do Mar S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/339344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZUq2PYAcBL13l5pAjFRhDiZVZk.jpg'),
(145765, 10429, 'Viagem ao Fundo do Mar S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/339345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ZFl22u5Tpy9GE2oHYRgomMPH34.jpg'),
(145766, 10429, 'Viagem ao Fundo do Mar S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/339346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDf6lH9EQgA2OeBjq3BZWqUbKmp.jpg'),
(145767, 10429, 'Viagem ao Fundo do Mar S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/339347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gc8lXjQZtAbfpZUsauRlJGYpEY1.jpg'),
(145768, 10429, 'Viagem ao Fundo do Mar S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/339348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eocrfA5xmKWQeXujZ0pKG0FJcpK.jpg'),
(145769, 10429, 'Viagem ao Fundo do Mar S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/339349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AmvI4loRBj64y1rLPvYbQV7LJag.jpg'),
(145770, 10429, 'Viagem ao Fundo do Mar S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/339350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lZek4rLlFguEpivbkOY8vgpzobo.jpg'),
(145771, 10429, 'Viagem ao Fundo do Mar S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/339351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l8FDQmJjeMDrxv06erxlDSIEqJA.jpg'),
(145772, 10429, 'Viagem ao Fundo do Mar S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/339352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4xcRLvnZ9kXEB7yP4SSKZqQNZ2J.jpg'),
(145773, 10429, 'Viagem ao Fundo do Mar S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/339353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kkPaz3uBrzPsFSj7Oj27Gb1eFFo.jpg'),
(145774, 10429, 'Viagem ao Fundo do Mar S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/339354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2NEoXHN2tRmw2nKbaRZBErb8m2D.jpg'),
(145775, 10429, 'Viagem ao Fundo do Mar S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/339355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gs8t1O6JoUd1u99HqW6Rui71AsZ.jpg'),
(145776, 10429, 'Viagem ao Fundo do Mar S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/339356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pdCyH59NBxyPNpABAafg1Nm6rav.jpg'),
(145777, 10429, 'Viagem ao Fundo do Mar S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/339357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fGuT7ABrNKOb1kCF8gXxrhsxv0E.jpg'),
(145778, 10429, 'Viagem ao Fundo do Mar S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/339358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sAo8HEPNfVbsKriTMohazGVZdBw.jpg'),
(145779, 10429, 'Viagem ao Fundo do Mar S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/339359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zxNBTFy8I9zhFrRVHe9n8FfDLcA.jpg'),
(145780, 10429, 'Viagem ao Fundo do Mar S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/339360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dIK1sa76yKGCGMaMRNEkMebq0sL.jpg'),
(145781, 10429, 'Viagem ao Fundo do Mar S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/339361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zaem8PEAJ81IxNcJBVQux4vRWsq.jpg'),
(145782, 10430, 'Viagem ao Fundo do Mar S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/339362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Bf912rq93v5d5izeUYmMK1i6Sk.jpg'),
(145783, 10430, 'Viagem ao Fundo do Mar S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/339363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vVaAAMVfjd42hFwP8upbx3GQmil.jpg'),
(145784, 10430, 'Viagem ao Fundo do Mar S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/339364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jjtvsMD9dL53WO57oR20btFHSwS.jpg'),
(145785, 10430, 'Viagem ao Fundo do Mar S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/339365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Jb3v6ACaB0FJCUY6QqlT5Y3jCd.jpg'),
(145786, 10430, 'Viagem ao Fundo do Mar S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/339366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fh9SsLm6EcYujIgnCbgtqDWbpqp.jpg'),
(145787, 10430, 'Viagem ao Fundo do Mar S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/339367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/srS3tNjbCnbuKbuXIeEKpihtjD5.jpg'),
(145788, 10430, 'Viagem ao Fundo do Mar S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/339368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jRFSriKIaQUTi2LkUf2ujp63svf.jpg'),
(145789, 10430, 'Viagem ao Fundo do Mar S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/339369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hnXIY31QMOMH3xGR9fPp2HSDjfE.jpg'),
(145790, 10430, 'Viagem ao Fundo do Mar S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/339370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dfpRU0GFfuwgpmiqlTdrey11s4E.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(145791, 10430, 'Viagem ao Fundo do Mar S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/339371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/17MNHSzflIgKSWkxAvicygJGHJ5.jpg'),
(145792, 10430, 'Viagem ao Fundo do Mar S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/339372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zL8NdGFUe1zBpOpKqJPaOHwZFQQ.jpg'),
(145793, 10430, 'Viagem ao Fundo do Mar S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/339373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ngUfqvnVQ2gywG4hdmI1otXvPzX.jpg'),
(145794, 10430, 'Viagem ao Fundo do Mar S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/339374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/51XKXS2WGVTsIl4wDHSIjgJ5kxz.jpg'),
(145795, 10430, 'Viagem ao Fundo do Mar S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/339375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4McbJpoWhGH0ug8CB2QapHEZy2K.jpg'),
(145796, 10430, 'Viagem ao Fundo do Mar S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/339376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mT6Nw2H4L9C23xDBLdviAFQZ3oK.jpg'),
(145797, 10430, 'Viagem ao Fundo do Mar S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/339377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1fUPUBYiGKRs44qO5XwzcUHHUR.jpg'),
(145798, 10430, 'Viagem ao Fundo do Mar S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/339378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v98fCfJo11yMrePyifw3yZmMSWG.jpg'),
(145799, 10430, 'Viagem ao Fundo do Mar S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/339379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hCud45VDkpKkSZ7lxf3nbcVU0tZ.jpg'),
(145800, 10430, 'Viagem ao Fundo do Mar S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/339380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pSN3XlUHwLnORytP3IUvCgCMOUV.jpg'),
(145801, 10430, 'Viagem ao Fundo do Mar S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/339381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mUsVwGuGLm8mjPXOxRvHpJgU3xc.jpg'),
(145802, 10430, 'Viagem ao Fundo do Mar S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/339382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gGV1iSeX9u3bam46HlQ3zimUxup.jpg'),
(145803, 10430, 'Viagem ao Fundo do Mar S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/339383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tkEvN8cwelXoRsc025qBujsP7eo.jpg'),
(145804, 10430, 'Viagem ao Fundo do Mar S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/339384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zww6l70dgCicHqmgWe36MJT3zs9.jpg'),
(145805, 10430, 'Viagem ao Fundo do Mar S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/339385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wUvOvKwM9VjgUPflxHe2J3Cin6B.jpg'),
(145806, 10430, 'Viagem ao Fundo do Mar S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/339386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wg2TlFDy4PlRmbughMhJHiQVsII.jpg'),
(145807, 10430, 'Viagem ao Fundo do Mar S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/339387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5mgpRADSfNdJ432djj52yTkoZPI.jpg'),
(145808, 10431, 'A Maldicao do Triangulo das Bermudas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/342277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j0kw3safoX5LLkuwuwZoKcbbVQH.jpg'),
(145809, 10431, 'A Maldicao do Triangulo das Bermudas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/342278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w9qiMIXbxkO83FactTGLgUNBd9I.jpg'),
(145810, 10431, 'A Maldicao do Triangulo das Bermudas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/342279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iRCCMZD04Ms97gXjwcUYzoHmjou.jpg'),
(145811, 10431, 'A Maldicao do Triangulo das Bermudas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/342280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qXernMtetvcvOnOWVWfigN5GvlN.jpg'),
(145812, 10431, 'A Maldicao do Triangulo das Bermudas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/342281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5P2DSpsFvfcy0dJUv2K7MBx0prD.jpg'),
(145813, 10431, 'A Maldicao do Triangulo das Bermudas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/342282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2NcGzG7rxVZkvpLO8s74VpIACMl.jpg'),
(145814, 10432, 'A Maldicao do Triangulo das Bermudas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/437704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2HETFR0zTj13ASVM8Z9E2KHnHWR.jpg'),
(145815, 10432, 'A Maldicao do Triangulo das Bermudas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/437705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2HETFR0zTj13ASVM8Z9E2KHnHWR.jpg'),
(145816, 10432, 'A Maldicao do Triangulo das Bermudas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/437706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2HETFR0zTj13ASVM8Z9E2KHnHWR.jpg'),
(145817, 10432, 'A Maldicao do Triangulo das Bermudas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/437707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2HETFR0zTj13ASVM8Z9E2KHnHWR.jpg'),
(145818, 10432, 'A Maldicao do Triangulo das Bermudas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/437708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2HETFR0zTj13ASVM8Z9E2KHnHWR.jpg'),
(145819, 10432, 'A Maldicao do Triangulo das Bermudas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/437709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2HETFR0zTj13ASVM8Z9E2KHnHWR.jpg'),
(145820, 10432, 'A Maldicao do Triangulo das Bermudas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/437710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2HETFR0zTj13ASVM8Z9E2KHnHWR.jpg'),
(145821, 10432, 'A Maldicao do Triangulo das Bermudas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/437711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2HETFR0zTj13ASVM8Z9E2KHnHWR.jpg'),
(145822, 10432, 'A Maldicao do Triangulo das Bermudas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/437712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2HETFR0zTj13ASVM8Z9E2KHnHWR.jpg'),
(145823, 10432, 'A Maldicao do Triangulo das Bermudas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/437713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2HETFR0zTj13ASVM8Z9E2KHnHWR.jpg'),
(145824, 10432, 'A Maldicao do Triangulo das Bermudas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/437714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2HETFR0zTj13ASVM8Z9E2KHnHWR.jpg'),
(145825, 10432, 'A Maldicao do Triangulo das Bermudas S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/437715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2HETFR0zTj13ASVM8Z9E2KHnHWR.jpg'),
(145826, 10433, 'Anos 90 A Decada que Mudou o Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/342267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yxMYkyu5697ZaVGdyJRkXR8072z.jpg'),
(145827, 10433, 'Anos 90 A Decada que Mudou o Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/342268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yxMYkyu5697ZaVGdyJRkXR8072z.jpg'),
(145828, 10433, 'Anos 90 A Decada que Mudou o Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/342269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yxMYkyu5697ZaVGdyJRkXR8072z.jpg'),
(145829, 10433, 'Anos 90 A Decada que Mudou o Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/342270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yxMYkyu5697ZaVGdyJRkXR8072z.jpg'),
(145830, 10433, 'Anos 90 A Decada que Mudou o Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/342271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yxMYkyu5697ZaVGdyJRkXR8072z.jpg'),
(145831, 10433, 'Anos 90 A Decada que Mudou o Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/342272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yxMYkyu5697ZaVGdyJRkXR8072z.jpg'),
(145832, 10433, 'Anos 90 A Decada que Mudou o Mundo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/342273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yxMYkyu5697ZaVGdyJRkXR8072z.jpg'),
(145833, 10433, 'Anos 90 A Decada que Mudou o Mundo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/342274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yxMYkyu5697ZaVGdyJRkXR8072z.jpg'),
(145834, 10433, 'Anos 90 A Decada que Mudou o Mundo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/342275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yxMYkyu5697ZaVGdyJRkXR8072z.jpg'),
(145835, 10433, 'Anos 90 A Decada que Mudou o Mundo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/342276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yxMYkyu5697ZaVGdyJRkXR8072z.jpg'),
(145836, 10434, 'Fiasco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/342260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iFpMz1llv947Hcbni4L4TTQTBwS.jpg'),
(145837, 10434, 'Fiasco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/342261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ayfBIrSOw5MEXaaWkE4nyed256D.jpg'),
(145838, 10434, 'Fiasco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/342262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6k8ENoLFPTO29v45tn8SvMGBAUU.jpg'),
(145839, 10434, 'Fiasco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/342263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hXZ2XdJwTrfPvyo0b5SiMAIROCp.jpg'),
(145840, 10434, 'Fiasco S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/342264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBMNAtOsA83fEKsACq3yPNReXWr.jpg'),
(145841, 10434, 'Fiasco S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/342265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ujw3HGZq5wha8tRLkWM5AGJWVQ.jpg'),
(145842, 10434, 'Fiasco S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/342266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ol6WfWeaDwzNuwfA7RXTS7V8gCV.jpg'),
(145843, 10435, 'Inacreditavel com Dan Aykroyd S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/342256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4yNLxCSmxR9yM2rwrA2l56aWxUM.jpg'),
(145844, 10435, 'Inacreditavel com Dan Aykroyd S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/342257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sC5FHjvqS3X1k5jihXA6cgI3Roz.jpg'),
(145845, 10435, 'Inacreditavel com Dan Aykroyd S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/342258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8wNkMyK6szHSmNZ5PaTI3ydvCQc.jpg'),
(145846, 10435, 'Inacreditavel com Dan Aykroyd S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/342259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tYbuuZ5X9KrlahUZ1615MwhCYlX.jpg'),
(145847, 10435, 'Inacreditavel com Dan Aykroyd S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/352207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/41E3f9EE9MXcjtBT9frFB72T15C.jpg'),
(145848, 10435, 'Inacreditavel com Dan Aykroyd S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/352208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/41E3f9EE9MXcjtBT9frFB72T15C.jpg'),
(145849, 10435, 'Inacreditavel com Dan Aykroyd S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/360829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/41E3f9EE9MXcjtBT9frFB72T15C.jpg'),
(145850, 10435, 'Inacreditavel com Dan Aykroyd S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/360830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/41E3f9EE9MXcjtBT9frFB72T15C.jpg'),
(145851, 10435, 'Inacreditavel com Dan Aykroyd S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/377891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/41E3f9EE9MXcjtBT9frFB72T15C.jpg'),
(145852, 10435, 'Inacreditavel com Dan Aykroyd S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/377892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/41E3f9EE9MXcjtBT9frFB72T15C.jpg'),
(145853, 10436, 'Senna por Ayrton S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/342253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rKhbBrtflAaR657KCAwYHC5hYDz.jpg'),
(145854, 10436, 'Senna por Ayrton S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/342254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6LhwOhvknAulC1ubgZ6KwISZOld.jpg'),
(145855, 10436, 'Senna por Ayrton S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/342255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iTAXEJkEdsjH2vEUUQ6szsCS2KT.jpg'),
(145856, 10437, 'Um Homem por Inteiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/342247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b1HrnAAMM2ULLddjs2V4GtY7uh8.jpg'),
(145857, 10437, 'Um Homem por Inteiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/342248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b1HrnAAMM2ULLddjs2V4GtY7uh8.jpg'),
(145858, 10437, 'Um Homem por Inteiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/342249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b1HrnAAMM2ULLddjs2V4GtY7uh8.jpg'),
(145859, 10437, 'Um Homem por Inteiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/342250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b1HrnAAMM2ULLddjs2V4GtY7uh8.jpg'),
(145860, 10437, 'Um Homem por Inteiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/342251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b1HrnAAMM2ULLddjs2V4GtY7uh8.jpg'),
(145861, 10437, 'Um Homem por Inteiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/342252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b1HrnAAMM2ULLddjs2V4GtY7uh8.jpg'),
(145862, 2218, 'A Grande Familia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/601530.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hRss8PdiQEJtxC8AuWtTXcHty9o.jpg'),
(145863, 2218, 'A Grande Familia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/601531.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pDFbtX87nQuecCp2NUF7R5bEChB.jpg'),
(145864, 2218, 'A Grande Familia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/601532.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4BHgTFBXnZOEMlJ0yFTPBGINwIq.jpg'),
(145865, 2218, 'A Grande Familia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/601533.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e6MfHQ4BxGCWYnVMHSIdGzvZwUJ.jpg'),
(145866, 2218, 'A Grande Familia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/601534.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gHSLNqylpiAgEV93ODSlEJryQeT.jpg'),
(145867, 2218, 'A Grande Familia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/601535.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9azd52SlfodwZuwQLCjw1OoQomt.jpg'),
(145868, 2218, 'A Grande Familia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/601536.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ujafi4lOT2tf7klrXCB53UFiOex.jpg'),
(145869, 2218, 'A Grande Familia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/601537.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sEmV4yHbhi832ao5NeBPQ5Jlbox.jpg'),
(145870, 2218, 'A Grande Familia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/601538.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cwpszsF38k9zHUJLFEVaUUXbzFR.jpg'),
(145871, 2218, 'A Grande Familia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/601539.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wR1cAqSta69pYnCu1Khp0HZOGj3.jpg'),
(145872, 2218, 'A Grande Familia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/601540.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sqcdBaSyH2MGVhnwaErIgzrNc5c.jpg'),
(145873, 2218, 'A Grande Familia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/601541.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/frPtiXZx1XIP42h9w2JEFSwOMMT.jpg'),
(145874, 2218, 'A Grande Familia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/601542.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uKplOc9pW6ihWIwWe6k8CetHyr1.jpg'),
(145875, 2218, 'A Grande Familia S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/601543.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AaiCMtxTQOFv10sEaT6RLK04bl6.jpg'),
(145876, 2218, 'A Grande Familia S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/601544.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4JM0SnzC9gCUwkPqdBSyLv0JoHT.jpg'),
(145877, 2218, 'A Grande Familia S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/601545.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jYR8rZ6jQ4MzayRaCvN2zSe7h1z.jpg'),
(145878, 2218, 'A Grande Familia S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/601546.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/83b9fSGZI1s4oWrhX5hHf8mu5da.jpg'),
(145879, 2218, 'A Grande Familia S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/601547.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rJ2A71ZI5k2yPvnPh8KXW0A1LqJ.jpg'),
(145880, 2218, 'A Grande Familia S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/601548.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2LJDUleFh5kUSUe6OWTPpduWg5X.jpg'),
(145881, 2218, 'A Grande Familia S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/601549.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sgl0hSM4fHbnMeMVHOEE2f1IjIN.jpg'),
(145882, 2218, 'A Grande Familia S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/601550.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c2qYIzGgtjJmtVawxIPj8z1iVc7.jpg'),
(145883, 2218, 'A Grande Familia S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/601551.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/NDJLWSkWs4SWNTgue2ljru1t4O.jpg'),
(145884, 2218, 'A Grande Familia S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/601552.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eaf3OZyXL97WiAqbv8LHKxzPH5M.jpg'),
(145885, 2218, 'A Grande Familia S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/601553.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/woUmCwX92qW7msHxoH1rlMvoO7g.jpg'),
(145886, 2218, 'A Grande Familia S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/601554.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2GEoiXZvUqYajReSSzX7u0aIx6D.jpg'),
(145887, 2218, 'A Grande Familia S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/601555.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a9Bsvdr2AVzrt7hVhmNAvZ7DSBW.jpg'),
(145888, 2218, 'A Grande Familia S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/601556.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l1WnailqC5zdzB3lEexWotHFdxN.jpg'),
(145889, 2218, 'A Grande Familia S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/601557.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5vxWdX1Eogknhp0bnccOQLH0pqC.jpg'),
(145890, 2218, 'A Grande Familia S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/601558.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pQDdGTzhe5L293aNtZRxzUKMcf1.jpg'),
(145891, 2218, 'A Grande Familia S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/601559.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hZVX3U9FCfk8NEIG2QjqLydfyI5.jpg'),
(145892, 2218, 'A Grande Familia S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/601560.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4LNr0A6LKGfdbWhhr7XCzhROE7H.jpg'),
(145893, 2218, 'A Grande Familia S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/601561.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mWxju9xzlRKzrdNawyJbCQy32Xl.jpg'),
(145894, 2218, 'A Grande Familia S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/601562.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/13p0u2i3EwfxAeu2UL54h5uxEld.jpg'),
(145895, 2218, 'A Grande Familia S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/601563.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rsbKcH1zOobtSNAN66oQJPRaQQ0.jpg'),
(145896, 2218, 'A Grande Familia S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/601564.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hhTgcJ50uOjoFqLeBk6YaNUtf9l.jpg'),
(145897, 2218, 'A Grande Familia S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/601565.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2XcVfortbWAiRaTBSLsln67Gii6.jpg'),
(145898, 2219, 'A Grande Familia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/601566.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kDZZpQWDoPkCmVD6n42O7XqhZSq.jpg'),
(145899, 2219, 'A Grande Familia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/601567.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ckt9LK2dm8SrNEJRrFimEIDfd1L.jpg'),
(145900, 2219, 'A Grande Familia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/601568.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9TCIMM4KcZdK8cwDi3wjmEqQRhX.jpg'),
(145901, 2219, 'A Grande Familia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/601569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145902, 2219, 'A Grande Familia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/601570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145903, 2219, 'A Grande Familia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/601571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145904, 2219, 'A Grande Familia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/601572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145905, 2219, 'A Grande Familia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/601573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145906, 2219, 'A Grande Familia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/601574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145907, 2219, 'A Grande Familia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/601575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145908, 2219, 'A Grande Familia S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/601576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145909, 2219, 'A Grande Familia S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/601577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145910, 2219, 'A Grande Familia S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/601578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145911, 2219, 'A Grande Familia S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/601579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145912, 2219, 'A Grande Familia S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/601580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145913, 2219, 'A Grande Familia S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/601581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145914, 2219, 'A Grande Familia S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/601582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145915, 2219, 'A Grande Familia S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/601583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145916, 2219, 'A Grande Familia S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/601584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145917, 2219, 'A Grande Familia S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/601585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145918, 2219, 'A Grande Familia S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/601586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145919, 2219, 'A Grande Familia S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/601587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145920, 2219, 'A Grande Familia S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/601588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145921, 2219, 'A Grande Familia S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/601589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145922, 2219, 'A Grande Familia S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/601590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145923, 2219, 'A Grande Familia S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/601591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145924, 2219, 'A Grande Familia S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/601592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145925, 2219, 'A Grande Familia S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/601593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145926, 2219, 'A Grande Familia S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/601594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145927, 2219, 'A Grande Familia S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/601595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145928, 2219, 'A Grande Familia S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/601596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145929, 2219, 'A Grande Familia S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/601597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145930, 2219, 'A Grande Familia S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/601598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145931, 2219, 'A Grande Familia S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/601599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145932, 2219, 'A Grande Familia S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/601600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145933, 2219, 'A Grande Familia S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/601601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145934, 2219, 'A Grande Familia S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/601602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145935, 2220, 'A Grande Familia S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/601603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145936, 2220, 'A Grande Familia S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/341997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145937, 2220, 'A Grande Familia S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/341998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145938, 2220, 'A Grande Familia S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/341999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145939, 2220, 'A Grande Familia S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/342000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145940, 2220, 'A Grande Familia S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/342001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145941, 2220, 'A Grande Familia S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/342002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145942, 2220, 'A Grande Familia S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/342003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145943, 2220, 'A Grande Familia S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/342004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145944, 2220, 'A Grande Familia S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/342005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145945, 2220, 'A Grande Familia S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/342006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145946, 2220, 'A Grande Familia S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/342007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145947, 2220, 'A Grande Familia S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/342008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145948, 2220, 'A Grande Familia S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/342009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145949, 2220, 'A Grande Familia S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/342010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145950, 2220, 'A Grande Familia S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/342011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145951, 2220, 'A Grande Familia S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/342012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145952, 2220, 'A Grande Familia S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/342013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145953, 2220, 'A Grande Familia S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/342014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145954, 2220, 'A Grande Familia S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/342015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145955, 2220, 'A Grande Familia S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/342016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145956, 2220, 'A Grande Familia S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/342017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145957, 2220, 'A Grande Familia S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/342018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145958, 2220, 'A Grande Familia S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/342019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145959, 2220, 'A Grande Familia S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/342020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145960, 2220, 'A Grande Familia S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/342021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145961, 2220, 'A Grande Familia S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/342022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145962, 2220, 'A Grande Familia S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/342023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145963, 2220, 'A Grande Familia S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/342024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145964, 2220, 'A Grande Familia S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/342025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145965, 2220, 'A Grande Familia S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/342026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145966, 2220, 'A Grande Familia S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/342027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145967, 2220, 'A Grande Familia S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/342028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145968, 2220, 'A Grande Familia S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/342029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145969, 2220, 'A Grande Familia S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/342030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145970, 2220, 'A Grande Familia S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/342031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145971, 2220, 'A Grande Familia S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/342032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145972, 2221, 'A Grande Familia S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/342033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145973, 2221, 'A Grande Familia S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/342034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145974, 2221, 'A Grande Familia S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/342035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145975, 2221, 'A Grande Familia S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/342036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145976, 2221, 'A Grande Familia S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/342037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145977, 2221, 'A Grande Familia S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/342038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145978, 2221, 'A Grande Familia S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/342039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145979, 2221, 'A Grande Familia S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/342040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145980, 2221, 'A Grande Familia S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/342041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145981, 2221, 'A Grande Familia S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/342042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145982, 2221, 'A Grande Familia S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/342043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145983, 2221, 'A Grande Familia S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/342044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145984, 2221, 'A Grande Familia S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/342045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145985, 2221, 'A Grande Familia S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/342046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145986, 2221, 'A Grande Familia S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/342047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145987, 2221, 'A Grande Familia S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/342048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145988, 2221, 'A Grande Familia S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/342049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145989, 2221, 'A Grande Familia S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/342050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145990, 2221, 'A Grande Familia S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/342051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145991, 2221, 'A Grande Familia S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/342052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145992, 2221, 'A Grande Familia S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/342053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145993, 2221, 'A Grande Familia S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/342054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145994, 2221, 'A Grande Familia S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/342055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145995, 2221, 'A Grande Familia S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/342056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145996, 2221, 'A Grande Familia S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/342057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145997, 2221, 'A Grande Familia S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/342058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145998, 2221, 'A Grande Familia S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/342059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(145999, 2221, 'A Grande Familia S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/342060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146000, 2221, 'A Grande Familia S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/342061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146001, 2221, 'A Grande Familia S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/342062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146002, 2222, 'A Grande Familia S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/342063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146003, 2222, 'A Grande Familia S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/342064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146004, 2222, 'A Grande Familia S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/342065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146005, 2222, 'A Grande Familia S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/342066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146006, 2222, 'A Grande Familia S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/342067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146007, 2222, 'A Grande Familia S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/342068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146008, 2222, 'A Grande Familia S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/342069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146009, 2222, 'A Grande Familia S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/342070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146010, 2222, 'A Grande Familia S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/342071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146011, 2222, 'A Grande Familia S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/342072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146012, 2222, 'A Grande Familia S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/342073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146013, 2222, 'A Grande Familia S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/342074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146014, 2222, 'A Grande Familia S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/342075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146015, 2222, 'A Grande Familia S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/342076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146016, 2222, 'A Grande Familia S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/342077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146017, 2222, 'A Grande Familia S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/342078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146018, 2222, 'A Grande Familia S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/342079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146019, 2222, 'A Grande Familia S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/342080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146020, 2222, 'A Grande Familia S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/342081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146021, 2222, 'A Grande Familia S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/342082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146022, 2222, 'A Grande Familia S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/342083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146023, 2222, 'A Grande Familia S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/342084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146024, 2222, 'A Grande Familia S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/342085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146025, 2222, 'A Grande Familia S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/342086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146026, 2222, 'A Grande Familia S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/342087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146027, 2222, 'A Grande Familia S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/342088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146028, 2222, 'A Grande Familia S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/342089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146029, 2222, 'A Grande Familia S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/342090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146030, 2222, 'A Grande Familia S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/342091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146031, 2222, 'A Grande Familia S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/342092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146032, 2222, 'A Grande Familia S05 E31', 'http://sinalprivado.info:80/series/1533784/1533784/342093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146033, 2222, 'A Grande Familia S05 E32', 'http://sinalprivado.info:80/series/1533784/1533784/342094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146034, 2222, 'A Grande Familia S05 E33', 'http://sinalprivado.info:80/series/1533784/1533784/342095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146035, 2222, 'A Grande Familia S05 E34', 'http://sinalprivado.info:80/series/1533784/1533784/342096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146036, 2222, 'A Grande Familia S05 E35', 'http://sinalprivado.info:80/series/1533784/1533784/342097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146037, 2222, 'A Grande Familia S05 E36', 'http://sinalprivado.info:80/series/1533784/1533784/342098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146038, 2223, 'A Grande Familia S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/342099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146039, 2223, 'A Grande Familia S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/342100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146040, 2223, 'A Grande Familia S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/342101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146041, 2223, 'A Grande Familia S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/342102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146042, 2223, 'A Grande Familia S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/342103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146043, 2223, 'A Grande Familia S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/346334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146044, 2223, 'A Grande Familia S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/342105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146045, 2223, 'A Grande Familia S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/342106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146046, 2223, 'A Grande Familia S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/342107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146047, 2223, 'A Grande Familia S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/342108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(146048, 2223, 'A Grande Familia S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/342109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146049, 2223, 'A Grande Familia S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/342110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146050, 2223, 'A Grande Familia S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/342111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146051, 2223, 'A Grande Familia S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/342112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146052, 2223, 'A Grande Familia S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/342113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146053, 2223, 'A Grande Familia S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/342114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146054, 2223, 'A Grande Familia S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/342115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146055, 2223, 'A Grande Familia S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/342116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146056, 2223, 'A Grande Familia S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/346347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146057, 2223, 'A Grande Familia S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/342118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146058, 2223, 'A Grande Familia S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/342119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146059, 2223, 'A Grande Familia S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/342120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146060, 2223, 'A Grande Familia S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/342121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146061, 2223, 'A Grande Familia S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/342122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146062, 2223, 'A Grande Familia S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/342123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146063, 2223, 'A Grande Familia S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/342124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146064, 2223, 'A Grande Familia S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/342125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146065, 2223, 'A Grande Familia S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/346356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146066, 2223, 'A Grande Familia S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/342127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146067, 2223, 'A Grande Familia S06 E30', 'http://sinalprivado.info:80/series/1533784/1533784/342128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146068, 2223, 'A Grande Familia S06 E31', 'http://sinalprivado.info:80/series/1533784/1533784/342129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146069, 2223, 'A Grande Familia S06 E32', 'http://sinalprivado.info:80/series/1533784/1533784/342130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146070, 2223, 'A Grande Familia S06 E33', 'http://sinalprivado.info:80/series/1533784/1533784/342131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146071, 2223, 'A Grande Familia S06 E34', 'http://sinalprivado.info:80/series/1533784/1533784/342132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146072, 2223, 'A Grande Familia S06 E35', 'http://sinalprivado.info:80/series/1533784/1533784/342133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146073, 2223, 'A Grande Familia S06 E36', 'http://sinalprivado.info:80/series/1533784/1533784/342134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146074, 2223, 'A Grande Familia S06 E37', 'http://sinalprivado.info:80/series/1533784/1533784/342135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146075, 2224, 'A Grande Familia S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/342136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146076, 2224, 'A Grande Familia S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/342137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146077, 2224, 'A Grande Familia S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/342138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146078, 2224, 'A Grande Familia S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/342139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146079, 2224, 'A Grande Familia S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/342140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146080, 2224, 'A Grande Familia S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/342141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/68DxN2vjYk1FUz1DbCZEz2LXtLx.jpg'),
(146081, 2224, 'A Grande Familia S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/342142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146082, 2224, 'A Grande Familia S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/342143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146083, 2224, 'A Grande Familia S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/342144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146084, 2224, 'A Grande Familia S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/342145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146085, 2224, 'A Grande Familia S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/342146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146086, 2224, 'A Grande Familia S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/342147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146087, 2224, 'A Grande Familia S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/342148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146088, 2224, 'A Grande Familia S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/342149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146089, 2224, 'A Grande Familia S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/342150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146090, 2224, 'A Grande Familia S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/342151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146091, 2224, 'A Grande Familia S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/342152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146092, 2224, 'A Grande Familia S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/342153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146093, 2224, 'A Grande Familia S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/342154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146094, 2224, 'A Grande Familia S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/342155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146095, 2224, 'A Grande Familia S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/342156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146096, 2224, 'A Grande Familia S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/342157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146097, 2224, 'A Grande Familia S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/342158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146098, 2224, 'A Grande Familia S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/342159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146099, 2224, 'A Grande Familia S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/342160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146100, 2224, 'A Grande Familia S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/342161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146101, 2224, 'A Grande Familia S07 E27', 'http://sinalprivado.info:80/series/1533784/1533784/342162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146102, 2224, 'A Grande Familia S07 E28', 'http://sinalprivado.info:80/series/1533784/1533784/342163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146103, 2224, 'A Grande Familia S07 E29', 'http://sinalprivado.info:80/series/1533784/1533784/342164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146104, 2224, 'A Grande Familia S07 E30', 'http://sinalprivado.info:80/series/1533784/1533784/342165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146105, 2224, 'A Grande Familia S07 E31', 'http://sinalprivado.info:80/series/1533784/1533784/342166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146106, 2224, 'A Grande Familia S07 E32', 'http://sinalprivado.info:80/series/1533784/1533784/342167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146107, 2224, 'A Grande Familia S07 E33', 'http://sinalprivado.info:80/series/1533784/1533784/342168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146108, 2224, 'A Grande Familia S07 E34', 'http://sinalprivado.info:80/series/1533784/1533784/342169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146109, 2224, 'A Grande Familia S07 E35', 'http://sinalprivado.info:80/series/1533784/1533784/342170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146110, 2224, 'A Grande Familia S07 E36', 'http://sinalprivado.info:80/series/1533784/1533784/342171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146111, 2224, 'A Grande Familia S07 E37', 'http://sinalprivado.info:80/series/1533784/1533784/342172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146112, 2225, 'A Grande Familia S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/342173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146113, 2225, 'A Grande Familia S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/342174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146114, 2225, 'A Grande Familia S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/342175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146115, 2225, 'A Grande Familia S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/342176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146116, 2225, 'A Grande Familia S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/342177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146117, 2225, 'A Grande Familia S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/342178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146118, 2225, 'A Grande Familia S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/342179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146119, 2225, 'A Grande Familia S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/342180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146120, 2225, 'A Grande Familia S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/342181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146121, 2225, 'A Grande Familia S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/342182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146122, 2225, 'A Grande Familia S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/342183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146123, 2225, 'A Grande Familia S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/342184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146124, 2225, 'A Grande Familia S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/342185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146125, 2225, 'A Grande Familia S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/342186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146126, 2225, 'A Grande Familia S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/342187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146127, 2225, 'A Grande Familia S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/342188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146128, 2225, 'A Grande Familia S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/342189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146129, 2225, 'A Grande Familia S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/342190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146130, 2225, 'A Grande Familia S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/342191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146131, 2225, 'A Grande Familia S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/342192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146132, 2225, 'A Grande Familia S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/342193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146133, 2225, 'A Grande Familia S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/342194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146134, 2225, 'A Grande Familia S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/342195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146135, 2225, 'A Grande Familia S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/342196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146136, 2225, 'A Grande Familia S08 E25', 'http://sinalprivado.info:80/series/1533784/1533784/342197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146137, 2225, 'A Grande Familia S08 E26', 'http://sinalprivado.info:80/series/1533784/1533784/342198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146138, 2225, 'A Grande Familia S08 E27', 'http://sinalprivado.info:80/series/1533784/1533784/342199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146139, 2225, 'A Grande Familia S08 E28', 'http://sinalprivado.info:80/series/1533784/1533784/342200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146140, 2225, 'A Grande Familia S08 E29', 'http://sinalprivado.info:80/series/1533784/1533784/342201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146141, 2225, 'A Grande Familia S08 E30', 'http://sinalprivado.info:80/series/1533784/1533784/342202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146142, 2225, 'A Grande Familia S08 E31', 'http://sinalprivado.info:80/series/1533784/1533784/342203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146143, 2225, 'A Grande Familia S08 E32', 'http://sinalprivado.info:80/series/1533784/1533784/342204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146144, 2225, 'A Grande Familia S08 E33', 'http://sinalprivado.info:80/series/1533784/1533784/342205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146145, 2225, 'A Grande Familia S08 E34', 'http://sinalprivado.info:80/series/1533784/1533784/342206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146146, 2225, 'A Grande Familia S08 E35', 'http://sinalprivado.info:80/series/1533784/1533784/342207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146147, 2225, 'A Grande Familia S08 E36', 'http://sinalprivado.info:80/series/1533784/1533784/342208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146148, 2225, 'A Grande Familia S08 E37', 'http://sinalprivado.info:80/series/1533784/1533784/342209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146149, 2225, 'A Grande Familia S08 E38', 'http://sinalprivado.info:80/series/1533784/1533784/342210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146150, 2226, 'A Grande Familia S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/342211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146151, 2226, 'A Grande Familia S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/342212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146152, 2226, 'A Grande Familia S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/342213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146153, 2226, 'A Grande Familia S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/342214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146154, 2226, 'A Grande Familia S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/342215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146155, 2226, 'A Grande Familia S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/342216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146156, 2226, 'A Grande Familia S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/342217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146157, 2226, 'A Grande Familia S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/342218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146158, 2226, 'A Grande Familia S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/342219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146159, 2226, 'A Grande Familia S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/342220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146160, 2226, 'A Grande Familia S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/342221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146161, 2226, 'A Grande Familia S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/342222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146162, 2226, 'A Grande Familia S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/342223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146163, 2226, 'A Grande Familia S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/342224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146164, 2226, 'A Grande Familia S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/342225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146165, 2226, 'A Grande Familia S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/342226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146166, 2226, 'A Grande Familia S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/342227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146167, 2226, 'A Grande Familia S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/342228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146168, 2226, 'A Grande Familia S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/342229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146169, 2226, 'A Grande Familia S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/342230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146170, 2226, 'A Grande Familia S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/342231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146171, 2226, 'A Grande Familia S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/342232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146172, 2226, 'A Grande Familia S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/342233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146173, 2226, 'A Grande Familia S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/342234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146174, 2226, 'A Grande Familia S09 E25', 'http://sinalprivado.info:80/series/1533784/1533784/342235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146175, 2226, 'A Grande Familia S09 E26', 'http://sinalprivado.info:80/series/1533784/1533784/342236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146176, 2226, 'A Grande Familia S09 E27', 'http://sinalprivado.info:80/series/1533784/1533784/342237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146177, 2226, 'A Grande Familia S09 E28', 'http://sinalprivado.info:80/series/1533784/1533784/342238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146178, 2226, 'A Grande Familia S09 E29', 'http://sinalprivado.info:80/series/1533784/1533784/342239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146179, 2226, 'A Grande Familia S09 E30', 'http://sinalprivado.info:80/series/1533784/1533784/342240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146180, 2226, 'A Grande Familia S09 E31', 'http://sinalprivado.info:80/series/1533784/1533784/342241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146181, 2226, 'A Grande Familia S09 E32', 'http://sinalprivado.info:80/series/1533784/1533784/342242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146182, 2226, 'A Grande Familia S09 E33', 'http://sinalprivado.info:80/series/1533784/1533784/342243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146183, 2226, 'A Grande Familia S09 E34', 'http://sinalprivado.info:80/series/1533784/1533784/342244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146184, 2226, 'A Grande Familia S09 E35', 'http://sinalprivado.info:80/series/1533784/1533784/342245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146185, 2226, 'A Grande Familia S09 E36', 'http://sinalprivado.info:80/series/1533784/1533784/342246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146186, 2227, 'A Grande Familia S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/346477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146187, 2227, 'A Grande Familia S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/346478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146188, 2227, 'A Grande Familia S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/346479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146189, 2227, 'A Grande Familia S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/346480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146190, 2227, 'A Grande Familia S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/346481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146191, 2227, 'A Grande Familia S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/346482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146192, 2227, 'A Grande Familia S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/346483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146193, 2227, 'A Grande Familia S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/346484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146194, 2227, 'A Grande Familia S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/346485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146195, 2227, 'A Grande Familia S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/346486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146196, 2227, 'A Grande Familia S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/346487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146197, 2227, 'A Grande Familia S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/346488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146198, 2227, 'A Grande Familia S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/346489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146199, 2227, 'A Grande Familia S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/346490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146200, 2227, 'A Grande Familia S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/346491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146201, 2227, 'A Grande Familia S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/346492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146202, 2227, 'A Grande Familia S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/346493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146203, 2227, 'A Grande Familia S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/346494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146204, 2227, 'A Grande Familia S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/346495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146205, 2227, 'A Grande Familia S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/346496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146206, 2227, 'A Grande Familia S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/346497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146207, 2227, 'A Grande Familia S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/346498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146208, 2227, 'A Grande Familia S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/346499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146209, 2227, 'A Grande Familia S10 E24', 'http://sinalprivado.info:80/series/1533784/1533784/346500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146210, 2227, 'A Grande Familia S10 E25', 'http://sinalprivado.info:80/series/1533784/1533784/346501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146211, 2227, 'A Grande Familia S10 E26', 'http://sinalprivado.info:80/series/1533784/1533784/346502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146212, 2227, 'A Grande Familia S10 E27', 'http://sinalprivado.info:80/series/1533784/1533784/346503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146213, 2227, 'A Grande Familia S10 E28', 'http://sinalprivado.info:80/series/1533784/1533784/346504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146214, 2227, 'A Grande Familia S10 E29', 'http://sinalprivado.info:80/series/1533784/1533784/346505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146215, 2227, 'A Grande Familia S10 E30', 'http://sinalprivado.info:80/series/1533784/1533784/346506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146216, 2227, 'A Grande Familia S10 E31', 'http://sinalprivado.info:80/series/1533784/1533784/346507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146217, 2227, 'A Grande Familia S10 E32', 'http://sinalprivado.info:80/series/1533784/1533784/346508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146218, 2227, 'A Grande Familia S10 E33', 'http://sinalprivado.info:80/series/1533784/1533784/346509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146219, 2227, 'A Grande Familia S10 E34', 'http://sinalprivado.info:80/series/1533784/1533784/346510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146220, 2227, 'A Grande Familia S10 E35', 'http://sinalprivado.info:80/series/1533784/1533784/346511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146221, 2227, 'A Grande Familia S10 E36', 'http://sinalprivado.info:80/series/1533784/1533784/346512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146222, 2228, 'A Grande Familia S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/349985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146223, 2228, 'A Grande Familia S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/349986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146224, 2228, 'A Grande Familia S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/349987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146225, 2228, 'A Grande Familia S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/349988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146226, 2228, 'A Grande Familia S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/349989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146227, 2228, 'A Grande Familia S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/349990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146228, 2228, 'A Grande Familia S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/349991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146229, 2228, 'A Grande Familia S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/349992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146230, 2228, 'A Grande Familia S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/349993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146231, 2228, 'A Grande Familia S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/349994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146232, 2228, 'A Grande Familia S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/349995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146233, 2228, 'A Grande Familia S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/349996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146234, 2228, 'A Grande Familia S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/349997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146235, 2228, 'A Grande Familia S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/349998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146236, 2228, 'A Grande Familia S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/349999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146237, 2228, 'A Grande Familia S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/350000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146238, 2228, 'A Grande Familia S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/350001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146239, 2228, 'A Grande Familia S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/350002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146240, 2228, 'A Grande Familia S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/350003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146241, 2228, 'A Grande Familia S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/350004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146242, 2228, 'A Grande Familia S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/350005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146243, 2228, 'A Grande Familia S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/350006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146244, 2228, 'A Grande Familia S11 E23', 'http://sinalprivado.info:80/series/1533784/1533784/350007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146245, 2228, 'A Grande Familia S11 E24', 'http://sinalprivado.info:80/series/1533784/1533784/350008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146246, 2228, 'A Grande Familia S11 E25', 'http://sinalprivado.info:80/series/1533784/1533784/350009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146247, 2228, 'A Grande Familia S11 E26', 'http://sinalprivado.info:80/series/1533784/1533784/350010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146248, 2228, 'A Grande Familia S11 E27', 'http://sinalprivado.info:80/series/1533784/1533784/350011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146249, 2228, 'A Grande Familia S11 E28', 'http://sinalprivado.info:80/series/1533784/1533784/350012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146250, 2228, 'A Grande Familia S11 E29', 'http://sinalprivado.info:80/series/1533784/1533784/350013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146251, 2228, 'A Grande Familia S11 E30', 'http://sinalprivado.info:80/series/1533784/1533784/350014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146252, 2228, 'A Grande Familia S11 E31', 'http://sinalprivado.info:80/series/1533784/1533784/350015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146253, 2228, 'A Grande Familia S11 E32', 'http://sinalprivado.info:80/series/1533784/1533784/350016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146254, 2228, 'A Grande Familia S11 E33', 'http://sinalprivado.info:80/series/1533784/1533784/350017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146255, 2228, 'A Grande Familia S11 E34', 'http://sinalprivado.info:80/series/1533784/1533784/350018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146256, 2228, 'A Grande Familia S11 E35', 'http://sinalprivado.info:80/series/1533784/1533784/350019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146257, 2228, 'A Grande Familia S11 E36', 'http://sinalprivado.info:80/series/1533784/1533784/350020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146258, 2228, 'A Grande Familia S11 E37', 'http://sinalprivado.info:80/series/1533784/1533784/350021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146259, 2228, 'A Grande Familia S11 E38', 'http://sinalprivado.info:80/series/1533784/1533784/350022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146260, 2229, 'A Grande Familia S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/350023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146261, 2229, 'A Grande Familia S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/350024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146262, 2229, 'A Grande Familia S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/350025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146263, 2229, 'A Grande Familia S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/350026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146264, 2229, 'A Grande Familia S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/350027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146265, 2229, 'A Grande Familia S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/350028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146266, 2229, 'A Grande Familia S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/350029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146267, 2229, 'A Grande Familia S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/350030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146268, 2229, 'A Grande Familia S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/350031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146269, 2229, 'A Grande Familia S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/350032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146270, 2229, 'A Grande Familia S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/350033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146271, 2229, 'A Grande Familia S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/350034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146272, 2229, 'A Grande Familia S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/350035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146273, 2229, 'A Grande Familia S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/350036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146274, 2229, 'A Grande Familia S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/350037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146275, 2229, 'A Grande Familia S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/350038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146276, 2229, 'A Grande Familia S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/350039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146277, 2229, 'A Grande Familia S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/350040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146278, 2229, 'A Grande Familia S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/350041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146279, 2229, 'A Grande Familia S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/350042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146280, 2229, 'A Grande Familia S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/350043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146281, 2229, 'A Grande Familia S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/350044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146282, 2229, 'A Grande Familia S12 E23', 'http://sinalprivado.info:80/series/1533784/1533784/350045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146283, 2229, 'A Grande Familia S12 E24', 'http://sinalprivado.info:80/series/1533784/1533784/350046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146284, 2229, 'A Grande Familia S12 E25', 'http://sinalprivado.info:80/series/1533784/1533784/350047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146285, 2229, 'A Grande Familia S12 E26', 'http://sinalprivado.info:80/series/1533784/1533784/350048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146286, 2229, 'A Grande Familia S12 E27', 'http://sinalprivado.info:80/series/1533784/1533784/350049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146287, 2229, 'A Grande Familia S12 E28', 'http://sinalprivado.info:80/series/1533784/1533784/350050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146288, 2229, 'A Grande Familia S12 E29', 'http://sinalprivado.info:80/series/1533784/1533784/350051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146289, 2229, 'A Grande Familia S12 E30', 'http://sinalprivado.info:80/series/1533784/1533784/350052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146290, 2229, 'A Grande Familia S12 E31', 'http://sinalprivado.info:80/series/1533784/1533784/350053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146291, 2229, 'A Grande Familia S12 E32', 'http://sinalprivado.info:80/series/1533784/1533784/350054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146292, 2229, 'A Grande Familia S12 E33', 'http://sinalprivado.info:80/series/1533784/1533784/350055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146293, 2229, 'A Grande Familia S12 E34', 'http://sinalprivado.info:80/series/1533784/1533784/350056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146294, 2229, 'A Grande Familia S12 E35', 'http://sinalprivado.info:80/series/1533784/1533784/350057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146295, 2229, 'A Grande Familia S12 E36', 'http://sinalprivado.info:80/series/1533784/1533784/350058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146296, 2229, 'A Grande Familia S12 E37', 'http://sinalprivado.info:80/series/1533784/1533784/350059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146297, 2229, 'A Grande Familia S12 E38', 'http://sinalprivado.info:80/series/1533784/1533784/350060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146298, 2230, 'A Grande Familia S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/350061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146299, 2230, 'A Grande Familia S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/350062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146300, 2230, 'A Grande Familia S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/350063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146301, 2230, 'A Grande Familia S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/350064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146302, 2230, 'A Grande Familia S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/350065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146303, 2230, 'A Grande Familia S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/350066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146304, 2230, 'A Grande Familia S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/350067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146305, 2230, 'A Grande Familia S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/350068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146306, 2230, 'A Grande Familia S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/350069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146307, 2230, 'A Grande Familia S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/350070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146308, 2230, 'A Grande Familia S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/350071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(146309, 2230, 'A Grande Familia S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/350072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146310, 2230, 'A Grande Familia S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/350073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146311, 2230, 'A Grande Familia S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/350074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146312, 2230, 'A Grande Familia S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/350075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146313, 2230, 'A Grande Familia S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/350076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146314, 2230, 'A Grande Familia S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/350077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146315, 2230, 'A Grande Familia S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/350078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146316, 2230, 'A Grande Familia S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/350079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146317, 2230, 'A Grande Familia S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/350080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146318, 2230, 'A Grande Familia S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/350081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146319, 2230, 'A Grande Familia S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/350082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146320, 2230, 'A Grande Familia S13 E23', 'http://sinalprivado.info:80/series/1533784/1533784/350083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146321, 2230, 'A Grande Familia S13 E24', 'http://sinalprivado.info:80/series/1533784/1533784/350084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146322, 2230, 'A Grande Familia S13 E25', 'http://sinalprivado.info:80/series/1533784/1533784/350085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146323, 2230, 'A Grande Familia S13 E26', 'http://sinalprivado.info:80/series/1533784/1533784/350086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146324, 2231, 'A Grande Familia S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/350087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146325, 2231, 'A Grande Familia S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/350088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146326, 2231, 'A Grande Familia S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/350089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146327, 2231, 'A Grande Familia S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/350090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146328, 2231, 'A Grande Familia S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/350091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146329, 2231, 'A Grande Familia S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/350092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146330, 2231, 'A Grande Familia S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/350093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146331, 2231, 'A Grande Familia S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/350094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146332, 2231, 'A Grande Familia S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/350095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146333, 2231, 'A Grande Familia S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/350096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146334, 2231, 'A Grande Familia S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/350097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146335, 2231, 'A Grande Familia S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/350098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146336, 2231, 'A Grande Familia S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/350099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146337, 2231, 'A Grande Familia S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/350100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146338, 2231, 'A Grande Familia S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/350101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146339, 2231, 'A Grande Familia S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/350102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146340, 2231, 'A Grande Familia S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/350103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146341, 2231, 'A Grande Familia S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/350104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146342, 2231, 'A Grande Familia S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/350105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146343, 2231, 'A Grande Familia S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/350106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146344, 2231, 'A Grande Familia S14 E21', 'http://sinalprivado.info:80/series/1533784/1533784/350107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146345, 2231, 'A Grande Familia S14 E22', 'http://sinalprivado.info:80/series/1533784/1533784/350108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146346, 2231, 'A Grande Familia S14 E23', 'http://sinalprivado.info:80/series/1533784/1533784/350109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/draJzGrnfB8gEqCGJrPhNORu0nz.jpg'),
(146347, 10438, 'Justica 2 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/339139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qYxjdMwHyWCqQtyac6pIrZMx4d5.jpg'),
(146348, 10438, 'Justica 2 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/339140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nUjtwdmQXUhTPzqGLNQBdozFSrS.jpg'),
(146349, 10438, 'Justica 2 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/339141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/CX9fGohkPL7yLc9TOfqih1lF3P.jpg'),
(146350, 10438, 'Justica 2 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/339142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/85JeZL0gbLCpLKl8lGyHA5DzeKl.jpg'),
(146351, 10438, 'Justica 2 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/339143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/utSTWFieUgB3cBydu1E0rI5olsw.jpg'),
(146352, 10438, 'Justica 2 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/339144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nj9Ju39iA6mKTha78U0E9xYH9sC.jpg'),
(146353, 10438, 'Justica 2 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/339145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dMlBvHvN0f40a49x7v51UKOzoTu.jpg'),
(146354, 10438, 'Justica 2 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/339146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zPKLSWlk879QkeAgV60ba2joo4S.jpg'),
(146355, 10438, 'Justica 2 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/339147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gEIWKchjl63IM56T06fHn9Dm6UY.jpg'),
(146356, 10438, 'Justica 2 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/339148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ak5jEZjTlwWBcvzNwDgCBHT9RKO.jpg'),
(146357, 10438, 'Justica 2 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/339149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w0pPc9YGvyVF1NyO0S3dSnWs47U.jpg'),
(146358, 10438, 'Justica 2 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/339150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sXTlOjkVjoqZibnIcfbUMt0qiMQ.jpg'),
(146359, 10438, 'Justica 2 S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/339151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNDtm7ZSTa0SKaps3GrKu3aAMZt.jpg'),
(146360, 10438, 'Justica 2 S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/339152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNDtm7ZSTa0SKaps3GrKu3aAMZt.jpg'),
(146361, 10438, 'Justica 2 S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/339153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNDtm7ZSTa0SKaps3GrKu3aAMZt.jpg'),
(146362, 10438, 'Justica 2 S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/339154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNDtm7ZSTa0SKaps3GrKu3aAMZt.jpg'),
(146363, 10438, 'Justica 2 S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/352150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNDtm7ZSTa0SKaps3GrKu3aAMZt.jpg'),
(146364, 10438, 'Justica 2 S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/352151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNDtm7ZSTa0SKaps3GrKu3aAMZt.jpg'),
(146365, 10438, 'Justica 2 S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/352152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNDtm7ZSTa0SKaps3GrKu3aAMZt.jpg'),
(146366, 10438, 'Justica 2 S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/352153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNDtm7ZSTa0SKaps3GrKu3aAMZt.jpg'),
(146367, 10438, 'Justica 2 S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/352154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNDtm7ZSTa0SKaps3GrKu3aAMZt.jpg'),
(146368, 10438, 'Justica 2 S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/352155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNDtm7ZSTa0SKaps3GrKu3aAMZt.jpg'),
(146369, 10438, 'Justica 2 S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/352156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNDtm7ZSTa0SKaps3GrKu3aAMZt.jpg'),
(146370, 10438, 'Justica 2 S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/352157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNDtm7ZSTa0SKaps3GrKu3aAMZt.jpg'),
(146371, 10438, 'Justica 2 S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/359573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNDtm7ZSTa0SKaps3GrKu3aAMZt.jpg'),
(146372, 10438, 'Justica 2 S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/359574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNDtm7ZSTa0SKaps3GrKu3aAMZt.jpg'),
(146373, 10438, 'Justica 2 S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/359575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNDtm7ZSTa0SKaps3GrKu3aAMZt.jpg'),
(146374, 10438, 'Justica 2 S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/359576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oNDtm7ZSTa0SKaps3GrKu3aAMZt.jpg'),
(146375, 10439, 'Casa em Obra do Pesadelo ao Sonho S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/346692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uGCc4ye2m1knxAETAJqHjayUpdT.jpg'),
(146376, 10439, 'Casa em Obra do Pesadelo ao Sonho S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/346693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uGCc4ye2m1knxAETAJqHjayUpdT.jpg'),
(146377, 10439, 'Casa em Obra do Pesadelo ao Sonho S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/346694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uGCc4ye2m1knxAETAJqHjayUpdT.jpg'),
(146378, 10439, 'Casa em Obra do Pesadelo ao Sonho S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/346695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uGCc4ye2m1knxAETAJqHjayUpdT.jpg'),
(146379, 10439, 'Casa em Obra do Pesadelo ao Sonho S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/346696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uGCc4ye2m1knxAETAJqHjayUpdT.jpg'),
(146380, 10439, 'Casa em Obra do Pesadelo ao Sonho S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uGCc4ye2m1knxAETAJqHjayUpdT.jpg'),
(146381, 10439, 'Casa em Obra do Pesadelo ao Sonho S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/360937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uGCc4ye2m1knxAETAJqHjayUpdT.jpg'),
(146382, 10439, 'Casa em Obra do Pesadelo ao Sonho S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/360938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uGCc4ye2m1knxAETAJqHjayUpdT.jpg'),
(146383, 10440, 'O Indice do Medo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/346688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8BfHxRcv6r5Z4t18I3fylHImzfK.jpg'),
(146384, 10440, 'O Indice do Medo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/346689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qorRo0UkBVYnSpBOwc3VGEBUjXA.jpg'),
(146385, 10440, 'O Indice do Medo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/346690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9G6EtwggAEoaohDEMIX4KiSRy7n.jpg'),
(146386, 10440, 'O Indice do Medo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/346691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nUFNtqpZeMfKfkQco0VPS4tG4CG.jpg'),
(146387, 10441, 'Seis Nao E Demais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/346684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kqIhCEZO9X6hMAP22artcCb7R9u.jpg'),
(146388, 10441, 'Seis Nao E Demais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/346685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUIG5WF2kneytmkkrZ6P0HqZRkM.jpg'),
(146389, 10441, 'Seis Nao E Demais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/346686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AkTISE9Ak8NB0jkewFUkvkAKbKL.jpg'),
(146390, 10441, 'Seis Nao E Demais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/346687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/arbLyYzQZGg2QU31VzoBkF9bedm.jpg'),
(146391, 10441, 'Seis Nao E Demais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/351407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9gkdpc1zUIlmc520nsyN0BnQXo.jpg'),
(146392, 10441, 'Seis Nao E Demais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/351408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9gkdpc1zUIlmc520nsyN0BnQXo.jpg'),
(146393, 10441, 'Seis Nao E Demais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/351409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9gkdpc1zUIlmc520nsyN0BnQXo.jpg'),
(146394, 10441, 'Seis Nao E Demais S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/351410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c9gkdpc1zUIlmc520nsyN0BnQXo.jpg'),
(146395, 10442, 'Star Wars Historias do Imperio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/346678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pKjjudnnmXpIeatUY6exm0BLrVN.jpg'),
(146396, 10442, 'Star Wars Historias do Imperio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/346679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aPjdhwQjgZNG7aFiLWi8gVZ2zR.jpg'),
(146397, 10442, 'Star Wars Historias do Imperio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/346680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r1R3XDXDV6bMTZQ9XNWD0dyLU6O.jpg'),
(146398, 10442, 'Star Wars Historias do Imperio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/346681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/85sb6N2mEnxf1PHtGUlrox4go5T.jpg'),
(146399, 10442, 'Star Wars Historias do Imperio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/346682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkzj2LPA9wmuifUfWD1t8z5Ak7A.jpg'),
(146400, 10442, 'Star Wars Historias do Imperio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/346683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wRBGOpcnxtofKfloHwnMPKWxYH.jpg'),
(146401, 10443, 'Cardcaptor Sakura S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/346608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pZ0eFsHPia5sgebM0RZTVdqLwbc.jpg'),
(146402, 10443, 'Cardcaptor Sakura S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/346609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rfEJLEVQQvazVXEh3yZ4Da0hkJ5.jpg'),
(146403, 10443, 'Cardcaptor Sakura S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/346610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uDTxZcFm5S5DZYSrC2RkjK1W3Zx.jpg'),
(146404, 10443, 'Cardcaptor Sakura S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/346611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5bpAUUJvdt8qCoDK4nbuPtPwx6r.jpg'),
(146405, 10443, 'Cardcaptor Sakura S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/346612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBnSOxolJTuGehVvlsQiSD9S9h3.jpg'),
(146406, 10443, 'Cardcaptor Sakura S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/346613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rqS1bRSngLhuHTjeNpFsfGKMpQy.jpg'),
(146407, 10443, 'Cardcaptor Sakura S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/346614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uXBSXxZcQ8RnAM69jUEQwEG6sbY.jpg'),
(146408, 10443, 'Cardcaptor Sakura S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/346615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6h8T5vzwR1cW3mZa4LlNLVizwRX.jpg'),
(146409, 10443, 'Cardcaptor Sakura S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/346616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Abt8I24yI6kExS7b8lZZch5TwTU.jpg'),
(146410, 10443, 'Cardcaptor Sakura S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/346617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tSvIpePOf1qp68kWcGf9gG7ESOl.jpg'),
(146411, 10443, 'Cardcaptor Sakura S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/346618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nQezFfSKPDAdydClgZ6YPBgZPDZ.jpg'),
(146412, 10443, 'Cardcaptor Sakura S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/346619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ApA5UvA2QfrWrMPkU2UaNRCLMbd.jpg'),
(146413, 10443, 'Cardcaptor Sakura S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/346620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1qxHHHxnkBLTfRmsq8JWE3RmFHU.jpg'),
(146414, 10443, 'Cardcaptor Sakura S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/346621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ltrFAV20ySHHi6HO5ZDr0DeBvp6.jpg'),
(146415, 10443, 'Cardcaptor Sakura S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/346622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9zVk4yDhCowWMK1iSkHfjLPypB1.jpg'),
(146416, 10443, 'Cardcaptor Sakura S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/346623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJLO33rCyhruOkNpao2vdwwPVTG.jpg'),
(146417, 10443, 'Cardcaptor Sakura S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/346624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wvfQBt9mBnym7KyQUHBJkaGUICp.jpg'),
(146418, 10443, 'Cardcaptor Sakura S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/346625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zrwnTIlxlsLFo6bXKOihdWO3gbZ.jpg'),
(146419, 10443, 'Cardcaptor Sakura S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/346626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g78254wJSslBzTCROqORmeMD0gB.jpg'),
(146420, 10443, 'Cardcaptor Sakura S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/346627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6wTTNqnReZ1OC5ssk8yoZxb0k38.jpg'),
(146421, 10443, 'Cardcaptor Sakura S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/346628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cH5Uli3OF05q50eavC0FoSp44D0.jpg'),
(146422, 10443, 'Cardcaptor Sakura S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/346629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bFV5iCnItHJoBX95pf9Ix2o4Bih.jpg'),
(146423, 10443, 'Cardcaptor Sakura S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/346630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q4Q0UASxHGBDfgYEJZVtLmtbuES.jpg'),
(146424, 10443, 'Cardcaptor Sakura S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/346631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7vJx2vkgzSoQvuoskwc7TOJlwpj.jpg'),
(146425, 10443, 'Cardcaptor Sakura S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/346632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l2bjKCSFeS7hXhVxBn3vHhqMwpD.jpg'),
(146426, 10443, 'Cardcaptor Sakura S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/346633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5YMr5jzMdCE8I0csBHNQBXuG6Pq.jpg'),
(146427, 10443, 'Cardcaptor Sakura S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/346634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vdF1YfcT0kmK2EtWGPscRo6guEa.jpg'),
(146428, 10443, 'Cardcaptor Sakura S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/346635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5CNO3vcmawEcEFfFIhaHGuNmJ2n.jpg'),
(146429, 10443, 'Cardcaptor Sakura S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/346636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j0RIZpcij3d1j1i0lme0HrEUWYt.jpg'),
(146430, 10443, 'Cardcaptor Sakura S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/346637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7x3wiFZ9faC1LplqRlVpAHuem29.jpg'),
(146431, 10443, 'Cardcaptor Sakura S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/346638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8RlE4GWJtIeQnVUxJr4KGSP1BRx.jpg'),
(146432, 10443, 'Cardcaptor Sakura S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/346639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uJBEkSlCwQ9ApWGByt5OGh9dN0Q.jpg'),
(146433, 10443, 'Cardcaptor Sakura S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/346640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hUJb58xiHyPBtPWVcspJxRYujpp.jpg'),
(146434, 10443, 'Cardcaptor Sakura S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/346641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e5q8gX4MnPEGNgbTXOHHsMSlTql.jpg'),
(146435, 10443, 'Cardcaptor Sakura S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/346642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kHTWh0dYxtjtjiQCtkC69UANzjy.jpg'),
(146436, 10443, 'Cardcaptor Sakura S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/346643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146437, 10443, 'Cardcaptor Sakura S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/346644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146438, 10443, 'Cardcaptor Sakura S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/346645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146439, 10443, 'Cardcaptor Sakura S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/346646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146440, 10443, 'Cardcaptor Sakura S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/346647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146441, 10443, 'Cardcaptor Sakura S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/346648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146442, 10443, 'Cardcaptor Sakura S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/346649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146443, 10443, 'Cardcaptor Sakura S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/346650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146444, 10443, 'Cardcaptor Sakura S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/346651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146445, 10443, 'Cardcaptor Sakura S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/346652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146446, 10443, 'Cardcaptor Sakura S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/346653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146447, 10443, 'Cardcaptor Sakura S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/346654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146448, 10443, 'Cardcaptor Sakura S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/346655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146449, 10443, 'Cardcaptor Sakura S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/346656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146450, 10443, 'Cardcaptor Sakura S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/346657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146451, 10443, 'Cardcaptor Sakura S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/346658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146452, 10443, 'Cardcaptor Sakura S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/346659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146453, 10443, 'Cardcaptor Sakura S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/346660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146454, 10443, 'Cardcaptor Sakura S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/346661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146455, 10443, 'Cardcaptor Sakura S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/346662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146456, 10443, 'Cardcaptor Sakura S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/346663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146457, 10443, 'Cardcaptor Sakura S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/346664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146458, 10443, 'Cardcaptor Sakura S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/346665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146459, 10443, 'Cardcaptor Sakura S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/346666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146460, 10443, 'Cardcaptor Sakura S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/346667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146461, 10443, 'Cardcaptor Sakura S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/346668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146462, 10443, 'Cardcaptor Sakura S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/346669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146463, 10443, 'Cardcaptor Sakura S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/346670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146464, 10443, 'Cardcaptor Sakura S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/346671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146465, 10443, 'Cardcaptor Sakura S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/346672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146466, 10443, 'Cardcaptor Sakura S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/346673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146467, 10443, 'Cardcaptor Sakura S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/346674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146468, 10443, 'Cardcaptor Sakura S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/346675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146469, 10443, 'Cardcaptor Sakura S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/346676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146470, 10443, 'Cardcaptor Sakura S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/346677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q1oEuSFkG6DZJnsXBPEPARUgrZn.jpg'),
(146471, 10444, 'Bodkin S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/350124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jMzwPV3Puc5EfEUz2LB9DnpUypK.jpg'),
(146472, 10444, 'Bodkin S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/350125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybEfdHryavnZuiFLJCl6wYk0CLp.jpg'),
(146473, 10444, 'Bodkin S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/350126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3m7MlrQ3RWZWWXgPd7dg0A2ALhV.jpg'),
(146474, 10444, 'Bodkin S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/350127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5SvfxAeI81NwrNsF3Cvfbi6RlqN.jpg'),
(146475, 10444, 'Bodkin S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/350128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2tSQvNhiBlIE5kU0KlLlqAbw8ga.jpg'),
(146476, 10444, 'Bodkin S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/350129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/luMjzZUp5jAU69nFVU6vOVKlZKV.jpg'),
(146477, 10444, 'Bodkin S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/350130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/At0nNiZkqIWMs1IIsJ9MkrmHe9V.jpg'),
(146478, 10445, 'Materia Escura S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/352073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3e4BWgbMXr8LQtFzuOrnLEQgeHH.jpg'),
(146479, 10445, 'Materia Escura S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/352074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tGDNcydJxlu448Mc5Qkdmw2NzWz.jpg'),
(146480, 10445, 'Materia Escura S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/352075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mAbuZuS4CqlTI6lvWIxPRHppbVs.jpg'),
(146481, 10445, 'Materia Escura S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/359487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mAbuZuS4CqlTI6lvWIxPRHppbVs.jpg'),
(146482, 10445, 'Materia Escura S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/368030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mAbuZuS4CqlTI6lvWIxPRHppbVs.jpg'),
(146483, 10445, 'Materia Escura S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/373941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mAbuZuS4CqlTI6lvWIxPRHppbVs.jpg'),
(146484, 10445, 'Materia Escura S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/382516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mAbuZuS4CqlTI6lvWIxPRHppbVs.jpg'),
(146485, 10445, 'Materia Escura S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/389521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mAbuZuS4CqlTI6lvWIxPRHppbVs.jpg'),
(146486, 10445, 'Materia Escura S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/396438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mAbuZuS4CqlTI6lvWIxPRHppbVs.jpg'),
(146487, 10446, 'Maxton Hall O Mundo Entre Nos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/350118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cbxIxWXp6KDW9U2II6afrCvdisQ.jpg'),
(146488, 10446, 'Maxton Hall O Mundo Entre Nos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/350119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/37OI3H6BMHbNCKJAbxDopITJHut.jpg'),
(146489, 10446, 'Maxton Hall O Mundo Entre Nos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/350120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oXV6lKEDjlDvIzdK0naZxtRNVhD.jpg'),
(146490, 10446, 'Maxton Hall O Mundo Entre Nos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/350121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xIBhYt1VecY0Qq0dyVlMcrRn4nM.jpg'),
(146491, 10446, 'Maxton Hall O Mundo Entre Nos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/350122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzApzjfALwbRwUeLyXhfSw5Rxfr.jpg'),
(146492, 10446, 'Maxton Hall O Mundo Entre Nos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/350123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vTkFSOnpNag9g0V5gxaHE0BLfzU.jpg'),
(146493, 10447, 'Maxton Hall O Mundo Entre Nos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/891996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1zZYpO2CH0WmoIfldwPuAWKbB4F.jpg'),
(146494, 10447, 'Maxton Hall O Mundo Entre Nos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/891997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1zZYpO2CH0WmoIfldwPuAWKbB4F.jpg'),
(146495, 10447, 'Maxton Hall O Mundo Entre Nos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/891998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1zZYpO2CH0WmoIfldwPuAWKbB4F.jpg'),
(146496, 10447, 'Maxton Hall O Mundo Entre Nos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/892435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1zZYpO2CH0WmoIfldwPuAWKbB4F.jpg'),
(146497, 10447, 'Maxton Hall O Mundo Entre Nos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/893114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1zZYpO2CH0WmoIfldwPuAWKbB4F.jpg'),
(146498, 10447, 'Maxton Hall O Mundo Entre Nos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/893577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1zZYpO2CH0WmoIfldwPuAWKbB4F.jpg'),
(146499, 10448, 'Proximo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/350110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9uBKgBKxpuoXHTBezHhy5pVMvyQ.jpg'),
(146500, 10448, 'Proximo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/350111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4EygkmFiTqU0qxs1Zd3w4jPsEUh.jpg'),
(146501, 10448, 'Proximo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/350112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tDCCUz6Qo0bKvWX4THvIBZhJGLW.jpg'),
(146502, 10448, 'Proximo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/350113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jxmsoerDxSb5jmb9XNLKj3S68Kb.jpg'),
(146503, 10448, 'Proximo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/350114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJFou8uU6yBeRwj7VL0RdlBLDCs.jpg'),
(146504, 10448, 'Proximo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/350115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jhaBHda3S6BbKE55DVPh64AJccA.jpg'),
(146505, 10448, 'Proximo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/350116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ifwdKC9uefHFIUzBgaEhtsZ808j.jpg'),
(146506, 10448, 'Proximo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/350117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tivYQ2cu7mYVzOWdcVHShqN6lbZ.jpg'),
(146507, 10449, 'Proximo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/805249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rvsrqGMRuUv4AA6fS8Il9gXb6wI.jpg'),
(146508, 10449, 'Proximo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/805250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rvsrqGMRuUv4AA6fS8Il9gXb6wI.jpg'),
(146509, 10449, 'Proximo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/805251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rvsrqGMRuUv4AA6fS8Il9gXb6wI.jpg'),
(146510, 10449, 'Proximo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/805252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rvsrqGMRuUv4AA6fS8Il9gXb6wI.jpg'),
(146511, 10449, 'Proximo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/805253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rvsrqGMRuUv4AA6fS8Il9gXb6wI.jpg'),
(146512, 10449, 'Proximo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/805254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rvsrqGMRuUv4AA6fS8Il9gXb6wI.jpg'),
(146513, 10449, 'Proximo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/805255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rvsrqGMRuUv4AA6fS8Il9gXb6wI.jpg'),
(146514, 10449, 'Proximo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/805256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rvsrqGMRuUv4AA6fS8Il9gXb6wI.jpg'),
(146515, 10450, 'Quilos Mortais Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/351418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xt2CvJp7GefoWeU81Ju6X2S0v07.jpg'),
(146516, 10450, 'Quilos Mortais Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/351419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2u5c3aISFwfjzcgQve6k5ouLrtu.jpg'),
(146517, 10450, 'Quilos Mortais Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/351420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fep8C2mhTJVTdBNNgQHrDwWDZ7j.jpg'),
(146518, 10450, 'Quilos Mortais Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/351421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fep8C2mhTJVTdBNNgQHrDwWDZ7j.jpg'),
(146519, 10450, 'Quilos Mortais Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/358738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fep8C2mhTJVTdBNNgQHrDwWDZ7j.jpg'),
(146520, 10450, 'Quilos Mortais Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/358739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fep8C2mhTJVTdBNNgQHrDwWDZ7j.jpg'),
(146521, 10451, 'Doctor Who (2024) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/392705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y0oixiNRCAfRlt98DeCD5eLidxq.jpg'),
(146522, 10451, 'Doctor Who (2024) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/350132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/30RtJ5V9wDwHIFKbJZ7cBiFDtlr.jpg'),
(146523, 10451, 'Doctor Who (2024) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/350133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/35OkthcUCrB6JWhydsbWeMBSsTy.jpg'),
(146524, 10451, 'Doctor Who (2024) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/350134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y0oixiNRCAfRlt98DeCD5eLidxq.jpg'),
(146525, 10451, 'Doctor Who (2024) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/350135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y0oixiNRCAfRlt98DeCD5eLidxq.jpg'),
(146526, 10451, 'Doctor Who (2024) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/369034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y0oixiNRCAfRlt98DeCD5eLidxq.jpg'),
(146527, 10451, 'Doctor Who (2024) S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/378236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y0oixiNRCAfRlt98DeCD5eLidxq.jpg'),
(146528, 10451, 'Doctor Who (2024) S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/387441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y0oixiNRCAfRlt98DeCD5eLidxq.jpg'),
(146529, 10451, 'Doctor Who (2024) S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/392713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y0oixiNRCAfRlt98DeCD5eLidxq.jpg'),
(146530, 10452, 'Doctor Who (2024) S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/641077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y0oixiNRCAfRlt98DeCD5eLidxq.jpg'),
(146531, 10452, 'Doctor Who (2024) S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/767619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y0oixiNRCAfRlt98DeCD5eLidxq.jpg'),
(146532, 10452, 'Doctor Who (2024) S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/776812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y0oixiNRCAfRlt98DeCD5eLidxq.jpg'),
(146533, 10452, 'Doctor Who (2024) S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/784861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y0oixiNRCAfRlt98DeCD5eLidxq.jpg'),
(146534, 10452, 'Doctor Who (2024) S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/795074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y0oixiNRCAfRlt98DeCD5eLidxq.jpg'),
(146535, 10452, 'Doctor Who (2024) S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/798651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y0oixiNRCAfRlt98DeCD5eLidxq.jpg'),
(146536, 10452, 'Doctor Who (2024) S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/799350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y0oixiNRCAfRlt98DeCD5eLidxq.jpg'),
(146537, 10452, 'Doctor Who (2024) S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/810253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y0oixiNRCAfRlt98DeCD5eLidxq.jpg'),
(146538, 10452, 'Doctor Who (2024) S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/822669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y0oixiNRCAfRlt98DeCD5eLidxq.jpg'),
(146539, 10453, 'A Batalha das Vovos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/348485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/40hyB76sdAzZHa9zVYhxvMQlMHv.jpg'),
(146540, 10453, 'A Batalha das Vovos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/348486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/40hyB76sdAzZHa9zVYhxvMQlMHv.jpg'),
(146541, 10453, 'A Batalha das Vovos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/348487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/40hyB76sdAzZHa9zVYhxvMQlMHv.jpg'),
(146542, 10453, 'A Batalha das Vovos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/348488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/40hyB76sdAzZHa9zVYhxvMQlMHv.jpg'),
(146543, 10453, 'A Batalha das Vovos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/348489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/40hyB76sdAzZHa9zVYhxvMQlMHv.jpg'),
(146544, 10453, 'A Batalha das Vovos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/348490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/40hyB76sdAzZHa9zVYhxvMQlMHv.jpg'),
(146545, 10454, 'Aeroporto Miami S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/348466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uwiQbag5A7K0k7RMWa20fJBb8sq.jpg'),
(146546, 10454, 'Aeroporto Miami S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/348467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nmzofyGHmnuxJNdgdIrvboX8qUj.jpg'),
(146547, 10454, 'Aeroporto Miami S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/348468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g6Fixh8lgP9dLVlhMBuOkxiZ3Ow.jpg'),
(146548, 10454, 'Aeroporto Miami S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/348469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/riuUDmzokGkXzutHQILp0D7tC6.jpg'),
(146549, 10454, 'Aeroporto Miami S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/348470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lrDy0erRhYTMUF46C3dtztI0c8e.jpg'),
(146550, 10454, 'Aeroporto Miami S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/348471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rczlAL8YC887cY2m1ABG4d4isTJ.jpg'),
(146551, 10455, 'Aeroporto Miami S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/348472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mFVZHweM29vR88w63xbTYpTmbRF.jpg'),
(146552, 10455, 'Aeroporto Miami S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/348473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eGM8vFnfyKCqCjfKZWTnfKu2vv3.jpg'),
(146553, 10455, 'Aeroporto Miami S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/348474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sLYyJ2fHP6NZBsrwarwpspuF13U.jpg'),
(146554, 10455, 'Aeroporto Miami S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/348475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/spMi8RpJjN26sWfGzWjYSLC3IiR.jpg'),
(146555, 10455, 'Aeroporto Miami S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/348476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gHRrGH7ZRxOBxRcZ5EeSUTzociY.jpg'),
(146556, 10455, 'Aeroporto Miami S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/348477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6MoEnPPNyARMHE6gWdrbLD20whJ.jpg'),
(146557, 10455, 'Aeroporto Miami S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/348478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6MoEnPPNyARMHE6gWdrbLD20whJ.jpg'),
(146558, 10455, 'Aeroporto Miami S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/348479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6MoEnPPNyARMHE6gWdrbLD20whJ.jpg'),
(146559, 10455, 'Aeroporto Miami S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/348480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6MoEnPPNyARMHE6gWdrbLD20whJ.jpg'),
(146560, 10455, 'Aeroporto Miami S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/348481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6MoEnPPNyARMHE6gWdrbLD20whJ.jpg'),
(146561, 10455, 'Aeroporto Miami S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/348482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6MoEnPPNyARMHE6gWdrbLD20whJ.jpg'),
(146562, 10455, 'Aeroporto Miami S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/348483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6MoEnPPNyARMHE6gWdrbLD20whJ.jpg'),
(146563, 10455, 'Aeroporto Miami S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/348484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6MoEnPPNyARMHE6gWdrbLD20whJ.jpg'),
(146564, 10456, 'Bleach S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/600871.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/huSX6KKEAQFB2SovmsbQtPED8DJ.jpg'),
(146565, 10456, 'Bleach S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/600872.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eXeX0NFS3hYQ3KXUaHykyTZhSDF.jpg'),
(146566, 10456, 'Bleach S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/600873.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kLg5TqWattin5QslAhbexZhqH68.jpg'),
(146567, 10456, 'Bleach S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/600874.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j2NoxgG8FBksGoVN1JkduZxPYCJ.jpg'),
(146568, 10456, 'Bleach S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/600875.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/62RW37FNZsMx5RUxJTwI3kKSsqX.jpg'),
(146569, 10456, 'Bleach S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/600876.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eBWiMi4mS0P2OloRsqsphsDzk8Z.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(146570, 10456, 'Bleach S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/600877.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xJXBwHZbhFsKxogHDbdDQ1pJH8S.jpg'),
(146571, 10456, 'Bleach S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/600878.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dYW4AYxxYAnpZPgjg94wVBFNPRz.jpg'),
(146572, 10456, 'Bleach S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/600879.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iKxBjbqvkQX8b3HAi34uF5gsBZq.jpg'),
(146573, 10456, 'Bleach S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/600880.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tFtQxb6ytqPR1A6PTVXkZzBl236.jpg'),
(146574, 10456, 'Bleach S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/600881.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/38I0hBskBtE4fLTBcjEGHNUTpO3.jpg'),
(146575, 10456, 'Bleach S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/600882.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qSRgYBS3PQ3wk2ZzbTy6tikz9Ro.jpg'),
(146576, 10456, 'Bleach S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/600883.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m5uys78Y23oNqXXyv79YtHEHuBI.jpg'),
(146577, 10456, 'Bleach S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/600884.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/npx4CFxK0orcShKETRX2CV0iClA.jpg'),
(146578, 10456, 'Bleach S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/600885.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oSTyMKcT5ah7dJQae5K320aPbp6.jpg'),
(146579, 10456, 'Bleach S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/600886.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zvAAc5hHM6beYEkNczqb7ve3QjM.jpg'),
(146580, 10456, 'Bleach S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/600887.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uqSNYBNWvjx0800oqWs3My7DMPN.jpg'),
(146581, 10456, 'Bleach S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/600888.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wOfLJ6LLukmuj0SXMusijt1AShL.jpg'),
(146582, 10456, 'Bleach S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/600889.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6dcvUv1TjemshrIcNYOLdULYxRn.jpg'),
(146583, 10456, 'Bleach S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/600890.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dQbyG18WnaLOrrmzQIVz7q5dnIs.jpg'),
(146584, 10457, 'Bleach S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/600891.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zGfMQ0J1tfmSWzE9jRvZeDt5vN0.jpg'),
(146585, 10457, 'Bleach S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/600892.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6a2mg7CAhWBTJkHsffRtH6jxExb.jpg'),
(146586, 10457, 'Bleach S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/600893.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/S4tZVBDNcHlDvRcF5Vcu3jeNkO.jpg'),
(146587, 10457, 'Bleach S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/600894.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eEeN76dqEXQq4Czgnt2WyM9BMQk.jpg'),
(146588, 10457, 'Bleach S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/600895.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1i7fH1SmouIPgv9gXlPnlsxWFir.jpg'),
(146589, 10457, 'Bleach S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/600896.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lyqVlNRnNvYfr6Z6HZqAJLk1pL4.jpg'),
(146590, 10457, 'Bleach S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/600897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146591, 10457, 'Bleach S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/600898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146592, 10457, 'Bleach S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/600899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146593, 10457, 'Bleach S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/600900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146594, 10457, 'Bleach S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/600901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146595, 10457, 'Bleach S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/600902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146596, 10457, 'Bleach S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/600903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146597, 10457, 'Bleach S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/600904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146598, 10457, 'Bleach S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/600905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146599, 10457, 'Bleach S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/600906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146600, 10457, 'Bleach S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/600907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146601, 10457, 'Bleach S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/600908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146602, 10457, 'Bleach S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/600909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146603, 10457, 'Bleach S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/600910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146604, 10457, 'Bleach S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/600911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146605, 10458, 'Bleach S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/600912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146606, 10458, 'Bleach S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/600913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146607, 10458, 'Bleach S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/600914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146608, 10458, 'Bleach S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/600915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146609, 10458, 'Bleach S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/600916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146610, 10458, 'Bleach S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/600917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146611, 10458, 'Bleach S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/600918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146612, 10458, 'Bleach S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/600919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146613, 10458, 'Bleach S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/600920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146614, 10458, 'Bleach S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/600921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146615, 10458, 'Bleach S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/600922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146616, 10458, 'Bleach S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/600923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146617, 10458, 'Bleach S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/600924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146618, 10458, 'Bleach S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/600925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146619, 10458, 'Bleach S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/600926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146620, 10458, 'Bleach S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/600927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146621, 10458, 'Bleach S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/600928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146622, 10458, 'Bleach S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/600929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146623, 10458, 'Bleach S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/600930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146624, 10458, 'Bleach S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/600931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146625, 10458, 'Bleach S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/600932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146626, 10458, 'Bleach S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/600933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146627, 10459, 'Bleach S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/600934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146628, 10459, 'Bleach S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/600935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146629, 10459, 'Bleach S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/600936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146630, 10459, 'Bleach S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/600937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146631, 10459, 'Bleach S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/600938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146632, 10459, 'Bleach S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/600939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146633, 10459, 'Bleach S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/600940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146634, 10459, 'Bleach S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/600941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146635, 10459, 'Bleach S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/600942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146636, 10459, 'Bleach S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/600943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146637, 10459, 'Bleach S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/600944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146638, 10459, 'Bleach S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/600945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146639, 10459, 'Bleach S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/600946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146640, 10459, 'Bleach S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/600947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146641, 10459, 'Bleach S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/600948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146642, 10459, 'Bleach S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/600949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146643, 10459, 'Bleach S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/600950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146644, 10459, 'Bleach S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/600951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146645, 10459, 'Bleach S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/600952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146646, 10459, 'Bleach S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/600953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146647, 10459, 'Bleach S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/600954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146648, 10459, 'Bleach S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/600955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146649, 10459, 'Bleach S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/600956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146650, 10459, 'Bleach S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/600957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146651, 10459, 'Bleach S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/600958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146652, 10459, 'Bleach S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/600959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146653, 10459, 'Bleach S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/600960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146654, 10459, 'Bleach S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/600961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146655, 10460, 'Bleach S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/600962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146656, 10460, 'Bleach S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/600963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146657, 10460, 'Bleach S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/600964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146658, 10460, 'Bleach S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/600965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146659, 10460, 'Bleach S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/600966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146660, 10460, 'Bleach S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/600967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146661, 10460, 'Bleach S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/600968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146662, 10460, 'Bleach S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/600969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146663, 10460, 'Bleach S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/600970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146664, 10460, 'Bleach S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/600971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146665, 10460, 'Bleach S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/600972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146666, 10460, 'Bleach S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/600973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146667, 10460, 'Bleach S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/600974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146668, 10460, 'Bleach S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/600975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146669, 10460, 'Bleach S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/600976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146670, 10460, 'Bleach S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/600977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146671, 10460, 'Bleach S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/600978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146672, 10460, 'Bleach S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/600979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146673, 10461, 'Bleach S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/600980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146674, 10461, 'Bleach S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/600981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146675, 10461, 'Bleach S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/600982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146676, 10461, 'Bleach S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/600983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146677, 10461, 'Bleach S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/600984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146678, 10461, 'Bleach S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/600985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146679, 10461, 'Bleach S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/600986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146680, 10461, 'Bleach S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/600987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146681, 10461, 'Bleach S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/600988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146682, 10461, 'Bleach S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/600989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146683, 10461, 'Bleach S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/600990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146684, 10461, 'Bleach S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/600991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146685, 10461, 'Bleach S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/600992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146686, 10461, 'Bleach S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/600993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146687, 10461, 'Bleach S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/600994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146688, 10461, 'Bleach S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/600995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146689, 10461, 'Bleach S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/600996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146690, 10461, 'Bleach S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/600997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146691, 10461, 'Bleach S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/600998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146692, 10461, 'Bleach S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/600999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146693, 10461, 'Bleach S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/601000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146694, 10461, 'Bleach S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/601001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146695, 10462, 'Bleach S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/601002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146696, 10462, 'Bleach S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/601003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146697, 10462, 'Bleach S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/601004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146698, 10462, 'Bleach S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/601005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146699, 10462, 'Bleach S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/601006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146700, 10462, 'Bleach S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/601007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146701, 10462, 'Bleach S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/601008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146702, 10462, 'Bleach S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/601009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146703, 10462, 'Bleach S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/601010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146704, 10462, 'Bleach S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/601011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146705, 10462, 'Bleach S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/601012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146706, 10462, 'Bleach S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/348216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146707, 10462, 'Bleach S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/348217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146708, 10462, 'Bleach S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/348218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146709, 10462, 'Bleach S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/348219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146710, 10462, 'Bleach S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/348220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146711, 10462, 'Bleach S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/348221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146712, 10462, 'Bleach S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/348222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146713, 10462, 'Bleach S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/348223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146714, 10462, 'Bleach S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/348224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146715, 10463, 'Bleach S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/348225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146716, 10463, 'Bleach S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/348226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146717, 10463, 'Bleach S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/348227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146718, 10463, 'Bleach S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/348228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146719, 10463, 'Bleach S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/348229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146720, 10463, 'Bleach S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/348230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146721, 10463, 'Bleach S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/348231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146722, 10463, 'Bleach S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/348232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146723, 10463, 'Bleach S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/348233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146724, 10463, 'Bleach S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/348234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146725, 10463, 'Bleach S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/348235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146726, 10463, 'Bleach S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/348236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146727, 10463, 'Bleach S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/348237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146728, 10463, 'Bleach S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/348238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146729, 10463, 'Bleach S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/348239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146730, 10463, 'Bleach S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/348240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146731, 10464, 'Bleach S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/348241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146732, 10464, 'Bleach S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/348242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146733, 10464, 'Bleach S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/348243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146734, 10464, 'Bleach S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/348244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146735, 10464, 'Bleach S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/348245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146736, 10464, 'Bleach S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/348246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146737, 10464, 'Bleach S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/348247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146738, 10464, 'Bleach S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/348248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146739, 10464, 'Bleach S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/348249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146740, 10464, 'Bleach S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/348250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146741, 10464, 'Bleach S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/348251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146742, 10464, 'Bleach S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/348252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146743, 10464, 'Bleach S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/348253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146744, 10464, 'Bleach S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/348254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146745, 10464, 'Bleach S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/348255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146746, 10464, 'Bleach S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/348256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146747, 10464, 'Bleach S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/348257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146748, 10464, 'Bleach S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/348258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146749, 10464, 'Bleach S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/348259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146750, 10464, 'Bleach S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/348260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146751, 10464, 'Bleach S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/348261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146752, 10464, 'Bleach S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/348262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146753, 10465, 'Bleach S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/348263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146754, 10465, 'Bleach S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/348264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146755, 10465, 'Bleach S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/348265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146756, 10465, 'Bleach S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/348266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146757, 10465, 'Bleach S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/348267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146758, 10465, 'Bleach S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/348268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146759, 10465, 'Bleach S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/348269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146760, 10465, 'Bleach S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/348270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146761, 10465, 'Bleach S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/348271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146762, 10465, 'Bleach S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/348272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146763, 10465, 'Bleach S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/348273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146764, 10465, 'Bleach S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/348274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146765, 10465, 'Bleach S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/348275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146766, 10465, 'Bleach S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/348276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146767, 10465, 'Bleach S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/348277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146768, 10465, 'Bleach S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/348278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146769, 10466, 'Bleach S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/348279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146770, 10466, 'Bleach S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/348280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146771, 10466, 'Bleach S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/348281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146772, 10466, 'Bleach S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/348282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146773, 10466, 'Bleach S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/348283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146774, 10466, 'Bleach S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/348284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146775, 10466, 'Bleach S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/348285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146776, 10466, 'Bleach S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/348286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146777, 10466, 'Bleach S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/348287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146778, 10467, 'Bleach S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/348288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146779, 10467, 'Bleach S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/348289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146780, 10467, 'Bleach S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/348290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146781, 10467, 'Bleach S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/348291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146782, 10467, 'Bleach S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/348292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146783, 10467, 'Bleach S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/348293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146784, 10467, 'Bleach S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/348294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146785, 10467, 'Bleach S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/348295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146786, 10467, 'Bleach S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/348296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146787, 10467, 'Bleach S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/348297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146788, 10467, 'Bleach S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/348298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146789, 10467, 'Bleach S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/348299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146790, 10467, 'Bleach S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/348300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146791, 10467, 'Bleach S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/348301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146792, 10467, 'Bleach S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/348302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146793, 10468, 'Bleach S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/348303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146794, 10468, 'Bleach S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/348304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146795, 10468, 'Bleach S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/348305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146796, 10468, 'Bleach S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/348306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146797, 10468, 'Bleach S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/348307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146798, 10468, 'Bleach S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/348308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146799, 10468, 'Bleach S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/348309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146800, 10468, 'Bleach S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/348310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146801, 10468, 'Bleach S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/348311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146802, 10468, 'Bleach S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/348312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146803, 10468, 'Bleach S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/348313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146804, 10468, 'Bleach S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/348314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146805, 10468, 'Bleach S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/348315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146806, 10468, 'Bleach S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/348316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146807, 10468, 'Bleach S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/348317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146808, 10468, 'Bleach S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/348318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146809, 10468, 'Bleach S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/348319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146810, 10468, 'Bleach S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/348320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146811, 10468, 'Bleach S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/348321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146812, 10468, 'Bleach S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/348322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146813, 10468, 'Bleach S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/348323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146814, 10468, 'Bleach S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/348324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146815, 10468, 'Bleach S13 E23', 'http://sinalprivado.info:80/series/1533784/1533784/348325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146816, 10468, 'Bleach S13 E24', 'http://sinalprivado.info:80/series/1533784/1533784/348326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146817, 10468, 'Bleach S13 E25', 'http://sinalprivado.info:80/series/1533784/1533784/348327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146818, 10468, 'Bleach S13 E26', 'http://sinalprivado.info:80/series/1533784/1533784/348328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146819, 10468, 'Bleach S13 E27', 'http://sinalprivado.info:80/series/1533784/1533784/348329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146820, 10468, 'Bleach S13 E28', 'http://sinalprivado.info:80/series/1533784/1533784/348330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146821, 10468, 'Bleach S13 E29', 'http://sinalprivado.info:80/series/1533784/1533784/348331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146822, 10468, 'Bleach S13 E30', 'http://sinalprivado.info:80/series/1533784/1533784/348332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146823, 10468, 'Bleach S13 E31', 'http://sinalprivado.info:80/series/1533784/1533784/348333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146824, 10468, 'Bleach S13 E32', 'http://sinalprivado.info:80/series/1533784/1533784/348334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146825, 10468, 'Bleach S13 E33', 'http://sinalprivado.info:80/series/1533784/1533784/348335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146826, 10468, 'Bleach S13 E34', 'http://sinalprivado.info:80/series/1533784/1533784/348336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146827, 10468, 'Bleach S13 E35', 'http://sinalprivado.info:80/series/1533784/1533784/348337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146828, 10468, 'Bleach S13 E36', 'http://sinalprivado.info:80/series/1533784/1533784/348338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146829, 10469, 'Bleach S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/348339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146830, 10469, 'Bleach S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/348340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146831, 10469, 'Bleach S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/348341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146832, 10469, 'Bleach S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/348342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146833, 10469, 'Bleach S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/348343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146834, 10469, 'Bleach S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/348344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146835, 10469, 'Bleach S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/348345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146836, 10469, 'Bleach S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/348346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146837, 10469, 'Bleach S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/348347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146838, 10469, 'Bleach S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/348348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146839, 10469, 'Bleach S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/348349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146840, 10469, 'Bleach S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/348350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146841, 10469, 'Bleach S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/348351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146842, 10469, 'Bleach S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/348352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146843, 10469, 'Bleach S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/348353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(146844, 10469, 'Bleach S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/348354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146845, 10469, 'Bleach S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/348355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146846, 10469, 'Bleach S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/348356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146847, 10469, 'Bleach S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/348357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146848, 10469, 'Bleach S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/348358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146849, 10469, 'Bleach S14 E21', 'http://sinalprivado.info:80/series/1533784/1533784/348359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146850, 10469, 'Bleach S14 E22', 'http://sinalprivado.info:80/series/1533784/1533784/348360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146851, 10469, 'Bleach S14 E23', 'http://sinalprivado.info:80/series/1533784/1533784/348361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146852, 10469, 'Bleach S14 E24', 'http://sinalprivado.info:80/series/1533784/1533784/348362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146853, 10469, 'Bleach S14 E25', 'http://sinalprivado.info:80/series/1533784/1533784/348363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146854, 10469, 'Bleach S14 E26', 'http://sinalprivado.info:80/series/1533784/1533784/348364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146855, 10469, 'Bleach S14 E27', 'http://sinalprivado.info:80/series/1533784/1533784/348365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146856, 10469, 'Bleach S14 E28', 'http://sinalprivado.info:80/series/1533784/1533784/348366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146857, 10469, 'Bleach S14 E29', 'http://sinalprivado.info:80/series/1533784/1533784/348367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146858, 10469, 'Bleach S14 E30', 'http://sinalprivado.info:80/series/1533784/1533784/348368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146859, 10469, 'Bleach S14 E31', 'http://sinalprivado.info:80/series/1533784/1533784/348369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146860, 10469, 'Bleach S14 E32', 'http://sinalprivado.info:80/series/1533784/1533784/348370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146861, 10469, 'Bleach S14 E33', 'http://sinalprivado.info:80/series/1533784/1533784/348371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146862, 10469, 'Bleach S14 E34', 'http://sinalprivado.info:80/series/1533784/1533784/348372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146863, 10469, 'Bleach S14 E35', 'http://sinalprivado.info:80/series/1533784/1533784/348373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146864, 10469, 'Bleach S14 E36', 'http://sinalprivado.info:80/series/1533784/1533784/348374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146865, 10469, 'Bleach S14 E37', 'http://sinalprivado.info:80/series/1533784/1533784/348375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146866, 10469, 'Bleach S14 E38', 'http://sinalprivado.info:80/series/1533784/1533784/348376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146867, 10469, 'Bleach S14 E39', 'http://sinalprivado.info:80/series/1533784/1533784/348377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146868, 10469, 'Bleach S14 E40', 'http://sinalprivado.info:80/series/1533784/1533784/348378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146869, 10469, 'Bleach S14 E41', 'http://sinalprivado.info:80/series/1533784/1533784/348379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146870, 10469, 'Bleach S14 E42', 'http://sinalprivado.info:80/series/1533784/1533784/348380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146871, 10469, 'Bleach S14 E43', 'http://sinalprivado.info:80/series/1533784/1533784/348381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146872, 10469, 'Bleach S14 E44', 'http://sinalprivado.info:80/series/1533784/1533784/348382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146873, 10469, 'Bleach S14 E45', 'http://sinalprivado.info:80/series/1533784/1533784/348383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146874, 10469, 'Bleach S14 E46', 'http://sinalprivado.info:80/series/1533784/1533784/348384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146875, 10469, 'Bleach S14 E47', 'http://sinalprivado.info:80/series/1533784/1533784/348385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146876, 10469, 'Bleach S14 E48', 'http://sinalprivado.info:80/series/1533784/1533784/348386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146877, 10469, 'Bleach S14 E49', 'http://sinalprivado.info:80/series/1533784/1533784/348387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146878, 10469, 'Bleach S14 E50', 'http://sinalprivado.info:80/series/1533784/1533784/348388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146879, 10469, 'Bleach S14 E51', 'http://sinalprivado.info:80/series/1533784/1533784/348389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146880, 10470, 'Bleach S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/348390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146881, 10470, 'Bleach S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/348391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146882, 10470, 'Bleach S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/348392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146883, 10470, 'Bleach S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/348393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146884, 10470, 'Bleach S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/348394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146885, 10470, 'Bleach S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/348395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146886, 10470, 'Bleach S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/348396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146887, 10470, 'Bleach S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/348397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146888, 10470, 'Bleach S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/348398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146889, 10470, 'Bleach S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/348399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146890, 10470, 'Bleach S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/348400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146891, 10470, 'Bleach S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/348401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146892, 10470, 'Bleach S15 E13', 'http://sinalprivado.info:80/series/1533784/1533784/348402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146893, 10470, 'Bleach S15 E14', 'http://sinalprivado.info:80/series/1533784/1533784/348403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146894, 10470, 'Bleach S15 E15', 'http://sinalprivado.info:80/series/1533784/1533784/348404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146895, 10470, 'Bleach S15 E16', 'http://sinalprivado.info:80/series/1533784/1533784/348405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146896, 10470, 'Bleach S15 E17', 'http://sinalprivado.info:80/series/1533784/1533784/348406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146897, 10470, 'Bleach S15 E18', 'http://sinalprivado.info:80/series/1533784/1533784/348407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146898, 10470, 'Bleach S15 E19', 'http://sinalprivado.info:80/series/1533784/1533784/348408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146899, 10470, 'Bleach S15 E20', 'http://sinalprivado.info:80/series/1533784/1533784/348409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146900, 10470, 'Bleach S15 E21', 'http://sinalprivado.info:80/series/1533784/1533784/348410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146901, 10470, 'Bleach S15 E22', 'http://sinalprivado.info:80/series/1533784/1533784/348411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146902, 10470, 'Bleach S15 E23', 'http://sinalprivado.info:80/series/1533784/1533784/348412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146903, 10470, 'Bleach S15 E24', 'http://sinalprivado.info:80/series/1533784/1533784/348413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146904, 10470, 'Bleach S15 E25', 'http://sinalprivado.info:80/series/1533784/1533784/348414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146905, 10470, 'Bleach S15 E26', 'http://sinalprivado.info:80/series/1533784/1533784/348415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146906, 10471, 'Bleach S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/348416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146907, 10471, 'Bleach S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/348417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146908, 10471, 'Bleach S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/348418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146909, 10471, 'Bleach S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/348419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146910, 10471, 'Bleach S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/348420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146911, 10471, 'Bleach S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/348421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146912, 10471, 'Bleach S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/348422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146913, 10471, 'Bleach S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/348423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146914, 10471, 'Bleach S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/348424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146915, 10471, 'Bleach S16 E10', 'http://sinalprivado.info:80/series/1533784/1533784/348425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146916, 10471, 'Bleach S16 E11', 'http://sinalprivado.info:80/series/1533784/1533784/348426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146917, 10471, 'Bleach S16 E12', 'http://sinalprivado.info:80/series/1533784/1533784/348427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146918, 10471, 'Bleach S16 E13', 'http://sinalprivado.info:80/series/1533784/1533784/348428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146919, 10471, 'Bleach S16 E14', 'http://sinalprivado.info:80/series/1533784/1533784/348429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146920, 10471, 'Bleach S16 E15', 'http://sinalprivado.info:80/series/1533784/1533784/348430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146921, 10471, 'Bleach S16 E16', 'http://sinalprivado.info:80/series/1533784/1533784/348431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146922, 10471, 'Bleach S16 E17', 'http://sinalprivado.info:80/series/1533784/1533784/348432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146923, 10471, 'Bleach S16 E18', 'http://sinalprivado.info:80/series/1533784/1533784/348433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146924, 10471, 'Bleach S16 E19', 'http://sinalprivado.info:80/series/1533784/1533784/348434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146925, 10471, 'Bleach S16 E20', 'http://sinalprivado.info:80/series/1533784/1533784/348435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146926, 10471, 'Bleach S16 E21', 'http://sinalprivado.info:80/series/1533784/1533784/348436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146927, 10471, 'Bleach S16 E22', 'http://sinalprivado.info:80/series/1533784/1533784/348437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146928, 10471, 'Bleach S16 E23', 'http://sinalprivado.info:80/series/1533784/1533784/348438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146929, 10471, 'Bleach S16 E24', 'http://sinalprivado.info:80/series/1533784/1533784/348439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146930, 10472, 'Bleach S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/702520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146931, 10472, 'Bleach S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/702521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146932, 10472, 'Bleach S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/702522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146933, 10472, 'Bleach S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/702523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146934, 10472, 'Bleach S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/702524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146935, 10472, 'Bleach S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/702525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146936, 10472, 'Bleach S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/702526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146937, 10472, 'Bleach S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/702527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146938, 10472, 'Bleach S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/702528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146939, 10472, 'Bleach S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/702529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146940, 10472, 'Bleach S17 E11', 'http://sinalprivado.info:80/series/1533784/1533784/702530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146941, 10472, 'Bleach S17 E12', 'http://sinalprivado.info:80/series/1533784/1533784/702531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146942, 10472, 'Bleach S17 E13', 'http://sinalprivado.info:80/series/1533784/1533784/702532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146943, 10472, 'Bleach S17 E14', 'http://sinalprivado.info:80/series/1533784/1533784/702533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146944, 10472, 'Bleach S17 E15', 'http://sinalprivado.info:80/series/1533784/1533784/702534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146945, 10472, 'Bleach S17 E16', 'http://sinalprivado.info:80/series/1533784/1533784/702535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146946, 10472, 'Bleach S17 E17', 'http://sinalprivado.info:80/series/1533784/1533784/702536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146947, 10472, 'Bleach S17 E18', 'http://sinalprivado.info:80/series/1533784/1533784/702537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146948, 10472, 'Bleach S17 E19', 'http://sinalprivado.info:80/series/1533784/1533784/702538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146949, 10472, 'Bleach S17 E20', 'http://sinalprivado.info:80/series/1533784/1533784/702539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146950, 10472, 'Bleach S17 E21', 'http://sinalprivado.info:80/series/1533784/1533784/702540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146951, 10472, 'Bleach S17 E22', 'http://sinalprivado.info:80/series/1533784/1533784/702541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146952, 10472, 'Bleach S17 E23', 'http://sinalprivado.info:80/series/1533784/1533784/702542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146953, 10472, 'Bleach S17 E24', 'http://sinalprivado.info:80/series/1533784/1533784/702543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146954, 10472, 'Bleach S17 E25', 'http://sinalprivado.info:80/series/1533784/1533784/702544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146955, 10472, 'Bleach S17 E26', 'http://sinalprivado.info:80/series/1533784/1533784/702545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146956, 10472, 'Bleach S17 E27', 'http://sinalprivado.info:80/series/1533784/1533784/702546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146957, 10472, 'Bleach S17 E28', 'http://sinalprivado.info:80/series/1533784/1533784/702547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146958, 10472, 'Bleach S17 E29', 'http://sinalprivado.info:80/series/1533784/1533784/702548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146959, 10472, 'Bleach S17 E30', 'http://sinalprivado.info:80/series/1533784/1533784/702549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146960, 10472, 'Bleach S17 E31', 'http://sinalprivado.info:80/series/1533784/1533784/702550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146961, 10472, 'Bleach S17 E32', 'http://sinalprivado.info:80/series/1533784/1533784/702551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146962, 10472, 'Bleach S17 E33', 'http://sinalprivado.info:80/series/1533784/1533784/702552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146963, 10472, 'Bleach S17 E34', 'http://sinalprivado.info:80/series/1533784/1533784/702553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146964, 10472, 'Bleach S17 E35', 'http://sinalprivado.info:80/series/1533784/1533784/702554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146965, 10472, 'Bleach S17 E36', 'http://sinalprivado.info:80/series/1533784/1533784/702555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146966, 10472, 'Bleach S17 E37', 'http://sinalprivado.info:80/series/1533784/1533784/702556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146967, 10472, 'Bleach S17 E38', 'http://sinalprivado.info:80/series/1533784/1533784/702557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146968, 10472, 'Bleach S17 E39', 'http://sinalprivado.info:80/series/1533784/1533784/702558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146969, 10472, 'Bleach S17 E40', 'http://sinalprivado.info:80/series/1533784/1533784/702559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146970, 10472, 'Bleach S17 E41', 'http://sinalprivado.info:80/series/1533784/1533784/348440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146971, 10472, 'Bleach S17 E42', 'http://sinalprivado.info:80/series/1533784/1533784/348441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146972, 10472, 'Bleach S17 E43', 'http://sinalprivado.info:80/series/1533784/1533784/348442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146973, 10472, 'Bleach S17 E44', 'http://sinalprivado.info:80/series/1533784/1533784/348443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146974, 10472, 'Bleach S17 E45', 'http://sinalprivado.info:80/series/1533784/1533784/348444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146975, 10472, 'Bleach S17 E46', 'http://sinalprivado.info:80/series/1533784/1533784/348445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146976, 10472, 'Bleach S17 E47', 'http://sinalprivado.info:80/series/1533784/1533784/348446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146977, 10472, 'Bleach S17 E48', 'http://sinalprivado.info:80/series/1533784/1533784/348447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146978, 10472, 'Bleach S17 E49', 'http://sinalprivado.info:80/series/1533784/1533784/348448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146979, 10472, 'Bleach S17 E50', 'http://sinalprivado.info:80/series/1533784/1533784/348449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146980, 10472, 'Bleach S17 E51', 'http://sinalprivado.info:80/series/1533784/1533784/348450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146981, 10472, 'Bleach S17 E52', 'http://sinalprivado.info:80/series/1533784/1533784/348451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146982, 10472, 'Bleach S17 E53', 'http://sinalprivado.info:80/series/1533784/1533784/348452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146983, 10472, 'Bleach S17 E54', 'http://sinalprivado.info:80/series/1533784/1533784/348453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146984, 10472, 'Bleach S17 E55', 'http://sinalprivado.info:80/series/1533784/1533784/348454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146985, 10472, 'Bleach S17 E56', 'http://sinalprivado.info:80/series/1533784/1533784/348455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146986, 10472, 'Bleach S17 E57', 'http://sinalprivado.info:80/series/1533784/1533784/348456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146987, 10472, 'Bleach S17 E58', 'http://sinalprivado.info:80/series/1533784/1533784/348457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146988, 10472, 'Bleach S17 E59', 'http://sinalprivado.info:80/series/1533784/1533784/348458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146989, 10472, 'Bleach S17 E60', 'http://sinalprivado.info:80/series/1533784/1533784/348459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146990, 10472, 'Bleach S17 E61', 'http://sinalprivado.info:80/series/1533784/1533784/348460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146991, 10472, 'Bleach S17 E62', 'http://sinalprivado.info:80/series/1533784/1533784/348461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146992, 10472, 'Bleach S17 E63', 'http://sinalprivado.info:80/series/1533784/1533784/348462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146993, 10472, 'Bleach S17 E64', 'http://sinalprivado.info:80/series/1533784/1533784/348463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146994, 10472, 'Bleach S17 E65', 'http://sinalprivado.info:80/series/1533784/1533784/348464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146995, 10472, 'Bleach S17 E66', 'http://sinalprivado.info:80/series/1533784/1533784/348465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/guyS28A4IxwoMXIq3Xj9AszMefP.jpg'),
(146996, 10473, 'Ingress The Animation S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/348063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/chR4hiuYYFlTxuAFfToSttKVUDV.jpg'),
(146997, 10473, 'Ingress The Animation S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/348064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hLQ19cDu0nZxu0ixHexV5UTg9nj.jpg'),
(146998, 10473, 'Ingress The Animation S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/348065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5nt1hH0xDtoI14QFwWHkq3ccH28.jpg'),
(146999, 10473, 'Ingress The Animation S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/348066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8OjO3DugSCiLvV2rkDXZbHMDWYC.jpg'),
(147000, 10473, 'Ingress The Animation S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/348067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1pg1FCCiR9NaBrvS2SDM9403YWR.jpg'),
(147001, 10473, 'Ingress The Animation S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/348068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gFDPUmC7tyIt3ECzSesCxHSSw8L.jpg'),
(147002, 10473, 'Ingress The Animation S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/348069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eXr3VPnqq6lKGNGCnsJuXvzrCgE.jpg'),
(147003, 10473, 'Ingress The Animation S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/348070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bc3aJnTAAaIB04HR8ER0vnUIWTp.jpg'),
(147004, 10473, 'Ingress The Animation S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/348071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ikvT73bzzx3xNer5kLwMeyscOKx.jpg'),
(147005, 10473, 'Ingress The Animation S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/348072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1toIYqVV3qj2Ix94o839mPYVt6I.jpg'),
(147006, 10473, 'Ingress The Animation S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/348073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ikvT73bzzx3xNer5kLwMeyscOKx.jpg'),
(147007, 10474, 'Kakegurui Twin S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/348057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aT3LMV0wfGEkoM1YMaUgscsNOmx.jpg'),
(147008, 10474, 'Kakegurui Twin S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/348058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iHYIYBAMhc5JTBFXF4x9XbSTwCd.jpg'),
(147009, 10474, 'Kakegurui Twin S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/348059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sH95s0y1vpR6m8oV0u8yUUtMxnp.jpg'),
(147010, 10474, 'Kakegurui Twin S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/348060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A9JvuXoPvX8tIK0wEEPpXDi4Iuf.jpg'),
(147011, 10474, 'Kakegurui Twin S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/348061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4rcA02iXs0NvXHb2QXTWBhzCWue.jpg'),
(147012, 10474, 'Kakegurui Twin S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/348062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yAZG1JpuUeO38h6ZfLKQ8wBQLm1.jpg'),
(147013, 10475, 'O Resort Zoobak S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/348006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147014, 10475, 'O Resort Zoobak S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/348007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147015, 10475, 'O Resort Zoobak S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/348008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147016, 10475, 'O Resort Zoobak S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/348009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147017, 10475, 'O Resort Zoobak S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/348010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147018, 10475, 'O Resort Zoobak S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/348011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147019, 10475, 'O Resort Zoobak S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/348012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147020, 10475, 'O Resort Zoobak S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/348013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147021, 10475, 'O Resort Zoobak S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/348014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147022, 10475, 'O Resort Zoobak S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/348015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147023, 10475, 'O Resort Zoobak S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/348016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147024, 10475, 'O Resort Zoobak S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/348017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147025, 10475, 'O Resort Zoobak S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/348018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147026, 10475, 'O Resort Zoobak S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/348019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147027, 10475, 'O Resort Zoobak S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/348020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147028, 10475, 'O Resort Zoobak S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/348021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147029, 10475, 'O Resort Zoobak S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/348022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147030, 10475, 'O Resort Zoobak S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/348023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147031, 10475, 'O Resort Zoobak S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/348024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147032, 10475, 'O Resort Zoobak S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/348025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147033, 10475, 'O Resort Zoobak S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/348026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147034, 10475, 'O Resort Zoobak S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/348027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147035, 10475, 'O Resort Zoobak S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/348028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147036, 10475, 'O Resort Zoobak S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/348029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147037, 10475, 'O Resort Zoobak S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/348030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147038, 10475, 'O Resort Zoobak S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/348031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147039, 10475, 'O Resort Zoobak S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/348032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147040, 10475, 'O Resort Zoobak S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/348033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147041, 10475, 'O Resort Zoobak S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/348034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147042, 10475, 'O Resort Zoobak S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/348035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147043, 10475, 'O Resort Zoobak S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/348036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147044, 10475, 'O Resort Zoobak S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/348037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147045, 10475, 'O Resort Zoobak S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/348038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147046, 10475, 'O Resort Zoobak S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/348039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147047, 10475, 'O Resort Zoobak S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/348040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147048, 10475, 'O Resort Zoobak S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/348041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147049, 10475, 'O Resort Zoobak S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/348042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147050, 10475, 'O Resort Zoobak S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/348043.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147051, 10475, 'O Resort Zoobak S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/348044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147052, 10475, 'O Resort Zoobak S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/348045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147053, 10475, 'O Resort Zoobak S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/348046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147054, 10475, 'O Resort Zoobak S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/348047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147055, 10475, 'O Resort Zoobak S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/348048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147056, 10475, 'O Resort Zoobak S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/348049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147057, 10475, 'O Resort Zoobak S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/348050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147058, 10475, 'O Resort Zoobak S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/348051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147059, 10475, 'O Resort Zoobak S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/348052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147060, 10475, 'O Resort Zoobak S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/348053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147061, 10475, 'O Resort Zoobak S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/348054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147062, 10475, 'O Resort Zoobak S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/348055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147063, 10475, 'O Resort Zoobak S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/348056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/udCwlz71g5867NgwT8wfwJs43ok.jpg'),
(147064, 10476, 'Os Homens que Venderam a Copa do Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/348004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/atGNCtITRTPjDV0G3tO00JzY0j1.jpg'),
(147065, 10476, 'Os Homens que Venderam a Copa do Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/348005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4DsJuWvn9jcoE946AvJA3g0PX6o.jpg'),
(147066, 10477, 'Os Ursinhos Gummi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Hr5JX25zLCY3pWsTHn4vRj1ktF.jpg'),
(147067, 10477, 'Os Ursinhos Gummi S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/leHUf4PefBA7vPs4SGgkk5rEJCG.jpg'),
(147068, 10477, 'Os Ursinhos Gummi S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5uajvMnSnE4L3ZaimRZsLpjcVpR.jpg'),
(147069, 10477, 'Os Ursinhos Gummi S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yYr4vbARapfx4gHjml2ziHEu5HK.jpg'),
(147070, 10477, 'Os Ursinhos Gummi S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aifaj2K68ekkY4uIGpvRzyTE0OI.jpg'),
(147071, 10477, 'Os Ursinhos Gummi S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gsiStfGmTMVsRHw1wnehJyPaJZA.jpg'),
(147072, 10477, 'Os Ursinhos Gummi S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uD5VjqRVopx43XMzjQGqgSpeiPD.jpg'),
(147073, 10477, 'Os Ursinhos Gummi S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aDistZKHawFrbSBKtmpOmc0WDfb.jpg'),
(147074, 10477, 'Os Ursinhos Gummi S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rPr3bmLr8JXbj2TsHgHeGWLuoc.jpg'),
(147075, 10477, 'Os Ursinhos Gummi S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lFCSZiIblzt7Hxcs1vPqBaTMTYc.jpg'),
(147076, 10477, 'Os Ursinhos Gummi S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Vib80cRmz7K6Prehyvbu1xxdAp.jpg'),
(147077, 10477, 'Os Ursinhos Gummi S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r2u6TAQ16a0ZfjIlkcTQVTGouPW.jpg'),
(147078, 10477, 'Os Ursinhos Gummi S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b2HMRNCUTTnStBcyGwVawVBoAys.jpg'),
(147079, 10478, 'Os Ursinhos Gummi S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oLO32WCPJXnJEPA0bxSW2Dt5QrB.jpg'),
(147080, 10478, 'Os Ursinhos Gummi S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oMZnYpKfJkHaAmCo2jCL1Mj8Zh7.jpg'),
(147081, 10478, 'Os Ursinhos Gummi S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9cXT3J68q7FvHTddJNpSjMJz28J.jpg'),
(147082, 10478, 'Os Ursinhos Gummi S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQCFPkdZgfIlEoxsNvbYwQwOY5B.jpg'),
(147083, 10478, 'Os Ursinhos Gummi S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2gphyKGeqIHZ4FpSd5om7gq6MDr.jpg'),
(147084, 10478, 'Os Ursinhos Gummi S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aeK0MkyMDVQxHLsjKajKIWw6mVr.jpg'),
(147085, 10478, 'Os Ursinhos Gummi S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y4bN9LBqv8Mho4seyJ8qjf0nUOZ.jpg'),
(147086, 10478, 'Os Ursinhos Gummi S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fS4aZVa0zkDhjE13377HLZexHvt.jpg'),
(147087, 10479, 'Os Ursinhos Gummi S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dfyjhFlnUZWugJWfcQTS9B4Hx6I.jpg'),
(147088, 10479, 'Os Ursinhos Gummi S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1X2oFP5vTmyyEPEp82SwX0lFOlm.jpg'),
(147089, 10479, 'Os Ursinhos Gummi S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sejx651NTwhRB6ReT5HM2YzX6TM.jpg'),
(147090, 10479, 'Os Ursinhos Gummi S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/neOhdfOY3WQhKz4ABX8o1kmQgAc.jpg'),
(147091, 10479, 'Os Ursinhos Gummi S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/khz6FdehS5h2ctF85hQKhsL4hNG.jpg'),
(147092, 10479, 'Os Ursinhos Gummi S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yACSqb2IQyQXDSaSd1UseK4TqYW.jpg'),
(147093, 10479, 'Os Ursinhos Gummi S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tTPmCZDYNguuaMgkfZvz6lrkI4u.jpg'),
(147094, 10479, 'Os Ursinhos Gummi S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p5fEFpiolKwI6kxroyaE7Cy6bEV.jpg'),
(147095, 10480, 'Os Ursinhos Gummi S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iUUHZJkFTRBI8leDnTP3g6oZeBZ.jpg'),
(147096, 10480, 'Os Ursinhos Gummi S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r5aFy57EAibv5hri1CBJNbVpwwg.jpg'),
(147097, 10480, 'Os Ursinhos Gummi S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mFglAx5RTrFqMMVwaY1xkBelU81.jpg'),
(147098, 10480, 'Os Ursinhos Gummi S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1dvS8ss6TYvyWvWV6AjKg1S3SPk.jpg'),
(147099, 10480, 'Os Ursinhos Gummi S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Pz2mhCrFpkcfUBocVaenI4kDD1.jpg'),
(147100, 10480, 'Os Ursinhos Gummi S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nVqKRu4JRaGx928GqwGZSbmfAJp.jpg'),
(147101, 10480, 'Os Ursinhos Gummi S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kgsw3w9SuXjzEaA9JNbLAMG9O0A.jpg'),
(147102, 10480, 'Os Ursinhos Gummi S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dHuGbHlBASnrwAg00QN4L2sLIWG.jpg'),
(147103, 10480, 'Os Ursinhos Gummi S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iqK0oxAlbChHdaOZnjb15QAdAgi.jpg'),
(147104, 10480, 'Os Ursinhos Gummi S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5di1ZACkWnXV0xrVCNiST8JfPXq.jpg'),
(147105, 10481, 'Os Ursinhos Gummi S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/21bXUq16Uk8mM1c0HRGuDiDK05n.jpg'),
(147106, 10481, 'Os Ursinhos Gummi S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4L8mSumbmZlDlOGGAFU1FpxAlAE.jpg'),
(147107, 10481, 'Os Ursinhos Gummi S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/molX7dAKdhZaD30zaVdh0wE9hH6.jpg'),
(147108, 10481, 'Os Ursinhos Gummi S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ahuOgrlbOY718WrUMrVFR7ogAll.jpg'),
(147109, 10481, 'Os Ursinhos Gummi S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xs7Bw31e8diBuP0TvEwDPJZ0iL9.jpg'),
(147110, 10481, 'Os Ursinhos Gummi S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9a5psTjCY4wLjIJizU7Bci2bVJe.jpg'),
(147111, 10481, 'Os Ursinhos Gummi S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i9qg1jkCsNBx1UqWYe8wfJ4qy30.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(147112, 10481, 'Os Ursinhos Gummi S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4IADuzAm2e3zJpQWoOhx9ROiaEU.jpg'),
(147113, 10482, 'Os Ursinhos Gummi S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/izoJ6ehrBRYEgke3Fry9BlN9BcC.jpg'),
(147114, 10482, 'Os Ursinhos Gummi S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1MMSRI1SEjnVTNQSxSoqEYZAvLK.jpg'),
(147115, 10482, 'Os Ursinhos Gummi S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQYNogZx5jrdiV1EmeOKRWPDdvv.jpg'),
(147116, 10482, 'Os Ursinhos Gummi S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j1Ab4QZkVKOhWMjxtu8s4UK3NFv.jpg'),
(147117, 10482, 'Os Ursinhos Gummi S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6sncNb6LX0Z1sTdu1qBWT8XgPjl.jpg'),
(147118, 10482, 'Os Ursinhos Gummi S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kL62qB18xpKbC81vxjPh49kJKJB.jpg'),
(147119, 10482, 'Os Ursinhos Gummi S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyRoIHTZ9iyCRix8uAtqfU61lqG.jpg'),
(147120, 10482, 'Os Ursinhos Gummi S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p9p0IbAyiF58N1517n1Rasr8cRR.jpg'),
(147121, 10482, 'Os Ursinhos Gummi S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pprdCSOI7bWIeDmdtxUpvwZANi7.jpg'),
(147122, 10482, 'Os Ursinhos Gummi S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ji8QIdgu2tEfrKvAe9HcwwWLW2T.jpg'),
(147123, 10482, 'Os Ursinhos Gummi S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5AcSPwypnL8AYEI3XwKUcKCCod.jpg'),
(147124, 10482, 'Os Ursinhos Gummi S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j29xcjFIrnJRyZxXxqESxUUDyAZ.jpg'),
(147125, 10482, 'Os Ursinhos Gummi S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6uFs3vtfG1pHyRDL4XxIULU51dS.jpg'),
(147126, 10482, 'Os Ursinhos Gummi S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/347999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/apAvkWy3nX3UDwrVuVsaQgwBLZ0.jpg'),
(147127, 10482, 'Os Ursinhos Gummi S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/348000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i9TujJ5mLlzRho7DUHHBlSJW22Z.jpg'),
(147128, 10482, 'Os Ursinhos Gummi S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/348001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n1cXlP2xLJXZfEWbFjzigWUtQ3P.jpg'),
(147129, 10482, 'Os Ursinhos Gummi S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/348002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wvRx1QtutDWqANM2Vf1TmktSCgk.jpg'),
(147130, 10482, 'Os Ursinhos Gummi S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/348003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xbMPgsvrAjBfb7spNw8Kiwht51f.jpg'),
(147131, 10483, 'Power Rangers Dino Fury S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147132, 10483, 'Power Rangers Dino Fury S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147133, 10483, 'Power Rangers Dino Fury S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147134, 10483, 'Power Rangers Dino Fury S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147135, 10483, 'Power Rangers Dino Fury S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147136, 10483, 'Power Rangers Dino Fury S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147137, 10483, 'Power Rangers Dino Fury S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147138, 10483, 'Power Rangers Dino Fury S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147139, 10483, 'Power Rangers Dino Fury S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147140, 10483, 'Power Rangers Dino Fury S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147141, 10483, 'Power Rangers Dino Fury S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147142, 10483, 'Power Rangers Dino Fury S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147143, 10483, 'Power Rangers Dino Fury S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147144, 10483, 'Power Rangers Dino Fury S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/347908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147145, 10483, 'Power Rangers Dino Fury S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/347909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147146, 10483, 'Power Rangers Dino Fury S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/347910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147147, 10483, 'Power Rangers Dino Fury S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/347911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147148, 10483, 'Power Rangers Dino Fury S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/347912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147149, 10483, 'Power Rangers Dino Fury S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/347913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147150, 10483, 'Power Rangers Dino Fury S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/347914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147151, 10483, 'Power Rangers Dino Fury S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/347915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147152, 10483, 'Power Rangers Dino Fury S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/347916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147153, 10484, 'Power Rangers Dino Fury S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147154, 10484, 'Power Rangers Dino Fury S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147155, 10484, 'Power Rangers Dino Fury S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147156, 10484, 'Power Rangers Dino Fury S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147157, 10484, 'Power Rangers Dino Fury S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147158, 10484, 'Power Rangers Dino Fury S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147159, 10484, 'Power Rangers Dino Fury S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147160, 10484, 'Power Rangers Dino Fury S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147161, 10484, 'Power Rangers Dino Fury S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147162, 10484, 'Power Rangers Dino Fury S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147163, 10484, 'Power Rangers Dino Fury S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147164, 10484, 'Power Rangers Dino Fury S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147165, 10484, 'Power Rangers Dino Fury S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147166, 10484, 'Power Rangers Dino Fury S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/347930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147167, 10484, 'Power Rangers Dino Fury S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/347931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147168, 10484, 'Power Rangers Dino Fury S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/347932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147169, 10484, 'Power Rangers Dino Fury S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/347933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147170, 10484, 'Power Rangers Dino Fury S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/347934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147171, 10484, 'Power Rangers Dino Fury S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/347935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147172, 10484, 'Power Rangers Dino Fury S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/347936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147173, 10484, 'Power Rangers Dino Fury S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/347937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147174, 10484, 'Power Rangers Dino Fury S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/347938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRPd2PZA7tnxBzfoayEwpJwjjG3.jpg'),
(147175, 10485, 'Reborn S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/354898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ZxoniLASiGYEchZK2wsISabokq.jpg'),
(147176, 10485, 'Reborn S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/354899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qwBK2wKZPX0SMgenRdFeiUfTX2U.jpg'),
(147177, 10485, 'Reborn S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/354900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147178, 10485, 'Reborn S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/363194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147179, 10485, 'Reborn S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/401569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147180, 10485, 'Reborn S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/893067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147181, 10485, 'Reborn S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/401570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147182, 10485, 'Reborn S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/401571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147183, 10485, 'Reborn S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/401572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147184, 10485, 'Reborn S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/401573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147185, 10485, 'Reborn S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/407178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147186, 10485, 'Reborn S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/415561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147187, 10485, 'Reborn S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/418206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147188, 10485, 'Reborn S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/697538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147189, 10485, 'Reborn S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/701174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147190, 10485, 'Reborn S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/701175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147191, 10485, 'Reborn S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/701176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147192, 10485, 'Reborn S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/704313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147193, 10485, 'Reborn S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/704314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147194, 10485, 'Reborn S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/716007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147195, 10485, 'Reborn S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/716008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147196, 10485, 'Reborn S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/716009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147197, 10485, 'Reborn S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/716010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147198, 10485, 'Reborn S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/716011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147199, 10485, 'Reborn S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/716012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147200, 10485, 'Reborn S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/717438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147201, 10485, 'Reborn S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/717439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147202, 10485, 'Reborn S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/717440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147203, 10485, 'Reborn S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/717441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147204, 10485, 'Reborn S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/723832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147205, 10485, 'Reborn S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/723833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147206, 10485, 'Reborn S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/723834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147207, 10485, 'Reborn S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/723835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147208, 10486, 'Reborn S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/893068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147209, 10486, 'Reborn S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/893069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147210, 10486, 'Reborn S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/893070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147211, 10486, 'Reborn S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/893071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147212, 10486, 'Reborn S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/893072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147213, 10486, 'Reborn S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/893073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147214, 10486, 'Reborn S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/893074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147215, 10486, 'Reborn S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/893075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147216, 10486, 'Reborn S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/893076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147217, 10486, 'Reborn S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/893077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147218, 10486, 'Reborn S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/893078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147219, 10486, 'Reborn S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/893079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147220, 10486, 'Reborn S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/893080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147221, 10486, 'Reborn S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/893081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147222, 10486, 'Reborn S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/893082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147223, 10486, 'Reborn S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/893083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147224, 10486, 'Reborn S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/893084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147225, 10486, 'Reborn S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/893085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147226, 10486, 'Reborn S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/893086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147227, 10486, 'Reborn S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/893087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147228, 10486, 'Reborn S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/893088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147229, 10486, 'Reborn S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/893089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147230, 10486, 'Reborn S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/893090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147231, 10486, 'Reborn S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/893091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147232, 10486, 'Reborn S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/893092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147233, 10486, 'Reborn S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/893093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147234, 10486, 'Reborn S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/893094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147235, 10486, 'Reborn S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/893095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147236, 10486, 'Reborn S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/893096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147237, 10486, 'Reborn S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/893097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147238, 10486, 'Reborn S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/893098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6x7mx9f3ufHCC3pNgMoMnzVo3jw.jpg'),
(147239, 10487, 'SPRIGGAN S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1DgqWHxZs3yolhpaQzXDyRO0nSU.jpg'),
(147240, 10487, 'SPRIGGAN S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u8D3XZcQqdJkebz4J80LSQMWmQ.jpg'),
(147241, 10487, 'SPRIGGAN S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nRXz7Y63FSZjoIeqsDFNaHycHbO.jpg'),
(147242, 10487, 'SPRIGGAN S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zq5e26ExKZ8DHg9tBqW4Sp7FRmu.jpg'),
(147243, 10487, 'SPRIGGAN S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/umKaLKVcJFEbnvZoxuN335T5ncE.jpg'),
(147244, 10487, 'SPRIGGAN S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gRgHA40vShTbRRrpjk1c8nnxlqD.jpg'),
(147245, 10488, 'Saiki Kusuo no Psi nan Reativado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/or8XjEy86CBIHkrTPzUQeBczxRQ.jpg'),
(147246, 10488, 'Saiki Kusuo no Psi nan Reativado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pq3dkpyonQhhD6IK7XFvSkrRYK6.jpg'),
(147247, 10488, 'Saiki Kusuo no Psi nan Reativado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dAk4pfN6ywUl1GeRaaAw6rxu18T.jpg'),
(147248, 10488, 'Saiki Kusuo no Psi nan Reativado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zgfqwBS5qm2nrRG2Q8o09QF7DFq.jpg'),
(147249, 10488, 'Saiki Kusuo no Psi nan Reativado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6WlU9GR7gt4uFsRaiAAg1yXAlTM.jpg'),
(147250, 10488, 'Saiki Kusuo no Psi nan Reativado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bfnXlQfsApeh4pymA6ocbVdOvGr.jpg'),
(147251, 10489, 'Sete Segundos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eoLzhoY0TM35IsiT35EIPWAGrfs.jpg'),
(147252, 10489, 'Sete Segundos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3dpcjJrr3NhERqcUuUi3LNKzeNE.jpg'),
(147253, 10489, 'Sete Segundos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r11mWi8xI4CbyH5D619tot8lXoV.jpg'),
(147254, 10489, 'Sete Segundos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1o54g683IeSsnOKLWh9lVvbgbTJ.jpg'),
(147255, 10489, 'Sete Segundos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pNeJkE2wAxyk6D3i0aWF2ydF1B1.jpg'),
(147256, 10489, 'Sete Segundos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ktfSCRSvXJNM4tZsHgOcTsRsJkZ.jpg'),
(147257, 10489, 'Sete Segundos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jvXbrFc0rYnpPWj6UeFBblN8Fs0.jpg'),
(147258, 10489, 'Sete Segundos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQJKdwtnJMdyVbZ0raWUgVOIUUH.jpg'),
(147259, 10489, 'Sete Segundos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cIF3xtTWtCYQ4A795mlVpS1JEa.jpg'),
(147260, 10489, 'Sete Segundos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6G2Bau3xLs2TEb2rHPqEFnZy5iJ.jpg'),
(147261, 10490, 'Acumuladores de Carros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZLztKXdvklHnfU8oMEWXJdLgtL.jpg'),
(147262, 10490, 'Acumuladores de Carros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bQBYWYm9aK7LDhLM5UwYD4Mp03G.jpg'),
(147263, 10490, 'Acumuladores de Carros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sXCennHkgYUzXLtEwywszrLB8U.jpg'),
(147264, 10490, 'Acumuladores de Carros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yXskjtSHSDeX0YbdHrp1UUvhhQM.jpg'),
(147265, 10490, 'Acumuladores de Carros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rHIPdA7Q1qb526oqs7RKk6sgU3s.jpg'),
(147266, 10490, 'Acumuladores de Carros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4LObjhtM2w0vH0G41z0V8aVdLc3.jpg'),
(147267, 10491, 'Acumuladores de Carros S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6mNidHzbfnaiuB7I0ncgRiAg3rp.jpg'),
(147268, 10491, 'Acumuladores de Carros S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2PZxIKd4RJvvWkdDKGI5QfwmwYq.jpg'),
(147269, 10491, 'Acumuladores de Carros S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3f4RDjhyGUblK6LwfNxbOWeOdyr.jpg'),
(147270, 10491, 'Acumuladores de Carros S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/82pfw4iHQLXF1GjCls8pf4kve61.jpg'),
(147271, 10491, 'Acumuladores de Carros S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hn2Qlvg0ge8buWGGIWOd3nhI6vy.jpg'),
(147272, 10491, 'Acumuladores de Carros S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qMep9W6Y7PSseOUZRtsK2CDtUim.jpg'),
(147273, 10492, 'Areia Movedica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oegSlN6sl83TZtqYPMOPS1n0CNS.jpg'),
(147274, 10492, 'Areia Movedica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sOfLfyaCUBMLTzl7YQVrASTdyT2.jpg'),
(147275, 10492, 'Areia Movedica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zu2amyjKtgGVBvZzz5PCAIiRcSc.jpg'),
(147276, 10492, 'Areia Movedica S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b84nVDGvLXaeBXxTgW4FI8p8xJI.jpg'),
(147277, 10492, 'Areia Movedica S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y7fcShKWlqTAzX1GGclsdyh1J0c.jpg'),
(147278, 10492, 'Areia Movedica S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3a31VfTgFCJuIqLpfCgInzxcXGs.jpg'),
(147279, 10493, 'Perdidos em Oz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c7kayV1xEaf1ZNqMqTm82zFvDG0.jpg'),
(147280, 10493, 'Perdidos em Oz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qOmQ1n3gRU6Pc1SaOXZXaAWpJzq.jpg'),
(147281, 10493, 'Perdidos em Oz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c3k2c3Ge1VcIdz7rQ5flA8ATuqu.jpg'),
(147282, 10493, 'Perdidos em Oz S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rxjVtuM7I3biMItfCAJloNveyFV.jpg'),
(147283, 10493, 'Perdidos em Oz S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oevyf6fhfeC0OZAjBJkpWJ29Dlq.jpg'),
(147284, 10493, 'Perdidos em Oz S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/90UbvCgtDD6CuBWUEQgm2qZJl0R.jpg'),
(147285, 10493, 'Perdidos em Oz S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZn75dSdBKrU7dOyy4lspE9tR7b.jpg'),
(147286, 10493, 'Perdidos em Oz S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aNCqgYwlS5A8baqdWfDWy6gapyo.jpg'),
(147287, 10493, 'Perdidos em Oz S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qFPql8KioS3NTR9We4hTgLb6lvK.jpg'),
(147288, 10493, 'Perdidos em Oz S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udkRiAhjligy4Ee65ORP1gfhxU3.jpg'),
(147289, 10493, 'Perdidos em Oz S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mWgJG939o6VN0phsmH0ULWD1OH4.jpg'),
(147290, 10493, 'Perdidos em Oz S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h8SpVnBpXGAdPrk17UVpgRu5J8r.jpg'),
(147291, 10493, 'Perdidos em Oz S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h1MDJF0vXB7H0Y76hriZbie8mzK.jpg'),
(147292, 10494, 'Perdidos em Oz S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bYPm31BjQed8fqbly7BFPjsOjLH.jpg'),
(147293, 10494, 'Perdidos em Oz S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bYPm31BjQed8fqbly7BFPjsOjLH.jpg'),
(147294, 10494, 'Perdidos em Oz S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bYPm31BjQed8fqbly7BFPjsOjLH.jpg'),
(147295, 10494, 'Perdidos em Oz S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bYPm31BjQed8fqbly7BFPjsOjLH.jpg'),
(147296, 10494, 'Perdidos em Oz S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bYPm31BjQed8fqbly7BFPjsOjLH.jpg'),
(147297, 10494, 'Perdidos em Oz S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bYPm31BjQed8fqbly7BFPjsOjLH.jpg'),
(147298, 10494, 'Perdidos em Oz S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bYPm31BjQed8fqbly7BFPjsOjLH.jpg'),
(147299, 10494, 'Perdidos em Oz S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bYPm31BjQed8fqbly7BFPjsOjLH.jpg'),
(147300, 10494, 'Perdidos em Oz S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bYPm31BjQed8fqbly7BFPjsOjLH.jpg'),
(147301, 10494, 'Perdidos em Oz S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bYPm31BjQed8fqbly7BFPjsOjLH.jpg'),
(147302, 10494, 'Perdidos em Oz S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bYPm31BjQed8fqbly7BFPjsOjLH.jpg'),
(147303, 10494, 'Perdidos em Oz S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bYPm31BjQed8fqbly7BFPjsOjLH.jpg'),
(147304, 10494, 'Perdidos em Oz S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bYPm31BjQed8fqbly7BFPjsOjLH.jpg'),
(147305, 10495, 'Tenku Shinpan Sem Saida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4RzFKfg2EhKgvrFvIux7nCxGkma.jpg'),
(147306, 10495, 'Tenku Shinpan Sem Saida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ulxUI3K5wdu9BIRN8hGtS9FEVFn.jpg'),
(147307, 10495, 'Tenku Shinpan Sem Saida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zI2v70p1Y0UEHhzGHE7enOolEhy.jpg'),
(147308, 10495, 'Tenku Shinpan Sem Saida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mlLMp1pqOMWb9RITXlBobJrG5dJ.jpg'),
(147309, 10495, 'Tenku Shinpan Sem Saida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oMTYZqogneSpJZkErQvspALjxH5.jpg'),
(147310, 10495, 'Tenku Shinpan Sem Saida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/opLDFVxSqjB2mXgMtE9VUrcIbZe.jpg'),
(147311, 10495, 'Tenku Shinpan Sem Saida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4FEtTDxMpWUje6iC7pRnti9VSkd.jpg'),
(147312, 10495, 'Tenku Shinpan Sem Saida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b7mP0jO1xxfbUOChhbKFQaCdJzS.jpg'),
(147313, 10495, 'Tenku Shinpan Sem Saida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/outswOyiBbUFMG61dcoO5D2aYMf.jpg'),
(147314, 10495, 'Tenku Shinpan Sem Saida S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oJNplzlDGFVIp2WB8fYHhggIQlI.jpg'),
(147315, 10495, 'Tenku Shinpan Sem Saida S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5B69cBt9DfvdhU2SW0t1Vpb2psn.jpg'),
(147316, 10495, 'Tenku Shinpan Sem Saida S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qmisH8j8lebDJh9Xh7AwizjYZbq.jpg'),
(147317, 10496, 'Vida no Paraiso Bahamas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147318, 10496, 'Vida no Paraiso Bahamas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147319, 10496, 'Vida no Paraiso Bahamas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147320, 10496, 'Vida no Paraiso Bahamas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147321, 10496, 'Vida no Paraiso Bahamas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147322, 10496, 'Vida no Paraiso Bahamas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147323, 10496, 'Vida no Paraiso Bahamas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147324, 10496, 'Vida no Paraiso Bahamas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147325, 10496, 'Vida no Paraiso Bahamas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147326, 10496, 'Vida no Paraiso Bahamas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147327, 10496, 'Vida no Paraiso Bahamas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147328, 10496, 'Vida no Paraiso Bahamas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147329, 10496, 'Vida no Paraiso Bahamas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147330, 10496, 'Vida no Paraiso Bahamas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/347744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147331, 10497, 'Vida no Paraiso Bahamas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147332, 10497, 'Vida no Paraiso Bahamas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147333, 10497, 'Vida no Paraiso Bahamas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147334, 10497, 'Vida no Paraiso Bahamas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147335, 10497, 'Vida no Paraiso Bahamas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147336, 10497, 'Vida no Paraiso Bahamas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147337, 10497, 'Vida no Paraiso Bahamas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147338, 10497, 'Vida no Paraiso Bahamas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147339, 10497, 'Vida no Paraiso Bahamas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147340, 10497, 'Vida no Paraiso Bahamas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147341, 10497, 'Vida no Paraiso Bahamas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147342, 10497, 'Vida no Paraiso Bahamas S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147343, 10497, 'Vida no Paraiso Bahamas S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147344, 10497, 'Vida no Paraiso Bahamas S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/347758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147345, 10498, 'Vida no Paraiso Bahamas S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147346, 10498, 'Vida no Paraiso Bahamas S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147347, 10498, 'Vida no Paraiso Bahamas S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147348, 10498, 'Vida no Paraiso Bahamas S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147349, 10498, 'Vida no Paraiso Bahamas S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147350, 10498, 'Vida no Paraiso Bahamas S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147351, 10498, 'Vida no Paraiso Bahamas S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147352, 10498, 'Vida no Paraiso Bahamas S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147353, 10498, 'Vida no Paraiso Bahamas S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147354, 10498, 'Vida no Paraiso Bahamas S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147355, 10498, 'Vida no Paraiso Bahamas S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147356, 10498, 'Vida no Paraiso Bahamas S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147357, 10498, 'Vida no Paraiso Bahamas S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147358, 10498, 'Vida no Paraiso Bahamas S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/347772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147359, 10499, 'Vida no Paraiso Bahamas S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147360, 10499, 'Vida no Paraiso Bahamas S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147361, 10499, 'Vida no Paraiso Bahamas S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147362, 10499, 'Vida no Paraiso Bahamas S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147363, 10499, 'Vida no Paraiso Bahamas S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147364, 10499, 'Vida no Paraiso Bahamas S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147365, 10499, 'Vida no Paraiso Bahamas S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147366, 10499, 'Vida no Paraiso Bahamas S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147367, 10499, 'Vida no Paraiso Bahamas S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147368, 10499, 'Vida no Paraiso Bahamas S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147369, 10499, 'Vida no Paraiso Bahamas S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147370, 10499, 'Vida no Paraiso Bahamas S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(147371, 10499, 'Vida no Paraiso Bahamas S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147372, 10499, 'Vida no Paraiso Bahamas S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/347786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aXiXO4FWHgSF3o1rm3amyrN4vKo.jpg'),
(147373, 10500, 'Havai Cinco 0 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s6WsI1x65kk8IC8gGDjZKafrvOU.jpg'),
(147374, 10500, 'Havai Cinco 0 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Lp2LZpFij8cafDbLy5BaHcjn37.jpg'),
(147375, 10500, 'Havai Cinco 0 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1uiMweCJJMc4Tugqx69CGnmYb2R.jpg'),
(147376, 10500, 'Havai Cinco 0 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sLqxZlsD3NIyCMmwR5osLj5qz0R.jpg'),
(147377, 10500, 'Havai Cinco 0 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6k0pLLt4eTfYUn2JVDZY5Oop4Pf.jpg'),
(147378, 10500, 'Havai Cinco 0 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/88X9phAAVbHMD9LZutJ4erKeAsD.jpg'),
(147379, 10500, 'Havai Cinco 0 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/otucmgsSYz6edbIj29mpevRfcdt.jpg'),
(147380, 10500, 'Havai Cinco 0 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8dzbjfccamgS49kYQBSvtj2uoup.jpg'),
(147381, 10500, 'Havai Cinco 0 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jvVkCdEhKpI6c5AqtvZ975FdB2y.jpg'),
(147382, 10500, 'Havai Cinco 0 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9LGEU0FIdXjI48T7sBvERtZPdjn.jpg'),
(147383, 10500, 'Havai Cinco 0 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kOMQAoqyeiA4vcGewHoQ3vq5T9X.jpg'),
(147384, 10500, 'Havai Cinco 0 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bVqMbkzb6vD3so9AeLqUZNm5Idt.jpg'),
(147385, 10500, 'Havai Cinco 0 S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8b6GNa3vzGg0cGAgKyDZ2r7btSF.jpg'),
(147386, 10500, 'Havai Cinco 0 S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/347556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4PGxKGsSRH5j7W9Dgs068qj11Td.jpg'),
(147387, 10500, 'Havai Cinco 0 S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/347557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gGhmkwvZ9ckJ6GBMD4BMBKPhGbR.jpg'),
(147388, 10500, 'Havai Cinco 0 S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/347558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b64c5KzuL4WHPs2DUz2HLCg9qXZ.jpg'),
(147389, 10500, 'Havai Cinco 0 S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/347559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Rtn82VumYqZv2qfPjorzaDF0tE.jpg'),
(147390, 10500, 'Havai Cinco 0 S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/347560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9GectdiBDtOjzPAzISBUwFpoSSx.jpg'),
(147391, 10500, 'Havai Cinco 0 S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/347561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6VuycoiN01jgbPVLKrYjwXYVMVd.jpg'),
(147392, 10500, 'Havai Cinco 0 S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/347562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qK0Au1BtIHPw6rPujIEjoBwT5Mr.jpg'),
(147393, 10500, 'Havai Cinco 0 S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/347563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v41Ojy0ysN3LbCKLUBdYVWTgjgo.jpg'),
(147394, 10500, 'Havai Cinco 0 S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/347564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uw8UncTqeSeQIHcKuCCIBK228Pv.jpg'),
(147395, 10500, 'Havai Cinco 0 S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/347565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eLxOTxRQwOB9tOXrCXMCmLibVJx.jpg'),
(147396, 10500, 'Havai Cinco 0 S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/347566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bSNPw1jXIbnJ6FwhXJmyYhTzhcn.jpg'),
(147397, 10501, 'Havai Cinco 0 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j6t9gZRzGj7uoiXu6R9fZcsF2UN.jpg'),
(147398, 10501, 'Havai Cinco 0 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyDNC2x5Vy0QSDxZW8MDgaSYcCN.jpg'),
(147399, 10501, 'Havai Cinco 0 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4J2oKA1wDminq1eiA4W5WGgpbq1.jpg'),
(147400, 10501, 'Havai Cinco 0 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cTPvb5g6GUgtZAqTYWyAAvVfPN5.jpg'),
(147401, 10501, 'Havai Cinco 0 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vMzYMHMovIhKYYygw1WYo6NbMnV.jpg'),
(147402, 10501, 'Havai Cinco 0 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tgq0DVQ9tjXFBIxyjs1RqivCfN4.jpg'),
(147403, 10501, 'Havai Cinco 0 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lQwmAnh2OLgOHNj4vAihpQjhMKE.jpg'),
(147404, 10501, 'Havai Cinco 0 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wCExgdMA2SUScpvGStZOjb0eFOB.jpg'),
(147405, 10501, 'Havai Cinco 0 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AddiA6qLZiP5JBAbCCYnAERClVU.jpg'),
(147406, 10501, 'Havai Cinco 0 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wXAvsdqojE7J2lGf9Xt2SJD6m2Y.jpg'),
(147407, 10501, 'Havai Cinco 0 S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u28PUHVOzz9ZeCW7ryh1HcoygsX.jpg'),
(147408, 10501, 'Havai Cinco 0 S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aucvgZ2fwRKWqLi9wKYXpEstt4b.jpg'),
(147409, 10501, 'Havai Cinco 0 S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l6kafuUCsq6aCFaxMRMGZgbF5No.jpg'),
(147410, 10501, 'Havai Cinco 0 S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/347580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7q8IEn6iPSepZrOygGWq2kBtCKl.jpg'),
(147411, 10501, 'Havai Cinco 0 S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/347581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pwhDwXQ1t6JgxXxFj3YObKFrCZt.jpg'),
(147412, 10501, 'Havai Cinco 0 S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/347582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vA3bezrbLQMPK8Kbb3pVOfs3esE.jpg'),
(147413, 10501, 'Havai Cinco 0 S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/347583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AbJwS3xixmHSrY6WPQwrm3oyyZ0.jpg'),
(147414, 10501, 'Havai Cinco 0 S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/347584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4g17fFyXScOseoTXj3kgdB6qrBM.jpg'),
(147415, 10501, 'Havai Cinco 0 S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/347585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sNFGSS29cC7adlY4w8QnHFoNf05.jpg'),
(147416, 10501, 'Havai Cinco 0 S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/347586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aq8EuNqm3u5L7XhH08jMTDHMXqa.jpg'),
(147417, 10501, 'Havai Cinco 0 S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/347587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yKZOwAQdj9m87bG1LYQhL2MCeId.jpg'),
(147418, 10501, 'Havai Cinco 0 S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/347588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6bhSFBJG9IAqEc4ADaioy4xw1G8.jpg'),
(147419, 10501, 'Havai Cinco 0 S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/347589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sw0lXfJmlmpFINTpYebNapPZHa9.jpg'),
(147420, 10502, 'Havai Cinco 0 S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ly1MF8RkSNzeJgwCg3j5H6jNbT6.jpg'),
(147421, 10502, 'Havai Cinco 0 S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lkgWKYZTnQHs9iSeR2XYHc7xnWH.jpg'),
(147422, 10502, 'Havai Cinco 0 S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/N07BdmTpH1pELeHBFjhOxDTHo6.jpg'),
(147423, 10502, 'Havai Cinco 0 S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A2GqzVoIy7Rk8hYRclnQeHRcGWt.jpg'),
(147424, 10502, 'Havai Cinco 0 S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jv39quMQ2cuxpPFgpuWAH4wBead.jpg'),
(147425, 10502, 'Havai Cinco 0 S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uT9skYO1z9CeL0eVELnY7bmHmTY.jpg'),
(147426, 10502, 'Havai Cinco 0 S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ae5RGpSF18P5aIObNVNQWqcUGIZ.jpg'),
(147427, 10502, 'Havai Cinco 0 S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l7kuTTfpM32HIa5CfItv4YdNbgt.jpg'),
(147428, 10502, 'Havai Cinco 0 S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hskJyYbf2WGbr9stVhDJO7UhuuT.jpg'),
(147429, 10502, 'Havai Cinco 0 S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfEtSjZpJqtZivMC8DIKMPVrjnj.jpg'),
(147430, 10502, 'Havai Cinco 0 S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mIHudl3uo47jRdL60tVdJJymwgs.jpg'),
(147431, 10502, 'Havai Cinco 0 S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/enaDgm5shl70Kp3GHM35j5F7VxE.jpg'),
(147432, 10502, 'Havai Cinco 0 S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rV7IRoG3ARvoXjGHEYOu6kfLEZG.jpg'),
(147433, 10502, 'Havai Cinco 0 S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/347603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2KIuwoXAX6WVqYaalBAkbmO9weC.jpg'),
(147434, 10502, 'Havai Cinco 0 S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/347604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l7inm6pdNC34SrYr09K9gxNG04t.jpg'),
(147435, 10502, 'Havai Cinco 0 S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/347605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/suImub2dzcyv2MXkKtVsdNcOBd6.jpg'),
(147436, 10502, 'Havai Cinco 0 S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/347606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pFTc2VDmvPNWGI2mhCono3PSihA.jpg'),
(147437, 10502, 'Havai Cinco 0 S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/347607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/chlX80S5YEJlDRvD8NnNNxWWbZb.jpg'),
(147438, 10502, 'Havai Cinco 0 S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/347608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zDDcKrVdVvnEa10iG9fNXktT1TJ.jpg'),
(147439, 10502, 'Havai Cinco 0 S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/347609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fikoL5C24didfKKtwgHb8Eyenmr.jpg'),
(147440, 10502, 'Havai Cinco 0 S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/347610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5tze2JWaY40gwCb8XiYoS8ixiz0.jpg'),
(147441, 10502, 'Havai Cinco 0 S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/347611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2CT9JRGSli1BNYa9nWteStuznhh.jpg'),
(147442, 10502, 'Havai Cinco 0 S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/347612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9GR8FmVhNmUQ0ySCaday8zDhFO0.jpg'),
(147443, 10502, 'Havai Cinco 0 S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/347613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1wVtEGXPvtGyTMiZJTAjXNcEH0O.jpg'),
(147444, 10503, 'Havai Cinco 0 S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aooAhS1r9550VViNWCqp6yyijcM.jpg'),
(147445, 10503, 'Havai Cinco 0 S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qnuZtn3ETF0D5csSorBSWpB7kaH.jpg'),
(147446, 10503, 'Havai Cinco 0 S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1jV3zWQndnZb5NgJ4f3NLHEaN4.jpg'),
(147447, 10503, 'Havai Cinco 0 S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gvWiGv8bfmUKbr9FGKbNFPAxSOK.jpg'),
(147448, 10503, 'Havai Cinco 0 S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mhHz5A9CMz6EPHhjcoGg1ZE3Cvs.jpg'),
(147449, 10503, 'Havai Cinco 0 S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cgWsDpY7IDVePm5VPXJfgFDltuY.jpg'),
(147450, 10503, 'Havai Cinco 0 S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/O06YeQPZBiIt1JIm6rCJbSoKXX.jpg'),
(147451, 10503, 'Havai Cinco 0 S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tXFmYvVUuTw0NGdIefAghvxxuOI.jpg'),
(147452, 10503, 'Havai Cinco 0 S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gKzHGuXq7uAPiAPiK7vrUPnjSfE.jpg'),
(147453, 10503, 'Havai Cinco 0 S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9WrwMm2iSol374WY3wpXPwR03y7.jpg'),
(147454, 10503, 'Havai Cinco 0 S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gGaoJFHIhIi7rwRVX1wWzEVfLNF.jpg'),
(147455, 10503, 'Havai Cinco 0 S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bX5NaWnKeMDmbNYw20b5nJm6y7u.jpg'),
(147456, 10503, 'Havai Cinco 0 S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mhYW4YGp6dTj2UEijTm6tx9MCJ9.jpg'),
(147457, 10503, 'Havai Cinco 0 S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/347627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8d4vH4MS36qfetFGSJViS5P8fO3.jpg'),
(147458, 10503, 'Havai Cinco 0 S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/347628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZ1wmRbz8pykg62czQABAVEulAe.jpg'),
(147459, 10503, 'Havai Cinco 0 S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/347629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nvGdOrv7H8Cw3All8cY8jq8CiRK.jpg'),
(147460, 10503, 'Havai Cinco 0 S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/347630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eOOaRroNoUvpwt5dt2s00q0lqvD.jpg'),
(147461, 10503, 'Havai Cinco 0 S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/347631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBbpDorEIPraI84mmKg0gA8Gomn.jpg'),
(147462, 10503, 'Havai Cinco 0 S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/347632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cy5gkLJ0xe48NoPpmlwOZN7Aj9W.jpg'),
(147463, 10503, 'Havai Cinco 0 S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/347633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a8xUxebhc9muVjDDjNPLDwvCPL6.jpg'),
(147464, 10503, 'Havai Cinco 0 S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/347634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gFsBrDr5HqrTlF5ZR5hrEPl5aTG.jpg'),
(147465, 10503, 'Havai Cinco 0 S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/347635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9x5qHOwkRqOXsHlP94RdJAB9NLC.jpg'),
(147466, 10504, 'Havai Cinco 0 S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zAJBFf9vNEMhL8ad9oQe4768zix.jpg'),
(147467, 10504, 'Havai Cinco 0 S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5y8yK6QrAlZdqY1ouefhx0ViUHR.jpg'),
(147468, 10504, 'Havai Cinco 0 S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mLNSE2GpJrBgUylVgUpw0NKwiaf.jpg'),
(147469, 10504, 'Havai Cinco 0 S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ebtnEdvdoIjzJNLFDc82FXJ11G.jpg'),
(147470, 10504, 'Havai Cinco 0 S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fRId2DJwcTN3bYv88V1ltiDLM95.jpg'),
(147471, 10504, 'Havai Cinco 0 S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i88ccu8FEBSm1Hh8HRCxTAa9Hsi.jpg'),
(147472, 10504, 'Havai Cinco 0 S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/waLrGhON502oq2KONgRnJsjJtlC.jpg'),
(147473, 10504, 'Havai Cinco 0 S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6J4vi5xZauTo7cF9UfXUiBwXjKA.jpg'),
(147474, 10504, 'Havai Cinco 0 S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vtCKW2BcuNrhOPUSlVpDbNIG2Zd.jpg'),
(147475, 10504, 'Havai Cinco 0 S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mTXgjt7IQgGEehV7HalT8auAaq8.jpg'),
(147476, 10504, 'Havai Cinco 0 S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/111MbWiGoGGRj9p6VTKuFsUZbYn.jpg'),
(147477, 10504, 'Havai Cinco 0 S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AwpYIOdQxcEPjF4CEHeXFZ1tWkB.jpg'),
(147478, 10504, 'Havai Cinco 0 S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63wOFUKYwe1rXAD2fCLLM3X1HBF.jpg'),
(147479, 10504, 'Havai Cinco 0 S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/347649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dDJndYbPdTjyFE5WpaURrp2FwyD.jpg'),
(147480, 10504, 'Havai Cinco 0 S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/347650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lgE0mMO4JpXNpZtPjnousD3x6eT.jpg'),
(147481, 10504, 'Havai Cinco 0 S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/347651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8TvsPNl9TQdhadafzrmpQBifow4.jpg'),
(147482, 10504, 'Havai Cinco 0 S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/347652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Qs7NCa6pfMQdkixLjfClSHqtFU.jpg'),
(147483, 10504, 'Havai Cinco 0 S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/347653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5LOep3jhfgZfytYpfr25RL1wZjC.jpg'),
(147484, 10504, 'Havai Cinco 0 S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/347654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tRQ9TNH66zVauietzdpmtRmPxdz.jpg'),
(147485, 10504, 'Havai Cinco 0 S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/347655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zY8kTLWr9ug3EpKtx9KkO2T0lGI.jpg'),
(147486, 10504, 'Havai Cinco 0 S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/347656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqk0Fo7pXCtxxUoK1CnBsTLLR3x.jpg'),
(147487, 10504, 'Havai Cinco 0 S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/347657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ueaiQS72scNsAuUZ0lq33dLEUyN.jpg'),
(147488, 10504, 'Havai Cinco 0 S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/347658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yhlPvRCiUQHYt21RdmHUtqGAT1U.jpg'),
(147489, 10504, 'Havai Cinco 0 S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/347659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y4MEicPd9DAvrg703uPyHLwFV4C.jpg'),
(147490, 10504, 'Havai Cinco 0 S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/347660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9fGtB5DEglc66OLLWFrgf6lVnDc.jpg'),
(147491, 10505, 'Havai Cinco 0 S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dmctTF10xT0WEknglkqQ8tJTpDN.jpg'),
(147492, 10505, 'Havai Cinco 0 S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hOMCqrlZhAGP93mYslNGPwTjc3e.jpg'),
(147493, 10505, 'Havai Cinco 0 S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xAFa6td2m770H4OttpsT8MdZYtn.jpg'),
(147494, 10505, 'Havai Cinco 0 S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rRBZoDjK07LxQrP8IvCfRkRwBml.jpg'),
(147495, 10505, 'Havai Cinco 0 S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5QvA2aMb2Qv1JJLQccrNnw6rjvz.jpg'),
(147496, 10505, 'Havai Cinco 0 S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qXoUdRPEzeiCKRwUam6P95XNTR8.jpg'),
(147497, 10505, 'Havai Cinco 0 S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBCNtRLNAkFO9OlQ2Cek8lgJKcu.jpg'),
(147498, 10505, 'Havai Cinco 0 S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5aIVV78ArF0BoZZjsFyorjvg0dX.jpg'),
(147499, 10505, 'Havai Cinco 0 S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zztbqdVCLnitjrcd6ymdElNbm6s.jpg'),
(147500, 10505, 'Havai Cinco 0 S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hEqub9JR3Kcma4Fp0K8bRfnP9a4.jpg'),
(147501, 10505, 'Havai Cinco 0 S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQyQFyHPclVLY3m3UVwHAE3dmil.jpg'),
(147502, 10505, 'Havai Cinco 0 S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/py37C97Un8zo5yep5FQtgUZhMpu.jpg'),
(147503, 10505, 'Havai Cinco 0 S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sApJwJBfVqAdKopIWoBvGcCSQRW.jpg'),
(147504, 10505, 'Havai Cinco 0 S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/347674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e9780CW0RJFYaWpaEyFRllIcCID.jpg'),
(147505, 10505, 'Havai Cinco 0 S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/347675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yyNDIU908uPu2TNoFnQpneDFLLK.jpg'),
(147506, 10505, 'Havai Cinco 0 S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/347676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bh8Tg1vNd2vwGCSW4h2GHuADQtE.jpg'),
(147507, 10505, 'Havai Cinco 0 S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/347677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kKbUC9xMxyBcOpQkEN0MPcphYsO.jpg'),
(147508, 10505, 'Havai Cinco 0 S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/347678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d2GVoQqy6NEIba9WD2jxU7Io0Zz.jpg'),
(147509, 10505, 'Havai Cinco 0 S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/347679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oMTUMD6tQwbpIfTO65r6CeAUlEv.jpg'),
(147510, 10505, 'Havai Cinco 0 S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/347680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hz0lDAHTE6BfzeY5uceTeJiHccW.jpg'),
(147511, 10505, 'Havai Cinco 0 S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/347681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3wx6DnidgNwdc2jJeRf1ppVq3DZ.jpg'),
(147512, 10505, 'Havai Cinco 0 S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/347682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f24sZ6ZV3eVBReGdgvBzP7DXc9G.jpg'),
(147513, 10505, 'Havai Cinco 0 S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/347683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8G4IwKJrhp1uv41wzilJfvcJ6PK.jpg'),
(147514, 10505, 'Havai Cinco 0 S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/347684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w90HCyZOm250Md5N3KeUGGQAQyh.jpg'),
(147515, 10505, 'Havai Cinco 0 S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/347685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4BFa9Gapr68o90EGjTwyISdiqk0.jpg'),
(147516, 10506, 'Havai Cinco 0 S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/436744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147517, 10506, 'Havai Cinco 0 S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/436745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147518, 10506, 'Havai Cinco 0 S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/436746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147519, 10506, 'Havai Cinco 0 S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/436747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147520, 10506, 'Havai Cinco 0 S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/436748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147521, 10506, 'Havai Cinco 0 S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/436749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147522, 10506, 'Havai Cinco 0 S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/436750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147523, 10506, 'Havai Cinco 0 S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/436751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147524, 10506, 'Havai Cinco 0 S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/436752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147525, 10506, 'Havai Cinco 0 S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/436753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147526, 10506, 'Havai Cinco 0 S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/436754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147527, 10506, 'Havai Cinco 0 S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/436755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147528, 10506, 'Havai Cinco 0 S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/436756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147529, 10506, 'Havai Cinco 0 S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/436757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147530, 10506, 'Havai Cinco 0 S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/436758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147531, 10506, 'Havai Cinco 0 S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/436759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147532, 10506, 'Havai Cinco 0 S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/436760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147533, 10506, 'Havai Cinco 0 S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/436761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147534, 10506, 'Havai Cinco 0 S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/436762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147535, 10506, 'Havai Cinco 0 S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/436763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147536, 10506, 'Havai Cinco 0 S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/436764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147537, 10506, 'Havai Cinco 0 S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/436765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147538, 10506, 'Havai Cinco 0 S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/436766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147539, 10506, 'Havai Cinco 0 S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/436767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147540, 10506, 'Havai Cinco 0 S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/436768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wGTE1SRuVB1xNfP63URLBQ7hwTd.jpg'),
(147541, 10507, 'Havai Cinco 0 S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/885561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4emPXswHXPz5DW2rZsAmWJsuMqa.jpg'),
(147542, 10507, 'Havai Cinco 0 S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/885562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rLwZsma91m81ABZOudBd4iNTXK2.jpg'),
(147543, 10507, 'Havai Cinco 0 S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/885563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nfPZJ97zxVylriojSgkd8FULWXu.jpg'),
(147544, 10507, 'Havai Cinco 0 S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/885564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2T8WaGmdXTOvhRdozMbiWrmAlP0.jpg'),
(147545, 10507, 'Havai Cinco 0 S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/885565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ZZjTpEdIoRcXHQBvz54Niw3A3e.jpg'),
(147546, 10507, 'Havai Cinco 0 S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/885566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cgqwWeaJ4hvaNnXV1lvAcNFtt1K.jpg'),
(147547, 10507, 'Havai Cinco 0 S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/885567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xktPF3nTxY7jFUOZaH9zcOk2v9U.jpg'),
(147548, 10507, 'Havai Cinco 0 S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/885568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/icAEeSiTLqB35mGsIHok3ULLZy8.jpg'),
(147549, 10507, 'Havai Cinco 0 S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/885569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2bHlbGd67t4ZbrAFR89wkoux4pW.jpg'),
(147550, 10507, 'Havai Cinco 0 S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/885570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sv9e7KuWzqwvudl1dgUMRKB4Npn.jpg'),
(147551, 10507, 'Havai Cinco 0 S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/885571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j16fB97lT1rweU4hXoTZ5pq5m8u.jpg'),
(147552, 10507, 'Havai Cinco 0 S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/885572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lZjSR0PV7lI302fqrcDLU6s76Aa.jpg'),
(147553, 10507, 'Havai Cinco 0 S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/885573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9rAXstngK4hKKPdTR79HTbVaH6c.jpg'),
(147554, 10507, 'Havai Cinco 0 S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/885574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6cOuEf0Uchcx20cl0eeSBVmf3eS.jpg'),
(147555, 10507, 'Havai Cinco 0 S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/885575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9zVhJD2sYSaguMADgV2G4zqFUVO.jpg'),
(147556, 10507, 'Havai Cinco 0 S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/885576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3TVHMsq8UnS5LpAag6HmN97YOqE.jpg'),
(147557, 10507, 'Havai Cinco 0 S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/885577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5I1vqiAcYmgkbLubsbEfWEQKDwU.jpg'),
(147558, 10507, 'Havai Cinco 0 S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/885578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a4S7k5NLxfROf0DBCoE2G9EeIeW.jpg'),
(147559, 10507, 'Havai Cinco 0 S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/885579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rYdZK6Il0qbSBENa0F1AFSyx2gu.jpg'),
(147560, 10507, 'Havai Cinco 0 S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/885580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/avamkHKiTgiz4aPU9XkTkF5JwKX.jpg'),
(147561, 10507, 'Havai Cinco 0 S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/885581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8lR9mJ55MGfJMTbqwRSvcFChbDP.jpg'),
(147562, 10507, 'Havai Cinco 0 S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/885582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gOm6PP71svhDmtVdQHOAhIUDcYj.jpg'),
(147563, 10507, 'Havai Cinco 0 S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/885583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Iw4qh1eg085QT7Szsi0jqIkrAH.jpg'),
(147564, 10507, 'Havai Cinco 0 S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/885584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uIva94JUX21kK1mDir0y8m2Kabx.jpg'),
(147565, 10508, 'Havai Cinco 0 S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/885585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jkJGFlbAiADjIf4a0JjGbcxOz36.jpg'),
(147566, 10508, 'Havai Cinco 0 S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/885586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n0sRiTXvLRZcPnaxpGFWKw6qNML.jpg'),
(147567, 10508, 'Havai Cinco 0 S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/885587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tZQufzFVFSa6EHrZPiYo7YDQrl8.jpg'),
(147568, 10508, 'Havai Cinco 0 S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/885588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qjocldwmjyYByrsAv0YtF18YY1R.jpg'),
(147569, 10508, 'Havai Cinco 0 S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/885589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ofgTneUJDlOwq5ZtJtz7oIkKv37.jpg'),
(147570, 10508, 'Havai Cinco 0 S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/885590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nh34qoZKQ36twVTKpRhYxmvHGrv.jpg'),
(147571, 10508, 'Havai Cinco 0 S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/885591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y8o9XCBW8OWU1KZI7CB2wUmzX3X.jpg'),
(147572, 10508, 'Havai Cinco 0 S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/885592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxJCRptiKiw957CB3AcGg6X3JON.jpg'),
(147573, 10508, 'Havai Cinco 0 S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/885593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eBRzga59kvkzYdvfGq9GxE2gvXW.jpg'),
(147574, 10508, 'Havai Cinco 0 S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/885594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7816PE8GeGz5noAUShufy35eUNl.jpg'),
(147575, 10508, 'Havai Cinco 0 S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/885595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWPvHnfFmzIwUsbLMWFyLOzsUFI.jpg'),
(147576, 10508, 'Havai Cinco 0 S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/885596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mqU34zAS3X1ZUqmMHB1lJqRCrTX.jpg'),
(147577, 10508, 'Havai Cinco 0 S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/885597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/LCxKrMPEAWRsp8ckH28iBEnnUx.jpg'),
(147578, 10508, 'Havai Cinco 0 S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/885598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUuuithlJu9vfYJJs4VR01zWiSX.jpg'),
(147579, 10508, 'Havai Cinco 0 S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/885599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a4KGIqXUa92effc3oECTuNTnC6o.jpg'),
(147580, 10508, 'Havai Cinco 0 S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/885600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eaxoX1iELu3dzo4V7Cpd9L11bH2.jpg'),
(147581, 10508, 'Havai Cinco 0 S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/885601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cSmYKDrnDG5irjuIxmpC4KwJ6fH.jpg'),
(147582, 10508, 'Havai Cinco 0 S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/885602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h3i6wCq7bbrdbk6NznWEcKmDFGD.jpg'),
(147583, 10508, 'Havai Cinco 0 S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/895759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eaubSPkA4BpM7UWIdYMsqEDtw12.jpg'),
(147584, 10508, 'Havai Cinco 0 S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/895760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kVz427csoGkJer8EngwMHy9sOHt.jpg'),
(147585, 10508, 'Havai Cinco 0 S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/885603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f6UJvmMbZxODMKx0nejWcl792Os.jpg'),
(147586, 10508, 'Havai Cinco 0 S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/885604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bMNKxUsd2Z0lnUZdYgaCMZlzZfU.jpg'),
(147587, 10508, 'Havai Cinco 0 S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/885605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ipd77k8HCfzehs3iNiElQsLQSoy.jpg'),
(147588, 10508, 'Havai Cinco 0 S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/885606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pIadoTOaJk3DPsGMnR1WV7zeuH.jpg'),
(147589, 10508, 'Havai Cinco 0 S09 E25', 'http://sinalprivado.info:80/series/1533784/1533784/885607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2kTXwUWxOUen1bmrGVNV4arByd8.jpg'),
(147590, 10509, 'Havai Cinco 0 S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/885608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jqEpR2JezkbBFhKxQtLfOb3hQEY.jpg'),
(147591, 10509, 'Havai Cinco 0 S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/885609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dTyD7ZEr11vwDW21INqjk3usWGS.jpg'),
(147592, 10509, 'Havai Cinco 0 S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/885610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7MiPafinxrOpk3rN8ZQTvqxjyLq.jpg'),
(147593, 10509, 'Havai Cinco 0 S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/885611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2qgsnwyoNEmBtID7a2DqZSYX219.jpg'),
(147594, 10509, 'Havai Cinco 0 S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/885612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dd82z0M8ThW964pcTc3oVGwL9uT.jpg'),
(147595, 10509, 'Havai Cinco 0 S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/885613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lGeMigpP9U15qw2O47Qmj4GXz2N.jpg'),
(147596, 10509, 'Havai Cinco 0 S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/885614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/upPogwvat3IeInHhxATemVhIGvj.jpg'),
(147597, 10509, 'Havai Cinco 0 S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/885615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gjspLmWyxwvBnPTRNE7zlQNVUDS.jpg'),
(147598, 10509, 'Havai Cinco 0 S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/885616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wBf7v58aT3aOCb5NEZ8pTCMxtFx.jpg'),
(147599, 10509, 'Havai Cinco 0 S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/885617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lCoAc5qXzC3p3aeij8P4y3mfzdy.jpg'),
(147600, 10509, 'Havai Cinco 0 S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/885618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7PvLMQ58NWgt9jU73NtArRhWRpg.jpg'),
(147601, 10509, 'Havai Cinco 0 S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/885619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jR8uZia9Yg7FFxQmkn3KlnbJEXs.jpg'),
(147602, 10509, 'Havai Cinco 0 S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/885620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6qrVQzUIVtIpavndwFKFiwTFBoH.jpg'),
(147603, 10509, 'Havai Cinco 0 S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/885621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uHIk0dfplzGXP4XDAtYGoBA9nyo.jpg'),
(147604, 10509, 'Havai Cinco 0 S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/885622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cpJFf6icTYkWJxa5p8dTevannR1.jpg'),
(147605, 10509, 'Havai Cinco 0 S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/885623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/msDGf8Srt178MdnsRql8fpz3a2V.jpg'),
(147606, 10509, 'Havai Cinco 0 S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/885624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wQkbJWgYvGKKvF2DZP3U75WWGZx.jpg'),
(147607, 10509, 'Havai Cinco 0 S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/885625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/foaQ1nxiKRjymX8DolSPyvCELgj.jpg'),
(147608, 10509, 'Havai Cinco 0 S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/885626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jsnxzIjVHl1McW9GQs7BftKjgAH.jpg'),
(147609, 10509, 'Havai Cinco 0 S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/885627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bXLmfIwMwpB4QC2PkTha3degKbv.jpg'),
(147610, 10509, 'Havai Cinco 0 S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/885628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hG1sWPVo8DDhXhn11HMEYLJSGBH.jpg'),
(147611, 10509, 'Havai Cinco 0 S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/885629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aer92pjCLKIkWGmNZwlcStVgWv7.jpg'),
(147612, 10510, 'Lilo e Stitch A Serie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8SwybaAIGo6JsrvkmIdEFukOpzh.jpg'),
(147613, 10510, 'Lilo e Stitch A Serie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fBkVNAR5AEPSOBI7lSWs3xjUQ0r.jpg'),
(147614, 10510, 'Lilo e Stitch A Serie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4GAlOHLj2vKFE70OngnZxKOonMV.jpg'),
(147615, 10510, 'Lilo e Stitch A Serie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hfMxvVeiCKvwleOhYNRsHZniXCS.jpg'),
(147616, 10510, 'Lilo e Stitch A Serie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1lQ091pVukK6ajuvZToB186WsTq.jpg'),
(147617, 10510, 'Lilo e Stitch A Serie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mVzZLg2yaB9zKodHugj0bhHwAcL.jpg'),
(147618, 10510, 'Lilo e Stitch A Serie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oABClIT932ipo7EajGkjRBWbYRG.jpg'),
(147619, 10510, 'Lilo e Stitch A Serie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ogkUZ5CYetdmOzUqaS55VpdH1hY.jpg'),
(147620, 10510, 'Lilo e Stitch A Serie S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hYM2ScaRdjKqJgGM3IjblzuCeHX.jpg'),
(147621, 10510, 'Lilo e Stitch A Serie S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/up8WwTTN1jg6QmMv8f15fGq93fB.jpg'),
(147622, 10510, 'Lilo e Stitch A Serie S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wVAcFVR4gYFgxh0bgfuFm00wzHG.jpg'),
(147623, 10510, 'Lilo e Stitch A Serie S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSVuEBr2b5humjzyT46CirlYPgp.jpg'),
(147624, 10510, 'Lilo e Stitch A Serie S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iZax920oxTddkMcaGpNNGjjJ5sw.jpg'),
(147625, 10510, 'Lilo e Stitch A Serie S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/347108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o8wWiZaxmM9UrNZTQs6e1aMQerU.jpg'),
(147626, 10510, 'Lilo e Stitch A Serie S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/347109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/klF79JzWsu6oRZSdU9pSAVZOHTm.jpg'),
(147627, 10510, 'Lilo e Stitch A Serie S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/347110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9RR6HFD31IwqEROWiZuti2msYpI.jpg'),
(147628, 10510, 'Lilo e Stitch A Serie S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/347111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gsJvkkBiRyc0vpPtxToFjbq7KCr.jpg'),
(147629, 10510, 'Lilo e Stitch A Serie S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/347112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kpSvPAwkE1hFagEC5NUwpsydTtG.jpg'),
(147630, 10510, 'Lilo e Stitch A Serie S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/347113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/57hLqcXzwulz9f9mTrJXbrrpWEu.jpg'),
(147631, 10510, 'Lilo e Stitch A Serie S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/347114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Abai5656VZEQo9uBVQOImmRUTLC.jpg'),
(147632, 10510, 'Lilo e Stitch A Serie S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/347115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/45NVUxWLnWrt2abUumbseTXRQEb.jpg'),
(147633, 10510, 'Lilo e Stitch A Serie S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/347116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rh6DUdH9XAJZIzMZNnwhw0afnnF.jpg'),
(147634, 10510, 'Lilo e Stitch A Serie S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/347117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8X6iF898pNSMV5ZiJO4ZW6EmlfA.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(147635, 10510, 'Lilo e Stitch A Serie S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/347118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQ39OGaxOz06JsCVA4jiIjQMpck.jpg'),
(147636, 10510, 'Lilo e Stitch A Serie S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/347119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rMg3wZKkdF7Jx8Td4500jJuiM5O.jpg'),
(147637, 10510, 'Lilo e Stitch A Serie S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/347120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/47f5FxQmPJpc5bNeSy1liuzilwz.jpg'),
(147638, 10510, 'Lilo e Stitch A Serie S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/347121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wbIAjEPQ2uqcsSm4rHQdOCBdnrZ.jpg'),
(147639, 10510, 'Lilo e Stitch A Serie S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/347122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A4apqDhckF3ESFThY4XAC2RJphV.jpg'),
(147640, 10510, 'Lilo e Stitch A Serie S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/347123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5QNwRJRy7D165CN35214eRZHxwE.jpg'),
(147641, 10510, 'Lilo e Stitch A Serie S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/347124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1kaOOUv1AnTjOAx69Ha72MitzIo.jpg'),
(147642, 10510, 'Lilo e Stitch A Serie S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/347125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5uddDEBySM0qNJg5IpcfljUe2wM.jpg'),
(147643, 10510, 'Lilo e Stitch A Serie S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/347126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vjUEhYIyKJWYYl1gNHnKbSyWCUa.jpg'),
(147644, 10510, 'Lilo e Stitch A Serie S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/347127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fU2io4HjUfStmVsH8BC97pFh0wm.jpg'),
(147645, 10510, 'Lilo e Stitch A Serie S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/347128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yBLmZfCVt9qKTmjM1fs59xyMBbd.jpg'),
(147646, 10510, 'Lilo e Stitch A Serie S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/347129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s360pAJADxnC7v7abpwerJAQ1VY.jpg'),
(147647, 10510, 'Lilo e Stitch A Serie S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/347130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/myU13pbqTK5exnC2LhAYpAg8veG.jpg'),
(147648, 10510, 'Lilo e Stitch A Serie S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/347131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6TE6bQxcJ08PwtHnO06Mb07xWft.jpg'),
(147649, 10510, 'Lilo e Stitch A Serie S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/347132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3qQ1S1Wf3ZhClcLpCycJ0w0ZsIw.jpg'),
(147650, 10510, 'Lilo e Stitch A Serie S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/347133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h8wRgYhyZZE9dXmB46xIcqGINPz.jpg'),
(147651, 10511, 'Lilo e Stitch A Serie S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wU1UZPH23kW14jJVLGkIPiYu4di.jpg'),
(147652, 10511, 'Lilo e Stitch A Serie S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qmI4VCxiNTZmo0oPE7okPKQnRGr.jpg'),
(147653, 10511, 'Lilo e Stitch A Serie S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qIvtPromExNB9QQfjKpY7sfrXzh.jpg'),
(147654, 10511, 'Lilo e Stitch A Serie S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/leYYxpZgn90tPwTeJDIgrP3WUWh.jpg'),
(147655, 10511, 'Lilo e Stitch A Serie S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/62FnjXwBpsN7fTsuVuM541wumzd.jpg'),
(147656, 10511, 'Lilo e Stitch A Serie S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8hGh6kLdEkIxMOuwVn9PvynEl02.jpg'),
(147657, 10511, 'Lilo e Stitch A Serie S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8SRrkvcKZZNCkoxBZ9BXkIphsef.jpg'),
(147658, 10511, 'Lilo e Stitch A Serie S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mnBKJJOdEewL3lKqsTYkeoEqTXt.jpg'),
(147659, 10511, 'Lilo e Stitch A Serie S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8V9SPbypoZTUycZkG8VBFPNFbGk.jpg'),
(147660, 10511, 'Lilo e Stitch A Serie S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4mrXD3TX6wU7tFnYGOkf4qQQqz1.jpg'),
(147661, 10511, 'Lilo e Stitch A Serie S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6mhQlK1wMbdMfstspyWg8U8BIhn.jpg'),
(147662, 10511, 'Lilo e Stitch A Serie S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7ERU1WsSpG2OUn8uhc8CR3pOA.jpg'),
(147663, 10511, 'Lilo e Stitch A Serie S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AgVuMrqiEYj8JQXNpTQO7jmXtPN.jpg'),
(147664, 10511, 'Lilo e Stitch A Serie S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/347147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4L2BRtwvblhLAH4m8SeimvqXFmI.jpg'),
(147665, 10511, 'Lilo e Stitch A Serie S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/347148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMGVInyz6yKVfUTQfPWfAO4eAvo.jpg'),
(147666, 10511, 'Lilo e Stitch A Serie S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/347149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2oEx6phCleTNleMiJgMx0DBoeHN.jpg'),
(147667, 10511, 'Lilo e Stitch A Serie S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/347150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEWJlIHADnDTenm4Fiz4NHM3Oa5.jpg'),
(147668, 10511, 'Lilo e Stitch A Serie S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/347151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nM2IKsS0ooFbMCY2SEZYtqJKkYD.jpg'),
(147669, 10511, 'Lilo e Stitch A Serie S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/347152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zS6orTetSXWsxo84zEAWhTd7DbN.jpg'),
(147670, 10511, 'Lilo e Stitch A Serie S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/347153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qNOI9GLnDarWB4Dt25qTq3Alk0r.jpg'),
(147671, 10511, 'Lilo e Stitch A Serie S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/347154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AeJAjKuRYRst00oVD0CZbAH7k9G.jpg'),
(147672, 10511, 'Lilo e Stitch A Serie S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/347155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q8PEPUJVED8KGjwu1Rn47fztBsP.jpg'),
(147673, 10511, 'Lilo e Stitch A Serie S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/347156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/boo2bmJDVlnHwTYIP0l5OYL2rBP.jpg'),
(147674, 10511, 'Lilo e Stitch A Serie S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/347157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/plwazYXel3bm2h2cSNr2Jhijw4J.jpg'),
(147675, 10511, 'Lilo e Stitch A Serie S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/347158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/X3qoxzqpQE6GdMUt5endZ5TPgJ.jpg'),
(147676, 10511, 'Lilo e Stitch A Serie S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/347159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/plwazYXel3bm2h2cSNr2Jhijw4J.jpg'),
(147677, 10512, 'Arnold (1978) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/346973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pYcSzuLxHISodUlcPan5jrIKW4.jpg'),
(147678, 10512, 'Arnold (1978) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/346974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n7OlZJXWvRIePx7RMedSFEswDim.jpg'),
(147679, 10512, 'Arnold (1978) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/346975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nvNQsTx89clrm66AA5exqKz058D.jpg'),
(147680, 10512, 'Arnold (1978) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/346976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vDVdTNOQVsQbyctDBIcDRw77i6i.jpg'),
(147681, 10512, 'Arnold (1978) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/346977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8m9ebBvBNqEG9wtbTbNVLTU8zGz.jpg'),
(147682, 10512, 'Arnold (1978) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/346978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nV4TrSi2sgiNYn4jTLLE5yaW7Yv.jpg'),
(147683, 10512, 'Arnold (1978) S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/346979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wTRTBC6JH81ZmH0LRQFNNcI8r7y.jpg'),
(147684, 10512, 'Arnold (1978) S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/346980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJtY5zViWPPSrAXld98tdeBVYWv.jpg'),
(147685, 10512, 'Arnold (1978) S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/346981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hmtdD3cSiksEGXv8EkXNwI9RkuO.jpg'),
(147686, 10512, 'Arnold (1978) S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/346982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wD9tS4r6MOLq8v6y2UsFiDunSdE.jpg'),
(147687, 10512, 'Arnold (1978) S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/346983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qbF1diZ4WViMwZpE2cgPstJleFo.jpg'),
(147688, 10512, 'Arnold (1978) S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/346984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sgwNZp1JYTxalkgZVdwzDAKmY5C.jpg'),
(147689, 10512, 'Arnold (1978) S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/346985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iiyKbZ4qkVtz1AV9lVzkzuQoshX.jpg'),
(147690, 10512, 'Arnold (1978) S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/346986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zpigtfbY7IqSSvTGQpBxjLUhkdM.jpg'),
(147691, 10512, 'Arnold (1978) S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/346987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3hqdAEfzVYEIU70tlSbGlSXpK1O.jpg'),
(147692, 10512, 'Arnold (1978) S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/346988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aiTk4GCpikwuQXpPSzcgcAnjjOR.jpg'),
(147693, 10512, 'Arnold (1978) S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/346989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6CfOPNquFP1p2herf25PPsmKBr6.jpg'),
(147694, 10512, 'Arnold (1978) S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/346990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8UzBwrcu3bkfeWC3j8zPgu581Z5.jpg'),
(147695, 10512, 'Arnold (1978) S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/346991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jjdInlsJxkFY5V1RPRQz3qMYxoO.jpg'),
(147696, 10512, 'Arnold (1978) S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/346992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lpZ9bYQKq1UBBShbZ9fzA0R8dGa.jpg'),
(147697, 10512, 'Arnold (1978) S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/346993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xyGulGl4gcqGVxXrSsefB9P4wrC.jpg'),
(147698, 10512, 'Arnold (1978) S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/346994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tTjor1ybqDrN0Avz4oE6KTa7zs7.jpg'),
(147699, 10513, 'Arnold (1978) S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/346995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ie8H2hY1NzU7FXc0mBKRazrikyO.jpg'),
(147700, 10513, 'Arnold (1978) S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/346996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3e4Fvihj4NSBbIG0jynAXMz7lf6.jpg'),
(147701, 10513, 'Arnold (1978) S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/346997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bfIjaVNeltOZEx1LAhT2WPACORq.jpg'),
(147702, 10513, 'Arnold (1978) S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/346998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bfIjaVNeltOZEx1LAhT2WPACORq.jpg'),
(147703, 10513, 'Arnold (1978) S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/346999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2C9SRhkf5gZtxYNhvptRpPtghDg.jpg'),
(147704, 10513, 'Arnold (1978) S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bd7SEvRqCoCN4qTn9UV3wsiULRQ.jpg'),
(147705, 10513, 'Arnold (1978) S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a3RMeesJW0N36njML3rpIbGN0jw.jpg'),
(147706, 10513, 'Arnold (1978) S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oBtE3Qo2CVgJVzc8TPOdf7hK190.jpg'),
(147707, 10513, 'Arnold (1978) S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7JkgPjKCVflXOQiov4XVi9VqOm3.jpg'),
(147708, 10513, 'Arnold (1978) S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hH4vYCD558stceRMfEYkmsq4VSu.jpg'),
(147709, 10513, 'Arnold (1978) S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3HOKbUYcBTOmL6tQrQb5yjZJm80.jpg'),
(147710, 10513, 'Arnold (1978) S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3HOKbUYcBTOmL6tQrQb5yjZJm80.jpg'),
(147711, 10513, 'Arnold (1978) S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aiNQW8VzuphyFncQF7SIxyIwyWz.jpg'),
(147712, 10513, 'Arnold (1978) S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/347008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oIX5deDZRERwYY3hQqrI3CsNuVn.jpg'),
(147713, 10513, 'Arnold (1978) S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/347009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/BsfHYc6hVEuQPivbXVD5oFly1P.jpg'),
(147714, 10513, 'Arnold (1978) S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/347010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rtzhZaJN4NhMmk2niO85UxZ8d0R.jpg'),
(147715, 10513, 'Arnold (1978) S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/347011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ozWnkhbr1btZbM1hLLteYBgiP3.jpg'),
(147716, 10513, 'Arnold (1978) S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/347012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hM5TOBIjinkJRkbyppGwdX6Td5S.jpg'),
(147717, 10513, 'Arnold (1978) S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/347013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rU8s2JZbIPCsnRB8tnuERNwC0qM.jpg'),
(147718, 10513, 'Arnold (1978) S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/347014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c1OxzCDWevuSnVSPIKLu0elv9YD.jpg'),
(147719, 10513, 'Arnold (1978) S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/347015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wxugHw7Z4BqksVxz8K9OvercOds.jpg'),
(147720, 10513, 'Arnold (1978) S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/347016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/njRnwTdWOwvbK3LJk3wXnXRTkdU.jpg'),
(147721, 10513, 'Arnold (1978) S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/347017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sMXW0C0EsNnrJmfVun2qtMDJXwe.jpg'),
(147722, 10514, 'Arnold (1978) S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vY7aSUa2Q1AEuuSiAKyyUUBUcXB.jpg'),
(147723, 10514, 'Arnold (1978) S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rEcpq0Q9zT93vIRSQ85wL0s7fZD.jpg'),
(147724, 10514, 'Arnold (1978) S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gsjXFqxy91DsnLXQWoM1pj8rdL0.jpg'),
(147725, 10514, 'Arnold (1978) S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1dsSDjDyOwDjcapffTxPkTucTSO.jpg'),
(147726, 10514, 'Arnold (1978) S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dnyMttSFMwU6YHyYTelFzkPxwaq.jpg'),
(147727, 10514, 'Arnold (1978) S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/30fL8Yj1demFVSCjKUlauva4fJN.jpg'),
(147728, 10514, 'Arnold (1978) S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AjHaminkOR7d7EQcq0rXckr66bE.jpg'),
(147729, 10514, 'Arnold (1978) S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cQotXWCmoF91IZa9DSkgdYHOiPN.jpg'),
(147730, 10514, 'Arnold (1978) S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sDkVF9QJqKPTWXJ6jyHETW6yQJr.jpg'),
(147731, 10514, 'Arnold (1978) S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2iukfZjP60CFNLeMnwn6UkRO1FS.jpg'),
(147732, 10514, 'Arnold (1978) S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jlPSIRFBFhl1Yhe2v7SJwbi8yLR.jpg'),
(147733, 10514, 'Arnold (1978) S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s9IVXTm7lsSLgiEl6bVhPJll9lO.jpg'),
(147734, 10514, 'Arnold (1978) S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ijRGN3Jeh7gCrhTb0yclSosmU6a.jpg'),
(147735, 10514, 'Arnold (1978) S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/347031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vmtUN6j1vu6PKTlHTqTo7wq0v76.jpg'),
(147736, 10515, 'Arnold (1978) S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/347032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3jorJO4afi9YxOnnr8sWR5EDzdE.jpg'),
(147737, 10515, 'Arnold (1978) S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/347033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nqW7zBip1UILpXpuZXVAjB3ZVFq.jpg'),
(147738, 10515, 'Arnold (1978) S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/347034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5A09XD3SHFTXwg9WyrzBVs1zhVD.jpg'),
(147739, 10515, 'Arnold (1978) S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/347035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lWZOUtFyyivfCbFC4VuIuR5ZyUJ.jpg'),
(147740, 10515, 'Arnold (1978) S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/347036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/etSsQcfALw3FZ2w6yZLFuQQR8xj.jpg'),
(147741, 10515, 'Arnold (1978) S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/347037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/neVDRXHVmMuosjGDM9E2XVHaDDc.jpg'),
(147742, 10515, 'Arnold (1978) S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/347038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yltKj0yHieY3n4Smj4A01Iu3HmM.jpg'),
(147743, 10515, 'Arnold (1978) S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/347039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yXXNiJnG400lFZP6n99mg6xHU3P.jpg'),
(147744, 10515, 'Arnold (1978) S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/347040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPFymm8ybpXlO00edDhC1AhjA94.jpg'),
(147745, 10515, 'Arnold (1978) S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/347041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zE0sUdjzKWYp9758DxpPttQMMMg.jpg'),
(147746, 10515, 'Arnold (1978) S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/347042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4imyMLbxeKYzCYv5tyecxEso8yu.jpg'),
(147747, 10515, 'Arnold (1978) S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/347043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sC0aKeGNnaMfr823Xnf46Exbl9E.jpg'),
(147748, 10515, 'Arnold (1978) S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/347044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s3E7HICshSVVLHwOWdiqtFCfdvB.jpg'),
(147749, 10515, 'Arnold (1978) S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/347045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qT4yzKDsWkqNx3uDso910VhQV9y.jpg'),
(147750, 10515, 'Arnold (1978) S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/347046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pNTXQdgrqTTRYNosiwNLJUAw0xC.jpg'),
(147751, 10515, 'Arnold (1978) S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/347047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sHjsFSu4GwvBmK0attmVVpIryuE.jpg'),
(147752, 10515, 'Arnold (1978) S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/347048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzt1BdhRjWjqoXGDv3277Qs8L8t.jpg'),
(147753, 10515, 'Arnold (1978) S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/347049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Av34wGoyLpUM0kNMVv24ML6AtCH.jpg'),
(147754, 10515, 'Arnold (1978) S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/347050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A0UGd6ytyuEeNyooMraPHmiJr4y.jpg'),
(147755, 10515, 'Arnold (1978) S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/347051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eTyR6TZI2XF2cRWG3ksf1JK16S1.jpg'),
(147756, 10515, 'Arnold (1978) S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/347052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/PuqkQNhjQyJCeEoFMZepPMuBdg.jpg'),
(147757, 10515, 'Arnold (1978) S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/347053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a8jAeTlrcveSDkNpYEVTHYjN4T8.jpg'),
(147758, 10515, 'Arnold (1978) S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/347054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mQJJAFEnHuPnGnnJ9Xn2UsGPpC7.jpg'),
(147759, 10516, 'Baseado Numa Historia Real S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/346965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y3pufuW1UcyBD0rLbTzFwXqqBlH.jpg'),
(147760, 10516, 'Baseado Numa Historia Real S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/346966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zQXxEJovttK43G9zFqGhj3Hasyw.jpg'),
(147761, 10516, 'Baseado Numa Historia Real S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/346967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/srPu3SboiXG252smcffshvJoy4r.jpg'),
(147762, 10516, 'Baseado Numa Historia Real S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/346968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u3sJwNSczEHzMGBeN1vdBY6FYmo.jpg'),
(147763, 10516, 'Baseado Numa Historia Real S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/346969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xi6SwwTVz8d19vaTCa4fMiR4tkR.jpg'),
(147764, 10516, 'Baseado Numa Historia Real S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/346970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/86dO5fdY4PWrepcyNVIxd17dEth.jpg'),
(147765, 10516, 'Baseado Numa Historia Real S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/346971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/no7PJd7ffXgCfHdFbSdGWm9nYLT.jpg'),
(147766, 10516, 'Baseado Numa Historia Real S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/346972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/29lEoBgfZd1c8kSzNHnYj8nBgDl.jpg'),
(147767, 10517, 'Pioneiros do Velho Oeste S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/346961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zZiTG86ofG6nqLcXygewt0ju1MX.jpg'),
(147768, 10517, 'Pioneiros do Velho Oeste S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/346962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sGHsqrFUYssxFZ8J3WnCADkWkFG.jpg'),
(147769, 10517, 'Pioneiros do Velho Oeste S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/346963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x4Nf3oafjLQ4JqID8IfCKHFSaR8.jpg'),
(147770, 10517, 'Pioneiros do Velho Oeste S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/346964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lpkA7Qh1n2VDqZAxlMcz4r69TN8.jpg'),
(147771, 10518, 'O Veu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/356091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yLwiPylJQ0WkgcOn2702JcadC2v.jpg'),
(147772, 10518, 'O Veu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/356092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ph7Wt6gjKDQQQDPiEWJnYqlaoJa.jpg'),
(147773, 10518, 'O Veu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/356093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5IeqZ52jiAAyu7ukCUkpi48c54h.jpg'),
(147774, 10518, 'O Veu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/358922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5IeqZ52jiAAyu7ukCUkpi48c54h.jpg'),
(147775, 10518, 'O Veu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/367256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5IeqZ52jiAAyu7ukCUkpi48c54h.jpg'),
(147776, 10518, 'O Veu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/388939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5IeqZ52jiAAyu7ukCUkpi48c54h.jpg'),
(147777, 10519, 'Remedy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/346735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zrmdwdhySuwNdja26EEZSAxJbXF.jpg'),
(147778, 10519, 'Remedy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/346736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nLGcl0KwkLpXrbQGcKZd2Y2bYWl.jpg'),
(147779, 10519, 'Remedy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/346737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/88ZsqTQAsay7vcVEnMxpHwomRQh.jpg'),
(147780, 10519, 'Remedy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/346738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fKSthW8ahQVqFT7wKFf4Dk43Fcv.jpg'),
(147781, 10519, 'Remedy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/346739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/miMGZUbJGS5EMDBVo9rZe5NOFR2.jpg'),
(147782, 10519, 'Remedy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/346740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zx9BTOdbrJExlP1Ovsfg6mFgDZn.jpg'),
(147783, 10519, 'Remedy S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/346741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n6hg5qeg9sR4uSj27ME6V7MK4J5.jpg'),
(147784, 10519, 'Remedy S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/346742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u0MoIQ0cR18RhBT2IAzu0kKcKUm.jpg'),
(147785, 10519, 'Remedy S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/346743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4eJacCEvWvPu560GJxP6zyvsBkq.jpg'),
(147786, 10519, 'Remedy S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/346744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Ck0WESyEN3qo5YRGtltOj33TP5.jpg'),
(147787, 10520, 'Remedy S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/346745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wrBKNEv2M4a1n6iffHhcSBgRR33.jpg'),
(147788, 10520, 'Remedy S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/346746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hZJsiRC4ZTPJLkRlxyYEih4XMj5.jpg'),
(147789, 10520, 'Remedy S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/346747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d7057pvGPzqv5PwiAR0PplnhLoj.jpg'),
(147790, 10520, 'Remedy S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/346748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/82DnvcQblHDbsy8yn0JSGbQMEUU.jpg'),
(147791, 10520, 'Remedy S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/346749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nTy4QqNSX1KOKjeel3fAJqlx8A.jpg'),
(147792, 10520, 'Remedy S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/346750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kWdWzhq4cx5eS2srlh4AqBgwyiq.jpg'),
(147793, 10520, 'Remedy S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/346751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oRv2FcjjoOAF5bmnEJ8qi1AlVMd.jpg'),
(147794, 10520, 'Remedy S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/346752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDRckZHZ3xM54LUF8N04Fce3MZ.jpg'),
(147795, 10520, 'Remedy S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/346753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ztZY9pFVKxML5seCRNf4VSESLOo.jpg'),
(147796, 10520, 'Remedy S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/346754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9YMJtFEdQEbP9IjNeweusb2UVZA.jpg'),
(147797, 10521, 'The Big Cigar A Fuga S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/346733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rQS9Osovgq5LIE7WBW1Ry7z8epS.jpg'),
(147798, 10521, 'The Big Cigar A Fuga S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/346734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWGHtDirOV1rtLeIyEuuAbjDgDM.jpg'),
(147799, 10521, 'The Big Cigar A Fuga S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/358586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9R0pvAm2k5uI8EAJSSxGCEfbmcK.jpg'),
(147800, 10521, 'The Big Cigar A Fuga S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/605899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9R0pvAm2k5uI8EAJSSxGCEfbmcK.jpg'),
(147801, 10521, 'The Big Cigar A Fuga S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/376240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9R0pvAm2k5uI8EAJSSxGCEfbmcK.jpg'),
(147802, 10521, 'The Big Cigar A Fuga S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/383951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9R0pvAm2k5uI8EAJSSxGCEfbmcK.jpg'),
(147803, 10522, 'Um Cavalheiro em Moscou S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/346725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uo2Omt5GpPEjnTSNr40LoEHXDJw.jpg'),
(147804, 10522, 'Um Cavalheiro em Moscou S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/346726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBSavepmrFFWCh2spcU11P5B1bO.jpg'),
(147805, 10522, 'Um Cavalheiro em Moscou S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/346727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4zCbUAFBjYC5wXbPNVswzosgXiG.jpg'),
(147806, 10522, 'Um Cavalheiro em Moscou S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/346728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cPMoOh5zSyjdAVKPxEwo4EQgsdT.jpg'),
(147807, 10522, 'Um Cavalheiro em Moscou S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/346729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xYgKK7bwuWbfWMc2hjCVNOAtP0F.jpg'),
(147808, 10522, 'Um Cavalheiro em Moscou S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/346730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8F6klFd6cqbp4HfXJjzu100G6aD.jpg'),
(147809, 10522, 'Um Cavalheiro em Moscou S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/346731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w5B7eRNwp1lNU7gWhb4punQvqmN.jpg'),
(147810, 10522, 'Um Cavalheiro em Moscou S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/346732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pA6ySE8i08mAZqWsU9NcYGwGT0f.jpg'),
(147811, 10523, 'Um Homem Sem Filtros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/346719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kinUzs63KIAgf0m1sKX7jA5TzGG.jpg'),
(147812, 10523, 'Um Homem Sem Filtros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/346720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d6IPpjfoWIT72GEruq0T5ZoOJUj.jpg'),
(147813, 10523, 'Um Homem Sem Filtros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/346721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zySUUz8jwc5BCPS6jtRRiBK8yWc.jpg'),
(147814, 10523, 'Um Homem Sem Filtros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/346722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8yU02pzuTt8OOOxIBKiDOmvqq60.jpg'),
(147815, 10523, 'Um Homem Sem Filtros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/346723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ez87enbPiGOT3OEwaiNuUgu6igm.jpg'),
(147816, 10523, 'Um Homem Sem Filtros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/346724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvteGWdf6xSqq9xuz17jzVhOJXu.jpg'),
(147817, 10523, 'Um Homem Sem Filtros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/358221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3m179bXlVEtvKsIn0VEZk5y9n0o.jpg'),
(147818, 10523, 'Um Homem Sem Filtros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/358222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3m179bXlVEtvKsIn0VEZk5y9n0o.jpg'),
(147819, 10523, 'Um Homem Sem Filtros S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/606783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3m179bXlVEtvKsIn0VEZk5y9n0o.jpg'),
(147820, 10523, 'Um Homem Sem Filtros S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/606784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3m179bXlVEtvKsIn0VEZk5y9n0o.jpg'),
(147821, 10523, 'Um Homem Sem Filtros S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/372729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3m179bXlVEtvKsIn0VEZk5y9n0o.jpg'),
(147822, 10523, 'Um Homem Sem Filtros S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/372730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3m179bXlVEtvKsIn0VEZk5y9n0o.jpg'),
(147823, 10524, 'Ashley Madison Sexo Mentiras e Escandalo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/350772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1oOaODfk3Cb8oTV6pK9hUyzOw2J.jpg'),
(147824, 10524, 'Ashley Madison Sexo Mentiras e Escandalo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/350773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hf3flKWUrO2sLYNmIQYfRQNBzN6.jpg'),
(147825, 10524, 'Ashley Madison Sexo Mentiras e Escandalo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/350774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/icGMYOfricnXaVGMGdX5AmkACVB.jpg'),
(147826, 10525, 'Gray S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/350764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ekLOZbp8accSH9uxejRoN9KRXaC.jpg'),
(147827, 10525, 'Gray S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/350765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bDMlQWHUlJSdlnsu4fbyh6g9KNC.jpg'),
(147828, 10525, 'Gray S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/350766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vomHcCuf52vnZz312YyZThTGmAK.jpg'),
(147829, 10525, 'Gray S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/350767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ff2sTTsNO3hdIcFG35zYmQ6A1Bu.jpg'),
(147830, 10525, 'Gray S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/350768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9vsF0OqYaaFRVR250eLS94Xrkez.jpg'),
(147831, 10525, 'Gray S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/350769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qpgqbDxFhgt10KGAqbBRa13iRhS.jpg'),
(147832, 10525, 'Gray S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/350770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/llLBIARW4547WsEKLrbNWfaNVmV.jpg'),
(147833, 10525, 'Gray S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/350771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2n5aTGMvowY1uaVe6HesDe5ArCi.jpg'),
(147834, 10526, 'Largados Pelados e Ilhados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/350761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/axbXLrScT2taZlBr0PilKR18Dgk.jpg'),
(147835, 10526, 'Largados Pelados e Ilhados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/350762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8PRaoyzzfudARDTymxRLZHUM8f.jpg'),
(147836, 10526, 'Largados Pelados e Ilhados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/350763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a5jcWYMErWm2J9N1iFKNrUs4tWS.jpg'),
(147837, 10526, 'Largados Pelados e Ilhados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/360731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fOVIve9iewiTKowYTnWJ6q3C5Dl.jpg'),
(147838, 10526, 'Largados Pelados e Ilhados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/604964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fOVIve9iewiTKowYTnWJ6q3C5Dl.jpg'),
(147839, 10526, 'Largados Pelados e Ilhados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/379796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fOVIve9iewiTKowYTnWJ6q3C5Dl.jpg'),
(147840, 10526, 'Largados Pelados e Ilhados S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/387393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fOVIve9iewiTKowYTnWJ6q3C5Dl.jpg'),
(147841, 10526, 'Largados Pelados e Ilhados S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/392605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fOVIve9iewiTKowYTnWJ6q3C5Dl.jpg'),
(147842, 10527, 'The 8 Show S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/350753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y5qaxtv0x305rk21c9gz3jbXqBr.jpg'),
(147843, 10527, 'The 8 Show S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/350754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jNTOSShlXzdQfqueivWCYhb2TWx.jpg'),
(147844, 10527, 'The 8 Show S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/350755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pK3Baxh9twN5ffLYCHBBGXa4Myk.jpg'),
(147845, 10527, 'The 8 Show S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/350756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/96rLqyuETqH97l4Us2F0XAgMZLi.jpg'),
(147846, 10527, 'The 8 Show S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/350757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ozGLBAuVZE7O6uSwrB0KtAE5FWF.jpg'),
(147847, 10527, 'The 8 Show S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/350758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rNwLAFe5FbIcJqlVhKKGiOb8vAP.jpg'),
(147848, 10527, 'The 8 Show S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/350759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e0EQFHUjQFEaPdUX0r7uv4hv3E5.jpg'),
(147849, 10527, 'The 8 Show S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/350760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7HqxGSXQbHvTs1AKIZotXhpx7G3.jpg'),
(147850, 10528, 'Cilada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2PAvxIPB5FB0Hk7bU2nYq9o3z8I.jpg'),
(147851, 10528, 'Cilada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2PAvxIPB5FB0Hk7bU2nYq9o3z8I.jpg'),
(147852, 10528, 'Cilada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2PAvxIPB5FB0Hk7bU2nYq9o3z8I.jpg'),
(147853, 10528, 'Cilada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2PAvxIPB5FB0Hk7bU2nYq9o3z8I.jpg'),
(147854, 10528, 'Cilada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2PAvxIPB5FB0Hk7bU2nYq9o3z8I.jpg'),
(147855, 10528, 'Cilada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2PAvxIPB5FB0Hk7bU2nYq9o3z8I.jpg'),
(147856, 10528, 'Cilada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2PAvxIPB5FB0Hk7bU2nYq9o3z8I.jpg'),
(147857, 10528, 'Cilada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2PAvxIPB5FB0Hk7bU2nYq9o3z8I.jpg'),
(147858, 10528, 'Cilada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2PAvxIPB5FB0Hk7bU2nYq9o3z8I.jpg'),
(147859, 10528, 'Cilada S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2PAvxIPB5FB0Hk7bU2nYq9o3z8I.jpg'),
(147860, 10529, 'Cilada S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/692771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2PAvxIPB5FB0Hk7bU2nYq9o3z8I.jpg'),
(147861, 10529, 'Cilada S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/692772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2PAvxIPB5FB0Hk7bU2nYq9o3z8I.jpg'),
(147862, 10529, 'Cilada S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/692773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2PAvxIPB5FB0Hk7bU2nYq9o3z8I.jpg'),
(147863, 10529, 'Cilada S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/692774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2PAvxIPB5FB0Hk7bU2nYq9o3z8I.jpg'),
(147864, 10529, 'Cilada S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/692775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2PAvxIPB5FB0Hk7bU2nYq9o3z8I.jpg'),
(147865, 10529, 'Cilada S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/692776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2PAvxIPB5FB0Hk7bU2nYq9o3z8I.jpg'),
(147866, 10529, 'Cilada S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/692777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2PAvxIPB5FB0Hk7bU2nYq9o3z8I.jpg'),
(147867, 10529, 'Cilada S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/692778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2PAvxIPB5FB0Hk7bU2nYq9o3z8I.jpg'),
(147868, 10529, 'Cilada S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/692779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2PAvxIPB5FB0Hk7bU2nYq9o3z8I.jpg'),
(147869, 10529, 'Cilada S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/692780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2PAvxIPB5FB0Hk7bU2nYq9o3z8I.jpg'),
(147870, 10530, '2gether The Series [L] S00 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag8sOpxOJXKPGKtMnmSGPm76h0g.jpg'),
(147871, 10530, '2gether The Series [L] S00 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag8sOpxOJXKPGKtMnmSGPm76h0g.jpg'),
(147872, 10530, '2gether The Series [L] S00 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag8sOpxOJXKPGKtMnmSGPm76h0g.jpg'),
(147873, 10530, '2gether The Series [L] S00 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag8sOpxOJXKPGKtMnmSGPm76h0g.jpg'),
(147874, 10530, '2gether The Series [L] S00 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag8sOpxOJXKPGKtMnmSGPm76h0g.jpg'),
(147875, 10531, '2gether The Series [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag8sOpxOJXKPGKtMnmSGPm76h0g.jpg'),
(147876, 10531, '2gether The Series [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag8sOpxOJXKPGKtMnmSGPm76h0g.jpg'),
(147877, 10531, '2gether The Series [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag8sOpxOJXKPGKtMnmSGPm76h0g.jpg'),
(147878, 10531, '2gether The Series [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag8sOpxOJXKPGKtMnmSGPm76h0g.jpg'),
(147879, 10531, '2gether The Series [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag8sOpxOJXKPGKtMnmSGPm76h0g.jpg'),
(147880, 10531, '2gether The Series [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag8sOpxOJXKPGKtMnmSGPm76h0g.jpg'),
(147881, 10531, '2gether The Series [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag8sOpxOJXKPGKtMnmSGPm76h0g.jpg'),
(147882, 10531, '2gether The Series [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag8sOpxOJXKPGKtMnmSGPm76h0g.jpg'),
(147883, 10531, '2gether The Series [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag8sOpxOJXKPGKtMnmSGPm76h0g.jpg'),
(147884, 10531, '2gether The Series [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag8sOpxOJXKPGKtMnmSGPm76h0g.jpg'),
(147885, 10531, '2gether The Series [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag8sOpxOJXKPGKtMnmSGPm76h0g.jpg'),
(147886, 10531, '2gether The Series [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag8sOpxOJXKPGKtMnmSGPm76h0g.jpg'),
(147887, 10531, '2gether The Series [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/353926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ag8sOpxOJXKPGKtMnmSGPm76h0g.jpg'),
(147888, 10532, 'A Rainha da Trapaca de Hollywood [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nCRpZHwbTFiNdUEPuVs135HcYag.jpg'),
(147889, 10532, 'A Rainha da Trapaca de Hollywood [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8KjsH2TtuAjTzJcYV6szQd9JSTf.jpg'),
(147890, 10532, 'A Rainha da Trapaca de Hollywood [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/otfujsaeO6bqx4ArNVGHfBwlnwW.jpg'),
(147891, 10533, 'All the Liquors [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zmZknzx8TqZoP7C4fThVUxOH6dX.jpg'),
(147892, 10533, 'All the Liquors [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8rwyiqUXLXrjcElH0m9YLDolrME.jpg'),
(147893, 10533, 'All the Liquors [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8yMmMjE7xKNkKtGgr4zWBs9bRg2.jpg'),
(147894, 10533, 'All the Liquors [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6qLoWsVYn3JmfHmsXtsjJ966Vg9.jpg'),
(147895, 10533, 'All the Liquors [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qRco8plBrzSsVr6BPrXQgmaf78D.jpg'),
(147896, 10533, 'All the Liquors [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qRco8plBrzSsVr6BPrXQgmaf78D.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(147897, 10533, 'All the Liquors [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ShxwUizlXtRvTpyUBW9VG4K3F7.jpg'),
(147898, 10533, 'All the Liquors [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aFR43y8bivSRn3SXygjMBKktIuo.jpg'),
(147899, 10534, 'Amor Por Acaso [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gbYKYKlNsAJAPDthcX9pMHFeKba.jpg'),
(147900, 10534, 'Amor Por Acaso [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sYyJfSthP1EjTIOaZ2cDeS7eaJ0.jpg'),
(147901, 10534, 'Amor Por Acaso [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aJNX4LscesPw7I8nZaSY2m3sqQj.jpg'),
(147902, 10534, 'Amor Por Acaso [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/upN0Kkk1ziMBtYeyubN0wjjTJS4.jpg'),
(147903, 10534, 'Amor Por Acaso [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nqRUX0wvuPAtfAbArrylTreBQyW.jpg'),
(147904, 10534, 'Amor Por Acaso [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/65Zv79XYsnCO8KjTWXe0UKpyeKb.jpg'),
(147905, 10534, 'Amor Por Acaso [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/99XJcmP0gqxydWUZUI3NR9mNHt2.jpg'),
(147906, 10534, 'Amor Por Acaso [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9WPfcymUw4yLqZAOauEpF1Wo6Ss.jpg'),
(147907, 10534, 'Amor Por Acaso [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AhIWCcJDQAgxiXs60elA05ZfjS.jpg'),
(147908, 10534, 'Amor Por Acaso [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zTHOku8fDOYrnR1ndFammcjc7DM.jpg'),
(147909, 10534, 'Amor Por Acaso [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7hi904rYaNJTQOEHarM4FUhDiTi.jpg'),
(147910, 10534, 'Amor Por Acaso [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uSrw39Y1RrsbFZ5OzyVJdaRfuSU.jpg'),
(147911, 10534, 'Amor Por Acaso [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/353887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rycoYri1DbNdHJDHPt4UHnEafB2.jpg'),
(147912, 10534, 'Amor Por Acaso [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/353888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/84RfBiegsSPj66cRdHeFduJJWPy.jpg'),
(147913, 10535, 'Amor Por Acaso [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q22ee7TAjZSOZtIrDrT6hGVpwtg.jpg'),
(147914, 10535, 'Amor Por Acaso [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dFEMKdRVlxnx87F8uqlqQuig85v.jpg'),
(147915, 10535, 'Amor Por Acaso [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2W4KXC3HUJkR4AZfmGtH6ZueC53.jpg'),
(147916, 10535, 'Amor Por Acaso [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vcJZekvTjXukNeVmQCbTPdg6cKo.jpg'),
(147917, 10535, 'Amor Por Acaso [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xx6kqBIlIxA16JgAGo8i9VCdvEC.jpg'),
(147918, 10535, 'Amor Por Acaso [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAbkzNXLFR6cS0TfBcOih5DCYuz.jpg'),
(147919, 10535, 'Amor Por Acaso [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bBD4y3eh7u1Du09p2L5nrx7HqGo.jpg'),
(147920, 10535, 'Amor Por Acaso [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qXxdi6Xu38WrsC4DjXpqAYs7u5C.jpg'),
(147921, 10535, 'Amor Por Acaso [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pakQpbQtILhVbxZlYG8TUWwYPrc.jpg'),
(147922, 10535, 'Amor Por Acaso [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7a2ieEpoUQ8OrhIbPVB0dCvWA98.jpg'),
(147923, 10535, 'Amor Por Acaso [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3quy3KX8wA0IqPkloktmLzBdNqY.jpg'),
(147924, 10535, 'Amor Por Acaso [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9L0EyqlO0qoRhGmR2715fYhf0fd.jpg'),
(147925, 10536, 'Amor no Ar [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKMpTvZHiF1nLqTzz7bWF2MtChY.jpg'),
(147926, 10536, 'Amor no Ar [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4RSajjnYlpu86rmST3DQRebdkTn.jpg'),
(147927, 10536, 'Amor no Ar [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jx9bOiJuybcJrJzBnKTK4M8oWPT.jpg'),
(147928, 10536, 'Amor no Ar [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gpnkyM53D7UWC1wsANnhDRrWagS.jpg'),
(147929, 10536, 'Amor no Ar [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4FZl7wKXfGdMhGNrGE66ToRHJS2.jpg'),
(147930, 10536, 'Amor no Ar [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gvWdXTDxIEzLlLrxApsOXAiF0eV.jpg'),
(147931, 10536, 'Amor no Ar [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8pMer0domraJbdft04WiIoRZlQu.jpg'),
(147932, 10536, 'Amor no Ar [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/176JvbquZVkPFYeflPDgDYRzi5o.jpg'),
(147933, 10536, 'Amor no Ar [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9L0NA8ILMour2D3fd8nydDbxyET.jpg'),
(147934, 10536, 'Amor no Ar [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ebGyXxn1wL0mcSUGrLioVjx5kOS.jpg'),
(147935, 10536, 'Amor no Ar [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lA0mxUhjdpAlY0pqrrtuela1mNd.jpg'),
(147936, 10536, 'Amor no Ar [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/23eGHqOwSHBqVPdyP20xSAxosss.jpg'),
(147937, 10536, 'Amor no Ar [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/353874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4EohGpA6FvLbH0fH5foh3OOV6NF.jpg'),
(147938, 10537, 'Cafe do Principe [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zfpPQ5MHqKOyL6bWqHANryN1kGM.jpg'),
(147939, 10537, 'Cafe do Principe [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2qBye1Ni4U0btR0058wI7ovKnK5.jpg'),
(147940, 10537, 'Cafe do Principe [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dDOXoQTb1bPBCgOWnmWz8XCUp2z.jpg'),
(147941, 10537, 'Cafe do Principe [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hfVoer2GQNfM1oGtFXmzPBBOMaJ.jpg'),
(147942, 10537, 'Cafe do Principe [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Va2GGB03W2FFhxjJXYlbFGERnm.jpg'),
(147943, 10537, 'Cafe do Principe [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vZAL7h8LhlbcKAyNEcB3vXL2eGo.jpg'),
(147944, 10537, 'Cafe do Principe [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/32fCCgYpqgPYiykbRI883PfA19j.jpg'),
(147945, 10537, 'Cafe do Principe [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AcVFgWmxJZWyW7TEXspmkkhelc0.jpg'),
(147946, 10537, 'Cafe do Principe [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oV1LBnbngiBipXWg5nkszxEaG3c.jpg'),
(147947, 10537, 'Cafe do Principe [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/etJHye8YJJFqrG5DUiMuKQNE1Ym.jpg'),
(147948, 10537, 'Cafe do Principe [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pfRTnCriBZDnSocFQnWn5cFgLc2.jpg'),
(147949, 10537, 'Cafe do Principe [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9yhgzBFONSxG0tNC6mSc0Ojj0hp.jpg'),
(147950, 10537, 'Cafe do Principe [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/353857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/okD9UzfvtAKRuYpx2wQA1uYoe3S.jpg'),
(147951, 10537, 'Cafe do Principe [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/353858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n6l8qbQeGng35k9GBpN8jB59UAE.jpg'),
(147952, 10537, 'Cafe do Principe [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/353859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bXwsF8le5xBOCGOptUNN6gr3Btg.jpg'),
(147953, 10537, 'Cafe do Principe [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/353860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xh9nOqIS0iBm2BWiL5POtTsAKpO.jpg'),
(147954, 10537, 'Cafe do Principe [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/353861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nlduxuKB4xfJ0PlZkIgwQjTYz0K.jpg'),
(147955, 10538, 'Casamento as Cegas Japao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hl864XhZ22JToxNbS8BtD4iTN1w.jpg'),
(147956, 10538, 'Casamento as Cegas Japao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e2EhuoMayAtHZf5oENSDHRq6iIH.jpg'),
(147957, 10538, 'Casamento as Cegas Japao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/62cPWWdfuQVE2cdyeff0h0wJrcq.jpg'),
(147958, 10538, 'Casamento as Cegas Japao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOrq4wxqhY5hy1AajOxLobYjcBV.jpg'),
(147959, 10538, 'Casamento as Cegas Japao [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jG6YujJL9k1LKXNMRcRbmHraBWm.jpg'),
(147960, 10538, 'Casamento as Cegas Japao [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n8vpVCVuCiunZRZ0EJvXyYJWH1Q.jpg'),
(147961, 10538, 'Casamento as Cegas Japao [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v46VORmWNXC63xqneo6a4r5Nr7L.jpg'),
(147962, 10538, 'Casamento as Cegas Japao [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tDDU4CfbOqNREcNZ1eDuBLiUk9b.jpg'),
(147963, 10538, 'Casamento as Cegas Japao [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lGeCt0pbsddCOeO4h9kNPsWKxsd.jpg'),
(147964, 10538, 'Casamento as Cegas Japao [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ruRvuGZXwTqWgLMn0moeosxjSjs.jpg'),
(147965, 10538, 'Casamento as Cegas Japao [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tV576rDLPYdBimxr26P9LLhptLp.jpg'),
(147966, 10539, 'Coffee Melody [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/khYahHmLlsYKKncQDbQq9pScpS9.jpg'),
(147967, 10539, 'Coffee Melody [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qrxAtZYD9NolH3LC6g49LgUKenO.jpg'),
(147968, 10539, 'Coffee Melody [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qrxAtZYD9NolH3LC6g49LgUKenO.jpg'),
(147969, 10539, 'Coffee Melody [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qrxAtZYD9NolH3LC6g49LgUKenO.jpg'),
(147970, 10539, 'Coffee Melody [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qrxAtZYD9NolH3LC6g49LgUKenO.jpg'),
(147971, 10539, 'Coffee Melody [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qrxAtZYD9NolH3LC6g49LgUKenO.jpg'),
(147972, 10539, 'Coffee Melody [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qrxAtZYD9NolH3LC6g49LgUKenO.jpg'),
(147973, 10539, 'Coffee Melody [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qrxAtZYD9NolH3LC6g49LgUKenO.jpg'),
(147974, 10539, 'Coffee Melody [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qrxAtZYD9NolH3LC6g49LgUKenO.jpg'),
(147975, 10539, 'Coffee Melody [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qrxAtZYD9NolH3LC6g49LgUKenO.jpg'),
(147976, 10539, 'Coffee Melody [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qrxAtZYD9NolH3LC6g49LgUKenO.jpg'),
(147977, 10539, 'Coffee Melody [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qrxAtZYD9NolH3LC6g49LgUKenO.jpg'),
(147978, 10540, 'Debaixo da Ponte A Verdadeira Historia do Assassinato de Reena Virk [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z959e4pPKAyNb6iA2nECuRBi19l.jpg'),
(147979, 10540, 'Debaixo da Ponte A Verdadeira Historia do Assassinato de Reena Virk [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1nrHbslpcJ29qEwuTAC1PEoTzY.jpg'),
(147980, 10540, 'Debaixo da Ponte A Verdadeira Historia do Assassinato de Reena Virk [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4G4oQYBKhn2PiiyQD3qa9gXUXh.jpg'),
(147981, 10540, 'Debaixo da Ponte A Verdadeira Historia do Assassinato de Reena Virk [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bUcmuBYPcC9jRJSrACEhTXmONeV.jpg'),
(147982, 10540, 'Debaixo da Ponte A Verdadeira Historia do Assassinato de Reena Virk [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2RdwYipsahUIru8AC3bus3TyMBm.jpg'),
(147983, 10540, 'Debaixo da Ponte A Verdadeira Historia do Assassinato de Reena Virk [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/369041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4YMpCGsAAHXWGScHsK1sbd7wprE.jpg'),
(147984, 10540, 'Debaixo da Ponte A Verdadeira Historia do Assassinato de Reena Virk [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/397109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4YMpCGsAAHXWGScHsK1sbd7wprE.jpg'),
(147985, 10541, 'Docinho [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mmRGlmTbAee4RJ4yR7jNcPum5TD.jpg'),
(147986, 10541, 'Docinho [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pviNZWFYFSO5PUjfkjJYRJ5m66d.jpg'),
(147987, 10541, 'Docinho [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zuKh53gRy8VziMTB8CV6y3kgZQM.jpg'),
(147988, 10541, 'Docinho [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yXXWSs9gLvt9M5YHfGdjHd68dd1.jpg'),
(147989, 10541, 'Docinho [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rU3Y8kqk1K8h7ASCqP7PunMrcVG.jpg'),
(147990, 10541, 'Docinho [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n7DwxOUbcWpRQlLt7kgb0kJDaV3.jpg'),
(147991, 10541, 'Docinho [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3GCGzuUAZcUvg8m2WkJCgUhH9nq.jpg'),
(147992, 10541, 'Docinho [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/89IcunVsjD1kxoScK70jonekbYe.jpg'),
(147993, 10541, 'Docinho [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hS46Ghk3CqoMCsnk2uOHl3mjssA.jpg'),
(147994, 10541, 'Docinho [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8s91Tz4uZrXuGVStJTLSM7RScY5.jpg'),
(147995, 10541, 'Docinho [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uDHG4hk5Ro08rbj8XHCjim2vO5T.jpg'),
(147996, 10541, 'Docinho [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i5CCsGIpOWjp7E8FBEJsnOFI7Wh.jpg'),
(147997, 10542, 'Dororo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yKSzJWzJONMo7pCoAr7r9PqutRP.jpg'),
(147998, 10542, 'Dororo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aAyIz1DjRO9zDFWHXiubvfjny44.jpg'),
(147999, 10542, 'Dororo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vyMMjIjIAHVb5REd3PoTcu1xTIQ.jpg'),
(148000, 10542, 'Dororo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xA9ldyVfLYaM925eozxD0YChKFZ.jpg'),
(148001, 10542, 'Dororo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qCURkokstKjVh9nEJiFp0DljsKj.jpg'),
(148002, 10542, 'Dororo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vCNIB14j6w8pu4LKeokPdDHxkvS.jpg'),
(148003, 10542, 'Dororo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sADQK5Pn7V7DHvTLUntbAa6ms8K.jpg'),
(148004, 10542, 'Dororo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wcEwjXwiG5Av5QSFHSGnVfjRWEg.jpg'),
(148005, 10542, 'Dororo [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u6vv9rz5P0K9JE95A2xTGP9tvvn.jpg'),
(148006, 10542, 'Dororo [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3EMzSIyeHCb1i6xs7B3ZqG6hsKt.jpg'),
(148007, 10542, 'Dororo [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4D6PrRfaZn1wMfnCyvqDtWOXVGY.jpg'),
(148008, 10542, 'Dororo [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Kqssb1ve18cwLKCD60NEJIz7nt.jpg'),
(148009, 10542, 'Dororo [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/353790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oIhjEQyABUWJGikWeZcPtui1QL3.jpg'),
(148010, 10542, 'Dororo [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/353791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hhos5hv7M2DvwjeOD2IM93OhY1Y.jpg'),
(148011, 10542, 'Dororo [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/353792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yVy1IBSqUtidCRHXpq094lz7V3N.jpg'),
(148012, 10542, 'Dororo [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/353793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AlW3Iuu6YeMhdYnkI0BHwmLvism.jpg'),
(148013, 10542, 'Dororo [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/353794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xv3F5maqfOMreLkwLyv6vbUdpVu.jpg'),
(148014, 10542, 'Dororo [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/353795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSodpEsJ62G3nynPLGKGOs0LC8m.jpg'),
(148015, 10542, 'Dororo [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/353796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aTo2W2lvxMRkgG2F6YjN203fSgt.jpg'),
(148016, 10542, 'Dororo [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/353797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ve42YCU5V2x2LeWGiIYVAItZBub.jpg'),
(148017, 10542, 'Dororo [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/353798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ih17ysxSiyA4jondtUO1q5xFBz.jpg'),
(148018, 10542, 'Dororo [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/353799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cVG0wNfH808GRhJCaqU4vqIqnoi.jpg'),
(148019, 10542, 'Dororo [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/353800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yah55wObW1L41UqasHH98pgKiAh.jpg'),
(148020, 10542, 'Dororo [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/353801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJYpl47wN4Bn7mhBk8YhueiMs9T.jpg'),
(148021, 10543, 'Dragon Raja The Blazing Dawn [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mGeuhvM6ucGunrgHOkQw3UCoEvB.jpg'),
(148022, 10543, 'Dragon Raja The Blazing Dawn [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMT1gID5Bghc23D0KjhoSgfAwTr.jpg'),
(148023, 10543, 'Dragon Raja The Blazing Dawn [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/akpBHWE8j9TkHUwwmrfzXFanB1l.jpg'),
(148024, 10543, 'Dragon Raja The Blazing Dawn [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iBFRC9koR9GWNwqvz2JF6wu0uaZ.jpg'),
(148025, 10543, 'Dragon Raja The Blazing Dawn [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ims5c5U9jkTBnvbQslJVCRv5dy7.jpg'),
(148026, 10543, 'Dragon Raja The Blazing Dawn [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rK6PyFwRBOsUAhK0ZLsDkS0udmu.jpg'),
(148027, 10543, 'Dragon Raja The Blazing Dawn [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zoNn9JA5tG3zuc5UCUgMmI7y8HC.jpg'),
(148028, 10543, 'Dragon Raja The Blazing Dawn [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bDVdcSraUKNYnTLY0Lejug50Je3.jpg'),
(148029, 10543, 'Dragon Raja The Blazing Dawn [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jXMij5fmaKBxGzd945Ssbbbgmd0.jpg'),
(148030, 10543, 'Dragon Raja The Blazing Dawn [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ejvyb4kKaeeIrxuwfPYkuYtMh20.jpg'),
(148031, 10543, 'Dragon Raja The Blazing Dawn [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFbYI9uR7TLZMzZCmOzahvgObBl.jpg'),
(148032, 10543, 'Dragon Raja The Blazing Dawn [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/369016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mGeuhvM6ucGunrgHOkQw3UCoEvB.jpg'),
(148033, 10543, 'Dragon Raja The Blazing Dawn [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/369017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mGeuhvM6ucGunrgHOkQw3UCoEvB.jpg'),
(148034, 10543, 'Dragon Raja The Blazing Dawn [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/378230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mGeuhvM6ucGunrgHOkQw3UCoEvB.jpg'),
(148035, 10543, 'Dragon Raja The Blazing Dawn [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/387434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mGeuhvM6ucGunrgHOkQw3UCoEvB.jpg'),
(148036, 10543, 'Dragon Raja The Blazing Dawn [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/419706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mGeuhvM6ucGunrgHOkQw3UCoEvB.jpg'),
(148037, 10543, 'Dragon Raja The Blazing Dawn [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/419707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mGeuhvM6ucGunrgHOkQw3UCoEvB.jpg'),
(148038, 10544, 'Dragon Raja The Blazing Dawn [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/887703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mGeuhvM6ucGunrgHOkQw3UCoEvB.jpg'),
(148039, 10544, 'Dragon Raja The Blazing Dawn [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/887704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mGeuhvM6ucGunrgHOkQw3UCoEvB.jpg'),
(148040, 10544, 'Dragon Raja The Blazing Dawn [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/887705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mGeuhvM6ucGunrgHOkQw3UCoEvB.jpg'),
(148041, 10544, 'Dragon Raja The Blazing Dawn [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/887706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mGeuhvM6ucGunrgHOkQw3UCoEvB.jpg'),
(148042, 10544, 'Dragon Raja The Blazing Dawn [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/887707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mGeuhvM6ucGunrgHOkQw3UCoEvB.jpg'),
(148043, 10544, 'Dragon Raja The Blazing Dawn [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/887708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mGeuhvM6ucGunrgHOkQw3UCoEvB.jpg'),
(148044, 10544, 'Dragon Raja The Blazing Dawn [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/887709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mGeuhvM6ucGunrgHOkQw3UCoEvB.jpg'),
(148045, 10544, 'Dragon Raja The Blazing Dawn [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/887710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mGeuhvM6ucGunrgHOkQw3UCoEvB.jpg'),
(148046, 10544, 'Dragon Raja The Blazing Dawn [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/887711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mGeuhvM6ucGunrgHOkQw3UCoEvB.jpg'),
(148047, 10544, 'Dragon Raja The Blazing Dawn [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/887712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mGeuhvM6ucGunrgHOkQw3UCoEvB.jpg'),
(148048, 10545, 'Elsbeth [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYw2q7XL7q1kjadMKluwakQetLX.jpg'),
(148049, 10545, 'Elsbeth [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fNU61HW85TvEE9E5H3me4XYQaVz.jpg'),
(148050, 10545, 'Elsbeth [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6RDDXomyjqXyds3uICnBCWemZVV.jpg'),
(148051, 10545, 'Elsbeth [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1D0PYo8VCSgRZ2SD9MNEslsnL71.jpg'),
(148052, 10545, 'Elsbeth [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/368982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148053, 10545, 'Elsbeth [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/403500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148054, 10545, 'Elsbeth [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/405269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148055, 10545, 'Elsbeth [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/405270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148056, 10545, 'Elsbeth [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/409244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148057, 10545, 'Elsbeth [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/422296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148058, 10546, 'Elsbeth [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/485487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148059, 10546, 'Elsbeth [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/496829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148060, 10546, 'Elsbeth [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/499573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148061, 10546, 'Elsbeth [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148062, 10546, 'Elsbeth [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/512460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148063, 10546, 'Elsbeth [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/641855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148064, 10546, 'Elsbeth [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/665049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148065, 10546, 'Elsbeth [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/683722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148066, 10546, 'Elsbeth [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/690602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148067, 10546, 'Elsbeth [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/702056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148068, 10546, 'Elsbeth [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/718623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148069, 10546, 'Elsbeth [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/730561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148070, 10546, 'Elsbeth [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/755081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148071, 10546, 'Elsbeth [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/778220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148072, 10546, 'Elsbeth [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/783477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148073, 10546, 'Elsbeth [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/788589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148074, 10546, 'Elsbeth [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/823153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148075, 10546, 'Elsbeth [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/811048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148076, 10546, 'Elsbeth [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/823155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148077, 10546, 'Elsbeth [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/844789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6RxCjj3I8FUPQHSkXnnE1xG2wn.jpg'),
(148078, 10547, 'En of Love [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ndLC9UNpDPqHdNtKvouKyQ0gXuk.jpg'),
(148079, 10547, 'En of Love [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ndLC9UNpDPqHdNtKvouKyQ0gXuk.jpg'),
(148080, 10547, 'En of Love [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ndLC9UNpDPqHdNtKvouKyQ0gXuk.jpg'),
(148081, 10547, 'En of Love [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ndLC9UNpDPqHdNtKvouKyQ0gXuk.jpg'),
(148082, 10548, 'En of Love [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ndLC9UNpDPqHdNtKvouKyQ0gXuk.jpg'),
(148083, 10548, 'En of Love [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ndLC9UNpDPqHdNtKvouKyQ0gXuk.jpg'),
(148084, 10548, 'En of Love [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ndLC9UNpDPqHdNtKvouKyQ0gXuk.jpg'),
(148085, 10548, 'En of Love [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ndLC9UNpDPqHdNtKvouKyQ0gXuk.jpg'),
(148086, 10549, 'En of Love [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/74i3njSLftOEKib02rsqmrMlLsg.jpg'),
(148087, 10549, 'En of Love [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1IUMbmxiIlezXIByCbGA5ZXGcbV.jpg'),
(148088, 10549, 'En of Love [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMRT2eLMk39AGMHtRBmO8fTwSot.jpg'),
(148089, 10550, 'Grande Dragao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4SP9FYOW9taNZQtUlb2b5zihrCE.jpg'),
(148090, 10550, 'Grande Dragao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6MjuvxU4ZU3LzrlI7KwuHzBosW0.jpg'),
(148091, 10550, 'Grande Dragao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fpvC5j7IMSlMbALUhdtBhmwVEq6.jpg'),
(148092, 10550, 'Grande Dragao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLKDytwpJydiulUyJypVmsLw0sa.jpg'),
(148093, 10550, 'Grande Dragao [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fe0s4WtLcOMD5s9Z3CguLg0hDwO.jpg'),
(148094, 10550, 'Grande Dragao [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8hAzc5gUnrcl9jakP0jDL51qlg9.jpg'),
(148095, 10550, 'Grande Dragao [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l8I2TvfqEWQAbmwlEUVBYphX1OH.jpg'),
(148096, 10550, 'Grande Dragao [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/awuDpt7pfdK9sq2ymGZuzle1iK6.jpg'),
(148097, 10551, 'Happy Merry Ending [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vLskBVWvqVjdJQnEPPeCGRoFS5Q.jpg'),
(148098, 10551, 'Happy Merry Ending [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fKgrSjGsThx0GNy35UeXDlGCNwV.jpg'),
(148099, 10551, 'Happy Merry Ending [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zi2uSNvu65SlNs278OCxpS6hOpq.jpg'),
(148100, 10551, 'Happy Merry Ending [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pq0weC4WZTDlhNeiJM3ZUEKe3Ik.jpg'),
(148101, 10551, 'Happy Merry Ending [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/417n4OAHKpd4KMfwIQny6iho15q.jpg'),
(148102, 10551, 'Happy Merry Ending [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cpcQnAnIBoP4SJMvjiRwQcJu9m.jpg'),
(148103, 10551, 'Happy Merry Ending [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6zbMIRKshB5sKj9WzOmNUH5mIR5.jpg'),
(148104, 10551, 'Happy Merry Ending [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gBCookhyo0hPUaTi3GWk4EVOO08.jpg'),
(148105, 10552, 'I Told Susent About You [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1CM6S46n6piQar1MAy3lagG571a.jpg'),
(148106, 10552, 'I Told Susent About You [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2xiTbmcDVytlI6EPnAXLw0KZcrW.jpg'),
(148107, 10552, 'I Told Susent About You [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b15xHoGaqhHNjDmYqtX3jC4B3iH.jpg'),
(148108, 10552, 'I Told Susent About You [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xpOeh1Hb5Kf1QxDAPcY455PfHjp.jpg'),
(148109, 10552, 'I Told Susent About You [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v9exiUfDiDAbQPMbg3WZ74tm1hy.jpg'),
(148110, 10553, 'I Told Susent About You [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fbf4LQLTWBFIMhoC00cTHscJaEf.jpg'),
(148111, 10553, 'I Told Susent About You [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhPOhXOTGYSw41iHS93yKkqTjsP.jpg'),
(148112, 10553, 'I Told Susent About You [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/38h7oqwrRmUmAfherDif4lNUMWH.jpg'),
(148113, 10553, 'I Told Susent About You [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yVwiDB5EYP5IEVdk0eVJBuxpexD.jpg'),
(148114, 10553, 'I Told Susent About You [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xdoqCJ1rtRObcSgK6yISYcOg6RO.jpg'),
(148115, 10554, 'Lembre de Mim [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cyFMQDEycAtoR7wvqKVjJAQQ4zJ.jpg'),
(148116, 10554, 'Lembre de Mim [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cFhFLpC5ukwy7mUL51gQsKFsI3x.jpg'),
(148117, 10554, 'Lembre de Mim [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ziGQ5GfdPw96em9bXa2UK7QF1F.jpg'),
(148118, 10554, 'Lembre de Mim [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vArjFrEsJYDmIDfbQkv5LCod1WJ.jpg'),
(148119, 10554, 'Lembre de Mim [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4EPa8nsbe2KlDTQwjBsB1vHWLWG.jpg'),
(148120, 10554, 'Lembre de Mim [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4h1wxU2x7QstUNQS19IxvzRVKch.jpg'),
(148121, 10554, 'Lembre de Mim [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1fttusJ4i7eeMLYcuzhDycT2DKU.jpg'),
(148122, 10554, 'Lembre de Mim [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNfVeJyUsUZV9jt0SxTTxKOtDJ8.jpg'),
(148123, 10554, 'Lembre de Mim [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uSlyh5f65hSpS31C59SNSJoGswW.jpg'),
(148124, 10554, 'Lembre de Mim [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xLB8PENZlJr0sNP7wOe6Klm1ZoO.jpg'),
(148125, 10554, 'Lembre de Mim [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rgO52gFA48px5XtnNB68YVJMboF.jpg'),
(148126, 10554, 'Lembre de Mim [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yITvEm9Ur5a7KTJ996xZfXIIMqw.jpg'),
(148127, 10554, 'Lembre de Mim [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/353724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pEZzwxCxBxxfyNWAmF3QixFlBfk.jpg'),
(148128, 10554, 'Lembre de Mim [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/353725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWFLsKl6EX7K0Bd2Gp0CYeRrkia.jpg'),
(148129, 10555, 'Love Mate [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4iAP0uvUdji2Y2phXqvZlLtBdAQ.jpg'),
(148130, 10555, 'Love Mate [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i0icT9Dhpc7RYRxZGiCWJz7DAAm.jpg'),
(148131, 10555, 'Love Mate [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xTqh2zP2RnCz3hUKo6J9AXyj5VH.jpg'),
(148132, 10555, 'Love Mate [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yp53AsWZff5CirQb1PISGflJmOb.jpg'),
(148133, 10555, 'Love Mate [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7mii6fK4q6a0Qyi6C0Docy6pe4P.jpg'),
(148134, 10555, 'Love Mate [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pLWsiLrsLQOKNrDtLrJN0yL3a8k.jpg'),
(148135, 10555, 'Love Mate [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qp21wQkJbi5A16sLSBk1cD3WMLB.jpg'),
(148136, 10555, 'Love Mate [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rq8rRYYaXcQ22kdmQbMzlbQLIjG.jpg'),
(148137, 10556, 'Meninos Antes de Flores [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wUz4tciAW8EjtYOg92X7fg1Ovr5.jpg'),
(148138, 10556, 'Meninos Antes de Flores [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ajIQGPkld0GS1pBymKQl3redCBY.jpg'),
(148139, 10556, 'Meninos Antes de Flores [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cyUYfcX2sA21kyRoYQrwFmyvuwh.jpg'),
(148140, 10556, 'Meninos Antes de Flores [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vrfLK0Oj5Wj4xAQm7MAjkge08Af.jpg'),
(148141, 10556, 'Meninos Antes de Flores [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qGw5s5mnH8pvJS0fmVzn9zrwKUg.jpg'),
(148142, 10556, 'Meninos Antes de Flores [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hGM93BoaS0riFWlbbZAB0MNgdKf.jpg'),
(148143, 10556, 'Meninos Antes de Flores [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3ivFqS5hRFT4j6FicHR90WatmaC.jpg'),
(148144, 10556, 'Meninos Antes de Flores [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dhFX7ln1aeAg6NkVjSMRio9key3.jpg'),
(148145, 10556, 'Meninos Antes de Flores [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9tnIWZjI9wH3R7jNylltXXLRPhn.jpg'),
(148146, 10556, 'Meninos Antes de Flores [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tQJCFBtBVrIapE5aN18EcbzZTAW.jpg'),
(148147, 10556, 'Meninos Antes de Flores [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1jn6TjhYKE0Us4zwMjs9tIyo8MJ.jpg'),
(148148, 10556, 'Meninos Antes de Flores [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jor4YcScWc499MmJwkvj4peCGpT.jpg'),
(148149, 10556, 'Meninos Antes de Flores [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/353699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jKGKa91lcBjyi0CqePp77qiJbjv.jpg'),
(148150, 10556, 'Meninos Antes de Flores [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/353700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cBythEslrKFWjaXIEy8aiGh1ntf.jpg'),
(148151, 10556, 'Meninos Antes de Flores [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/353701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qhUyndaX6HOVXfEqAeYHS3Lb6uX.jpg'),
(148152, 10556, 'Meninos Antes de Flores [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/353702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fieB0JOz246GGW3yC9vc4C3zBz1.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(148153, 10556, 'Meninos Antes de Flores [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/353703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6K7KtPVW0m2E51TJuenPTYPfE21.jpg'),
(148154, 10556, 'Meninos Antes de Flores [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/353704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A8bCcy1IDGPZQ4Bmm9IAJxYjSLr.jpg'),
(148155, 10556, 'Meninos Antes de Flores [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/353705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9tohKAMuvJmYIwAjBN4mk4F7EE2.jpg'),
(148156, 10556, 'Meninos Antes de Flores [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/353706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEgXFZu1jvHTiOilb44jnIilQq.jpg'),
(148157, 10556, 'Meninos Antes de Flores [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/353707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Pq7utpqrVHIuiZb9nspqYjmXN2.jpg'),
(148158, 10556, 'Meninos Antes de Flores [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/353708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mWWiJ4aoqRs0f34RXiNjhaKpfQu.jpg'),
(148159, 10556, 'Meninos Antes de Flores [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/604668.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cO9Sgo4WGSAqGmfWKE4O8z68apT.jpg'),
(148160, 10556, 'Meninos Antes de Flores [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/353710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gTMTD9Y18byKARVW6iStGYeJ7bw.jpg'),
(148161, 10556, 'Meninos Antes de Flores [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/353711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zq5lnUAs0Q7ueE15hJyTGPh11DU.jpg'),
(148162, 10557, 'Meow Orelhas para Cima [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qxJvrNotvUJOkPqBpoyRVgTPsWh.jpg'),
(148163, 10557, 'Meow Orelhas para Cima [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cK6yOnj2tTYkn8GUnuXToE5BEbi.jpg'),
(148164, 10557, 'Meow Orelhas para Cima [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vBmSWYYOxpYt3mGiXBxrS3bkPeh.jpg'),
(148165, 10557, 'Meow Orelhas para Cima [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vBmSWYYOxpYt3mGiXBxrS3bkPeh.jpg'),
(148166, 10557, 'Meow Orelhas para Cima [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vBmSWYYOxpYt3mGiXBxrS3bkPeh.jpg'),
(148167, 10557, 'Meow Orelhas para Cima [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vBmSWYYOxpYt3mGiXBxrS3bkPeh.jpg'),
(148168, 10557, 'Meow Orelhas para Cima [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vBmSWYYOxpYt3mGiXBxrS3bkPeh.jpg'),
(148169, 10557, 'Meow Orelhas para Cima [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vBmSWYYOxpYt3mGiXBxrS3bkPeh.jpg'),
(148170, 10558, 'Nao Diga Nao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pbG8EIwbviLvXtY5y8FG2RvbkUB.jpg'),
(148171, 10558, 'Nao Diga Nao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/68YIMzNdwovhVzoKydfxUR3tlZu.jpg'),
(148172, 10558, 'Nao Diga Nao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sC0Ibdb0lKf6EHJ5hVyAS3HJMSx.jpg'),
(148173, 10558, 'Nao Diga Nao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/15vlR7YpM1blgZRO4DdWflhwiQ1.jpg'),
(148174, 10558, 'Nao Diga Nao [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yOR8zzli9sKECmjK04wLZtkxOC0.jpg'),
(148175, 10558, 'Nao Diga Nao [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aSRf1HM0WHy4oibsfKJs4Ttc76y.jpg'),
(148176, 10558, 'Nao Diga Nao [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fg05G82nxrKwzNu1l9aoIwDRRaQ.jpg'),
(148177, 10558, 'Nao Diga Nao [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s2WsplDnZJ8ru3J0QLHNtk6I6wF.jpg'),
(148178, 10558, 'Nao Diga Nao [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/feRR70jdZvJlUBboYD3nXlbdECZ.jpg'),
(148179, 10558, 'Nao Diga Nao [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uJZDKXZE6pdfbIN0SZEtENPd0Ic.jpg'),
(148180, 10558, 'Nao Diga Nao [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t9D8ycyV3a225ILWN3uXcUBGZdk.jpg'),
(148181, 10558, 'Nao Diga Nao [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o8zybKKwPM8eSezUCLFFzxDm5Y4.jpg'),
(148182, 10559, 'Nao Me Abandone Jamais [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iW5PSBtXBqbEofbAy44yLg6MgBD.jpg'),
(148183, 10559, 'Nao Me Abandone Jamais [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bjvI8v1c4x8YYVOqk6zreNt7AgL.jpg'),
(148184, 10559, 'Nao Me Abandone Jamais [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/geaO7mDg1KvEPuqiRDybc7KS4pV.jpg'),
(148185, 10559, 'Nao Me Abandone Jamais [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gDD1JnKVUUKynfIKFtbTXJpBeiE.jpg'),
(148186, 10559, 'Nao Me Abandone Jamais [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A1nNlxItSgpXFRmy83uze4uMy7L.jpg'),
(148187, 10559, 'Nao Me Abandone Jamais [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1aDNK9u5vLgVhDmxiAdoD7daGRH.jpg'),
(148188, 10559, 'Nao Me Abandone Jamais [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gHVaA1K67bgBviuJIhRnvKLmbHW.jpg'),
(148189, 10559, 'Nao Me Abandone Jamais [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dky3l6xGkzMOxvjm1ZZRPSd3fRT.jpg'),
(148190, 10559, 'Nao Me Abandone Jamais [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mOplkdDIn8BtqL1WoyqrgS1n0um.jpg'),
(148191, 10559, 'Nao Me Abandone Jamais [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7B8KlJGKYmdjFvzkVC8Vz7KvUUz.jpg'),
(148192, 10559, 'Nao Me Abandone Jamais [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yxfTe7qgmLl4H9yD32FtnCGmMzm.jpg'),
(148193, 10559, 'Nao Me Abandone Jamais [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPLF0YesbRI3GlmyZxau2rMsp7Z.jpg'),
(148194, 10560, 'O Presidente da Minha Escola [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6lcuuJ03W33yxJjdo7fMIJmYLKM.jpg'),
(148195, 10560, 'O Presidente da Minha Escola [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z0n2C7TRiqzgLu7NDXrFqx2MFqw.jpg'),
(148196, 10560, 'O Presidente da Minha Escola [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AjQKu346qThYdnnvMkJPSoi3HNK.jpg'),
(148197, 10560, 'O Presidente da Minha Escola [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dVHvUUosAWKnPXEwyByETVvFBtE.jpg'),
(148198, 10560, 'O Presidente da Minha Escola [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXiJXNt47jqH8NW3nWvFNJdHEv3.jpg'),
(148199, 10560, 'O Presidente da Minha Escola [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tf54obRIqmOKLESHOjo0ZFYwfuD.jpg'),
(148200, 10560, 'O Presidente da Minha Escola [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8tHCia1DIhtuqnvi0srXYep5Kbg.jpg'),
(148201, 10560, 'O Presidente da Minha Escola [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c1Il7KXuiZXcnJlXKjsTopdIg7N.jpg'),
(148202, 10560, 'O Presidente da Minha Escola [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y0ra6I8bFlnNjuV09r9y5XwJg9a.jpg'),
(148203, 10560, 'O Presidente da Minha Escola [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7TgJjo3OXEgCSKd1cD3kodQljz4.jpg'),
(148204, 10560, 'O Presidente da Minha Escola [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zFm57mhN4f0f7LDFixlPqhmMMdP.jpg'),
(148205, 10560, 'O Presidente da Minha Escola [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u9AIyJ70SDIdt1bgssKhfUpUSTH.jpg'),
(148206, 10561, 'O Tatuador de Auschwitz [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/egYgRLLGTf3zRxB72HAofnfh2EC.jpg'),
(148207, 10561, 'O Tatuador de Auschwitz [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCgRoiz3iKOlEsFgI4vSVndO4et.jpg'),
(148208, 10561, 'O Tatuador de Auschwitz [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AmUKxjr18Q4q8IIm7YMVKlfBffh.jpg'),
(148209, 10561, 'O Tatuador de Auschwitz [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uqXXXv50pnYTWebCP29Ea2YK0ri.jpg'),
(148210, 10561, 'O Tatuador de Auschwitz [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/379744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nAdgX2CmkrNaRTJelFlBkpRQO0b.jpg'),
(148211, 10561, 'O Tatuador de Auschwitz [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/379745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nAdgX2CmkrNaRTJelFlBkpRQO0b.jpg'),
(148212, 10562, 'O Veu [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yLwiPylJQ0WkgcOn2702JcadC2v.jpg'),
(148213, 10562, 'O Veu [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ph7Wt6gjKDQQQDPiEWJnYqlaoJa.jpg'),
(148214, 10562, 'O Veu [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/me0pUGfzBBQGlbvimnUeciwhZ3R.jpg'),
(148215, 10562, 'O Veu [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oyqyovVfsVp03jZncp3RLREK7up.jpg'),
(148216, 10562, 'O Veu [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wd6CDmAJqQ4doQgDCtGabtuVqI1.jpg'),
(148217, 10563, 'Oxygen The Series [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oOJHOxX4drNzPNdAMgJ2sh1nc3t.jpg'),
(148218, 10563, 'Oxygen The Series [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/brDajTEUCPPGs3e2Umcjiw8qC5B.jpg'),
(148219, 10563, 'Oxygen The Series [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udcneBL9i5d6juD4IG6W5OSZQHt.jpg'),
(148220, 10563, 'Oxygen The Series [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hKpgVNlhn3aSFlRfrsTfdRxG43j.jpg'),
(148221, 10563, 'Oxygen The Series [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vS34rMiNrYfihnRRrywgD03pd9Y.jpg'),
(148222, 10563, 'Oxygen The Series [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zKOTJmtVWWQmVhywnVuOXadhDAt.jpg'),
(148223, 10563, 'Oxygen The Series [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8nFCGHQJ4Xbf2xvz3YKBNTQvgv3.jpg'),
(148224, 10563, 'Oxygen The Series [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3DOtXHgsC5bFnI6dBIc3t9aPFKV.jpg'),
(148225, 10563, 'Oxygen The Series [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yetL3m4UziSmE3ONQWabWs8GxEn.jpg'),
(148226, 10563, 'Oxygen The Series [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vPyh84RnuSe2W7eXq53Pn5KTwoD.jpg'),
(148227, 10563, 'Oxygen The Series [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sKXBiVBH2jfRHnHfhQbSEWXAYQI.jpg'),
(148228, 10563, 'Oxygen The Series [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/up4zYBdmmhbVabuYgaaSGCsxhPx.jpg'),
(148229, 10563, 'Oxygen The Series [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/353625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gBFQO8EKqEHpdThL3ea3lALJHfO.jpg'),
(148230, 10564, 'Paixao Secreta por Voce [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fsv38GnNPfxEeifXYdNDDJ5kHkK.jpg'),
(148231, 10564, 'Paixao Secreta por Voce [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lhGCkTRDkTKP59kbDVNalDgdkmB.jpg'),
(148232, 10564, 'Paixao Secreta por Voce [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jJ1N3MOWsZ1AzowCuFa4xXhUHea.jpg'),
(148233, 10564, 'Paixao Secreta por Voce [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zGEFLmn7bHIsPSFFlSnqQ5nNJ3V.jpg'),
(148234, 10564, 'Paixao Secreta por Voce [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4H0G354S4Gx1mIS6uXIrUPQpGSY.jpg'),
(148235, 10564, 'Paixao Secreta por Voce [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bT4RW1R6cm6YJy9hnlrYkbGjflO.jpg'),
(148236, 10564, 'Paixao Secreta por Voce [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m1kWqznqDbivQuJSIMnK8HZ4kB7.jpg'),
(148237, 10564, 'Paixao Secreta por Voce [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g6H8buQ54LKRs8FHN8aVz94N0R5.jpg'),
(148238, 10564, 'Paixao Secreta por Voce [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hoep5cXYcGKMCYyBbtzeS9esv66.jpg'),
(148239, 10564, 'Paixao Secreta por Voce [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iTvw3fiGQ5PU16IL0AJKQq0DSgr.jpg'),
(148240, 10564, 'Paixao Secreta por Voce [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iPQFfV4i9UNhdiKJeRCENQsAR9h.jpg'),
(148241, 10564, 'Paixao Secreta por Voce [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSK1Kl4QZYVGeFQCNcHIrvX5B4u.jpg'),
(148242, 10564, 'Paixao Secreta por Voce [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/353611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8A62zKWOLpJDRfTuGL3u75e6lop.jpg'),
(148243, 10564, 'Paixao Secreta por Voce [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/353612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hTO5EYoPke5eDIGhFBvRXRHLtqf.jpg'),
(148244, 10565, 'Second Chance [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2hB6NJSguPqLqkwAZd4rDkVottr.jpg'),
(148245, 10565, 'Second Chance [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lTckq4sdW02wSTzTgYgiVzmX47v.jpg'),
(148246, 10565, 'Second Chance [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oJwdhaF11UUcl8pGyTEuSPoK14M.jpg'),
(148247, 10565, 'Second Chance [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uavbAz4xHG4PtnUuaIJ8FwcjsWd.jpg'),
(148248, 10565, 'Second Chance [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6tFSYds8W3Y5fMlagqegMbOlRY.jpg'),
(148249, 10565, 'Second Chance [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fFuVn601b8YueV5hmHcogaNMXdi.jpg'),
(148250, 10566, 'Seja Meu Superastro [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xL6NMmQKaNO0snnXh3lsb8SPYwV.jpg'),
(148251, 10566, 'Seja Meu Superastro [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2VUE6j5o2uUIZ45qdh53pDnLubG.jpg'),
(148252, 10566, 'Seja Meu Superastro [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eYKykpXisoxXIjap72pR3Cwrc5M.jpg'),
(148253, 10566, 'Seja Meu Superastro [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6fj4gBuKrbJY4l5FHOukyUPbM6.jpg'),
(148254, 10566, 'Seja Meu Superastro [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p5kXuKYxwUTSalZrM09KfDGUXEf.jpg'),
(148255, 10566, 'Seja Meu Superastro [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iICPfQQSdHRKWjcSss0kaAK27UY.jpg'),
(148256, 10566, 'Seja Meu Superastro [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AaiMauV9el0aZyh7IUt5TAm9BCO.jpg'),
(148257, 10566, 'Seja Meu Superastro [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJ0TBZxR2ER9ob1XKnqKO3bwkhQ.jpg'),
(148258, 10566, 'Seja Meu Superastro [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cRJfCicdK0ZeGOSXnUl7m9XetxE.jpg'),
(148259, 10566, 'Seja Meu Superastro [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vub4BVljzh0GqeYAUB4SjiumSv6.jpg'),
(148260, 10566, 'Seja Meu Superastro [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/drpYtrccFul3DvGKIpaBNxsKH2a.jpg'),
(148261, 10566, 'Seja Meu Superastro [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uOxWhbpR4CrbFnlvmESWDZys5wr.jpg'),
(148262, 10567, 'Shardlake [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sqqUDZYBBnRzM8o3GsA6axFHnEC.jpg'),
(148263, 10567, 'Shardlake [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sanGmzqYeL5tL3rpoqFWmbctZzn.jpg'),
(148264, 10567, 'Shardlake [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhq3aRiM50iNuR9r8ngGvzQsPQ4.jpg'),
(148265, 10567, 'Shardlake [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iYlnj7cTk7oyCvREgcSaaPsNoyz.jpg'),
(148266, 10568, 'Sindrome do Amor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gqx7Vg59rRGNtwsLh6TjFr2CJvq.jpg'),
(148267, 10568, 'Sindrome do Amor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3OCQbCfBw2L60J486U9DND1oVSG.jpg'),
(148268, 10568, 'Sindrome do Amor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mz02digOeiendDiCdsY4DTE0d51.jpg'),
(148269, 10568, 'Sindrome do Amor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uKftLkvt5Z4V3FfD52mOuhaoR08.jpg'),
(148270, 10568, 'Sindrome do Amor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1rHoY6ggA8VU0u9uOv7VOu8ONBE.jpg'),
(148271, 10568, 'Sindrome do Amor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6EOcA1ZIUy3eE7iExohfxtEQz8O.jpg'),
(148272, 10568, 'Sindrome do Amor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/euDp0HGs4sLnCJWes6bNYwdXmiY.jpg'),
(148273, 10568, 'Sindrome do Amor [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xd35vJzXFfAG1ekj2kAl6tT6c5S.jpg'),
(148274, 10568, 'Sindrome do Amor [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cBbGNpVnt9nKofwI5KoUR30bMrO.jpg'),
(148275, 10568, 'Sindrome do Amor [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zV6lhs1qdnfadZ3Yd7sfY6QPMgp.jpg'),
(148276, 10568, 'Sindrome do Amor [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a1VPQIhCaAK05HQulFFlP57YNRj.jpg'),
(148277, 10568, 'Sindrome do Amor [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xYXAilrI9ksr25DFZhwniaXNYsB.jpg'),
(148278, 10569, 'Sound Euphonium [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/apkpc5aB584fgaR45Xk2m3eWzgw.jpg'),
(148279, 10569, 'Sound Euphonium [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4AVLf7TnwUR6syJ9u4O0XHaHYOg.jpg'),
(148280, 10569, 'Sound Euphonium [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lZQTNFKNZ71UQfOvSMmRZnvbora.jpg'),
(148281, 10569, 'Sound Euphonium [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r9CjMa4v7esjmRwPix61n79RXLD.jpg'),
(148282, 10569, 'Sound Euphonium [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6avm7qJP4B9gi5K5mQPWTjnu7uT.jpg'),
(148283, 10569, 'Sound Euphonium [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oXBO1P1n4jxEDZO6XAeQRuN75Jq.jpg'),
(148284, 10569, 'Sound Euphonium [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4X2Z6985UFh37aWYk0zPT2wjPfB.jpg'),
(148285, 10569, 'Sound Euphonium [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/znFqfP1u1cBKit3M55wj3IvMxRl.jpg'),
(148286, 10569, 'Sound Euphonium [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pnzvbDhw0PYw8lbyKtoA2603ra.jpg'),
(148287, 10569, 'Sound Euphonium [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zZyJgGif4ukrfWvaFuyNINAe4A2.jpg'),
(148288, 10569, 'Sound Euphonium [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyC63OD5BDzjVE0W25ac3OQOsIe.jpg'),
(148289, 10569, 'Sound Euphonium [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8E85SU02HnkwiV1ocHSuhkGhlKC.jpg'),
(148290, 10569, 'Sound Euphonium [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/353545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ZMAWfoukXaOsAVuuTNSU3OrLqL.jpg'),
(148291, 10569, 'Sound Euphonium [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/353546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5PwD9F9ot5z3CUvb95qXtk3PGsf.jpg'),
(148292, 10570, 'Sound Euphonium [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5VdbsYR5mIvEnDQ7IJMWDYxP5di.jpg'),
(148293, 10570, 'Sound Euphonium [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wwYDQaTsEC8M7TWcBxG72dD3ylm.jpg'),
(148294, 10570, 'Sound Euphonium [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/17zrsHiUF9b6DPpB6m1UpvDA9qD.jpg'),
(148295, 10570, 'Sound Euphonium [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nIcH8z7B4bGBDd5Fq9ynZKl2Rfm.jpg'),
(148296, 10570, 'Sound Euphonium [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ojcBYtHM5L4A3Lw7Jr1Mq62X1if.jpg'),
(148297, 10570, 'Sound Euphonium [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2SMNWFxP6NXOpqv6IQs2ll6aqZk.jpg'),
(148298, 10570, 'Sound Euphonium [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wpd67e3O5qu8dIWZg51SZUPfQmk.jpg'),
(148299, 10570, 'Sound Euphonium [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/axvEFI2CmaFelD6y8BftDhO91W3.jpg'),
(148300, 10570, 'Sound Euphonium [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/17aWv7hdA3Fb2iE22io7bWWoVvZ.jpg'),
(148301, 10570, 'Sound Euphonium [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cyHFTcSMDCu1MtCa6Ak9ej8KzMK.jpg'),
(148302, 10570, 'Sound Euphonium [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sb4fVPsnAkDRq55s2TsENgMAKPl.jpg'),
(148303, 10570, 'Sound Euphonium [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pzBOkTPvsuD1YPx24X7dyAsXmNT.jpg'),
(148304, 10570, 'Sound Euphonium [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/353559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8IUY7eziXyQojyLEPKJV7fPZWtl.jpg'),
(148305, 10571, 'Sound Euphonium [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/615398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5PwD9F9ot5z3CUvb95qXtk3PGsf.jpg'),
(148306, 10571, 'Sound Euphonium [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rSVhf50Y4en7DEWm1Tu26MNNjBb.jpg'),
(148307, 10571, 'Sound Euphonium [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iPytTguViqvxYmcWns853om5taU.jpg'),
(148308, 10571, 'Sound Euphonium [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ll6O7olWmPZzYlcwKEIsGvl9rSK.jpg'),
(148309, 10571, 'Sound Euphonium [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ytU0zZNRExususNcynvSVdINZU.jpg'),
(148310, 10571, 'Sound Euphonium [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2moR7WQRBc4eN7QNfLfTLtuQ3lX.jpg'),
(148311, 10571, 'Sound Euphonium [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/373016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5PwD9F9ot5z3CUvb95qXtk3PGsf.jpg'),
(148312, 10571, 'Sound Euphonium [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/373017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5PwD9F9ot5z3CUvb95qXtk3PGsf.jpg'),
(148313, 10571, 'Sound Euphonium [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/373018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5PwD9F9ot5z3CUvb95qXtk3PGsf.jpg'),
(148314, 10571, 'Sound Euphonium [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/376277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5PwD9F9ot5z3CUvb95qXtk3PGsf.jpg'),
(148315, 10571, 'Sound Euphonium [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/615408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5PwD9F9ot5z3CUvb95qXtk3PGsf.jpg'),
(148316, 10571, 'Sound Euphonium [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5PwD9F9ot5z3CUvb95qXtk3PGsf.jpg'),
(148317, 10571, 'Sound Euphonium [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/418177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5PwD9F9ot5z3CUvb95qXtk3PGsf.jpg'),
(148318, 10572, 'Star and Sky Star in My Mind [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xcLeNn2ybG8wnQBLfYtMDNiEPtg.jpg'),
(148319, 10572, 'Star and Sky Star in My Mind [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fWQV5hhe9ozdFVFiBUrQyLfEPFJ.jpg'),
(148320, 10572, 'Star and Sky Star in My Mind [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6h3WKNKG6Tn6Sk9FNF1Nkj696l4.jpg'),
(148321, 10572, 'Star and Sky Star in My Mind [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/heqo8uX5qhhod2Bstp4ta8aPn0a.jpg'),
(148322, 10572, 'Star and Sky Star in My Mind [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cxsIqFXy5dXi1YejNqwKUShLmFx.jpg'),
(148323, 10572, 'Star and Sky Star in My Mind [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gPb10v37RFPcpKC2AD5vXb06Q1G.jpg'),
(148324, 10572, 'Star and Sky Star in My Mind [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aajR8xVD7x7J2N6h70tU147jTJq.jpg'),
(148325, 10572, 'Star and Sky Star in My Mind [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mEbBLWPK4VtiQar4vXYMWOweljb.jpg'),
(148326, 10573, 'Teoria do Amor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7YNeG2dK4qNsqYAQ8yhkVN2JHej.jpg'),
(148327, 10573, 'Teoria do Amor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7YNeG2dK4qNsqYAQ8yhkVN2JHej.jpg'),
(148328, 10573, 'Teoria do Amor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7YNeG2dK4qNsqYAQ8yhkVN2JHej.jpg'),
(148329, 10573, 'Teoria do Amor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7YNeG2dK4qNsqYAQ8yhkVN2JHej.jpg'),
(148330, 10573, 'Teoria do Amor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7YNeG2dK4qNsqYAQ8yhkVN2JHej.jpg'),
(148331, 10573, 'Teoria do Amor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7YNeG2dK4qNsqYAQ8yhkVN2JHej.jpg'),
(148332, 10573, 'Teoria do Amor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7YNeG2dK4qNsqYAQ8yhkVN2JHej.jpg'),
(148333, 10573, 'Teoria do Amor [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7YNeG2dK4qNsqYAQ8yhkVN2JHej.jpg'),
(148334, 10573, 'Teoria do Amor [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7YNeG2dK4qNsqYAQ8yhkVN2JHej.jpg'),
(148335, 10573, 'Teoria do Amor [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7YNeG2dK4qNsqYAQ8yhkVN2JHej.jpg'),
(148336, 10573, 'Teoria do Amor [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vVlKQ9EErlOzMFy4L5rA94g8WAx.jpg'),
(148337, 10573, 'Teoria do Amor [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n2LdvVZ3gHBeJSSPxykQIDwpwEQ.jpg'),
(148338, 10574, 'TharnType The Series [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5QJZVEJjCCAYZvOlfA0sM3wKMSM.jpg'),
(148339, 10574, 'TharnType The Series [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cM6Ozjo8jC1AcB5MX5KgPN16Wve.jpg'),
(148340, 10574, 'TharnType The Series [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mKI1VLSTsefxjloObajXFTxFTNO.jpg'),
(148341, 10574, 'TharnType The Series [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pEX4zIIFDpoUbrxKwHKUjdtp9O9.jpg'),
(148342, 10574, 'TharnType The Series [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ggD55oKfVXJZu2MDZ5GSc6SCJg.jpg'),
(148343, 10574, 'TharnType The Series [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMQbQbNHLN8BNBQK232boZwQEjG.jpg'),
(148344, 10574, 'TharnType The Series [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q2FyzanRP0cFS48rREXnJn5JM2x.jpg'),
(148345, 10574, 'TharnType The Series [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/91idG3nW1LjL9nwWnqsaP1OJkNm.jpg'),
(148346, 10574, 'TharnType The Series [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4zfrDdHuohVDBRpOQb6QypqusvZ.jpg'),
(148347, 10574, 'TharnType The Series [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d0YHLqd1RouKLsl51LuAS0Ny6dv.jpg'),
(148348, 10574, 'TharnType The Series [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHt6pufVRpU5entJrLXagNBUtV1.jpg'),
(148349, 10574, 'TharnType The Series [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4VtHuIhhg5pACORw3GskNE9cMbc.jpg'),
(148350, 10574, 'TharnType The Series [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/353512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aE8XUqAzurIbKAq3V6hr2WkSYA9.jpg'),
(148351, 10575, 'The Yearbook [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vgV2urPcdbPTvHAp235AkhCUuAE.jpg'),
(148352, 10575, 'The Yearbook [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9c7dZFlJyVWgTJzk0FmviIl6iQJ.jpg'),
(148353, 10575, 'The Yearbook [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vRrzEfxJoVPqmCwRQMDtGXgBTEK.jpg'),
(148354, 10575, 'The Yearbook [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mzlzSdRYXheV5s97tgaq5iBI14f.jpg'),
(148355, 10575, 'The Yearbook [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k1G7RiDhfD01NQHN2KJQb8qtuZp.jpg'),
(148356, 10575, 'The Yearbook [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yzohvJhs8x95G5eSjhYCnaEvhbM.jpg'),
(148357, 10575, 'The Yearbook [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aSgyuPKYDLr0A3F8v0feHHxhMEb.jpg'),
(148358, 10575, 'The Yearbook [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6yKa1vQhP2uG1qtsv7XdPl7zjOA.jpg'),
(148359, 10576, 'Toradora [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a4OyowWYW8qOdmghJXqhWcBdA4F.jpg'),
(148360, 10576, 'Toradora [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7WrkYPhOubW64tl0qw3SIisODck.jpg'),
(148361, 10576, 'Toradora [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bwbMZc0UlTEuDUaKnadOg5HMOSY.jpg'),
(148362, 10576, 'Toradora [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6DxcBB7Up4MhX3JtxneDHZYZKJk.jpg'),
(148363, 10576, 'Toradora [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/km8gFOgBgCy79NKcpagpWlHUlxk.jpg'),
(148364, 10576, 'Toradora [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c3oSMlxVhKelYS07GeF753xjsRJ.jpg'),
(148365, 10576, 'Toradora [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z6M3neMhrtNvh2v6F2ARr0WKcnH.jpg'),
(148366, 10576, 'Toradora [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/353474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rTPcqwMXMpa8qDWb8xh3Oi6YfPO.jpg'),
(148367, 10576, 'Toradora [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/353475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pP9XXhzBPukjzBWY9hgkJvV9eHl.jpg'),
(148368, 10576, 'Toradora [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/353476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wNuezk8WWJTtQfl0h8YouOYBdiy.jpg'),
(148369, 10576, 'Toradora [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/353477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eTF8ndjaB2p0nsjoNlhExwDGvlr.jpg'),
(148370, 10576, 'Toradora [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/353478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p5IMRy5ujdmB9eqGitU8DEcmt4b.jpg'),
(148371, 10576, 'Toradora [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/353479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3CERj76soQ2x2gCvVlVRQWw0S3.jpg'),
(148372, 10576, 'Toradora [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/353480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oVCBcDLAjflzA3fO3VEFTUjqOYG.jpg'),
(148373, 10576, 'Toradora [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/353481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tGEgIxxnhixZ70gGEvYt9LgkCl0.jpg'),
(148374, 10576, 'Toradora [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/353482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iQMZAjx4yb3qUh5CGnW3hQFJIgr.jpg'),
(148375, 10576, 'Toradora [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/353483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iNZIEq4nVWg72f7MUbjV0B19tGs.jpg'),
(148376, 10576, 'Toradora [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/353484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aiuQyjshml2YE3yY5fd4bYA6QyC.jpg'),
(148377, 10576, 'Toradora [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/353485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/enR1sqlQdK8MbbbtRD8exoWAlBX.jpg'),
(148378, 10576, 'Toradora [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/353486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ZbUNRyHyIrLmdO1DwugHO07iHr.jpg'),
(148379, 10576, 'Toradora [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/353487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nZn8htdbOMr4WQIktQ0npzCJpap.jpg'),
(148380, 10576, 'Toradora [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/353488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7QsBPf0IIGp0ECrpKAcLYOM8pw8.jpg'),
(148381, 10576, 'Toradora [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/353489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8FJ0evwhZB0QA2tJCP0tepiD1LR.jpg'),
(148382, 10576, 'Toradora [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/353490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pi1WI4nWs11CYOBjnsrTbwm9DGL.jpg'),
(148383, 10576, 'Toradora [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/353491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2dQMy6gJ8qcAouRm1UwbSu20ub8.jpg'),
(148384, 10577, 'Um Ombro Para Chorar [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/353460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eXB93PXlroqHUBoGSyVEZ8m5Zqe.jpg'),
(148385, 10577, 'Um Ombro Para Chorar [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/353461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gw0wPyITMqzp0f43v4uIu4i9DHD.jpg'),
(148386, 10577, 'Um Ombro Para Chorar [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/353462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3DuYBduSnIdMwkDPsFewGDGF9Q0.jpg'),
(148387, 10577, 'Um Ombro Para Chorar [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/353463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u221MKoQmJrPKWOvDG8c97XAKA3.jpg'),
(148388, 10577, 'Um Ombro Para Chorar [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/353464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nf21WGYOrQmn1LwRRYOB9uzdSlx.jpg'),
(148389, 10577, 'Um Ombro Para Chorar [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/353465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nvIPyp38WbVu9ssGA67WiLSzGnZ.jpg'),
(148390, 10577, 'Um Ombro Para Chorar [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/353466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u6ttjCtbJgdvaUrKp4aiBCkBczs.jpg'),
(148391, 10578, 'A Condition Called Love S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/358177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2v9s5BdL4lJW60wRrtHypPqz36M.jpg'),
(148392, 10578, 'A Condition Called Love S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/358178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uyvLVACop7ISHBzJGcwgWkZkrrX.jpg'),
(148393, 10578, 'A Condition Called Love S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/358179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8sIHsIw3JQyxQhSCF4wcdWEXuEF.jpg'),
(148394, 10578, 'A Condition Called Love S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/358180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/75Ju4zCmqc8FoabgRBrPDMmkeh3.jpg'),
(148395, 10579, 'Aoashi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/358153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7bwfG5T96ViLo88xU8MVtcr9jCT.jpg'),
(148396, 10579, 'Aoashi S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/358154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3HsHK1DX6lMs2ZzcIIn9C75xEi0.jpg'),
(148397, 10579, 'Aoashi S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/358155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jr8HtxCNsl32xkcsvJFgM0HNUvC.jpg'),
(148398, 10579, 'Aoashi S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/358156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v9jsZgTJuIdtRCp5f8ZhLCHNtU2.jpg'),
(148399, 10579, 'Aoashi S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/358157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzE2Hnr7EwnGcwNoTRtqLFNnqm6.jpg'),
(148400, 10579, 'Aoashi S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/358158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nTMslfZKvTvLPToFcoGmGiLQ69V.jpg'),
(148401, 10579, 'Aoashi S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/358159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOzs2d1jEjPChezQYi9BCKPlNbN.jpg'),
(148402, 10579, 'Aoashi S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/358160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bUThe8lGTQ82yAJR1akfD6wVycN.jpg'),
(148403, 10579, 'Aoashi S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/358161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5pa0okjjfCLHbi7Bd91Gyu4Gdan.jpg'),
(148404, 10579, 'Aoashi S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/358162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mYPkJ78I6APMABsionXmTnVqVi5.jpg'),
(148405, 10579, 'Aoashi S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/358163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/swp1PJSIW8q9Sde5UDHqsEXHZfs.jpg'),
(148406, 10579, 'Aoashi S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/358164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jN5bHSSteiDbzduRNibov86tGGk.jpg'),
(148407, 10579, 'Aoashi S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/358165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pIDBH2mfh2aQ3URgQb3rqhekjw8.jpg'),
(148408, 10579, 'Aoashi S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/358166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ivso6mZUZB60BK88UqZKTD7Psud.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(148409, 10579, 'Aoashi S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/358167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/53KfJ4iAHYrHnIdGHDD5loPzRGH.jpg'),
(148410, 10579, 'Aoashi S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/358168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r0EUidjCxU1kCUpTUNyzzu7UKnW.jpg'),
(148411, 10579, 'Aoashi S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/358169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2RykHwAsgFjhga2kbfovjIQozZi.jpg'),
(148412, 10579, 'Aoashi S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/358170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wlbtRffKmwOomY1uSqbXFKV6t3G.jpg'),
(148413, 10579, 'Aoashi S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/358171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/niLn7ZylVBzC6YkZ8ip7VQWI9SS.jpg'),
(148414, 10579, 'Aoashi S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/358172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yIOjQz7S3JFuTYMVDknLeFSy75d.jpg'),
(148415, 10579, 'Aoashi S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/358173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vuhsKYLGRcwVUzfgV8MXOC4FL2y.jpg'),
(148416, 10579, 'Aoashi S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/358174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wAyVco6WmNNwNUEuQokSb7mY6Zj.jpg'),
(148417, 10579, 'Aoashi S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/358175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tE7BoUxFcZbMWWCWKevejiUIRGK.jpg'),
(148418, 10579, 'Aoashi S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/358176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/XhtcC4wJH1Xuit6SDNENUZWJ5z.jpg'),
(148419, 10580, 'Casos Arquivados Os Assassinatos de Rifkin S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/358151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8kq3BJNLkesFkPeHs9Sy0Ko36yn.jpg'),
(148420, 10580, 'Casos Arquivados Os Assassinatos de Rifkin S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/358152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/16rpAfTJ16XIa36vNOKsho8KXyu.jpg'),
(148421, 10581, 'Instinct S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/358138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lDDvMvIB4NYzgWN7BbKKsFYcH4E.jpg'),
(148422, 10581, 'Instinct S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/358139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nCn3ZRF0gaRRP1Kh1dHugRSkiD.jpg'),
(148423, 10581, 'Instinct S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/358140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7a4Vx9b84AFgYo0FhtluY3n9a0P.jpg'),
(148424, 10581, 'Instinct S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/358141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eRuGF684qFZpFk4FzxHYI7SLeeg.jpg'),
(148425, 10581, 'Instinct S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/358142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g2jO39MVdPFCd7wTjPN8Hwl0iaG.jpg'),
(148426, 10581, 'Instinct S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/358143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kn4tZiL2PAGuLtczmT9OlspW4RB.jpg'),
(148427, 10581, 'Instinct S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/358144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t4CIcNHaWOgDMsUVv9y0QX8Hvjz.jpg'),
(148428, 10581, 'Instinct S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/358145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUMjnT4UT88bKjtWPk7HFSs4KuU.jpg'),
(148429, 10581, 'Instinct S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/358146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2Kf1wvgGG7MWX7RXspp4i63668.jpg'),
(148430, 10581, 'Instinct S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/358147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6PcH0rM8Yfe2NqFpob4fmyPUFDn.jpg'),
(148431, 10581, 'Instinct S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/358148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aAL2m7vzDKpekdhiq1DgwgfVLEI.jpg'),
(148432, 10581, 'Instinct S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/358149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5GLhwcBjan7CaprDczq054sLtoX.jpg'),
(148433, 10581, 'Instinct S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/358150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rOzp9SqNr7lUHhp8Ys7ejcYznUi.jpg'),
(148434, 10582, 'Instinct S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/815287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vjaybf9ZEZDDhrdJ8my91XyEVB6.jpg'),
(148435, 10582, 'Instinct S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/815288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/byg99XoHOlTCB7sFSDpdmycSdZQ.jpg'),
(148436, 10582, 'Instinct S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/815289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7syhkOnLfvHzV64vZQMpESPK5Ez.jpg'),
(148437, 10582, 'Instinct S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/815290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6boV7Q1AKlDFwlIO0K3UdatuQQp.jpg'),
(148438, 10582, 'Instinct S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/815291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eE2ytVnO3tXM68dWd8ih74LlNTu.jpg'),
(148439, 10582, 'Instinct S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/815292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dodF0PAVVVah3f6pOuWeBVlNl8u.jpg'),
(148440, 10582, 'Instinct S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/815293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5DtXt1zKGNygebzArrTMIrcLwGg.jpg'),
(148441, 10582, 'Instinct S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/815294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/woyyf3CLZQh0rLhuFiQU9FH0Nv3.jpg'),
(148442, 10582, 'Instinct S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/815295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3a37IqI9fvhzPOMpq6QiOUvkluv.jpg'),
(148443, 10582, 'Instinct S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/815296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gjX2fGpAikdPcW5jrTSXkkHpeJc.jpg'),
(148444, 10582, 'Instinct S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/815297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a7Iniw4HtQtZbmv3sj63R5EcZOj.jpg'),
(148445, 10583, 'Jurassic World Teoria do Caos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/358128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eDqHedIgMyQeQ3B2FLgKRToUILA.jpg'),
(148446, 10583, 'Jurassic World Teoria do Caos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/358129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bZpdySpn4DIZiZNeqquN5uqev74.jpg'),
(148447, 10583, 'Jurassic World Teoria do Caos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/358130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eNs3K92SD95QA3MpPniNI7mskIq.jpg'),
(148448, 10583, 'Jurassic World Teoria do Caos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/358131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ooyglFXTRxzRuM6c7Nb7pQNBBJ8.jpg'),
(148449, 10583, 'Jurassic World Teoria do Caos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/358132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5hWALmh2KLSu6U9j83EkTuoTVTX.jpg'),
(148450, 10583, 'Jurassic World Teoria do Caos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/358133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/46SaXTbn0ij1kClFAlaosDoHXrr.jpg'),
(148451, 10583, 'Jurassic World Teoria do Caos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/358134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2hQMqvrYjahvx72E5dzhsMBgtTe.jpg'),
(148452, 10583, 'Jurassic World Teoria do Caos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/358135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3T05kmYiW4dGwqWDUkGuNWPG1eR.jpg'),
(148453, 10583, 'Jurassic World Teoria do Caos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/358136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h34ANOg0mhEcVRBF7rg3sufajKf.jpg'),
(148454, 10583, 'Jurassic World Teoria do Caos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/358137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97AsqfyhFChgRo3jZFTnaJ9Ksgh.jpg'),
(148455, 10584, 'Jurassic World Teoria do Caos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2Od0cY2IeayDj5osUxZSAD1QK.jpg'),
(148456, 10584, 'Jurassic World Teoria do Caos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2Od0cY2IeayDj5osUxZSAD1QK.jpg'),
(148457, 10584, 'Jurassic World Teoria do Caos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2Od0cY2IeayDj5osUxZSAD1QK.jpg'),
(148458, 10584, 'Jurassic World Teoria do Caos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2Od0cY2IeayDj5osUxZSAD1QK.jpg'),
(148459, 10584, 'Jurassic World Teoria do Caos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2Od0cY2IeayDj5osUxZSAD1QK.jpg'),
(148460, 10584, 'Jurassic World Teoria do Caos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2Od0cY2IeayDj5osUxZSAD1QK.jpg'),
(148461, 10584, 'Jurassic World Teoria do Caos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2Od0cY2IeayDj5osUxZSAD1QK.jpg'),
(148462, 10584, 'Jurassic World Teoria do Caos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2Od0cY2IeayDj5osUxZSAD1QK.jpg'),
(148463, 10584, 'Jurassic World Teoria do Caos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/486861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2Od0cY2IeayDj5osUxZSAD1QK.jpg'),
(148464, 10584, 'Jurassic World Teoria do Caos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/486862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2Od0cY2IeayDj5osUxZSAD1QK.jpg'),
(148465, 10585, 'Kaiju No. 8 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/358122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6sYkwztTsCvHSt4eNaNCofIabaA.jpg'),
(148466, 10585, 'Kaiju No. 8 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/358123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qnw5xoDHL1YBc7uNXaoqgxeXMOk.jpg'),
(148467, 10585, 'Kaiju No. 8 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/358124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4wmoBvVAh9jAVNZOtQxVihNQ5gb.jpg'),
(148468, 10585, 'Kaiju No. 8 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/358125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ocKXnYcu58oMS5065PMhDsTbNfM.jpg'),
(148469, 10585, 'Kaiju No. 8 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/358126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7TMMZ08p1DRskTG3OHomLsZgEN1.jpg'),
(148470, 10585, 'Kaiju No. 8 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/358127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sYo459puDf7hNXdOUAJUSvQ7BEM.jpg'),
(148471, 10585, 'Kaiju No. 8 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/360822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rK1GWa7W9DUu6tuySM2AtLVTpxE.jpg'),
(148472, 10585, 'Kaiju No. 8 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/368334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rK1GWa7W9DUu6tuySM2AtLVTpxE.jpg'),
(148473, 10585, 'Kaiju No. 8 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/377834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rK1GWa7W9DUu6tuySM2AtLVTpxE.jpg'),
(148474, 10585, 'Kaiju No. 8 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/387403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rK1GWa7W9DUu6tuySM2AtLVTpxE.jpg'),
(148475, 10585, 'Kaiju No. 8 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/392678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rK1GWa7W9DUu6tuySM2AtLVTpxE.jpg'),
(148476, 10585, 'Kaiju No. 8 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/396731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rK1GWa7W9DUu6tuySM2AtLVTpxE.jpg'),
(148477, 10586, 'Kaiju No. 8 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/862098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rK1GWa7W9DUu6tuySM2AtLVTpxE.jpg'),
(148478, 10586, 'Kaiju No. 8 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/872320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rK1GWa7W9DUu6tuySM2AtLVTpxE.jpg'),
(148479, 10586, 'Kaiju No. 8 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/878214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rK1GWa7W9DUu6tuySM2AtLVTpxE.jpg'),
(148480, 10586, 'Kaiju No. 8 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/879033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rK1GWa7W9DUu6tuySM2AtLVTpxE.jpg'),
(148481, 10586, 'Kaiju No. 8 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/880057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rK1GWa7W9DUu6tuySM2AtLVTpxE.jpg'),
(148482, 10586, 'Kaiju No. 8 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/880882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rK1GWa7W9DUu6tuySM2AtLVTpxE.jpg'),
(148483, 10586, 'Kaiju No. 8 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/881332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rK1GWa7W9DUu6tuySM2AtLVTpxE.jpg'),
(148484, 10586, 'Kaiju No. 8 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/881333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rK1GWa7W9DUu6tuySM2AtLVTpxE.jpg'),
(148485, 10586, 'Kaiju No. 8 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/883551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rK1GWa7W9DUu6tuySM2AtLVTpxE.jpg'),
(148486, 10586, 'Kaiju No. 8 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/884056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rK1GWa7W9DUu6tuySM2AtLVTpxE.jpg'),
(148487, 10586, 'Kaiju No. 8 S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/885779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rK1GWa7W9DUu6tuySM2AtLVTpxE.jpg'),
(148488, 10586, 'Kaiju No. 8 S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/886252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rK1GWa7W9DUu6tuySM2AtLVTpxE.jpg'),
(148489, 10587, 'Kevin Spacey A Historia Nao Contada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/358120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ymRj52r5tFN0BwoUhkJIsuHZVNA.jpg'),
(148490, 10587, 'Kevin Spacey A Historia Nao Contada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/358121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/NSi9gnLct9htrCDoaD0f1TT2t9.jpg'),
(148491, 10588, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S00 E01', 'http://sinalprivado.info:80/series/1533784/1533784/358095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6evGcWeNhD0hvZWrf1GUlM2dRds.jpg'),
(148492, 10588, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S00 E02', 'http://sinalprivado.info:80/series/1533784/1533784/358096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ymZpdCeQmMU5mi4OdCbK6kqFDsf.jpg'),
(148493, 10589, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/358097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c93ohIPep6Pd2ltcixMM49zf09I.jpg'),
(148494, 10589, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/358098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5wf4kCvdTCvbwi6jUQmM0lxDPeL.jpg'),
(148495, 10589, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/358099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bv7h9C9JCEuEQjf3Z5fegSahAu1.jpg'),
(148496, 10589, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/358100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6542ftoNCEyHNfi0TKKWzuFFOQX.jpg'),
(148497, 10589, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/358101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQCJtk2W8cAGjwUdJByGW2oLU6n.jpg'),
(148498, 10589, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/358102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mjhexvyiePjlMoibwdHrDao4XVj.jpg'),
(148499, 10589, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/358103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eXJvrz81IXjwQfpaImBSH7f4dqd.jpg'),
(148500, 10589, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/358104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/es4qpyBOxbFCyMY3mcaiasYZyoY.jpg'),
(148501, 10589, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/358105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oForvGu6gqF1xUHwtQY2zrk1Kij.jpg'),
(148502, 10589, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/358106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1faDRmHvlUlBNTMNELrpyqMrm8e.jpg'),
(148503, 10590, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/358107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/16Y76Utc88jQFrKQlazWEIOiJAa.jpg'),
(148504, 10590, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/358108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9SC3TPy7JNy6GPPQbNCxMsDosdS.jpg'),
(148505, 10590, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/358109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVre0WCffItFyMdeehx2IyUDczZ.jpg'),
(148506, 10590, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/358110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vSeTaswN4pFhLL9jL0vFulU6Rnc.jpg'),
(148507, 10590, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/358111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8S5L4vitRPHS03cU1HuwoH6JapB.jpg'),
(148508, 10590, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/358112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gjDoPsy9MlbyoGwRmawMQnZJOJl.jpg'),
(148509, 10590, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/358113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oW74GKp4MlM24vNjaeVuYdNi96A.jpg'),
(148510, 10590, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/358114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cri9SJridfnhgaUJu2KfoTjz393.jpg'),
(148511, 10590, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/358115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8pGCqJ1uDILuuJpeX1Xyb3nZaVf.jpg'),
(148512, 10590, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/358116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cP270lqGtcYTJD1MLALJTblPVlz.jpg'),
(148513, 10591, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/358117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOUJPe0wfg8GS2QLG8xCr3L2kZD.jpg'),
(148514, 10591, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/358118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jJM8mQknHdLSWrvN0NnUiannIAL.jpg'),
(148515, 10591, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/358119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j89cTvzKOGnLSJx8o4wmJbUvz9U.jpg'),
(148516, 10591, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/360757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kvXF7ugmNHo2HyNLy7lhQQVbBBa.jpg'),
(148517, 10591, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/613885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kvXF7ugmNHo2HyNLy7lhQQVbBBa.jpg'),
(148518, 10591, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/424723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kvXF7ugmNHo2HyNLy7lhQQVbBBa.jpg'),
(148519, 10591, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/382545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kvXF7ugmNHo2HyNLy7lhQQVbBBa.jpg'),
(148520, 10591, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/424725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kvXF7ugmNHo2HyNLy7lhQQVbBBa.jpg'),
(148521, 10591, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/417086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kvXF7ugmNHo2HyNLy7lhQQVbBBa.jpg'),
(148522, 10591, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/417087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kvXF7ugmNHo2HyNLy7lhQQVbBBa.jpg'),
(148523, 10591, 'Konosuba As Bencaos de Deus Neste Mundo Maravilhoso S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/417088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kvXF7ugmNHo2HyNLy7lhQQVbBBa.jpg'),
(148524, 10592, 'Laid Back Camp S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/358066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/um2qeNBAwuRMpECHyfqdQYXQYLA.jpg'),
(148525, 10592, 'Laid Back Camp S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/358067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3WDnvsX8S28zG5gVDVTcshTXdXa.jpg'),
(148526, 10592, 'Laid Back Camp S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/358068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zvJ4vuHvSpIHdaQ6qHAeK2gv2p1.jpg'),
(148527, 10592, 'Laid Back Camp S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/358069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jXjdqnsze9y2ZxAWZOt0JIOQH7n.jpg'),
(148528, 10592, 'Laid Back Camp S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/358070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nk3uHlhhXTyyl8ljAwXOpC0fJv7.jpg'),
(148529, 10592, 'Laid Back Camp S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/358071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ZLuRTiyXmaJKqLOqcxyBeLyI7j.jpg'),
(148530, 10592, 'Laid Back Camp S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/358072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yZ9KowL8cUMpoNks9CiJFc6g8Ul.jpg'),
(148531, 10592, 'Laid Back Camp S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/358073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5v1l7yK6bTAwlqsSN3L5QpMokfk.jpg'),
(148532, 10592, 'Laid Back Camp S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/358074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nQMJhZL1EOTFDQ4GK5xrb8xkEdX.jpg'),
(148533, 10592, 'Laid Back Camp S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/358075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2JcjFO96nKKNAE8JB8WoxEi5Ylo.jpg'),
(148534, 10592, 'Laid Back Camp S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/358076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p5QftqT6zQlp6qwJPGPHP7vQc2d.jpg'),
(148535, 10592, 'Laid Back Camp S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/358077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qGzN0ZdujPpuwvDaW4Uba2Zs6FT.jpg'),
(148536, 10592, 'Laid Back Camp S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/358078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AuKoz8qBqQ3gPuKNdzEfi0kBAIZ.jpg'),
(148537, 10593, 'Laid Back Camp S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/358079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6yvnQmHZ63fPSPmglXuqcCH6xG.jpg'),
(148538, 10593, 'Laid Back Camp S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/358080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g42lrW8msn4WBdutPaUQAD4daxa.jpg'),
(148539, 10593, 'Laid Back Camp S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/358081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a0OVchRrFpDobmZEWOLSdPhBFEI.jpg'),
(148540, 10593, 'Laid Back Camp S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/358082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pkozJRDcAWNjfiQjmuEV6wbXIKw.jpg'),
(148541, 10593, 'Laid Back Camp S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/358083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMnXJHnQHYzgL4OhWWYyTcT3dPd.jpg'),
(148542, 10593, 'Laid Back Camp S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/358084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oFrHaI1L0W2d7BiaCgOUwmRD4XN.jpg'),
(148543, 10593, 'Laid Back Camp S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/358085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8DCAbGwRV8nurHIt6WnKSPLnKMV.jpg'),
(148544, 10593, 'Laid Back Camp S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/358086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nf2yvEe9RVrJC0gtlU8BduAKBIx.jpg'),
(148545, 10593, 'Laid Back Camp S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/358087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ibpC1N3hsegFkvHofUuEbOQAzsB.jpg'),
(148546, 10593, 'Laid Back Camp S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/358088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cC9wT2E2aSUlsOuSMb8caPdBpQP.jpg'),
(148547, 10593, 'Laid Back Camp S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/358089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9aDWQvU3PCbCo143tAfl0zbLIAj.jpg'),
(148548, 10593, 'Laid Back Camp S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/358090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rNVOOd8iXBmfe3Ei2egUz617oN4.jpg'),
(148549, 10594, 'Laid Back Camp S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/358091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z5PW1VK0yICvRT9FXgKKrjyIPK5.jpg'),
(148550, 10594, 'Laid Back Camp S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/358092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/84gdj4owO2PLuB09EqP6Zgm2BL4.jpg'),
(148551, 10594, 'Laid Back Camp S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/358093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a3xmdwr6ntaRtl1g7FwKlrIfFGX.jpg'),
(148552, 10594, 'Laid Back Camp S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/358094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qrgVMthdhAwJCeyj0aSLIenbB7O.jpg'),
(148553, 10594, 'Laid Back Camp S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/412174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AuKoz8qBqQ3gPuKNdzEfi0kBAIZ.jpg'),
(148554, 10594, 'Laid Back Camp S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/412175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AuKoz8qBqQ3gPuKNdzEfi0kBAIZ.jpg'),
(148555, 10594, 'Laid Back Camp S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/412176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AuKoz8qBqQ3gPuKNdzEfi0kBAIZ.jpg'),
(148556, 10594, 'Laid Back Camp S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/412177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AuKoz8qBqQ3gPuKNdzEfi0kBAIZ.jpg'),
(148557, 10594, 'Laid Back Camp S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/412178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AuKoz8qBqQ3gPuKNdzEfi0kBAIZ.jpg'),
(148558, 10594, 'Laid Back Camp S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/412179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AuKoz8qBqQ3gPuKNdzEfi0kBAIZ.jpg'),
(148559, 10594, 'Laid Back Camp S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/415725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AuKoz8qBqQ3gPuKNdzEfi0kBAIZ.jpg'),
(148560, 10594, 'Laid Back Camp S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/412180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AuKoz8qBqQ3gPuKNdzEfi0kBAIZ.jpg'),
(148561, 10595, 'Lv2 kara Cheat datta Motoyuusha Kouho no Mattari Isekai Life S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/358062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/88VK8yDXgh7q6kN5Eh8DUGG2BtB.jpg'),
(148562, 10595, 'Lv2 kara Cheat datta Motoyuusha Kouho no Mattari Isekai Life S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/358063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ccPFRSme3rdiBBuAl59CbAfkvgd.jpg'),
(148563, 10595, 'Lv2 kara Cheat datta Motoyuusha Kouho no Mattari Isekai Life S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/358064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A1gJWfvZbSdxKCu310VS2RknaL7.jpg'),
(148564, 10595, 'Lv2 kara Cheat datta Motoyuusha Kouho no Mattari Isekai Life S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/358065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glG4YvnloEQZPEdz45eS6Z2o5bY.jpg'),
(148565, 10596, 'Romario O Cara S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/358060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iNCrU3wnzAmV3DEWHlMJicEBX0V.jpg'),
(148566, 10596, 'Romario O Cara S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/358061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8zjY5KaNBwlB2SpXEPdGauBLyTS.jpg'),
(148567, 10596, 'Romario O Cara S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/606789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5FcI5WoL1GgRj6op7sa811kOIla.jpg'),
(148568, 10596, 'Romario O Cara S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/606790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5FcI5WoL1GgRj6op7sa811kOIla.jpg'),
(148569, 10596, 'Romario O Cara S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/373032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5FcI5WoL1GgRj6op7sa811kOIla.jpg'),
(148570, 10596, 'Romario O Cara S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/373033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5FcI5WoL1GgRj6op7sa811kOIla.jpg'),
(148571, 10597, 'Seducao Mortal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/358052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y4volRMPIV4g1dhwERR4XKUwRMq.jpg'),
(148572, 10597, 'Seducao Mortal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/358053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1nLtzbJOl4uZeW2MegnMGTwKFeV.jpg'),
(148573, 10597, 'Seducao Mortal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/358054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jczRO2FDmER4YgrXfj6HPABMRLP.jpg'),
(148574, 10597, 'Seducao Mortal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/358055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dXXWFcGBTVhmc514g7LjLkiLwtw.jpg'),
(148575, 10597, 'Seducao Mortal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/358056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w1HbneRmIrmmk9Tl2qQKqIn6oZK.jpg'),
(148576, 10597, 'Seducao Mortal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/358057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pmi5X6CEDFw9tAQTAzRdWP91Fgs.jpg'),
(148577, 10597, 'Seducao Mortal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/358058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pMTzXrfRFXvEXUhrNw0EgOSBPqb.jpg'),
(148578, 10597, 'Seducao Mortal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/358059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2qDZGhfqb9GH7TWrPCNmCcefh1S.jpg'),
(148579, 10598, 'Time Patrol Bon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/358040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JMHkFOJPs4VSpiXnT6hYFPvAng.jpg'),
(148580, 10598, 'Time Patrol Bon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/358041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cCzX5AFI7OaZsNTaShytZZMQSFu.jpg'),
(148581, 10598, 'Time Patrol Bon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/358042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y1v9lJXFwfzR5lKaS38Q7NECPxP.jpg'),
(148582, 10598, 'Time Patrol Bon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/358043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZu8g4apJpOWQ8rY8hVmoZ5VPFJ.jpg'),
(148583, 10598, 'Time Patrol Bon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/358044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mn0I6iwwToMRxzAsWCQSsAVLMkI.jpg'),
(148584, 10598, 'Time Patrol Bon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/358045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y9Zj4OZ0JXuKskfSbTPyFjAdsGK.jpg'),
(148585, 10598, 'Time Patrol Bon S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/358046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c0b6D3PEIlEBedLh5aCmJWw5Gag.jpg'),
(148586, 10598, 'Time Patrol Bon S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/358047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rZ4DjsEEUjfsDxUlKQkjsz3MiIw.jpg'),
(148587, 10598, 'Time Patrol Bon S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/358048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A81xak3gs6StaJ3PgldgOfWJ2mi.jpg'),
(148588, 10598, 'Time Patrol Bon S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/358049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1g1QtOWhZYBkuiMJwNrmWhqmPwe.jpg'),
(148589, 10598, 'Time Patrol Bon S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/358050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4rekcJNxoG2fB1lc3Nv0pYCc1Ud.jpg'),
(148590, 10598, 'Time Patrol Bon S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/358051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bW2iAVaNgOqj1A3G34giskRm6dC.jpg'),
(148591, 10599, 'Time Patrol Bon S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/418109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8UbPzRZv3yjAtdynf1H2I1eUysC.jpg'),
(148592, 10599, 'Time Patrol Bon S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/418110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8UbPzRZv3yjAtdynf1H2I1eUysC.jpg'),
(148593, 10599, 'Time Patrol Bon S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/418111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8UbPzRZv3yjAtdynf1H2I1eUysC.jpg'),
(148594, 10599, 'Time Patrol Bon S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/418112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8UbPzRZv3yjAtdynf1H2I1eUysC.jpg'),
(148595, 10599, 'Time Patrol Bon S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/418113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8UbPzRZv3yjAtdynf1H2I1eUysC.jpg'),
(148596, 10599, 'Time Patrol Bon S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/418114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8UbPzRZv3yjAtdynf1H2I1eUysC.jpg'),
(148597, 10599, 'Time Patrol Bon S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/418115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8UbPzRZv3yjAtdynf1H2I1eUysC.jpg'),
(148598, 10599, 'Time Patrol Bon S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/418116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8UbPzRZv3yjAtdynf1H2I1eUysC.jpg'),
(148599, 10599, 'Time Patrol Bon S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/418117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8UbPzRZv3yjAtdynf1H2I1eUysC.jpg'),
(148600, 10599, 'Time Patrol Bon S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/418118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8UbPzRZv3yjAtdynf1H2I1eUysC.jpg'),
(148601, 10599, 'Time Patrol Bon S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/418119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8UbPzRZv3yjAtdynf1H2I1eUysC.jpg'),
(148602, 10599, 'Time Patrol Bon S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/418120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8UbPzRZv3yjAtdynf1H2I1eUysC.jpg'),
(148603, 10600, 'Por Que Voce [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/361382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bT7dsSYZDHUVwUNz5oaZT9kfeoZ.jpg'),
(148604, 10600, 'Por Que Voce [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/361383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sOdmtoPKShUBKVrTJQSIyLT0EgH.jpg'),
(148605, 10600, 'Por Que Voce [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/361384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hy0KjS8rk177Iza1vqRgl6ad4QP.jpg'),
(148606, 10600, 'Por Que Voce [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/361385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7dpUBT0qIHMHnUp3Zw1aSvjfDJp.jpg'),
(148607, 10600, 'Por Que Voce [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/361386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zs4hcCnguGLagnrE7oUzVmMj66I.jpg'),
(148608, 10600, 'Por Que Voce [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/361387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eEZMW6KRDxaITIUrqAzXC7LuNDj.jpg'),
(148609, 10600, 'Por Que Voce [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/361388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aW2D2Jar1huEF0ERZezRFRIUvox.jpg'),
(148610, 10600, 'Por Que Voce [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/361389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/okfBkRidWkC9cPF9uBW6RMewkOe.jpg'),
(148611, 10601, 'Furia no Transito S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/361377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h8gITxNrsajMo6UoUA6FrUcfPqJ.jpg'),
(148612, 10601, 'Furia no Transito S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/361378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fokGzz7EHKeDyOWVua1rgBp3xFB.jpg'),
(148613, 10601, 'Furia no Transito S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/361379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qqv7TtHezQn19z743fz7Zgxhvrq.jpg'),
(148614, 10601, 'Furia no Transito S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/361380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8EGh4rC12VqfgXsgaiOifesS07c.jpg'),
(148615, 10601, 'Furia no Transito S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/361381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6SoL5jJbQVNKWG2hKqV4syDqcFa.jpg'),
(148616, 10601, 'Furia no Transito S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/368405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LrinAZErFMTM08Zd2zI537bRZq.jpg'),
(148617, 10601, 'Furia no Transito S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/387416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LrinAZErFMTM08Zd2zI537bRZq.jpg'),
(148618, 10601, 'Furia no Transito S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/387417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LrinAZErFMTM08Zd2zI537bRZq.jpg'),
(148619, 10602, 'Furia no Transito S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/854717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LrinAZErFMTM08Zd2zI537bRZq.jpg'),
(148620, 10602, 'Furia no Transito S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/854718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LrinAZErFMTM08Zd2zI537bRZq.jpg'),
(148621, 10602, 'Furia no Transito S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/854719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LrinAZErFMTM08Zd2zI537bRZq.jpg'),
(148622, 10602, 'Furia no Transito S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/854720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LrinAZErFMTM08Zd2zI537bRZq.jpg'),
(148623, 10602, 'Furia no Transito S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/854721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LrinAZErFMTM08Zd2zI537bRZq.jpg'),
(148624, 10603, 'Furia no Transito S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/854722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LrinAZErFMTM08Zd2zI537bRZq.jpg'),
(148625, 10603, 'Furia no Transito S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/854723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LrinAZErFMTM08Zd2zI537bRZq.jpg'),
(148626, 10603, 'Furia no Transito S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/854724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LrinAZErFMTM08Zd2zI537bRZq.jpg'),
(148627, 10603, 'Furia no Transito S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/854725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LrinAZErFMTM08Zd2zI537bRZq.jpg'),
(148628, 10603, 'Furia no Transito S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/854726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LrinAZErFMTM08Zd2zI537bRZq.jpg'),
(148629, 10603, 'Furia no Transito S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/854727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LrinAZErFMTM08Zd2zI537bRZq.jpg'),
(148630, 10603, 'Furia no Transito S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/854728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LrinAZErFMTM08Zd2zI537bRZq.jpg'),
(148631, 10604, 'O Rei dos Pneus S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/361371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/SkwTyZq1toxkawGoDDZe5SgTN5.jpg'),
(148632, 10604, 'O Rei dos Pneus S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/361372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/67mGU7B7EPYngHrJuYJFxVRBmVV.jpg'),
(148633, 10604, 'O Rei dos Pneus S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/361373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5tvjps7OqLB0V5kYEkU0IVxjXxd.jpg'),
(148634, 10604, 'O Rei dos Pneus S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/361374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qomyL1QQByXvf1RrcKhYxsgDvB4.jpg'),
(148635, 10604, 'O Rei dos Pneus S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/361375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jYSY3TdXDcLq88dhh8eWyV77DPH.jpg'),
(148636, 10604, 'O Rei dos Pneus S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/361376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2T5fle4lsQQFUWAevePAepek6CW.jpg'),
(148637, 10605, 'Riquezas Insanas da Antiguidade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/361360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aP3FdBMqNPwMR7W8zjL9CoRWNyu.jpg'),
(148638, 10605, 'Riquezas Insanas da Antiguidade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/361361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a8fGPqKzqlI25aIubIpQRXmNmXy.jpg'),
(148639, 10605, 'Riquezas Insanas da Antiguidade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/361362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nKDKCURc0UJOToQdYmOYSLRnls0.jpg'),
(148640, 10605, 'Riquezas Insanas da Antiguidade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/361363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hhBWEMjps0zYu2Ifn0LBHmObTkp.jpg'),
(148641, 10605, 'Riquezas Insanas da Antiguidade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/361364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ehfR5YB12gOyEcuOspxTQPUApUG.jpg'),
(148642, 10605, 'Riquezas Insanas da Antiguidade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/361365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ihvFnDysimU5OA0KAWbokt1iZlF.jpg'),
(148643, 10605, 'Riquezas Insanas da Antiguidade S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439667.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pxf93VmpHtuivnGC8fE3yjKFMEc.jpg'),
(148644, 10605, 'Riquezas Insanas da Antiguidade S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/361366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6GD6DMOrOKBVmQMg7KGaqjUQy2B.jpg'),
(148645, 10605, 'Riquezas Insanas da Antiguidade S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/361367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/SBl9KM6A2rGhqzvrzhhmilGvuT.jpg'),
(148646, 10605, 'Riquezas Insanas da Antiguidade S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/361368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZkxAuGzdKnhvqJ2f6GAC8pMiER.jpg'),
(148647, 10605, 'Riquezas Insanas da Antiguidade S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/361369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Sd9UFPJO5kunYs4MZa47n1aDH2.jpg'),
(148648, 10605, 'Riquezas Insanas da Antiguidade S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/361370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rcOeTkGEseDjXNFsQPKvEDl4sNi.jpg'),
(148649, 10606, 'Suzhal Vortice S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/361352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eGFnQgbTCh7FItiszTj1x85KSOo.jpg'),
(148650, 10606, 'Suzhal Vortice S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/361353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uOXVePkIHXZJeGnlb4icpDSyiGc.jpg'),
(148651, 10606, 'Suzhal Vortice S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/361354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/poFvgrd1BoxZ0LVMSv57mEMSp0i.jpg'),
(148652, 10606, 'Suzhal Vortice S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/361355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/G9fLxujbp4Vx5V3HnuprmDMN3V.jpg'),
(148653, 10606, 'Suzhal Vortice S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/361356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4gtUVKJ0aYJiTnrFfd3Z0bHF4Wf.jpg'),
(148654, 10606, 'Suzhal Vortice S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/361357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fCpO5TmvBXUmbWCiBsTxyNGmsqw.jpg'),
(148655, 10606, 'Suzhal Vortice S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/361358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uPjTsHSgewN6YXH6cs9YejeuUXA.jpg'),
(148656, 10606, 'Suzhal Vortice S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/361359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tAq8vEz0PlRGwUB2P0aKtA1il2z.jpg'),
(148657, 10607, 'Uma Familia Inusitada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/361350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/XREBWhbZ4du2zsJWCAdZOl4UR1.jpg'),
(148658, 10607, 'Uma Familia Inusitada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/361351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AgDmuW5jfddZN4j1DNlZaIjuwFA.jpg'),
(148659, 10607, 'Uma Familia Inusitada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/609084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFA68Vj0P0cqsWEWlyzMdSFYyIs.jpg'),
(148660, 10607, 'Uma Familia Inusitada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/609085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFA68Vj0P0cqsWEWlyzMdSFYyIs.jpg'),
(148661, 10607, 'Uma Familia Inusitada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/376173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFA68Vj0P0cqsWEWlyzMdSFYyIs.jpg'),
(148662, 10607, 'Uma Familia Inusitada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/376174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFA68Vj0P0cqsWEWlyzMdSFYyIs.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(148663, 10607, 'Uma Familia Inusitada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/385683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFA68Vj0P0cqsWEWlyzMdSFYyIs.jpg'),
(148664, 10607, 'Uma Familia Inusitada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/385684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFA68Vj0P0cqsWEWlyzMdSFYyIs.jpg'),
(148665, 10607, 'Uma Familia Inusitada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFA68Vj0P0cqsWEWlyzMdSFYyIs.jpg'),
(148666, 10607, 'Uma Familia Inusitada S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFA68Vj0P0cqsWEWlyzMdSFYyIs.jpg'),
(148667, 10607, 'Uma Familia Inusitada S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/393946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFA68Vj0P0cqsWEWlyzMdSFYyIs.jpg'),
(148668, 10607, 'Uma Familia Inusitada S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/393947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFA68Vj0P0cqsWEWlyzMdSFYyIs.jpg'),
(148669, 10608, 'As Cronicas de Evermoor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytPVVenWnZ8L91ctE59P0QCCgYk.jpg'),
(148670, 10608, 'As Cronicas de Evermoor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytPVVenWnZ8L91ctE59P0QCCgYk.jpg'),
(148671, 10608, 'As Cronicas de Evermoor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytPVVenWnZ8L91ctE59P0QCCgYk.jpg'),
(148672, 10608, 'As Cronicas de Evermoor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytPVVenWnZ8L91ctE59P0QCCgYk.jpg'),
(148673, 10608, 'As Cronicas de Evermoor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytPVVenWnZ8L91ctE59P0QCCgYk.jpg'),
(148674, 10608, 'As Cronicas de Evermoor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytPVVenWnZ8L91ctE59P0QCCgYk.jpg'),
(148675, 10608, 'As Cronicas de Evermoor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytPVVenWnZ8L91ctE59P0QCCgYk.jpg'),
(148676, 10608, 'As Cronicas de Evermoor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytPVVenWnZ8L91ctE59P0QCCgYk.jpg'),
(148677, 10608, 'As Cronicas de Evermoor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytPVVenWnZ8L91ctE59P0QCCgYk.jpg'),
(148678, 10608, 'As Cronicas de Evermoor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytPVVenWnZ8L91ctE59P0QCCgYk.jpg'),
(148679, 10608, 'As Cronicas de Evermoor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytPVVenWnZ8L91ctE59P0QCCgYk.jpg'),
(148680, 10608, 'As Cronicas de Evermoor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/364702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytPVVenWnZ8L91ctE59P0QCCgYk.jpg'),
(148681, 10608, 'As Cronicas de Evermoor S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/364703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytPVVenWnZ8L91ctE59P0QCCgYk.jpg'),
(148682, 10608, 'As Cronicas de Evermoor S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/364704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytPVVenWnZ8L91ctE59P0QCCgYk.jpg'),
(148683, 10608, 'As Cronicas de Evermoor S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/364705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytPVVenWnZ8L91ctE59P0QCCgYk.jpg'),
(148684, 10608, 'As Cronicas de Evermoor S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/364706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytPVVenWnZ8L91ctE59P0QCCgYk.jpg'),
(148685, 10608, 'As Cronicas de Evermoor S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/364707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytPVVenWnZ8L91ctE59P0QCCgYk.jpg'),
(148686, 10608, 'As Cronicas de Evermoor S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/364708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytPVVenWnZ8L91ctE59P0QCCgYk.jpg'),
(148687, 10608, 'As Cronicas de Evermoor S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/364709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytPVVenWnZ8L91ctE59P0QCCgYk.jpg'),
(148688, 10608, 'As Cronicas de Evermoor S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/364710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytPVVenWnZ8L91ctE59P0QCCgYk.jpg'),
(148689, 10609, 'Dominion [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/slqWIqUfmaD3CcVRjvTIQTnw5xr.jpg'),
(148690, 10609, 'Dominion [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aCpVjNEzhXggbGradTtoAS1UnW2.jpg'),
(148691, 10609, 'Dominion [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yAJfd3hPMOfe2Ena3pzWQZGL9Cu.jpg'),
(148692, 10609, 'Dominion [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dbYbapCuqU1axVY99EGxHbT0n71.jpg'),
(148693, 10609, 'Dominion [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEv9JMpzvqrfpxVMpK5DLVxJpcs.jpg'),
(148694, 10609, 'Dominion [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hKbZ3GsLKJJu1Kz8w7RAkw1y0rB.jpg'),
(148695, 10609, 'Dominion [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQnvk4WqtpQ1IJ2nbJxha3dNodK.jpg'),
(148696, 10609, 'Dominion [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wTG17aO3KmbDtU0kX1O0RHTGeen.jpg'),
(148697, 10610, 'A Lenda de ShenLi [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iFDpALlCc8H2Jf1R1xcGaGAL17k.jpg'),
(148698, 10610, 'A Lenda de ShenLi [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hn9E9tpqGnZONvIx1Du1nOrI7kR.jpg'),
(148699, 10610, 'A Lenda de ShenLi [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ovoiEE5Dc08QOYb1F8ueAFh6Akt.jpg'),
(148700, 10610, 'A Lenda de ShenLi [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/51bFU7VjX5z7O9qa6eR3w6WSQvc.jpg'),
(148701, 10610, 'A Lenda de ShenLi [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tArEUiGW5PT3x0OEElPvtX65Faa.jpg'),
(148702, 10610, 'A Lenda de ShenLi [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9imuceGsALLvdwJrRMuHSQxC17S.jpg'),
(148703, 10610, 'A Lenda de ShenLi [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6tmHr9I5hFEOYcKljd0NussgFD1.jpg'),
(148704, 10610, 'A Lenda de ShenLi [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/28RK41N4D3RorLxKrSqg0blCLXM.jpg'),
(148705, 10610, 'A Lenda de ShenLi [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJQDE6i54c9SJASBzANXWCOwwnY.jpg'),
(148706, 10610, 'A Lenda de ShenLi [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xGGJQlq6BhdCRTVksBkAR3dZPiQ.jpg'),
(148707, 10610, 'A Lenda de ShenLi [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Bcrgb04KCy6cOooBqerhW2NSZO.jpg'),
(148708, 10610, 'A Lenda de ShenLi [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/364615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ipleDSzgaLIrx343d2jHi9eoElI.jpg'),
(148709, 10610, 'A Lenda de ShenLi [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/364616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ShMgG733MA2jtSU4NaRkHw55HS.jpg'),
(148710, 10610, 'A Lenda de ShenLi [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/364617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y1dELeeenLpWtf5mLbnlUb7ir46.jpg'),
(148711, 10610, 'A Lenda de ShenLi [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/364618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ov9NfRyAdqGvV2bsTRCpm6RYEDN.jpg'),
(148712, 10610, 'A Lenda de ShenLi [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/364619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Mqd4kzAohqddcDORzm6LjwlXIc.jpg'),
(148713, 10610, 'A Lenda de ShenLi [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/364620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBbQCbjWvVkW0uAJSmDm79jc4v4.jpg'),
(148714, 10610, 'A Lenda de ShenLi [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/364621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zCUmlptfHxHHPxd93ztL9oyMFJr.jpg'),
(148715, 10610, 'A Lenda de ShenLi [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/364622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t2soLv7OkycRmsjGujzDdh6Zgnt.jpg'),
(148716, 10610, 'A Lenda de ShenLi [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/364623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x9bI2FAHN8B8DsyIsAvTuuThFZe.jpg'),
(148717, 10610, 'A Lenda de ShenLi [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/364624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1WyFDFsHzz1nCYK347F5RTOs0Wd.jpg'),
(148718, 10610, 'A Lenda de ShenLi [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/364625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/85lBftgLIoFVtsTLPLO9ZvpczQE.jpg'),
(148719, 10610, 'A Lenda de ShenLi [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/364626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xYncrt0aI6G7BQ4TJW0T79exJYC.jpg'),
(148720, 10610, 'A Lenda de ShenLi [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/364627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mW3kve6FJN8jIOVxbAUmgI6EbpP.jpg'),
(148721, 10610, 'A Lenda de ShenLi [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/364628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qWcDBKcBMEimZ1C7kpUFNE6sRhf.jpg'),
(148722, 10610, 'A Lenda de ShenLi [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/364629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oFqdrNeNbDcM3XCXPBwrxTN19yg.jpg'),
(148723, 10610, 'A Lenda de ShenLi [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/364630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oPE1kqQm8TYgZE9uLipzMc8ycVN.jpg'),
(148724, 10610, 'A Lenda de ShenLi [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/364631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yJbtg8ANfQ1MlNHotH5vjLx3WK1.jpg'),
(148725, 10610, 'A Lenda de ShenLi [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/364632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hKqJow0lw2ZLgkGD7o9oNnZYGeA.jpg'),
(148726, 10610, 'A Lenda de ShenLi [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/364633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/34QTDUcwqoqgZbDFQJwV3h22x2u.jpg'),
(148727, 10610, 'A Lenda de ShenLi [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/364634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q62amKdPLnbsZzKCOfM2IbcidgC.jpg'),
(148728, 10610, 'A Lenda de ShenLi [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/364635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/MngEpsl9SMNzTGLxBcRLWQLkEL.jpg'),
(148729, 10610, 'A Lenda de ShenLi [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/364636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A7XaCqP6ccupiicG0cgoeNVAu6j.jpg'),
(148730, 10610, 'A Lenda de ShenLi [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/364637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4XlPC3V24OGmtYy1No0zPzh5hpx.jpg'),
(148731, 10610, 'A Lenda de ShenLi [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/364638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nPYPK1qyKdaBSIiKG1zBYthpsIC.jpg'),
(148732, 10610, 'A Lenda de ShenLi [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/364639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zPveupk5Th6rMpNS40TGbstsVkB.jpg'),
(148733, 10610, 'A Lenda de ShenLi [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/364640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ncXjOqRMGOKCsA3nYbnPsd3nmTX.jpg'),
(148734, 10610, 'A Lenda de ShenLi [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/364641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3K21OoTADVUcd0rHV4RM3VEPGtB.jpg'),
(148735, 10610, 'A Lenda de ShenLi [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/364642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s0bfsS5kuMg1RgcAIrE64mv0tnu.jpg'),
(148736, 10611, 'A Salad Bowl of Eccentrics [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tKDpQ5MtobgruUaY63RYN6lkEPT.jpg'),
(148737, 10611, 'A Salad Bowl of Eccentrics [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sUhVTOEWOZ58WB9UYRtu4c9bxNd.jpg'),
(148738, 10611, 'A Salad Bowl of Eccentrics [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/niXXkO1bbxMuNmm2RbomtJJIPzo.jpg'),
(148739, 10611, 'A Salad Bowl of Eccentrics [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uIVhEsOwVf9xMY9D1GNi9EuUuYe.jpg'),
(148740, 10611, 'A Salad Bowl of Eccentrics [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3VyC6G3mOH9CXAKt9w0SvUX2Fmb.jpg'),
(148741, 10611, 'A Salad Bowl of Eccentrics [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/19hadoWoqw2BsR5jfA38ttF3FRq.jpg'),
(148742, 10611, 'A Salad Bowl of Eccentrics [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i9Fd27JdNwEKpO5I1RmSFlHgnZJ.jpg'),
(148743, 10611, 'A Salad Bowl of Eccentrics [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zI7IjrfkhevUDd9CltBuo66oY6H.jpg'),
(148744, 10611, 'A Salad Bowl of Eccentrics [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/380145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/syqUYWnOIDMzrplUQpcg4dpCxF3.jpg'),
(148745, 10611, 'A Salad Bowl of Eccentrics [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/380146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/syqUYWnOIDMzrplUQpcg4dpCxF3.jpg'),
(148746, 10611, 'A Salad Bowl of Eccentrics [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/383437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/syqUYWnOIDMzrplUQpcg4dpCxF3.jpg'),
(148747, 10611, 'A Salad Bowl of Eccentrics [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/385181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/syqUYWnOIDMzrplUQpcg4dpCxF3.jpg'),
(148748, 10612, 'A Vida que Voce Queria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehr8VbxdZbSHAn4gAaL7uzWz8Ky.jpg'),
(148749, 10612, 'A Vida que Voce Queria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehr8VbxdZbSHAn4gAaL7uzWz8Ky.jpg'),
(148750, 10612, 'A Vida que Voce Queria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehr8VbxdZbSHAn4gAaL7uzWz8Ky.jpg'),
(148751, 10612, 'A Vida que Voce Queria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehr8VbxdZbSHAn4gAaL7uzWz8Ky.jpg'),
(148752, 10612, 'A Vida que Voce Queria S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehr8VbxdZbSHAn4gAaL7uzWz8Ky.jpg'),
(148753, 10612, 'A Vida que Voce Queria S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehr8VbxdZbSHAn4gAaL7uzWz8Ky.jpg'),
(148754, 10613, 'Aishiteruze Baby [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148755, 10613, 'Aishiteruze Baby [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148756, 10613, 'Aishiteruze Baby [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148757, 10613, 'Aishiteruze Baby [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148758, 10613, 'Aishiteruze Baby [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148759, 10613, 'Aishiteruze Baby [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148760, 10613, 'Aishiteruze Baby [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148761, 10613, 'Aishiteruze Baby [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148762, 10613, 'Aishiteruze Baby [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148763, 10613, 'Aishiteruze Baby [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148764, 10613, 'Aishiteruze Baby [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148765, 10613, 'Aishiteruze Baby [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/364575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148766, 10613, 'Aishiteruze Baby [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/364576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148767, 10613, 'Aishiteruze Baby [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/364577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148768, 10613, 'Aishiteruze Baby [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/364578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148769, 10613, 'Aishiteruze Baby [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/364579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148770, 10613, 'Aishiteruze Baby [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/364580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148771, 10613, 'Aishiteruze Baby [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/364581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148772, 10613, 'Aishiteruze Baby [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/364582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148773, 10613, 'Aishiteruze Baby [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/364583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148774, 10613, 'Aishiteruze Baby [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/364584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148775, 10613, 'Aishiteruze Baby [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/364585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148776, 10613, 'Aishiteruze Baby [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/364586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148777, 10613, 'Aishiteruze Baby [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/364587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148778, 10613, 'Aishiteruze Baby [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/364588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148779, 10613, 'Aishiteruze Baby [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/364589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11YhLRucLdmIj0t3m9MtuQZec7V.jpg'),
(148780, 10614, 'Amor no Contrato [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vOQsUbt6cbvCQRdvONXbTYm89lq.jpg'),
(148781, 10614, 'Amor no Contrato [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6YDRkuNtKV4r62LgnBKsHQkQ6WG.jpg'),
(148782, 10614, 'Amor no Contrato [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z2S6w4j6E62kHAJPOXD1AOPDlFM.jpg'),
(148783, 10614, 'Amor no Contrato [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJmjl7HX5sGXsdE45pPtNGLMM0L.jpg'),
(148784, 10614, 'Amor no Contrato [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wEvwlkBdAcrdQWfzQleS7W10XAD.jpg'),
(148785, 10614, 'Amor no Contrato [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQwCxz5KjOSpWWZQOvfM4f7sy0.jpg'),
(148786, 10614, 'Amor no Contrato [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a2oN8JA3NkQtgKo2EQLMo2fy7oS.jpg'),
(148787, 10614, 'Amor no Contrato [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4uoqXXWOt1XM5fxv79QRrON73Xz.jpg'),
(148788, 10614, 'Amor no Contrato [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cexZidD20pGzlOZwsyBK1lRBXqF.jpg'),
(148789, 10614, 'Amor no Contrato [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7qUqi3kfAjzTyX1ACPwezSrCWj.jpg'),
(148790, 10614, 'Amor no Contrato [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/52qi5vWG0Zrv8bvdXorfJI6VvNW.jpg'),
(148791, 10614, 'Amor no Contrato [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/364559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6zq75jJpJcpatoGGVp8HKLpuRZu.jpg'),
(148792, 10614, 'Amor no Contrato [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/364560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDxBonxcMZw97PqsvxvDLB0wHFu.jpg'),
(148793, 10614, 'Amor no Contrato [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/364561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1XYHeEhHoVZMKrAaK0HbE6P5ndz.jpg'),
(148794, 10614, 'Amor no Contrato [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/364562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/23zQiP3SLDPve5fMlv5Ue5HjFjS.jpg'),
(148795, 10614, 'Amor no Contrato [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/364563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ag5fGtFttOa0z6jlzqCeMKrJ90O.jpg'),
(148796, 10615, 'An Archdemons Dilemma How to Love Your Elf Bride [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n0DkM02BoYy3lk2nzuVdVAOohAE.jpg'),
(148797, 10615, 'An Archdemons Dilemma How to Love Your Elf Bride [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6o0uvTNW0uGqOqukI8c8DKP2San.jpg'),
(148798, 10615, 'An Archdemons Dilemma How to Love Your Elf Bride [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4gXeemOWAxrRCvRwgFxvAUJ3pLa.jpg'),
(148799, 10615, 'An Archdemons Dilemma How to Love Your Elf Bride [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yCqEtp7uLQGuCDvq1BLdDk3SnTg.jpg'),
(148800, 10615, 'An Archdemons Dilemma How to Love Your Elf Bride [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kOhyyujMPRV8cVlnOWmgllTKOKU.jpg'),
(148801, 10615, 'An Archdemons Dilemma How to Love Your Elf Bride [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tazhwfzAt4fNoGfkBsFagj2FdvW.jpg'),
(148802, 10615, 'An Archdemons Dilemma How to Love Your Elf Bride [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1P6hKVNCudX2E2sEv3bhkRRlGUL.jpg'),
(148803, 10615, 'An Archdemons Dilemma How to Love Your Elf Bride [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/69Kan36xSxeVirvxGYcRp6Ye4LH.jpg'),
(148804, 10615, 'An Archdemons Dilemma How to Love Your Elf Bride [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/380134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iW0iY5Fv0V6oHQ33Jk9iTsyV3Y6.jpg'),
(148805, 10615, 'An Archdemons Dilemma How to Love Your Elf Bride [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/380135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iW0iY5Fv0V6oHQ33Jk9iTsyV3Y6.jpg'),
(148806, 10615, 'An Archdemons Dilemma How to Love Your Elf Bride [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/380136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iW0iY5Fv0V6oHQ33Jk9iTsyV3Y6.jpg'),
(148807, 10615, 'An Archdemons Dilemma How to Love Your Elf Bride [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/383398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iW0iY5Fv0V6oHQ33Jk9iTsyV3Y6.jpg'),
(148808, 10616, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bqT6Yffx1gZkkUAPs8mE8mjW1cU.jpg'),
(148809, 10616, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a39jW1qSRxBN5fJKycBbKWkUHyw.jpg'),
(148810, 10616, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1g7nulEuCJ0aqI2xIVAokCXcjSz.jpg'),
(148811, 10616, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ezKspOjA0KhnvQ3qUdCSSkdEPGc.jpg'),
(148812, 10616, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dOzGS8ORpnarxzBTVpoXXs0yyVr.jpg'),
(148813, 10616, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tUpvx8nErabArphJ0r5ejvAygxf.jpg'),
(148814, 10616, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/79EiTpqTQmjStXONjq7yPjqA66K.jpg'),
(148815, 10616, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i5grx0y4jYzx64RO3HCJXKXoyIg.jpg'),
(148816, 10616, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/380125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pMLitK7uCKoF25dNn5Xai0RuFra.jpg'),
(148817, 10616, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/727779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pMLitK7uCKoF25dNn5Xai0RuFra.jpg'),
(148818, 10616, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/727780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pMLitK7uCKoF25dNn5Xai0RuFra.jpg'),
(148819, 10616, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/727781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pMLitK7uCKoF25dNn5Xai0RuFra.jpg'),
(148820, 10617, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/634428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pMLitK7uCKoF25dNn5Xai0RuFra.jpg'),
(148821, 10617, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/634429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pMLitK7uCKoF25dNn5Xai0RuFra.jpg'),
(148822, 10617, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/634430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pMLitK7uCKoF25dNn5Xai0RuFra.jpg'),
(148823, 10617, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/634431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pMLitK7uCKoF25dNn5Xai0RuFra.jpg'),
(148824, 10617, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/634432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pMLitK7uCKoF25dNn5Xai0RuFra.jpg'),
(148825, 10617, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/634433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pMLitK7uCKoF25dNn5Xai0RuFra.jpg'),
(148826, 10617, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/634434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pMLitK7uCKoF25dNn5Xai0RuFra.jpg'),
(148827, 10617, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/512560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pMLitK7uCKoF25dNn5Xai0RuFra.jpg'),
(148828, 10617, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/514637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pMLitK7uCKoF25dNn5Xai0RuFra.jpg'),
(148829, 10617, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pMLitK7uCKoF25dNn5Xai0RuFra.jpg'),
(148830, 10617, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/521407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pMLitK7uCKoF25dNn5Xai0RuFra.jpg'),
(148831, 10617, 'As a Reincarnated Aristocrat Ill Use My Appraisal Skill to Rise in the World [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/642073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pMLitK7uCKoF25dNn5Xai0RuFra.jpg'),
(148832, 10618, 'Astro Note [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fn35XRcqL07iMasT8JIVttoO1gi.jpg'),
(148833, 10618, 'Astro Note [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n6J2OSUQkknmnd3ayxeqU9sgKoj.jpg'),
(148834, 10618, 'Astro Note [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yXI91VIhOBK54wgwCXLv0crgeGw.jpg'),
(148835, 10618, 'Astro Note [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gLSnEHYRJWVeGVLIlCgTxRjc5NN.jpg'),
(148836, 10618, 'Astro Note [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fDggzWejUukYdBmxSD7Snw2q9pV.jpg'),
(148837, 10618, 'Astro Note [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8RYA025JWM9FARgMyUIEIoyv8pF.jpg'),
(148838, 10618, 'Astro Note [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iUxqwqDUR0XFFyGjCXOM0nc8qf5.jpg'),
(148839, 10618, 'Astro Note [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sE0yaLzQxDgZ60wpGbyWsFKetGP.jpg'),
(148840, 10618, 'Astro Note [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/380115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t80gwqjaQ5QtYP5NDFHtFnpgnqL.jpg'),
(148841, 10618, 'Astro Note [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/380116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t80gwqjaQ5QtYP5NDFHtFnpgnqL.jpg'),
(148842, 10618, 'Astro Note [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/383386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t80gwqjaQ5QtYP5NDFHtFnpgnqL.jpg'),
(148843, 10618, 'Astro Note [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/392939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t80gwqjaQ5QtYP5NDFHtFnpgnqL.jpg'),
(148844, 10619, 'Blue Archive The Animation S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ygmEcErrtQ9HgSX6Nooe9csAyTv.jpg'),
(148845, 10619, 'Blue Archive The Animation S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2YrV12UZQTjhv30KLjeMlwykquk.jpg'),
(148846, 10619, 'Blue Archive The Animation S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zF61SYwcNKw8br1oXsFNYnXjtCZ.jpg'),
(148847, 10619, 'Blue Archive The Animation S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s09A3I2xUTVwoUxwhmgSvQp8KOF.jpg'),
(148848, 10619, 'Blue Archive The Animation S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iOms3s3VZYGS8bLHxXUV6rrvVpy.jpg'),
(148849, 10619, 'Blue Archive The Animation S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aNmZFV77MVmSj68nQS8C72wdTdJ.jpg'),
(148850, 10619, 'Blue Archive The Animation S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c9aMhaLi1Z42DucBiLW5uMuWxJA.jpg'),
(148851, 10620, 'Boku no Hero Academia [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5S4t7vjGUahG8ieEUTDNPi1DPBh.jpg'),
(148852, 10620, 'Boku no Hero Academia [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Aa6blmgqkJDVDrf70Un1hXfjIT.jpg'),
(148853, 10620, 'Boku no Hero Academia [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/un1Xph8SN0yBOwwa4ntNga0XkiN.jpg'),
(148854, 10620, 'Boku no Hero Academia [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUq0PFzkFH0cTmsw9sBpTE2vgw9.jpg'),
(148855, 10620, 'Boku no Hero Academia [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fBVvIvLZ1pMg8Ox1MSRBmbTiIz3.jpg'),
(148856, 10620, 'Boku no Hero Academia [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/upEMKOD1lt7yMDg0ISB8WrkECjy.jpg'),
(148857, 10620, 'Boku no Hero Academia [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXV0b7N5WNk0ytYJryBqc6O8nVT.jpg'),
(148858, 10620, 'Boku no Hero Academia [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sjHC0vaEDAiMFhRHNGP0NvpVj9E.jpg'),
(148859, 10620, 'Boku no Hero Academia [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4lEhvo3bs3Svu0yTFNMNmBHv7pz.jpg'),
(148860, 10620, 'Boku no Hero Academia [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3QC4VYPiVCW7IEynQfrrGqFaNyg.jpg'),
(148861, 10620, 'Boku no Hero Academia [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/soDtzvKUfazGMrwRYlI4yUBifK2.jpg'),
(148862, 10620, 'Boku no Hero Academia [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/364393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qJRML65qJ7mbzuTdMK8Nyxt40s3.jpg'),
(148863, 10620, 'Boku no Hero Academia [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/364394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tcGyMcpJZhibydDqP2E1M6Ezd1G.jpg'),
(148864, 10621, 'Boku no Hero Academia [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zZvIDhNNe3WQdt3RkNPBN0tPVmy.jpg'),
(148865, 10621, 'Boku no Hero Academia [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i7PYwjTCbQMQS0uEKJGZZIgl9nb.jpg'),
(148866, 10621, 'Boku no Hero Academia [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sy4x22W7mzpSzdcENPXsztmbXnJ.jpg'),
(148867, 10621, 'Boku no Hero Academia [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jFDSZqlC8sfKgOO6vuiQjDidfkS.jpg'),
(148868, 10621, 'Boku no Hero Academia [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vKXtSJpnvBBiBdnKz90nlhiWcoI.jpg'),
(148869, 10621, 'Boku no Hero Academia [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fPMY8vANaLtYEokGTEWlB1951X6.jpg'),
(148870, 10621, 'Boku no Hero Academia [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7QnQCNfBQOmjo8HMr0oQkyQbdL.jpg'),
(148871, 10621, 'Boku no Hero Academia [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h0QFP8dKtq6I0dOsljPh5uMjUET.jpg'),
(148872, 10621, 'Boku no Hero Academia [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/viz7Ei6dxSmLXQwvVbodQvUfhxf.jpg'),
(148873, 10621, 'Boku no Hero Academia [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/edmDKyqrYDtp53b5uCylfS5gFY9.jpg'),
(148874, 10621, 'Boku no Hero Academia [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3D3vfbtDmMHsbse73NYfUK3ShU8.jpg'),
(148875, 10621, 'Boku no Hero Academia [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/364406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tRaD9tu1Qjq9kcdgN4UHYgKzlqa.jpg'),
(148876, 10621, 'Boku no Hero Academia [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/364407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148877, 10621, 'Boku no Hero Academia [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/364408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148878, 10621, 'Boku no Hero Academia [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/364409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148879, 10621, 'Boku no Hero Academia [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/364410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148880, 10621, 'Boku no Hero Academia [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/364411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148881, 10621, 'Boku no Hero Academia [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/364412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148882, 10621, 'Boku no Hero Academia [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/364413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148883, 10621, 'Boku no Hero Academia [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/364414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148884, 10621, 'Boku no Hero Academia [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/364415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148885, 10621, 'Boku no Hero Academia [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/364416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148886, 10621, 'Boku no Hero Academia [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/364417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148887, 10621, 'Boku no Hero Academia [L] S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/364418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148888, 10621, 'Boku no Hero Academia [L] S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/364419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148889, 10622, 'Boku no Hero Academia [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148890, 10622, 'Boku no Hero Academia [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148891, 10622, 'Boku no Hero Academia [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148892, 10622, 'Boku no Hero Academia [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148893, 10622, 'Boku no Hero Academia [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148894, 10622, 'Boku no Hero Academia [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148895, 10622, 'Boku no Hero Academia [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148896, 10622, 'Boku no Hero Academia [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148897, 10622, 'Boku no Hero Academia [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148898, 10622, 'Boku no Hero Academia [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148899, 10622, 'Boku no Hero Academia [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148900, 10622, 'Boku no Hero Academia [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/364431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148901, 10622, 'Boku no Hero Academia [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/364432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148902, 10622, 'Boku no Hero Academia [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/364433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148903, 10622, 'Boku no Hero Academia [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/364434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148904, 10622, 'Boku no Hero Academia [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/364435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148905, 10622, 'Boku no Hero Academia [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/364436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148906, 10622, 'Boku no Hero Academia [L] S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/364437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(148907, 10622, 'Boku no Hero Academia [L] S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/364438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148908, 10622, 'Boku no Hero Academia [L] S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/364439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148909, 10622, 'Boku no Hero Academia [L] S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/364440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148910, 10622, 'Boku no Hero Academia [L] S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/364441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148911, 10622, 'Boku no Hero Academia [L] S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/364442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148912, 10622, 'Boku no Hero Academia [L] S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/364443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148913, 10622, 'Boku no Hero Academia [L] S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/364444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148914, 10623, 'Boku no Hero Academia [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148915, 10623, 'Boku no Hero Academia [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148916, 10623, 'Boku no Hero Academia [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148917, 10623, 'Boku no Hero Academia [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148918, 10623, 'Boku no Hero Academia [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148919, 10623, 'Boku no Hero Academia [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148920, 10623, 'Boku no Hero Academia [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148921, 10623, 'Boku no Hero Academia [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148922, 10623, 'Boku no Hero Academia [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148923, 10623, 'Boku no Hero Academia [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148924, 10623, 'Boku no Hero Academia [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148925, 10623, 'Boku no Hero Academia [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/364456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148926, 10623, 'Boku no Hero Academia [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/364457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148927, 10623, 'Boku no Hero Academia [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/364458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148928, 10623, 'Boku no Hero Academia [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/364459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148929, 10623, 'Boku no Hero Academia [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/364460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148930, 10623, 'Boku no Hero Academia [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/364461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148931, 10623, 'Boku no Hero Academia [L] S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/364462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148932, 10623, 'Boku no Hero Academia [L] S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/364463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148933, 10623, 'Boku no Hero Academia [L] S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/364464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148934, 10623, 'Boku no Hero Academia [L] S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/364465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148935, 10623, 'Boku no Hero Academia [L] S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/364466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148936, 10623, 'Boku no Hero Academia [L] S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/364467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148937, 10623, 'Boku no Hero Academia [L] S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/364468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148938, 10623, 'Boku no Hero Academia [L] S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/364469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148939, 10624, 'Boku no Hero Academia [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148940, 10624, 'Boku no Hero Academia [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148941, 10624, 'Boku no Hero Academia [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148942, 10624, 'Boku no Hero Academia [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148943, 10624, 'Boku no Hero Academia [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148944, 10624, 'Boku no Hero Academia [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148945, 10624, 'Boku no Hero Academia [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148946, 10624, 'Boku no Hero Academia [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148947, 10624, 'Boku no Hero Academia [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148948, 10624, 'Boku no Hero Academia [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148949, 10624, 'Boku no Hero Academia [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148950, 10624, 'Boku no Hero Academia [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/364481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148951, 10624, 'Boku no Hero Academia [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/364482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148952, 10624, 'Boku no Hero Academia [L] S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/364483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148953, 10624, 'Boku no Hero Academia [L] S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/364484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148954, 10624, 'Boku no Hero Academia [L] S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/364485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148955, 10624, 'Boku no Hero Academia [L] S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/364486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148956, 10624, 'Boku no Hero Academia [L] S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/364487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148957, 10624, 'Boku no Hero Academia [L] S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/364488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148958, 10624, 'Boku no Hero Academia [L] S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/364489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148959, 10624, 'Boku no Hero Academia [L] S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/364490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148960, 10624, 'Boku no Hero Academia [L] S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/364491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148961, 10624, 'Boku no Hero Academia [L] S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/364492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148962, 10624, 'Boku no Hero Academia [L] S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/364493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148963, 10624, 'Boku no Hero Academia [L] S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/364494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148964, 10625, 'Boku no Hero Academia [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148965, 10625, 'Boku no Hero Academia [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148966, 10625, 'Boku no Hero Academia [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148967, 10625, 'Boku no Hero Academia [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148968, 10625, 'Boku no Hero Academia [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148969, 10625, 'Boku no Hero Academia [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148970, 10625, 'Boku no Hero Academia [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148971, 10625, 'Boku no Hero Academia [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148972, 10625, 'Boku no Hero Academia [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148973, 10625, 'Boku no Hero Academia [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148974, 10625, 'Boku no Hero Academia [L] S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148975, 10625, 'Boku no Hero Academia [L] S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/364506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148976, 10625, 'Boku no Hero Academia [L] S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/364507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148977, 10625, 'Boku no Hero Academia [L] S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/364508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148978, 10625, 'Boku no Hero Academia [L] S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/364509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148979, 10625, 'Boku no Hero Academia [L] S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/364510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148980, 10625, 'Boku no Hero Academia [L] S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/364511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148981, 10625, 'Boku no Hero Academia [L] S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/364512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148982, 10625, 'Boku no Hero Academia [L] S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/364513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148983, 10625, 'Boku no Hero Academia [L] S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/364514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148984, 10625, 'Boku no Hero Academia [L] S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/364515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148985, 10625, 'Boku no Hero Academia [L] S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/364516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148986, 10625, 'Boku no Hero Academia [L] S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/364517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148987, 10625, 'Boku no Hero Academia [L] S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/364518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148988, 10625, 'Boku no Hero Academia [L] S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/364519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148989, 10626, 'Boku no Hero Academia [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148990, 10626, 'Boku no Hero Academia [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148991, 10626, 'Boku no Hero Academia [L] S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148992, 10626, 'Boku no Hero Academia [L] S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148993, 10626, 'Boku no Hero Academia [L] S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/380084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148994, 10626, 'Boku no Hero Academia [L] S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/380085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148995, 10626, 'Boku no Hero Academia [L] S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/387728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148996, 10626, 'Boku no Hero Academia [L] S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/392895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148997, 10626, 'Boku no Hero Academia [L] S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/398008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148998, 10626, 'Boku no Hero Academia [L] S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/409671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(148999, 10626, 'Boku no Hero Academia [L] S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149000, 10626, 'Boku no Hero Academia [L] S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/425537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149001, 10626, 'Boku no Hero Academia [L] S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/435238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149002, 10626, 'Boku no Hero Academia [L] S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/437513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149003, 10626, 'Boku no Hero Academia [L] S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/444993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149004, 10626, 'Boku no Hero Academia [L] S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/448682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149005, 10626, 'Boku no Hero Academia [L] S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/456705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149006, 10626, 'Boku no Hero Academia [L] S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/461982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149007, 10626, 'Boku no Hero Academia [L] S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/468181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149008, 10626, 'Boku no Hero Academia [L] S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/475223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149009, 10626, 'Boku no Hero Academia [L] S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/478926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149010, 10626, 'Boku no Hero Academia [L] S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/485812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149011, 10627, 'Boku no Hero Academia [L] S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/887716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149012, 10627, 'Boku no Hero Academia [L] S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/888113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149013, 10627, 'Boku no Hero Academia [L] S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/889681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149014, 10627, 'Boku no Hero Academia [L] S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/890025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149015, 10627, 'Boku no Hero Academia [L] S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/890986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149016, 10627, 'Boku no Hero Academia [L] S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/892181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149017, 10627, 'Boku no Hero Academia [L] S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/892594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149018, 10627, 'Boku no Hero Academia [L] S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/893315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149019, 10627, 'Boku no Hero Academia [L] S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/893544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149020, 10627, 'Boku no Hero Academia [L] S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/894821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149021, 10627, 'Boku no Hero Academia [L] S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/895802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dmUuNVWAJumRkDNuauFaLSvga00.jpg'),
(149022, 10628, 'Date A Live [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ppt6MBnlQ9JmaardqUSxSgkikbv.jpg'),
(149023, 10628, 'Date A Live [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wfG0zqF3OQdRxOo6hiA6tO4bBDT.jpg'),
(149024, 10628, 'Date A Live [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhXwFDQnSGcb93FQUiQGSSbMLgL.jpg'),
(149025, 10628, 'Date A Live [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xdkXPGbFV9WKuyqWNWO00MBjmRD.jpg'),
(149026, 10628, 'Date A Live [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sjUgnHTKec3SbQAfFLPbYZetZDQ.jpg'),
(149027, 10628, 'Date A Live [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uQml8XL3KJKNdFYqGSfiQuLZIq6.jpg'),
(149028, 10628, 'Date A Live [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gEGGYj8tyxMbyhKKRgjmmNwtx0j.jpg'),
(149029, 10628, 'Date A Live [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pAxp7NBy37Vq7abAVwSBczISRLI.jpg'),
(149030, 10628, 'Date A Live [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJH1qqQRLr4rD03Pqp9SS0cA7Db.jpg'),
(149031, 10628, 'Date A Live [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6qYiVjSidkG04csdKjx9dSzEdw4.jpg'),
(149032, 10628, 'Date A Live [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sLcz7pcAiOzaSahVPvglmvg6AT5.jpg'),
(149033, 10628, 'Date A Live [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/364338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jmbstya66w3UeEI6rUOYeBqrRSk.jpg'),
(149034, 10629, 'Date A Live [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tsIJLANCYFPoC97wNL6KB2esSc.jpg'),
(149035, 10629, 'Date A Live [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sY7L7UeECG4diwUw8tTHQiJQc1u.jpg'),
(149036, 10629, 'Date A Live [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lU84SyoDW7jEQb7pFwEw6Neivk8.jpg'),
(149037, 10629, 'Date A Live [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3pyb8Q7Q23ao47J093tBeEHmco.jpg'),
(149038, 10629, 'Date A Live [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s0F8QHG7YPASAR19R5kxYtro0Zt.jpg'),
(149039, 10629, 'Date A Live [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b8E9lilHWO0LkgVvYIweQrleSGR.jpg'),
(149040, 10629, 'Date A Live [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/IfZ7oBTHNvIFO9jMdgWk0lRQZ2.jpg'),
(149041, 10629, 'Date A Live [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ycBhqsoTJSmOzhp3g86FF9Hv814.jpg'),
(149042, 10629, 'Date A Live [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fpu31Ul4YGvoWzgWNOFK2WIlWAW.jpg'),
(149043, 10629, 'Date A Live [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qeEgFcO8tBqeschoqq4Nb2ZuJIt.jpg'),
(149044, 10629, 'Date A Live [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k6Ieby3PqFgTaOuM5o8n9O8fEUa.jpg'),
(149045, 10630, 'Date A Live [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4IxxowgZxnreT1Lyiiw5a0oPd8e.jpg'),
(149046, 10630, 'Date A Live [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/emleByRwbaF6OnxoHlfoHRVDeHN.jpg'),
(149047, 10630, 'Date A Live [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gK1dXKD31jehxd7E8X5cOY78D7N.jpg'),
(149048, 10630, 'Date A Live [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9w7XErtvv4jLmSuWqOnQpzCJ6Nt.jpg'),
(149049, 10630, 'Date A Live [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sU4uK9QB4gnXZndsNlUdKHFMp1T.jpg'),
(149050, 10630, 'Date A Live [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wPxyIO2dGN2dl1BzhJWCU5py6L7.jpg'),
(149051, 10630, 'Date A Live [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tXur3Bf6ilqhkCKLfMEA2LOBibf.jpg'),
(149052, 10630, 'Date A Live [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/T2m92D3jKdDUqUl1n4uxjJ6vEm.jpg'),
(149053, 10630, 'Date A Live [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sJhLTFb06au9Yoy6zxKnH8yymOc.jpg'),
(149054, 10630, 'Date A Live [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v63Mjd7T4F9LsBpf3DY6GeVwc9S.jpg'),
(149055, 10630, 'Date A Live [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nXtSm7A8Pk7z32ggz3aMbZ1ESnu.jpg'),
(149056, 10630, 'Date A Live [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/364361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3mk0COu7Htmn8gK0bfYDTw2TEr7.jpg'),
(149057, 10631, 'Date A Live [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mV1Bqw7CWYMBncHqN1Qj71ZC9CW.jpg'),
(149058, 10631, 'Date A Live [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bshTkdfh3sX7u1yLVPN06BPH8xK.jpg'),
(149059, 10631, 'Date A Live [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ytbekoFgel87nt8PZqiTkwo9JRC.jpg'),
(149060, 10631, 'Date A Live [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aJtk1EE6gM5RnUuNf0pRk52DGfN.jpg'),
(149061, 10631, 'Date A Live [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s5jqS8RVdV8la2cQfLJc24LQaCS.jpg'),
(149062, 10631, 'Date A Live [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qCESXcrRKf6Qj8KzRtEAmyTWe6L.jpg'),
(149063, 10631, 'Date A Live [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ptKBQJqiQwo3idIDK5g4Gpb93x.jpg'),
(149064, 10631, 'Date A Live [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCAljH1WuirrI8NTNwzeBJiIv0n.jpg'),
(149065, 10631, 'Date A Live [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x1SayDw9TJndYvvySR1enyH88nU.jpg'),
(149066, 10631, 'Date A Live [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dxfckcq1TFcAcs7HMaetYptYJKj.jpg'),
(149067, 10631, 'Date A Live [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5jyzcpU1Tm3ZclwneiQY3pEGHLj.jpg'),
(149068, 10631, 'Date A Live [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/364373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cUUh6OYeQJQQnAlPrCpZUyjumtk.jpg'),
(149069, 10632, 'Date A Live [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/25iu5XcfnVQXDK6z1JYpvhJ3GEn.jpg'),
(149070, 10632, 'Date A Live [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ytcgUzXholCuF9Ln2XmH87Kcm2.jpg'),
(149071, 10632, 'Date A Live [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/olRLWEJ1k9PcNwpC2esrDHcXt1i.jpg'),
(149072, 10632, 'Date A Live [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhMUk9eFUhR6EdHKNkWAycvnz0x.jpg'),
(149073, 10632, 'Date A Live [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qjxp9TgyHuHMBuUhSYoOwvYavGi.jpg'),
(149074, 10632, 'Date A Live [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cfiU3I7Yjjy5ba5bb1SWzEQugPg.jpg'),
(149075, 10632, 'Date A Live [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tX6UWI1hDa5bV1R90QWFPs3YhDD.jpg'),
(149076, 10632, 'Date A Live [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nSFQFdnMHGq7MtT8Umx70p9JXKR.jpg'),
(149077, 10632, 'Date A Live [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/379941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k6Ieby3PqFgTaOuM5o8n9O8fEUa.jpg'),
(149078, 10632, 'Date A Live [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/383201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k6Ieby3PqFgTaOuM5o8n9O8fEUa.jpg'),
(149079, 10632, 'Date A Live [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/384388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k6Ieby3PqFgTaOuM5o8n9O8fEUa.jpg'),
(149080, 10632, 'Date A Live [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/397173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/k6Ieby3PqFgTaOuM5o8n9O8fEUa.jpg'),
(149081, 10633, 'Florescendo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/41OSC2aFdO24lWSk1Va0BYgvHF0.jpg'),
(149082, 10633, 'Florescendo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vlQnJeqv8VahuGFzcJ9R9bgimRE.jpg'),
(149083, 10633, 'Florescendo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/530T9OhtQkBdfAGxFNxO9VB3EMg.jpg'),
(149084, 10633, 'Florescendo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iC7Mr2wyZckZSGabulMdhyMZqTA.jpg'),
(149085, 10633, 'Florescendo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wD8NqPMxserVyjK6sIzM6tECLOU.jpg'),
(149086, 10633, 'Florescendo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mJVxCn9nQpnevsQIhUxTUtN8G22.jpg'),
(149087, 10633, 'Florescendo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rjg0dDkFxlSIwLAkuaxnaXsvLwT.jpg'),
(149088, 10633, 'Florescendo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ASU8ubCbY8EEIZhld1VK9aRgXQ.jpg'),
(149089, 10633, 'Florescendo [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lfcueHvQTf82sRvpvOw0R1P5RNN.jpg'),
(149090, 10633, 'Florescendo [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2qYvhZs0dR7UajE7EWDTfuLJMyN.jpg'),
(149091, 10633, 'Florescendo [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uwSAUBSXIsLs3WKkQ0Vx7pHMzoB.jpg'),
(149092, 10633, 'Florescendo [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/364299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d3QJAH57nrARaJqpgrUaO7N1daf.jpg'),
(149093, 10633, 'Florescendo [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/364300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jbWJ2772GPr0U1aQwtdUfnkTiE3.jpg'),
(149094, 10633, 'Florescendo [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/364301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xtsekyTncqRKrrEIo4KDruAMILU.jpg'),
(149095, 10633, 'Florescendo [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/364302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7Fj8jRPO8a0shhBxm7wSqxGtZZ.jpg'),
(149096, 10633, 'Florescendo [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/364303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bVI5Ftcyqj3Yah3OgQI1rBVAF6U.jpg'),
(149097, 10633, 'Florescendo [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/364304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p8dItOMxMqP89fHsVThZCr9XQwc.jpg'),
(149098, 10633, 'Florescendo [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/364305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9M3gjVFaRnFICA46NspkumSjIhM.jpg'),
(149099, 10633, 'Florescendo [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/364306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1KiZF3r5cFCyXq14QmQqTdLRMyb.jpg'),
(149100, 10633, 'Florescendo [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/364307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/alhyDROgwZXBjappYGd3r7dTVZ4.jpg'),
(149101, 10633, 'Florescendo [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/364308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7WoPSMMYM5OChfy0PWh3nsCO4Qp.jpg'),
(149102, 10633, 'Florescendo [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/364309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d8EgaEXHnc5FykFmS8sqo7qt4rb.jpg'),
(149103, 10633, 'Florescendo [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/364310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/935WAxii2itONMRw6osSUEtV1OD.jpg'),
(149104, 10633, 'Florescendo [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/364311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cd7fodpoIkbpCDEOM99GQJ26m2H.jpg'),
(149105, 10633, 'Florescendo [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/364312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/snzYOHLmrh8UuuFRscLFkrmZ0Gx.jpg'),
(149106, 10633, 'Florescendo [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/364313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oCKzQvgJ9FpEuzm9d7bXkI4GKAX.jpg'),
(149107, 10633, 'Florescendo [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/364314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/scT4zmUTomZebPIfpM1atJUzm2i.jpg'),
(149108, 10633, 'Florescendo [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/364315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pMl4ag2t5IVJwCgWf2myqEhKdtU.jpg'),
(149109, 10633, 'Florescendo [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/364316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x57XA3OdLutOOcGYs8RhWODRhPj.jpg'),
(149110, 10633, 'Florescendo [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/364317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/DCwLeNyFq5w9syWMPUzHzsgd3c.jpg'),
(149111, 10633, 'Florescendo [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/364318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ylMCSZRVJMovqwPRfBd6c5ZS5sF.jpg'),
(149112, 10633, 'Florescendo [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/364319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uvZ1cwyFr1qm71XB6xFboZBuXvR.jpg'),
(149113, 10634, 'GIRLS BAND CRY [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tl09m8rTN4a1cMzRd7KKuQSSjbf.jpg'),
(149114, 10634, 'GIRLS BAND CRY [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7MD0CpXY0fkchtPkIhkqJ6HCHN.jpg'),
(149115, 10634, 'GIRLS BAND CRY [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7J4ayKC5HdAwjYVTX6lMxjMxxy0.jpg'),
(149116, 10634, 'GIRLS BAND CRY [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7I8FEYhBocNfCv2PG1KIz95LqUv.jpg'),
(149117, 10634, 'GIRLS BAND CRY [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ouAw1kVBUTyS746ngyaNL38cxsl.jpg'),
(149118, 10635, 'Go Go Loser Ranger [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7FArKOV46JCPM8n0dEhw0rCpBZv.jpg'),
(149119, 10635, 'Go Go Loser Ranger [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzqSckBeNnXEe7jIuSNz3QJkfhz.jpg'),
(149120, 10635, 'Go Go Loser Ranger [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dgRtIa6A3bNYQGVMNq8ghhg8qAy.jpg'),
(149121, 10635, 'Go Go Loser Ranger [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6biAKicGcrKmbAr3O9ZfwhP55K6.jpg'),
(149122, 10635, 'Go Go Loser Ranger [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b2zAkxCRVDBdCYNzlsQQIhZsVPK.jpg'),
(149123, 10635, 'Go Go Loser Ranger [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n2IXRTYmY37obhMCxLotFHV2ci8.jpg'),
(149124, 10635, 'Go Go Loser Ranger [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qLZMnkv4S4QRSPK0O9adVSrXUzr.jpg'),
(149125, 10635, 'Go Go Loser Ranger [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/379884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehVlmldQnNdlU3uCjERzqH5A8mk.jpg'),
(149126, 10635, 'Go Go Loser Ranger [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/379885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehVlmldQnNdlU3uCjERzqH5A8mk.jpg'),
(149127, 10635, 'Go Go Loser Ranger [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehVlmldQnNdlU3uCjERzqH5A8mk.jpg'),
(149128, 10635, 'Go Go Loser Ranger [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/392701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehVlmldQnNdlU3uCjERzqH5A8mk.jpg'),
(149129, 10635, 'Go Go Loser Ranger [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/398686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehVlmldQnNdlU3uCjERzqH5A8mk.jpg'),
(149130, 10636, 'Go Go Loser Ranger [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/766783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehVlmldQnNdlU3uCjERzqH5A8mk.jpg'),
(149131, 10636, 'Go Go Loser Ranger [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/776252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehVlmldQnNdlU3uCjERzqH5A8mk.jpg'),
(149132, 10636, 'Go Go Loser Ranger [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/783294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehVlmldQnNdlU3uCjERzqH5A8mk.jpg'),
(149133, 10636, 'Go Go Loser Ranger [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/792988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehVlmldQnNdlU3uCjERzqH5A8mk.jpg'),
(149134, 10636, 'Go Go Loser Ranger [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/796533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehVlmldQnNdlU3uCjERzqH5A8mk.jpg'),
(149135, 10636, 'Go Go Loser Ranger [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/805077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehVlmldQnNdlU3uCjERzqH5A8mk.jpg'),
(149136, 10636, 'Go Go Loser Ranger [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/808425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehVlmldQnNdlU3uCjERzqH5A8mk.jpg'),
(149137, 10636, 'Go Go Loser Ranger [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/819942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehVlmldQnNdlU3uCjERzqH5A8mk.jpg'),
(149138, 10636, 'Go Go Loser Ranger [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/832208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehVlmldQnNdlU3uCjERzqH5A8mk.jpg'),
(149139, 10636, 'Go Go Loser Ranger [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/840937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehVlmldQnNdlU3uCjERzqH5A8mk.jpg'),
(149140, 10636, 'Go Go Loser Ranger [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/848123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehVlmldQnNdlU3uCjERzqH5A8mk.jpg'),
(149141, 10636, 'Go Go Loser Ranger [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/858942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ehVlmldQnNdlU3uCjERzqH5A8mk.jpg'),
(149142, 10637, 'Grandpa and Grandma Turn Young Again [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dOWx3KT1pRjl9lc24050h03XlS7.jpg'),
(149143, 10637, 'Grandpa and Grandma Turn Young Again [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9RkozcHUzp9Nb34dUMoV13Pe0wz.jpg'),
(149144, 10637, 'Grandpa and Grandma Turn Young Again [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hAkOrIw17AQflevEFh7IXqRbm10.jpg'),
(149145, 10637, 'Grandpa and Grandma Turn Young Again [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d2vKaloSek9qgEAOzOo9P4r6x9T.jpg'),
(149146, 10637, 'Grandpa and Grandma Turn Young Again [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5CwMuOo4eAUjWamnd5zdA1gSuFK.jpg'),
(149147, 10637, 'Grandpa and Grandma Turn Young Again [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/VwUhQUk6bgsjeyWnIlGG196l90.jpg'),
(149148, 10637, 'Grandpa and Grandma Turn Young Again [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/610bKm2UU2bzWkxwoej9FYqu7NP.jpg'),
(149149, 10637, 'Grandpa and Grandma Turn Young Again [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/379875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pfiHJ5l67ptZSStHFaFdAppd5kZ.jpg'),
(149150, 10637, 'Grandpa and Grandma Turn Young Again [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/379876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pfiHJ5l67ptZSStHFaFdAppd5kZ.jpg'),
(149151, 10637, 'Grandpa and Grandma Turn Young Again [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pfiHJ5l67ptZSStHFaFdAppd5kZ.jpg'),
(149152, 10638, 'HIGHSPEED Etoile [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4SHwhk5BzaH2xTQbYwebFclof4H.jpg'),
(149153, 10638, 'HIGHSPEED Etoile [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aCn1wR4DMmVScLSOJ1fxHB3xLph.jpg'),
(149154, 10638, 'HIGHSPEED Etoile [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pcACo5MOiRQS8ALKtD2TexXMuEr.jpg'),
(149155, 10638, 'HIGHSPEED Etoile [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zVih5IAJ7ceoKr752zdlCFBmV20.jpg'),
(149156, 10638, 'HIGHSPEED Etoile [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6XCXZMZxG4aieDBAKzjtNNq44eo.jpg'),
(149157, 10638, 'HIGHSPEED Etoile [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j580CZoRr3kwe8KHbbpQKMbHbZV.jpg'),
(149158, 10638, 'HIGHSPEED Etoile [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/35ptQrmzKPCK00Z0jIGy6CqMgrg.jpg'),
(149159, 10638, 'HIGHSPEED Etoile [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5XObnQOHQcP0RrVwun077uO2gUM.jpg'),
(149160, 10638, 'HIGHSPEED Etoile [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/379865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPvEzlhKAEycts5WzDE9CNDAtqp.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(149161, 10638, 'HIGHSPEED Etoile [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/379866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPvEzlhKAEycts5WzDE9CNDAtqp.jpg'),
(149162, 10638, 'HIGHSPEED Etoile [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/383740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPvEzlhKAEycts5WzDE9CNDAtqp.jpg'),
(149163, 10638, 'HIGHSPEED Etoile [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/392690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xPvEzlhKAEycts5WzDE9CNDAtqp.jpg'),
(149164, 10639, 'Handyman Saitou in another world [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ruvotA2szVJfCi19KN2UvKYq7Lj.jpg'),
(149165, 10639, 'Handyman Saitou in another world [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qeFNLGWylDtP9O7KpcGzY0HyRc2.jpg'),
(149166, 10639, 'Handyman Saitou in another world [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dp0BoHqFpd07AtAtaMR3BgwuixK.jpg'),
(149167, 10639, 'Handyman Saitou in another world [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jflGrsimStu2Laoptkw0vAXZyAS.jpg'),
(149168, 10639, 'Handyman Saitou in another world [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bQAwd7irazTyMLTrdb56jmInJOd.jpg'),
(149169, 10639, 'Handyman Saitou in another world [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dmQBOatCS9Z3bOZJD2jG5l2Vjpj.jpg'),
(149170, 10639, 'Handyman Saitou in another world [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9GKG78m6u21qs3iffrUakAOBJIs.jpg'),
(149171, 10639, 'Handyman Saitou in another world [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1dHhhCv1de22XvW78DRza4HOWzc.jpg'),
(149172, 10639, 'Handyman Saitou in another world [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/babecBCbmH8heexnYXKfp1wn4HE.jpg'),
(149173, 10639, 'Handyman Saitou in another world [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bdbGL1roPJkFtTnpdE1BQO83yr5.jpg'),
(149174, 10639, 'Handyman Saitou in another world [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lKdjtwejQH1YAYzUbdJAhIen3V8.jpg'),
(149175, 10639, 'Handyman Saitou in another world [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/364260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3dXSYqkggPQw1CFsnmQbjHeDBvN.jpg'),
(149176, 10640, 'Lolla A Historia do Lollapalooza [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEipzzNEv5UNBfE4b0GFSONU8G9.jpg'),
(149177, 10640, 'Lolla A Historia do Lollapalooza [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iLb7YNOUq0DopRstw4YgnRHEAgW.jpg'),
(149178, 10640, 'Lolla A Historia do Lollapalooza [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f47OxK6yIlAW5sUTzTZe1AlgpH5.jpg'),
(149179, 10641, 'Montecristo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jNAj1abNptWALTxZUOqwGP3ngEb.jpg'),
(149180, 10641, 'Montecristo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ftcQyvnnboqHsUVO8L2GnksX6UX.jpg'),
(149181, 10641, 'Montecristo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5JjEAkYm2fBp68topGegZ93W1vi.jpg'),
(149182, 10641, 'Montecristo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnTEQbe99ddp1pouTjXuhhSTPHG.jpg'),
(149183, 10641, 'Montecristo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8wgnsGAwMOVyBaZnNpRRJOg6bl7.jpg'),
(149184, 10641, 'Montecristo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1CTxKJlKXeWAIwhzi9qIarTqCbI.jpg'),
(149185, 10642, 'Mysterious Disappearances [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Xbfpa9FY5YjkDInWTUF5rXGvtg.jpg'),
(149186, 10642, 'Mysterious Disappearances [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8DIC8AxMlyYMTVrJiW25ZUMh7Pq.jpg'),
(149187, 10642, 'Mysterious Disappearances [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9mMTL9BBiIlnZDhgFkmqeOBTkai.jpg'),
(149188, 10642, 'Mysterious Disappearances [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/39F38R7QDQoE4XZN4zuBR8iHhQA.jpg'),
(149189, 10642, 'Mysterious Disappearances [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wgj6TLf8wUPKF1JtmW1zMJFoxbc.jpg'),
(149190, 10642, 'Mysterious Disappearances [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ebF8uZoOuCQCVDnON0avU33F2tw.jpg'),
(149191, 10642, 'Mysterious Disappearances [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gkGAcWVaRJNzbvxzece5sLPK4MU.jpg'),
(149192, 10642, 'Mysterious Disappearances [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/379775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ok245ByWj1VrZI80pmtm0EwDmd.jpg'),
(149193, 10642, 'Mysterious Disappearances [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/379776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ok245ByWj1VrZI80pmtm0EwDmd.jpg'),
(149194, 10642, 'Mysterious Disappearances [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/382491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ok245ByWj1VrZI80pmtm0EwDmd.jpg'),
(149195, 10642, 'Mysterious Disappearances [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/389493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ok245ByWj1VrZI80pmtm0EwDmd.jpg'),
(149196, 10642, 'Mysterious Disappearances [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/396412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ok245ByWj1VrZI80pmtm0EwDmd.jpg'),
(149197, 10643, 'Nijiyon Animation [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHz2A8azAbYy30mIIj5eFTyu27V.jpg'),
(149198, 10643, 'Nijiyon Animation [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qRYnIiPba6akTLgfmSLJqXuqdZX.jpg'),
(149199, 10643, 'Nijiyon Animation [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yF79gNWcFUS01qXNIMrqbq2pF28.jpg'),
(149200, 10643, 'Nijiyon Animation [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cwR51Dpk4xNgE0T51XLF931isNX.jpg'),
(149201, 10643, 'Nijiyon Animation [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zUgvFQFvNxl9iH7gkxiSck09HIf.jpg'),
(149202, 10643, 'Nijiyon Animation [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iLP4bgKOXMZ0vuiBuObUOjYHpg9.jpg'),
(149203, 10643, 'Nijiyon Animation [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kwxmwnDXx2B0zMvHKsLnrPkgAhl.jpg'),
(149204, 10643, 'Nijiyon Animation [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yVktKHSZg4fmLUtw3nSQX3YxCdH.jpg'),
(149205, 10643, 'Nijiyon Animation [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1je7oV81PIgOxlc5myM6Vx1urkN.jpg'),
(149206, 10643, 'Nijiyon Animation [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ypYP1VB8HmQP1p39mpEdIlmz2Y.jpg'),
(149207, 10643, 'Nijiyon Animation [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qw6HkP8E2DMyvGA8BjRi6HHWWo5.jpg'),
(149208, 10643, 'Nijiyon Animation [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/364224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8N2mHy1rgnIM13pIk3mmfVjrtCK.jpg'),
(149209, 10644, 'Nijiyon Animation [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w4HRxqbrDanMTDTsZc9UHVQBhKp.jpg'),
(149210, 10644, 'Nijiyon Animation [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/avAGRckKePaJbXcnzD9us9zaYGu.jpg'),
(149211, 10644, 'Nijiyon Animation [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5vg2AyzDMzIzA5YuAyJixi35fx3.jpg'),
(149212, 10644, 'Nijiyon Animation [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/leLgvvOvWSdSMtE3sZqaj70ienS.jpg'),
(149213, 10644, 'Nijiyon Animation [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kRSE5TdoaeQZwDK9KFSXH5LE9f5.jpg'),
(149214, 10644, 'Nijiyon Animation [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r9UYOyirhSmUDCd6Aai2SQF3v3b.jpg'),
(149215, 10644, 'Nijiyon Animation [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yU0oORTj01uBk3cni98EMzuUKPD.jpg'),
(149216, 10644, 'Nijiyon Animation [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nWpgci1YswqK0yrRrTErjoYqcR0.jpg'),
(149217, 10644, 'Nijiyon Animation [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/379766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eXd1W47yx3u7ZcFQ8rhwjp9omJo.jpg'),
(149218, 10644, 'Nijiyon Animation [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/379767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eXd1W47yx3u7ZcFQ8rhwjp9omJo.jpg'),
(149219, 10644, 'Nijiyon Animation [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/382020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eXd1W47yx3u7ZcFQ8rhwjp9omJo.jpg'),
(149220, 10644, 'Nijiyon Animation [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/395914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eXd1W47yx3u7ZcFQ8rhwjp9omJo.jpg'),
(149221, 10645, 'O Casamento Proibido [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lP7eb9ED5txekKttdHjvVPIAYXW.jpg'),
(149222, 10645, 'O Casamento Proibido [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gcFEcZHfj4KpfNZjaf0RKfo3Qe4.jpg'),
(149223, 10645, 'O Casamento Proibido [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hKBEpkT0WVZukvt0qdnDUFFMLPX.jpg'),
(149224, 10645, 'O Casamento Proibido [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yAhYF5OnyzMgxw1PehZMayRF1Mj.jpg'),
(149225, 10645, 'O Casamento Proibido [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ccT0Qg7eQB3qvOAC5BmB6RM9vfQ.jpg'),
(149226, 10645, 'O Casamento Proibido [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSAKI9UiLa6Ib5sz9NPDaPRupeb.jpg'),
(149227, 10645, 'O Casamento Proibido [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jdQ6QZ4iWwodGh6rLnXSdjrGgui.jpg'),
(149228, 10645, 'O Casamento Proibido [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3fLN2tHve0FICdkfex6IAgFndrr.jpg'),
(149229, 10645, 'O Casamento Proibido [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wfuZihu2HQYKvU9FSV2BvsAj01N.jpg'),
(149230, 10645, 'O Casamento Proibido [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f69oPLbvfYHOvr3tDuE0J5FpFPU.jpg'),
(149231, 10645, 'O Casamento Proibido [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f69oPLbvfYHOvr3tDuE0J5FpFPU.jpg'),
(149232, 10645, 'O Casamento Proibido [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/364212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f69oPLbvfYHOvr3tDuE0J5FpFPU.jpg'),
(149233, 10646, 'Oblivion Battery [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rDzo46nsY1sYFU0UVryT1pzyzKo.jpg'),
(149234, 10646, 'Oblivion Battery [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mCdosQD9v0fAuyG9ENQTYLyZZWM.jpg'),
(149235, 10646, 'Oblivion Battery [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/naZua5cgjH1AjbfGu3E6DNmpXWW.jpg'),
(149236, 10646, 'Oblivion Battery [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jqhi6txYiRdnoXbdtcebwSz0U57.jpg'),
(149237, 10646, 'Oblivion Battery [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hHsIWpVTwbAQDcsQn2RBdMMvxay.jpg'),
(149238, 10646, 'Oblivion Battery [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/orgqPvT9GfXF3yhFwl3loaPhRZw.jpg'),
(149239, 10646, 'Oblivion Battery [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/epwcTSq3lpPtK1c9BJ3VN5svYD8.jpg'),
(149240, 10646, 'Oblivion Battery [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/379739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6mhVHKDOchX5xvVV2QXZAwnCHZQ.jpg'),
(149241, 10646, 'Oblivion Battery [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/381918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6mhVHKDOchX5xvVV2QXZAwnCHZQ.jpg'),
(149242, 10646, 'Oblivion Battery [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/388933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6mhVHKDOchX5xvVV2QXZAwnCHZQ.jpg'),
(149243, 10646, 'Oblivion Battery [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/395790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6mhVHKDOchX5xvVV2QXZAwnCHZQ.jpg'),
(149244, 10646, 'Oblivion Battery [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/400499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6mhVHKDOchX5xvVV2QXZAwnCHZQ.jpg'),
(149245, 10647, 'Our Dating Story The Experienced You and The Inexperienced Me [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gtvPdtzu95MXRSgFKMYuCeb8Bkr.jpg'),
(149246, 10647, 'Our Dating Story The Experienced You and The Inexperienced Me [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hgisv1LTizJ2Fo3HVroW1eneFFP.jpg'),
(149247, 10647, 'Our Dating Story The Experienced You and The Inexperienced Me [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zEb6Umyxls1Xh3TTZu9LcKYOwhJ.jpg'),
(149248, 10647, 'Our Dating Story The Experienced You and The Inexperienced Me [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9TGuvrMQuBIt0cLj4xmAPnNiDBc.jpg'),
(149249, 10647, 'Our Dating Story The Experienced You and The Inexperienced Me [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xpP8b5fVOeSouDPZa0kqY7ph5ux.jpg'),
(149250, 10647, 'Our Dating Story The Experienced You and The Inexperienced Me [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ir61DaFPnkGdnCtZKU0iUYBTsHw.jpg'),
(149251, 10647, 'Our Dating Story The Experienced You and The Inexperienced Me [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vDm6rTKCkHSdawWwCmIiWgNNJFJ.jpg'),
(149252, 10647, 'Our Dating Story The Experienced You and The Inexperienced Me [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZkNIKWhD9AH1U4vdu5xT4uU359.jpg'),
(149253, 10647, 'Our Dating Story The Experienced You and The Inexperienced Me [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/el0wpbyWfxPrhYv2V63ysxuB2tk.jpg'),
(149254, 10647, 'Our Dating Story The Experienced You and The Inexperienced Me [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xKQd6TcqcLWjYkzGrhamWqQMdsh.jpg'),
(149255, 10647, 'Our Dating Story The Experienced You and The Inexperienced Me [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gvSCIvVd3aDJBrBdcwvXJoNm4jZ.jpg'),
(149256, 10647, 'Our Dating Story The Experienced You and The Inexperienced Me [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/364193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vEQDHDv5DSIHVQWbNQlazhWg0GA.jpg'),
(149257, 10648, 'Red Eye [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w34GSXanQPKyWsS5HfXZ7PAX8Vv.jpg'),
(149258, 10648, 'Red Eye [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/irYUmIQMHXatUc5CechvDqQey5.jpg'),
(149259, 10648, 'Red Eye [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v12koz1EfeMn4kCNY2Igr3Bavju.jpg'),
(149260, 10648, 'Red Eye [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/379677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9q0bue4rFLxuyOIbBzo7Z83NrK.jpg'),
(149261, 10648, 'Red Eye [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/609147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9q0bue4rFLxuyOIbBzo7Z83NrK.jpg'),
(149262, 10648, 'Red Eye [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/394325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9q0bue4rFLxuyOIbBzo7Z83NrK.jpg'),
(149263, 10649, 'The Midnight Romance in Hagwon [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pDvOJOUzntuGMgxn1MMOvYDQWWH.jpg'),
(149264, 10649, 'The Midnight Romance in Hagwon [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tXQGV70cvRb885qB77ZFLrGiGAY.jpg'),
(149265, 10649, 'The Midnight Romance in Hagwon [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tCwshzM2ZEut3AnY8ic3aobf8Wg.jpg'),
(149266, 10649, 'The Midnight Romance in Hagwon [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kj8F11tpELiqSCepiddoiz5kTKV.jpg'),
(149267, 10649, 'The Midnight Romance in Hagwon [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQkQY9GVUsrECt2WISMg5fiBR0l.jpg'),
(149268, 10649, 'The Midnight Romance in Hagwon [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364178.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tqNJvDQwZFwfoRFB3cszA4e2eaN.jpg'),
(149269, 10649, 'The Midnight Romance in Hagwon [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/379258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yetZahu9fS9ACWAsNUdSBu51M59.jpg'),
(149270, 10649, 'The Midnight Romance in Hagwon [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/379259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yetZahu9fS9ACWAsNUdSBu51M59.jpg'),
(149271, 10649, 'The Midnight Romance in Hagwon [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/383876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yetZahu9fS9ACWAsNUdSBu51M59.jpg'),
(149272, 10649, 'The Midnight Romance in Hagwon [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/383877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yetZahu9fS9ACWAsNUdSBu51M59.jpg'),
(149273, 10649, 'The Midnight Romance in Hagwon [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/388357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yetZahu9fS9ACWAsNUdSBu51M59.jpg'),
(149274, 10649, 'The Midnight Romance in Hagwon [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/388358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yetZahu9fS9ACWAsNUdSBu51M59.jpg'),
(149275, 10649, 'The Midnight Romance in Hagwon [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/390827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yetZahu9fS9ACWAsNUdSBu51M59.jpg'),
(149276, 10649, 'The Midnight Romance in Hagwon [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/390828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yetZahu9fS9ACWAsNUdSBu51M59.jpg'),
(149277, 10649, 'The Midnight Romance in Hagwon [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/398430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yetZahu9fS9ACWAsNUdSBu51M59.jpg'),
(149278, 10649, 'The Midnight Romance in Hagwon [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/398431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yetZahu9fS9ACWAsNUdSBu51M59.jpg'),
(149279, 10650, 'The Responder [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qhIf57VNFqNTMeRNTasJf4FnPyi.jpg'),
(149280, 10650, 'The Responder [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hbLbhCZnvLZz9oi1yqfc3ofBGA1.jpg'),
(149281, 10650, 'The Responder [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/379247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9rG7UmjRCtSgHq8QzW07Drdq9HB.jpg'),
(149282, 10650, 'The Responder [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/379248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9rG7UmjRCtSgHq8QzW07Drdq9HB.jpg'),
(149283, 10650, 'The Responder [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/379249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9rG7UmjRCtSgHq8QzW07Drdq9HB.jpg'),
(149284, 10651, 'The Responder [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1dR1RgM6YBOGWdHcy9MNgmKwd29.jpg'),
(149285, 10651, 'The Responder [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/379251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9rG7UmjRCtSgHq8QzW07Drdq9HB.jpg'),
(149286, 10651, 'The Responder [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/388346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9rG7UmjRCtSgHq8QzW07Drdq9HB.jpg'),
(149287, 10651, 'The Responder [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9rG7UmjRCtSgHq8QzW07Drdq9HB.jpg'),
(149288, 10651, 'The Responder [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9rG7UmjRCtSgHq8QzW07Drdq9HB.jpg'),
(149289, 10652, 'Tio Samsik [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lnoF7p08RVwyXHcthbk5OnmDOuj.jpg'),
(149290, 10652, 'Tio Samsik [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9rJ2DjU3Lo77KINzQdrQ0HVYzXe.jpg'),
(149291, 10652, 'Tio Samsik [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lLcQMtkWhbpBJMR3LhMBf5Z77W4.jpg'),
(149292, 10652, 'Tio Samsik [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oLrwXksUP2elvYXBkOh5gnpR5hZ.jpg'),
(149293, 10652, 'Tio Samsik [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lNbPpKlOp3yvD70EUCYFBmttQMk.jpg'),
(149294, 10652, 'Tio Samsik [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d1fvyZ0TLM3LmEX5sxHiTXhZXQW.jpg'),
(149295, 10652, 'Tio Samsik [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dEG8bqE16RCMS4yZn1V4FtD9ef8.jpg'),
(149296, 10652, 'Tio Samsik [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7bxnuBoTY89U9PXx4TXSKVvlciO.jpg'),
(149297, 10652, 'Tio Samsik [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4k5HK8uoT3HwvHEPYm2waCogmDK.jpg'),
(149298, 10652, 'Tio Samsik [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/379243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSs7Ru92T0SruR1rSDtuna0dezF.jpg'),
(149299, 10652, 'Tio Samsik [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/379244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSs7Ru92T0SruR1rSDtuna0dezF.jpg'),
(149300, 10652, 'Tio Samsik [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/388334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSs7Ru92T0SruR1rSDtuna0dezF.jpg'),
(149301, 10652, 'Tio Samsik [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/388335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSs7Ru92T0SruR1rSDtuna0dezF.jpg'),
(149302, 10652, 'Tio Samsik [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/388336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSs7Ru92T0SruR1rSDtuna0dezF.jpg'),
(149303, 10652, 'Tio Samsik [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/388337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSs7Ru92T0SruR1rSDtuna0dezF.jpg'),
(149304, 10652, 'Tio Samsik [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/388338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mSs7Ru92T0SruR1rSDtuna0dezF.jpg'),
(149305, 10653, 'Tonari no Yokai San [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ecLRumBmBaXO3g9vJYu1CnDme4.jpg'),
(149306, 10653, 'Tonari no Yokai San [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Wa5KQHKHZ5SiGzBY9PkpeY1Y6w.jpg'),
(149307, 10653, 'Tonari no Yokai San [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ZjksI3VMb3JgXLsCciP0GjVqq.jpg'),
(149308, 10653, 'Tonari no Yokai San [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/acezqjSZIntb700CKIQJYOgikfx.jpg'),
(149309, 10653, 'Tonari no Yokai San [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FmOoMhBqpUKkM0MZvck83axhPc.jpg'),
(149310, 10653, 'Tonari no Yokai San [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Hbs0DPvQmfoMqipJbEuhN6rW7X.jpg'),
(149311, 10653, 'Tonari no Yokai San [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfp3jAsellyHBY3gQNNPuhmgXdY.jpg'),
(149312, 10653, 'Tonari no Yokai San [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z87EyKR6J7BoiGaZZB8JH4gZE3a.jpg'),
(149313, 10653, 'Tonari no Yokai San [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/379232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e0mes3mZNJsaNOQTFbytDFweIJF.jpg'),
(149314, 10653, 'Tonari no Yokai San [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/379233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e0mes3mZNJsaNOQTFbytDFweIJF.jpg'),
(149315, 10653, 'Tonari no Yokai San [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/388322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e0mes3mZNJsaNOQTFbytDFweIJF.jpg'),
(149316, 10653, 'Tonari no Yokai San [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e0mes3mZNJsaNOQTFbytDFweIJF.jpg'),
(149317, 10653, 'Tonari no Yokai San [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/400065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e0mes3mZNJsaNOQTFbytDFweIJF.jpg'),
(149318, 10654, 'Touken Ranbu [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6xRyeDgOjlCKCicHZdKUCIEltYl.jpg'),
(149319, 10654, 'Touken Ranbu [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6UxP2uzdcceUIr4YAyY3fuUZvEE.jpg'),
(149320, 10654, 'Touken Ranbu [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6EFoD31H2vGr1DkS3sn7NImg84f.jpg'),
(149321, 10654, 'Touken Ranbu [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/SQzvk5pdTzuRiM7wh7xMPRjDur.jpg'),
(149322, 10654, 'Touken Ranbu [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cY7H6esAOJ9CBkZWVCUH0EpdCKW.jpg'),
(149323, 10654, 'Touken Ranbu [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3zDUgHOTJXI2dBZRcXc75FYrM4k.jpg'),
(149324, 10654, 'Touken Ranbu [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ioOIAZq1Qn5rHs4B0tNT4NlNgTC.jpg'),
(149325, 10654, 'Touken Ranbu [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3jkCR6bjbLLt4fwz8qnU1H9gjQm.jpg'),
(149326, 10654, 'Touken Ranbu [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i9WhVHKRWzEynPfksVBFPz3dNjs.jpg'),
(149327, 10654, 'Touken Ranbu [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ePObjeuJnYbCljOyMAvSS9gzkwQ.jpg'),
(149328, 10654, 'Touken Ranbu [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oWlz8QizszYkMCb3JHvw9Z0bJxb.jpg'),
(149329, 10654, 'Touken Ranbu [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/364119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yAC1Ph3V3lJvEcZmWtwwNHFFO15.jpg'),
(149330, 10654, 'Touken Ranbu [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/364120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eFBpaEV1iwXvjl6pbDx94zr1RBk.jpg'),
(149331, 10655, 'Touken Ranbu [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149332, 10655, 'Touken Ranbu [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149333, 10655, 'Touken Ranbu [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149334, 10655, 'Touken Ranbu [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149335, 10655, 'Touken Ranbu [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149336, 10655, 'Touken Ranbu [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149337, 10655, 'Touken Ranbu [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149338, 10655, 'Touken Ranbu [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149339, 10655, 'Touken Ranbu [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149340, 10655, 'Touken Ranbu [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149341, 10655, 'Touken Ranbu [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149342, 10655, 'Touken Ranbu [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/364132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149343, 10656, 'Touken Ranbu [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149344, 10656, 'Touken Ranbu [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149345, 10656, 'Touken Ranbu [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149346, 10656, 'Touken Ranbu [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149347, 10656, 'Touken Ranbu [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149348, 10656, 'Touken Ranbu [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149349, 10656, 'Touken Ranbu [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149350, 10656, 'Touken Ranbu [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149351, 10656, 'Touken Ranbu [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149352, 10656, 'Touken Ranbu [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149353, 10656, 'Touken Ranbu [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149354, 10656, 'Touken Ranbu [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/364144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149355, 10657, 'Touken Ranbu [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149356, 10657, 'Touken Ranbu [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149357, 10657, 'Touken Ranbu [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149358, 10657, 'Touken Ranbu [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149359, 10657, 'Touken Ranbu [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149360, 10657, 'Touken Ranbu [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149361, 10657, 'Touken Ranbu [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149362, 10657, 'Touken Ranbu [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5XEP1Zj3yK5oPbfoAMt0gnw7YC8.jpg'),
(149363, 10658, 'Unnamed Memory [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364101.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f8XRQAvYXIHDIOwmlGqeihABXGP.jpg'),
(149364, 10658, 'Unnamed Memory [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/33T4pe82JeLKj5ijhUAm5ADOFV5.jpg'),
(149365, 10658, 'Unnamed Memory [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ugYvuq4wVybRSGJedNo9d6bTdA.jpg'),
(149366, 10658, 'Unnamed Memory [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c3wUDuRtvH8bR8vhy1xSiOZte5x.jpg'),
(149367, 10658, 'Unnamed Memory [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mdxiZBra1d7m6dX2bghreyfb4kd.jpg'),
(149368, 10658, 'Unnamed Memory [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aKTewR6bs4mUSwHlILT64SOxlPM.jpg'),
(149369, 10658, 'Unnamed Memory [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fRaFMvZOZ9YCcCd6BZ2baAE24ut.jpg'),
(149370, 10658, 'Unnamed Memory [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/379222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2h67cW61TtPdl6R41TkbTJv4Xiz.jpg'),
(149371, 10658, 'Unnamed Memory [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/379223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2h67cW61TtPdl6R41TkbTJv4Xiz.jpg'),
(149372, 10658, 'Unnamed Memory [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/383811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2h67cW61TtPdl6R41TkbTJv4Xiz.jpg'),
(149373, 10658, 'Unnamed Memory [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/388281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2h67cW61TtPdl6R41TkbTJv4Xiz.jpg'),
(149374, 10658, 'Unnamed Memory [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/393935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2h67cW61TtPdl6R41TkbTJv4Xiz.jpg'),
(149375, 10659, 'Unnamed Memory [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/661279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2h67cW61TtPdl6R41TkbTJv4Xiz.jpg'),
(149376, 10659, 'Unnamed Memory [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/667168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2h67cW61TtPdl6R41TkbTJv4Xiz.jpg'),
(149377, 10659, 'Unnamed Memory [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/671193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2h67cW61TtPdl6R41TkbTJv4Xiz.jpg'),
(149378, 10659, 'Unnamed Memory [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/678216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2h67cW61TtPdl6R41TkbTJv4Xiz.jpg'),
(149379, 10659, 'Unnamed Memory [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/684995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2h67cW61TtPdl6R41TkbTJv4Xiz.jpg'),
(149380, 10659, 'Unnamed Memory [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/692620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2h67cW61TtPdl6R41TkbTJv4Xiz.jpg'),
(149381, 10659, 'Unnamed Memory [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/700494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2h67cW61TtPdl6R41TkbTJv4Xiz.jpg'),
(149382, 10659, 'Unnamed Memory [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/708275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2h67cW61TtPdl6R41TkbTJv4Xiz.jpg'),
(149383, 10659, 'Unnamed Memory [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/722877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2h67cW61TtPdl6R41TkbTJv4Xiz.jpg'),
(149384, 10659, 'Unnamed Memory [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/731961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2h67cW61TtPdl6R41TkbTJv4Xiz.jpg'),
(149385, 10659, 'Unnamed Memory [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/731962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2h67cW61TtPdl6R41TkbTJv4Xiz.jpg'),
(149386, 10659, 'Unnamed Memory [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/739682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2h67cW61TtPdl6R41TkbTJv4Xiz.jpg'),
(149387, 10660, 'Usagi Drop [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364090.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o0K11QsgVQjYfbKF8uQTljJQpjk.jpg'),
(149388, 10660, 'Usagi Drop [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364091.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uiSEG34iSF2DgzDGjH911iubMX.jpg'),
(149389, 10660, 'Usagi Drop [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/miJQOL5XSReLO5XXzpAUm9v9VXc.jpg'),
(149390, 10660, 'Usagi Drop [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sBPOpYDPl52p6DU9p5a2XleGyVb.jpg'),
(149391, 10660, 'Usagi Drop [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fwgZfP5CWHGI4frmUHOFioAzuI1.jpg'),
(149392, 10660, 'Usagi Drop [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2TI85dIVu2Y2KElGid36jwmjMLK.jpg'),
(149393, 10660, 'Usagi Drop [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ronUhLQGYlHAzlIswIS4jacw4tW.jpg'),
(149394, 10660, 'Usagi Drop [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364097.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uBZBKqeXOGf7z0xZ1Jt9TfalC8P.jpg'),
(149395, 10660, 'Usagi Drop [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/364098.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bNJOw759FcMWHzVG4BHqz1P1amD.jpg'),
(149396, 10660, 'Usagi Drop [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/364099.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v0m4NWqeq7TSr2bBUgLJdb1ZbPU.jpg'),
(149397, 10660, 'Usagi Drop [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/364100.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m1EZV8mJWUK2G6ZoNMrAgI7NUsj.jpg'),
(149398, 10661, 'Vampire Dormitory [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364083.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dIaOFwZIfSHbi9UnmgBJjHQT4NM.jpg'),
(149399, 10661, 'Vampire Dormitory [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364084.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oRXkGYybmlZwjEpW3CPktbTQn9N.jpg'),
(149400, 10661, 'Vampire Dormitory [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364085.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9vG5EpbekRbR2nPmLSZloTCqy6r.jpg'),
(149401, 10661, 'Vampire Dormitory [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364086.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9cYbxtDuqNmCFSIVy3nawcreXGm.jpg'),
(149402, 10661, 'Vampire Dormitory [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364087.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/15pXuyb4kvGRZCrf0MUrk6ybwFl.jpg'),
(149403, 10661, 'Vampire Dormitory [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364088.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tiet2A7riROH0EbzzGDtbhVa869.jpg'),
(149404, 10661, 'Vampire Dormitory [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364089.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6MRAgNVXgVCHXU7BiLDBAOOVUqc.jpg'),
(149405, 10661, 'Vampire Dormitory [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/379212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/22c8lGyJv5fph12Wk518spTjPFo.jpg'),
(149406, 10661, 'Vampire Dormitory [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/379213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/22c8lGyJv5fph12Wk518spTjPFo.jpg'),
(149407, 10661, 'Vampire Dormitory [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/379214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/22c8lGyJv5fph12Wk518spTjPFo.jpg'),
(149408, 10661, 'Vampire Dormitory [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/388270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/22c8lGyJv5fph12Wk518spTjPFo.jpg'),
(149409, 10661, 'Vampire Dormitory [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/22c8lGyJv5fph12Wk518spTjPFo.jpg'),
(149410, 10662, 'Viral Hit [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/609050.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xG54T2JtsnR9qSg2nLQMoLghkRs.jpg'),
(149411, 10662, 'Viral Hit [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/609052.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sQzxNB9zNNBdkw7qhmlO2WIhdlT.jpg'),
(149412, 10662, 'Viral Hit [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/609054.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x4B0IvkcxKTH8Pz640yITsjc8W8.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(149413, 10662, 'Viral Hit [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/609056.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kXMKdzCLBiHshpDDdcUAWC3xrz1.jpg'),
(149414, 10662, 'Viral Hit [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/609058.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3PENBE4BoNN2v7uDkns9GTapmLW.jpg'),
(149415, 10662, 'Viral Hit [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/609060.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kJJJc7xSEFN02NQuupGVTs1M41c.jpg'),
(149416, 10662, 'Viral Hit [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/609062.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xYGbuqpmYmuzYbHYIP1jQ55n1oL.jpg'),
(149417, 10662, 'Viral Hit [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/364082.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hK9LA9x37AI2oWHJgOwhS07tUS3.jpg'),
(149418, 10662, 'Viral Hit [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/379194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/biUCx1p4dAImAuqti1caxqKVzE7.jpg'),
(149419, 10662, 'Viral Hit [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/383801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/biUCx1p4dAImAuqti1caxqKVzE7.jpg'),
(149420, 10662, 'Viral Hit [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/388259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/biUCx1p4dAImAuqti1caxqKVzE7.jpg'),
(149421, 10662, 'Viral Hit [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/393923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/biUCx1p4dAImAuqti1caxqKVzE7.jpg'),
(149422, 10663, 'YATAGARASU The Raven Does Not Choose Its Master [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/369835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7h8yk2tWLYU5h9wMQCGoyx2y1dh.jpg'),
(149423, 10663, 'YATAGARASU The Raven Does Not Choose Its Master [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/369836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rzzN0oP4k5uQkOYMk36LDL81DTW.jpg'),
(149424, 10663, 'YATAGARASU The Raven Does Not Choose Its Master [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/369837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJ3cV2xTBauRobg0biM9156msrd.jpg'),
(149425, 10663, 'YATAGARASU The Raven Does Not Choose Its Master [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/369838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yUoCBC6fVU36XVY8IuD8yL8TZiL.jpg'),
(149426, 10663, 'YATAGARASU The Raven Does Not Choose Its Master [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/369839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDtHqYqm77pfHASSSSd1JRridgi.jpg'),
(149427, 10663, 'YATAGARASU The Raven Does Not Choose Its Master [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/369840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2vluwZqR9jJnH2O9lXWpNwUocij.jpg'),
(149428, 10663, 'YATAGARASU The Raven Does Not Choose Its Master [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/369841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zVQHayl6vLSLxEYalnK1ElqP4GZ.jpg'),
(149429, 10663, 'YATAGARASU The Raven Does Not Choose Its Master [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/369842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/41H0QjevOE6M0mS2Y5AAKtbziOI.jpg'),
(149430, 10663, 'YATAGARASU The Raven Does Not Choose Its Master [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/379176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zBu8G5vARl1i9omZ4AEXpXh9N14.jpg'),
(149431, 10663, 'YATAGARASU The Raven Does Not Choose Its Master [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/379177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zBu8G5vARl1i9omZ4AEXpXh9N14.jpg'),
(149432, 10663, 'YATAGARASU The Raven Does Not Choose Its Master [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/388228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zBu8G5vARl1i9omZ4AEXpXh9N14.jpg'),
(149433, 10663, 'YATAGARASU The Raven Does Not Choose Its Master [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zBu8G5vARl1i9omZ4AEXpXh9N14.jpg'),
(149434, 10663, 'YATAGARASU The Raven Does Not Choose Its Master [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/400020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zBu8G5vARl1i9omZ4AEXpXh9N14.jpg'),
(149435, 10663, 'YATAGARASU The Raven Does Not Choose Its Master [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/415505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zBu8G5vARl1i9omZ4AEXpXh9N14.jpg'),
(149436, 10663, 'YATAGARASU The Raven Does Not Choose Its Master [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/432879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zBu8G5vARl1i9omZ4AEXpXh9N14.jpg'),
(149437, 10663, 'YATAGARASU The Raven Does Not Choose Its Master [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/438462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zBu8G5vARl1i9omZ4AEXpXh9N14.jpg'),
(149438, 10663, 'YATAGARASU The Raven Does Not Choose Its Master [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/445495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zBu8G5vARl1i9omZ4AEXpXh9N14.jpg'),
(149439, 10663, 'YATAGARASU The Raven Does Not Choose Its Master [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/449759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zBu8G5vARl1i9omZ4AEXpXh9N14.jpg'),
(149440, 10663, 'YATAGARASU The Raven Does Not Choose Its Master [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/454067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zBu8G5vARl1i9omZ4AEXpXh9N14.jpg'),
(149441, 10663, 'YATAGARASU The Raven Does Not Choose Its Master [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/463373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zBu8G5vARl1i9omZ4AEXpXh9N14.jpg'),
(149442, 10664, 'Yoru no Kurage wa Oyogenai [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/364061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jwEluacgCAiBXH5RHUsX2PrsIoA.jpg'),
(149443, 10664, 'Yoru no Kurage wa Oyogenai [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/364062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5OS9j23ekCwgK7D4VS2vEwduzl.jpg'),
(149444, 10664, 'Yoru no Kurage wa Oyogenai [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/364063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8huARflA72dsqrX5gNLJFYcyYED.jpg'),
(149445, 10664, 'Yoru no Kurage wa Oyogenai [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/364064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lvjn3QX0cEqEzwj6wuoaRZgIGvJ.jpg'),
(149446, 10664, 'Yoru no Kurage wa Oyogenai [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/364065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mxk72GKKA8csWGWBEYeHFcmmIo6.jpg'),
(149447, 10664, 'Yoru no Kurage wa Oyogenai [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/364066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/icNEwrQU3ZYK2rNapTDw55DPf9j.jpg'),
(149448, 10664, 'Yoru no Kurage wa Oyogenai [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/364067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24tr7v0Jc135co25ty3Ba6dqU3Y.jpg'),
(149449, 10664, 'Yoru no Kurage wa Oyogenai [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/605877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r2FXjiG9Mgn0AtSqVfpat2PpNU0.jpg'),
(149450, 10664, 'Yoru no Kurage wa Oyogenai [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/379167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r2FXjiG9Mgn0AtSqVfpat2PpNU0.jpg'),
(149451, 10664, 'Yoru no Kurage wa Oyogenai [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/383750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r2FXjiG9Mgn0AtSqVfpat2PpNU0.jpg'),
(149452, 10665, 'Eric S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/369861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yI3fE4QGvk7UC8UzidD2uF9hcVy.jpg'),
(149453, 10665, 'Eric S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/369862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k1JnFXNOayiPwyTGXhVWxSEnWRj.jpg'),
(149454, 10665, 'Eric S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/369863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9dhHjoyC3o4tGSLjMtU5rZnw28y.jpg'),
(149455, 10665, 'Eric S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/369864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/imvCPQkF8f9b8fnqo437iwZ2fpN.jpg'),
(149456, 10665, 'Eric S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/369865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQgnjxntc3oYtKcRC9zrEPx2Hc3.jpg'),
(149457, 10665, 'Eric S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/369866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fYl61UW4fb41rCr35x8kRnYJMmb.jpg'),
(149458, 10666, 'Geek Girl S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/369851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hj9YDNQgEtg1qsSxmLAH0iwaDqS.jpg'),
(149459, 10666, 'Geek Girl S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/369852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i4qgqN1rdbDlDNy9cqcOJs2VPOe.jpg'),
(149460, 10666, 'Geek Girl S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/369853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mU4Ou4cMubHRYgFXP4eUysLF729.jpg'),
(149461, 10666, 'Geek Girl S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/369854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7yt1EBC2ZgNdc4VYvw6ExN4mI79.jpg'),
(149462, 10666, 'Geek Girl S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/369855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fM1pxQ38Te8dmVMwQGpRjpSF7S8.jpg'),
(149463, 10666, 'Geek Girl S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/369856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Av85ul97t0aY3YL2AefsL5qRJi8.jpg'),
(149464, 10666, 'Geek Girl S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/369857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pV97HHpYQjV28pEc9WM2NhPY5ol.jpg'),
(149465, 10666, 'Geek Girl S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/369858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lsdSDyBpSyvBE4u9K0ZWeQjtaMN.jpg'),
(149466, 10666, 'Geek Girl S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/369859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v4GEP3gZwrTD9SeeSUU1jJjZ87d.jpg'),
(149467, 10666, 'Geek Girl S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/369860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vqrCueWsDK6aehNLGjek3BeSJ2b.jpg'),
(149468, 10667, 'Nao nos Calaremos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/369843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/trrWYSPyJ2tu9cSKseVzLCDJddy.jpg'),
(149469, 10667, 'Nao nos Calaremos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/369844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5gVoXUMyOVgbrMuxQhR2cjyoVjX.jpg'),
(149470, 10667, 'Nao nos Calaremos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/369845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/82wnBSfXCCzbGa10on9cYglw1jf.jpg'),
(149471, 10667, 'Nao nos Calaremos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/369846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bU6SmEd2wHxmvOcA4zjvJm2f303.jpg'),
(149472, 10667, 'Nao nos Calaremos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/369847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/py6XBdQv7lpOdUBn8LHli2jcSws.jpg'),
(149473, 10667, 'Nao nos Calaremos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/369848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQQQry4e05LvcvQYfv9BoCPlZFQ.jpg'),
(149474, 10667, 'Nao nos Calaremos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/369849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AdKKt9J2jsUVlzT9CKTthOQGrTA.jpg'),
(149475, 10667, 'Nao nos Calaremos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/369850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kSQSfE55EJIXtn4f57SD8SN4kX7.jpg'),
(149476, 10668, 'O Jogo da Piramide S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/369825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/53DckG9m3mnA2k06OIZWggZRLnZ.jpg'),
(149477, 10668, 'O Jogo da Piramide S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/369826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Jnyhpgp69mHF7Y0C3oamAcCt1K.jpg'),
(149478, 10668, 'O Jogo da Piramide S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/369827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/swqK0Iu4obsHABbcqQPJjdYghPp.jpg'),
(149479, 10668, 'O Jogo da Piramide S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/369828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/die1iaWAtxL58yO26Gh7HjqBLkZ.jpg'),
(149480, 10668, 'O Jogo da Piramide S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/369829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nPCy7GUwIl5wwE4rkkmnw8AiM63.jpg'),
(149481, 10668, 'O Jogo da Piramide S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/369830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eoJsPPts543FAHh77LuVMqtXZZx.jpg'),
(149482, 10668, 'O Jogo da Piramide S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/369831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cAc6VTiEf31mwi0YqZpcti9s4Qq.jpg'),
(149483, 10668, 'O Jogo da Piramide S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/369832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13VN1qLx7Fu3szeZQe0ca0mJmhs.jpg'),
(149484, 10668, 'O Jogo da Piramide S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/369833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ySyDAVzMzHkShZJJOcUowwSgG6V.jpg'),
(149485, 10668, 'O Jogo da Piramide S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/369834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jTK1udjRYa7NPBX6Nkbir6We8rY.jpg'),
(149486, 10669, 'Quilos Mortais Mexico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/369823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cQ3XOZc8bdLDoKHcUNup7qKJZNd.jpg'),
(149487, 10669, 'Quilos Mortais Mexico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/369824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x2X6BniJxP4nREHwh5iT5bcVF0Z.jpg'),
(149488, 10669, 'Quilos Mortais Mexico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/373173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yZRcAk2RvR3f6rCq1N9rbWxjxYq.jpg'),
(149489, 10669, 'Quilos Mortais Mexico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/373174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yZRcAk2RvR3f6rCq1N9rbWxjxYq.jpg'),
(149490, 10669, 'Quilos Mortais Mexico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/380939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yZRcAk2RvR3f6rCq1N9rbWxjxYq.jpg'),
(149491, 10669, 'Quilos Mortais Mexico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/380940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yZRcAk2RvR3f6rCq1N9rbWxjxYq.jpg'),
(149492, 10670, 'Minha Vida Animal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/369817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f4We6NCKt3BUriM85PJ0nPPaTWY.jpg'),
(149493, 10670, 'Minha Vida Animal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/369818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f4We6NCKt3BUriM85PJ0nPPaTWY.jpg'),
(149494, 10670, 'Minha Vida Animal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/369819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f4We6NCKt3BUriM85PJ0nPPaTWY.jpg'),
(149495, 10670, 'Minha Vida Animal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/369820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f4We6NCKt3BUriM85PJ0nPPaTWY.jpg'),
(149496, 10670, 'Minha Vida Animal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/369821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f4We6NCKt3BUriM85PJ0nPPaTWY.jpg'),
(149497, 10670, 'Minha Vida Animal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/369822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f4We6NCKt3BUriM85PJ0nPPaTWY.jpg'),
(149498, 10671, 'Febre do Ouro O Inverno Esta Aqui S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/369809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ftJUqaRUJ9hWvj53rL1bLWJF1GL.jpg'),
(149499, 10671, 'Febre do Ouro O Inverno Esta Aqui S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/369810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1pCRXffxo1YZlYr5SEfCv9R62HX.jpg'),
(149500, 10671, 'Febre do Ouro O Inverno Esta Aqui S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/369811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pilWVP1te36JGyCt36foVjydhBS.jpg'),
(149501, 10671, 'Febre do Ouro O Inverno Esta Aqui S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/369812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8LKetfyNjN1gpUbHBkNN62w9At2.jpg'),
(149502, 10671, 'Febre do Ouro O Inverno Esta Aqui S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/369813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dPnHqPC53oRD5rxbK4EqJoyyfY.jpg'),
(149503, 10671, 'Febre do Ouro O Inverno Esta Aqui S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/369814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zgkfHn4WMQLuU3ujeCsDtC1xAqI.jpg'),
(149504, 10671, 'Febre do Ouro O Inverno Esta Aqui S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/369815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yDHsquSKqPd9iyB7S30yhoiXuAM.jpg'),
(149505, 10671, 'Febre do Ouro O Inverno Esta Aqui S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/369816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7eyOokhnxznpVNqqppC8GUuldxT.jpg'),
(149506, 10672, 'Grand Hotel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/369796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fuOMGU3e4J0MAmnXRLcFVs61Lru.jpg'),
(149507, 10672, 'Grand Hotel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/369797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9xFLMWvGOg1TZfi0fdw3IC1Ispy.jpg'),
(149508, 10672, 'Grand Hotel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/369798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zc7gzAilzmuHwq9guataWSexaIO.jpg'),
(149509, 10672, 'Grand Hotel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/369799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7L5xRWy0LZt6uNiIs8PLJaprR1x.jpg'),
(149510, 10672, 'Grand Hotel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/369800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ijQ2SPxjzYeI5MgXeex5crDmosh.jpg'),
(149511, 10672, 'Grand Hotel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/369801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wn9SL5W7VY8khQb8J8Y3JN3KQiW.jpg'),
(149512, 10672, 'Grand Hotel S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/369802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZ4SzBuCGIFdJj1EdDMprZTEPxj.jpg'),
(149513, 10672, 'Grand Hotel S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/369803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ZmFIj2EpxGgQqw4uueMrBklvnv.jpg'),
(149514, 10672, 'Grand Hotel S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/369804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vsGDQ7j6TQmcxH1e9u3Z66IWuvx.jpg'),
(149515, 10672, 'Grand Hotel S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/369805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rEUG4fpjjo2exmWnv0Bj4TanZSn.jpg'),
(149516, 10672, 'Grand Hotel S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/369806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sgf5QIutGSgzwWhazLJQPiJskPt.jpg'),
(149517, 10672, 'Grand Hotel S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/369807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gLYI8x3GS4HBKf8oTd7BBhNKg1a.jpg'),
(149518, 10672, 'Grand Hotel S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/369808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBylsXLwUXr0vrSKC4aF3zdhvwp.jpg'),
(149519, 10673, 'Me Salva Dessa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/607165.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h2B0AVMGmBRO7qhZ2bLhGEox9Y1.jpg'),
(149520, 10673, 'Me Salva Dessa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/607166.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/smDe9zUR8hKnljyhONGCJjeUbgU.jpg'),
(149521, 10673, 'Me Salva Dessa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/607167.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iZgiKeZdTHjxYjvVRFdpvy6i9lS.jpg'),
(149522, 10673, 'Me Salva Dessa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/607168.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8iE9A1rF8tC1cdT1gmgjHwEzSBX.jpg'),
(149523, 10674, 'Blue Archive The Animation [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/604989.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ygmEcErrtQ9HgSX6Nooe9csAyTv.jpg'),
(149524, 10674, 'Blue Archive The Animation [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/604990.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2YrV12UZQTjhv30KLjeMlwykquk.jpg'),
(149525, 10674, 'Blue Archive The Animation [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/604991.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zF61SYwcNKw8br1oXsFNYnXjtCZ.jpg'),
(149526, 10674, 'Blue Archive The Animation [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/604992.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s09A3I2xUTVwoUxwhmgSvQp8KOF.jpg'),
(149527, 10674, 'Blue Archive The Animation [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/604993.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iOms3s3VZYGS8bLHxXUV6rrvVpy.jpg'),
(149528, 10674, 'Blue Archive The Animation [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/604994.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aNmZFV77MVmSj68nQS8C72wdTdJ.jpg'),
(149529, 10674, 'Blue Archive The Animation [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/604995.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c9aMhaLi1Z42DucBiLW5uMuWxJA.jpg'),
(149530, 10674, 'Blue Archive The Animation [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/380093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mQUHs5srrBG3VtQkMFjMHnje2TI.jpg'),
(149531, 10674, 'Blue Archive The Animation [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/380094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mQUHs5srrBG3VtQkMFjMHnje2TI.jpg'),
(149532, 10674, 'Blue Archive The Animation [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/383323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mQUHs5srrBG3VtQkMFjMHnje2TI.jpg'),
(149533, 10674, 'Blue Archive The Animation [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/385044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mQUHs5srrBG3VtQkMFjMHnje2TI.jpg'),
(149534, 1338, 'Marianne S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/376033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jolldqnvaZxp8xdVCi8DeaXFBx6.jpg'),
(149535, 1338, 'Marianne S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/376034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xqdMLwVCubL0suN0SxqWHh1rDle.jpg'),
(149536, 1338, 'Marianne S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/376035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/czNJrc9gWB9VYKg0S5XBvLWdsQ1.jpg'),
(149537, 1338, 'Marianne S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/376036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sK40gsjlpnulavsy6WOj4dsDYtR.jpg'),
(149538, 1338, 'Marianne S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/376037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lBlwinGchDnbEOOpsIk16mkDC5d.jpg'),
(149539, 1338, 'Marianne S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/376038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kKyQy1HurImzmYlJEXNi4FL5NlQ.jpg'),
(149540, 1338, 'Marianne S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/376039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/whjONsMsy2FnSGTybrrxIvClpUT.jpg'),
(149541, 1338, 'Marianne S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/376040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9qyhj6WwpYPEyKpUyQgOqNoP2Jz.jpg'),
(149542, 10675, 'Rio Paris A Tragedia do Voo 447 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/376029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fREYpDcIqXCCxg7zBJdDY2nviCr.jpg'),
(149543, 10675, 'Rio Paris A Tragedia do Voo 447 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/376030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wXCjfUww6krTjqCwE3IKbeYrHog.jpg'),
(149544, 10675, 'Rio Paris A Tragedia do Voo 447 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/376031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMuxa8C5zQnEamNEUcljzgsxUGv.jpg'),
(149545, 10675, 'Rio Paris A Tragedia do Voo 447 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/376032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wNNLilAgGXnHFtmsPxChUwz8KGu.jpg'),
(149546, 10676, 'Scorpion Servico de Inteligencia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/375935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qrRFryW2ktF59FMe0WNJfLiy4zP.jpg'),
(149547, 10676, 'Scorpion Servico de Inteligencia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/375936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUm0Ij1GoaHbW1D6FIFuGLUckVc.jpg'),
(149548, 10676, 'Scorpion Servico de Inteligencia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/375937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ZNubEjohSdlFyBNBWhSGSbpHlA.jpg'),
(149549, 10676, 'Scorpion Servico de Inteligencia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/375938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6Ifmb5C2GWEg9rFDGkCOJ3Lq22.jpg'),
(149550, 10676, 'Scorpion Servico de Inteligencia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/375939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xQmOQtDz8tKQOWFRBtvzaKkLbab.jpg'),
(149551, 10676, 'Scorpion Servico de Inteligencia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/375940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5FCgKG4MngceFr3exWoTd8YhPF5.jpg'),
(149552, 10676, 'Scorpion Servico de Inteligencia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/375941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1fVy0ffLkqJh0Wzm5HkeExcoYgb.jpg'),
(149553, 10676, 'Scorpion Servico de Inteligencia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/375942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWLWvBvhUaZVb3FiNGFZDLf0Sbl.jpg'),
(149554, 10676, 'Scorpion Servico de Inteligencia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/375943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yqeiOdC0CnExs4c1ds55CSH2M6q.jpg'),
(149555, 10676, 'Scorpion Servico de Inteligencia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/375944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1i94yeR2BLXOwAhN5XRCqvodcJH.jpg'),
(149556, 10676, 'Scorpion Servico de Inteligencia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/375945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6mIcYnx7i4R21GrZOBluXlmucmO.jpg'),
(149557, 10676, 'Scorpion Servico de Inteligencia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/375946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s8zAl2OqnEms8OdSrh6D9TlsuIl.jpg'),
(149558, 10676, 'Scorpion Servico de Inteligencia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/375947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/NESOeFbO3quR8y7JptqedsQX6y.jpg'),
(149559, 10676, 'Scorpion Servico de Inteligencia S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/375948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wJz3o2EAC6cg4P055EzZLcfttWp.jpg'),
(149560, 10676, 'Scorpion Servico de Inteligencia S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/375949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/553ZN14iBBJs7msERQY8PJCvb41.jpg'),
(149561, 10676, 'Scorpion Servico de Inteligencia S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/375950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xf2HaokjVVG19LHCxSvZuA8yXPj.jpg'),
(149562, 10676, 'Scorpion Servico de Inteligencia S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/375951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/roHJh0f7zHpEKoezrmX2Gm7TlYi.jpg'),
(149563, 10676, 'Scorpion Servico de Inteligencia S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/375952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgdxh9mqUmB709aklavqoPp23it.jpg'),
(149564, 10676, 'Scorpion Servico de Inteligencia S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/375953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6F9nVg5ULnqJ2ikoY409kQUXxYR.jpg'),
(149565, 10676, 'Scorpion Servico de Inteligencia S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/375954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v9VtlowSZTy7QuaAJJ8anl0IpyI.jpg'),
(149566, 10676, 'Scorpion Servico de Inteligencia S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/375955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/abV0tqoduEF4AMf3651J8C9Wmh1.jpg'),
(149567, 10676, 'Scorpion Servico de Inteligencia S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/375956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8x13AXe2UEtecHWAfBJ705QssnX.jpg'),
(149568, 10677, 'Scorpion Servico de Inteligencia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/375957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8LcAEjN8Rsty6m21eNUpqUTSroI.jpg'),
(149569, 10677, 'Scorpion Servico de Inteligencia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/375958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbt7PjThk7iUruZXyxdhLCURkhi.jpg'),
(149570, 10677, 'Scorpion Servico de Inteligencia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/375959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rAf1PMew5EgGvRzjEWJ7RrHDXEN.jpg'),
(149571, 10677, 'Scorpion Servico de Inteligencia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/375960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lvGb1VSFYz8bwXPTa8Rvgz4r8t3.jpg'),
(149572, 10677, 'Scorpion Servico de Inteligencia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/375961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yxeSsG0Oq5TUOkti9nbnFwVi3I4.jpg'),
(149573, 10677, 'Scorpion Servico de Inteligencia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/375962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8HcQx3rlro8dZi2qN2SKENtFJnP.jpg'),
(149574, 10677, 'Scorpion Servico de Inteligencia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/375963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9EiFCy4tAIXP0DVXz0xRc1Qxvrp.jpg'),
(149575, 10677, 'Scorpion Servico de Inteligencia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/375964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fR4L4c04kgNo1ZtMRQEI0qztZU6.jpg'),
(149576, 10677, 'Scorpion Servico de Inteligencia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/375965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tq1KxJLJ1PDp6Q5yNryuIytYXTz.jpg'),
(149577, 10677, 'Scorpion Servico de Inteligencia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/375966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r9Al0s640PhnToH9fdbc4egWs44.jpg'),
(149578, 10677, 'Scorpion Servico de Inteligencia S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/375967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Jc7xlF4P2AOgO69EPAhdode6C1.jpg'),
(149579, 10677, 'Scorpion Servico de Inteligencia S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/375968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jbWaItYTYqvBQSNeSY9iEOHd2GG.jpg'),
(149580, 10677, 'Scorpion Servico de Inteligencia S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/375969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oI2dKdE7vIKU0CHqKSWm2dTDqnj.jpg'),
(149581, 10677, 'Scorpion Servico de Inteligencia S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/375970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kMnaVviPx30b02MNZ6kwiZJe67E.jpg'),
(149582, 10677, 'Scorpion Servico de Inteligencia S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/375971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1JTPk3HyYTYeFqdCkNJAjDTD9e2.jpg'),
(149583, 10677, 'Scorpion Servico de Inteligencia S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/375972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a2lsa2JgX9Ga0jeE7KkVyd0Rokg.jpg'),
(149584, 10677, 'Scorpion Servico de Inteligencia S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/375973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4qOwOHnf81JdGgK1NQWI7unoD3O.jpg'),
(149585, 10677, 'Scorpion Servico de Inteligencia S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/375974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vq6D2ZkeKY6ZYVm1KMc93YkFP0K.jpg'),
(149586, 10677, 'Scorpion Servico de Inteligencia S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/375975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v9EuQF777TdjjeetpnlfeQb2XjZ.jpg'),
(149587, 10677, 'Scorpion Servico de Inteligencia S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/375976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yOH65UT7aBFDsQ8dSqDofNN8BDJ.jpg'),
(149588, 10677, 'Scorpion Servico de Inteligencia S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/375977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3q54jcF48S4bi3btIKvK9CLtrWx.jpg'),
(149589, 10677, 'Scorpion Servico de Inteligencia S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/375978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d95KIML37AEzdtwNFKAXe4r97Tf.jpg'),
(149590, 10677, 'Scorpion Servico de Inteligencia S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/375979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lWYLwoGA68WqFDWGD4ajm16u3A9.jpg'),
(149591, 10677, 'Scorpion Servico de Inteligencia S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/375980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qzDhVAjHJrMnQAsFH9qECiQhiHa.jpg'),
(149592, 10677, 'Scorpion Servico de Inteligencia S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/375981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hzeirSF6bRjssDh5JFrm5WRwFLd.jpg'),
(149593, 10678, 'Scorpion Servico de Inteligencia S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/375982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kV52OElXISWdpyOLi8Nxs8fnvVM.jpg'),
(149594, 10678, 'Scorpion Servico de Inteligencia S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/375983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rN0QNEavlpZAaQ7jzJvDCEj1cuu.jpg'),
(149595, 10678, 'Scorpion Servico de Inteligencia S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/375984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8legTr6kOPUpWEp2k9b8dH3ej9m.jpg'),
(149596, 10678, 'Scorpion Servico de Inteligencia S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/375985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/92AwdEUxgpMK2SzJ6AlYfoUEqMR.jpg'),
(149597, 10678, 'Scorpion Servico de Inteligencia S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/375986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kIMiEsLtPtgOnlQjmVHpUzUMtmW.jpg'),
(149598, 10678, 'Scorpion Servico de Inteligencia S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/375987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hpLxZczXRH6RSLhR94vKoW40zXl.jpg'),
(149599, 10678, 'Scorpion Servico de Inteligencia S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/375988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lF0zczwsQNQ7zFNHCDNOFRnUMQm.jpg'),
(149600, 10678, 'Scorpion Servico de Inteligencia S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/375989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qrVKs5arhsszonM8U0xM9uFn0L6.jpg'),
(149601, 10678, 'Scorpion Servico de Inteligencia S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/375990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w4l8lQWcxoybihiV8Kc8EgIK6oJ.jpg'),
(149602, 10678, 'Scorpion Servico de Inteligencia S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/375991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a8ZwlIqg4L6PbyhPd7XW4bpLx7s.jpg'),
(149603, 10678, 'Scorpion Servico de Inteligencia S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/375992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8KWA6L6SRChjm5jekaFwOjKCTxO.jpg'),
(149604, 10678, 'Scorpion Servico de Inteligencia S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/375993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/izLTkHkhMGhHOjqLR8PUUqGs4a3.jpg'),
(149605, 10678, 'Scorpion Servico de Inteligencia S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/375994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7jVLoBYaGLYUFXap5PxVjgxPSln.jpg'),
(149606, 10678, 'Scorpion Servico de Inteligencia S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/375995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSECaLISf0NaXCmgnrGVmKL1WHX.jpg'),
(149607, 10678, 'Scorpion Servico de Inteligencia S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/375996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tWxAATuWdHLbE9ijzGOwsimAQf.jpg'),
(149608, 10678, 'Scorpion Servico de Inteligencia S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/375997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2cfxvBE23K0T481FwMqLoJ2MkQX.jpg'),
(149609, 10678, 'Scorpion Servico de Inteligencia S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/375998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shuBV8WLl7fAt8SxTAPCqqk1rqc.jpg'),
(149610, 10678, 'Scorpion Servico de Inteligencia S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/375999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A306OBNbiIf2MHZdUdjbtwBLzJE.jpg'),
(149611, 10678, 'Scorpion Servico de Inteligencia S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/376000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lGfqkFiWgUOyFSht78s4hHh3d97.jpg'),
(149612, 10678, 'Scorpion Servico de Inteligencia S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/376001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1tVOi29Hu5w2f4R7U2e2Wg9mq4J.jpg'),
(149613, 10678, 'Scorpion Servico de Inteligencia S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/376002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ayoK0ENNyX1vBx8a5BivGeyWtn4.jpg'),
(149614, 10678, 'Scorpion Servico de Inteligencia S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/376003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tdV15euwdhi8yEsmd8Gww69U7qo.jpg'),
(149615, 10678, 'Scorpion Servico de Inteligencia S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/376004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glJoLElDX7HbYf6ldkKp2j6oUWl.jpg'),
(149616, 10678, 'Scorpion Servico de Inteligencia S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/376005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rBn6hyBJ8BWRWi4Dp3lGDhOLHaC.jpg'),
(149617, 10678, 'Scorpion Servico de Inteligencia S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/376006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xsng9kgxWKxEp6aJL3069jLHamh.jpg'),
(149618, 10679, 'Scorpion Servico de Inteligencia S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/376007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qkPG0gsRivzP7Tco4lzNCFBmyWe.jpg'),
(149619, 10679, 'Scorpion Servico de Inteligencia S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/376008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kY0i18p7UvqK0aoZPFyEzaidmwP.jpg'),
(149620, 10679, 'Scorpion Servico de Inteligencia S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/376009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7cMoARZOhKeaB1PMa9KaMP6Lrzs.jpg'),
(149621, 10679, 'Scorpion Servico de Inteligencia S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/376010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fSoAIcKWpJUVFny5jDG6CjsxXZa.jpg'),
(149622, 10679, 'Scorpion Servico de Inteligencia S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/376011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aCAfuGFzjAcsmqvANEpxHEGgAk3.jpg'),
(149623, 10679, 'Scorpion Servico de Inteligencia S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/376012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97h5Db9fEM0tf92U7EzyGJGYkv6.jpg'),
(149624, 10679, 'Scorpion Servico de Inteligencia S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/376013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mQM8ajRVELlfrVihFhQRzvHo9W4.jpg'),
(149625, 10679, 'Scorpion Servico de Inteligencia S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/376014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AgD0eHOaNZ8aMqsCn1mGZTsh8xU.jpg'),
(149626, 10679, 'Scorpion Servico de Inteligencia S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/376015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9eYlsYQFzsM7xa2VOgySPYFc2u0.jpg'),
(149627, 10679, 'Scorpion Servico de Inteligencia S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/376016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/czYCFyhJaxn0f8SMkoADgcTqZ70.jpg'),
(149628, 10679, 'Scorpion Servico de Inteligencia S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/376017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jQDdXLBTKgYAIyfqPNtMSX3QJNG.jpg'),
(149629, 10679, 'Scorpion Servico de Inteligencia S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/376018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/paTAOJUOP1qUJRRe1vmcADF3ZgJ.jpg'),
(149630, 10679, 'Scorpion Servico de Inteligencia S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/376019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qBbd6vr3c5FbNIL5Ij1H4gYrzMn.jpg'),
(149631, 10679, 'Scorpion Servico de Inteligencia S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/376020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pphuo2aAI7CN7IAEaZENeSPtVpP.jpg'),
(149632, 10679, 'Scorpion Servico de Inteligencia S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/376021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fqJHRWS1Yw2rmw9CktZ95dbwta6.jpg'),
(149633, 10679, 'Scorpion Servico de Inteligencia S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/376022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/faYeBZUCM4ZuLBfno3uwKqTBkQJ.jpg'),
(149634, 10679, 'Scorpion Servico de Inteligencia S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/376023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ziSqGKZ4FAeVvGXOkZKAOlwDRIb.jpg'),
(149635, 10679, 'Scorpion Servico de Inteligencia S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/376024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8PJm35gPAcGorH4w4ssF4ZahERz.jpg'),
(149636, 10679, 'Scorpion Servico de Inteligencia S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/376025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mdUyov9e9pTXBtlsoUyAHmhWZQF.jpg'),
(149637, 10679, 'Scorpion Servico de Inteligencia S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/376026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vEmI5TxcBsMMTuBst3qjMA2uM8.jpg'),
(149638, 10679, 'Scorpion Servico de Inteligencia S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/376027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q08yE0rrcdGsveJA9o9MBkKNe2B.jpg'),
(149639, 10679, 'Scorpion Servico de Inteligencia S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/376028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/szO5SHMfCjspBSHUknAhvrrGmCZ.jpg'),
(149640, 10680, 'Bright Minds S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/375918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAVc8xxEGWLy71dKHYOIG55Vayk.jpg'),
(149641, 10680, 'Bright Minds S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/375919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pg5BnNuug98GR7SZ6lP4ViT16ta.jpg'),
(149642, 10680, 'Bright Minds S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/375920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2IY3Q4EEOCGiF68QW5jgEGmMoB.jpg'),
(149643, 10680, 'Bright Minds S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/375921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nFsezl3DyBaAohEVsYFOxkXfT7m.jpg'),
(149644, 10680, 'Bright Minds S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/375922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sewBs0IgTWI4y968GiDZ1mnzI75.jpg'),
(149645, 10680, 'Bright Minds S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/375923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/BldVW0PmveWk8BJQN3XLnHZfrX.jpg'),
(149646, 10680, 'Bright Minds S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/375924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vIkVXYhd7x7t6haFkIpvNs1N3zp.jpg'),
(149647, 10680, 'Bright Minds S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/375925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dzRukyp09WdMbfpqaolfAQPESt5.jpg'),
(149648, 10680, 'Bright Minds S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/375926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGaxpA7nSKtzxraAZsPHWXIV0B6.jpg'),
(149649, 10681, 'Bright Minds S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/375927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7DOyI6eoghZB9vWT6zQ6kd4CQHP.jpg'),
(149650, 10681, 'Bright Minds S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/375928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m9ozMZdpSl5IOeXXKarby30W0F6.jpg'),
(149651, 10681, 'Bright Minds S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/375929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9DLcBrh4iG3VLu77REMoC5faJLT.jpg'),
(149652, 10681, 'Bright Minds S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/375930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4XX4xKZSIorcIUgyLlLkJSRZGV3.jpg'),
(149653, 10681, 'Bright Minds S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/375931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zJiVL5A5xQFOPiidwYNhgScfl2h.jpg'),
(149654, 10681, 'Bright Minds S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/375932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/28JjxxEC4EgAC5oUAEnpUNkpUvK.jpg'),
(149655, 10681, 'Bright Minds S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/375933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5KdxWoI6lBRrT0phuXr9elKddK2.jpg'),
(149656, 10681, 'Bright Minds S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/375934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gp5dOqsFto5Voo6c0DmmyetvQVq.jpg'),
(149657, 10682, 'Cronicas de Metal Hurlant S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/375906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nTrXtfuPtMRkJuqMy5MwvxDeyCD.jpg'),
(149658, 10682, 'Cronicas de Metal Hurlant S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/375907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kyQv43fY6lHwxfaKQdkdoySyf0f.jpg'),
(149659, 10682, 'Cronicas de Metal Hurlant S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/375908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q4He0k2QddDZdsbQB1djEPIMhL4.jpg'),
(149660, 10682, 'Cronicas de Metal Hurlant S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/375909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Ff9ecHscfAzpgo9OYAeZWi4Vmk.jpg'),
(149661, 10682, 'Cronicas de Metal Hurlant S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/375910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qGhb1QCNgXw0MEM6C9tDIbdNJLU.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(149662, 10682, 'Cronicas de Metal Hurlant S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/375911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCLSLx65A2GABScUAaF2IJezYfI.jpg'),
(149663, 10683, 'Cronicas de Metal Hurlant S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/375912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j9ZclGaUPvWyP7DrX3qiBIIiOEF.jpg'),
(149664, 10683, 'Cronicas de Metal Hurlant S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/375913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9va78BnCdkAPx2rQWUyPRXqPXF9.jpg'),
(149665, 10683, 'Cronicas de Metal Hurlant S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/375914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/igeADIRyAjoHHtGRG9mTT3ijCPk.jpg'),
(149666, 10683, 'Cronicas de Metal Hurlant S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/375915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bqb1G23uB46JwXXQLOABZuVUhNW.jpg'),
(149667, 10683, 'Cronicas de Metal Hurlant S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/375916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yTPo070XOaWaSRFyOaT4Nzt3BKI.jpg'),
(149668, 10683, 'Cronicas de Metal Hurlant S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/375917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oiGya5yEE7u39WWMhqJ0c0wyln0.jpg'),
(149669, 10684, 'De Ferias com o Ex Diretoria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/375904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qcNV3krHhlCnQbvhIbANUs5Zgj0.jpg'),
(149670, 10684, 'De Ferias com o Ex Diretoria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/375905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qcNV3krHhlCnQbvhIbANUs5Zgj0.jpg'),
(149671, 10684, 'De Ferias com o Ex Diretoria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/383144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qcNV3krHhlCnQbvhIbANUs5Zgj0.jpg'),
(149672, 10684, 'De Ferias com o Ex Diretoria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/384330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qcNV3krHhlCnQbvhIbANUs5Zgj0.jpg'),
(149673, 10684, 'De Ferias com o Ex Diretoria S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/397114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qcNV3krHhlCnQbvhIbANUs5Zgj0.jpg'),
(149674, 10684, 'De Ferias com o Ex Diretoria S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/399905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qcNV3krHhlCnQbvhIbANUs5Zgj0.jpg'),
(149675, 10684, 'De Ferias com o Ex Diretoria S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/406404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qcNV3krHhlCnQbvhIbANUs5Zgj0.jpg'),
(149676, 10684, 'De Ferias com o Ex Diretoria S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/412914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qcNV3krHhlCnQbvhIbANUs5Zgj0.jpg'),
(149677, 10684, 'De Ferias com o Ex Diretoria S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/415039.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qcNV3krHhlCnQbvhIbANUs5Zgj0.jpg'),
(149678, 10684, 'De Ferias com o Ex Diretoria S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/422306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qcNV3krHhlCnQbvhIbANUs5Zgj0.jpg'),
(149679, 10684, 'De Ferias com o Ex Diretoria S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/427868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qcNV3krHhlCnQbvhIbANUs5Zgj0.jpg'),
(149680, 10684, 'De Ferias com o Ex Diretoria S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/429877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qcNV3krHhlCnQbvhIbANUs5Zgj0.jpg'),
(149681, 10684, 'De Ferias com o Ex Diretoria S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/437020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qcNV3krHhlCnQbvhIbANUs5Zgj0.jpg'),
(149682, 10685, 'Descobrindo a Europa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/375879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1nv3qjLCllj1iS3UtXRIgIOL0q5.jpg'),
(149683, 10685, 'Descobrindo a Europa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/375880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1xFY5GPIMQbdnCAvna3Homm6Tq2.jpg'),
(149684, 10685, 'Descobrindo a Europa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/375881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fJAIQS0pkClSapj8pqbfaQxKVaS.jpg'),
(149685, 10685, 'Descobrindo a Europa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/375882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7nR3lpGkV06fAyYrWNRf6ccFz0J.jpg'),
(149686, 10685, 'Descobrindo a Europa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/375883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7r513lXMGOdIV0SHVjQFKUE2oqz.jpg'),
(149687, 10685, 'Descobrindo a Europa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/375884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rmXOw3ZOkeZmQI6DqFOg4geWUQR.jpg'),
(149688, 10686, 'Descobrindo a Europa S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/375885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s63TH8JyZIWkOzIYwBFCGGZCUNU.jpg'),
(149689, 10686, 'Descobrindo a Europa S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/375886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mYYVyf43pG6kP1A01T59wpu5XlM.jpg'),
(149690, 10686, 'Descobrindo a Europa S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/375887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iKlGLTTOAVh3CTVrbZ90muE4kNV.jpg'),
(149691, 10686, 'Descobrindo a Europa S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/375888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AbGmCkhhpXZVfNnzLboXOV6186h.jpg'),
(149692, 10686, 'Descobrindo a Europa S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/375889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0mJyQESb6WKh3q30XObef6pa3N.jpg'),
(149693, 10686, 'Descobrindo a Europa S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/375890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5EfmlqE91wmxuykEc5IFp1wG04x.jpg'),
(149694, 10687, 'Descobrindo a Europa S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/375891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zZ492VqVT4zM5zx5p8Gw3qoFvnn.jpg'),
(149695, 10687, 'Descobrindo a Europa S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/375892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xcMX92hGaOIJedlFP9IYTI84Elh.jpg'),
(149696, 10687, 'Descobrindo a Europa S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/375893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bKaR25A9957mJeVUiUuIS6R9PZP.jpg'),
(149697, 10687, 'Descobrindo a Europa S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/375894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7tNiZTqqVqhBvj7E81ESwxkp5pO.jpg'),
(149698, 10687, 'Descobrindo a Europa S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/375895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7QKuQ93D5hkdqa6OAszLSvJNJTt.jpg'),
(149699, 10687, 'Descobrindo a Europa S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/375896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gsHocAhYIr694S1f7sIIsD37FY4.jpg'),
(149700, 10688, 'Descobrindo a Europa S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/375897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qtFEVtrCMTOaZDkalYWVusdgsfi.jpg'),
(149701, 10688, 'Descobrindo a Europa S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/375898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gnWILZL8LR4f6wDmGNM1eXGgMUd.jpg'),
(149702, 10688, 'Descobrindo a Europa S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/375899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ncUY6T7OGsMIGb3HTXg0nRUyD2.jpg'),
(149703, 10688, 'Descobrindo a Europa S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/375900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ldAsnjnlBUgMWzLUomcHOhKFtuK.jpg'),
(149704, 10688, 'Descobrindo a Europa S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/375901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hNqsQrFgu5QawDWUH6ndDVyhk0Q.jpg'),
(149705, 10688, 'Descobrindo a Europa S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/375902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wwqmbeJityWhOnijtydgteBTMfg.jpg'),
(149706, 10688, 'Descobrindo a Europa S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/375903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5dF8QAzVLwlUKInCo7PUFBvIwf.jpg'),
(149707, 10689, 'The Acolyte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/375877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xNJxDtYahA28uOCqYvCqShiZFpR.jpg'),
(149708, 10689, 'The Acolyte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/375878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ukNUswsOXC8Wfvtu5Q7kp7Knf6b.jpg'),
(149709, 10689, 'The Acolyte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/383966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xeeF1KWSz8EEUl8RBz64qRnxm7V.jpg'),
(149710, 10689, 'The Acolyte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/388462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xeeF1KWSz8EEUl8RBz64qRnxm7V.jpg'),
(149711, 10689, 'The Acolyte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/394081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xeeF1KWSz8EEUl8RBz64qRnxm7V.jpg'),
(149712, 10689, 'The Acolyte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/400226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xeeF1KWSz8EEUl8RBz64qRnxm7V.jpg'),
(149713, 10689, 'The Acolyte S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/404054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xeeF1KWSz8EEUl8RBz64qRnxm7V.jpg'),
(149714, 10689, 'The Acolyte S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/411279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xeeF1KWSz8EEUl8RBz64qRnxm7V.jpg'),
(149715, 10690, 'Hitler e o Nazismo Comeco Meio e Fim S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/375871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/or8A5pVwFbwZy245r1OkbZHj6Xl.jpg'),
(149716, 10690, 'Hitler e o Nazismo Comeco Meio e Fim S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/375872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/icdr1ohvAiwnsIljh36fK7kBTZh.jpg'),
(149717, 10690, 'Hitler e o Nazismo Comeco Meio e Fim S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/375873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ngb9FIhM8e2pIs4rceaQs1Jxv1.jpg'),
(149718, 10690, 'Hitler e o Nazismo Comeco Meio e Fim S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/375874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/75ro8cSbn3WVd6XZJEjTobFLv2t.jpg'),
(149719, 10690, 'Hitler e o Nazismo Comeco Meio e Fim S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/375875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pnhrpbw2k0ye6pYsacQUsJQAy7.jpg'),
(149720, 10690, 'Hitler e o Nazismo Comeco Meio e Fim S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/375876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/54QBMaZ3sQVcriFZ00AsYjSfEli.jpg'),
(149721, 10691, 'Hierarchy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/372658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f12hr4nE278fojfpE8wAwM0kkEe.jpg'),
(149722, 10691, 'Hierarchy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/372659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5NlHhiXF5JP5U37W2hqgvxtVhxt.jpg'),
(149723, 10691, 'Hierarchy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/372660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sqCWOCuLuRknu9M5QG566KDz0vi.jpg'),
(149724, 10691, 'Hierarchy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/372661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgkpYlvKSgcs7PmZEe5ADdrqPHY.jpg'),
(149725, 10691, 'Hierarchy S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/372662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJm9RuRflT2AoI3PFw7zMLsw9XE.jpg'),
(149726, 10691, 'Hierarchy S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/372663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kPe2ult0XQ1hKO8kSnMPfRmEPAV.jpg'),
(149727, 10691, 'Hierarchy S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/372664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a4VzjIz0XC7egUf6pg7Q9ZaWJey.jpg'),
(149728, 10692, 'Os Parcas A Serie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/372648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9fN9HzGbYdXU5ljqPdQdjL0Og7L.jpg'),
(149729, 10692, 'Os Parcas A Serie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/372649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yA1CGHkExrfz62HceD9pdu4XWog.jpg'),
(149730, 10692, 'Os Parcas A Serie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/372650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gBUvPwqTiTqbfd1Tbkq89ycn07x.jpg'),
(149731, 10692, 'Os Parcas A Serie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/372651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aa1tDUZwdWrYyN4LzyDeXzczGb0.jpg'),
(149732, 10692, 'Os Parcas A Serie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/372652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4rL88sjLol5VQE8OIxq2OybFkUG.jpg'),
(149733, 10692, 'Os Parcas A Serie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/372653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/17rkmDczFvj6UqCdW5GDNvCdbrv.jpg'),
(149734, 10692, 'Os Parcas A Serie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/372654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xF430AAGts5n4oBvPJ387nSBAQb.jpg'),
(149735, 10692, 'Os Parcas A Serie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/372655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hX9RjhiiWyVFWqs3Zk2fuZImmDw.jpg'),
(149736, 10692, 'Os Parcas A Serie S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/372656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8OOZRxpQ373NpO9vRJeYkqjL2KZ.jpg'),
(149737, 10692, 'Os Parcas A Serie S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/372657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qSsMTf5ddXFF0Lm1WlSWGUWNwff.jpg'),
(149738, 10693, 'Quem e o assassino S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/372642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zm5z7g3zhg9GWK17xuEFCmIHibd.jpg'),
(149739, 10693, 'Quem e o assassino S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/372643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/juekrIuOvLNA9yI3Z4lSbFWiAkl.jpg'),
(149740, 10693, 'Quem e o assassino S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/372644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xEM32jbqlzuDAHGrIwbxER4he9f.jpg'),
(149741, 10693, 'Quem e o assassino S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/372645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nD8jSSxYsHX8VpoWh6OFp4ZoIQ3.jpg'),
(149742, 10693, 'Quem e o assassino S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/372646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xaMseiltHdm6kd09nfqRhASC3jG.jpg'),
(149743, 10693, 'Quem e o assassino S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/372647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xaMseiltHdm6kd09nfqRhASC3jG.jpg'),
(149744, 10694, 'Fantasmas (2024) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/378970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q3kK9oJa2QKCCQYVACEsiat6PJC.jpg'),
(149745, 10694, 'Fantasmas (2024) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/387419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gYxLi966L1V1iHgexBA8Iu0IyB4.jpg'),
(149746, 10694, 'Fantasmas (2024) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/392704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gYxLi966L1V1iHgexBA8Iu0IyB4.jpg'),
(149747, 10694, 'Fantasmas (2024) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/396735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gYxLi966L1V1iHgexBA8Iu0IyB4.jpg'),
(149748, 10694, 'Fantasmas (2024) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/403137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gYxLi966L1V1iHgexBA8Iu0IyB4.jpg'),
(149749, 10694, 'Fantasmas (2024) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/408980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gYxLi966L1V1iHgexBA8Iu0IyB4.jpg'),
(149750, 10695, 'O Poder de Hitler S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/378969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vNGynqjPYg58Xd4icE8IrUPIUqK.jpg'),
(149751, 10695, 'O Poder de Hitler S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/388954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ancRA4DTpCr6d0EM7wyv7dLfm1v.jpg'),
(149752, 10695, 'O Poder de Hitler S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/392338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ancRA4DTpCr6d0EM7wyv7dLfm1v.jpg'),
(149753, 10696, 'O Segredo das Coisas S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/378865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2rVdwSgdsjqX5JWhf9FGVzgmhS9.jpg'),
(149754, 10696, 'O Segredo das Coisas S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/378866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e4RKLWD1mDHsin4KBDyqobfu4dB.jpg'),
(149755, 10696, 'O Segredo das Coisas S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/378867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hhxkBuL9hWlymxH6FSRHgcaHZpx.jpg'),
(149756, 10696, 'O Segredo das Coisas S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/378868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ICMDqUntGNOoqRkBld6SyjFlo6.jpg'),
(149757, 10696, 'O Segredo das Coisas S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/378869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b4FKo08GvUqSb9MjcrC3EbJD707.jpg'),
(149758, 10696, 'O Segredo das Coisas S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/378870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uVXvGeBhf2BNz5o9I2LVxp4vljM.jpg'),
(149759, 10696, 'O Segredo das Coisas S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/378871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fIZ8eoAPfbtatIfwyPHEm0wh98x.jpg'),
(149760, 10696, 'O Segredo das Coisas S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/378872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tYtnoLKaJQM41ryDfqbnRU375Su.jpg'),
(149761, 10696, 'O Segredo das Coisas S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/378873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n45UUKlh44KIuJBpTnhWyZ1IPnV.jpg'),
(149762, 10696, 'O Segredo das Coisas S16 E10', 'http://sinalprivado.info:80/series/1533784/1533784/378874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pYZMzaUuutQ0g4swqjNCypp1iyp.jpg'),
(149763, 10696, 'O Segredo das Coisas S16 E11', 'http://sinalprivado.info:80/series/1533784/1533784/378875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tKBdqaD8DBfpqFQYKRIxbJK2htR.jpg'),
(149764, 10696, 'O Segredo das Coisas S16 E12', 'http://sinalprivado.info:80/series/1533784/1533784/378876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f2EGSynyISxQ0Tlag5r9PbggNsp.jpg'),
(149765, 10696, 'O Segredo das Coisas S16 E13', 'http://sinalprivado.info:80/series/1533784/1533784/378877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/reXgnejaCyuKzwjFVOyUz1Od04o.jpg'),
(149766, 10697, 'O Segredo das Coisas S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/378878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ynYFLzEhTbcZGOhaIm80GoDcJY9.jpg'),
(149767, 10697, 'O Segredo das Coisas S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/378879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b044RMPNvTRUIh4vw4kRqbXOEAv.jpg'),
(149768, 10697, 'O Segredo das Coisas S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/378880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b0tLSvHw6J0DB29DZIU6LV3FS1G.jpg'),
(149769, 10697, 'O Segredo das Coisas S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/378881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wEE2FqFnkZW1lq3Hcgy6lj3nYsD.jpg'),
(149770, 10697, 'O Segredo das Coisas S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/378882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yQJbOqKXDM3aIf59PxtQ4MLaGqw.jpg'),
(149771, 10697, 'O Segredo das Coisas S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/378883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sXV8trUHCUjh7IUdxXKIwmhFnKT.jpg'),
(149772, 10697, 'O Segredo das Coisas S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/378884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ovgqtRjfDtACk55dcyz5FLfbJMH.jpg'),
(149773, 10697, 'O Segredo das Coisas S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/378885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pFL8hjdbLq5aorRKfItJuRKcjdK.jpg'),
(149774, 10697, 'O Segredo das Coisas S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/378886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rIvZCBvLSzxEkqAIvomVW0IffD5.jpg'),
(149775, 10697, 'O Segredo das Coisas S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/378887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PdmMEP1ON71uDFrg2vb5QGkPEf.jpg'),
(149776, 10697, 'O Segredo das Coisas S17 E11', 'http://sinalprivado.info:80/series/1533784/1533784/378888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zMPfcedLySKUbBrwZsFYktZRjNv.jpg'),
(149777, 10697, 'O Segredo das Coisas S17 E12', 'http://sinalprivado.info:80/series/1533784/1533784/378889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A5d5kViktFHIDChU7epk9lJfRvy.jpg'),
(149778, 10697, 'O Segredo das Coisas S17 E13', 'http://sinalprivado.info:80/series/1533784/1533784/378890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6SEobluPWwgsfzEZrBhP3E3e4Q2.jpg'),
(149779, 10698, 'O Segredo das Coisas S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/378891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvExwVlD087mclPT0eiJhE29EsR.jpg'),
(149780, 10698, 'O Segredo das Coisas S18 E02', 'http://sinalprivado.info:80/series/1533784/1533784/378892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJRc3zHY9BbxaeccUakqbYf2dJ7.jpg'),
(149781, 10698, 'O Segredo das Coisas S18 E03', 'http://sinalprivado.info:80/series/1533784/1533784/378893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tZ3cuKQ9K1wIjXPiC25kNR0aRu7.jpg'),
(149782, 10698, 'O Segredo das Coisas S18 E04', 'http://sinalprivado.info:80/series/1533784/1533784/378894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3HMmY9uoBMProSXbwrwyYWtasej.jpg'),
(149783, 10698, 'O Segredo das Coisas S18 E05', 'http://sinalprivado.info:80/series/1533784/1533784/378895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/30PkDer8L5AOrhvXeweBv8GjZUg.jpg'),
(149784, 10698, 'O Segredo das Coisas S18 E06', 'http://sinalprivado.info:80/series/1533784/1533784/378896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dL6Dqz3Sotu0Wp2NuP99bGiEbzA.jpg'),
(149785, 10698, 'O Segredo das Coisas S18 E07', 'http://sinalprivado.info:80/series/1533784/1533784/378897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v3aAbtHYg0nYoCQVkqYf2eXJPJt.jpg'),
(149786, 10698, 'O Segredo das Coisas S18 E08', 'http://sinalprivado.info:80/series/1533784/1533784/378898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/piUC0YUXAjSianTPT9rCVz2cdoK.jpg'),
(149787, 10698, 'O Segredo das Coisas S18 E09', 'http://sinalprivado.info:80/series/1533784/1533784/378899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ptntFKZ6r94kplAykoiExYLqxHq.jpg'),
(149788, 10698, 'O Segredo das Coisas S18 E10', 'http://sinalprivado.info:80/series/1533784/1533784/378900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hF8HnjnFAjr36cJ9cobX8wys5ZD.jpg'),
(149789, 10698, 'O Segredo das Coisas S18 E11', 'http://sinalprivado.info:80/series/1533784/1533784/378901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u7ijwG1bYHzGx61OwemBJJMP779.jpg'),
(149790, 10698, 'O Segredo das Coisas S18 E12', 'http://sinalprivado.info:80/series/1533784/1533784/378902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oYgpmG5Q3LU5HoQtg9Ls6Vbcx3n.jpg'),
(149791, 10698, 'O Segredo das Coisas S18 E13', 'http://sinalprivado.info:80/series/1533784/1533784/378903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3oRKvljGcW8FWGGwNPm3DwHoRLa.jpg'),
(149792, 10699, 'O Segredo das Coisas S19 E01', 'http://sinalprivado.info:80/series/1533784/1533784/378904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jrIRE2G5wICgTbsGOsPkTLvAiLW.jpg'),
(149793, 10699, 'O Segredo das Coisas S19 E02', 'http://sinalprivado.info:80/series/1533784/1533784/378905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1xhIvjcPilPd0wuxHs39PNDGciL.jpg'),
(149794, 10699, 'O Segredo das Coisas S19 E03', 'http://sinalprivado.info:80/series/1533784/1533784/378906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/DF0NheEbThvOJtisFQWAU6Smv4.jpg'),
(149795, 10699, 'O Segredo das Coisas S19 E04', 'http://sinalprivado.info:80/series/1533784/1533784/378907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pRmOQhvpK5CNm8ldOu9cGbyBIIP.jpg'),
(149796, 10699, 'O Segredo das Coisas S19 E05', 'http://sinalprivado.info:80/series/1533784/1533784/378908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/baYQXPqQ1zeJLkd8ZNELH3R1Zt7.jpg'),
(149797, 10699, 'O Segredo das Coisas S19 E06', 'http://sinalprivado.info:80/series/1533784/1533784/378909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7ewpQW1rH7jrlvCFDQNymT503J.jpg'),
(149798, 10699, 'O Segredo das Coisas S19 E07', 'http://sinalprivado.info:80/series/1533784/1533784/378910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x8gRgmPl6cSEJ8YerE4vSGNr0Pc.jpg'),
(149799, 10699, 'O Segredo das Coisas S19 E08', 'http://sinalprivado.info:80/series/1533784/1533784/378911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bgYT95Akcwi0cP2aF7TANjIYIkK.jpg'),
(149800, 10699, 'O Segredo das Coisas S19 E09', 'http://sinalprivado.info:80/series/1533784/1533784/378912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nWENBv21CsSlYwg4p8iUlLnmsrd.jpg'),
(149801, 10699, 'O Segredo das Coisas S19 E10', 'http://sinalprivado.info:80/series/1533784/1533784/378913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5OrOd5DMosizlUX9zuXqCAcbVZI.jpg'),
(149802, 10699, 'O Segredo das Coisas S19 E11', 'http://sinalprivado.info:80/series/1533784/1533784/378914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nHcT9Aeni6AsUhByDitwXJhQc4Y.jpg'),
(149803, 10699, 'O Segredo das Coisas S19 E12', 'http://sinalprivado.info:80/series/1533784/1533784/378915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kMbp12KAQ2D68gr4tvJ6tseZCmf.jpg'),
(149804, 10699, 'O Segredo das Coisas S19 E13', 'http://sinalprivado.info:80/series/1533784/1533784/378916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3pI8iBT5c9x8XzSVsPHpsc5KL1.jpg'),
(149805, 10700, 'O Segredo das Coisas S20 E01', 'http://sinalprivado.info:80/series/1533784/1533784/378917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y2x8d5DiiFwNBDU5q03REWbKto4.jpg'),
(149806, 10700, 'O Segredo das Coisas S20 E02', 'http://sinalprivado.info:80/series/1533784/1533784/378918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d4xVJE6aOvhKP7xsIZ5UZHZjpyC.jpg'),
(149807, 10700, 'O Segredo das Coisas S20 E03', 'http://sinalprivado.info:80/series/1533784/1533784/378919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rg9Q5AOGg4F8HnKqosv5ziyRrtP.jpg'),
(149808, 10700, 'O Segredo das Coisas S20 E04', 'http://sinalprivado.info:80/series/1533784/1533784/378920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dvG3OPHtwzE2HYzf8gZ4cM9IGia.jpg'),
(149809, 10700, 'O Segredo das Coisas S20 E05', 'http://sinalprivado.info:80/series/1533784/1533784/378921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odQhYZUTpPr0d2RiyNWR3HtV56V.jpg'),
(149810, 10700, 'O Segredo das Coisas S20 E06', 'http://sinalprivado.info:80/series/1533784/1533784/378922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/txVCoto0tRWNA2xxZEEcFafYxBW.jpg'),
(149811, 10700, 'O Segredo das Coisas S20 E07', 'http://sinalprivado.info:80/series/1533784/1533784/378923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y6yFCo9emsPVSSBBJx1nBDfQGB5.jpg'),
(149812, 10700, 'O Segredo das Coisas S20 E08', 'http://sinalprivado.info:80/series/1533784/1533784/378924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v1wr1LU2onoI23aBm0UnZudXvsj.jpg'),
(149813, 10700, 'O Segredo das Coisas S20 E09', 'http://sinalprivado.info:80/series/1533784/1533784/378925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u8ToSpAg3WuFK2CnBA1968PRUjc.jpg'),
(149814, 10700, 'O Segredo das Coisas S20 E10', 'http://sinalprivado.info:80/series/1533784/1533784/378926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3TX6jkqssEo25ZTxcuUtUDcXXZ3.jpg'),
(149815, 10700, 'O Segredo das Coisas S20 E11', 'http://sinalprivado.info:80/series/1533784/1533784/378927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sVHRprzvptBJN8NGVr7nEB2qVbD.jpg'),
(149816, 10700, 'O Segredo das Coisas S20 E12', 'http://sinalprivado.info:80/series/1533784/1533784/378928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4FdHdP2t9nBvOe3KoEOveYNYFyT.jpg'),
(149817, 10700, 'O Segredo das Coisas S20 E13', 'http://sinalprivado.info:80/series/1533784/1533784/378929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zejWZXwEraRXrP4l0eQezU9LlZB.jpg'),
(149818, 10701, 'O Segredo das Coisas S21 E01', 'http://sinalprivado.info:80/series/1533784/1533784/378930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/meaW17hQYQyQRv4Zj8vsEIdYOx4.jpg'),
(149819, 10701, 'O Segredo das Coisas S21 E02', 'http://sinalprivado.info:80/series/1533784/1533784/378931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pvpRsyhs5Gb7X29sUSILlM4NpxR.jpg'),
(149820, 10701, 'O Segredo das Coisas S21 E03', 'http://sinalprivado.info:80/series/1533784/1533784/378932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lU3eOuF5sXRh8EBYyK8hdrj45fm.jpg'),
(149821, 10701, 'O Segredo das Coisas S21 E04', 'http://sinalprivado.info:80/series/1533784/1533784/378933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yl3fKohgFBPbv5mtTtpL9lE0ZHi.jpg'),
(149822, 10701, 'O Segredo das Coisas S21 E05', 'http://sinalprivado.info:80/series/1533784/1533784/378934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/inEPjyyo42NwDpMnV3Nc8DRHHcy.jpg'),
(149823, 10701, 'O Segredo das Coisas S21 E06', 'http://sinalprivado.info:80/series/1533784/1533784/378935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/voRfwjyyD7cZ3ike0mVILakGeXm.jpg'),
(149824, 10701, 'O Segredo das Coisas S21 E07', 'http://sinalprivado.info:80/series/1533784/1533784/378936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1t0OIFNiJE9uvyuNxATuA0BABk6.jpg'),
(149825, 10701, 'O Segredo das Coisas S21 E08', 'http://sinalprivado.info:80/series/1533784/1533784/378937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4lBMAlFJ1HTEHBElr3PTyVHSdlr.jpg'),
(149826, 10701, 'O Segredo das Coisas S21 E09', 'http://sinalprivado.info:80/series/1533784/1533784/378938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sGvPBSyIALriMXSZaPypfXLwv0t.jpg'),
(149827, 10701, 'O Segredo das Coisas S21 E10', 'http://sinalprivado.info:80/series/1533784/1533784/378939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nnitOah78OmBP7PMAGcisC71hbj.jpg'),
(149828, 10702, 'O Segredo das Coisas S22 E01', 'http://sinalprivado.info:80/series/1533784/1533784/378940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mrlmVB7el0QaUk110q3yLVyl4HA.jpg'),
(149829, 10702, 'O Segredo das Coisas S22 E02', 'http://sinalprivado.info:80/series/1533784/1533784/378941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fZVPViQDviw3JcREqvyloG9NpX7.jpg'),
(149830, 10702, 'O Segredo das Coisas S22 E03', 'http://sinalprivado.info:80/series/1533784/1533784/378942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v7YpGcKg6cRQKxmgWPvGYFjFBd9.jpg'),
(149831, 10703, 'O Segredo das Coisas S23 E01', 'http://sinalprivado.info:80/series/1533784/1533784/378943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dFq7L2qNOOQ8pdFYDxYYwFjxrvl.jpg'),
(149832, 10703, 'O Segredo das Coisas S23 E02', 'http://sinalprivado.info:80/series/1533784/1533784/378944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d6waz9CepFtzmGZnNXOSz0K4Uz8.jpg'),
(149833, 10703, 'O Segredo das Coisas S23 E03', 'http://sinalprivado.info:80/series/1533784/1533784/378945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wTGBweVsyEMzqjJgAiSqYWaL0Si.jpg'),
(149834, 10703, 'O Segredo das Coisas S23 E04', 'http://sinalprivado.info:80/series/1533784/1533784/378946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8bqfkABjVhsvZAoo67HroDVyH2V.jpg'),
(149835, 10703, 'O Segredo das Coisas S23 E05', 'http://sinalprivado.info:80/series/1533784/1533784/378947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4CNErPlyatSs33eDUX7Oq3spnoO.jpg'),
(149836, 10703, 'O Segredo das Coisas S23 E06', 'http://sinalprivado.info:80/series/1533784/1533784/378948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lAEQj63167ThyiO7yIRkZB1aZxf.jpg'),
(149837, 10703, 'O Segredo das Coisas S23 E07', 'http://sinalprivado.info:80/series/1533784/1533784/378949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1bRdVsQWieY1ba6gACmToRQq9T.jpg'),
(149838, 10703, 'O Segredo das Coisas S23 E08', 'http://sinalprivado.info:80/series/1533784/1533784/378950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qaKJKCuiWghIFrSq6DaoXQNE7hA.jpg'),
(149839, 10703, 'O Segredo das Coisas S23 E09', 'http://sinalprivado.info:80/series/1533784/1533784/378951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zj2r4LaoFEeKEWKM3QpvSGDiIT5.jpg'),
(149840, 10703, 'O Segredo das Coisas S23 E10', 'http://sinalprivado.info:80/series/1533784/1533784/378952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yJEKUiui3YXmWwjQLPnHwSMRQO3.jpg'),
(149841, 10703, 'O Segredo das Coisas S23 E11', 'http://sinalprivado.info:80/series/1533784/1533784/378953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/byREhWefl1QrKT8M285YYY07ZIM.jpg'),
(149842, 10703, 'O Segredo das Coisas S23 E12', 'http://sinalprivado.info:80/series/1533784/1533784/378954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7S9jz95rztqTjcnoz5zhfw99OZL.jpg'),
(149843, 10703, 'O Segredo das Coisas S23 E13', 'http://sinalprivado.info:80/series/1533784/1533784/378955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hPlbkJl2KmZSZti5I0NDQJiMnId.jpg'),
(149844, 10703, 'O Segredo das Coisas S23 E14', 'http://sinalprivado.info:80/series/1533784/1533784/378956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iYekbzhxzCd3M7n6CgtQJF5yqxq.jpg'),
(149845, 10703, 'O Segredo das Coisas S23 E15', 'http://sinalprivado.info:80/series/1533784/1533784/378957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iYekbzhxzCd3M7n6CgtQJF5yqxq.jpg'),
(149846, 10703, 'O Segredo das Coisas S23 E16', 'http://sinalprivado.info:80/series/1533784/1533784/378958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iYekbzhxzCd3M7n6CgtQJF5yqxq.jpg'),
(149847, 10703, 'O Segredo das Coisas S23 E17', 'http://sinalprivado.info:80/series/1533784/1533784/378959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iYekbzhxzCd3M7n6CgtQJF5yqxq.jpg'),
(149848, 10703, 'O Segredo das Coisas S23 E18', 'http://sinalprivado.info:80/series/1533784/1533784/378960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iYekbzhxzCd3M7n6CgtQJF5yqxq.jpg'),
(149849, 10703, 'O Segredo das Coisas S23 E19', 'http://sinalprivado.info:80/series/1533784/1533784/378961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iYekbzhxzCd3M7n6CgtQJF5yqxq.jpg'),
(149850, 10703, 'O Segredo das Coisas S23 E20', 'http://sinalprivado.info:80/series/1533784/1533784/378962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iYekbzhxzCd3M7n6CgtQJF5yqxq.jpg'),
(149851, 10703, 'O Segredo das Coisas S23 E21', 'http://sinalprivado.info:80/series/1533784/1533784/378963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iYekbzhxzCd3M7n6CgtQJF5yqxq.jpg'),
(149852, 10703, 'O Segredo das Coisas S23 E22', 'http://sinalprivado.info:80/series/1533784/1533784/378964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iYekbzhxzCd3M7n6CgtQJF5yqxq.jpg'),
(149853, 10703, 'O Segredo das Coisas S23 E23', 'http://sinalprivado.info:80/series/1533784/1533784/378965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iYekbzhxzCd3M7n6CgtQJF5yqxq.jpg'),
(149854, 10703, 'O Segredo das Coisas S23 E24', 'http://sinalprivado.info:80/series/1533784/1533784/378966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iYekbzhxzCd3M7n6CgtQJF5yqxq.jpg'),
(149855, 10703, 'O Segredo das Coisas S23 E25', 'http://sinalprivado.info:80/series/1533784/1533784/378967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iYekbzhxzCd3M7n6CgtQJF5yqxq.jpg'),
(149856, 10703, 'O Segredo das Coisas S23 E26', 'http://sinalprivado.info:80/series/1533784/1533784/378968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iYekbzhxzCd3M7n6CgtQJF5yqxq.jpg'),
(149857, 10704, 'O Misteio da Rota 20 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/378862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iE7541mUbEFyOzCg0UJ8L0lEG7V.jpg'),
(149858, 10704, 'O Misteio da Rota 20 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/378863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ky9JIcVjMvHLZFtwnHvrMHEdjEM.jpg'),
(149859, 10704, 'O Misteio da Rota 20 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/378864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2KmzYTLThsHH3yypBQsJpvt1IAH.jpg'),
(149860, 10705, 'As Cronicas de Spiderwick [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/380368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7tvPOBbuNWvl8hz0JpU6byD3yCc.jpg'),
(149861, 10705, 'As Cronicas de Spiderwick [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/380369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sf0tvDAYPsKaZWj8LJlPaVx3FYn.jpg'),
(149862, 10705, 'As Cronicas de Spiderwick [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/380370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5DB0wDmo79xVo6ghxWtceZnQZy3.jpg'),
(149863, 10705, 'As Cronicas de Spiderwick [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/403717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ic5Hs6zYcM4YUuxyezFUAFQie39.jpg'),
(149864, 10705, 'As Cronicas de Spiderwick [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/406476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ic5Hs6zYcM4YUuxyezFUAFQie39.jpg'),
(149865, 10705, 'As Cronicas de Spiderwick [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/406477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ic5Hs6zYcM4YUuxyezFUAFQie39.jpg'),
(149866, 10705, 'As Cronicas de Spiderwick [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/409701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ic5Hs6zYcM4YUuxyezFUAFQie39.jpg'),
(149867, 10705, 'As Cronicas de Spiderwick [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/409702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ic5Hs6zYcM4YUuxyezFUAFQie39.jpg'),
(149868, 10706, 'Bright Minds [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/380335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAVc8xxEGWLy71dKHYOIG55Vayk.jpg'),
(149869, 10706, 'Bright Minds [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/380336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pg5BnNuug98GR7SZ6lP4ViT16ta.jpg'),
(149870, 10706, 'Bright Minds [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/380337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o2IY3Q4EEOCGiF68QW5jgEGmMoB.jpg'),
(149871, 10706, 'Bright Minds [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/380338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nFsezl3DyBaAohEVsYFOxkXfT7m.jpg'),
(149872, 10706, 'Bright Minds [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/380339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sewBs0IgTWI4y968GiDZ1mnzI75.jpg'),
(149873, 10706, 'Bright Minds [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/380340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/BldVW0PmveWk8BJQN3XLnHZfrX.jpg'),
(149874, 10706, 'Bright Minds [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/380341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vIkVXYhd7x7t6haFkIpvNs1N3zp.jpg'),
(149875, 10706, 'Bright Minds [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/380342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dzRukyp09WdMbfpqaolfAQPESt5.jpg'),
(149876, 10706, 'Bright Minds [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/380343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGaxpA7nSKtzxraAZsPHWXIV0B6.jpg'),
(149877, 10707, 'Bright Minds [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/380344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7DOyI6eoghZB9vWT6zQ6kd4CQHP.jpg'),
(149878, 10707, 'Bright Minds [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/380345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m9ozMZdpSl5IOeXXKarby30W0F6.jpg'),
(149879, 10707, 'Bright Minds [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/380346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9DLcBrh4iG3VLu77REMoC5faJLT.jpg'),
(149880, 10707, 'Bright Minds [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/380347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4XX4xKZSIorcIUgyLlLkJSRZGV3.jpg'),
(149881, 10707, 'Bright Minds [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/380348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zJiVL5A5xQFOPiidwYNhgScfl2h.jpg'),
(149882, 10707, 'Bright Minds [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/380349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/28JjxxEC4EgAC5oUAEnpUNkpUvK.jpg'),
(149883, 10707, 'Bright Minds [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/380350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5KdxWoI6lBRrT0phuXr9elKddK2.jpg'),
(149884, 10707, 'Bright Minds [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/380351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gp5dOqsFto5Voo6c0DmmyetvQVq.jpg'),
(149885, 10708, 'Bright Minds [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/380352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y0LYmLdZNwaVMlsCvbTi1eqcmap.jpg'),
(149886, 10708, 'Bright Minds [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/380353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d3ERqpqMFEtsghxUOvOgyjHI3xc.jpg'),
(149887, 10708, 'Bright Minds [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/380354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rAXs8PrB5oqUxCIKei0BdXnVkCV.jpg'),
(149888, 10708, 'Bright Minds [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/380355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dpJDRLJQmmUdZ2Ba9aqIPduDDJC.jpg'),
(149889, 10708, 'Bright Minds [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/380356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yZb8TfNRnqF5dabzFRRim8uDm31.jpg'),
(149890, 10708, 'Bright Minds [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/380357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fuD4K32tPXTnpW41E1AF6zeHGVo.jpg'),
(149891, 10708, 'Bright Minds [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/380358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sqTLzObZZooRv5voYSSpVjZJgQ9.jpg'),
(149892, 10708, 'Bright Minds [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/380359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wb74negYZibsmvPisBFRPg0X66G.jpg'),
(149893, 10709, 'Bright Minds [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/380360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gp8SsZmVBmDnG9V9JFTmENX0vKe.jpg'),
(149894, 10709, 'Bright Minds [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/380361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mvoota5h4GWkTTWRlDO9sCjT14i.jpg'),
(149895, 10709, 'Bright Minds [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/380362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/85DY7EA8kIy6NDgbTleMPrAJMSw.jpg'),
(149896, 10709, 'Bright Minds [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/380363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGQ2dlU1AGzdju00rtvX164wjNg.jpg'),
(149897, 10709, 'Bright Minds [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/380364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/guYxmOohDWBZIDnSAQMJELJ9CSG.jpg'),
(149898, 10709, 'Bright Minds [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/380365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vGWot24kISNC0IJqR5QRK2PDrpY.jpg'),
(149899, 10709, 'Bright Minds [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/380366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kRbULtbDM7u39dhsxqYUYPihCZh.jpg'),
(149900, 10709, 'Bright Minds [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/380367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGQLtCOV0CNTNuulnTPQQSXXdVM.jpg'),
(149901, 10710, 'Bright Minds [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/891792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGaxpA7nSKtzxraAZsPHWXIV0B6.jpg'),
(149902, 10710, 'Bright Minds [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/891793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGaxpA7nSKtzxraAZsPHWXIV0B6.jpg'),
(149903, 10710, 'Bright Minds [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/891794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGaxpA7nSKtzxraAZsPHWXIV0B6.jpg'),
(149904, 10710, 'Bright Minds [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/891795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGaxpA7nSKtzxraAZsPHWXIV0B6.jpg'),
(149905, 10710, 'Bright Minds [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/891796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGaxpA7nSKtzxraAZsPHWXIV0B6.jpg'),
(149906, 10710, 'Bright Minds [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/891797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGaxpA7nSKtzxraAZsPHWXIV0B6.jpg'),
(149907, 10710, 'Bright Minds [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/891798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGaxpA7nSKtzxraAZsPHWXIV0B6.jpg'),
(149908, 10710, 'Bright Minds [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/891799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGaxpA7nSKtzxraAZsPHWXIV0B6.jpg'),
(149909, 10711, 'Clipped [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/380333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3CalPJYJvYCuGyiULy9wmNHW81R.jpg'),
(149910, 10711, 'Clipped [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/380334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tcKmFL1zJ3xggPdwIlbvD3SEVSi.jpg'),
(149911, 10711, 'Clipped [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/403503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cDrw2HGhR1rctZBlxBgGXJq8lT.jpg'),
(149912, 10711, 'Clipped [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/403504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cDrw2HGhR1rctZBlxBgGXJq8lT.jpg'),
(149913, 10711, 'Clipped [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/403505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cDrw2HGhR1rctZBlxBgGXJq8lT.jpg'),
(149914, 10711, 'Clipped [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/403506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2cDrw2HGhR1rctZBlxBgGXJq8lT.jpg'),
(149915, 10712, 'Irma ao Quadrado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/380215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sKPke4TtNNk0ASNlKfqETuywy5e.jpg'),
(149916, 10712, 'Irma ao Quadrado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/380216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LeiAnZzXQcHWbMzdVchidV0jLW.jpg'),
(149917, 10712, 'Irma ao Quadrado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/380217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/faboAPNRtEmdXJchkq9MYDwN4Nq.jpg'),
(149918, 10712, 'Irma ao Quadrado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/380218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hg2imsW9BMxBr4WETLc2CT11PNZ.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(149919, 10712, 'Irma ao Quadrado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/380219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xeLs4LdEvRLKLimTkO5cECvxEsU.jpg'),
(149920, 10712, 'Irma ao Quadrado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/380220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/77TwsnkXOhnlQBgPLqlATL0IuY4.jpg'),
(149921, 10712, 'Irma ao Quadrado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/380221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cB2GOdnUkSuNid295EGVP2R1UBU.jpg'),
(149922, 10712, 'Irma ao Quadrado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/380222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rfLoK9M0YSkLRYNrNI5MHVq8lKH.jpg'),
(149923, 10712, 'Irma ao Quadrado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/380223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bHUU9NDBPsTdJaVu5SnZwQ22reL.jpg'),
(149924, 10712, 'Irma ao Quadrado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/380224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b4o6AkTWdtQ23D56qBoNQQl0VTK.jpg'),
(149925, 10712, 'Irma ao Quadrado S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/380225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bBAXNqavWQzVOqGqMbrN7uUrli5.jpg'),
(149926, 10713, 'Irma ao Quadrado S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/380226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uk6JzakrpTBenm0wCwHX4jOo2H.jpg'),
(149927, 10713, 'Irma ao Quadrado S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/380227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/chCjMOIWvX8rhQXWrQdkgw2GNL9.jpg'),
(149928, 10713, 'Irma ao Quadrado S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/380228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aXiyLlgDjRPxizoReAA80VcDtC3.jpg'),
(149929, 10713, 'Irma ao Quadrado S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/380229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wXkcBLgzgIexeAHZ0ZOcRC6oVqp.jpg'),
(149930, 10713, 'Irma ao Quadrado S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/380230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a9wRuy8z6UuB8BKqLu6TSCRzm0a.jpg'),
(149931, 10713, 'Irma ao Quadrado S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/380231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xbMjRpMQ4589RbFh2YEDPqWv3aE.jpg'),
(149932, 10713, 'Irma ao Quadrado S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/380232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v61443OnHPQiUnbaTaBWKOeyLHq.jpg'),
(149933, 10713, 'Irma ao Quadrado S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/380233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ael8prKo7zVnYwhNRLHOZZrggWO.jpg'),
(149934, 10713, 'Irma ao Quadrado S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/380234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eTsUg39ZHD9ReOfeQtatq63zlfa.jpg'),
(149935, 10713, 'Irma ao Quadrado S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/380235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AnymI9sMy1L8kIP88iNYX1MVRJC.jpg'),
(149936, 10713, 'Irma ao Quadrado S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/380236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zY7Lqw1zTHemsFHUbQGyzr9WrQ9.jpg'),
(149937, 10713, 'Irma ao Quadrado S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/380237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2KcHrcKEYn9CaiyPoqHqVAlesxd.jpg'),
(149938, 10713, 'Irma ao Quadrado S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/380238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xrdTQ9VeEQlUPTYzVF9MvorLokh.jpg'),
(149939, 10713, 'Irma ao Quadrado S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/380239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wQwLZfgTeQ14dbuBAeQfR3C9Uig.jpg'),
(149940, 10713, 'Irma ao Quadrado S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/380240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u40BWVjVpCxWjePorNpFVYzMRwl.jpg'),
(149941, 10713, 'Irma ao Quadrado S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/380241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tsxMILNl5TsRN1i8f8wipffNaVR.jpg'),
(149942, 10713, 'Irma ao Quadrado S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/380242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8owKuNY8ur9doFtwc7t8LuzXmyh.jpg'),
(149943, 10713, 'Irma ao Quadrado S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/380243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ClJ6H8Ga0nIn0SSrW3tfJeiaFS.jpg'),
(149944, 10713, 'Irma ao Quadrado S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/380244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jtdfdc4nGKLrqe9u2DQ8Tg1xZmd.jpg'),
(149945, 10714, 'Irma ao Quadrado S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/380245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/caJngQC519PswzC0h3VW8GnR3Cr.jpg'),
(149946, 10714, 'Irma ao Quadrado S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/380246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/beycnGDmXbynIM5ryvALHKmD6tB.jpg'),
(149947, 10714, 'Irma ao Quadrado S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/380247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dKOYMnIM0pFNYreBkdBr17nO0Nh.jpg'),
(149948, 10714, 'Irma ao Quadrado S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/380248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cwQQdC3zSFcvooc4gz665UxC5LT.jpg'),
(149949, 10714, 'Irma ao Quadrado S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/380249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6G7ocFRM0bdPqCNTqCsI6gsKJ9g.jpg'),
(149950, 10714, 'Irma ao Quadrado S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/380250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5uHX2WYh4iFiMUEG7FZxNMrpqf7.jpg'),
(149951, 10714, 'Irma ao Quadrado S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/380251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rjkCEyZhmsAYaiEymgO26uKqWzf.jpg'),
(149952, 10714, 'Irma ao Quadrado S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/380252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Vo6SSr4edOnfszRP0pPSjwTaPD.jpg'),
(149953, 10714, 'Irma ao Quadrado S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/380253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/odEzQipCQwLj0C4wH598tXhjH0Q.jpg'),
(149954, 10714, 'Irma ao Quadrado S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/380254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2pkuRbYJLKcVkeEoVmbmCk8c7QU.jpg'),
(149955, 10714, 'Irma ao Quadrado S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/380255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sVM1h63zZu2N5e5fgl07hsjq00P.jpg'),
(149956, 10714, 'Irma ao Quadrado S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/380256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7JOqMn0ggVyJ10VCYNhKdzhT40t.jpg'),
(149957, 10714, 'Irma ao Quadrado S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/380257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tsxu6EENyrsVW02Odg6txLAVSwe.jpg'),
(149958, 10714, 'Irma ao Quadrado S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/380258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4upfALdtwL9qoDIVDARHMzDlybT.jpg'),
(149959, 10714, 'Irma ao Quadrado S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/380259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lVSPlxVXlsNO6TfOAcpV6gryKiH.jpg'),
(149960, 10714, 'Irma ao Quadrado S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/380260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a3LAUofwZA0Dp2PMmdb0EacJIdl.jpg'),
(149961, 10714, 'Irma ao Quadrado S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/380261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uiwevjIQuOFZSSvugZxbCgrrYZT.jpg'),
(149962, 10714, 'Irma ao Quadrado S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/380262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dg7H3RidrlWkUU3HVKqtEEqylwY.jpg'),
(149963, 10714, 'Irma ao Quadrado S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/380263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zAONgxVwp2I8i3ZLovXGZ6PSUfi.jpg'),
(149964, 10714, 'Irma ao Quadrado S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/380264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qHF41fanKr0nS9n2o29iNOieZGt.jpg'),
(149965, 10714, 'Irma ao Quadrado S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/380265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3cXaj3i2HURE2Lc42mL6xFDMtQb.jpg'),
(149966, 10714, 'Irma ao Quadrado S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/380266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m1G1MA0IlyzEV0fRArqgXXURo5m.jpg'),
(149967, 10715, 'Irma ao Quadrado S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/380267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nECLM8npW0eAJqCfVexSQxObaCy.jpg'),
(149968, 10715, 'Irma ao Quadrado S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/380268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d8bUuFQEK0nVsIY9RCmzthYdsIa.jpg'),
(149969, 10715, 'Irma ao Quadrado S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/380269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o5qeTPMxE9nnvyMMln5Jvc1qOXw.jpg'),
(149970, 10715, 'Irma ao Quadrado S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/380270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zmRYEO3dResw8qc5OlkevrG8XWj.jpg'),
(149971, 10715, 'Irma ao Quadrado S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/380271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nr6R86Bl3nsWCbkQuvIquUwmfga.jpg'),
(149972, 10715, 'Irma ao Quadrado S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/380272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gWmQWveZALP0xyMVyOyEJNaNLf1.jpg'),
(149973, 10715, 'Irma ao Quadrado S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/380273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5j1Dsv5fdXPrvRA4icz2wzJnwL6.jpg'),
(149974, 10715, 'Irma ao Quadrado S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/380274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s0Ld5gog3IbZYKCQkKvMRrV7Env.jpg'),
(149975, 10715, 'Irma ao Quadrado S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/380275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzMtRhsYtu5etOzbqBhvPlUIKVo.jpg'),
(149976, 10715, 'Irma ao Quadrado S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/380276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1dZ59eJi6fod2NvHlhXK6ZkabaT.jpg'),
(149977, 10715, 'Irma ao Quadrado S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/380277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eL5VFms0Euorz6NsVsBYPR1RWUw.jpg'),
(149978, 10715, 'Irma ao Quadrado S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/380278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tn6v4Hg3fqpZsIYfozRwfzlsLa6.jpg'),
(149979, 10715, 'Irma ao Quadrado S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/380279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pwb8atkYcRZZ6N9n3PsGUPsmm4P.jpg'),
(149980, 10715, 'Irma ao Quadrado S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/380280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vSCjujAOmO7x1b3MeXLwYcy2oWN.jpg'),
(149981, 10715, 'Irma ao Quadrado S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/380281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/36AllLRtwxcVT6ocKltMjcMkCMk.jpg'),
(149982, 10715, 'Irma ao Quadrado S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/380282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/35vnZNPBj7Ax92H7IDSqfqdwJEY.jpg'),
(149983, 10715, 'Irma ao Quadrado S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/380283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUlDQVakU6ELFEBjBRYXQQDr6Lu.jpg'),
(149984, 10715, 'Irma ao Quadrado S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/380284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hg8JJMZev1o3d9qE2HMBa9k3SOq.jpg'),
(149985, 10715, 'Irma ao Quadrado S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/380285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r1lNZjE3tEPrKCGHnMltRtqxzX7.jpg'),
(149986, 10715, 'Irma ao Quadrado S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/380286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Dig35Fql1dsxAQWUBv3qrpqG3p.jpg'),
(149987, 10715, 'Irma ao Quadrado S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/380287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1LjhifocmDBrPVbCGaEmL7ID8TN.jpg'),
(149988, 10715, 'Irma ao Quadrado S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/380288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tuGmUEHhDTRTdGqAdwFBWxT0qAt.jpg'),
(149989, 10716, 'Irma ao Quadrado S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/380289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zLLN1xu1b4nNtwpaJOhSiwgx0DN.jpg'),
(149990, 10716, 'Irma ao Quadrado S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/380290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWlsEgVVpn1i5jPpLhK19AxoOpi.jpg'),
(149991, 10716, 'Irma ao Quadrado S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/380291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2PuOCr5t2wjvbpqA2JdrSkWKM3i.jpg'),
(149992, 10716, 'Irma ao Quadrado S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/380292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/70ybgVQD1xfb9nv3z4zI9XO63qS.jpg'),
(149993, 10716, 'Irma ao Quadrado S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/380293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Z8OLwS0B774m5VS0B2IyBX5NfB.jpg'),
(149994, 10716, 'Irma ao Quadrado S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/380294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1lMDc6sUmUkQV0ARCH8YE5CHTnE.jpg'),
(149995, 10716, 'Irma ao Quadrado S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/380295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1TBZ8JYpsv8SJTu3U6BUO6v6fHI.jpg'),
(149996, 10716, 'Irma ao Quadrado S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/380296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o84ta2NiAPseMeY5OqKB1zJ79b3.jpg'),
(149997, 10716, 'Irma ao Quadrado S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/380297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v4BHiYJUOefVh5qAYG4YPogn9pe.jpg'),
(149998, 10716, 'Irma ao Quadrado S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/380298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Uolvrnqhh6oV4nPEOEvlpoFlHV.jpg'),
(149999, 10716, 'Irma ao Quadrado S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/380299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7NMke2aBYDcuKwO6CNmGOTyEb5H.jpg'),
(150000, 10716, 'Irma ao Quadrado S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/380300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nGTsNLhrj2SPyyiMrapCXmocdH5.jpg'),
(150001, 10716, 'Irma ao Quadrado S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/380301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/foMBPlDHX86lIWZ7vDMaXYWa5gu.jpg'),
(150002, 10716, 'Irma ao Quadrado S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/380302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ccPKw9o9mub4vGL5XT1UFS0bNHb.jpg'),
(150003, 10716, 'Irma ao Quadrado S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/380303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aVEFWMi7svAme3X28PAsVqZcVgI.jpg'),
(150004, 10716, 'Irma ao Quadrado S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/380304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dlUAovBtoPcaRglBoBXkpAHMBGR.jpg'),
(150005, 10716, 'Irma ao Quadrado S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/380305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6qKBzeegef6KXV2qtQg9220tWxe.jpg'),
(150006, 10716, 'Irma ao Quadrado S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/380306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l40e2GDLuvELYaeKrcW5skLv3hT.jpg'),
(150007, 10716, 'Irma ao Quadrado S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/380307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wKb8v45GFMD5h4rIvU0SM4k8dTN.jpg'),
(150008, 10716, 'Irma ao Quadrado S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/380308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hOEBk9JLs1QNlLsHluBne3EIms7.jpg'),
(150009, 10716, 'Irma ao Quadrado S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/380309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t9AQ6qd4r8J9IYwvmxTJ4GD5VV3.jpg'),
(150010, 10716, 'Irma ao Quadrado S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/380310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vcnB2YBwYY4hSmvR7Y3Gr25BtSs.jpg'),
(150011, 10717, 'Irma ao Quadrado S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/380311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cI38BL5WS11jmFN9beuyDBPjKZD.jpg'),
(150012, 10717, 'Irma ao Quadrado S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/380312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l0wohGxG6S5KrngOwVxPqv5n5A0.jpg'),
(150013, 10717, 'Irma ao Quadrado S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/380313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/puoffQjcF30khCZUNaO6sk9uZfT.jpg'),
(150014, 10717, 'Irma ao Quadrado S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/380314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/16YaW9AH6FdGeHcMwqbxigphzKC.jpg'),
(150015, 10717, 'Irma ao Quadrado S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/380315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PZcutJaAWIM301DxneyaL4lqZd.jpg'),
(150016, 10717, 'Irma ao Quadrado S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/380316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ziNBZC7lASfXBhhUdzplXL5ZmhG.jpg'),
(150017, 10717, 'Irma ao Quadrado S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/380317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uXgH8eUJa6yowty2OhgDmLzM4qK.jpg'),
(150018, 10717, 'Irma ao Quadrado S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/380318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJ5g4PLgTmdt1HmjSze3lX000iu.jpg'),
(150019, 10717, 'Irma ao Quadrado S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/380319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dV4YFDsAtYo6JUIjcUR0WU7cjrY.jpg'),
(150020, 10717, 'Irma ao Quadrado S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/380320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qmjVNGqteGbSkHgwOyHLn0C7ZKY.jpg'),
(150021, 10717, 'Irma ao Quadrado S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/380321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvsXxRYY8b8t3baAKRZSqR9dPla.jpg'),
(150022, 10717, 'Irma ao Quadrado S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/380322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mXiKcIbX5uhWXJSQbyYSfqDI98E.jpg'),
(150023, 10717, 'Irma ao Quadrado S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/380323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e7vPvf84u7bk3PQ9mYW7yuaDUtZ.jpg'),
(150024, 10717, 'Irma ao Quadrado S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/380324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q2laXNua3ObLW1yClEBkcs3x1yx.jpg'),
(150025, 10717, 'Irma ao Quadrado S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/380325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xq1yiX9buy0I29sl4BIvsLnXiwY.jpg'),
(150026, 10717, 'Irma ao Quadrado S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/380326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ujbIDOWgIMLudSDl5CJMdAwgZcS.jpg'),
(150027, 10717, 'Irma ao Quadrado S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/380327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dDbwC84Cbq0yiq35N9uUUjj8Ekc.jpg'),
(150028, 10717, 'Irma ao Quadrado S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/380328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cSjHNeep0gNLqkJoywd1KrKrZdC.jpg'),
(150029, 10717, 'Irma ao Quadrado S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/380329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p3rzfIUQepji0Y6vSuOeix7yJpf.jpg'),
(150030, 10717, 'Irma ao Quadrado S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/380330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ixCnTUcNfGfxIrz69lJTUPQ1nPs.jpg'),
(150031, 10717, 'Irma ao Quadrado S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/380331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n3YWVZ45KyV0RUtoGx3Vu5uB2H9.jpg'),
(150032, 10717, 'Irma ao Quadrado S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/380332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vKbktQiJLRFtKjFv60lgBaRfcCC.jpg'),
(150033, 10718, 'Nick e Aaron Carter A Queda dos Idolos [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/380211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7JEMkZ4hs6IQjazPBHBuD15rMDI.jpg'),
(150034, 10718, 'Nick e Aaron Carter A Queda dos Idolos [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/380212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6UMgEwOfAcTsVv0FtzamE6xvhDc.jpg'),
(150035, 10718, 'Nick e Aaron Carter A Queda dos Idolos [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/380213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zbLpnXcy9heyk0vrPPAPsBhCRl1.jpg'),
(150036, 10718, 'Nick e Aaron Carter A Queda dos Idolos [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/380214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2bUBKSY6hlkebpIZtRBztUrOpXS.jpg'),
(150037, 10719, 'Um Monstro Como Nunca se Viu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/380205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8XFM09qoEy0Szm8HsN9uiXyr7WR.jpg'),
(150038, 10719, 'Um Monstro Como Nunca se Viu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/380206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8XFM09qoEy0Szm8HsN9uiXyr7WR.jpg'),
(150039, 10719, 'Um Monstro Como Nunca se Viu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/380207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8XFM09qoEy0Szm8HsN9uiXyr7WR.jpg'),
(150040, 10719, 'Um Monstro Como Nunca se Viu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/380208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8XFM09qoEy0Szm8HsN9uiXyr7WR.jpg'),
(150041, 10719, 'Um Monstro Como Nunca se Viu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/380209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8XFM09qoEy0Szm8HsN9uiXyr7WR.jpg'),
(150042, 10719, 'Um Monstro Como Nunca se Viu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/380210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8XFM09qoEy0Szm8HsN9uiXyr7WR.jpg'),
(150043, 10720, 'Viktor Delivers [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/380196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/52Crs8ZnLFl47EhFlljPjK5DgS2.jpg'),
(150044, 10720, 'Viktor Delivers [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/380197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/52Crs8ZnLFl47EhFlljPjK5DgS2.jpg'),
(150045, 10720, 'Viktor Delivers [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/380198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/52Crs8ZnLFl47EhFlljPjK5DgS2.jpg'),
(150046, 10720, 'Viktor Delivers [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/380199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/52Crs8ZnLFl47EhFlljPjK5DgS2.jpg'),
(150047, 10720, 'Viktor Delivers [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/380200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/52Crs8ZnLFl47EhFlljPjK5DgS2.jpg'),
(150048, 10720, 'Viktor Delivers [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/380201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/52Crs8ZnLFl47EhFlljPjK5DgS2.jpg'),
(150049, 10720, 'Viktor Delivers [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/380202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/52Crs8ZnLFl47EhFlljPjK5DgS2.jpg'),
(150050, 10720, 'Viktor Delivers [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/380203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/52Crs8ZnLFl47EhFlljPjK5DgS2.jpg'),
(150051, 10720, 'Viktor Delivers [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/380204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/52Crs8ZnLFl47EhFlljPjK5DgS2.jpg'),
(150052, 10721, 'Juacas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/379078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150053, 10721, 'Juacas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/379079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g0vPgc7zKoVCPCWFjYWUq1ciXSx.jpg'),
(150054, 10721, 'Juacas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/379080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150055, 10721, 'Juacas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/379081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150056, 10721, 'Juacas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/379082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150057, 10721, 'Juacas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/379083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150058, 10721, 'Juacas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/379084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150059, 10721, 'Juacas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/379085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150060, 10721, 'Juacas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/379086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150061, 10721, 'Juacas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/379087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150062, 10721, 'Juacas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/379088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150063, 10721, 'Juacas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/379089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150064, 10721, 'Juacas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/379090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150065, 10721, 'Juacas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/379091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150066, 10721, 'Juacas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/379092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150067, 10721, 'Juacas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/379093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150068, 10721, 'Juacas S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/379094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150069, 10721, 'Juacas S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/379095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150070, 10721, 'Juacas S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/379096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150071, 10721, 'Juacas S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/379097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150072, 10721, 'Juacas S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/379098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150073, 10721, 'Juacas S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/379099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150074, 10721, 'Juacas S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/379100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150075, 10721, 'Juacas S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/379101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150076, 10721, 'Juacas S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/379102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9WRhDUfhA7oh39GaJq3UYujoIEe.jpg'),
(150077, 10722, 'Quem e voce Alaska S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/379070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dcBfHrs2zawE4iWhQrlFAzBJ7R.jpg'),
(150078, 10722, 'Quem e voce Alaska S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/379071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/97D5GTRsz5XTAHdzkHyGhRavJcg.jpg'),
(150079, 10722, 'Quem e voce Alaska S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/379072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vGwEbsmzkLjSLhvGfsEO80X5Gjv.jpg'),
(150080, 10722, 'Quem e voce Alaska S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/379073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nl53H97BzaFPabe3u0oO73PxY66.jpg'),
(150081, 10722, 'Quem e voce Alaska S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/379074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zBsBazu1GC9Ih7InSyToAySWILH.jpg'),
(150082, 10722, 'Quem e voce Alaska S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/379075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/663ZrFNieF6blGFNFANs1wvylKM.jpg'),
(150083, 10722, 'Quem e voce Alaska S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/379076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2EWVPfgqt0L1ngfOWBdy87qvcku.jpg'),
(150084, 10722, 'Quem e voce Alaska S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/379077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mTJ3ZRWpUUAvfg2gwESVi9qHSZ7.jpg'),
(150085, 10723, 'Segura a Onda [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/378972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1bFepeqNpx940YCTh0mI2tHgZCa.jpg'),
(150086, 10723, 'Segura a Onda [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/378973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/714jnxgQqyowldnKMmNEomzeE3j.jpg'),
(150087, 10723, 'Segura a Onda [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/378974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rrhO0WLNiBceTtIaVzneYbfxu0.jpg'),
(150088, 10723, 'Segura a Onda [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/378975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJDXheFIqCpHwuOSzRjC1ll4ce7.jpg'),
(150089, 10723, 'Segura a Onda [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/378976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yr6MpW5rWhhuA801NMuyOF9YhDq.jpg'),
(150090, 10723, 'Segura a Onda [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/378977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7sMTNc4RJUW6KKXP1v8E2FUBd8g.jpg'),
(150091, 10723, 'Segura a Onda [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/378978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z9M2G0LjY8hAKQLWumeFKgwH5t6.jpg'),
(150092, 10723, 'Segura a Onda [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/378979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oOsRhfK7w2sxKsWdexjxhi3BC5y.jpg'),
(150093, 10723, 'Segura a Onda [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/378980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/coVQKZOVT5uePmDt2Oi0trADvEz.jpg'),
(150094, 10723, 'Segura a Onda [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/378981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Ihx1IkvyHAmG23vOT6cs1GW22n.jpg'),
(150095, 10724, 'Segura a Onda [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/378982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rkn1BHbc1aXyocRAQ2tsC1ubp0T.jpg'),
(150096, 10724, 'Segura a Onda [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/378983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9se1m3XAFKEl3yQsVuA4QAwKxNE.jpg'),
(150097, 10724, 'Segura a Onda [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/378984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1GbmXaGBxI8FFh06WYBD7RpCLgI.jpg'),
(150098, 10724, 'Segura a Onda [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/378985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hdB4riK0Zs5RNEBwdcOr87ZhXZX.jpg'),
(150099, 10724, 'Segura a Onda [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/378986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cmbH5yuKZCAiWFxOL2fQSVNXYkT.jpg'),
(150100, 10724, 'Segura a Onda [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/378987.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9kCOrDMzHiZTgZV70ZxUSTuWsaK.jpg'),
(150101, 10724, 'Segura a Onda [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/378988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ixobf0R2OcPkX6s9fz5FmwbYPd.jpg'),
(150102, 10724, 'Segura a Onda [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/378989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iHiTUtXlLFYKfz8c5uvUgrFg8po.jpg'),
(150103, 10725, 'Segura a Onda [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/378990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tBRiSBA754KCFZsaQ374G2VsUsl.jpg'),
(150104, 10725, 'Segura a Onda [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/378991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vcxtaiV0vZULMe9iqFMQ4t0ow5Z.jpg'),
(150105, 10725, 'Segura a Onda [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/378992.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1oESB8eQaoV3mKDrosCPMmrjyhy.jpg'),
(150106, 10725, 'Segura a Onda [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/378993.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ode5Ukjzf6yCa0I3B7AsCqemKDu.jpg'),
(150107, 10725, 'Segura a Onda [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/378994.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9L95MraJEuPlXG7GyftpQGlABlW.jpg'),
(150108, 10725, 'Segura a Onda [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/378995.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v6RgPbNZbrWh45h79kSuWbeClLK.jpg'),
(150109, 10725, 'Segura a Onda [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/378996.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bbk8A9ZEQUtaiVu27qZoUyOkOqr.jpg'),
(150110, 10725, 'Segura a Onda [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/378997.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/icndQk4tCLmsBEKNMb4zdcD2vLq.jpg'),
(150111, 10725, 'Segura a Onda [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/378998.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wugfMUtw0fV6ljnHE7zZj8AiT3y.jpg'),
(150112, 10725, 'Segura a Onda [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/378999.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t9B7oGJ2WcGHOQvIJaFSJzt5z7w.jpg'),
(150113, 10726, 'Segura a Onda [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/379000.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lqGILMuoiymGd8NSY16Len0fIz0.jpg'),
(150114, 10726, 'Segura a Onda [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/379001.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9AuleeIjUbcDMHtuf1KKjYY6rTI.jpg'),
(150115, 10726, 'Segura a Onda [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/379002.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8VMg3RsHMxCMuyLmQLsbkIZJ9bo.jpg'),
(150116, 10726, 'Segura a Onda [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/379003.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3jMl54vJIQE9G9rcCTLyc1dzaMk.jpg'),
(150117, 10726, 'Segura a Onda [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/379004.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/73R35C0GYcsxBJzT3zjaDmv1oXk.jpg'),
(150118, 10726, 'Segura a Onda [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/379005.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sSHdcZJj4GjTZrvYt8U0SejUefh.jpg'),
(150119, 10726, 'Segura a Onda [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/379006.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6KGNcOuIs6ZYfbb40IWyR1gfeb1.jpg'),
(150120, 10726, 'Segura a Onda [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/379007.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fJWtU4DZwYZxG2dLOgYj91nDlEQ.jpg'),
(150121, 10726, 'Segura a Onda [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/379008.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n6gqLeI6hwR82FvC60nKpe2cTpV.jpg'),
(150122, 10726, 'Segura a Onda [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/379009.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/juwb2bNZ2f80L4uChMr2TY2d6Os.jpg'),
(150123, 10727, 'Segura a Onda [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/379010.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xbkhDtczYuWDcz34ts0RqzTAidP.jpg'),
(150124, 10727, 'Segura a Onda [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/379011.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m1zqNpqiYlFrsCuRVm8YBuMUj0z.jpg'),
(150125, 10727, 'Segura a Onda [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/379012.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sh5Oj1s8DA5vtI6a9VAQjB348kT.jpg'),
(150126, 10727, 'Segura a Onda [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/379013.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/huiHoOpY78lmqQZa36CXsqiPJG4.jpg'),
(150127, 10727, 'Segura a Onda [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/379014.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zi7wmHONMZog51ZAHqHsEmK5t89.jpg'),
(150128, 10727, 'Segura a Onda [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/379015.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6rdqp5U6GVDlxaJlwxaSC0lm8eY.jpg'),
(150129, 10727, 'Segura a Onda [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/379016.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a1RgH4H3PdMJAT6fUcpUo6IuaC9.jpg'),
(150130, 10727, 'Segura a Onda [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/379017.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nd1vSYa2NmoBnOHDaYssFykSzb.jpg'),
(150131, 10727, 'Segura a Onda [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/379018.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUB10ttQbRbiW3n5ivTcTZKV72N.jpg'),
(150132, 10727, 'Segura a Onda [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/379019.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWcexca7UFPqqK75Dg5LZX8HGhb.jpg'),
(150133, 10728, 'Segura a Onda [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/379020.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yBAJNVysVPX4MKuH4qeG8tCJ0R1.jpg'),
(150134, 10728, 'Segura a Onda [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/379021.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rL6RJm6ddZRbLrM9RqNYwFDWVtC.jpg'),
(150135, 10728, 'Segura a Onda [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/379022.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cWDLRPPEBK16diojJUJieswDN4q.jpg'),
(150136, 10728, 'Segura a Onda [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/379023.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQtOh4wqFrY80P5lW3eOftyxOVY.jpg'),
(150137, 10728, 'Segura a Onda [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/379024.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vF1VmtDyVSceq2pOW9Y3lLG0S4z.jpg'),
(150138, 10728, 'Segura a Onda [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/379025.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgUc7ZmjYJmQynp4xZ49k6vDv6m.jpg'),
(150139, 10728, 'Segura a Onda [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/379026.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dEEKRR3tx46qHotcuWIFSenWZyN.jpg'),
(150140, 10728, 'Segura a Onda [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/379027.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fFV91Nh2UdDpCT9F3yqKwplWE84.jpg'),
(150141, 10728, 'Segura a Onda [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/379028.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cVCIAiziIZpvLXVQgZo6WTAzRUc.jpg'),
(150142, 10728, 'Segura a Onda [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/379029.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1laFScs9OiJYvbvb2WBVISMQ6TQ.jpg'),
(150143, 10729, 'Segura a Onda [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/379030.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f26Q4zWYAqpziLu0N8uHqiWWNOQ.jpg'),
(150144, 10729, 'Segura a Onda [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/379031.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sqImZ7VBcxh0vwZPouIIjHDOwK6.jpg'),
(150145, 10729, 'Segura a Onda [L] S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/379032.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zyxPSQqbrdLVo9kDFkMqGOtjUAC.jpg'),
(150146, 10729, 'Segura a Onda [L] S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/379033.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sCRYIpYu7RKTxZQUHKAP5bec9Eg.jpg'),
(150147, 10729, 'Segura a Onda [L] S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/379034.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AvDB6ipeS2cOB5dO4dYpjKTJgTT.jpg'),
(150148, 10729, 'Segura a Onda [L] S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/379035.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p8zhfsZw8pQCbAQuvz7jdstPWe7.jpg'),
(150149, 10729, 'Segura a Onda [L] S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/379036.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kU61qfc8Jkz4SGmWLtisf0Lzwz.jpg'),
(150150, 10729, 'Segura a Onda [L] S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/379037.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/38FLTM1ugWGR8Q2baeY7Eadahyh.jpg'),
(150151, 10729, 'Segura a Onda [L] S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/379038.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5WrczTc67n3bAl0mjt7Mu2cLkWJ.jpg'),
(150152, 10729, 'Segura a Onda [L] S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/379039.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ignNzLR9B6BSMIyH3VuPwR4kZ38.jpg'),
(150153, 10730, 'Segura a Onda [L] S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/379040.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8tIdLgL5ibFrg3lvlKg9Oz1lA0S.jpg'),
(150154, 10730, 'Segura a Onda [L] S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/379041.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyIQETOXBYZ8NLv98TGtO9YKVCV.jpg'),
(150155, 10730, 'Segura a Onda [L] S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/379042.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xbIHauuig1oUrRhSQcELYrOJT07.jpg'),
(150156, 10730, 'Segura a Onda [L] S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/379043.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rkzWQTQd1m6MRLURmvoKkoPw3mi.jpg'),
(150157, 10730, 'Segura a Onda [L] S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/379044.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6L0ByHDbuUPaXfERvYOCsmRTigi.jpg'),
(150158, 10730, 'Segura a Onda [L] S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/379045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uPMvvY48VQj2TuVbr1AjWjGd8NM.jpg'),
(150159, 10730, 'Segura a Onda [L] S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/379046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bb5gNp1Lz6zbUWwcBjf8jCbZ6qr.jpg'),
(150160, 10730, 'Segura a Onda [L] S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/379047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tQfYMYX6Jp1QxuNvv1bfG8hnkS4.jpg'),
(150161, 10730, 'Segura a Onda [L] S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/379048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nBwZjM8pvwdIkSTHdYH3gEAPHia.jpg'),
(150162, 10730, 'Segura a Onda [L] S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/379049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/exrtSAwFZYqiaKRMOdy26EKy6yn.jpg'),
(150163, 10731, 'Segura a Onda [L] S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/379050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kiGK7Me57rF57EU2W8llj3GkKpN.jpg'),
(150164, 10731, 'Segura a Onda [L] S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/379051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kya15sTIsGqRHl2XgEbIrS8epNt.jpg'),
(150165, 10731, 'Segura a Onda [L] S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/379052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Fl7rRUkcd7NgSo5QsybKBsJ1QH.jpg'),
(150166, 10731, 'Segura a Onda [L] S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/379053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/upLDgLzHU8EX0rw1SI1Jv4corXp.jpg'),
(150167, 10731, 'Segura a Onda [L] S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/379054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/brYWtcSvusw7U7gtRs8YF14o7If.jpg'),
(150168, 10731, 'Segura a Onda [L] S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/379055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tuYT2aRKV4QxrI1uVWeOFBgXLyp.jpg'),
(150169, 10731, 'Segura a Onda [L] S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/379056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5ROJoTw3f8KFNTBNPYbIT7NwHl.jpg'),
(150170, 10731, 'Segura a Onda [L] S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/379057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vCizeF2xShcjqmmW5y7TDZ9WOUw.jpg'),
(150171, 10731, 'Segura a Onda [L] S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/379058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gnFvqKGGl6Z9n6lIey8TYmFVNkv.jpg'),
(150172, 10731, 'Segura a Onda [L] S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/379059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJs4KwMYdT9SWrMSIcnNxvtM9c7.jpg'),
(150173, 10732, 'Segura a Onda [L] S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/379060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iZYmk7WlKYNVkXjemWcFILJ0w0E.jpg'),
(150174, 10732, 'Segura a Onda [L] S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/379061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6jurDD1TXk0Kq5LthPIvNqB0blX.jpg'),
(150175, 10732, 'Segura a Onda [L] S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/379062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7RO6EPToAQ38yQEfiASJyWb03wB.jpg'),
(150176, 10732, 'Segura a Onda [L] S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/379063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wbEEHZoYQQWnmkmRoJfPBLImYTv.jpg'),
(150177, 10732, 'Segura a Onda [L] S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/379064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCmxapTGG4s1cCmV1FSfWE4VL2V.jpg'),
(150178, 10732, 'Segura a Onda [L] S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/379065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4hb9vH8cr3CKYRLdWgrOZUso4YY.jpg'),
(150179, 10732, 'Segura a Onda [L] S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/379066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3tD0hu6bpUBtIKDcOOKQjO4fNzZ.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(150180, 10732, 'Segura a Onda [L] S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/379067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5PIG9U2GQ7dw0PzL2Q3LaP3rsOt.jpg'),
(150181, 10732, 'Segura a Onda [L] S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/379068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aEaC2uUzMF9FNTYg2ygey5POEKu.jpg'),
(150182, 10732, 'Segura a Onda [L] S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/379069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7u7E04AknWQA0O1fcBwc0Ok2D19.jpg'),
(150183, 10733, 'H2O Meninas Sereias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/380393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9fjEAZAtbEwNcrHNQg11stk9EF8.jpg'),
(150184, 10733, 'H2O Meninas Sereias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/380394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aNyhzPr1fdi2CSK0dsQVaGUMdTs.jpg'),
(150185, 10733, 'H2O Meninas Sereias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/380395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7UD7EZRlQ2EsRKTnjoJdHBCjzv3.jpg'),
(150186, 10733, 'H2O Meninas Sereias S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/380396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qRylkn0Qk0Y8RT8K6uaxWU0NT9P.jpg'),
(150187, 10733, 'H2O Meninas Sereias S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/380397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fGA9cNdYMjiKD2wtGoND4SmXz01.jpg'),
(150188, 10733, 'H2O Meninas Sereias S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/380398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z5EdKvBXjh3SvLcGorHMZOLdhNP.jpg'),
(150189, 10733, 'H2O Meninas Sereias S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/380399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aOUbo67aE95UNTtST9a2VZGZFeN.jpg'),
(150190, 10733, 'H2O Meninas Sereias S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/380400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mWcqzSK0HJOv6afvsRHnGjMzGEM.jpg'),
(150191, 10733, 'H2O Meninas Sereias S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/380401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/om8r78ZmuWKxPcHhRvNmQXLLsTg.jpg'),
(150192, 10733, 'H2O Meninas Sereias S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/380402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iOokQYg9ukhJEFYNwdbVTmFUoKh.jpg'),
(150193, 10733, 'H2O Meninas Sereias S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/380403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3DjDaKKUF9mHesYVsjesFtMIysn.jpg'),
(150194, 10733, 'H2O Meninas Sereias S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/380404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j0TaYDmcTwc8ch3NdJvdyLMNts9.jpg'),
(150195, 10733, 'H2O Meninas Sereias S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/380405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lH5uwcEozCsKEVb29RR929lARK9.jpg'),
(150196, 10733, 'H2O Meninas Sereias S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/380406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lzeTitIMa1hYpa3LHRQvWp3eE4W.jpg'),
(150197, 10733, 'H2O Meninas Sereias S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/380407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lkn5Hen6rkunCksJo4dCnyLR4RX.jpg'),
(150198, 10733, 'H2O Meninas Sereias S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/380408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bGeFRvZWj43aoRcBQcr22mPvTff.jpg'),
(150199, 10733, 'H2O Meninas Sereias S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/380409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFg6T7DGxnV871OTp4Oh1bpMaSN.jpg'),
(150200, 10733, 'H2O Meninas Sereias S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/380410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q8g4ud1CJjt2UELlVvmrdpABmJn.jpg'),
(150201, 10733, 'H2O Meninas Sereias S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/380411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/npqnD3AMx8TV76T9m6SKsLFEy2C.jpg'),
(150202, 10733, 'H2O Meninas Sereias S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/380412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yY6WdnVhEL1XcJJ9TVvmSihOswb.jpg'),
(150203, 10733, 'H2O Meninas Sereias S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/380413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9yZ4GXLos866omXrnys6NDdld7B.jpg'),
(150204, 10733, 'H2O Meninas Sereias S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/380414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eZk7a4Ia13wuqWDLhNyP5IUpS7u.jpg'),
(150205, 10733, 'H2O Meninas Sereias S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/380415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cbd7hi8n6q7CfsbcTu6819o5vC2.jpg'),
(150206, 10733, 'H2O Meninas Sereias S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/380416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qoDSgUjLHYR9QMILNfQoPx6Lypf.jpg'),
(150207, 10733, 'H2O Meninas Sereias S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/380417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vjYihHgadPd4HrXFePV98X0Quli.jpg'),
(150208, 10733, 'H2O Meninas Sereias S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/380418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oOQsqd7DwFL4UDdWDY8O4w9IbZ3.jpg'),
(150209, 10734, 'H2O Meninas Sereias S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/380419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/HKzMUdr3r9KVXu3ZQwf6tlVzyJ.jpg'),
(150210, 10734, 'H2O Meninas Sereias S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/380420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fBEchoHAiPNqOgxDyxphetMSPXi.jpg'),
(150211, 10734, 'H2O Meninas Sereias S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/380421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tVaLkhjtcOx2GHXvCLPKIX4jey9.jpg'),
(150212, 10734, 'H2O Meninas Sereias S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/380422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h21WxoiOyI4d6c3X9KkAsz0QxQX.jpg'),
(150213, 10734, 'H2O Meninas Sereias S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/380423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nPQtzLn6exGWGugmotfUW4KbwMA.jpg'),
(150214, 10734, 'H2O Meninas Sereias S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/380424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v9deGH2WvyWPYFG2HYDSYqIXRQl.jpg'),
(150215, 10734, 'H2O Meninas Sereias S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/380425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5oogcBnGhzXFJzeWFxE1BgbQQdU.jpg'),
(150216, 10734, 'H2O Meninas Sereias S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/380426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ewkS15xYu7ejKqBXI5PSgKg5np1.jpg'),
(150217, 10734, 'H2O Meninas Sereias S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/380427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ynAoJcXUi3ePkM46P5wlPFCS9T8.jpg'),
(150218, 10734, 'H2O Meninas Sereias S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/380428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q2TxhZaH45nUga4LpywT9QZQn2G.jpg'),
(150219, 10734, 'H2O Meninas Sereias S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/380429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7kd39kaUOdMZZLVT04roQiX9oab.jpg'),
(150220, 10734, 'H2O Meninas Sereias S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/380430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tYEE36EMHzjS6rXK10uzXTakq1T.jpg'),
(150221, 10734, 'H2O Meninas Sereias S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/380431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nmvw9yIO2VjPaXO42EOTdGyfk0Y.jpg'),
(150222, 10734, 'H2O Meninas Sereias S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/380432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i2p8qQHwiOD7DJsWSXaylfW9At1.jpg'),
(150223, 10734, 'H2O Meninas Sereias S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/380433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/exNyFB4AgUXvnMcm6MpHkWra4k6.jpg'),
(150224, 10734, 'H2O Meninas Sereias S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/380434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lQYyDf89pyHBH5CAUD5HEWlkRrx.jpg'),
(150225, 10734, 'H2O Meninas Sereias S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/380435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fQf13SRwIAqM7QVz2IyRpfVDTlq.jpg'),
(150226, 10734, 'H2O Meninas Sereias S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/380436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8a7xHPZ74fsSuIVaE6cNCwKwrR.jpg'),
(150227, 10734, 'H2O Meninas Sereias S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/380437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tpvtPPGIzzB0EFrAGp7esDwQH1k.jpg'),
(150228, 10734, 'H2O Meninas Sereias S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/380438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wloCj5oeKEkGzqM24tCGHEB4lHb.jpg'),
(150229, 10734, 'H2O Meninas Sereias S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/380439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pUtiLqM7HrAQ8EE5gZ0uloxny1U.jpg'),
(150230, 10734, 'H2O Meninas Sereias S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/380440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AfWO6O97jMLu3vPY8my2Ff0Uc4u.jpg'),
(150231, 10734, 'H2O Meninas Sereias S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/380441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lUU8iYxAePimZbd2Du7q4jjLuWi.jpg'),
(150232, 10734, 'H2O Meninas Sereias S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/380442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/DdQos1eLJZPKEJIJsuPjUMyXW4.jpg'),
(150233, 10734, 'H2O Meninas Sereias S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/380443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cv8Hnjx2BeTAVeSyG8HJD4ecHo9.jpg'),
(150234, 10734, 'H2O Meninas Sereias S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/380444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cowsMclZSFjH3LBxDMBRuhiZOj1.jpg'),
(150235, 10735, 'H2O Meninas Sereias S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/380445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qMt1kg9U0u869w5oPFmt3ypiVjo.jpg'),
(150236, 10735, 'H2O Meninas Sereias S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/380446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9t2tPUGE3LvLTXqTyZkcX0A66p8.jpg'),
(150237, 10735, 'H2O Meninas Sereias S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/380447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q8njkiFdY1NfjpbXagt0Hz6eAG4.jpg'),
(150238, 10735, 'H2O Meninas Sereias S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/380448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v5aiNSiMYYGKVQjxMTqpkxl9OTG.jpg'),
(150239, 10735, 'H2O Meninas Sereias S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/380449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1QlKtvIpr3m5pyt4d8FVB6Yg6MW.jpg'),
(150240, 10735, 'H2O Meninas Sereias S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/380450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6YIMr8Ysba4P6jPvl6spu6IE9AX.jpg'),
(150241, 10735, 'H2O Meninas Sereias S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/380451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tzbqUtlinNxto3iiIT9L2SQGiag.jpg'),
(150242, 10735, 'H2O Meninas Sereias S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/380452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yPVoExVPlOrygNLSEYxm3Id13wz.jpg'),
(150243, 10735, 'H2O Meninas Sereias S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/380453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZtYLYT0RRYWJ6crUqZQSDiJyQu.jpg'),
(150244, 10735, 'H2O Meninas Sereias S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/380454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mW0xFuIXRoUKX2TsdY2uKYdQl22.jpg'),
(150245, 10735, 'H2O Meninas Sereias S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/380455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jpQOWSgAd6IheS7jHEpWM8VZDBO.jpg'),
(150246, 10735, 'H2O Meninas Sereias S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/380456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3QhxIOIFCPkDlTMwxEOoScjj3HD.jpg'),
(150247, 10735, 'H2O Meninas Sereias S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/380457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2bIBSw14UpZUkQUpXXMMbG1jJ0O.jpg'),
(150248, 10735, 'H2O Meninas Sereias S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/380458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nCfCKxtwOKTFGFMBHpZBiTf6Va7.jpg'),
(150249, 10735, 'H2O Meninas Sereias S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/380459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1VAMEmLCM3a3VN134PVb0E3I8F6.jpg'),
(150250, 10735, 'H2O Meninas Sereias S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/380460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yGDgcLp3J8EJVFrP5AI8Bir18xw.jpg'),
(150251, 10735, 'H2O Meninas Sereias S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/380461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xYa7qKKIob0oLxRbEtMnJqP3lSX.jpg'),
(150252, 10735, 'H2O Meninas Sereias S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/380462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jXnDkSDQgvSO4fssGAzwdy5JOdF.jpg'),
(150253, 10735, 'H2O Meninas Sereias S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/380463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmKp7r0D9gubpHbtGZRRYW1P7sA.jpg'),
(150254, 10735, 'H2O Meninas Sereias S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/380464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wQG4Y2I1M8u7JEHjJYDbn43qISU.jpg'),
(150255, 10735, 'H2O Meninas Sereias S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/380465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k63OuV5CKkoKr1Ia9MwFFSBAUSz.jpg'),
(150256, 10735, 'H2O Meninas Sereias S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/380466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wyJ43iGIKCTuajMYwUoBkleLw7A.jpg'),
(150257, 10735, 'H2O Meninas Sereias S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/380467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4GLS99RX7DLZGcu8sKoedfrF6hE.jpg'),
(150258, 10735, 'H2O Meninas Sereias S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/380468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pRIqhhWjOuK5PVtgBmelxRCPTuy.jpg'),
(150259, 10735, 'H2O Meninas Sereias S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/380469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w9Fjlqi2grsuqXqRVWLYOiqMT5F.jpg'),
(150260, 10735, 'H2O Meninas Sereias S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/380470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/269ZgcsPl823p6xli2vwx9MdiIT.jpg'),
(150261, 1256, 'Love Alarm S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/380385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bDBXo2CbWbOOROjHe0ISseYwr86.jpg'),
(150262, 1256, 'Love Alarm S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/380386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gVG3ZIa4YZ4G83y7e3Hk6Fm4TfJ.jpg'),
(150263, 1256, 'Love Alarm S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/380387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8tEV7lWf938uHLW52YoGHUaEOdi.jpg'),
(150264, 1256, 'Love Alarm S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/380388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/is10w1JBS22WQer4ESd5q4dVWbo.jpg'),
(150265, 1256, 'Love Alarm S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/380389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yrmkGrvJpkL1FPh4vPyi28nB1kt.jpg'),
(150266, 1256, 'Love Alarm S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/380390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uLSmeqPGPAifUTZkHbA2DRC5Z3V.jpg'),
(150267, 1256, 'Love Alarm S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/380391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yY8nV4t6oQw6nxLIXW7ar9L2egD.jpg'),
(150268, 1256, 'Love Alarm S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/380392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/smXQEwBGWYILzSTSnvFMjxkMVii.jpg'),
(150269, 10736, 'Ninjago Mestres do Spinjitzu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/380372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/12e0EA0VEXfIXlWtSc0UcVm0geX.jpg'),
(150270, 10736, 'Ninjago Mestres do Spinjitzu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/380373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LUmvkiX9yPFPo3BocFWKiol4yF.jpg'),
(150271, 10736, 'Ninjago Mestres do Spinjitzu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/380374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sEdXu29dMeg2NjDlapYO9QGsykZ.jpg'),
(150272, 10736, 'Ninjago Mestres do Spinjitzu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/380375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nm3noVytR5IZTm9IMtSkROKXIOl.jpg'),
(150273, 10736, 'Ninjago Mestres do Spinjitzu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/380376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iTKMFjRjm7V6NZszfhxISmlI8MA.jpg'),
(150274, 10736, 'Ninjago Mestres do Spinjitzu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/380377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eawK6rdAIb5XCMHEocwJdxDwDYo.jpg'),
(150275, 10736, 'Ninjago Mestres do Spinjitzu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/380378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7S3HOj5iWorNahnuDMgDyWe3sSq.jpg'),
(150276, 10736, 'Ninjago Mestres do Spinjitzu S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/380379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJ6nVMEpeUZGLKp3hiZBeNtdZ9d.jpg'),
(150277, 10736, 'Ninjago Mestres do Spinjitzu S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/380380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lV5Sk89icFdfAlbw7dZJvWGPs3F.jpg'),
(150278, 10736, 'Ninjago Mestres do Spinjitzu S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/380381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ebgcKH9ZoWhWqJCKWFjbmqpMYs.jpg'),
(150279, 10736, 'Ninjago Mestres do Spinjitzu S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/380382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q8WMOd57D9pcPpVG9jNXaYdcqca.jpg'),
(150280, 10736, 'Ninjago Mestres do Spinjitzu S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/380383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4DXhsB0d0CkPTakBAyaXM3Ccq73.jpg'),
(150281, 10736, 'Ninjago Mestres do Spinjitzu S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/380384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cN2Nvte6jRVXOu8qB6Qq3k2yKR2.jpg'),
(150282, 10737, 'The Listener [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/383623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vmziGlkUBlVejkvyTxHivHzJ88q.jpg'),
(150283, 10737, 'The Listener [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/383624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/53KEIF8yIjuhI3sqnLDNrxtEenu.jpg'),
(150284, 10737, 'The Listener [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/383625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/TNQ9GQwfw1Gpt3vBkteGFwFVV6.jpg'),
(150285, 10737, 'The Listener [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/383626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jSsGB4AxGuD23J6U3Om6hxBhcFu.jpg'),
(150286, 10737, 'The Listener [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/383627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b7Why042YfO2tVYaFQ5LYYHemYa.jpg'),
(150287, 10737, 'The Listener [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/383628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hQLvDtAHYOq6QZL3tGkRQebDWvY.jpg'),
(150288, 10737, 'The Listener [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/383629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cPeT3X6HIkijlhHmc4wDMJH9Ol4.jpg'),
(150289, 10737, 'The Listener [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/383630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/CN8L8gbksdI30536WIkip3dWSK.jpg'),
(150290, 10737, 'The Listener [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/383631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u0hZnvz2w2MyGwaVpBxTFevQVGk.jpg'),
(150291, 10737, 'The Listener [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/383632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vUEFPZeJ0RUIvtMugcvxNecie0k.jpg'),
(150292, 10737, 'The Listener [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/383633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n63Stewb6LUPlTELDJbP7r18kIQ.jpg'),
(150293, 10737, 'The Listener [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/383634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtryzD19l5sOnFh15DKiC5abPaO.jpg'),
(150294, 10737, 'The Listener [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/383635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ta7WL62udxiizOM4HglJbDkl6ca.jpg'),
(150295, 10738, 'The Listener [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/383636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fngrbc49yBrF0WNZ7Jq8eNoSKEg.jpg'),
(150296, 10738, 'The Listener [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/383637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Es2JuhluAZMDJkDlDssQUzFxph.jpg'),
(150297, 10738, 'The Listener [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/383638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qpp6YlF9bMPsAWPRkJRhy9Xbywi.jpg'),
(150298, 10738, 'The Listener [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/383639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ArUir97JrsezcJtKs8F5bAMGOZf.jpg'),
(150299, 10738, 'The Listener [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/383640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l1POsBc6mj2Kp5ysaUrbdHA4nzu.jpg'),
(150300, 10738, 'The Listener [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/383641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNbK1LOO6uOtb8Nxbxc6uTd21He.jpg'),
(150301, 10738, 'The Listener [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/383642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j46hFYGKEVB7NFgF58XlCrjCPkw.jpg'),
(150302, 10738, 'The Listener [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/383643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hVavWl2PREikk8Ur4cU23p8YkNc.jpg'),
(150303, 10738, 'The Listener [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/383644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfKzdKxLpNFObBQTb2rgecmIGFA.jpg'),
(150304, 10738, 'The Listener [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/383645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pruxIDmHaUP2vLbci6wHa4D4yuU.jpg'),
(150305, 10738, 'The Listener [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/383646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mz7VLscNXmc3dTjccG7kCqMNJ5o.jpg'),
(150306, 10738, 'The Listener [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/383647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5key9WKb7tRBTAbwUIvRhIzNxyd.jpg'),
(150307, 10738, 'The Listener [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/383648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lfxPaAfgSTajRubzpyttdDjsWzQ.jpg'),
(150308, 10739, 'The Listener [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/383649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1k0R818iQxqYxMNcKZCR7FGmN3v.jpg'),
(150309, 10739, 'The Listener [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/383650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/QFuf7MbWZJhedhIL0Av6bXpqLd.jpg'),
(150310, 10739, 'The Listener [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/383651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nM4YVFOfDs6pSppnOGaokpw0eWN.jpg'),
(150311, 10739, 'The Listener [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/383652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s70gedmBU6jqJflOIXNfhN7fy4F.jpg'),
(150312, 10739, 'The Listener [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/383653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xxJmBrwU50ZTgG9lY6vL8Dq9fq9.jpg'),
(150313, 10739, 'The Listener [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/383654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n0lR0zEXi9TeRmc14Rc6GJFM3PU.jpg'),
(150314, 10739, 'The Listener [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/383655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uzbH0dB0HvDsPjedKnwhBGMy9in.jpg'),
(150315, 10739, 'The Listener [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/383656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7mo2G3JuY4reSwLtedDnf1XhYmu.jpg'),
(150316, 10739, 'The Listener [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/383657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/22Y9hkMVQLCQnJz4c7HOgbnZB4u.jpg'),
(150317, 10739, 'The Listener [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/383658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qoDrZ9df9QHhXDdH6bGesnvCnyk.jpg'),
(150318, 10739, 'The Listener [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/383659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/noitUcpQfhhQHtgoRlzpaYG2Eq5.jpg'),
(150319, 10739, 'The Listener [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/383660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ddfnsvaY54etpNLerpUEk5uRxDb.jpg'),
(150320, 10739, 'The Listener [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/383661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4cZDTbY3w8fmBUGdDSX8RR4jHMf.jpg'),
(150321, 10740, 'The Listener [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/383662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/miNmzN1exoV44U5OYUZNXRSp9Je.jpg'),
(150322, 10740, 'The Listener [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/383663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2yZ1o5M2TEh5mC44jpmKr4TIIFR.jpg'),
(150323, 10740, 'The Listener [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/383664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qO83n0IM7NoZn1s1qxazCyDfMjO.jpg'),
(150324, 10740, 'The Listener [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/383665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p9F1QK2WBPd6poQMfFICZwxhu3b.jpg'),
(150325, 10740, 'The Listener [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/383666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e0rwWj38N7lu8gX9Zrw0EU62IeN.jpg'),
(150326, 10740, 'The Listener [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/383667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hIa8PuTolmfPHNd3W9sqOKhoZo5.jpg'),
(150327, 10740, 'The Listener [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/383668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w6cytMzTnQbAYm4VHC9CjGygyFg.jpg'),
(150328, 10740, 'The Listener [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/383669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4dGcscW3q7626nloxSi1yDHejPR.jpg'),
(150329, 10740, 'The Listener [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/383670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xfA03LJBVgm3WfwQL8f8uPxPtaX.jpg'),
(150330, 10740, 'The Listener [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/383671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/owFETOxhrqWOiI7F8AUSiG7cazd.jpg'),
(150331, 10740, 'The Listener [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/383672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63UBuz1SPhszunUjDAAjJEIF2uo.jpg'),
(150332, 10740, 'The Listener [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/383673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jkXEv5azi4gwRIzz0y8Dw7Eubdk.jpg'),
(150333, 10740, 'The Listener [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/383674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oNAqhY64tP6S5bXkQDz1proOpHH.jpg'),
(150334, 10741, 'The Listener [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/385445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o80J7MZegBjkfdpaVO77buaAeRj.jpg'),
(150335, 10741, 'The Listener [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/385446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nGAoo90m86Y7nd5xEGlmdykynei.jpg'),
(150336, 10741, 'The Listener [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/385447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gjRv03wHp51rsTrorZOKSFTkqo.jpg'),
(150337, 10741, 'The Listener [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/385448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7SnOEQ5Su0NuPTi8uwp0Y2wkT9t.jpg'),
(150338, 10741, 'The Listener [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/385449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uVJoeHagguy9k2vgxNEyxhzBB0F.jpg'),
(150339, 10741, 'The Listener [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/385450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1WjiZrEvgB5I73n0iYY0RFdMszJ.jpg'),
(150340, 10741, 'The Listener [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/385451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yRZ8SVsWrE22g9SahuYvLLuDKST.jpg'),
(150341, 10741, 'The Listener [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/385452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hmFUjmkbLrau2X4dLvCr27CYTIM.jpg'),
(150342, 10741, 'The Listener [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/385453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6UBnox16JgMWw0DNydIeR9n0t0J.jpg'),
(150343, 10741, 'The Listener [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/385454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Ig6OXI6pDa66m5pOrmXE7cw8e3.jpg'),
(150344, 10741, 'The Listener [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/385455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uER3A5kskQNgeiZpBmnTsFJtnsR.jpg'),
(150345, 10741, 'The Listener [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/385456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aMqm38qxI7KaRRcqA1LvNDhtb2U.jpg'),
(150346, 10741, 'The Listener [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/385457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8DeQsE7GEu6Hd7zH2MXx0vMAroF.jpg'),
(150347, 10742, 'Acima de Qualquer Suspeita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/383621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hToxFEhhlPTR9lT5O3EVAg7uU5K.jpg'),
(150348, 10742, 'Acima de Qualquer Suspeita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/383622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aZtruAnHmjBoxcKqmq1SDPbgImM.jpg'),
(150349, 10742, 'Acima de Qualquer Suspeita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/385140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4pvvSFNIgm6TDuETajfCIklvyp6.jpg'),
(150350, 10742, 'Acima de Qualquer Suspeita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/398084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4pvvSFNIgm6TDuETajfCIklvyp6.jpg'),
(150351, 10742, 'Acima de Qualquer Suspeita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/401283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4pvvSFNIgm6TDuETajfCIklvyp6.jpg'),
(150352, 10742, 'Acima de Qualquer Suspeita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/405411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4pvvSFNIgm6TDuETajfCIklvyp6.jpg'),
(150353, 10742, 'Acima de Qualquer Suspeita S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/413032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4pvvSFNIgm6TDuETajfCIklvyp6.jpg'),
(150354, 10742, 'Acima de Qualquer Suspeita S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/415110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4pvvSFNIgm6TDuETajfCIklvyp6.jpg'),
(150355, 10743, 'Descendentes do Sol S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/383620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cbPzc5qli0iyOvIBjPgJq3CriDk.jpg'),
(150356, 10743, 'Descendentes do Sol S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/384326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pNdMKYl9j4fC5xFBO0rB2NFMnUM.jpg'),
(150357, 10743, 'Descendentes do Sol S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/397101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pNdMKYl9j4fC5xFBO0rB2NFMnUM.jpg'),
(150358, 10743, 'Descendentes do Sol S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/401188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pNdMKYl9j4fC5xFBO0rB2NFMnUM.jpg'),
(150359, 10743, 'Descendentes do Sol S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/405275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pNdMKYl9j4fC5xFBO0rB2NFMnUM.jpg'),
(150360, 10743, 'Descendentes do Sol S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/412906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pNdMKYl9j4fC5xFBO0rB2NFMnUM.jpg'),
(150361, 10744, 'Doutor Climax S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/383612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jlQT845qIPa5ON2c9gTLqJRpUd9.jpg'),
(150362, 10744, 'Doutor Climax S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/383613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A1Mn3I1iKIe59RfdWVrkD7I8QxA.jpg'),
(150363, 10744, 'Doutor Climax S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/383614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mLyvWiaAo6UCSM9TTBRdb7pKGvN.jpg'),
(150364, 10744, 'Doutor Climax S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/383615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rbwStGWBWapaE9L5c3P89jOk3bK.jpg'),
(150365, 10744, 'Doutor Climax S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/383616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dV0UAgQvj0zn2aIF9LxuBAFSouG.jpg'),
(150366, 10744, 'Doutor Climax S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/383617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eSgB3oHuqsmCOZktopmIsSQO965.jpg'),
(150367, 10744, 'Doutor Climax S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/383618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oDXkTKDV8n2vkm3GMIwP7Vs70t9.jpg'),
(150368, 10744, 'Doutor Climax S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/383619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bKYcnbc8iMddyBQgSeAR8Sss9x.jpg'),
(150369, 10745, 'Memorial de Maria Moura S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/383593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cj6uHkx2AnB68qraRq0ONX6HKvm.jpg'),
(150370, 10745, 'Memorial de Maria Moura S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/383594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cj6uHkx2AnB68qraRq0ONX6HKvm.jpg'),
(150371, 10745, 'Memorial de Maria Moura S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/383595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cj6uHkx2AnB68qraRq0ONX6HKvm.jpg'),
(150372, 10745, 'Memorial de Maria Moura S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/383596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cj6uHkx2AnB68qraRq0ONX6HKvm.jpg'),
(150373, 10745, 'Memorial de Maria Moura S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/383597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cj6uHkx2AnB68qraRq0ONX6HKvm.jpg'),
(150374, 10745, 'Memorial de Maria Moura S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/383598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cj6uHkx2AnB68qraRq0ONX6HKvm.jpg'),
(150375, 10745, 'Memorial de Maria Moura S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/383599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cj6uHkx2AnB68qraRq0ONX6HKvm.jpg'),
(150376, 10745, 'Memorial de Maria Moura S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/383600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cj6uHkx2AnB68qraRq0ONX6HKvm.jpg'),
(150377, 10745, 'Memorial de Maria Moura S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/383601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cj6uHkx2AnB68qraRq0ONX6HKvm.jpg'),
(150378, 10745, 'Memorial de Maria Moura S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/383602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cj6uHkx2AnB68qraRq0ONX6HKvm.jpg'),
(150379, 10745, 'Memorial de Maria Moura S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/383603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cj6uHkx2AnB68qraRq0ONX6HKvm.jpg'),
(150380, 10745, 'Memorial de Maria Moura S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/383604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cj6uHkx2AnB68qraRq0ONX6HKvm.jpg'),
(150381, 10745, 'Memorial de Maria Moura S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/383605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cj6uHkx2AnB68qraRq0ONX6HKvm.jpg'),
(150382, 10745, 'Memorial de Maria Moura S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/383606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cj6uHkx2AnB68qraRq0ONX6HKvm.jpg'),
(150383, 10745, 'Memorial de Maria Moura S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/383607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cj6uHkx2AnB68qraRq0ONX6HKvm.jpg'),
(150384, 10745, 'Memorial de Maria Moura S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/383608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cj6uHkx2AnB68qraRq0ONX6HKvm.jpg'),
(150385, 10745, 'Memorial de Maria Moura S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/383609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cj6uHkx2AnB68qraRq0ONX6HKvm.jpg'),
(150386, 10745, 'Memorial de Maria Moura S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/383610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cj6uHkx2AnB68qraRq0ONX6HKvm.jpg'),
(150387, 10745, 'Memorial de Maria Moura S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/383611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cj6uHkx2AnB68qraRq0ONX6HKvm.jpg'),
(150388, 10746, 'O Caso Asunta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/383587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fyMBbWFx3BVogqmKEZU5jJo6Cbz.jpg'),
(150389, 10746, 'O Caso Asunta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/383588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eLK32jY6aS4xXoIWQ7Mt4ABC5CG.jpg'),
(150390, 10746, 'O Caso Asunta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/383589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8uHWZzMRytRFEOquSFDLsfbUWqE.jpg'),
(150391, 10746, 'O Caso Asunta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/383590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xO2u7yjjbgOZnGnOgR9pnpSd12e.jpg'),
(150392, 10746, 'O Caso Asunta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/383591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bDUAufP4bD7ZNCQkhxdW8f0I5TL.jpg'),
(150393, 10746, 'O Caso Asunta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/383592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ahML1aEtTWJ81EgqmtMYcE6WYS8.jpg'),
(150394, 10747, 'O Jogo Que Mudou A Historia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/383585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/488T8M49mMsvgm95Yafv3sQ42vP.jpg'),
(150395, 10747, 'O Jogo Que Mudou A Historia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/383586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1UL4DQMdTOdNUt0Ovv4TkRBxL.jpg'),
(150396, 10747, 'O Jogo Que Mudou A Historia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/388957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trc7lqDTPpgvHLin4BDkWNJ6z6C.jpg'),
(150397, 10747, 'O Jogo Que Mudou A Historia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/388958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trc7lqDTPpgvHLin4BDkWNJ6z6C.jpg'),
(150398, 10747, 'O Jogo Que Mudou A Historia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/395795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trc7lqDTPpgvHLin4BDkWNJ6z6C.jpg'),
(150399, 10747, 'O Jogo Que Mudou A Historia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/395796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trc7lqDTPpgvHLin4BDkWNJ6z6C.jpg'),
(150400, 10747, 'O Jogo Que Mudou A Historia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/402846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trc7lqDTPpgvHLin4BDkWNJ6z6C.jpg'),
(150401, 10747, 'O Jogo Que Mudou A Historia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/402847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trc7lqDTPpgvHLin4BDkWNJ6z6C.jpg'),
(150402, 10747, 'O Jogo Que Mudou A Historia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/408471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trc7lqDTPpgvHLin4BDkWNJ6z6C.jpg'),
(150403, 10747, 'O Jogo Que Mudou A Historia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/408472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/trc7lqDTPpgvHLin4BDkWNJ6z6C.jpg'),
(150404, 10748, 'Pesadelos e Devaneios de Joko Anwar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/383578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bGQ3yq05z0gcuMdmeKOBYGwjgrb.jpg'),
(150405, 10748, 'Pesadelos e Devaneios de Joko Anwar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/383579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ljz7zWuBFCNfw4SsYZXQDvmItRT.jpg'),
(150406, 10748, 'Pesadelos e Devaneios de Joko Anwar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/383580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/28wRdVFx8QrQqcZgMMio2tDLFUF.jpg'),
(150407, 10748, 'Pesadelos e Devaneios de Joko Anwar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/383581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/BrsrPIQLbb9Vo9S2JdAgLfUEBA.jpg'),
(150408, 10748, 'Pesadelos e Devaneios de Joko Anwar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/383582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fjVQliPhOnnGT9rGaumXI3NiIxt.jpg'),
(150409, 10748, 'Pesadelos e Devaneios de Joko Anwar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/383583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AszCtgkcseMMrvLaSzpJacVQMn6.jpg'),
(150410, 10748, 'Pesadelos e Devaneios de Joko Anwar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/383584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ay7QnJ4Np2owo0MMw245r1dOfWi.jpg'),
(150411, 10749, 'Requiem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/383572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yarrjKitqVExj9DsjrSR2aR4GsA.jpg'),
(150412, 10749, 'Requiem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/383573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kWLov5102zGtbJjTID7vppDIxE.jpg'),
(150413, 10749, 'Requiem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/383574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mSl4P1ZLKKHOc6g05FXpTSVdMsr.jpg'),
(150414, 10749, 'Requiem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/383575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bACRIgB5eG2tetJX4mBgubUCqhg.jpg'),
(150415, 10749, 'Requiem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/383576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oLdtoihVP73X2m6HbowxbAWkCdU.jpg'),
(150416, 10749, 'Requiem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/383577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kJIQCsPPxEMpQvTd7gw9gTzVCVU.jpg'),
(150417, 10750, 'SAND LAND A SERIE S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/383559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cYa88H6lCHEqnhicNIaOopJUvnM.jpg'),
(150418, 10750, 'SAND LAND A SERIE S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/383560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/89oSmm3vgYZOa66WkIc0zTqXlX0.jpg'),
(150419, 10750, 'SAND LAND A SERIE S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/383561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/61TsGXNx8Of5lQLWqCx79cWvu9k.jpg'),
(150420, 10750, 'SAND LAND A SERIE S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/383562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m7YakbK37GWkrMljSRT1HNkZ74k.jpg'),
(150421, 10750, 'SAND LAND A SERIE S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/383563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyBalsaIfmkljhrsMFqwqctP4z0.jpg'),
(150422, 10750, 'SAND LAND A SERIE S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/383564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qdLsHWIqBmEfwuSi4E2n1qbKibH.jpg'),
(150423, 10750, 'SAND LAND A SERIE S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/383565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r74IHKMIaGLmsfUwVLrtEjwt4Dr.jpg'),
(150424, 10750, 'SAND LAND A SERIE S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/383566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yNZOTqvniez39KmC38b5PkZDlY.jpg'),
(150425, 10750, 'SAND LAND A SERIE S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/383567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t3MAACTKkQVXHn8ZGxieD9dS5nr.jpg'),
(150426, 10750, 'SAND LAND A SERIE S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/383568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lBhV55pLsA8gBlPTV28M6uFAB5O.jpg'),
(150427, 10750, 'SAND LAND A SERIE S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/383569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7q3LbwaqLJt0DOVFdxFrjZNkM2r.jpg'),
(150428, 10750, 'SAND LAND A SERIE S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/383570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sZXz1gvVhBtQkNrMwhb2DqrbpVU.jpg'),
(150429, 10750, 'SAND LAND A SERIE S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/383571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/khv5snLCQz2yaE9yRTSfKzBYadt.jpg'),
(150430, 10751, 'Suite Magnolia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/383551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ij9vld2zaX3IyyrirOjeRwqjjSt.jpg'),
(150431, 10751, 'Suite Magnolia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/383552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i5VIPadB5EzVawiuXtYf1O9IY53.jpg'),
(150432, 10751, 'Suite Magnolia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/383553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9V2GqsjJvi55i76uJoQ54OKMOKC.jpg'),
(150433, 10751, 'Suite Magnolia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/383554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8gA2D10bKIw9rGkboXt56iSmhV.jpg'),
(150434, 10751, 'Suite Magnolia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/383555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mRiO451FmvfgzoczGxrBMeL9u8N.jpg'),
(150435, 10751, 'Suite Magnolia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/383556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zpTTD7qO9yfbrIqt5MDqkjfEBm6.jpg'),
(150436, 10751, 'Suite Magnolia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/383557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ydpS6idxYnJA3P3LV41duXAsNsi.jpg'),
(150437, 10751, 'Suite Magnolia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/383558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zW2dHMEqwSAHbZ6zCgxWCikQhLF.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(150438, 10752, 'Roosevelt Um Capitulo na Historia Americana S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/383548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/re5DJ3OsNXy009pZ8xirswXkJnd.jpg'),
(150439, 10752, 'Roosevelt Um Capitulo na Historia Americana S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/383549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/495lfVjYBLksKMjPIUpYMVZHMS.jpg'),
(150440, 10752, 'Roosevelt Um Capitulo na Historia Americana S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/383550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mNO9FBpPuIsO9t0p0FXFcJmio3Z.jpg'),
(150441, 10753, 'Snoopy Vai Acampar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/383535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dfYHEBWA5kRRuAEtYf4ABx1sKad.jpg'),
(150442, 10753, 'Snoopy Vai Acampar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/383536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1W3VSkxvbjXwvJvvSfi2nLtpO2t.jpg'),
(150443, 10753, 'Snoopy Vai Acampar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/383537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r6p1qcaIXtMePTjsxaROiO0m5Do.jpg'),
(150444, 10753, 'Snoopy Vai Acampar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/383538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lmx1wmaqBOJbEQ8dVrfUbHCC09s.jpg'),
(150445, 10753, 'Snoopy Vai Acampar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/383539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9R2dGV3U20ZFlCkrzAvVi0GpoUZ.jpg'),
(150446, 10753, 'Snoopy Vai Acampar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/383540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/re6Muijx2pzhU5vCBBPhWVL4p91.jpg'),
(150447, 10753, 'Snoopy Vai Acampar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/383541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gKWUlL3caaHtLYLn46YjkqDRyeS.jpg'),
(150448, 10753, 'Snoopy Vai Acampar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/383542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x5dnSXdnDsGa54eONyGU1WtmhhN.jpg'),
(150449, 10753, 'Snoopy Vai Acampar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/383543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8lHAhkvLCTYoKrK3aq7vI9IDHoj.jpg'),
(150450, 10753, 'Snoopy Vai Acampar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/383544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1gpHXy5eVpsGc3p3PLQTqBjDkJ.jpg'),
(150451, 10753, 'Snoopy Vai Acampar S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/383545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nsBbixaxkwt8qDGMZqDKuEtVRg6.jpg'),
(150452, 10753, 'Snoopy Vai Acampar S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/383546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1nYunJyfCaL8VMd9kY6uUoxmgeY.jpg'),
(150453, 10753, 'Snoopy Vai Acampar S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/383547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qzecDZL3LVzYXkcAE8lkoy0QH0R.jpg'),
(150454, 10754, 'Black ish S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/385524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/apr5o6p2yc1jNeXaZZfUpvwEuFK.jpg'),
(150455, 10754, 'Black ish S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/385525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/537h62rVsw83VS1aKHsO1Wf55ZU.jpg'),
(150456, 10754, 'Black ish S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/385526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b3iOF06qDeEdLBD4VrWMyJsXE2U.jpg'),
(150457, 10754, 'Black ish S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/385527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pVK4kXW9Hn7CwuSpdkS3pOmdLuC.jpg'),
(150458, 10754, 'Black ish S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/385528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qyx0swZ9GjfRrkAQ2LdCUmYUp0O.jpg'),
(150459, 10754, 'Black ish S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/385529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tND8n39T0pqAf971oAvne6CwxGI.jpg'),
(150460, 10754, 'Black ish S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/385530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gFP6mKKZWyytJzSpJgsK6qxjyZp.jpg'),
(150461, 10754, 'Black ish S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/385531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bwZ3wd7o2ELPRw8dph5DrboedKT.jpg'),
(150462, 10754, 'Black ish S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/385532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cdL6H1216HGKaunvDDYzNnpTAS4.jpg'),
(150463, 10754, 'Black ish S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/385533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uzErelhUu7y7ikhEkGcS0qJZhS3.jpg'),
(150464, 10754, 'Black ish S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/385534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/faioAIKsULLrIBVtq37PYSGr8dV.jpg'),
(150465, 10754, 'Black ish S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/385535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l1UZbn2Ddy4epZihmkkDKPDmOw6.jpg'),
(150466, 10754, 'Black ish S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/385536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5vjIZbRhsPeh8Q7qxPSbfNvH9fQ.jpg'),
(150467, 10754, 'Black ish S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/385537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A02CHg1gDBSxEN6rJXAhcmTCwOQ.jpg'),
(150468, 10754, 'Black ish S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/385538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j8LrAMXMr9SM8U0HoyC2j7EktHk.jpg'),
(150469, 10754, 'Black ish S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/385539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vsw9YFkrj6ihPXZU7fN5t8LWDmH.jpg'),
(150470, 10754, 'Black ish S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/385540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Ac4uljP8wSjgrmd2hEKV4H0yDv.jpg'),
(150471, 10754, 'Black ish S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/385541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/36cO2xtkMC82BHzUs0moLmGkyFu.jpg'),
(150472, 10754, 'Black ish S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/385542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/huK8i4nDT3qe9mvU6LaSfs7IIB6.jpg'),
(150473, 10754, 'Black ish S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/385543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Sb4om3T6fqzvODmQxYT3bsTqOd.jpg'),
(150474, 10754, 'Black ish S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/385544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/731xs3rl1VhL1sh2rxR7C7vtSxX.jpg'),
(150475, 10754, 'Black ish S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/385545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/78hj5qFDk71TRg5WUbGFOVY2KXR.jpg'),
(150476, 10754, 'Black ish S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/385546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pHXyBZmVvvSksq3KlBncExJmDsy.jpg'),
(150477, 10754, 'Black ish S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/385547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uT9WoUFgGBlzlKYcpomKbX24SHo.jpg'),
(150478, 10755, 'Black ish S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/385548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/efn80XqyKsUHrDtDcNW48sV5LcA.jpg'),
(150479, 10755, 'Black ish S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/385549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9MwMvIqDgRcsSmgQRcZZNn2Du3a.jpg'),
(150480, 10755, 'Black ish S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/385550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jXJADSMtxG4fCLrVTlf3gTvT36G.jpg'),
(150481, 10755, 'Black ish S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/385551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sSxngcSORGOJxvfvSPFPfQNEYGB.jpg'),
(150482, 10755, 'Black ish S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/385552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gCapAsfyhvx0nw1uX8ev4LJOj90.jpg'),
(150483, 10755, 'Black ish S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/385553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sXlD83agOmO09Sf1am1rMdNj5t7.jpg'),
(150484, 10755, 'Black ish S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/385554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lKkmzeMGyetUjN9ehFl6V1hUdRn.jpg'),
(150485, 10755, 'Black ish S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/385555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kOJabUuACjnHEN8ksuCPVBejwAB.jpg'),
(150486, 10755, 'Black ish S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/385556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t61XH9TQG1pi5h7koR7z8lXGmj8.jpg'),
(150487, 10755, 'Black ish S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/385557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aDXOTAJTFQkdSRNCGjpBAND0xsE.jpg'),
(150488, 10755, 'Black ish S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/385558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mo2aucLvzJvZxSr0i5V2ZzfWsp4.jpg'),
(150489, 10755, 'Black ish S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/385559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/warhLD7ur2pPqPLGBZDi3dtkGSY.jpg'),
(150490, 10755, 'Black ish S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/385560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bKgfQirOltzsrHjG7Trj00nUk5I.jpg'),
(150491, 10755, 'Black ish S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/385561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uNo4rCIBbTEGFO323mRZrU7CvjR.jpg'),
(150492, 10755, 'Black ish S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/385562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nczTyNfI0cbVHWxIsT9NZSpGgrW.jpg'),
(150493, 10755, 'Black ish S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/385563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cFS7q97nNnnyhmVGA04sXTdBlNP.jpg'),
(150494, 10755, 'Black ish S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/385564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4celgldWarYcOE2T8VDlWjrrU5R.jpg'),
(150495, 10755, 'Black ish S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/385565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4SJSV3Eo7z9umamVIeJy6ELJDfB.jpg'),
(150496, 10755, 'Black ish S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/385566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hxua0DszmQWANtZzDu1tDNmhbsy.jpg'),
(150497, 10755, 'Black ish S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/385567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h2zJV2dKhTWOeRjiRfvQjwc1PMF.jpg'),
(150498, 10755, 'Black ish S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/385568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vdmgFlqR0Nv2tk0H0YGlulmWpCG.jpg'),
(150499, 10755, 'Black ish S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/385569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ovay34WdiiUZ55OtrSqlOa829mO.jpg'),
(150500, 10755, 'Black ish S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/385570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oRUIDSXbgx0qNQLYn04HdMhjy6e.jpg'),
(150501, 10756, 'Black ish S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/385571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/NHYG4zazQblCacxDkyloOZu9PF.jpg'),
(150502, 10756, 'Black ish S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/385572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzzuYkAdxn3H96cztfaYOE2X4Xj.jpg'),
(150503, 10756, 'Black ish S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/385573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jrHQmAUkMHrpcZwysm3IiKEGBPz.jpg'),
(150504, 10756, 'Black ish S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/385574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sjKL4P3kOBRJVszruwKlOIlIi74.jpg'),
(150505, 10756, 'Black ish S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/385575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aRLCroqEmlPiuJe1rHOqXbXW8HZ.jpg'),
(150506, 10756, 'Black ish S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/385576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/85KBxyqSkfHFoI9WrkDjKcxxMR6.jpg'),
(150507, 10756, 'Black ish S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/385577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZMncO22qsPnKWc0aYLpKG0aR9f.jpg'),
(150508, 10756, 'Black ish S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/385578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fIy3q4wMsNF1QAlWakbTLiuA0Ju.jpg'),
(150509, 10756, 'Black ish S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/385579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7YxJufsCsg6jXY0LjiI5iLWB6HS.jpg'),
(150510, 10756, 'Black ish S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/385580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cVB8q3avLxJVimvEReeGj7NCxdp.jpg'),
(150511, 10756, 'Black ish S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/385581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xHQHJtL46ZfmqDPdMbuPQsj409.jpg'),
(150512, 10756, 'Black ish S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/385582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jwK281fUK2XNztNOpFVAWmymTIx.jpg'),
(150513, 10756, 'Black ish S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/385583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yUOmTSggI20Gdjz9tybDjefXRXX.jpg'),
(150514, 10756, 'Black ish S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/385584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/40ki6BkYeScs2V2t53TjfCklXVd.jpg'),
(150515, 10756, 'Black ish S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/385585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ao9BAYDQApiijlFJKpMtgthRUx.jpg'),
(150516, 10756, 'Black ish S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/385586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lg9FkYGkwk6WVkhV86UOHWoOi8Y.jpg'),
(150517, 10756, 'Black ish S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/385587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hbw8e3JPh6gfabybjoXRYatpsdK.jpg'),
(150518, 10756, 'Black ish S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/385588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCGgtUhST6AmaVpIsAy1FC4YAbX.jpg'),
(150519, 10756, 'Black ish S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/385589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/919rCzeWrax71ENQjfMUC3FZX35.jpg'),
(150520, 10756, 'Black ish S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/385590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Hl1FdT3SE2A7sYDxB3mJTw4DxL.jpg'),
(150521, 10756, 'Black ish S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/385591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/26xfsAjBTSGmifZJNufy32Snvw2.jpg'),
(150522, 10756, 'Black ish S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/385592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/94ksTn5LlX8mA2CdMKzX78gk1QG.jpg'),
(150523, 10756, 'Black ish S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/385593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3avFIHzfZnsw1pL4sSCDBqfTj8.jpg'),
(150524, 10756, 'Black ish S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/385594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zaGvY11LcCsj4ugES0zYOVXOUg2.jpg'),
(150525, 10757, 'Black ish S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/385595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jY1wxobR6p6lrJe3cF1refHfI6B.jpg'),
(150526, 10757, 'Black ish S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/385596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jI3GjxdACRLkHl9NOYzhxkNE2Sg.jpg'),
(150527, 10757, 'Black ish S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/385597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAtMRfWrxbvxXkz3fA4a1bzgdYo.jpg'),
(150528, 10757, 'Black ish S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/385598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wQDcxNkdx0di2Bd9KubF35EeEmQ.jpg'),
(150529, 10757, 'Black ish S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/385599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iPguxKwiri9rq5D7J4lYlJtNLO.jpg'),
(150530, 10757, 'Black ish S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/385600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1KBVC2aHwq41uN3023JKLCJose8.jpg'),
(150531, 10757, 'Black ish S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/385601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eYTb9N3wwBKqGtq8TDKEY4m6GW6.jpg'),
(150532, 10757, 'Black ish S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/385602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kWeVjA1EX3jLrJdn0Vwl8yQDtJD.jpg'),
(150533, 10757, 'Black ish S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/385603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLKKtsddyN8mNkGEBxW4mVqRCoc.jpg'),
(150534, 10757, 'Black ish S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/385604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ejnbmIA7jxajmjong4wJzI334rF.jpg'),
(150535, 10757, 'Black ish S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/385605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5LNtQuOczgkB3TtDYrKc6wInLEe.jpg'),
(150536, 10757, 'Black ish S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/385606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCdtN2gWT5J3SIXuCiN0CMUz8PE.jpg'),
(150537, 10757, 'Black ish S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/385607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8djHL3NucTrmhX6Le3gQ2SLkEmg.jpg'),
(150538, 10757, 'Black ish S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/385608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bX6ITcwLf3QBUBYh5KtnVLnjLwk.jpg'),
(150539, 10757, 'Black ish S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/385609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pR6SxVscaJNTga27UIq47dyKSou.jpg'),
(150540, 10757, 'Black ish S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/385610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qXLtTtpBnTcT7tRXTLjA8iQa8I0.jpg'),
(150541, 10757, 'Black ish S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/385611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hOP6dzuUF8vaDsQCCoBXkbPSnmv.jpg'),
(150542, 10757, 'Black ish S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/385612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1XGosepsX2yzoSRgCIwMqrIEIT6.jpg'),
(150543, 10757, 'Black ish S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/385613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sdRsEWs9aN4iDcxlamSjjH1vpuF.jpg'),
(150544, 10757, 'Black ish S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/385614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nvh67JMM4MXoRAYHEfAUI2sLAF9.jpg'),
(150545, 10757, 'Black ish S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/385615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/10fVq6vjX1fOQa8sVy35YLuMrcy.jpg'),
(150546, 10757, 'Black ish S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/385616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4x1ZVG21GrDKRUSAJn2BP1m4iWZ.jpg'),
(150547, 10757, 'Black ish S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/385617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tbySzpT2xt0YiM16ZdWYlp8Pkw5.jpg'),
(150548, 10758, 'Black ish S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/385618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nNO05Ekwffnv5DITOuUrDQHm733.jpg'),
(150549, 10758, 'Black ish S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/385619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t2AebDDucvwRtvuUwDFl8gYyFDM.jpg'),
(150550, 10758, 'Black ish S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/385620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s2jMK0sLSuRVIoilKL12u7CGwBm.jpg'),
(150551, 10758, 'Black ish S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/385621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qF4SDSyrCgjTy27JMOd5QcVUIB9.jpg'),
(150552, 10758, 'Black ish S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/385622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rsb8Wz7qhOmr6uQDZLYt55kfM40.jpg'),
(150553, 10758, 'Black ish S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/385623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fMnGRlXubTyTudAuWyrAlgHQeKm.jpg'),
(150554, 10758, 'Black ish S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/385624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sUommHZby0x115t0U79rRvN0VHT.jpg'),
(150555, 10758, 'Black ish S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/385625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p5mnWW0ZZdanie3TsdmiPQEfOEY.jpg'),
(150556, 10758, 'Black ish S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/385626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ysnG6jc2OlmiKHclO7Z0tHnagFS.jpg'),
(150557, 10758, 'Black ish S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/385627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sxKqbhVS9LumQwormL2ulhUd5rk.jpg'),
(150558, 10758, 'Black ish S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/385628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iDmQTSAiNrtImokzIIfaw0WVIGq.jpg'),
(150559, 10758, 'Black ish S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/385629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tLFI0Xli0h77OgZ6PI4SSXGM5ll.jpg'),
(150560, 10758, 'Black ish S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/385630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dULWCgyhBejyUVTLmnYPtO3SyMo.jpg'),
(150561, 10758, 'Black ish S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/385631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7TYn5QeKA6WhOOWwKLNQQInwgHw.jpg'),
(150562, 10758, 'Black ish S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/385632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpsbM88cZYwmbHDuTTSBrQo2blx.jpg'),
(150563, 10758, 'Black ish S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/385633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Sq1GH9pIqr5YJiDGA4eRw1Yb5L.jpg'),
(150564, 10758, 'Black ish S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/385634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Q7yF02RelUMT1dKiwhetzi1rkc.jpg'),
(150565, 10758, 'Black ish S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/385635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n62Qm5qDqfN6JSOHHj4CPcnqa9T.jpg'),
(150566, 10758, 'Black ish S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/385636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8MmrlEbdskHTINxhSlOfYcfBapQ.jpg'),
(150567, 10758, 'Black ish S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/385637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ahs3csRJ0ztxfGfFNKBWBZeSKnR.jpg'),
(150568, 10758, 'Black ish S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/385638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dqbyvQZpqBHh7fR7li8ga9xak7m.jpg'),
(150569, 10758, 'Black ish S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/385639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yhyRu7ki45cNIw6tbBcFWzNTFwT.jpg'),
(150570, 10758, 'Black ish S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/385640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mggMVsSJTC5cx5hNsz8V4sUOsE2.jpg'),
(150571, 10759, 'Black ish S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/385641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g38AvgHBmbAHFJTz9kobFSd53EF.jpg'),
(150572, 10759, 'Black ish S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/385642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qQWPDU9gUji9XVzTbZryKNwLdpP.jpg'),
(150573, 10759, 'Black ish S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/385643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3995iC0PdAVBzjvJe7eMjqV8Ezk.jpg'),
(150574, 10759, 'Black ish S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/385644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uQeZnHwndKR0MDdWVOLvXH9acOT.jpg'),
(150575, 10759, 'Black ish S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/385645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qQPVoMATDZKFHfgK3GlRUOgPpki.jpg'),
(150576, 10759, 'Black ish S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/385646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kfaSOsFdkiF3FqS2LpmJLTeJp5F.jpg'),
(150577, 10759, 'Black ish S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/385647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h7XVtsN0ds2vGLNVltXHV6ebwS8.jpg'),
(150578, 10759, 'Black ish S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/385648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Ed8FDDfc5aiFCrpbJ8g1SqNTiK.jpg'),
(150579, 10759, 'Black ish S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/385649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qcqnP2E9z4v0BXUZEKjeDtAHPqe.jpg'),
(150580, 10759, 'Black ish S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/385650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kTgfi5AoIqPAgU4m7lpkJ0YDeJC.jpg'),
(150581, 10759, 'Black ish S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/385651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8rcnl0A8ENGcDRoujMf1I7InDJP.jpg'),
(150582, 10759, 'Black ish S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/385652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jQnxDvW9s6YhqaF7mUsIdDDLRdN.jpg'),
(150583, 10759, 'Black ish S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/385653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eAwcS3dMUJUuMHCEQcrw9XW4vnv.jpg'),
(150584, 10759, 'Black ish S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/385654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/edBADo58DEzydkhI99iyb5XJ0AL.jpg'),
(150585, 10759, 'Black ish S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/385655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/smKaK4m6R3cC1k0ElxNKQSViO8p.jpg'),
(150586, 10759, 'Black ish S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/385656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QtL3b7UlJa5v8qH5p0Y7Iacgxv.jpg'),
(150587, 10759, 'Black ish S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/385657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sWcSxOFoXCBY0n5JZFRbckKE2Xk.jpg'),
(150588, 10759, 'Black ish S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/385658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kMxlw4L9YbCbJhjqIILj6xMxSRm.jpg'),
(150589, 10759, 'Black ish S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/385659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dzs7tPq0MJgPrMcXxBFPI5wohqX.jpg'),
(150590, 10759, 'Black ish S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/385660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tvbilU5AnNAM2YBbR3LGi4rAzQy.jpg'),
(150591, 10759, 'Black ish S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/385661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dhuVxM3VlsKDdWCoJMGic1yE0Mi.jpg'),
(150592, 10759, 'Black ish S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/385662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fvCer1Pc2cSbdPwYYYLqqu5lBWi.jpg'),
(150593, 10759, 'Black ish S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/385663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q882WaiAxe5yEDydSeEB3f8mdEP.jpg'),
(150594, 10760, 'Black ish S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/385664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/voDztE3A7Cu5GJyQYHxlDcuQTOg.jpg'),
(150595, 10760, 'Black ish S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/385665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hOPceiHUpgDnupCheD6m1nRSTqg.jpg'),
(150596, 10760, 'Black ish S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/385666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/trP3Fs87IpVwj3Q73JBZ6th0lkW.jpg'),
(150597, 10760, 'Black ish S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/385667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2G1zbc2CON48Y2V71s4cQebRDxz.jpg'),
(150598, 10760, 'Black ish S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/385668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hfWiLwGFUS7zsEdgTSPQtDQDSIs.jpg'),
(150599, 10760, 'Black ish S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/385669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ei0G3VBFfWIFlJez06dG3B7of10.jpg'),
(150600, 10760, 'Black ish S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/385670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5IrXtZEk6mZBIuC2XkVAOzhg0cl.jpg'),
(150601, 10760, 'Black ish S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/385671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/znMcWscOGgWz3AcvkF5crxDGIUI.jpg'),
(150602, 10760, 'Black ish S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/385672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a7bZwtGF2b8w02iP3Z6Vk8c6dv7.jpg'),
(150603, 10760, 'Black ish S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/385673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzVKCBYt3qYnDbY5NPS3stPlZe0.jpg'),
(150604, 10760, 'Black ish S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/385674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hW32XRqGrg5MJUabU66Yp69kGkc.jpg'),
(150605, 10760, 'Black ish S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/385675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lCR0EtedRTk3x7vY3Pr8N2zgu00.jpg'),
(150606, 10760, 'Black ish S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/385676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3oqEvAHMoJ3ADfVGloBt1HygZkz.jpg'),
(150607, 10761, 'Thank You Goodnight A Historia de Bon Jovi [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/385458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3PnxGflBVEloS56beEDi97524pw.jpg'),
(150608, 10761, 'Thank You Goodnight A Historia de Bon Jovi [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/385459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9dvaaXBdXm70IkzvzkHJWmoTdPE.jpg'),
(150609, 10761, 'Thank You Goodnight A Historia de Bon Jovi [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/385460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uo4FWHoYIoZLgltPdQwuVSw3Wvl.jpg'),
(150610, 10761, 'Thank You Goodnight A Historia de Bon Jovi [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/385461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ZS4B0Jui9brg6mBezteCruJKx6.jpg'),
(150611, 10762, 'As Cheerleaders do Dallas Cowboys S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/385386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wW7dNpzzi3kJFGghv5kiQkWQozq.jpg'),
(150612, 10762, 'As Cheerleaders do Dallas Cowboys S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/385387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k2amefvqvzCyzszwjZhil1qISou.jpg'),
(150613, 10762, 'As Cheerleaders do Dallas Cowboys S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/385388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hKPFMWBOffQQ1RVzUF3n4qOF0SU.jpg'),
(150614, 10762, 'As Cheerleaders do Dallas Cowboys S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/385389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5SVgtad6Tt0LB1JY3VLvCj99h3G.jpg'),
(150615, 10762, 'As Cheerleaders do Dallas Cowboys S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/385390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q2jsHSWcJsDUMj5RR7nfWkx8JNI.jpg'),
(150616, 10762, 'As Cheerleaders do Dallas Cowboys S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/385391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4e297vDGqput4K34Ll7F3HJcOSW.jpg'),
(150617, 10762, 'As Cheerleaders do Dallas Cowboys S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/385392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yeLgStfDlct6mlJVjJ8A9SeXU5.jpg'),
(150618, 10763, 'As Cheerleaders do Dallas Cowboys S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/844634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2VhSkommoalG1BOlMteuS5DAV7.jpg'),
(150619, 10763, 'As Cheerleaders do Dallas Cowboys S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/844635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2VhSkommoalG1BOlMteuS5DAV7.jpg'),
(150620, 10763, 'As Cheerleaders do Dallas Cowboys S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/844636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2VhSkommoalG1BOlMteuS5DAV7.jpg'),
(150621, 10763, 'As Cheerleaders do Dallas Cowboys S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/844637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2VhSkommoalG1BOlMteuS5DAV7.jpg'),
(150622, 10763, 'As Cheerleaders do Dallas Cowboys S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/844638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2VhSkommoalG1BOlMteuS5DAV7.jpg'),
(150623, 10763, 'As Cheerleaders do Dallas Cowboys S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/844639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2VhSkommoalG1BOlMteuS5DAV7.jpg'),
(150624, 10763, 'As Cheerleaders do Dallas Cowboys S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/844640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/p2VhSkommoalG1BOlMteuS5DAV7.jpg'),
(150625, 10764, 'Familia Soprano S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rp60DTAFpbaz9vaC1G9SVzQgwOM.jpg'),
(150626, 10764, 'Familia Soprano S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/huaDp6GlmXQgqSVQSzVykMOVS02.jpg'),
(150627, 10764, 'Familia Soprano S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pR7Ag4lzWOexnzfsCXvZP6HkyD0.jpg'),
(150628, 10764, 'Familia Soprano S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jnNSVBFDUsW0Wu5gvWcPW2eMW8N.jpg'),
(150629, 10764, 'Familia Soprano S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pqQ4I8TCdaLewD4N6KmJp2xbXc0.jpg'),
(150630, 10764, 'Familia Soprano S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wzk5RH2jMxB7gJut6y0YWNP9lwh.jpg'),
(150631, 10764, 'Familia Soprano S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mXHa6YCuGtuWmXrQstjWE1WR5sX.jpg'),
(150632, 10764, 'Familia Soprano S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k1KJoBCRAqoycRZ1gp4BZFhyuDY.jpg'),
(150633, 10764, 'Familia Soprano S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ijeGto0FdRz80hWGji4A2bIIiCS.jpg'),
(150634, 10764, 'Familia Soprano S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ByYOmaoM0nGGvuGZCADHGwvDZ8.jpg'),
(150635, 10764, 'Familia Soprano S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/390693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ozkAnGH5RDqZyVGXZrJXBOW3hUm.jpg'),
(150636, 10764, 'Familia Soprano S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1k7zhehsLVnJreZPt6nXZpECOlp.jpg'),
(150637, 10764, 'Familia Soprano S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/390695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wP8mcwsJ4TCcGsshslYlGOxW8Lf.jpg'),
(150638, 10765, 'Familia Soprano S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sq1g7fvRP2I0I8u5jDGZs1Hi63I.jpg'),
(150639, 10765, 'Familia Soprano S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eUmSRNXcDdTCbLf7xACxGEDAIgg.jpg'),
(150640, 10765, 'Familia Soprano S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5BDtxh2qUcEqVhEBLYMW5x6Dl8M.jpg'),
(150641, 10765, 'Familia Soprano S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zn8O3jl97w2v8pSDfUwBDjHxu8v.jpg'),
(150642, 10765, 'Familia Soprano S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3GscVIAqlY6shrdLHzi1w5Md0h8.jpg'),
(150643, 10765, 'Familia Soprano S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/metrJgcOJLONNAnbReeTSX2B7Yv.jpg'),
(150644, 10765, 'Familia Soprano S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/heFJp0OmNIWd1YFS0eKXWDWeDEp.jpg'),
(150645, 10765, 'Familia Soprano S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yub7FYe1LSVk54mmYuZf6bW4hze.jpg'),
(150646, 10765, 'Familia Soprano S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jsHFwt5e9nhfbLpku5I5AgjjN3r.jpg'),
(150647, 10765, 'Familia Soprano S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fxyNkfPJCKVP5DFHj3wYie5xHSk.jpg'),
(150648, 10765, 'Familia Soprano S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/390706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9H7qoVXODCVUsQtR2pKkvjO6doM.jpg'),
(150649, 10765, 'Familia Soprano S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nBUs5abBMFiBmXcMZROfSXnEhni.jpg'),
(150650, 10765, 'Familia Soprano S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/390708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iPO5z1RCP89nIDxLeMu5Wotxaap.jpg'),
(150651, 10766, 'Familia Soprano S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bfHdyTgLjhKtpTurQ2XgW787jIL.jpg'),
(150652, 10766, 'Familia Soprano S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y4zOu1ckPyLfrXnGPJGiC9rTskS.jpg'),
(150653, 10766, 'Familia Soprano S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1BpUxjXB1kdShwRghR9MDf0PYk8.jpg'),
(150654, 10766, 'Familia Soprano S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/38hfWxzdDXPFw516LI0hbsljcXe.jpg'),
(150655, 10766, 'Familia Soprano S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y2SU9ZukxnJWpExdHe7xw9YOnx6.jpg'),
(150656, 10766, 'Familia Soprano S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nTvv5YqLijFB6hYiUl1eTQJO0UF.jpg'),
(150657, 10766, 'Familia Soprano S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gcjVBMBGqEZ46w6dHXAUgrH8M3j.jpg'),
(150658, 10766, 'Familia Soprano S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gUUBdvGWoIJLkBPVErWpSYj1pVs.jpg'),
(150659, 10766, 'Familia Soprano S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ijzLHouwQazSXpy2484HH7sxl3x.jpg'),
(150660, 10766, 'Familia Soprano S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jq8B8FTl6Njd7D0Tc6fkMgAnJ3m.jpg'),
(150661, 10766, 'Familia Soprano S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/390719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ftAHLYsZ8bcRTVPxooFxDT0MXah.jpg'),
(150662, 10766, 'Familia Soprano S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7rjDtpW3KUbh03qCJM2mZ7cMxGm.jpg'),
(150663, 10766, 'Familia Soprano S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/390721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xBSp07br6VSEmW7Pr0X9M277VOs.jpg'),
(150664, 10767, 'Familia Soprano S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xO3T1PISHcbB05kPisgD3JXLTIr.jpg'),
(150665, 10767, 'Familia Soprano S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LBcvYZwOynX8Xh9gPfRDTgVPTQ.jpg'),
(150666, 10767, 'Familia Soprano S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aV7wUP0kccC7uRbep76V74ZxqDm.jpg'),
(150667, 10767, 'Familia Soprano S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5GFFv4DQipJM21uZU4mb7Fbkgp3.jpg'),
(150668, 10767, 'Familia Soprano S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u7sIWsv4NFapjb3FqASfyiWNDUV.jpg'),
(150669, 10767, 'Familia Soprano S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vdxZUMRhL2hGCBw1bQvRPrOnmEi.jpg'),
(150670, 10767, 'Familia Soprano S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJ8efBXIf8hBX2zGT3xiNzlROUP.jpg'),
(150671, 10767, 'Familia Soprano S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1g8Sor8N5DJchtber24nDjzq7y4.jpg'),
(150672, 10767, 'Familia Soprano S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iGgZeLq9WDgLPpRgkjMI99zOe2c.jpg'),
(150673, 10767, 'Familia Soprano S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q8KCna8fodFEFNmdxWJK30IGdMu.jpg'),
(150674, 10767, 'Familia Soprano S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/390732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Qsji9ovsqBZpvdnf5COzxb0MxC.jpg'),
(150675, 10767, 'Familia Soprano S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jvccKapn8uNkr24LpGSpCZ3Uytn.jpg'),
(150676, 10767, 'Familia Soprano S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/390734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nbmCZQE2yEf6u8UwUxrWPcAB3dH.jpg'),
(150677, 10768, 'Familia Soprano S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eY7Wx365ejifI6PQ8sfesC1aK3J.jpg'),
(150678, 10768, 'Familia Soprano S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jGEqcOgC74jqFmke2lCtVbzKzz0.jpg'),
(150679, 10768, 'Familia Soprano S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wIEzCGhXzRNiIDXdPmNkC8by9Dz.jpg'),
(150680, 10768, 'Familia Soprano S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i0mYCpasuXQVlnumasDjOV4m1bz.jpg'),
(150681, 10768, 'Familia Soprano S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7es2rVmIh3t1QTOyL8yf0z6LU8Q.jpg'),
(150682, 10768, 'Familia Soprano S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jfvUtoGR905z52pPzjHlPq5mHGZ.jpg'),
(150683, 10768, 'Familia Soprano S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1xR5XUpHj2A99oUkU1N4HLAVJFF.jpg'),
(150684, 10768, 'Familia Soprano S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q55n1umJwLBJSqoQnbaErKGEQR6.jpg'),
(150685, 10768, 'Familia Soprano S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2EhiCPz5hRHA7q0ATaU3ZPbZqkW.jpg'),
(150686, 10768, 'Familia Soprano S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wkb8rrxVlV9xzqDNKVkbTmEsBd.jpg'),
(150687, 10768, 'Familia Soprano S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/390745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ltTDXuP2P0yFOHLIkq92wZXMtlb.jpg'),
(150688, 10768, 'Familia Soprano S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iLTJ5S8G9q1jeg9FthaN3ITa3zP.jpg'),
(150689, 10768, 'Familia Soprano S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/390747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fC9a76KVi8hPrMmLcY2KN8Fti71.jpg'),
(150690, 10769, 'Familia Soprano S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t3qm4IPssY2vyR7NndVBBblyxFi.jpg'),
(150691, 10769, 'Familia Soprano S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5K8m3nLdBPpuWCTzgdX7smwogJq.jpg'),
(150692, 10769, 'Familia Soprano S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wkCf1gon6RGJk95SqJEVZss0k94.jpg'),
(150693, 10769, 'Familia Soprano S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vCyDuOdaeEg37YBi5NNw8ANC8vw.jpg'),
(150694, 10769, 'Familia Soprano S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f6LWpHGYIRzYsOlFP3vUgomPhD8.jpg'),
(150695, 10769, 'Familia Soprano S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bAFFzG0Vu5k7fQ0hrT3xc0aA3xM.jpg'),
(150696, 10769, 'Familia Soprano S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g2mryp7b4MzkY3ODscvX0ad8V94.jpg'),
(150697, 10769, 'Familia Soprano S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/toZRM9DALHMcsrRq7W0Ks7weIk3.jpg'),
(150698, 10769, 'Familia Soprano S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7QbIIT6k0oxzHgJEVBcUtyiA7Gz.jpg'),
(150699, 10769, 'Familia Soprano S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6o4d4gZTO6vY5lsfqESaFmrmknf.jpg'),
(150700, 10769, 'Familia Soprano S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/390758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/swfz12c6D2Q8oBRGB4qQbdEzPAH.jpg'),
(150701, 10769, 'Familia Soprano S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6QwO0QsSrnLtOwkIrX9OxDQSnIM.jpg'),
(150702, 10769, 'Familia Soprano S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/390760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tNenW6tQPtDLYcDRpuvDlKcNT3R.jpg'),
(150703, 10769, 'Familia Soprano S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/390761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jq8W6gUrbPWMRIwmAYeXhrNk9Ia.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(150704, 10769, 'Familia Soprano S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/390762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s9PqugLdNkzOujoN4aiRwD5xuK9.jpg'),
(150705, 10769, 'Familia Soprano S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/390763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bEi5gMeepKrcwo85XCdZ1p6DlOL.jpg'),
(150706, 10769, 'Familia Soprano S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/390764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bkHqIMkENTRZISILm607ixwPKZK.jpg'),
(150707, 10769, 'Familia Soprano S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/390765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8RVwXqFRvVCVMwYKYFqgIMs9Wmi.jpg'),
(150708, 10769, 'Familia Soprano S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/390766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gOf37LsQJ7qV75YkxGS0SKAixoP.jpg'),
(150709, 10769, 'Familia Soprano S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/390767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6AznnF21DOiPsnaHDgCbxrcgH1d.jpg'),
(150710, 10769, 'Familia Soprano S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/390768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7PnsVHIZEw5YB1qegg2leAIjKnx.jpg'),
(150711, 10770, 'Gangues da Galicia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/604680.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/629GCyuSiAGspYVBRlZP6HSdgBE.jpg'),
(150712, 10770, 'Gangues da Galicia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/604682.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/elzbArsJFhSiog2xvYQhr8x6xCO.jpg'),
(150713, 10770, 'Gangues da Galicia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/604684.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a8IpIAJgjQlJCixhfw26dwSiBZz.jpg'),
(150714, 10770, 'Gangues da Galicia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/604686.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tRT3frFkj9k0L07buXU4BhRjVzH.jpg'),
(150715, 10770, 'Gangues da Galicia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/604688.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y1YJvrSviv7ygoUpgyzzgWutk4V.jpg'),
(150716, 10770, 'Gangues da Galicia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/604690.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/174kKTzA9Rg6AAjDLvo0oKalgXq.jpg'),
(150717, 10770, 'Gangues da Galicia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/604692.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zghaT39SKcOaBWnmfhetEwF4weu.jpg'),
(150718, 10770, 'Gangues da Galicia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7CRPtNIylSfnRsqZn35cmMbvLA2.jpg'),
(150719, 10770, 'Gangues da Galicia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7CRPtNIylSfnRsqZn35cmMbvLA2.jpg'),
(150720, 10770, 'Gangues da Galicia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7CRPtNIylSfnRsqZn35cmMbvLA2.jpg'),
(150721, 10771, 'Na Cama com Pitanda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uOFI6dNLmWNV9XirbEddkga0Ygh.jpg'),
(150722, 10771, 'Na Cama com Pitanda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yzma9BSNi7BGNFoQlcZyKisca3v.jpg'),
(150723, 10771, 'Na Cama com Pitanda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/prMZfnSXoWrcrYrq3NtW5REJj08.jpg'),
(150724, 10771, 'Na Cama com Pitanda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hmAxuQyr1vJksSpMBTGwpndZmB7.jpg'),
(150725, 10771, 'Na Cama com Pitanda S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e9tZ82ksHtVBpcPSQspPn2988or.jpg'),
(150726, 10771, 'Na Cama com Pitanda S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/25XWPGZ0zfkL9iboM1OfhuutZ6i.jpg'),
(150727, 10771, 'Na Cama com Pitanda S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8jO44MX5kNMxcj8SgfqE9Ijsru.jpg'),
(150728, 10771, 'Na Cama com Pitanda S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kkcSQo2L0CdS3y7nmNNUccwEoB8.jpg'),
(150729, 10771, 'Na Cama com Pitanda S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJUKNJ1TldTiflBecjm1qE8AvGk.jpg'),
(150730, 10771, 'Na Cama com Pitanda S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Q1RgqHJWGJkG9dbvlIScnM1cGY.jpg'),
(150731, 10772, 'Meus Pes Estao Me Matando S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/YGsrXCEQUdyTzCXVTrSSIvIRah.jpg'),
(150732, 10772, 'Meus Pes Estao Me Matando S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ee33cUGaJ92ntC6J66y36z4sAsY.jpg'),
(150733, 10772, 'Meus Pes Estao Me Matando S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hMF0VwtUs5oyZgaIJ0TfzOf4xTe.jpg'),
(150734, 10772, 'Meus Pes Estao Me Matando S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i3rLpfQ9I5aIixaClDfJKyFSlUo.jpg'),
(150735, 10772, 'Meus Pes Estao Me Matando S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJ46o0AYRMD2VygvbErTRMQHVAh.jpg'),
(150736, 10772, 'Meus Pes Estao Me Matando S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2vL54u8uBZKghTIPErbnZfJ5dgC.jpg'),
(150737, 10772, 'Meus Pes Estao Me Matando S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jlcrAIzqKVvkHcefAo1bbvIpbED.jpg'),
(150738, 10772, 'Meus Pes Estao Me Matando S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oeWhEnFzNTh0y4nbXq2toAlDbrl.jpg'),
(150739, 10772, 'Meus Pes Estao Me Matando S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zEVTVWDKlwB9OadVC8z2PgT9zET.jpg'),
(150740, 10772, 'Meus Pes Estao Me Matando S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tRQDazsa06KNg5XdD3HMsGHroFd.jpg'),
(150741, 10773, 'Meus Pes Estao Me Matando S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c7GIVuyKZ0hg2OUVsOpgq48NkMJ.jpg'),
(150742, 10773, 'Meus Pes Estao Me Matando S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Bw2WbB2OEnu84NhZ7lQXKrwgDL.jpg'),
(150743, 10773, 'Meus Pes Estao Me Matando S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x9nVmEGs49MjMUgygfltb89RA9g.jpg'),
(150744, 10773, 'Meus Pes Estao Me Matando S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6mWXVDvhnsUSHyvPLRFvFiyLtjD.jpg'),
(150745, 10773, 'Meus Pes Estao Me Matando S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4m8Iis2N4GjzzBtGB2jR558BH8S.jpg'),
(150746, 10773, 'Meus Pes Estao Me Matando S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jR1LcO4i5RQBDlZuTo3c7cAMnNk.jpg'),
(150747, 10773, 'Meus Pes Estao Me Matando S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jVfTH77ibb3vDLAxAz9QE7EnJ4p.jpg'),
(150748, 10773, 'Meus Pes Estao Me Matando S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xDRaC7bf8LiDWK80C9s9GbQGCOZ.jpg'),
(150749, 10773, 'Meus Pes Estao Me Matando S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bozbJ8hozyGFwTemyCPbZBJwN5B.jpg'),
(150750, 10773, 'Meus Pes Estao Me Matando S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/atgdco9sIydxSXWLftqNKll78RR.jpg'),
(150751, 10774, 'Meus Pes Estao Me Matando S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pDjO86jqoOor8xdq8Q4818nIs0S.jpg'),
(150752, 10774, 'Meus Pes Estao Me Matando S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gFWqMuqktppzwLy1nlQfqFnjvN8.jpg'),
(150753, 10774, 'Meus Pes Estao Me Matando S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3OXYegj7ReQZaXwosn56amSDzH8.jpg'),
(150754, 10774, 'Meus Pes Estao Me Matando S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2UjdBJTg70ESNTw13dtWLnbQKK1.jpg'),
(150755, 10774, 'Meus Pes Estao Me Matando S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZtqm333pgwn0n27ZRRnba5i6gq.jpg'),
(150756, 10774, 'Meus Pes Estao Me Matando S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d6WJtfNW1KOK5beTDtsC1AV7lez.jpg'),
(150757, 10774, 'Meus Pes Estao Me Matando S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUOfi4VtNKQEaJ9SZvOdxmPObE0.jpg'),
(150758, 10774, 'Meus Pes Estao Me Matando S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wrfnBMG7GDIIcvWT9tOsxb90nqD.jpg'),
(150759, 10774, 'Meus Pes Estao Me Matando S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tQlUl2o8tMYPufiBmCuuiENJhQ0.jpg'),
(150760, 10774, 'Meus Pes Estao Me Matando S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fKpOnFVp0GkEAPcFnfRUgZWmNhT.jpg'),
(150761, 10775, 'Meus Pes Estao Me Matando S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svG9D0Oxuj8PcO1ieTwcNTfURI5.jpg'),
(150762, 10775, 'Meus Pes Estao Me Matando S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jss19F8ZYRCh7qYdoPfpDPfG9Ua.jpg'),
(150763, 10775, 'Meus Pes Estao Me Matando S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mt5MYL7lYCgNqG0ETFJjFIKbAjc.jpg'),
(150764, 10775, 'Meus Pes Estao Me Matando S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Agab5e5rzEgod4p6rmbowSkiBaf.jpg'),
(150765, 10775, 'Meus Pes Estao Me Matando S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zIWr3cqSmv21BumMbgiLTNBE96k.jpg'),
(150766, 10775, 'Meus Pes Estao Me Matando S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AsRJRMeWAGGYzizZ4wzIED4CwBG.jpg'),
(150767, 10775, 'Meus Pes Estao Me Matando S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sBGKevugn5678IkwBd5pOww3pJO.jpg'),
(150768, 10775, 'Meus Pes Estao Me Matando S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oh8orKuc9rogHgYYRHbQOwtHh8z.jpg'),
(150769, 10775, 'Meus Pes Estao Me Matando S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d8NN511ZrKf36ShdiHS9IRciyce.jpg'),
(150770, 10775, 'Meus Pes Estao Me Matando S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fcVBCnXySlTkw0TDaa39ehCkEd7.jpg'),
(150771, 10776, 'Taken (2002) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3vdqUm1egVyE81yXtYidqVhR9GF.jpg'),
(150772, 10776, 'Taken (2002) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k4c2LOuvWprSqdshwqwzTbosF7j.jpg'),
(150773, 10776, 'Taken (2002) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rmGm02UkZqfQ0CiLAzoGk29NAJz.jpg'),
(150774, 10776, 'Taken (2002) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k7l1Mqws9xooabC3DAfrWSf7nwl.jpg'),
(150775, 10776, 'Taken (2002) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ofB8pelR958mUoUlykPo5kziIPF.jpg'),
(150776, 10776, 'Taken (2002) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1pOrw5P2M00AkXkfnaqzl0vxWB.jpg'),
(150777, 10776, 'Taken (2002) S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aNCcpLsLY6mRvjaY3ZkZUXuckwv.jpg'),
(150778, 10776, 'Taken (2002) S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1oZZiJdFCFZKV6umuS8QJH0OXhX.jpg'),
(150779, 10776, 'Taken (2002) S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oycPHTO0Op9hJQrMLjJOWAOxrDU.jpg'),
(150780, 10776, 'Taken (2002) S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fXilBNKytziKS7UBGAkTJOJathw.jpg'),
(150781, 10777, 'Anjo do Amor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rosmK2waGTdBlcDMwylE7wjMbzM.jpg'),
(150782, 10777, 'Anjo do Amor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tdbn4XVO59F6Vh1S11plDtLtlJZ.jpg'),
(150783, 10777, 'Anjo do Amor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pxaqMXOgc8xExv9ugrmIap8CpOp.jpg'),
(150784, 10777, 'Anjo do Amor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Ebcthv12v3erbYRQ8s0GzyynXi.jpg'),
(150785, 10777, 'Anjo do Amor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cPDLWp9nuK4DZLPaJkyghT8fopN.jpg'),
(150786, 10777, 'Anjo do Amor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/asUOR7j7YY24QHbzKxHSvsxIijv.jpg'),
(150787, 10777, 'Anjo do Amor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e6Ok3WONSezAnBs3JO3vTG7EGts.jpg'),
(150788, 10777, 'Anjo do Amor [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aNJTsSlQWdix2UB6DZJhtzScabZ.jpg'),
(150789, 10777, 'Anjo do Amor [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9BsAlZlsab00oSHstt2e1S6FRKV.jpg'),
(150790, 10777, 'Anjo do Amor [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d2oJey0yjaTlFL8yr0aJIsJ85tB.jpg'),
(150791, 10777, 'Anjo do Amor [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/390585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mGhQDRZrcOQ9lX5usq8hmQ4HDQa.jpg'),
(150792, 10777, 'Anjo do Amor [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aGt2XmLJAMuFwcYrJX9GMUQBBkF.jpg'),
(150793, 10777, 'Anjo do Amor [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/390587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lMfEy4yeq1TYr6d5FtO0fPTS3xW.jpg'),
(150794, 10777, 'Anjo do Amor [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/390588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vrRYBr20s4GfkZqwQAvSDfPpLW8.jpg'),
(150795, 10777, 'Anjo do Amor [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/390589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mO70hsNqyt5r64MdV5cHZul5k2W.jpg'),
(150796, 10777, 'Anjo do Amor [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/390590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3wUcvcX2FVI6H1pnZQbAxsg6ifl.jpg'),
(150797, 10778, 'NCIS Sydney [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wAa07lZ9HKAswaEtTuRXvX4RPaQ.jpg'),
(150798, 10778, 'NCIS Sydney [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9tzw6QOhvQyI7Pv3MVT9e2rVlb.jpg'),
(150799, 10778, 'NCIS Sydney [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k7F3HXULfhSjkx1jEeS7oE8GhbG.jpg'),
(150800, 10778, 'NCIS Sydney [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6o3V49R4C3gXjud1m62nO3oTdac.jpg'),
(150801, 10778, 'NCIS Sydney [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aAV9InBEzIFxxpnKJcTfvrS4OoE.jpg'),
(150802, 10778, 'NCIS Sydney [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/402955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(150803, 10778, 'NCIS Sydney [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/402956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(150804, 10778, 'NCIS Sydney [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/402957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(150805, 10779, 'NCIS Sydney [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/700073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(150806, 10779, 'NCIS Sydney [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/712602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(150807, 10779, 'NCIS Sydney [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/717918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(150808, 10779, 'NCIS Sydney [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/729086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(150809, 10779, 'NCIS Sydney [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/759900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(150810, 10779, 'NCIS Sydney [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/759901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(150811, 10779, 'NCIS Sydney [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/783170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(150812, 10779, 'NCIS Sydney [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/807153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(150813, 10779, 'NCIS Sydney [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/826593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(150814, 10779, 'NCIS Sydney [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/852670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(150815, 10780, 'NCIS Sydney [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/890609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(150816, 10780, 'NCIS Sydney [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/890610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(150817, 10780, 'NCIS Sydney [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/891781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(150818, 10780, 'NCIS Sydney [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/894172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(150819, 10780, 'NCIS Sydney [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/894173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(150820, 10780, 'NCIS Sydney [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/894804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(150821, 10780, 'NCIS Sydney [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/894805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(150822, 10780, 'NCIS Sydney [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/897378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(150823, 10781, 'A Rainha da Persia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150824, 10781, 'A Rainha da Persia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150825, 10781, 'A Rainha da Persia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150826, 10781, 'A Rainha da Persia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150827, 10781, 'A Rainha da Persia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150828, 10781, 'A Rainha da Persia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/398411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150829, 10781, 'A Rainha da Persia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/398412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150830, 10781, 'A Rainha da Persia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/398413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150831, 10781, 'A Rainha da Persia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/398414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150832, 10781, 'A Rainha da Persia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/398415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150833, 10781, 'A Rainha da Persia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/403775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150834, 10781, 'A Rainha da Persia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/403776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150835, 10781, 'A Rainha da Persia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/403777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150836, 10781, 'A Rainha da Persia S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/403778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150837, 10781, 'A Rainha da Persia S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/403779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150838, 10781, 'A Rainha da Persia S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/405427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150839, 10781, 'A Rainha da Persia S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/405428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150840, 10781, 'A Rainha da Persia S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/406497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150841, 10781, 'A Rainha da Persia S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/409721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150842, 10781, 'A Rainha da Persia S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/409722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150843, 10781, 'A Rainha da Persia S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/413053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150844, 10781, 'A Rainha da Persia S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/413054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150845, 10781, 'A Rainha da Persia S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/413055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150846, 10781, 'A Rainha da Persia S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/415134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150847, 10781, 'A Rainha da Persia S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/415135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150848, 10781, 'A Rainha da Persia S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/415136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150849, 10781, 'A Rainha da Persia S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/415137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150850, 10781, 'A Rainha da Persia S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/415138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150851, 10781, 'A Rainha da Persia S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/419835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150852, 10781, 'A Rainha da Persia S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/419836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wtgXUF7YcYbgeIiGrwNMXvrBVO7.jpg'),
(150853, 10782, 'Agents of Mystery S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gMohD6HO3cxrohb3Q9qtZrhqULD.jpg'),
(150854, 10782, 'Agents of Mystery S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rY2CcwH7SmiTDvTLZ5Zuvccwv8L.jpg'),
(150855, 10782, 'Agents of Mystery S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGUFhvqVAYAN4Huyn0X6MGVJLWq.jpg'),
(150856, 10782, 'Agents of Mystery S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pcjWuyYRQBra4nWZiq5TXHSbBVJ.jpg'),
(150857, 10782, 'Agents of Mystery S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mBpOXqp6sgYap5W1xar4sohGfp2.jpg'),
(150858, 10782, 'Agents of Mystery S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3yrBaWEBo83gMOLADtj5AtcnscJ.jpg'),
(150859, 10783, 'My Son Jeffrey The Dahmer Family Tapes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z3uUzPJqwmhh92EWDwj6Vd64zfd.jpg'),
(150860, 10783, 'My Son Jeffrey The Dahmer Family Tapes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/42KXaiHaFgDdVnlVennhvTRltbH.jpg'),
(150861, 10783, 'My Son Jeffrey The Dahmer Family Tapes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2eREFeEozNv185TbbmimEtur2C0.jpg'),
(150862, 10783, 'My Son Jeffrey The Dahmer Family Tapes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHG0YGdnTQgCKC5LBdSNzQdFGrS.jpg'),
(150863, 10784, 'Os Trapalhoes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150864, 10784, 'Os Trapalhoes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150865, 10784, 'Os Trapalhoes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150866, 10784, 'Os Trapalhoes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150867, 10784, 'Os Trapalhoes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150868, 10784, 'Os Trapalhoes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150869, 10784, 'Os Trapalhoes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150870, 10784, 'Os Trapalhoes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150871, 10784, 'Os Trapalhoes S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150872, 10784, 'Os Trapalhoes S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150873, 10784, 'Os Trapalhoes S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/390382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150874, 10784, 'Os Trapalhoes S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150875, 10784, 'Os Trapalhoes S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/390384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150876, 10784, 'Os Trapalhoes S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/390385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150877, 10784, 'Os Trapalhoes S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/390386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150878, 10784, 'Os Trapalhoes S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/390387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150879, 10784, 'Os Trapalhoes S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/390388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150880, 10784, 'Os Trapalhoes S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/390389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150881, 10784, 'Os Trapalhoes S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/390390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150882, 10784, 'Os Trapalhoes S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/390391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150883, 10784, 'Os Trapalhoes S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/390392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150884, 10784, 'Os Trapalhoes S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/390393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150885, 10784, 'Os Trapalhoes S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/390394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150886, 10784, 'Os Trapalhoes S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/390395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150887, 10784, 'Os Trapalhoes S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/390396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150888, 10784, 'Os Trapalhoes S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/390397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150889, 10784, 'Os Trapalhoes S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/390398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150890, 10784, 'Os Trapalhoes S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/390399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150891, 10784, 'Os Trapalhoes S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/390400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150892, 10784, 'Os Trapalhoes S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/390401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150893, 10784, 'Os Trapalhoes S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/390402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150894, 10784, 'Os Trapalhoes S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/390403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150895, 10784, 'Os Trapalhoes S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/390404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150896, 10784, 'Os Trapalhoes S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/390405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150897, 10784, 'Os Trapalhoes S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/390406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150898, 10784, 'Os Trapalhoes S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/390407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150899, 10784, 'Os Trapalhoes S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/390408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150900, 10784, 'Os Trapalhoes S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/390409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150901, 10784, 'Os Trapalhoes S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/390410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150902, 10785, 'Os Trapalhoes S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150903, 10785, 'Os Trapalhoes S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150904, 10785, 'Os Trapalhoes S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150905, 10785, 'Os Trapalhoes S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150906, 10785, 'Os Trapalhoes S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150907, 10785, 'Os Trapalhoes S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150908, 10785, 'Os Trapalhoes S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150909, 10785, 'Os Trapalhoes S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150910, 10785, 'Os Trapalhoes S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150911, 10785, 'Os Trapalhoes S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150912, 10785, 'Os Trapalhoes S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/390421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150913, 10785, 'Os Trapalhoes S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150914, 10785, 'Os Trapalhoes S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/390423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150915, 10785, 'Os Trapalhoes S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/390424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150916, 10785, 'Os Trapalhoes S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/390425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150917, 10785, 'Os Trapalhoes S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/390426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150918, 10785, 'Os Trapalhoes S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/390427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150919, 10785, 'Os Trapalhoes S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/390428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150920, 10785, 'Os Trapalhoes S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/390429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150921, 10785, 'Os Trapalhoes S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/390430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150922, 10785, 'Os Trapalhoes S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/390431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150923, 10785, 'Os Trapalhoes S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/390432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150924, 10785, 'Os Trapalhoes S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/390433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150925, 10785, 'Os Trapalhoes S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/390434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150926, 10785, 'Os Trapalhoes S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/390435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150927, 10785, 'Os Trapalhoes S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/390436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150928, 10785, 'Os Trapalhoes S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/390437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150929, 10785, 'Os Trapalhoes S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/390438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150930, 10785, 'Os Trapalhoes S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/390439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150931, 10785, 'Os Trapalhoes S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/390440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150932, 10785, 'Os Trapalhoes S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/390441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150933, 10785, 'Os Trapalhoes S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/390442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150934, 10785, 'Os Trapalhoes S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/390443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150935, 10785, 'Os Trapalhoes S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/390444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150936, 10785, 'Os Trapalhoes S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/390445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150937, 10785, 'Os Trapalhoes S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/390446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150938, 10785, 'Os Trapalhoes S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/390447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150939, 10785, 'Os Trapalhoes S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/390448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150940, 10786, 'Os Trapalhoes S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150941, 10786, 'Os Trapalhoes S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150942, 10786, 'Os Trapalhoes S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150943, 10786, 'Os Trapalhoes S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150944, 10786, 'Os Trapalhoes S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150945, 10786, 'Os Trapalhoes S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150946, 10786, 'Os Trapalhoes S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150947, 10786, 'Os Trapalhoes S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150948, 10786, 'Os Trapalhoes S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150949, 10786, 'Os Trapalhoes S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150950, 10786, 'Os Trapalhoes S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/390459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150951, 10786, 'Os Trapalhoes S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150952, 10786, 'Os Trapalhoes S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/390461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150953, 10786, 'Os Trapalhoes S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/390462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150954, 10786, 'Os Trapalhoes S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/390463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150955, 10786, 'Os Trapalhoes S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/390464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150956, 10786, 'Os Trapalhoes S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/390465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150957, 10786, 'Os Trapalhoes S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/390466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150958, 10786, 'Os Trapalhoes S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/390467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150959, 10786, 'Os Trapalhoes S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/390468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150960, 10786, 'Os Trapalhoes S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/390469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150961, 10786, 'Os Trapalhoes S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/390470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150962, 10786, 'Os Trapalhoes S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/390471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150963, 10786, 'Os Trapalhoes S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/390472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(150964, 10786, 'Os Trapalhoes S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/390473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150965, 10786, 'Os Trapalhoes S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/390474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150966, 10786, 'Os Trapalhoes S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/390475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150967, 10786, 'Os Trapalhoes S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/390476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150968, 10786, 'Os Trapalhoes S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/390477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150969, 10786, 'Os Trapalhoes S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/390478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150970, 10786, 'Os Trapalhoes S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/390479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150971, 10786, 'Os Trapalhoes S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/390480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150972, 10786, 'Os Trapalhoes S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/390481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150973, 10786, 'Os Trapalhoes S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/390482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150974, 10786, 'Os Trapalhoes S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/390483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150975, 10786, 'Os Trapalhoes S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/390484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150976, 10786, 'Os Trapalhoes S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/390485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150977, 10787, 'Os Trapalhoes S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150978, 10787, 'Os Trapalhoes S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150979, 10787, 'Os Trapalhoes S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150980, 10787, 'Os Trapalhoes S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150981, 10787, 'Os Trapalhoes S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150982, 10787, 'Os Trapalhoes S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150983, 10787, 'Os Trapalhoes S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150984, 10787, 'Os Trapalhoes S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150985, 10787, 'Os Trapalhoes S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150986, 10787, 'Os Trapalhoes S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150987, 10787, 'Os Trapalhoes S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/390496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150988, 10787, 'Os Trapalhoes S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150989, 10787, 'Os Trapalhoes S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/390498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150990, 10787, 'Os Trapalhoes S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/390499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150991, 10787, 'Os Trapalhoes S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/390500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150992, 10787, 'Os Trapalhoes S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/390501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150993, 10787, 'Os Trapalhoes S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/390502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150994, 10787, 'Os Trapalhoes S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/390503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150995, 10787, 'Os Trapalhoes S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/390504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150996, 10787, 'Os Trapalhoes S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/390505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150997, 10787, 'Os Trapalhoes S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/390506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150998, 10787, 'Os Trapalhoes S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/390507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(150999, 10787, 'Os Trapalhoes S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/390508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151000, 10787, 'Os Trapalhoes S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/390509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151001, 10787, 'Os Trapalhoes S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/390510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151002, 10787, 'Os Trapalhoes S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/390511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151003, 10787, 'Os Trapalhoes S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/390512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151004, 10787, 'Os Trapalhoes S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/390513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151005, 10787, 'Os Trapalhoes S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/390514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151006, 10787, 'Os Trapalhoes S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/390515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151007, 10787, 'Os Trapalhoes S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/390516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151008, 10787, 'Os Trapalhoes S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/390517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151009, 10787, 'Os Trapalhoes S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/390518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151010, 10787, 'Os Trapalhoes S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/390519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151011, 10787, 'Os Trapalhoes S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/390520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151012, 10788, 'Os Trapalhoes S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151013, 10788, 'Os Trapalhoes S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151014, 10788, 'Os Trapalhoes S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151015, 10788, 'Os Trapalhoes S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151016, 10788, 'Os Trapalhoes S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151017, 10788, 'Os Trapalhoes S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151018, 10788, 'Os Trapalhoes S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151019, 10788, 'Os Trapalhoes S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151020, 10788, 'Os Trapalhoes S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151021, 10788, 'Os Trapalhoes S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151022, 10788, 'Os Trapalhoes S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/390531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151023, 10788, 'Os Trapalhoes S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151024, 10788, 'Os Trapalhoes S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/390533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151025, 10788, 'Os Trapalhoes S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/390534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151026, 10788, 'Os Trapalhoes S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/390535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151027, 10788, 'Os Trapalhoes S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/390536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151028, 10788, 'Os Trapalhoes S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/390537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151029, 10788, 'Os Trapalhoes S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/390538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151030, 10788, 'Os Trapalhoes S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/390539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151031, 10788, 'Os Trapalhoes S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/390540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151032, 10788, 'Os Trapalhoes S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/390541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151033, 10788, 'Os Trapalhoes S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/390542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151034, 10788, 'Os Trapalhoes S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/390543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151035, 10788, 'Os Trapalhoes S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/390544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151036, 10788, 'Os Trapalhoes S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/390545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151037, 10789, 'Os Trapalhoes S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151038, 10789, 'Os Trapalhoes S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151039, 10789, 'Os Trapalhoes S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151040, 10789, 'Os Trapalhoes S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151041, 10789, 'Os Trapalhoes S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151042, 10789, 'Os Trapalhoes S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151043, 10789, 'Os Trapalhoes S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151044, 10789, 'Os Trapalhoes S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151045, 10789, 'Os Trapalhoes S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151046, 10789, 'Os Trapalhoes S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151047, 10789, 'Os Trapalhoes S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/390556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151048, 10789, 'Os Trapalhoes S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151049, 10789, 'Os Trapalhoes S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/390558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151050, 10789, 'Os Trapalhoes S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/390559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151051, 10789, 'Os Trapalhoes S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/390560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151052, 10789, 'Os Trapalhoes S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/390561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151053, 10789, 'Os Trapalhoes S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/390562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151054, 10789, 'Os Trapalhoes S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/390563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151055, 10789, 'Os Trapalhoes S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/390564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151056, 10789, 'Os Trapalhoes S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/390565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151057, 10789, 'Os Trapalhoes S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/390566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151058, 10789, 'Os Trapalhoes S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/390567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151059, 10789, 'Os Trapalhoes S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/390568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151060, 10789, 'Os Trapalhoes S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/390569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151061, 10789, 'Os Trapalhoes S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/390570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151062, 10789, 'Os Trapalhoes S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/390571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151063, 10789, 'Os Trapalhoes S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/390572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151064, 10789, 'Os Trapalhoes S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/390573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151065, 10789, 'Os Trapalhoes S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/390574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW9bmYxHhpcoqolHCm62w9F0l2.jpg'),
(151066, 10790, 'Os Trapalhoes (2017) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Rr3TV6IIVlWKWOpAsW9PxyCpEp.jpg'),
(151067, 10790, 'Os Trapalhoes (2017) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Sg8nOm4KAyZ7NxJTUkgxkDpC3p.jpg'),
(151068, 10790, 'Os Trapalhoes (2017) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mTiyAAa0okZ97rQ3h28kEo1YqLC.jpg'),
(151069, 10790, 'Os Trapalhoes (2017) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sHp5Nt4VW1pWICGfeJEsUeY4tod.jpg'),
(151070, 10790, 'Os Trapalhoes (2017) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lRMACfFjod7AnwaNbws1OhPqEeH.jpg'),
(151071, 10790, 'Os Trapalhoes (2017) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nFg18HbBRsAVXfmTb0ISaFlzTVw.jpg'),
(151072, 10790, 'Os Trapalhoes (2017) S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nyYgBeMt3VZQEMyInNbe3O3KrvO.jpg'),
(151073, 10790, 'Os Trapalhoes (2017) S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6e38OrI293d3Jkx4rMpHWcde4mk.jpg'),
(151074, 10790, 'Os Trapalhoes (2017) S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fLshTKaR6ohjMKtoc9zChhiQ0ju.jpg'),
(151075, 10791, 'Rush Medicina Vip S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7AG9tdGhJtquL7VQvoJTIOobZSM.jpg'),
(151076, 10791, 'Rush Medicina Vip S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8JOdzXi6A98zBW1qub5Bp4dlR4J.jpg'),
(151077, 10791, 'Rush Medicina Vip S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rD56XXd4G6vDfAbrljhh5trSJGC.jpg'),
(151078, 10791, 'Rush Medicina Vip S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z22PHmIeQZLvHPUslpbwoEaLp20.jpg'),
(151079, 10791, 'Rush Medicina Vip S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1j7esoFY5rkMCgUATXtW3RWHDhs.jpg'),
(151080, 10791, 'Rush Medicina Vip S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l4RSU9gr9WJoL98dQi9q5WXp85k.jpg'),
(151081, 10791, 'Rush Medicina Vip S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k298L7meneLA6ou3oqyRstXOTOI.jpg'),
(151082, 10791, 'Rush Medicina Vip S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kb2nkX8SqtMorgo2kF99cfV071N.jpg'),
(151083, 10791, 'Rush Medicina Vip S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/auk0fUKwUGpm3iB4CCJca9ruZdf.jpg'),
(151084, 10791, 'Rush Medicina Vip S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f8stn95EWpWmNnep6G94SSD48UX.jpg'),
(151085, 10792, 'Vivendo com o Inimigo Sombras da Morte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mgFG1cZuDmUOGIpNCNaoMTDVSC2.jpg'),
(151086, 10792, 'Vivendo com o Inimigo Sombras da Morte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rOfdNGPJEoHpGtWJoVQGYiPaz0.jpg'),
(151087, 10792, 'Vivendo com o Inimigo Sombras da Morte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xMoXBhJwzQyByF3us2HT3harVNA.jpg'),
(151088, 10792, 'Vivendo com o Inimigo Sombras da Morte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3OsmlWH5wZxuAABjbzJV78urNsk.jpg'),
(151089, 10792, 'Vivendo com o Inimigo Sombras da Morte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qoxyEmUQmbrWNcUuV01Ho6bAafh.jpg'),
(151090, 10792, 'Vivendo com o Inimigo Sombras da Morte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3IYOOePyRgb1zrWDa3RmlM9vjdS.jpg'),
(151091, 10793, 'Vivendo com o Inimigo Sombras da Morte S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2dkUGF8nGXJ2X2aW2iFo44rVPcZ.jpg'),
(151092, 10793, 'Vivendo com o Inimigo Sombras da Morte S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9tPqHn9bBENHEbXST7Il7gqKJi.jpg'),
(151093, 10793, 'Vivendo com o Inimigo Sombras da Morte S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9hTY6C8jwXr4IlyTfG41yjOgcvh.jpg'),
(151094, 10793, 'Vivendo com o Inimigo Sombras da Morte S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kc1kpkT4MkDb010QON2hb2pYCHB.jpg'),
(151095, 10793, 'Vivendo com o Inimigo Sombras da Morte S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1jQT3lSxuJbLU5sm4pbwtaPiGsN.jpg'),
(151096, 10793, 'Vivendo com o Inimigo Sombras da Morte S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y8ES8JJIjdZyBrlI11wPT6mp6I2.jpg'),
(151097, 10793, 'Vivendo com o Inimigo Sombras da Morte S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nKLCJQ4LFxuOQXvB3mZzGbLwYBb.jpg'),
(151098, 10793, 'Vivendo com o Inimigo Sombras da Morte S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wAGb86wTMIzY9fnrWs5i4KyI9HS.jpg'),
(151099, 10794, 'Vivendo com o Inimigo Sombras da Morte S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m9rmBPG23qj42LulZukTBc1m9cz.jpg'),
(151100, 10794, 'Vivendo com o Inimigo Sombras da Morte S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2XAEgH3z6bkTbCIJ70XdtSwymS5.jpg'),
(151101, 10794, 'Vivendo com o Inimigo Sombras da Morte S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0Ra5ccG2P21BjFAOvbJ8XzFPrh.jpg'),
(151102, 10794, 'Vivendo com o Inimigo Sombras da Morte S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0Ra5ccG2P21BjFAOvbJ8XzFPrh.jpg'),
(151103, 10794, 'Vivendo com o Inimigo Sombras da Morte S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0Ra5ccG2P21BjFAOvbJ8XzFPrh.jpg'),
(151104, 10794, 'Vivendo com o Inimigo Sombras da Morte S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0Ra5ccG2P21BjFAOvbJ8XzFPrh.jpg'),
(151105, 10795, 'Vivendo com o Inimigo Sombras da Morte S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0Ra5ccG2P21BjFAOvbJ8XzFPrh.jpg'),
(151106, 10795, 'Vivendo com o Inimigo Sombras da Morte S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0Ra5ccG2P21BjFAOvbJ8XzFPrh.jpg'),
(151107, 10795, 'Vivendo com o Inimigo Sombras da Morte S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0Ra5ccG2P21BjFAOvbJ8XzFPrh.jpg'),
(151108, 10795, 'Vivendo com o Inimigo Sombras da Morte S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0Ra5ccG2P21BjFAOvbJ8XzFPrh.jpg'),
(151109, 10795, 'Vivendo com o Inimigo Sombras da Morte S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0Ra5ccG2P21BjFAOvbJ8XzFPrh.jpg'),
(151110, 10795, 'Vivendo com o Inimigo Sombras da Morte S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0Ra5ccG2P21BjFAOvbJ8XzFPrh.jpg'),
(151111, 10796, 'Vivendo com o Inimigo Sombras da Morte S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0Ra5ccG2P21BjFAOvbJ8XzFPrh.jpg'),
(151112, 10796, 'Vivendo com o Inimigo Sombras da Morte S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0Ra5ccG2P21BjFAOvbJ8XzFPrh.jpg'),
(151113, 10796, 'Vivendo com o Inimigo Sombras da Morte S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0Ra5ccG2P21BjFAOvbJ8XzFPrh.jpg'),
(151114, 10796, 'Vivendo com o Inimigo Sombras da Morte S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0Ra5ccG2P21BjFAOvbJ8XzFPrh.jpg'),
(151115, 10796, 'Vivendo com o Inimigo Sombras da Morte S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0Ra5ccG2P21BjFAOvbJ8XzFPrh.jpg'),
(151116, 10796, 'Vivendo com o Inimigo Sombras da Morte S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0Ra5ccG2P21BjFAOvbJ8XzFPrh.jpg'),
(151117, 10797, 'Vivendo com o Inimigo Sombras da Morte S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/prTqPL3EckzHBssIKqjVCtNT5aE.jpg'),
(151118, 10797, 'Vivendo com o Inimigo Sombras da Morte S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aRiZ33VL5l19X9rmSvteQ36xVuq.jpg'),
(151119, 10797, 'Vivendo com o Inimigo Sombras da Morte S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/404014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0Ra5ccG2P21BjFAOvbJ8XzFPrh.jpg'),
(151120, 10797, 'Vivendo com o Inimigo Sombras da Morte S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/404015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0Ra5ccG2P21BjFAOvbJ8XzFPrh.jpg'),
(151121, 10797, 'Vivendo com o Inimigo Sombras da Morte S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/404016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0Ra5ccG2P21BjFAOvbJ8XzFPrh.jpg'),
(151122, 10797, 'Vivendo com o Inimigo Sombras da Morte S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/411206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v0Ra5ccG2P21BjFAOvbJ8XzFPrh.jpg'),
(151123, 10798, 'Yo Kai Watch S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/SPZyPWPmixDmFFRs1TRgOc06ye.jpg'),
(151124, 10798, 'Yo Kai Watch S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wTo3oxjzAAhiWVBzPPi6nJpGFQe.jpg'),
(151125, 10798, 'Yo Kai Watch S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Hz7dxvWJ3gkj7p5wQXkjQpUCVf.jpg'),
(151126, 10798, 'Yo Kai Watch S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jxBCEKpiReJR4xW5pSBewPwkTSW.jpg'),
(151127, 10798, 'Yo Kai Watch S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2l0ss9arCwXQZLu2NwY4yfzjBe.jpg'),
(151128, 10798, 'Yo Kai Watch S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A930muEvcmm6npP1e9IqJUbgk8W.jpg'),
(151129, 10798, 'Yo Kai Watch S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cqOT98glp1U3cjwLHMcygal22dK.jpg'),
(151130, 10798, 'Yo Kai Watch S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sIVsI86fjWSLUgOyklxATrxY25Z.jpg'),
(151131, 10798, 'Yo Kai Watch S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4EsuZhu2bAUBBxjkMVhs0SNCpND.jpg'),
(151132, 10798, 'Yo Kai Watch S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hdYAA5CEZjuGf5XvjJCF3IXdpDm.jpg'),
(151133, 10798, 'Yo Kai Watch S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/390248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8fZLV8WKvgCNyaJXUTFw2dGMDxM.jpg'),
(151134, 10798, 'Yo Kai Watch S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/390249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bYQVQjKZBwfjh13KPeflWCGLzC3.jpg'),
(151135, 10798, 'Yo Kai Watch S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/390250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kgV5cTiqsfYSWHLZw4acC1FFVGI.jpg'),
(151136, 10798, 'Yo Kai Watch S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/390251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mpJGWcxtnt4ZWvgLc1BWxVPmH29.jpg'),
(151137, 10798, 'Yo Kai Watch S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/390252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t0eddO93mdcLdymDYDas0HPw9yJ.jpg'),
(151138, 10798, 'Yo Kai Watch S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/390253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uT7Tch9HzmuWpIkkDkTD1a50Ae1.jpg'),
(151139, 10798, 'Yo Kai Watch S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/390254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dJtPrn8earpht7Ffp9MoUIoeUBh.jpg'),
(151140, 10798, 'Yo Kai Watch S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/390255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3nQrqs6zRruMjp1Kj8R8dfHTx64.jpg'),
(151141, 10798, 'Yo Kai Watch S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/390256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y9ohFm9DFL2A4tV78GiOVmOkroc.jpg'),
(151142, 10798, 'Yo Kai Watch S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/390257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k8MHIsmT17FXuXI3pbGHa5lOovG.jpg'),
(151143, 10798, 'Yo Kai Watch S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/390258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vWFzrjuyrOkJC7KN2eABFZRbPzR.jpg'),
(151144, 10798, 'Yo Kai Watch S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/390259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rW71seqQhyIrceQ6J1GqeQQkt7E.jpg'),
(151145, 10798, 'Yo Kai Watch S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/390260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nqxSZx9RTHll25sIS7pyXcLHjxD.jpg'),
(151146, 10798, 'Yo Kai Watch S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/390261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y41ckSDsG3IxKQjLcn6ESpnT7Q5.jpg'),
(151147, 10798, 'Yo Kai Watch S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/390262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tWmZ3yMTTvaYyuAnVClWzmwHg0s.jpg'),
(151148, 10798, 'Yo Kai Watch S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/390263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k5i3evVTHLOiQgUmcn7SI3RH2tG.jpg'),
(151149, 10798, 'Yo Kai Watch S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/390264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151150, 10798, 'Yo Kai Watch S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/390265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151151, 10798, 'Yo Kai Watch S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/390266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151152, 10798, 'Yo Kai Watch S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/390267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151153, 10798, 'Yo Kai Watch S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/390268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151154, 10798, 'Yo Kai Watch S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/390269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151155, 10798, 'Yo Kai Watch S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/390270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151156, 10798, 'Yo Kai Watch S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/390271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151157, 10798, 'Yo Kai Watch S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/390272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151158, 10798, 'Yo Kai Watch S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/390273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151159, 10798, 'Yo Kai Watch S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/390274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151160, 10798, 'Yo Kai Watch S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/390275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151161, 10798, 'Yo Kai Watch S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/390276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151162, 10798, 'Yo Kai Watch S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/390277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151163, 10798, 'Yo Kai Watch S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/390278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151164, 10798, 'Yo Kai Watch S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/390279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151165, 10798, 'Yo Kai Watch S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/390280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151166, 10798, 'Yo Kai Watch S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/390281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151167, 10798, 'Yo Kai Watch S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/390282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151168, 10798, 'Yo Kai Watch S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/390283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151169, 10798, 'Yo Kai Watch S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/390284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151170, 10798, 'Yo Kai Watch S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/390285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151171, 10798, 'Yo Kai Watch S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/390286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151172, 10798, 'Yo Kai Watch S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/390287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151173, 10798, 'Yo Kai Watch S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/390288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151174, 10798, 'Yo Kai Watch S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/390289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151175, 10798, 'Yo Kai Watch S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/390290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151176, 10798, 'Yo Kai Watch S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/390291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151177, 10798, 'Yo Kai Watch S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/390292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151178, 10798, 'Yo Kai Watch S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/390293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151179, 10798, 'Yo Kai Watch S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/390294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151180, 10798, 'Yo Kai Watch S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/390295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151181, 10798, 'Yo Kai Watch S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/390296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151182, 10798, 'Yo Kai Watch S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/390297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151183, 10798, 'Yo Kai Watch S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/390298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151184, 10798, 'Yo Kai Watch S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/390299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151185, 10798, 'Yo Kai Watch S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/390300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151186, 10798, 'Yo Kai Watch S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/390301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151187, 10798, 'Yo Kai Watch S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/390302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151188, 10798, 'Yo Kai Watch S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/390303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151189, 10798, 'Yo Kai Watch S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/390304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151190, 10798, 'Yo Kai Watch S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/390305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151191, 10798, 'Yo Kai Watch S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/390306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151192, 10798, 'Yo Kai Watch S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/390307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151193, 10798, 'Yo Kai Watch S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/390308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151194, 10798, 'Yo Kai Watch S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/390309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151195, 10798, 'Yo Kai Watch S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/390310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151196, 10798, 'Yo Kai Watch S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/390311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151197, 10798, 'Yo Kai Watch S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/390312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151198, 10798, 'Yo Kai Watch S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/390313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tEVN1zjnAoi4N9Q57dfTn41JO7W.jpg'),
(151199, 10799, 'Quanto Vale Esse Doce S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/390228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jHJIt3OMjFxseIWL7836cPPGP8y.jpg'),
(151200, 10799, 'Quanto Vale Esse Doce S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/390229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jHJIt3OMjFxseIWL7836cPPGP8y.jpg'),
(151201, 10799, 'Quanto Vale Esse Doce S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/390230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jHJIt3OMjFxseIWL7836cPPGP8y.jpg'),
(151202, 10799, 'Quanto Vale Esse Doce S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/390231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jHJIt3OMjFxseIWL7836cPPGP8y.jpg'),
(151203, 10799, 'Quanto Vale Esse Doce S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/390232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jHJIt3OMjFxseIWL7836cPPGP8y.jpg'),
(151204, 10799, 'Quanto Vale Esse Doce S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/390233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jHJIt3OMjFxseIWL7836cPPGP8y.jpg'),
(151205, 10799, 'Quanto Vale Esse Doce S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/390234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jHJIt3OMjFxseIWL7836cPPGP8y.jpg'),
(151206, 10799, 'Quanto Vale Esse Doce S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/390235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jHJIt3OMjFxseIWL7836cPPGP8y.jpg'),
(151207, 10799, 'Quanto Vale Esse Doce S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/390236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jHJIt3OMjFxseIWL7836cPPGP8y.jpg'),
(151208, 10799, 'Quanto Vale Esse Doce S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/390237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jHJIt3OMjFxseIWL7836cPPGP8y.jpg'),
(151209, 10800, 'Power Rangers Ninja Storm S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/870eA45xdZS5hrXTey4cmFJDEiT.jpg'),
(151210, 10800, 'Power Rangers Ninja Storm S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pos46Q8tRCsTjMiUd1IEXruGZZ6.jpg'),
(151211, 10800, 'Power Rangers Ninja Storm S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kKo8IqN7zAXuO70vqIUhZ34wRvC.jpg'),
(151212, 10800, 'Power Rangers Ninja Storm S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vtGEpQ0kazjhrQmUrzyhiC8Ngar.jpg'),
(151213, 10800, 'Power Rangers Ninja Storm S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k1zpSfW9UzP3zZeQAy7KmAZ7kDF.jpg'),
(151214, 10800, 'Power Rangers Ninja Storm S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mes6aVKlTOUyJF9wzMgG3th74bC.jpg'),
(151215, 10800, 'Power Rangers Ninja Storm S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/393194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uJZf76MfF3rjnPArCrk7tmFkoZu.jpg'),
(151216, 10800, 'Power Rangers Ninja Storm S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/393195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q4tLhwQoYQdUtUIPdUrPmYPHdrV.jpg'),
(151217, 10800, 'Power Rangers Ninja Storm S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/393196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7p9VpdD92NqYTGBwoRdJlqpWyJf.jpg'),
(151218, 10800, 'Power Rangers Ninja Storm S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/393197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pa5W6SrAhsKFhXpQA8pYnMLzZ6n.jpg'),
(151219, 10800, 'Power Rangers Ninja Storm S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/393198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yjs0Lc7qtQOtbOZ4mw1TFS5VQUf.jpg'),
(151220, 10800, 'Power Rangers Ninja Storm S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/393199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1foneG3YfPERCguwRJurxf2qfZ5.jpg'),
(151221, 10800, 'Power Rangers Ninja Storm S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/393200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pqPGv2QBenWxctdEImtclx0ht07.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(151222, 10800, 'Power Rangers Ninja Storm S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/393201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jyw2PbE393xqJKF9rUh2viO7m8N.jpg'),
(151223, 10800, 'Power Rangers Ninja Storm S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/393202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1miTzta6SiJeUbNbz5o9KdjAOel.jpg'),
(151224, 10800, 'Power Rangers Ninja Storm S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/393203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJmwR266bRVno6a3wdg36twgyFw.jpg'),
(151225, 10800, 'Power Rangers Ninja Storm S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/393204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lg6itRi3iRSB4YwJfEd6cocy7L.jpg'),
(151226, 10800, 'Power Rangers Ninja Storm S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/393205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFBjaYPW1Q0PStVnAl1BsoonMID.jpg'),
(151227, 10800, 'Power Rangers Ninja Storm S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/393206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/peX3KEMkRKVpNqE4mU16aqjFvOZ.jpg'),
(151228, 10800, 'Power Rangers Ninja Storm S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/393207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kh9gdCjV1IDUOX68l0fqN37wwEC.jpg'),
(151229, 10800, 'Power Rangers Ninja Storm S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/393208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jx1BBBkx6LthlX9I2YxFxh3n442.jpg'),
(151230, 10800, 'Power Rangers Ninja Storm S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/393209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zl3pJZEVUdVgpuyZQD7KX6d01rv.jpg'),
(151231, 10800, 'Power Rangers Ninja Storm S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/393210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6brzw2H4XSTxBbgxeFkqaPx6av3.jpg'),
(151232, 10800, 'Power Rangers Ninja Storm S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/393211.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hGOI8lGQwNqhAQWlntKOrhiix2l.jpg'),
(151233, 10800, 'Power Rangers Ninja Storm S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/393212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oksywj1O7bjfTPnngZ9Drjd1o5e.jpg'),
(151234, 10800, 'Power Rangers Ninja Storm S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/393213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/onFpon96iqd91jnMTLG1MNCBGy.jpg'),
(151235, 10800, 'Power Rangers Ninja Storm S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/393214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zie9Kph98dsAxgrGCTIJbdBxTYh.jpg'),
(151236, 10800, 'Power Rangers Ninja Storm S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/393215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvcagjeZk6Zw8dTI8tWjofJvMDM.jpg'),
(151237, 10800, 'Power Rangers Ninja Storm S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/393216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wH4cYiUtQTna9m0bzQc7jqFuZrA.jpg'),
(151238, 10800, 'Power Rangers Ninja Storm S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/393217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Ze8OAVXFHmaDIaCOZkm5Hmde5P.jpg'),
(151239, 10800, 'Power Rangers Ninja Storm S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/393218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9tYrdKDAMplpe5eZinRJMoJ4kA1.jpg'),
(151240, 10800, 'Power Rangers Ninja Storm S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/393219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ojfJwKNguEYU1TY348QVGL4nGU.jpg'),
(151241, 10800, 'Power Rangers Ninja Storm S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/393220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nauREnMyvTJASFyE0UR8tPDmvIf.jpg'),
(151242, 10800, 'Power Rangers Ninja Storm S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/393221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udBsggkIfx5czXol427NiPgW1Ts.jpg'),
(151243, 10800, 'Power Rangers Ninja Storm S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/393222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSXTH4yuDapjFwkEYK6IwYc2C0H.jpg'),
(151244, 10800, 'Power Rangers Ninja Storm S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/393223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uLurnu2Q5Q6qlKyH0nXypA7SqY7.jpg'),
(151245, 10800, 'Power Rangers Ninja Storm S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/393224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kaNTTpMLtX2nLYtEiZd76BR7Nna.jpg'),
(151246, 10800, 'Power Rangers Ninja Storm S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/393225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yl18Xpoxoj5NTXhrLegnrznQlbM.jpg'),
(151247, 10801, 'Ainda um Misterio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393133.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/au2C3vYWuClk6KZdKeLUO7kzZOH.jpg'),
(151248, 10801, 'Ainda um Misterio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393134.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eIjGPpLz2F9ayNmjsX0FGcLWnvM.jpg'),
(151249, 10801, 'Ainda um Misterio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393135.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/knvSR4l8DZHigzyvDghD4U5lRbH.jpg'),
(151250, 10801, 'Ainda um Misterio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393136.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qYRBOjBbixXIKX5ZsrrSarq3t89.jpg'),
(151251, 10801, 'Ainda um Misterio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393137.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pgL3eQ1tJ7nRMBRtiEyHkmprMco.jpg'),
(151252, 10802, 'Ainda um Misterio S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393138.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e1dyLg9Cby5bPB41sdEPDp7Tc8T.jpg'),
(151253, 10802, 'Ainda um Misterio S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393139.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1p00dWLGXoo4LEpBDrnfect2hVw.jpg'),
(151254, 10802, 'Ainda um Misterio S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393140.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtbc8liS8WJGyfLoSulKrz4LE4Y.jpg'),
(151255, 10802, 'Ainda um Misterio S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393141.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mWNPxJrFYernZHfZ7aKFN6BWuFt.jpg'),
(151256, 10802, 'Ainda um Misterio S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393142.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dyATtXmge6klTfJ3L2kjHHWHnwY.jpg'),
(151257, 10802, 'Ainda um Misterio S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393143.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gVNlf0BkywjsewXiKRd9D2LJE13.jpg'),
(151258, 10802, 'Ainda um Misterio S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/393144.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pUAEThe92O41JwzMJ6I0fHRkwf.jpg'),
(151259, 10802, 'Ainda um Misterio S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/393145.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zqe5wq4CYnzFumk9sCB22CC3aLM.jpg'),
(151260, 10802, 'Ainda um Misterio S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/393146.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7R4pdPja0F8q3Jz6jlFtN7CTDs1.jpg'),
(151261, 10802, 'Ainda um Misterio S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/393147.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/34PauAJvNDOsZ7L1vLJ7WGPqsVJ.jpg'),
(151262, 10802, 'Ainda um Misterio S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/393148.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pTiNYFDUy4wuaNpXaSiTYKzKqEr.jpg'),
(151263, 10802, 'Ainda um Misterio S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/393149.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/VQoCuuyOvj1MqPypfMuogxEA4b.jpg'),
(151264, 10802, 'Ainda um Misterio S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/393150.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oAP3AC1UagUqG9CmHXX7rTJuTsP.jpg'),
(151265, 10802, 'Ainda um Misterio S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/393151.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bI9flCE9lqCNuP6TRYQ2yvXr90g.jpg'),
(151266, 10802, 'Ainda um Misterio S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/393152.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rtTtDNca9CDVmQ6k5pIPvq9SL2U.jpg'),
(151267, 10802, 'Ainda um Misterio S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/393153.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gdnl6lP30CvEvoB5ovKCzsJRw06.jpg'),
(151268, 10802, 'Ainda um Misterio S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/393154.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpAABrn1ceB378SGn2Kc5DQLlCX.jpg'),
(151269, 10803, 'Ainda um Misterio S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393155.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hgqroFcuJqA8fv8VaEzVnVzkHEB.jpg'),
(151270, 10803, 'Ainda um Misterio S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393156.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/73trqQYOlam0NpB2YAGJN5n6qfs.jpg'),
(151271, 10803, 'Ainda um Misterio S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393157.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ybqzgIuAkfR8Jn7TCV2Cw9IHggL.jpg'),
(151272, 10803, 'Ainda um Misterio S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393158.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aObjpJocJj6aoRfRLHreBy7tMvM.jpg'),
(151273, 10803, 'Ainda um Misterio S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393159.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bZXnPPMg7KqaTGRn8AwY4Fe59DQ.jpg'),
(151274, 10803, 'Ainda um Misterio S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393160.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ko5YlS0hGdl20a7MZJ1RCaj3fv.jpg'),
(151275, 10803, 'Ainda um Misterio S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/393161.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZ8aTDc7OQSi0sVtFBsl1xcggUe.jpg'),
(151276, 10803, 'Ainda um Misterio S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/393162.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gsLh9dqTPdr5ZAqx8f1EoexVDt.jpg'),
(151277, 10803, 'Ainda um Misterio S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/393163.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n5Mt51Fj5XsIhvpPuPUXFAoyi9Q.jpg'),
(151278, 10803, 'Ainda um Misterio S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/393164.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lLQQY4t32x2tx0Ce9eE3tS09s9K.jpg'),
(151279, 10803, 'Ainda um Misterio S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/393165.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j51VYScIfMgtKa6DXJrxKnjycjd.jpg'),
(151280, 10803, 'Ainda um Misterio S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/393166.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sG5VHW3lLE03DZtOqPLSFefUgmQ.jpg'),
(151281, 10803, 'Ainda um Misterio S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/393167.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iLJ5bdwv5BIoSSo09ENn9htbytS.jpg'),
(151282, 10804, 'Ainda um Misterio S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393168.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3CZcTrowZONyBvfiPpn63ltpRjT.jpg'),
(151283, 10804, 'Ainda um Misterio S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393169.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Ldrskl5Yx0EOicq7SWd757LrLB.jpg'),
(151284, 10804, 'Ainda um Misterio S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393170.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ag3Jyp74VmfUAo0ET1S4Tble02U.jpg'),
(151285, 10804, 'Ainda um Misterio S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393171.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gMF8vjPUrTqvOO5VivA10RHjJox.jpg'),
(151286, 10804, 'Ainda um Misterio S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393172.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rUoav8408Bie6OqedA61honYpqA.jpg'),
(151287, 10804, 'Ainda um Misterio S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393173.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nWA1sVtdfqUygBUnuiXB4I12Iyx.jpg'),
(151288, 10804, 'Ainda um Misterio S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/393174.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/otOI6mIpKN2lZjs6UOX5qapzSng.jpg'),
(151289, 10804, 'Ainda um Misterio S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/393175.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cXD7KQdcxUp73TvBhf5qUMh5exV.jpg'),
(151290, 10804, 'Ainda um Misterio S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/393176.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qMhdEJsfojCQkiEdPgyGd1CRnxB.jpg'),
(151291, 10804, 'Ainda um Misterio S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/393177.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWfc0XkIYBxK4OXNwjEUnfid6LB.jpg'),
(151292, 10805, 'Ainda um Misterio S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bW94bga7pENkHxWXvZIxXeWvZh0.jpg'),
(151293, 10805, 'Ainda um Misterio S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bW94bga7pENkHxWXvZIxXeWvZh0.jpg'),
(151294, 10805, 'Ainda um Misterio S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bW94bga7pENkHxWXvZIxXeWvZh0.jpg'),
(151295, 10805, 'Ainda um Misterio S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bW94bga7pENkHxWXvZIxXeWvZh0.jpg'),
(151296, 10805, 'Ainda um Misterio S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bW94bga7pENkHxWXvZIxXeWvZh0.jpg'),
(151297, 10805, 'Ainda um Misterio S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bW94bga7pENkHxWXvZIxXeWvZh0.jpg'),
(151298, 10805, 'Ainda um Misterio S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/393184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bW94bga7pENkHxWXvZIxXeWvZh0.jpg'),
(151299, 10805, 'Ainda um Misterio S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/393185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bW94bga7pENkHxWXvZIxXeWvZh0.jpg'),
(151300, 10805, 'Ainda um Misterio S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/393186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bW94bga7pENkHxWXvZIxXeWvZh0.jpg'),
(151301, 10805, 'Ainda um Misterio S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/393187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bW94bga7pENkHxWXvZIxXeWvZh0.jpg'),
(151302, 10806, 'Chillin in Another World with Level 2 Super Cheat Powers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393124.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/88VK8yDXgh7q6kN5Eh8DUGG2BtB.jpg'),
(151303, 10806, 'Chillin in Another World with Level 2 Super Cheat Powers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393125.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ccPFRSme3rdiBBuAl59CbAfkvgd.jpg'),
(151304, 10806, 'Chillin in Another World with Level 2 Super Cheat Powers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393126.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A1gJWfvZbSdxKCu310VS2RknaL7.jpg'),
(151305, 10806, 'Chillin in Another World with Level 2 Super Cheat Powers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393127.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/glG4YvnloEQZPEdz45eS6Z2o5bY.jpg'),
(151306, 10806, 'Chillin in Another World with Level 2 Super Cheat Powers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393128.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iUkKaiF2KsMAIW4M24iCJFswQMn.jpg'),
(151307, 10806, 'Chillin in Another World with Level 2 Super Cheat Powers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393129.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k04cyu8MAvsnLZiw6bJoWdOueJ6.jpg'),
(151308, 10806, 'Chillin in Another World with Level 2 Super Cheat Powers S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/393130.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mBB4tOKNl2bmXEsuaIu31pJhADh.jpg'),
(151309, 10806, 'Chillin in Another World with Level 2 Super Cheat Powers S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/393131.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pp2DsYdljuTs8zmyCjvGjWhRem4.jpg'),
(151310, 10806, 'Chillin in Another World with Level 2 Super Cheat Powers S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/393132.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aW2QRv38hNm5BJDwNQZfFjocOXr.jpg'),
(151311, 10806, 'Chillin in Another World with Level 2 Super Cheat Powers S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/412979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uU8JO4PsbgpuZmbkUMPjdpxEjBO.jpg'),
(151312, 10806, 'Chillin in Another World with Level 2 Super Cheat Powers S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/412980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uU8JO4PsbgpuZmbkUMPjdpxEjBO.jpg'),
(151313, 10806, 'Chillin in Another World with Level 2 Super Cheat Powers S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/412981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uU8JO4PsbgpuZmbkUMPjdpxEjBO.jpg'),
(151314, 10807, 'Conexoes Traicoeiras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393114.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6CJPzgVzCpWQ3Pq030zwVY6tdHK.jpg'),
(151315, 10807, 'Conexoes Traicoeiras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393115.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAEoZe7KJW4u4gTo8RyhL3cOyJu.jpg'),
(151316, 10807, 'Conexoes Traicoeiras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393116.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lxW2IklS7h0IYjIQu51WLf0brM5.jpg'),
(151317, 10807, 'Conexoes Traicoeiras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393117.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/deLlhX6IGpDTU0bYIfu6zcnogZ6.jpg'),
(151318, 10807, 'Conexoes Traicoeiras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393118.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJtGYDvjwT5LsxZANeWOK8uZBsT.jpg'),
(151319, 10807, 'Conexoes Traicoeiras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393119.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9vNBi7ed3E0fxzJHlY7y82jjCwq.jpg'),
(151320, 10807, 'Conexoes Traicoeiras S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/393120.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5zxO9lwMfnDTEriEw9At4Olg3eB.jpg'),
(151321, 10807, 'Conexoes Traicoeiras S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/393121.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/28VENX6thlvuJeegCdzfr83gFUd.jpg'),
(151322, 10807, 'Conexoes Traicoeiras S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/393122.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gVkQDGkvPjS70XMjPPxcuQ5EnM.jpg'),
(151323, 10807, 'Conexoes Traicoeiras S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/393123.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/foVlkZtCpFQynPTIz75LREXBonE.jpg'),
(151324, 10807, 'Conexoes Traicoeiras S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/398798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckEXEXVgODZWJbQS4iAdLQCmXgn.jpg'),
(151325, 10807, 'Conexoes Traicoeiras S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/398799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckEXEXVgODZWJbQS4iAdLQCmXgn.jpg'),
(151326, 10807, 'Conexoes Traicoeiras S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/406417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckEXEXVgODZWJbQS4iAdLQCmXgn.jpg'),
(151327, 10807, 'Conexoes Traicoeiras S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/406418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckEXEXVgODZWJbQS4iAdLQCmXgn.jpg'),
(151328, 10808, 'Lua de Mel Mortal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393110.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pwzgyMX6Z7P7NVics1eMlMUO6Yg.jpg'),
(151329, 10808, 'Lua de Mel Mortal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393111.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6rjsFQf91b678ZUM7Aqo9GnbxNu.jpg'),
(151330, 10808, 'Lua de Mel Mortal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393112.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lBCl62GWrGCYzLAPvF8IujsuFAN.jpg'),
(151331, 10808, 'Lua de Mel Mortal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393113.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hgi3PSUODpJ5Rwj9BURADU6TOnH.jpg'),
(151332, 10809, 'Minha Lady Jane S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393102.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tfJVVrrgYAfIw2QVrDF3qZ7LroY.jpg'),
(151333, 10809, 'Minha Lady Jane S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393103.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gvKbUXAMWGILeshzvv0kNdmizsv.jpg'),
(151334, 10809, 'Minha Lady Jane S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393104.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9pJQKVeghM6wV9f7Pez50bU6vZB.jpg'),
(151335, 10809, 'Minha Lady Jane S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393105.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xX2XeeYSPrX7ddUsDSWIleEVceW.jpg'),
(151336, 10809, 'Minha Lady Jane S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393106.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udKUEMB3SNcqmPEEKlUvnFLYCID.jpg'),
(151337, 10809, 'Minha Lady Jane S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393107.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bitudV3GBc4X3uP51j5shWxTkyt.jpg'),
(151338, 10809, 'Minha Lady Jane S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/393108.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3BTBtTm42EAmBkisuPcWGWeWSV.jpg'),
(151339, 10809, 'Minha Lady Jane S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/393109.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u6oSuN5snGzYlxElWnLn5srEOR9.jpg'),
(151340, 10810, 'Pequenos Gigantes da Natureza S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ImmshQCC4wZNsQzbmwQ0Ah4ox4.jpg'),
(151341, 10810, 'Pequenos Gigantes da Natureza S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ImmshQCC4wZNsQzbmwQ0Ah4ox4.jpg'),
(151342, 10810, 'Pequenos Gigantes da Natureza S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ImmshQCC4wZNsQzbmwQ0Ah4ox4.jpg'),
(151343, 10810, 'Pequenos Gigantes da Natureza S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ImmshQCC4wZNsQzbmwQ0Ah4ox4.jpg'),
(151344, 10810, 'Pequenos Gigantes da Natureza S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ImmshQCC4wZNsQzbmwQ0Ah4ox4.jpg'),
(151345, 10810, 'Pequenos Gigantes da Natureza S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ImmshQCC4wZNsQzbmwQ0Ah4ox4.jpg'),
(151346, 10811, 'Pequenos Gigantes da Natureza S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ImmshQCC4wZNsQzbmwQ0Ah4ox4.jpg'),
(151347, 10811, 'Pequenos Gigantes da Natureza S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ImmshQCC4wZNsQzbmwQ0Ah4ox4.jpg'),
(151348, 10811, 'Pequenos Gigantes da Natureza S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ImmshQCC4wZNsQzbmwQ0Ah4ox4.jpg'),
(151349, 10811, 'Pequenos Gigantes da Natureza S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ImmshQCC4wZNsQzbmwQ0Ah4ox4.jpg'),
(151350, 10811, 'Pequenos Gigantes da Natureza S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ImmshQCC4wZNsQzbmwQ0Ah4ox4.jpg'),
(151351, 10811, 'Pequenos Gigantes da Natureza S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ImmshQCC4wZNsQzbmwQ0Ah4ox4.jpg'),
(151352, 10811, 'Pequenos Gigantes da Natureza S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/393094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ImmshQCC4wZNsQzbmwQ0Ah4ox4.jpg'),
(151353, 10811, 'Pequenos Gigantes da Natureza S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/393095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ImmshQCC4wZNsQzbmwQ0Ah4ox4.jpg'),
(151354, 10811, 'Pequenos Gigantes da Natureza S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/393096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ImmshQCC4wZNsQzbmwQ0Ah4ox4.jpg'),
(151355, 10811, 'Pequenos Gigantes da Natureza S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/393097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ImmshQCC4wZNsQzbmwQ0Ah4ox4.jpg'),
(151356, 10811, 'Pequenos Gigantes da Natureza S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/393098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ImmshQCC4wZNsQzbmwQ0Ah4ox4.jpg'),
(151357, 10811, 'Pequenos Gigantes da Natureza S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/393099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ImmshQCC4wZNsQzbmwQ0Ah4ox4.jpg'),
(151358, 10811, 'Pequenos Gigantes da Natureza S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/393100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ImmshQCC4wZNsQzbmwQ0Ah4ox4.jpg'),
(151359, 10811, 'Pequenos Gigantes da Natureza S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/393101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ImmshQCC4wZNsQzbmwQ0Ah4ox4.jpg'),
(151360, 10812, 'Roma Ascensao e Queda de um Imperio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393070.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xziarXzJahAojFeR1zdEiYD8oQt.jpg'),
(151361, 10812, 'Roma Ascensao e Queda de um Imperio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393071.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s133henkrslXXVt0oRsbYcKtR15.jpg'),
(151362, 10812, 'Roma Ascensao e Queda de um Imperio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393072.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yaMImIN0IqDE8inet6tGwb2817K.jpg'),
(151363, 10812, 'Roma Ascensao e Queda de um Imperio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393073.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1qJB7mzXkYI2aI72VWc4JP6q4V1.jpg'),
(151364, 10812, 'Roma Ascensao e Queda de um Imperio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393074.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2Zr2YL1BiM2A6Q2JOBnKdC2v8k.jpg'),
(151365, 10812, 'Roma Ascensao e Queda de um Imperio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393075.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v2FtJdvOgIZ09cnZ22aqHoxlIgP.jpg'),
(151366, 10812, 'Roma Ascensao e Queda de um Imperio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/393076.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/suNnJCuDazN1fNDpukdSB6O6PQw.jpg'),
(151367, 10812, 'Roma Ascensao e Queda de um Imperio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/393077.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7nBPVRNgAO2f96UiY9KFLWGz8e8.jpg'),
(151368, 10812, 'Roma Ascensao e Queda de um Imperio S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/393078.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vDORZmXQqnUC0J4uwyvS48631rV.jpg'),
(151369, 10812, 'Roma Ascensao e Queda de um Imperio S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/393079.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yufw9WweJBVTQ0KW6shkhgCGGEP.jpg'),
(151370, 10812, 'Roma Ascensao e Queda de um Imperio S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/393080.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kHPGaNBH13esLy1qKiYtZ5C9sRy.jpg'),
(151371, 10812, 'Roma Ascensao e Queda de um Imperio S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/393081.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mb2mdGGdTjubAyMfiX4eDzfbF1A.jpg'),
(151372, 5388, 'Smiling Friends S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393053.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dHDrJBnnEQQU9D5xtX50s0n9ZHA.jpg'),
(151373, 5388, 'Smiling Friends S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393054.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9IJXCeuXGEenNvotRiK0iLDAuTH.jpg'),
(151374, 5388, 'Smiling Friends S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393055.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9N3dpw5ajGNx9rPgnK9yz2h4QMv.jpg'),
(151375, 5388, 'Smiling Friends S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393056.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vB4CXq4clxs1iE3K3RBzJ7uUDkZ.jpg'),
(151376, 5388, 'Smiling Friends S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393057.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z3ledZoTnAZRDdNxbIT28BZuJi0.jpg'),
(151377, 5388, 'Smiling Friends S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393058.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A34cKftnVVEIQyV16EDwLp0e61u.jpg'),
(151378, 5388, 'Smiling Friends S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/393059.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3enkr2iVHpL3Purpkg4MVnciw2P.jpg'),
(151379, 5388, 'Smiling Friends S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/393060.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lnainxcaQvu5tAdxF3yGRTSFuYT.jpg'),
(151380, 5388, 'Smiling Friends S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/393061.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2n9gOffofsDhyVjVQ8zGyIu5EbX.jpg'),
(151381, 10813, 'Smiling Friends S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393062.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgzLja7UW1Dfn0xDutKiuQtVx57.jpg'),
(151382, 10813, 'Smiling Friends S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393063.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eIugtNFaofqBX0IK95m0TCx064D.jpg'),
(151383, 10813, 'Smiling Friends S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393064.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/19Nf7mG9jV7BDHjYP5DgKbikGd2.jpg'),
(151384, 10813, 'Smiling Friends S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393065.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bN8uKUDqYWdJ9WCDG14gRsQnxKc.jpg'),
(151385, 10813, 'Smiling Friends S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393066.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/szrHVOToDfpNfFpr8QG1yFlPbaW.jpg'),
(151386, 10813, 'Smiling Friends S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393067.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dMpJqex5i9tfPMDrC9doHqyfCtM.jpg'),
(151387, 10813, 'Smiling Friends S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/393068.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/edG9evHYsty8nZhqrhgCnguRVz2.jpg'),
(151388, 10813, 'Smiling Friends S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/393069.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3w0DSVFCHWbNK1zrxYaUxmOYpXQ.jpg'),
(151389, 10814, 'Smiling Friends S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/888140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d0vwkQpKgBwZKHllNRV4nYJjLUs.jpg'),
(151390, 10814, 'Smiling Friends S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/889728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d0vwkQpKgBwZKHllNRV4nYJjLUs.jpg'),
(151391, 10814, 'Smiling Friends S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/889729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d0vwkQpKgBwZKHllNRV4nYJjLUs.jpg'),
(151392, 10814, 'Smiling Friends S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/891017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d0vwkQpKgBwZKHllNRV4nYJjLUs.jpg'),
(151393, 10814, 'Smiling Friends S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/892418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d0vwkQpKgBwZKHllNRV4nYJjLUs.jpg'),
(151394, 10814, 'Smiling Friends S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/893063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d0vwkQpKgBwZKHllNRV4nYJjLUs.jpg'),
(151395, 10814, 'Smiling Friends S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/893453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d0vwkQpKgBwZKHllNRV4nYJjLUs.jpg'),
(151396, 10814, 'Smiling Friends S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/894198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d0vwkQpKgBwZKHllNRV4nYJjLUs.jpg'),
(151397, 10815, 'Supacell S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393047.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eWvl6hiqHhrM1dA4eusCdvJRuxt.jpg'),
(151398, 10815, 'Supacell S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393048.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1aVelst9h9WZJza1ccqRNftRjMk.jpg'),
(151399, 10815, 'Supacell S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393049.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ONzrBYMgzTd3JAbGZHcdUnu4zg.jpg'),
(151400, 10815, 'Supacell S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393050.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3HgmsxtTG7yTtkVT4uCg5PrE1gr.jpg'),
(151401, 10815, 'Supacell S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393051.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3PxbfZeazL9B4tHOp4okAxcYjyE.jpg'),
(151402, 10815, 'Supacell S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393052.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xm7WcPCWzYcecpmO6MArNY5pbRp.jpg'),
(151403, 10816, 'Terra de Mulheres S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393045.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7rKRc6ctFJXPlrZxGe8OFH3eDkI.jpg'),
(151404, 10816, 'Terra de Mulheres S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393046.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qkgXFLP2SD8QsSJ9oURql1oYU3o.jpg'),
(151405, 10816, 'Terra de Mulheres S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/400229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eIy7ZOEuHFuMueMqR8QAyAUSqxO.jpg'),
(151406, 10816, 'Terra de Mulheres S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/404058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eIy7ZOEuHFuMueMqR8QAyAUSqxO.jpg'),
(151407, 10816, 'Terra de Mulheres S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/411284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eIy7ZOEuHFuMueMqR8QAyAUSqxO.jpg'),
(151408, 10816, 'Terra de Mulheres S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/414337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eIy7ZOEuHFuMueMqR8QAyAUSqxO.jpg'),
(151409, 10817, 'Yellowstone One Fifty S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pg5YRQPGyS8ZGjMUYlKvec1AYuh.jpg'),
(151410, 10817, 'Yellowstone One Fifty S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9C4tp7m7ldlZHYoSB0cm6myxCCK.jpg'),
(151411, 10817, 'Yellowstone One Fifty S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yiWvBC4jDW4s8l8JDumQtcRpear.jpg'),
(151412, 10817, 'Yellowstone One Fifty S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5pramPkurxq4RKm35DcBOskOjle.jpg'),
(151413, 10818, 'Blood Blockade Battlefront S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tH2mCwKm8sgC8RAPNdOKyIQtKYr.jpg'),
(151414, 10818, 'Blood Blockade Battlefront S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ccHNNE8TdUzi6NlksODqMJI8OH.jpg'),
(151415, 10818, 'Blood Blockade Battlefront S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/euGc7boo4z7heQwyeXWaYAbx2vO.jpg'),
(151416, 10818, 'Blood Blockade Battlefront S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n0pq4Ut0jX2GEblT90g3Ya6joHM.jpg'),
(151417, 10818, 'Blood Blockade Battlefront S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnz9MpStyl4Le6yewQTyQJyY8hn.jpg'),
(151418, 10818, 'Blood Blockade Battlefront S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/smxSoTvh8sOQN1IycimnrUR76tA.jpg'),
(151419, 10818, 'Blood Blockade Battlefront S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/393827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A77idlqRXWCATrUCKNOPMhqO4Ab.jpg'),
(151420, 10818, 'Blood Blockade Battlefront S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/393828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xEFY9Uj580DE0jyh0gjJ3EhQw6S.jpg'),
(151421, 10818, 'Blood Blockade Battlefront S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/393829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6W1SlUiq76YgindhFhM3QDKlR7z.jpg'),
(151422, 10818, 'Blood Blockade Battlefront S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/393830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yGzVM6BLyh4GCaQTwDLybc7OEcx.jpg'),
(151423, 10818, 'Blood Blockade Battlefront S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/393831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJxCGMtuf13zEYxMcpIxj1ZIuPS.jpg'),
(151424, 10818, 'Blood Blockade Battlefront S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/393832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j2MK2f2QIWe7gePGHg5hVOwDOUQ.jpg'),
(151425, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kLDfENy7B07ICO3e0sT8XjCQ4lO.jpg'),
(151426, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iTHQ2YcXuodNNK08ko0T4M8B6FN.jpg'),
(151427, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8KvtQzv7uhG3mGcmKFmO6pGoUFF.jpg'),
(151428, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uX6C5ydqDpTiQk7EaJtVodLM9NO.jpg'),
(151429, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8UiGtADBz8ss99bChCimeGcP1xI.jpg'),
(151430, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6E0CujFRcKEi4Y7BY956zZjosDg.jpg'),
(151431, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/393706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A6EKfp0v9ELKHEO2RSZhGAlFYkM.jpg'),
(151432, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/393707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ruRE3C4RtyNegmtynykx1xkyu9m.jpg'),
(151433, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/393708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/36kanj9m0WWzNSF1IK9sYhMJMQV.jpg'),
(151434, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/393709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9yK6vNyJQM8oTf90S37xAGUglAC.jpg'),
(151435, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/393710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4vyLjLaWI2nFWrDMb63opHxZF08.jpg'),
(151436, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/393711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6uIA09uRyrmodlsHZ6NB1S6vkD4.jpg'),
(151437, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/393712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3QZ7FjuzX3UaUBghz10j86vd59.jpg'),
(151438, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/393713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zr13N1wU818ive6IUsCuCiHX9dy.jpg'),
(151439, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/393714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rn98XWpEAAoTlrSqcZ468NkMfBW.jpg'),
(151440, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/393715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7WAxcwKAw0UWDXHGf9ewuen3JLN.jpg'),
(151441, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/393716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sr8DppOyeB6qQS0k8LXnsGXbXUC.jpg'),
(151442, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/393717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rk6nNwtK7lL1ZxjDRNZtUDygNpK.jpg'),
(151443, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/393718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c8y3uTHy5LJaPIqiQq4sJ03I3Gq.jpg'),
(151444, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/393719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/52DNZpSGcCgg36BAxuHR9VK0L5G.jpg'),
(151445, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/393720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sgaInrbHsimefVeFNPOYEkSkv8R.jpg'),
(151446, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/393721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/okjsaw23lmysJTD9I4SJboEUwzK.jpg'),
(151447, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/393722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pwf3PWfq0HikHJvNDie7LQnDUgP.jpg'),
(151448, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/393723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ujCeJMg69oNVPoMq1YXyNCYOKfI.jpg'),
(151449, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/393724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ijmvRC1xU8niAMpfaYh9T07aEsT.jpg'),
(151450, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/393725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iUmepgSE5SuKICuwzvN0OEkt0Av.jpg'),
(151451, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/393726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uc7audYKu6OUREUhQiq7VecpPfw.jpg'),
(151452, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/393727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1vZwmvh1I1vFcffd3QzAQ7gGaV5.jpg'),
(151453, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/393728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wht2R8vwLuHYGad30cqftfd4Z0N.jpg'),
(151454, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/393729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/26kFNnPP7bTw77IhwyRernytOs0.jpg'),
(151455, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/393730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhH8jR0NNe2GDi9HvvZ90HOBc59.jpg'),
(151456, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/393731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5AKRZ7m0PGs0XxjbFAXUVkVFhea.jpg'),
(151457, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/393732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rmjbhL2nasKfMAOVLKo9u2T36nd.jpg'),
(151458, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/393733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pEq4FJlmvrUFUGyOaM74hcVq2JQ.jpg'),
(151459, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/393734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lUDBXpgTHuf1c9mfjXyyLSW0PnF.jpg'),
(151460, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/393735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wbeA9IW9WxEJA2vhw8fPpe6Wehq.jpg'),
(151461, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/393736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pvjoWpTnTplX1tN961xoK98JPPL.jpg'),
(151462, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/393737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oGZTvBGg68zQOrpKgLnqjevhA46.jpg'),
(151463, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/393738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dOgtKQJReFeJLOLxricfCDxcrYp.jpg'),
(151464, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/393739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sjh95ZutCw6Qkt6V5ddH5XakivK.jpg'),
(151465, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/393740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5J8rs2d5rl7UKekB8x7ME43Yjqa.jpg'),
(151466, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/393741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dmCkY9PzmrCkXjLsQmjfhO1N8LX.jpg'),
(151467, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/393742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/apwdViRHdS7fpos7dzTOJ4ZQmP7.jpg'),
(151468, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/393743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x2GaswPtDQYnQchaNoU7y6RLXVk.jpg'),
(151469, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/393744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/njBnGk79gqCikaPobcbCH8iVXWP.jpg'),
(151470, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/393745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gTcrQruVVulVjzcGqsuz0goH6sB.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(151471, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/393746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lm4JMXiXQu9YcutSVEOymy0wgSM.jpg'),
(151472, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/393747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a2x2uPL7sqnTn995hKuYH0CEzmC.jpg'),
(151473, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/393748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jHA5LBQLP3PdsBuqexbxEHAd7qv.jpg'),
(151474, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/393749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ucynpngToVPgqmlpjkXNA2CeQzf.jpg'),
(151475, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/393750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tsZHM0b5v6WBKo0E5HcRHiZNnH6.jpg'),
(151476, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/393751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QTpY0tdJS667H5rp8hEQP3cDgG.jpg'),
(151477, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/393752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c3JYchFkFLhgfm8zaHFzUFL1ygf.jpg'),
(151478, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/393753.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aVF0ZDjHSZY3x3ktL8Uo6wqJMfC.jpg'),
(151479, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/393754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5HJNy7GT45nXdrJxpGkzi5mSHz.jpg'),
(151480, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/393755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLGxuKXwI5D5U44wZPmVWWBDZ4i.jpg'),
(151481, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/393756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rTjYGC6M8lM3U3YGjariWHptT1H.jpg'),
(151482, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/393757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rPZTvgOmoZwiIYrXsHL8E85KyY2.jpg'),
(151483, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/393758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ag9wNFzc4OAtbwK0SRqdwoVZppi.jpg'),
(151484, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/393759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ncW6xTJdpXcleSBxIKlMyCEfzFc.jpg'),
(151485, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/393760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5tYGSP5ZbPnifwZOG9uL63yGMI.jpg'),
(151486, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/393761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vBVgDrI68NQubJTDy3H9wNs2DFw.jpg'),
(151487, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/393762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9zFJZVmYdsaXjuOX6ZX7QunJWZ4.jpg'),
(151488, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/393763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fQI7Y8zHND1a6jh8vmIoAyHtv0v.jpg'),
(151489, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/393764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vALzVDzFgpGnZfbWK86TsnsYrRg.jpg'),
(151490, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/393765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zhJVynVyHLEzDVGXVJedbqWika2.jpg'),
(151491, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/393766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/upRVdTXvKRhgktUxuutcwZodhRh.jpg'),
(151492, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/393767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eyljqFa9kLhlxuP12IrtOlhdOiT.jpg'),
(151493, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/393768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/523gmrsBnFO2Flry0vyTi14UUXw.jpg'),
(151494, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/393769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8cd4uEkAM8WYIxQp4WrcVdYNo9l.jpg'),
(151495, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/393770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5O0bPGJYrOFh0nlcv4lP0gjt1a0.jpg'),
(151496, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/393771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xXDgnfhkSScMoiTsNRiGtNF245f.jpg'),
(151497, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/393772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lQAd510Pe2GAvqnreTYojM6FrPC.jpg'),
(151498, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/393773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/apt7wqPiWKSQeKn8gYtjrNyaetL.jpg'),
(151499, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/393774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cbYD6hDTbWKUT55sIT1t5xC6bZl.jpg'),
(151500, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/393775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aOTKeDAIBSSlJ9UwiunLeZI5VSv.jpg'),
(151501, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/393776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ekuEuVrZUk1IqlGshGJoxNxcTrK.jpg'),
(151502, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/393777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ldLwu2umaapFyZkXeZpqvGYtfVe.jpg'),
(151503, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/393778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLWu10ggsesS2KktimlR238WHe9.jpg'),
(151504, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/393779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/euGDDvYTtubMX8SCRHIfc65a7Yo.jpg'),
(151505, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/393780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AoQuNo46VaWJLoF5YrSKC1u9U1l.jpg'),
(151506, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/393781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8xr8HNbjk3nZuPyIdVv2FUYvbJk.jpg'),
(151507, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/393782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cdmHLcacq7Lj9azp7QYgNmWobcO.jpg'),
(151508, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/393783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4upixDAjUfOmjxyBHBZN5KXtRP5.jpg'),
(151509, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/393784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bid6VUaonocKdltd0SWDC7Kyppt.jpg'),
(151510, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/393785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fbEIlwTnY5KPu15CnnydunwXQMP.jpg'),
(151511, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/393786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pz4f35bZjwRV8G95Ro9cEmZuPuj.jpg'),
(151512, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/393787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hACtv1OuqN17DV241EwOTfAS4gZ.jpg'),
(151513, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/393788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4n7rScK7CiBranka9Igtjt2XYNf.jpg'),
(151514, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/393789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v0waE3k4dVN9MpcCmcUUF7PZqRm.jpg'),
(151515, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/393790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFUJ5qboTuKP80re8jrRSBmvAff.jpg'),
(151516, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/393791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wgfq1tPavMvui30lTSgMSulVxon.jpg'),
(151517, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/393792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AL93c5YVBjZee5ZsHog3m799lg.jpg'),
(151518, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/393793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xnaZumXnCTU7L5KbbU8hx10Q9Zy.jpg'),
(151519, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/393794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6IUbK4bnJ20YHS8YvZbjA8ZP6jC.jpg'),
(151520, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/393795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lx08mKpRjFH4KTR6jlxZObgMiCy.jpg'),
(151521, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/393796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Wy0cpiw3Q36ZOCyVqLkq9HwJx0.jpg'),
(151522, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/393797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3kOUfnN1PM91X9hoH469X12LpEF.jpg'),
(151523, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/393798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jtiJsKxnQX7srUrzDWwhymtlH8w.jpg'),
(151524, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/393799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mWmWxW2NtmylPLI6KvlQMOfuWlB.jpg'),
(151525, 10819, 'Dragon Quest The Adventure of Dai [L] S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/393800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/spo9ZaCbIRaU2esyOycSEVZpMe3.jpg'),
(151526, 10820, 'Marco Polo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iisiLGOuLVZe0CawkV2clBeaqdE.jpg'),
(151527, 10820, 'Marco Polo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8axrzm5EdFngvOfdyQMHrAiDeLT.jpg'),
(151528, 10820, 'Marco Polo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iarwu6nyAaM7PfN8aU2aVBcdJWo.jpg'),
(151529, 10820, 'Marco Polo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wSk9iL61fsfPsgOjeLfnHjuto5z.jpg'),
(151530, 10820, 'Marco Polo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g2EvK5EjIzm2OjNDV1O7aYLvKUo.jpg'),
(151531, 10820, 'Marco Polo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJUSymGQOvTk1AOUmU2XOiamXeD.jpg'),
(151532, 10820, 'Marco Polo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/393807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJ03mpbLCBk4NAGhkp8LjOtbaGQ.jpg'),
(151533, 10820, 'Marco Polo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/393808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lytIBnGomlWJRgRNcb9ibpdwEKq.jpg'),
(151534, 10820, 'Marco Polo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/393809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sOd0L0eprrfRrwEFpMLqoFQOlYT.jpg'),
(151535, 10820, 'Marco Polo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/393810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t5kcwvEsyyPdxIheVQEZVbRwgoG.jpg'),
(151536, 10821, 'Marco Polo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uEqkAPnCN1cQXxP5TKHcbrZvyEE.jpg'),
(151537, 10821, 'Marco Polo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5TBUcWcGIP0f3IgeMKuJwPLY8iq.jpg'),
(151538, 10821, 'Marco Polo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1TtPpswHkwcwZp7lokAx0yuWZGl.jpg'),
(151539, 10821, 'Marco Polo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7laaupCEFDq8sX3POZk3vXNiomK.jpg'),
(151540, 10821, 'Marco Polo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qsLWBlWKFZXqb42dkumQNa4nHss.jpg'),
(151541, 10821, 'Marco Polo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oTAofQJMt7KaKL3C0gQaanzhkMN.jpg'),
(151542, 10821, 'Marco Polo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/393817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pMqnSmmvwK0SkP8vH2DssELRo1h.jpg'),
(151543, 10821, 'Marco Polo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/393818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fMbK2Wkyb6LYDQerY6eOBvFeOB7.jpg'),
(151544, 10821, 'Marco Polo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/393819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7WTDkyqrl7ErQumnCKdQHbRBqkO.jpg'),
(151545, 10821, 'Marco Polo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/393820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wKJjKMOalpvQpeqDk1zfICFRTsy.jpg'),
(151546, 10822, 'Meu Chefe [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hYZpObCCyoMRxPaEkYou0n2ZBfT.jpg'),
(151547, 10822, 'Meu Chefe [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xF4p6fVgdqhrHmRt3gp3ygXtgEO.jpg'),
(151548, 10822, 'Meu Chefe [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oSiSUxV6AkaD9SwDQunw6skzlKa.jpg'),
(151549, 10822, 'Meu Chefe [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qzuifqEt8my7GK1Cgds45AlDlEY.jpg'),
(151550, 10822, 'Meu Chefe [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nI0BreAFdgkgSjLDpXLUTleSe6J.jpg'),
(151551, 10822, 'Meu Chefe [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3i5ltMLXpj9QyiOLrSRT6EJ3FOX.jpg'),
(151552, 10822, 'Meu Chefe [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/393670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sr49AUQ54pWRFCO31ol9TiYjEaL.jpg'),
(151553, 10822, 'Meu Chefe [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/393671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWaBqGSO4vKLsdzP2sYAV1xjAED.jpg'),
(151554, 10822, 'Meu Chefe [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/393672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j9hTygzPiF6e5S3ANpMh4ePezBb.jpg'),
(151555, 10822, 'Meu Chefe [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/393673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/40aKdJ4Jhp3ztJDmBocNqI5fCNs.jpg'),
(151556, 10822, 'Meu Chefe [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/393674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vKUSpKGtW663rME4MorRYUKxrln.jpg'),
(151557, 10822, 'Meu Chefe [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/393675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rbsouXGRMMKBI6FIICfTt0i0Hkl.jpg'),
(151558, 10822, 'Meu Chefe [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/393676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4DfilJNPY69sEX17tV1sKmKKCFj.jpg'),
(151559, 10822, 'Meu Chefe [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/393677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gaRAZie7rgOwJpYvMdKpoxUqJyS.jpg'),
(151560, 10822, 'Meu Chefe [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/393678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hTolD7Mdp5mB86ioKQsArP6wpq9.jpg'),
(151561, 10822, 'Meu Chefe [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/393679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yBmFFV8rbNK9buCJaDpdxzUS3Hr.jpg'),
(151562, 10822, 'Meu Chefe [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/393680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AdE3mdockIb3Jwepk0RLbsBTAkD.jpg'),
(151563, 10822, 'Meu Chefe [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/393681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oYwlfEDVcWQgSUWi2tw3tKt0jEF.jpg'),
(151564, 10822, 'Meu Chefe [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/393682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wqjdS9HOYgGPBthdGqmgteGT9dV.jpg'),
(151565, 10822, 'Meu Chefe [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/393683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2VHEATEiapA8S31JCJr4ohtmxKm.jpg'),
(151566, 10822, 'Meu Chefe [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/393684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2WrS8UAR22AMptelX148qumQGR8.jpg'),
(151567, 10822, 'Meu Chefe [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/393685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xUNIHPy2FAzPSUV4pRcCPrdNJUt.jpg'),
(151568, 10822, 'Meu Chefe [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/393686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eaK7gzLhLuMZV0plM13BUZ3IJ4h.jpg'),
(151569, 10822, 'Meu Chefe [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/393687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fLAJ2ubEQv4o13FswR2M1PgRcKD.jpg'),
(151570, 10822, 'Meu Chefe [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/393688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lPMWZbQHko6O0j0RaT8JyWERpRo.jpg'),
(151571, 10822, 'Meu Chefe [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/393689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1oDTPXlrAabIydLwH5lRVpsVsG6.jpg'),
(151572, 10822, 'Meu Chefe [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/393690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oUsBozuhrhYH6SaPLL2f8EeeitK.jpg'),
(151573, 10822, 'Meu Chefe [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/393691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qfqO9q9fotJsbrKte07ccDl5B5l.jpg'),
(151574, 10822, 'Meu Chefe [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/393692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ztlUJqR2UsevYBmiGQueRljxroQ.jpg'),
(151575, 10822, 'Meu Chefe [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/393693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c1cOM4RliTdskJc02l4NUsbieta.jpg'),
(151576, 10822, 'Meu Chefe [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/393694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l13XrAxOTI63d5fKGtUxkS2Ao0N.jpg'),
(151577, 10822, 'Meu Chefe [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/393695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pIFy8HkFubQdXkL3C0h9qkYfMFU.jpg'),
(151578, 10822, 'Meu Chefe [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/393696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r1v1D03qG243U3ob880aN0evIhK.jpg'),
(151579, 10822, 'Meu Chefe [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/393697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cUNhngKPju7lfWW6Av92vMS7rS3.jpg'),
(151580, 10822, 'Meu Chefe [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/393698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7yWoWH35uEKe5YvPicsWlGsrmoE.jpg'),
(151581, 10822, 'Meu Chefe [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/393699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AfeDJQx6X2lgNRaFzzPnQANz4eI.jpg'),
(151582, 10823, 'O Que Houve com a Secretaria Kim [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zFHplEPtshE3yLagZCzJMPhPJcL.jpg'),
(151583, 10823, 'O Que Houve com a Secretaria Kim [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qx0gxPMVPwXlHdNe5ves4BaC5Vc.jpg'),
(151584, 10823, 'O Que Houve com a Secretaria Kim [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rNr8sCLyBgXNS2PbfxlbM8ZLwXc.jpg'),
(151585, 10823, 'O Que Houve com a Secretaria Kim [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9cei7VJYlKrMSmxJGQaKfAA4RIu.jpg'),
(151586, 10823, 'O Que Houve com a Secretaria Kim [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d7yhXPPyqyveyPMOYfcDFEizQLA.jpg'),
(151587, 10823, 'O Que Houve com a Secretaria Kim [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/onB89hF6BOlm4bVPhUCukSGOLHV.jpg'),
(151588, 10823, 'O Que Houve com a Secretaria Kim [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/393654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cq6QGTL8PjjHAgRao0hZ8mW8YnC.jpg'),
(151589, 10823, 'O Que Houve com a Secretaria Kim [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/393655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5BiR0tJkI1QA2m7YFJdIU9XdhHh.jpg'),
(151590, 10823, 'O Que Houve com a Secretaria Kim [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/393656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4li912WPP1jZUkhBapyUkjgxXft.jpg'),
(151591, 10823, 'O Que Houve com a Secretaria Kim [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/393657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mhvvAp1QtEdrPlVnAslLjzb8hf0.jpg'),
(151592, 10823, 'O Que Houve com a Secretaria Kim [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/393658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJa1yqkBtluMoCkEBQh36PQPC0n.jpg'),
(151593, 10823, 'O Que Houve com a Secretaria Kim [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/393659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1fAFsy6JJUj0ZMsGXdzXBIDz0tZ.jpg'),
(151594, 10823, 'O Que Houve com a Secretaria Kim [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/393660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nsANoaiOfiOxV614FaVdwKVd0UE.jpg'),
(151595, 10823, 'O Que Houve com a Secretaria Kim [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/393661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cCHl1ruaRkx5cqmMgV2Xekoafli.jpg'),
(151596, 10823, 'O Que Houve com a Secretaria Kim [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/393662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9t3LkJuW7oO8xngYBfMYD7PkuNW.jpg'),
(151597, 10823, 'O Que Houve com a Secretaria Kim [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/393663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0g5J1p2iHru2QqtBgWOYUKYlS9.jpg'),
(151598, 10824, 'Yu Gi Oh GX S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMtfPu3cDfrYklJxeb96YGncwxK.jpg'),
(151599, 10824, 'Yu Gi Oh GX S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kMRIiF5PrWSSHYkMbAdhdMe0UBs.jpg'),
(151600, 10824, 'Yu Gi Oh GX S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/87FlU1LTwUxrE83H97jwBpYuoix.jpg'),
(151601, 10824, 'Yu Gi Oh GX S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ydbZ00Z6tSZbTy2PuGvf4AJSKZM.jpg'),
(151602, 10824, 'Yu Gi Oh GX S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r7DjfWYD1t8LFzbYzgEXdfud5DJ.jpg'),
(151603, 10824, 'Yu Gi Oh GX S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7M01JMFrYHSrsd15xMD8fVH2dQf.jpg'),
(151604, 10824, 'Yu Gi Oh GX S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/393436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/64ndYJhY9eBf8qhxYjmp3eSclqU.jpg'),
(151605, 10824, 'Yu Gi Oh GX S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/393437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cEG3rWyqZ2mNs1Y9k6cpfu41GUb.jpg'),
(151606, 10824, 'Yu Gi Oh GX S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/393438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hmohs2zKGIhGWIlx3jCEPEYGpWG.jpg'),
(151607, 10824, 'Yu Gi Oh GX S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/393439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s7G7HzGkpxxar7h3S2SXycHWMMV.jpg'),
(151608, 10824, 'Yu Gi Oh GX S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/393440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yxnPGhg9bsmW5sgd8VRCXxPoOOq.jpg'),
(151609, 10824, 'Yu Gi Oh GX S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/393441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xk7YaozJy9UeKw1RK3L2pLP9CrP.jpg'),
(151610, 10824, 'Yu Gi Oh GX S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/393442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wJoxR6rOqIhd5Iau9R8qYndiRm5.jpg'),
(151611, 10824, 'Yu Gi Oh GX S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/393443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vi5wfzl7xFE0TVtp4QXFaVahgZm.jpg'),
(151612, 10824, 'Yu Gi Oh GX S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/393444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zd4xb4kDjVQtHJvnUfWf1kq2V7I.jpg'),
(151613, 10824, 'Yu Gi Oh GX S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/393445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9qY6VThinBxbNs7JCwZKz2vrjGX.jpg'),
(151614, 10824, 'Yu Gi Oh GX S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/393446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lckWr2uHDfpxMrgG4foxi7Wa7w5.jpg'),
(151615, 10824, 'Yu Gi Oh GX S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/393447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kTcmn9OUZzfi6Q3PgBiplC1spop.jpg'),
(151616, 10824, 'Yu Gi Oh GX S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/393448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/smuY4AFDgJaQA3fvTJGJyR8iegd.jpg'),
(151617, 10824, 'Yu Gi Oh GX S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/393449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7MszogEDWOQhLnfHF5thSZAxzWZ.jpg'),
(151618, 10824, 'Yu Gi Oh GX S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/393450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fEA4FR7qg9Of3mBykobJdmcOrPJ.jpg'),
(151619, 10824, 'Yu Gi Oh GX S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/393451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vn1pq6jFDWKoVaQHbXv3ttoAmQW.jpg'),
(151620, 10824, 'Yu Gi Oh GX S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/393452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nuDFXfhFNmioxYtf4R6KDqihWZm.jpg'),
(151621, 10824, 'Yu Gi Oh GX S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/393453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vFCmEZiddyoNmioN1UXQvoMIiA9.jpg'),
(151622, 10824, 'Yu Gi Oh GX S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/393454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ihyHeQGXKr683UxLyGAzIpozGn7.jpg'),
(151623, 10824, 'Yu Gi Oh GX S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/393455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgVj4o4XLju5SV7B7o7WEowcmKe.jpg'),
(151624, 10824, 'Yu Gi Oh GX S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/393456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vZOMp9ZlvgtAMbF8PhvcqsSJ494.jpg'),
(151625, 10824, 'Yu Gi Oh GX S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/393457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i5AH8HjUr4YMp82qewRPT431XA9.jpg'),
(151626, 10824, 'Yu Gi Oh GX S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/393458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h6p9NtMZALFfml7gkfqbSe4AWCb.jpg'),
(151627, 10824, 'Yu Gi Oh GX S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/393459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nhci5gCc1zt3XABtM9siz0MVpEq.jpg'),
(151628, 10824, 'Yu Gi Oh GX S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/393460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uzE93gtsV7YJ27RosSlxR3EMCDf.jpg'),
(151629, 10824, 'Yu Gi Oh GX S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/393461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gcjQrS8Gcvo6KbbBXfhrxVKyHpJ.jpg'),
(151630, 10824, 'Yu Gi Oh GX S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/393462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rLd1sBZqr7Oc0exIPTYCvDQf7ZR.jpg'),
(151631, 10824, 'Yu Gi Oh GX S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/393463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qjjVwsHsbDtYEEoe459smeleeMb.jpg'),
(151632, 10824, 'Yu Gi Oh GX S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/393464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fBu2zKd3XFEsZfbJvQtcOSpvG2k.jpg'),
(151633, 10824, 'Yu Gi Oh GX S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/393465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/emyHqM5TlSaTT1VlSSsbZrpv9EW.jpg'),
(151634, 10824, 'Yu Gi Oh GX S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/393466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6oPS7WwNsYY4rw5e4nn22uW51rU.jpg'),
(151635, 10824, 'Yu Gi Oh GX S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/393467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nqMTX39FMva4sJSAx0fI7L4YH1m.jpg'),
(151636, 10824, 'Yu Gi Oh GX S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/393468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x9mzuWdyKP4bQBv5VNFJhlfwRkr.jpg'),
(151637, 10824, 'Yu Gi Oh GX S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/393469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zh1s4UXTr9AQ4yV7oOTlfSIN7z4.jpg'),
(151638, 10824, 'Yu Gi Oh GX S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/393470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8m9OlHY02Mxq8yo61QNxa2ghpKA.jpg'),
(151639, 10824, 'Yu Gi Oh GX S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/393471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nYHcpqAAAmuSXZL6sE3fN6bGmqi.jpg'),
(151640, 10824, 'Yu Gi Oh GX S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/393472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gujJ5x33SfmfCwCCFAtKiuUSjTH.jpg'),
(151641, 10824, 'Yu Gi Oh GX S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/393473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/G5GZkQcHXYAyqWK6EKiqOp0CtN.jpg'),
(151642, 10824, 'Yu Gi Oh GX S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/393474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6IqERbooaArX0Ni4joB4aZHRz78.jpg'),
(151643, 10824, 'Yu Gi Oh GX S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/393475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2J2C3cm0EPn4E05Px1XFZgzvEvz.jpg'),
(151644, 10824, 'Yu Gi Oh GX S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/393476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2uFZSJ7x0qGeEdpZtZRkdE5aGqW.jpg'),
(151645, 10824, 'Yu Gi Oh GX S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/393477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cFTC4Y26cDyDHOH2ScwO5GnWa7r.jpg'),
(151646, 10824, 'Yu Gi Oh GX S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/393478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/edJSv9Vpjy6fZikfIzCgEQEwdnZ.jpg'),
(151647, 10824, 'Yu Gi Oh GX S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/393479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/36WnDthUBXtCPPO69lMLsW8VJEm.jpg'),
(151648, 10824, 'Yu Gi Oh GX S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/393480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tBObOLApV71dELZj8CdosFCTHSY.jpg'),
(151649, 10824, 'Yu Gi Oh GX S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/393481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fYO1M1i22M3AZeu0lJT9JKxtiuE.jpg'),
(151650, 10824, 'Yu Gi Oh GX S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/393482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151651, 10824, 'Yu Gi Oh GX S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/393483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151652, 10824, 'Yu Gi Oh GX S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/393484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151653, 10824, 'Yu Gi Oh GX S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/393485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151654, 10824, 'Yu Gi Oh GX S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/393486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151655, 10824, 'Yu Gi Oh GX S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/393487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151656, 10824, 'Yu Gi Oh GX S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/393488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151657, 10824, 'Yu Gi Oh GX S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/393489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151658, 10824, 'Yu Gi Oh GX S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/393490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151659, 10824, 'Yu Gi Oh GX S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/393491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151660, 10824, 'Yu Gi Oh GX S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/393492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151661, 10824, 'Yu Gi Oh GX S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/393493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151662, 10824, 'Yu Gi Oh GX S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/393494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151663, 10824, 'Yu Gi Oh GX S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/393495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151664, 10824, 'Yu Gi Oh GX S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/393496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151665, 10824, 'Yu Gi Oh GX S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/393497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151666, 10824, 'Yu Gi Oh GX S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/393498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151667, 10824, 'Yu Gi Oh GX S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/393499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151668, 10824, 'Yu Gi Oh GX S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/393500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151669, 10824, 'Yu Gi Oh GX S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/393501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151670, 10824, 'Yu Gi Oh GX S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/393502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151671, 10824, 'Yu Gi Oh GX S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/393503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151672, 10824, 'Yu Gi Oh GX S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/393504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151673, 10824, 'Yu Gi Oh GX S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/393505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151674, 10824, 'Yu Gi Oh GX S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/393506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151675, 10824, 'Yu Gi Oh GX S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/393507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151676, 10824, 'Yu Gi Oh GX S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/393508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151677, 10824, 'Yu Gi Oh GX S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/393509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151678, 10824, 'Yu Gi Oh GX S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/393510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151679, 10824, 'Yu Gi Oh GX S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/393511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151680, 10824, 'Yu Gi Oh GX S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/393512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151681, 10824, 'Yu Gi Oh GX S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/393513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151682, 10824, 'Yu Gi Oh GX S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/393514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151683, 10824, 'Yu Gi Oh GX S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/393515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151684, 10824, 'Yu Gi Oh GX S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/393516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151685, 10824, 'Yu Gi Oh GX S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/393517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151686, 10824, 'Yu Gi Oh GX S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/393518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151687, 10824, 'Yu Gi Oh GX S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/393519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151688, 10824, 'Yu Gi Oh GX S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/393520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151689, 10824, 'Yu Gi Oh GX S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/393521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151690, 10824, 'Yu Gi Oh GX S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/393522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151691, 10824, 'Yu Gi Oh GX S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/393523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151692, 10824, 'Yu Gi Oh GX S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/393524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151693, 10824, 'Yu Gi Oh GX S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/393525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151694, 10824, 'Yu Gi Oh GX S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/393526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151695, 10824, 'Yu Gi Oh GX S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/393527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151696, 10824, 'Yu Gi Oh GX S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/393528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151697, 10824, 'Yu Gi Oh GX S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/393529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151698, 10824, 'Yu Gi Oh GX S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/393530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151699, 10824, 'Yu Gi Oh GX S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/393531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151700, 10824, 'Yu Gi Oh GX S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/393532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151701, 10824, 'Yu Gi Oh GX S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/393533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151702, 10824, 'Yu Gi Oh GX S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/393534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151703, 10824, 'Yu Gi Oh GX S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/393535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151704, 10824, 'Yu Gi Oh GX S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/393536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151705, 10824, 'Yu Gi Oh GX S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/393537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151706, 10824, 'Yu Gi Oh GX S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/393538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151707, 10824, 'Yu Gi Oh GX S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/393539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151708, 10824, 'Yu Gi Oh GX S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/393540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151709, 10824, 'Yu Gi Oh GX S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/393541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151710, 10824, 'Yu Gi Oh GX S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/393542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151711, 10824, 'Yu Gi Oh GX S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/393543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151712, 10824, 'Yu Gi Oh GX S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/393544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151713, 10824, 'Yu Gi Oh GX S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/393545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151714, 10824, 'Yu Gi Oh GX S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/393546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151715, 10824, 'Yu Gi Oh GX S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/393547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151716, 10824, 'Yu Gi Oh GX S01 E119', 'http://sinalprivado.info:80/series/1533784/1533784/393548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151717, 10824, 'Yu Gi Oh GX S01 E120', 'http://sinalprivado.info:80/series/1533784/1533784/393549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151718, 10824, 'Yu Gi Oh GX S01 E121', 'http://sinalprivado.info:80/series/1533784/1533784/393550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151719, 10824, 'Yu Gi Oh GX S01 E122', 'http://sinalprivado.info:80/series/1533784/1533784/393551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151720, 10824, 'Yu Gi Oh GX S01 E123', 'http://sinalprivado.info:80/series/1533784/1533784/393552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151721, 10824, 'Yu Gi Oh GX S01 E124', 'http://sinalprivado.info:80/series/1533784/1533784/393553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151722, 10824, 'Yu Gi Oh GX S01 E125', 'http://sinalprivado.info:80/series/1533784/1533784/393554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151723, 10824, 'Yu Gi Oh GX S01 E126', 'http://sinalprivado.info:80/series/1533784/1533784/393555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151724, 10824, 'Yu Gi Oh GX S01 E127', 'http://sinalprivado.info:80/series/1533784/1533784/393556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151725, 10824, 'Yu Gi Oh GX S01 E128', 'http://sinalprivado.info:80/series/1533784/1533784/393557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151726, 10824, 'Yu Gi Oh GX S01 E129', 'http://sinalprivado.info:80/series/1533784/1533784/393558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151727, 10824, 'Yu Gi Oh GX S01 E130', 'http://sinalprivado.info:80/series/1533784/1533784/393559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151728, 10824, 'Yu Gi Oh GX S01 E131', 'http://sinalprivado.info:80/series/1533784/1533784/393560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(151729, 10824, 'Yu Gi Oh GX S01 E132', 'http://sinalprivado.info:80/series/1533784/1533784/393561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151730, 10824, 'Yu Gi Oh GX S01 E133', 'http://sinalprivado.info:80/series/1533784/1533784/393562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151731, 10824, 'Yu Gi Oh GX S01 E134', 'http://sinalprivado.info:80/series/1533784/1533784/393563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151732, 10824, 'Yu Gi Oh GX S01 E135', 'http://sinalprivado.info:80/series/1533784/1533784/393564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151733, 10824, 'Yu Gi Oh GX S01 E136', 'http://sinalprivado.info:80/series/1533784/1533784/393565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151734, 10824, 'Yu Gi Oh GX S01 E137', 'http://sinalprivado.info:80/series/1533784/1533784/393566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151735, 10824, 'Yu Gi Oh GX S01 E138', 'http://sinalprivado.info:80/series/1533784/1533784/393567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151736, 10824, 'Yu Gi Oh GX S01 E139', 'http://sinalprivado.info:80/series/1533784/1533784/393568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151737, 10824, 'Yu Gi Oh GX S01 E140', 'http://sinalprivado.info:80/series/1533784/1533784/393569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151738, 10824, 'Yu Gi Oh GX S01 E141', 'http://sinalprivado.info:80/series/1533784/1533784/393570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151739, 10824, 'Yu Gi Oh GX S01 E142', 'http://sinalprivado.info:80/series/1533784/1533784/393571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151740, 10824, 'Yu Gi Oh GX S01 E143', 'http://sinalprivado.info:80/series/1533784/1533784/393572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151741, 10824, 'Yu Gi Oh GX S01 E144', 'http://sinalprivado.info:80/series/1533784/1533784/393573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151742, 10824, 'Yu Gi Oh GX S01 E145', 'http://sinalprivado.info:80/series/1533784/1533784/393574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151743, 10824, 'Yu Gi Oh GX S01 E146', 'http://sinalprivado.info:80/series/1533784/1533784/393575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151744, 10824, 'Yu Gi Oh GX S01 E147', 'http://sinalprivado.info:80/series/1533784/1533784/393576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151745, 10824, 'Yu Gi Oh GX S01 E148', 'http://sinalprivado.info:80/series/1533784/1533784/393577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151746, 10824, 'Yu Gi Oh GX S01 E149', 'http://sinalprivado.info:80/series/1533784/1533784/393578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151747, 10824, 'Yu Gi Oh GX S01 E150', 'http://sinalprivado.info:80/series/1533784/1533784/393579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151748, 10824, 'Yu Gi Oh GX S01 E151', 'http://sinalprivado.info:80/series/1533784/1533784/393580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151749, 10824, 'Yu Gi Oh GX S01 E152', 'http://sinalprivado.info:80/series/1533784/1533784/393581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151750, 10824, 'Yu Gi Oh GX S01 E153', 'http://sinalprivado.info:80/series/1533784/1533784/393582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151751, 10824, 'Yu Gi Oh GX S01 E154', 'http://sinalprivado.info:80/series/1533784/1533784/393583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151752, 10824, 'Yu Gi Oh GX S01 E155', 'http://sinalprivado.info:80/series/1533784/1533784/393584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151753, 10824, 'Yu Gi Oh GX S01 E156', 'http://sinalprivado.info:80/series/1533784/1533784/393585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151754, 10824, 'Yu Gi Oh GX S01 E157', 'http://sinalprivado.info:80/series/1533784/1533784/393586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151755, 10824, 'Yu Gi Oh GX S01 E158', 'http://sinalprivado.info:80/series/1533784/1533784/393587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151756, 10824, 'Yu Gi Oh GX S01 E159', 'http://sinalprivado.info:80/series/1533784/1533784/393588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151757, 10824, 'Yu Gi Oh GX S01 E160', 'http://sinalprivado.info:80/series/1533784/1533784/393589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151758, 10824, 'Yu Gi Oh GX S01 E161', 'http://sinalprivado.info:80/series/1533784/1533784/393590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151759, 10824, 'Yu Gi Oh GX S01 E162', 'http://sinalprivado.info:80/series/1533784/1533784/393591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151760, 10824, 'Yu Gi Oh GX S01 E163', 'http://sinalprivado.info:80/series/1533784/1533784/393592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151761, 10824, 'Yu Gi Oh GX S01 E164', 'http://sinalprivado.info:80/series/1533784/1533784/393593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151762, 10824, 'Yu Gi Oh GX S01 E165', 'http://sinalprivado.info:80/series/1533784/1533784/393594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151763, 10824, 'Yu Gi Oh GX S01 E166', 'http://sinalprivado.info:80/series/1533784/1533784/393595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151764, 10824, 'Yu Gi Oh GX S01 E167', 'http://sinalprivado.info:80/series/1533784/1533784/393596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151765, 10824, 'Yu Gi Oh GX S01 E168', 'http://sinalprivado.info:80/series/1533784/1533784/393597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151766, 10824, 'Yu Gi Oh GX S01 E169', 'http://sinalprivado.info:80/series/1533784/1533784/393598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151767, 10824, 'Yu Gi Oh GX S01 E170', 'http://sinalprivado.info:80/series/1533784/1533784/393599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151768, 10824, 'Yu Gi Oh GX S01 E171', 'http://sinalprivado.info:80/series/1533784/1533784/393600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151769, 10824, 'Yu Gi Oh GX S01 E172', 'http://sinalprivado.info:80/series/1533784/1533784/393601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151770, 10824, 'Yu Gi Oh GX S01 E173', 'http://sinalprivado.info:80/series/1533784/1533784/393602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151771, 10824, 'Yu Gi Oh GX S01 E174', 'http://sinalprivado.info:80/series/1533784/1533784/393603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151772, 10824, 'Yu Gi Oh GX S01 E175', 'http://sinalprivado.info:80/series/1533784/1533784/393604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151773, 10824, 'Yu Gi Oh GX S01 E176', 'http://sinalprivado.info:80/series/1533784/1533784/393605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151774, 10824, 'Yu Gi Oh GX S01 E177', 'http://sinalprivado.info:80/series/1533784/1533784/393606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151775, 10824, 'Yu Gi Oh GX S01 E178', 'http://sinalprivado.info:80/series/1533784/1533784/393607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151776, 10824, 'Yu Gi Oh GX S01 E179', 'http://sinalprivado.info:80/series/1533784/1533784/393608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151777, 10824, 'Yu Gi Oh GX S01 E180', 'http://sinalprivado.info:80/series/1533784/1533784/393609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/veMmM3STfZo0IsexmtDZW9zB1RF.jpg'),
(151778, 10825, 'Power Rangers Super Patrulha Delta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/393610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/870eA45xdZS5hrXTey4cmFJDEiT.jpg'),
(151779, 10825, 'Power Rangers Super Patrulha Delta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/393611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pos46Q8tRCsTjMiUd1IEXruGZZ6.jpg'),
(151780, 10825, 'Power Rangers Super Patrulha Delta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/393612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kKo8IqN7zAXuO70vqIUhZ34wRvC.jpg'),
(151781, 10825, 'Power Rangers Super Patrulha Delta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/393613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vtGEpQ0kazjhrQmUrzyhiC8Ngar.jpg'),
(151782, 10825, 'Power Rangers Super Patrulha Delta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/393614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k1zpSfW9UzP3zZeQAy7KmAZ7kDF.jpg'),
(151783, 10825, 'Power Rangers Super Patrulha Delta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/393615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mes6aVKlTOUyJF9wzMgG3th74bC.jpg'),
(151784, 10825, 'Power Rangers Super Patrulha Delta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/393616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uJZf76MfF3rjnPArCrk7tmFkoZu.jpg'),
(151785, 10825, 'Power Rangers Super Patrulha Delta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/393617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q4tLhwQoYQdUtUIPdUrPmYPHdrV.jpg'),
(151786, 10825, 'Power Rangers Super Patrulha Delta S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/393618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7p9VpdD92NqYTGBwoRdJlqpWyJf.jpg'),
(151787, 10825, 'Power Rangers Super Patrulha Delta S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/393619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pa5W6SrAhsKFhXpQA8pYnMLzZ6n.jpg'),
(151788, 10825, 'Power Rangers Super Patrulha Delta S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/393620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yjs0Lc7qtQOtbOZ4mw1TFS5VQUf.jpg'),
(151789, 10825, 'Power Rangers Super Patrulha Delta S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/393621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1foneG3YfPERCguwRJurxf2qfZ5.jpg'),
(151790, 10825, 'Power Rangers Super Patrulha Delta S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/393622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pqPGv2QBenWxctdEImtclx0ht07.jpg'),
(151791, 10825, 'Power Rangers Super Patrulha Delta S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/393623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jyw2PbE393xqJKF9rUh2viO7m8N.jpg'),
(151792, 10825, 'Power Rangers Super Patrulha Delta S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/393624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1miTzta6SiJeUbNbz5o9KdjAOel.jpg'),
(151793, 10825, 'Power Rangers Super Patrulha Delta S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/393625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rJmwR266bRVno6a3wdg36twgyFw.jpg'),
(151794, 10825, 'Power Rangers Super Patrulha Delta S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/393626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lg6itRi3iRSB4YwJfEd6cocy7L.jpg'),
(151795, 10825, 'Power Rangers Super Patrulha Delta S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/393627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFBjaYPW1Q0PStVnAl1BsoonMID.jpg'),
(151796, 10825, 'Power Rangers Super Patrulha Delta S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/393628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/peX3KEMkRKVpNqE4mU16aqjFvOZ.jpg'),
(151797, 10825, 'Power Rangers Super Patrulha Delta S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/393629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kh9gdCjV1IDUOX68l0fqN37wwEC.jpg'),
(151798, 10825, 'Power Rangers Super Patrulha Delta S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/393630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jx1BBBkx6LthlX9I2YxFxh3n442.jpg'),
(151799, 10825, 'Power Rangers Super Patrulha Delta S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/393631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zl3pJZEVUdVgpuyZQD7KX6d01rv.jpg'),
(151800, 10825, 'Power Rangers Super Patrulha Delta S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/393632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6brzw2H4XSTxBbgxeFkqaPx6av3.jpg'),
(151801, 10825, 'Power Rangers Super Patrulha Delta S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/393633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hGOI8lGQwNqhAQWlntKOrhiix2l.jpg'),
(151802, 10825, 'Power Rangers Super Patrulha Delta S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/393634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oksywj1O7bjfTPnngZ9Drjd1o5e.jpg'),
(151803, 10825, 'Power Rangers Super Patrulha Delta S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/393635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/onFpon96iqd91jnMTLG1MNCBGy.jpg'),
(151804, 10825, 'Power Rangers Super Patrulha Delta S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/393636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zie9Kph98dsAxgrGCTIJbdBxTYh.jpg'),
(151805, 10825, 'Power Rangers Super Patrulha Delta S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/393637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kvcagjeZk6Zw8dTI8tWjofJvMDM.jpg'),
(151806, 10825, 'Power Rangers Super Patrulha Delta S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/393638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wH4cYiUtQTna9m0bzQc7jqFuZrA.jpg'),
(151807, 10825, 'Power Rangers Super Patrulha Delta S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/393639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Ze8OAVXFHmaDIaCOZkm5Hmde5P.jpg'),
(151808, 10825, 'Power Rangers Super Patrulha Delta S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/393640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9tYrdKDAMplpe5eZinRJMoJ4kA1.jpg'),
(151809, 10825, 'Power Rangers Super Patrulha Delta S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/393641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ojfJwKNguEYU1TY348QVGL4nGU.jpg'),
(151810, 10825, 'Power Rangers Super Patrulha Delta S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/393642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nauREnMyvTJASFyE0UR8tPDmvIf.jpg'),
(151811, 10825, 'Power Rangers Super Patrulha Delta S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/393643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udBsggkIfx5czXol427NiPgW1Ts.jpg'),
(151812, 10825, 'Power Rangers Super Patrulha Delta S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/393644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSXTH4yuDapjFwkEYK6IwYc2C0H.jpg'),
(151813, 10825, 'Power Rangers Super Patrulha Delta S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/393645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uLurnu2Q5Q6qlKyH0nXypA7SqY7.jpg'),
(151814, 10825, 'Power Rangers Super Patrulha Delta S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/393646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kaNTTpMLtX2nLYtEiZd76BR7Nna.jpg'),
(151815, 10825, 'Power Rangers Super Patrulha Delta S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/393647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yl18Xpoxoj5NTXhrLegnrznQlbM.jpg'),
(151816, 10826, 'Between Lands S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/398348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rkUjYIlcKSxmYNsTzyUG8JrvsQK.jpg'),
(151817, 10826, 'Between Lands S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/398349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hglPKmSe3MggglqBQHF1WHuADqD.jpg'),
(151818, 10826, 'Between Lands S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/398350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/FN5iUw9sjgeE4BJ2gSNCcHIkQ6.jpg'),
(151819, 10826, 'Between Lands S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/398351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7kNlZBBQREoKPR9hdNSRmuuiVYR.jpg'),
(151820, 10826, 'Between Lands S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/398352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y85hummgaIUsrqJ0EwaLNatrmd8.jpg'),
(151821, 10826, 'Between Lands S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/398353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hRvPLQwRaditZqcEPFhS31GwKYN.jpg'),
(151822, 10826, 'Between Lands S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/398354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/46buhK9DEfH8j35PeTHj7sRlib0.jpg'),
(151823, 10826, 'Between Lands S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/398355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6S5VZW2FAq0Rck6mVSS3i06hYeo.jpg'),
(151824, 10826, 'Between Lands S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/398356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jalUmY2Ou4eAZ3CdCUEcoaC6pWX.jpg'),
(151825, 10826, 'Between Lands S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/398357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kY88EByRKf0sAjpBWqEM8tAtykM.jpg'),
(151826, 10827, 'Go Viva do seu Jeito S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/398318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/svEmRZN5Tg3G36wYpbpqxPDUSUs.jpg'),
(151827, 10827, 'Go Viva do seu Jeito S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/398319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ATWXyeXT1uoKSTd0YyrNXdYuSW.jpg'),
(151828, 10827, 'Go Viva do seu Jeito S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/398320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dF4xKmjk514HAo4yrlgkXoMuFaK.jpg'),
(151829, 10827, 'Go Viva do seu Jeito S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/398321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qv7DzTwIwOAVeUIvyWaNX5ioIuQ.jpg'),
(151830, 10827, 'Go Viva do seu Jeito S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/398322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a5gGFvXP7ARXG5eIVYwZbyQpWRe.jpg'),
(151831, 10827, 'Go Viva do seu Jeito S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/398323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pTaaJRUKHHnPVUFCnvvp2diO1VW.jpg'),
(151832, 10827, 'Go Viva do seu Jeito S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/398324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnzDHjc22c8Z3jAYJZX1fzEkiF1.jpg'),
(151833, 10827, 'Go Viva do seu Jeito S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/398325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vcojDQ92BPtpwGYmwPUkxIElSYl.jpg'),
(151834, 10827, 'Go Viva do seu Jeito S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/398326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ab2kmInoDrSW7oE3wDHfXbOgQSy.jpg'),
(151835, 10827, 'Go Viva do seu Jeito S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/398327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3hIMVxCJtcD9oqCPbkJqRAfVoy9.jpg'),
(151836, 10827, 'Go Viva do seu Jeito S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/398328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/18OCtRTMnRdVk6rKavFxBELt2Zy.jpg'),
(151837, 10827, 'Go Viva do seu Jeito S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/398329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZe4hSo5UnyYhkNRNMWRbLgAe7c.jpg'),
(151838, 10827, 'Go Viva do seu Jeito S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/398330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nxOQtdQUcUlX2oCHdVePSOyzlOc.jpg'),
(151839, 10827, 'Go Viva do seu Jeito S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/398331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a2JaaCm1l61aq4NSYVb46Udw5ao.jpg'),
(151840, 10827, 'Go Viva do seu Jeito S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/398332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/twsXYlOal6SX6VVNVhoBIJiyavn.jpg'),
(151841, 10828, 'Go Viva do seu Jeito S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/398333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1R2qUTVyyUePeOoVrrzfhCPoeRo.jpg'),
(151842, 10828, 'Go Viva do seu Jeito S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/398334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1R2qUTVyyUePeOoVrrzfhCPoeRo.jpg'),
(151843, 10828, 'Go Viva do seu Jeito S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/398335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1R2qUTVyyUePeOoVrrzfhCPoeRo.jpg'),
(151844, 10828, 'Go Viva do seu Jeito S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/398336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1R2qUTVyyUePeOoVrrzfhCPoeRo.jpg'),
(151845, 10828, 'Go Viva do seu Jeito S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/398337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1R2qUTVyyUePeOoVrrzfhCPoeRo.jpg'),
(151846, 10828, 'Go Viva do seu Jeito S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/398338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1R2qUTVyyUePeOoVrrzfhCPoeRo.jpg'),
(151847, 10828, 'Go Viva do seu Jeito S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/398339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1R2qUTVyyUePeOoVrrzfhCPoeRo.jpg'),
(151848, 10828, 'Go Viva do seu Jeito S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/398340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1R2qUTVyyUePeOoVrrzfhCPoeRo.jpg'),
(151849, 10828, 'Go Viva do seu Jeito S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/398341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1R2qUTVyyUePeOoVrrzfhCPoeRo.jpg'),
(151850, 10828, 'Go Viva do seu Jeito S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/398342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1R2qUTVyyUePeOoVrrzfhCPoeRo.jpg'),
(151851, 10828, 'Go Viva do seu Jeito S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/398343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1R2qUTVyyUePeOoVrrzfhCPoeRo.jpg'),
(151852, 10828, 'Go Viva do seu Jeito S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/398344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1R2qUTVyyUePeOoVrrzfhCPoeRo.jpg'),
(151853, 10828, 'Go Viva do seu Jeito S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/398345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1R2qUTVyyUePeOoVrrzfhCPoeRo.jpg'),
(151854, 10828, 'Go Viva do seu Jeito S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/398346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1R2qUTVyyUePeOoVrrzfhCPoeRo.jpg'),
(151855, 10828, 'Go Viva do seu Jeito S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/398347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1R2qUTVyyUePeOoVrrzfhCPoeRo.jpg'),
(151856, 10829, 'Pindorama S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/398313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uXBIs7WL5N4IWelVro6cSgoV5kO.jpg'),
(151857, 10829, 'Pindorama S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/398314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uXBIs7WL5N4IWelVro6cSgoV5kO.jpg'),
(151858, 10829, 'Pindorama S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/398315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uXBIs7WL5N4IWelVro6cSgoV5kO.jpg'),
(151859, 10829, 'Pindorama S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/398316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uXBIs7WL5N4IWelVro6cSgoV5kO.jpg'),
(151860, 10829, 'Pindorama S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/398317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uXBIs7WL5N4IWelVro6cSgoV5kO.jpg'),
(151861, 10830, 'Por Uma Vida Melhor A Jornada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/398310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6m8NOsBXCun7bExkJH9FfgNVtfE.jpg'),
(151862, 10830, 'Por Uma Vida Melhor A Jornada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/398311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9w3kCn1y8qQXNLYgXwRIArfi3Mh.jpg'),
(151863, 10830, 'Por Uma Vida Melhor A Jornada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/398312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g2alDB4l3XfKTcHBS13HJzLm1Oy.jpg'),
(151864, 10831, 'Turbilhao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/398298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/edYzy4Y3P0tFj89rSxk7vQ7Gv43.jpg'),
(151865, 10831, 'Turbilhao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/398299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pyWnp4JKl0myk3M4y920x1Sjoon.jpg'),
(151866, 10831, 'Turbilhao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/398300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lUZcXh2nE3XFA6QecLKcK1rZb8x.jpg'),
(151867, 10831, 'Turbilhao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/398301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o3uCxWtBiR5t2dQXJg5G5wD4O3E.jpg'),
(151868, 10831, 'Turbilhao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/398302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBFgc7ERslQx8ffS8ZmH074TMxt.jpg'),
(151869, 10831, 'Turbilhao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/398303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sIycW0JgEAafUw8KWNR4F7UFRoH.jpg'),
(151870, 10831, 'Turbilhao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/398304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ieLy1G3IAJRW4NQAVdk5A1fGD5.jpg'),
(151871, 10831, 'Turbilhao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/398305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5DsJtbkulP5FfUJpHKSWkEujqk8.jpg'),
(151872, 10831, 'Turbilhao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/398306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a1BO2S0msaHQh5oT6fmICp4UEQL.jpg'),
(151873, 10831, 'Turbilhao S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/398307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mbaarxcHIoBlrxAIB7xERbm5XcB.jpg'),
(151874, 10831, 'Turbilhao S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/398308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zeg1U2pirhMejFUXOZ82d0fpEju.jpg'),
(151875, 10831, 'Turbilhao S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/398309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ldJIjDZcVngklm8Q6cMvvhOYOy2.jpg'),
(151876, 10832, 'Vidas Roubadas A Saga de Isabella S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/398293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g27Ng9SGekFwx3RFNbYMip4PrDR.jpg'),
(151877, 10832, 'Vidas Roubadas A Saga de Isabella S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/398294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g27Ng9SGekFwx3RFNbYMip4PrDR.jpg'),
(151878, 10832, 'Vidas Roubadas A Saga de Isabella S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/398295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g27Ng9SGekFwx3RFNbYMip4PrDR.jpg'),
(151879, 10832, 'Vidas Roubadas A Saga de Isabella S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/398296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g27Ng9SGekFwx3RFNbYMip4PrDR.jpg'),
(151880, 10832, 'Vidas Roubadas A Saga de Isabella S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/398297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g27Ng9SGekFwx3RFNbYMip4PrDR.jpg'),
(151881, 10833, 'WondLa A Trilogia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/398286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pnQzGrh9BuomZvdvECGGSRF0qda.jpg'),
(151882, 10833, 'WondLa A Trilogia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/398287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x7RZOv0yceCiqZ0dRvn7kkKA8N5.jpg'),
(151883, 10833, 'WondLa A Trilogia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/398288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5OrpR2G25YPcWBDVB6qDXj7HJmZ.jpg'),
(151884, 10833, 'WondLa A Trilogia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/398289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r4jQtJIkDf7IbliUJDfvmlteCeq.jpg'),
(151885, 10833, 'WondLa A Trilogia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/398290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lG1HWnUEwU2EjYl1MAtYteR1lHV.jpg'),
(151886, 10833, 'WondLa A Trilogia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/398291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Qm9wL6PsfGb9QPTA4Fo5I5q1OP.jpg'),
(151887, 10833, 'WondLa A Trilogia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/398292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fMOsOrfXPK1D6WLtnuMxePDIOFw.jpg'),
(151888, 10834, 'WondLa A Trilogia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/892152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDqjIQViDvGPFPPWJ6MQ5jSlJSD.jpg'),
(151889, 10834, 'WondLa A Trilogia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/892153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rDM23guGsTUz1DiLpsll04Bpwab.jpg'),
(151890, 10834, 'WondLa A Trilogia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/892154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sMPHKv8f2hAFgh4ycfgSLfDbC2f.jpg'),
(151891, 10834, 'WondLa A Trilogia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/892155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gEiLZeUxAQbcc3bicehpL0l1zMS.jpg'),
(151892, 10834, 'WondLa A Trilogia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/892156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/e8js0LwJA0v7Oxh0wk2e26udAot.jpg'),
(151893, 10834, 'WondLa A Trilogia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/892157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKYVQ9XndVBgexEm8fkvuxmOnz9.jpg'),
(151894, 10834, 'WondLa A Trilogia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/892158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A5TCG8fzKVf4zmft2PBKQa3wI7n.jpg'),
(151895, 10835, 'WondLa A Trilogia S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/894849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Stx4qbWB1beHxuOTuHwPmWlCkC.jpg'),
(151896, 10835, 'WondLa A Trilogia S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/894850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Stx4qbWB1beHxuOTuHwPmWlCkC.jpg'),
(151897, 10835, 'WondLa A Trilogia S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/894851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Stx4qbWB1beHxuOTuHwPmWlCkC.jpg'),
(151898, 10835, 'WondLa A Trilogia S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/894852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Stx4qbWB1beHxuOTuHwPmWlCkC.jpg'),
(151899, 10835, 'WondLa A Trilogia S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/894853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Stx4qbWB1beHxuOTuHwPmWlCkC.jpg'),
(151900, 10835, 'WondLa A Trilogia S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/894854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9Stx4qbWB1beHxuOTuHwPmWlCkC.jpg'),
(151901, 10836, '2002 Uma Historia Marcante S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mTaS10A6Z31xIr8SXrnDo7dpGD3.jpg'),
(151902, 10836, '2002 Uma Historia Marcante S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mTaS10A6Z31xIr8SXrnDo7dpGD3.jpg'),
(151903, 10836, '2002 Uma Historia Marcante S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mTaS10A6Z31xIr8SXrnDo7dpGD3.jpg'),
(151904, 4790, 'Os Smurfs S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399189.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v6ArH4IgtvUrJPduV35DZ6ZE2d0.jpg'),
(151905, 4790, 'Os Smurfs S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399190.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gVgSafFkHfaLGpoR1Tp6gdDxn7q.jpg'),
(151906, 4790, 'Os Smurfs S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399191.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yOIcoWYxK7My5cQ0sKwm5u3U7p5.jpg'),
(151907, 4790, 'Os Smurfs S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/399192.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bxOxWZkqqREMLNo9MEDF0ulHEsk.jpg'),
(151908, 4790, 'Os Smurfs S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399193.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lFL9fjjY5L8bVi5dkvot7z1le6s.jpg'),
(151909, 4790, 'Os Smurfs S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/399194.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/llQMRG3nuF6Mh4K5TAiTWrBbtzP.jpg'),
(151910, 4790, 'Os Smurfs S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/399195.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pmgAXTfZm5kleq9X4wG10P1nqyr.jpg'),
(151911, 4790, 'Os Smurfs S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/399196.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fWxtZf4L01EghTJOWDBWXV3S3I8.jpg'),
(151912, 4790, 'Os Smurfs S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/399197.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/91uOCvjK9yFB50ybbspi8ARworz.jpg'),
(151913, 4790, 'Os Smurfs S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/399198.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d8K2qxIM1SwaI88c4u4aZf4RSVJ.jpg'),
(151914, 4790, 'Os Smurfs S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/399199.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rUobZ2XuXjUrLZ82V49G2B6RuMQ.jpg'),
(151915, 4790, 'Os Smurfs S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/399200.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6EgyPZ5TroopjfDNAcGFvR8JuY2.jpg'),
(151916, 4790, 'Os Smurfs S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/399201.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iTjFErr9aA4FaizE2OqTEBN6vMI.jpg'),
(151917, 4790, 'Os Smurfs S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/399202.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9mVhfIIX54Z4aMt41K8p5mdGZU.jpg'),
(151918, 4790, 'Os Smurfs S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/399203.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dUfIKAgSuWM4xIM32HyOyKt03kV.jpg'),
(151919, 4790, 'Os Smurfs S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/399204.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2bEDOtTW81ueaCcaGxH4gmCTouO.jpg'),
(151920, 4790, 'Os Smurfs S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/399205.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bCUC2894c8J6dKejSMP19yuR7Vm.jpg'),
(151921, 4790, 'Os Smurfs S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/399206.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hYwbBbKpOT9SJuWRF1CH6mgTiqj.jpg'),
(151922, 4790, 'Os Smurfs S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/399207.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7FrDuRdb1i9VUfRnrufXzdDnKRE.jpg'),
(151923, 4790, 'Os Smurfs S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/399208.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/btqLltGaTH2HhezjxA5kmFLZaJ2.jpg'),
(151924, 4790, 'Os Smurfs S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/399209.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4H2HzPbfYsyO1pTweQYeJg4NF7R.jpg'),
(151925, 4790, 'Os Smurfs S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/399210.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wLVRUz0Qh33LVbGijG0QXXaPeoD.jpg'),
(151926, 4790, 'Os Smurfs S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/608899.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fdFroMc0Sj2WqUyUZ90vzHdLJU.jpg'),
(151927, 4790, 'Os Smurfs S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/399212.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Ufq4US3wHHKSpdzLutJOLt4QJi.jpg'),
(151928, 4790, 'Os Smurfs S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/399213.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/njzFneKDc52TOHPyxUuhh3YQtKk.jpg'),
(151929, 4790, 'Os Smurfs S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/399214.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Px45dLN4bi4HX1vhnFUfQqGOp7.jpg'),
(151930, 4790, 'Os Smurfs S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/399215.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bJuVvCoLr6b51UzqLKR46bw1I4u.jpg'),
(151931, 4790, 'Os Smurfs S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/399216.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rmhlXOz71XoWpR1Ir7ZiEcANLg4.jpg'),
(151932, 4790, 'Os Smurfs S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/399217.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jXZk52ccVse6xbtrje10yBj1Fns.jpg'),
(151933, 4790, 'Os Smurfs S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/399218.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJN4OzofT6PreAEbqpx5tbBaEXl.jpg'),
(151934, 4790, 'Os Smurfs S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/399219.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5lqaqoZVoPZqwHzvC5inv7QK7uk.jpg'),
(151935, 4790, 'Os Smurfs S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/399220.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6wiTybk0kkPUNPqRn9hGfDf0aFp.jpg'),
(151936, 4790, 'Os Smurfs S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/399221.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v4VmVg12AfgBrLbk6nO8Z9FOyDu.jpg'),
(151937, 4790, 'Os Smurfs S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/399222.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzBeb6kgpGWT764Me47TrdY4Dn6.jpg'),
(151938, 4790, 'Os Smurfs S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/399223.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8DmK7HABEMHK2MJl3HV3SOaUxNi.jpg'),
(151939, 4790, 'Os Smurfs S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/399224.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s7V31dPioppHoV1N0mWIIkU52HS.jpg'),
(151940, 4790, 'Os Smurfs S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/399225.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qApbBPw8dwBPHXr68EGslLHIDlB.jpg'),
(151941, 4790, 'Os Smurfs S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/399226.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6VorcpLJWjpDjJONErY0GBsUGj.jpg'),
(151942, 4790, 'Os Smurfs S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/399227.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4fCiCwwt0RBqq4t6fOoI4Y7SqiE.jpg'),
(151943, 4790, 'Os Smurfs S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/399228.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vzr4UX2NmZMJ6rBPIxB9PxW340U.jpg'),
(151944, 4790, 'Os Smurfs S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/399229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/830TQfVcgsWS9poZDHxFFeM53dd.jpg'),
(151945, 4790, 'Os Smurfs S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/399230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gijX2f4fEsT5F9LFkOEUpgBwv8p.jpg'),
(151946, 4790, 'Os Smurfs S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/399231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nL7iqRKFJfPBbQUiQFCih8E4Ncg.jpg'),
(151947, 4790, 'Os Smurfs S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/399232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jpZGrUnZUuJ4eZVGgBhpmQNc134.jpg'),
(151948, 4790, 'Os Smurfs S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/399233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/up9QpP1pSthN8tiKowic1UluxQv.jpg'),
(151949, 4790, 'Os Smurfs S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/399234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tNLE2qIJYAH6z3yvqyxu8evUPXc.jpg'),
(151950, 4790, 'Os Smurfs S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/399235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dtadi1eb3npRxw07kXZKmjlF3nq.jpg'),
(151951, 4790, 'Os Smurfs S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/399236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3VmVk6vQhSN9ByIN2kT5Rv5VQgj.jpg'),
(151952, 4790, 'Os Smurfs S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/399237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/laTk52WA26sUhdcSoY36cMC7M9N.jpg'),
(151953, 4790, 'Os Smurfs S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/399238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4JInxH68Qmz4Qt1flmIN1erdlSb.jpg'),
(151954, 4790, 'Os Smurfs S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/399239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rFERMR24OKbzoXnXUtoHCYdxpPm.jpg'),
(151955, 4790, 'Os Smurfs S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/399240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Xzd8cY1G8ncl7pjjmFNMOFtxTO.jpg'),
(151956, 4791, 'Os Smurfs S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399241.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tOTqMiiIRHAeGqrZ6yPyO2v4TYh.jpg'),
(151957, 4791, 'Os Smurfs S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399242.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tj3UM9jnLdNsH6hQLZmY1bxMOXk.jpg'),
(151958, 4791, 'Os Smurfs S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399243.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lcXato5QpAunuWTR3a9ZYPjlrro.jpg'),
(151959, 4791, 'Os Smurfs S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/399244.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iGYX06H7GdFHzInJvrSirnQrefr.jpg'),
(151960, 4791, 'Os Smurfs S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399245.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/teBDFoEP63mSIblIaHId0c50epe.jpg'),
(151961, 4791, 'Os Smurfs S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/399246.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1zN0zzrVdHm0KU1InbeefItB9K4.jpg'),
(151962, 4791, 'Os Smurfs S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/399247.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/en1unpDE09JUbPHzS9Xu7Lf8OLD.jpg'),
(151963, 4791, 'Os Smurfs S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/399248.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kHCaEHsm8arfvnJfisqtpE86jUT.jpg'),
(151964, 4791, 'Os Smurfs S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/399249.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hFj9z0smbQsSDE1IcBiEMxmtfWH.jpg'),
(151965, 4791, 'Os Smurfs S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/399250.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jAdwgj73REWVzXmGnYPm9aYcsJz.jpg'),
(151966, 4791, 'Os Smurfs S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/399251.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zv6UeFcX8wscIogAP7QjG22M7gB.jpg'),
(151967, 4791, 'Os Smurfs S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/399252.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oCTfwEH9tbhJ6PidTco6OJEBUFs.jpg'),
(151968, 4791, 'Os Smurfs S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/399253.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mVt4dtPsVCXMtmPrXtveHzKezeY.jpg'),
(151969, 4791, 'Os Smurfs S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/399254.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xm2APRAjMJiO6klVPYztFMzHdtv.jpg'),
(151970, 4791, 'Os Smurfs S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/399255.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/EAu038D4eQFWaLd6mhyKEprBCk.jpg'),
(151971, 4791, 'Os Smurfs S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/399256.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qpwgLlhQ1OV5Nt7OXh7WaUGZY5D.jpg'),
(151972, 4791, 'Os Smurfs S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/399257.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7KR0fDtMTAaib3dRaK280ZdlytH.jpg'),
(151973, 4791, 'Os Smurfs S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/399258.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jOGWnkNBGOursg0tVsVsGGWVAQ8.jpg'),
(151974, 4791, 'Os Smurfs S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/399259.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMiy3UmrWGkz9sFbBI8cX6ChoVW.jpg'),
(151975, 4791, 'Os Smurfs S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/399260.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tst96LtYvK7CdCwSPzxba9sCRCw.jpg'),
(151976, 4791, 'Os Smurfs S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/399261.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8DqigHoZFYXTK9ahk5gZZYQKbzk.jpg'),
(151977, 4791, 'Os Smurfs S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/399262.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/caa8XZfPPrcEElEYc7CVsw7UgmG.jpg'),
(151978, 4791, 'Os Smurfs S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/399263.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bcO7CpB1SwIvcYxx6TD7Y3fan7X.jpg'),
(151979, 4791, 'Os Smurfs S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/399264.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3QZab3SXwueFIyOXfKfH9u1HdCZ.jpg'),
(151980, 4791, 'Os Smurfs S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/399265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oQQK7oQrLzSo7ANPZTNjsDPOePo.jpg'),
(151981, 4791, 'Os Smurfs S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/399266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qhuqGP0ysmTqhhK25bl1TPxt7Bs.jpg'),
(151982, 4791, 'Os Smurfs S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/399267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dSh8Wkg1wxpsWgP7GIcMOdnZLGO.jpg'),
(151983, 4791, 'Os Smurfs S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/399268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5Gpk9A81xyR1cIdlUs7eIrcVfUa.jpg'),
(151984, 4791, 'Os Smurfs S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/399269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mrpDeWyS2yIqvTIlwoOZX4Z5XIn.jpg'),
(151985, 4791, 'Os Smurfs S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/399270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nfzTqtVDnCvI7KLVPkvYBGDXmDd.jpg'),
(151986, 4791, 'Os Smurfs S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/399271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o4nJ0VqVCer3tynrdGrgon4svIC.jpg'),
(151987, 4791, 'Os Smurfs S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/399272.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pR0LlhURfT5TaZkdpsjxdHqbS1V.jpg'),
(151988, 4791, 'Os Smurfs S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/399273.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZiTC8skWJpyunXbhXEn68X3sZQ.jpg'),
(151989, 4791, 'Os Smurfs S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/399274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/urcwumrTS06ukiitfrkrBBSPPf2.jpg'),
(151990, 4791, 'Os Smurfs S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/399275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ieTTRmveUojs7zE4NH2NnHs49Q.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(151991, 4791, 'Os Smurfs S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/399276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udPR69jiuvWjsp3MxHYY6LJiHep.jpg'),
(151992, 4791, 'Os Smurfs S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/399277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vmocJSzWz0lfcd69O0VvlNdN2A3.jpg'),
(151993, 4791, 'Os Smurfs S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/399278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yG5NVmjIvfPDich6gPOkYOoHrk1.jpg'),
(151994, 4791, 'Os Smurfs S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/399279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dNfAr6xtY9YWfH9zpkGqnFc5Hvm.jpg'),
(151995, 4791, 'Os Smurfs S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/399280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xiQDMb4j1L55mqDnFNuoi1K4kUY.jpg'),
(151996, 4791, 'Os Smurfs S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/399281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/73TykamcLbtNQj5uWIDhI88mFjU.jpg'),
(151997, 4791, 'Os Smurfs S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/399282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tZzaK1QpFy0wJYWMsKwr9ktPEw7.jpg'),
(151998, 4791, 'Os Smurfs S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/399283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yPt6YQoQy7TKqxVuJoOBOSaSKun.jpg'),
(151999, 4791, 'Os Smurfs S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/399284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jqMWMtvz5a3ntljFnDeMEiTdBd1.jpg'),
(152000, 4791, 'Os Smurfs S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/399285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3I8371rhMurYei2zd21mN30djzS.jpg'),
(152001, 4791, 'Os Smurfs S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/399286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nAy3ivdkfod1A6mL2JdMZDfwNeY.jpg'),
(152002, 4791, 'Os Smurfs S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/399287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFWFSXQXkZcFnVn9m9wW43F29xM.jpg'),
(152003, 4791, 'Os Smurfs S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/399288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eKgGZjlkw5EblGxYT9zp5DjoVhB.jpg'),
(152004, 4791, 'Os Smurfs S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/399289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fqgLj8TxCSF3x7QLS5JGX3C52hV.jpg'),
(152005, 4791, 'Os Smurfs S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/399290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5U0VWZQuzeiYVofkoBgxUQXWiga.jpg'),
(152006, 4791, 'Os Smurfs S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/399291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zKblKe7ay0PPaXj1pqYJMXocd8k.jpg'),
(152007, 4791, 'Os Smurfs S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/399292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9gHenJkWVMXfpoXw71kUojK6kR9.jpg'),
(152008, 10837, 'Zoe e Raven S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399179.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tsdbdenJmO7lmhGZA4HHN6O5GKg.jpg'),
(152009, 10837, 'Zoe e Raven S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399180.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b3Orq3mcR1hjDh2npm5ZQdNqiiG.jpg'),
(152010, 10837, 'Zoe e Raven S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399181.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3UgRBEEtDGLFwRgEbqE0VOFGudo.jpg'),
(152011, 10837, 'Zoe e Raven S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/399182.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/382Ns9gq9VUXMqlXBA7aInIo0Iv.jpg'),
(152012, 10837, 'Zoe e Raven S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399183.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4h0vTVoLlBfTIIWXzNVZidIa0Jr.jpg'),
(152013, 10837, 'Zoe e Raven S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/399184.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pAYsfPFBzs6xzVeyZ1V5DvvfeFD.jpg'),
(152014, 10837, 'Zoe e Raven S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/399185.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s0OD4Ld8lIsNScyvmu0Hzd6RVDg.jpg'),
(152015, 10837, 'Zoe e Raven S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/399186.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5x6JaW3p54MQQDOUTy3IJrKw0se.jpg'),
(152016, 10837, 'Zoe e Raven S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/399187.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hflBM6cWHczZBV9Am1fyY3V5eEm.jpg'),
(152017, 10837, 'Zoe e Raven S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/399188.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/94NiGAAl5e6pj29pw8EqZPbzV8k.jpg'),
(152018, 10838, 'SPRINT S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/398400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4Rpzm4w6G7XnJO5aXcWWS8FxX6J.jpg'),
(152019, 10838, 'SPRINT S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/398401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1wbHfPIeJ4jXdc1wQOiwGUzQ20F.jpg'),
(152020, 10838, 'SPRINT S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/398402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pZtmQZNJye6W3GAT5CJOezJMhL3.jpg'),
(152021, 10838, 'SPRINT S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/398403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pM3rUkJjRZPUczZfLNAyOqZOuKm.jpg'),
(152022, 10838, 'SPRINT S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/398404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jrYEn38kIIb6DbZfnWQVjyuYWXu.jpg'),
(152023, 10838, 'SPRINT S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/398405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1I60Z5MKrBoKRyacfaiDTGWYYyD.jpg'),
(152024, 10839, 'O Homem com Mil Filhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lSIsZ1wddzYQLD2ousttho7uiZU.jpg'),
(152025, 10839, 'O Homem com Mil Filhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zxKMxGbOxD6LNydvk5m5UKhbCdd.jpg'),
(152026, 10839, 'O Homem com Mil Filhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/69YOA27xF2KjK81cM2dRJwCzRbL.jpg'),
(152027, 10840, 'A Fabrica de Kota [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ju8lcylvAqKfXUHgbLZNKGqFH2i.jpg'),
(152028, 10840, 'A Fabrica de Kota [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hbMef0M7CwR7RTyaf4ROogSMNrV.jpg'),
(152029, 10840, 'A Fabrica de Kota [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nOZGwVvDhCj3g1un1aO6iErFQif.jpg'),
(152030, 10840, 'A Fabrica de Kota [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/399527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m8pbCvrnDmvT5Qm9kfe4M8BA3RL.jpg'),
(152031, 10840, 'A Fabrica de Kota [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g0BboQL6aNNARflbBVQqvt3yrys.jpg'),
(152032, 10841, 'A Fabrica de Kota [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Ff1wmqkematI62qEOC1KtLvaG9.jpg'),
(152033, 10841, 'A Fabrica de Kota [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rcYIvblpZrQ2AVcgEsbhTe4AFUN.jpg'),
(152034, 10841, 'A Fabrica de Kota [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uEPNYkPod6taNKbO0EIkfmJplpo.jpg'),
(152035, 10841, 'A Fabrica de Kota [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/399532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1KNZrwpVKgBcfCMk1zWYaAPjO8X.jpg'),
(152036, 10841, 'A Fabrica de Kota [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n3YpAEPtGaZTRkr8UNDr6TD4sjI.jpg'),
(152037, 10842, 'A Fabrica de Kota [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ncTXnH4Y1hKbjiZCwEdInoYtLYJ.jpg'),
(152038, 10842, 'A Fabrica de Kota [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fq9YmjfOKzrI3EqHfbk1ESGtizy.jpg'),
(152039, 10842, 'A Fabrica de Kota [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p9Fw35VIRyPnTeNvUn2ho2TAn9J.jpg'),
(152040, 10842, 'A Fabrica de Kota [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/399537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iew3pWjXOrWse2pfPQmIIHvoE5O.jpg'),
(152041, 10842, 'A Fabrica de Kota [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1VjsHwvZ2bAvAzBiBulJAfEr0Xw.jpg'),
(152042, 10843, 'Cult Massacre One Day in Jonestown [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tDXroNaQy754S24TYdbmb2ItHS6.jpg'),
(152043, 10843, 'Cult Massacre One Day in Jonestown [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wbxW2y5wAwLtssNY1y5nFFWDoI9.jpg'),
(152044, 10843, 'Cult Massacre One Day in Jonestown [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7hJ1KtsZPKmgnITmBU4aKwTp7dd.jpg'),
(152045, 10844, 'Dare To Love [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yittELZuPu4u25HXcYPu4rMK0iq.jpg'),
(152046, 10844, 'Dare To Love [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yittELZuPu4u25HXcYPu4rMK0iq.jpg'),
(152047, 10844, 'Dare To Love [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yittELZuPu4u25HXcYPu4rMK0iq.jpg'),
(152048, 10844, 'Dare To Love [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/399508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yittELZuPu4u25HXcYPu4rMK0iq.jpg'),
(152049, 10844, 'Dare To Love [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yittELZuPu4u25HXcYPu4rMK0iq.jpg'),
(152050, 10844, 'Dare To Love [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/399510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yittELZuPu4u25HXcYPu4rMK0iq.jpg'),
(152051, 10844, 'Dare To Love [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/399511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yittELZuPu4u25HXcYPu4rMK0iq.jpg'),
(152052, 10844, 'Dare To Love [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/399512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yittELZuPu4u25HXcYPu4rMK0iq.jpg'),
(152053, 10844, 'Dare To Love [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/399513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yittELZuPu4u25HXcYPu4rMK0iq.jpg'),
(152054, 10844, 'Dare To Love [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/399514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yittELZuPu4u25HXcYPu4rMK0iq.jpg'),
(152055, 10844, 'Dare To Love [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/399515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yittELZuPu4u25HXcYPu4rMK0iq.jpg'),
(152056, 10844, 'Dare To Love [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/399516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yittELZuPu4u25HXcYPu4rMK0iq.jpg'),
(152057, 10844, 'Dare To Love [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/399517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yittELZuPu4u25HXcYPu4rMK0iq.jpg'),
(152058, 10844, 'Dare To Love [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/399518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yittELZuPu4u25HXcYPu4rMK0iq.jpg'),
(152059, 10844, 'Dare To Love [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/399519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yittELZuPu4u25HXcYPu4rMK0iq.jpg'),
(152060, 10844, 'Dare To Love [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/399520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yittELZuPu4u25HXcYPu4rMK0iq.jpg'),
(152061, 10845, 'Do Escandalo a Paixao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p9iw8k2iZTfiABQZX9GP9jLtbnA.jpg'),
(152062, 10845, 'Do Escandalo a Paixao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7EeWNcx6T8vTynRpPJ2FsDsLCnc.jpg'),
(152063, 10845, 'Do Escandalo a Paixao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zFi0jxeqA0QgTyfvAFzAyCpHhhj.jpg'),
(152064, 10845, 'Do Escandalo a Paixao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/399500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lEDsWeSymau5oRUpHmRBo2I2qo0.jpg'),
(152065, 10845, 'Do Escandalo a Paixao [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sgymRJ4gAupnjnCpu8Yqm93HIci.jpg'),
(152066, 10845, 'Do Escandalo a Paixao [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/399502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bwh10yNaqzWLLtrM8Dxe3S98F0s.jpg'),
(152067, 10845, 'Do Escandalo a Paixao [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/399503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2QEhznteQjbD2MZjmgheKWJ1U2F.jpg'),
(152068, 10845, 'Do Escandalo a Paixao [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/399504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ikhoae4tKydR8EKPn26fyRfmQkC.jpg'),
(152069, 10845, 'Do Escandalo a Paixao [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/406394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6K4EG6bTrQiK2COYAuGQFPeUkjz.jpg'),
(152070, 10845, 'Do Escandalo a Paixao [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/406395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6K4EG6bTrQiK2COYAuGQFPeUkjz.jpg'),
(152071, 10845, 'Do Escandalo a Paixao [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/409255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6K4EG6bTrQiK2COYAuGQFPeUkjz.jpg'),
(152072, 10845, 'Do Escandalo a Paixao [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/409256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6K4EG6bTrQiK2COYAuGQFPeUkjz.jpg'),
(152073, 10846, 'How Music Got Free [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8N1ciDdPoXx8Bb7OmhkGyl1F5n9.jpg'),
(152074, 10846, 'How Music Got Free [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A1jxUwciot2cWccw4qXxTHrOBeL.jpg'),
(152075, 10847, 'Meu Colega de Quarto e Um Gumiho [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7RU47iLpPGDqnrZqVfATRzbiRp3.jpg'),
(152076, 10847, 'Meu Colega de Quarto e Um Gumiho [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sBEH5lrYt9I7wtF0WTOkMsPad8D.jpg'),
(152077, 10847, 'Meu Colega de Quarto e Um Gumiho [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tfmZSTmJCViM6IjwbBQka7pNANX.jpg'),
(152078, 10847, 'Meu Colega de Quarto e Um Gumiho [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/399482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/K9NDV4X20uYZqWuSBFdooLfXSy.jpg'),
(152079, 10847, 'Meu Colega de Quarto e Um Gumiho [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gvpuiy76MSad1hCNO9REKELKgcf.jpg'),
(152080, 10847, 'Meu Colega de Quarto e Um Gumiho [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/399484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fsI8MZn3RR9Wvi23aUfPT5UNZ2F.jpg'),
(152081, 10847, 'Meu Colega de Quarto e Um Gumiho [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/399485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4lFiFnyN8NIeQjRlm8NzhUNEafX.jpg'),
(152082, 10847, 'Meu Colega de Quarto e Um Gumiho [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/399486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7VcHrWhAkK4C8t40Ce0UOVTLuUg.jpg'),
(152083, 10847, 'Meu Colega de Quarto e Um Gumiho [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/399487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vbNvC8kORRdsda9RPRJLQwi6VNw.jpg'),
(152084, 10847, 'Meu Colega de Quarto e Um Gumiho [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/399488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oivREZXT0F8qYsRt7ZL9wb84SZ8.jpg'),
(152085, 10847, 'Meu Colega de Quarto e Um Gumiho [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/399489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fznPZhI0N9yMGMdafKEJZisoqIr.jpg'),
(152086, 10847, 'Meu Colega de Quarto e Um Gumiho [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/399490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hIXlPBqMTOy4bJJDvkix1fDy02E.jpg'),
(152087, 10847, 'Meu Colega de Quarto e Um Gumiho [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/399491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9gmqNTIiR7XrITE80r8O5ORe01N.jpg'),
(152088, 10847, 'Meu Colega de Quarto e Um Gumiho [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/399492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/46W5Y5pMT39wIVyMeU2Y5TySpoy.jpg'),
(152089, 10847, 'Meu Colega de Quarto e Um Gumiho [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/399493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bA6Az8u5OlnYXABghn6gABZcGYz.jpg'),
(152090, 10847, 'Meu Colega de Quarto e Um Gumiho [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/399494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rEieqxDqr26sCdIfAvjyAEiGFzm.jpg'),
(152091, 10848, 'Meu Doce Mafioso [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xIive9M0PXqJAnY8mxxsNayaKHN.jpg'),
(152092, 10848, 'Meu Doce Mafioso [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wAy2QwczziahUHTo6wdpCL926sD.jpg'),
(152093, 10848, 'Meu Doce Mafioso [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yIbtVWDumFhGyzEcqDmM87JBUKD.jpg'),
(152094, 10848, 'Meu Doce Mafioso [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/399476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nqKPrh9sNjY1NMqqbnelyb88ykt.jpg'),
(152095, 10848, 'Meu Doce Mafioso [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/waK7de8Jm58vQaTrZo6gMaxHB0r.jpg'),
(152096, 10848, 'Meu Doce Mafioso [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/399478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ony8vHaKPfWZD68yXFWXRp56ajy.jpg'),
(152097, 10848, 'Meu Doce Mafioso [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/402982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmauRokBPCZYKZslyzcKLz4qqke.jpg'),
(152098, 10848, 'Meu Doce Mafioso [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/402983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmauRokBPCZYKZslyzcKLz4qqke.jpg'),
(152099, 10848, 'Meu Doce Mafioso [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/406384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmauRokBPCZYKZslyzcKLz4qqke.jpg'),
(152100, 10848, 'Meu Doce Mafioso [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/408542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmauRokBPCZYKZslyzcKLz4qqke.jpg'),
(152101, 10848, 'Meu Doce Mafioso [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/414695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmauRokBPCZYKZslyzcKLz4qqke.jpg'),
(152102, 10848, 'Meu Doce Mafioso [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/414696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmauRokBPCZYKZslyzcKLz4qqke.jpg'),
(152103, 10848, 'Meu Doce Mafioso [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/414697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmauRokBPCZYKZslyzcKLz4qqke.jpg'),
(152104, 10848, 'Meu Doce Mafioso [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/419481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmauRokBPCZYKZslyzcKLz4qqke.jpg'),
(152105, 10848, 'Meu Doce Mafioso [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/424618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmauRokBPCZYKZslyzcKLz4qqke.jpg'),
(152106, 10848, 'Meu Doce Mafioso [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/424619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rmauRokBPCZYKZslyzcKLz4qqke.jpg'),
(152107, 10849, 'O Jogador 2 Entre Golpistas [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYUFUc0XyGOSWefSZQoUSqBRxpR.jpg'),
(152108, 10849, 'O Jogador 2 Entre Golpistas [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYUFUc0XyGOSWefSZQoUSqBRxpR.jpg'),
(152109, 10849, 'O Jogador 2 Entre Golpistas [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYUFUc0XyGOSWefSZQoUSqBRxpR.jpg'),
(152110, 10849, 'O Jogador 2 Entre Golpistas [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/399466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYUFUc0XyGOSWefSZQoUSqBRxpR.jpg'),
(152111, 10849, 'O Jogador 2 Entre Golpistas [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYUFUc0XyGOSWefSZQoUSqBRxpR.jpg'),
(152112, 10849, 'O Jogador 2 Entre Golpistas [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/399468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYUFUc0XyGOSWefSZQoUSqBRxpR.jpg'),
(152113, 10849, 'O Jogador 2 Entre Golpistas [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/399469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYUFUc0XyGOSWefSZQoUSqBRxpR.jpg'),
(152114, 10849, 'O Jogador 2 Entre Golpistas [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/399470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYUFUc0XyGOSWefSZQoUSqBRxpR.jpg'),
(152115, 10849, 'O Jogador 2 Entre Golpistas [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/399471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYUFUc0XyGOSWefSZQoUSqBRxpR.jpg'),
(152116, 10849, 'O Jogador 2 Entre Golpistas [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/399472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYUFUc0XyGOSWefSZQoUSqBRxpR.jpg'),
(152117, 10849, 'O Jogador 2 Entre Golpistas [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/406374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYUFUc0XyGOSWefSZQoUSqBRxpR.jpg'),
(152118, 10849, 'O Jogador 2 Entre Golpistas [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/406375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oYUFUc0XyGOSWefSZQoUSqBRxpR.jpg'),
(152119, 10850, 'O Jogo da Vitima [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2JfA5r0M03kEX4N9XayMQeCGp9z.jpg'),
(152120, 10850, 'O Jogo da Vitima [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m0bgCFlL3rrcRjPAE80Fyb8kexI.jpg'),
(152121, 10850, 'O Jogo da Vitima [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wlU4GsxPGqqGlpBSulUH4Z8cNGZ.jpg'),
(152122, 10850, 'O Jogo da Vitima [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/399450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yhRHeu7rDvbN3KPUvZ125W5ADuU.jpg'),
(152123, 10850, 'O Jogo da Vitima [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/36qeAvHfnQkdFwQl2hofhMxWLHt.jpg'),
(152124, 10850, 'O Jogo da Vitima [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/399452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s72pizwf2iFMt5r4pOBu8UgLD6n.jpg'),
(152125, 10850, 'O Jogo da Vitima [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/399453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y9eHh8dT8yGPSnMpMnnUARnhnfN.jpg'),
(152126, 10850, 'O Jogo da Vitima [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/399454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k6MmcvMPe94B5gA6KEMDwMnGQ3s.jpg'),
(152127, 10851, 'O Jogo da Vitima [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9qAu7sG2MJkSmf86el02KKbDMwZ.jpg'),
(152128, 10851, 'O Jogo da Vitima [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jCQJNPfOicQ3XsEX9IsJkACxAor.jpg'),
(152129, 10851, 'O Jogo da Vitima [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jyUmReCkYlP1YrOnPnwm6vIypcf.jpg'),
(152130, 10851, 'O Jogo da Vitima [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/399458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/59tbZ6ZaSfOSY7bXi2jRZLp9NeL.jpg'),
(152131, 10851, 'O Jogo da Vitima [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8hNXpFHsw4trMFNHGoxB1l8G7g8.jpg'),
(152132, 10851, 'O Jogo da Vitima [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/399460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4cbu5QsURqMrsqm65GJHbe2DDSz.jpg'),
(152133, 10851, 'O Jogo da Vitima [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/399461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d1vXBsVdla1QI6VsNmgkPwogHeO.jpg'),
(152134, 10851, 'O Jogo da Vitima [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/399462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rZmeP2Zk03rZ55QiimDDWyc21g.jpg'),
(152135, 10852, 'THE NEW GATE [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ULWI934J1h3ixx1Wt5Md6W0gA5.jpg'),
(152136, 10852, 'THE NEW GATE [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yJbRREsyfdQpxsHsZoVkoQHg56f.jpg'),
(152137, 10852, 'THE NEW GATE [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ifEhjZjeclGEzBnQmu9rZWBiAEI.jpg'),
(152138, 10852, 'THE NEW GATE [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/399438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2d5RltufJkN98RnrbZyTFiicINf.jpg'),
(152139, 10852, 'THE NEW GATE [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mg9TQ7oa2UgWXM0Ex8PxDWjwbAp.jpg'),
(152140, 10852, 'THE NEW GATE [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/399440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ryx9ml9Oj8iYmOJwa7HHPzNPT5G.jpg'),
(152141, 10852, 'THE NEW GATE [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/399441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kx04EEaAkcRJytRWAv0OZJR5Yjh.jpg'),
(152142, 10852, 'THE NEW GATE [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/399442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bOSEcYAzKF8gx0QIpdmz0iLn91q.jpg'),
(152143, 10852, 'THE NEW GATE [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/399443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xmfmOdprdCXubelzetX7SiVXDKa.jpg'),
(152144, 10852, 'THE NEW GATE [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/399444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJqMRKTBPZ8eEDEgGD4vcqEQgKD.jpg'),
(152145, 10852, 'THE NEW GATE [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/399445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yKeC8YuPSF8XhHmki7mBqqVuytg.jpg'),
(152146, 10852, 'THE NEW GATE [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/399446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dUV2UQYq9cKEkZepS1zlwm63mQK.jpg'),
(152147, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGqgOMCuYJEcPbHhZDGX2vMiAoG.jpg'),
(152148, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m6aT4dDkd5fI4X2nVb055T5ymJh.jpg'),
(152149, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m18g4vMG7Uda3ROv7FP4KuAMpMx.jpg'),
(152150, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/399414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shsZqSkqo5CWN6ecZstG7dOgYGb.jpg'),
(152151, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rInUnnK8aK0QZH4o7Gn3QSO06iM.jpg'),
(152152, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/399416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i51iCGOyMb4VscpDOvUqbVXntqi.jpg'),
(152153, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/399417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iyF9cEjbvpu20cx0IpPrAXzpay3.jpg'),
(152154, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/399418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/caX5CUxE7sm13wGdR4O5AqpCVej.jpg'),
(152155, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/399419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tLPtYiIli8oppPG8NzFqXbR3NQc.jpg'),
(152156, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/399420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4YB32KAKSAZWgpSvm1HS9btavlS.jpg'),
(152157, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/399421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jRIiZwB8sS44GJ7yzrPMIHtOdrr.jpg'),
(152158, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/399422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7EYZ6HpvqXikCW0411W5lUTCkcj.jpg'),
(152159, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/399423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2MFLaUfAc9fYTAoqfyzEJrNAwgd.jpg'),
(152160, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/399424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qVtA7CPfljwgZ7vkXLwGsP0kxnA.jpg'),
(152161, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/399425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rNfh1PlYDwD5OG8djP1iTPsnCGV.jpg'),
(152162, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/399426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x0cfZ2IhMMMkFloeqyl94GRHW52.jpg'),
(152163, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/399427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p8neA12JFRymMPdvIvj91EeENOx.jpg'),
(152164, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/399428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ZDCMx5ExDQ2xFicc3xd8OUDy4d.jpg'),
(152165, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/399429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jnk5SCzqFJlQBnFY1HDWa1lgac5.jpg'),
(152166, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/399430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ynRw0qgQNcBCy9WcRpsB1CkwTln.jpg'),
(152167, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/399431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nth90D16hQrcRxfkTKER2PFJK4S.jpg'),
(152168, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/399432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nUYRParvVFbEqS2H9B82u9xNcIs.jpg'),
(152169, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/399433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k5NjOPZAQB6VZP2xhpk87miG3vN.jpg'),
(152170, 10853, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/399434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lvHzix2q33QTRoR9Vo9nZYuG0W3.jpg'),
(152171, 10854, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/678260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aJnmS9S3m6BsSnzMNEnF0KPl9PC.jpg'),
(152172, 10854, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/678261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aJnmS9S3m6BsSnzMNEnF0KPl9PC.jpg'),
(152173, 10854, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/678262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aJnmS9S3m6BsSnzMNEnF0KPl9PC.jpg'),
(152174, 10854, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/678263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aJnmS9S3m6BsSnzMNEnF0KPl9PC.jpg'),
(152175, 10854, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/678264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aJnmS9S3m6BsSnzMNEnF0KPl9PC.jpg'),
(152176, 10854, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/678265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aJnmS9S3m6BsSnzMNEnF0KPl9PC.jpg'),
(152177, 10854, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/678266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aJnmS9S3m6BsSnzMNEnF0KPl9PC.jpg'),
(152178, 10854, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/678267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aJnmS9S3m6BsSnzMNEnF0KPl9PC.jpg'),
(152179, 10854, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/678268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aJnmS9S3m6BsSnzMNEnF0KPl9PC.jpg'),
(152180, 10854, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/678269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aJnmS9S3m6BsSnzMNEnF0KPl9PC.jpg'),
(152181, 10854, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/678270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aJnmS9S3m6BsSnzMNEnF0KPl9PC.jpg'),
(152182, 10854, 'The Seven Deadly Sins Os Quatro Cavaleiros do Apocalipse S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/678271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aJnmS9S3m6BsSnzMNEnF0KPl9PC.jpg'),
(152183, 10855, 'Alexa e Katie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ulg6SQnQKvUt1Sy9MLiYOMNcRju.jpg'),
(152184, 10855, 'Alexa e Katie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qp2QDQkrvZglvrmEYBsKhUdI0mv.jpg'),
(152185, 10855, 'Alexa e Katie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/haaq1Nx6WR3YqLt6um3eBENbW2Y.jpg'),
(152186, 10855, 'Alexa e Katie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/399317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8uzRJZmhOofuMrphxrAGvZxXDU3.jpg'),
(152187, 10855, 'Alexa e Katie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y9xg7uBFWmFdGvk6h0kFdkFKiQn.jpg'),
(152188, 10855, 'Alexa e Katie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/399319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/im4vZx1u5OQJyQCiC6ci6NMn2Pv.jpg'),
(152189, 10855, 'Alexa e Katie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/399320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k9ClwcnbN4GegO256TGCAvSlVTP.jpg'),
(152190, 10855, 'Alexa e Katie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/399321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5MSb4aI2HsOY3E37Vpf8D5BIZec.jpg'),
(152191, 10855, 'Alexa e Katie S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/399322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7wcYApFuDpVZRGHjMRaxGKgxMDc.jpg'),
(152192, 10855, 'Alexa e Katie S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/399323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/skBm5ZMSEQ0B1ofjBi3oR5mDIu7.jpg'),
(152193, 10855, 'Alexa e Katie S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/399324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/53Zi5sqRXTVtyaU6R4xQP3N0b2j.jpg'),
(152194, 10855, 'Alexa e Katie S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/399325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aRInJidrf6C7wjlYoIEMC5LqU4A.jpg'),
(152195, 10855, 'Alexa e Katie S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/399326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eOhvjVy4gHPzdszygwQXm27u31m.jpg'),
(152196, 10856, 'Alexa e Katie S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jZoYehsVJ8VMzQF1YeKnwzA9ATB.jpg'),
(152197, 10856, 'Alexa e Katie S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6qXuKmS48RPGCvjYyTyukwN2iKS.jpg'),
(152198, 10856, 'Alexa e Katie S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zlTb5eYrSf0dAUrTYPKA2nIeCT6.jpg'),
(152199, 10856, 'Alexa e Katie S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/399330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/neBIvEaiD6UjqOflSnBSMjq4Ju7.jpg'),
(152200, 10856, 'Alexa e Katie S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wpbhdk0tAlLs9dqRV833Ci9eicV.jpg'),
(152201, 10856, 'Alexa e Katie S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/399332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2c0WQHNGXiZM8jCE4bgwztGvnSF.jpg'),
(152202, 10856, 'Alexa e Katie S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/399333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dKkWE8aKScOAPRNmXTscFxWAf3r.jpg'),
(152203, 10856, 'Alexa e Katie S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/399334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6PxtIhZeIEXcEZMK2rpAJqTLuW3.jpg'),
(152204, 10856, 'Alexa e Katie S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/399335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5V2bJX13UlQYugoioVyxyTZxw7v.jpg'),
(152205, 10856, 'Alexa e Katie S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/399336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j2TrWCsUIEor7YfVOuHZXuOrNR3.jpg'),
(152206, 10857, 'Alexa e Katie S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8fh4xngP085YqW2BPMb4RYWhBSU.jpg'),
(152207, 10857, 'Alexa e Katie S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hCLbXdVrNNg0hIdVrBBdsZFTj6h.jpg'),
(152208, 10857, 'Alexa e Katie S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jsqQt8YHohhC1xANYKahAvNrJXu.jpg'),
(152209, 10857, 'Alexa e Katie S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/399340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xV4ZF4lHzL4EMn5taPHDqoDjthu.jpg'),
(152210, 10857, 'Alexa e Katie S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/anmIOyTLKi6SIKtYhJE9hUMf678.jpg'),
(152211, 10857, 'Alexa e Katie S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/399342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/boXp3N21gw1e1f4qSw9xUsCyTxt.jpg'),
(152212, 10857, 'Alexa e Katie S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/399343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eeUeWEmQlaY6qQj6KGNh89GSrXO.jpg'),
(152213, 10857, 'Alexa e Katie S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/399344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wushaXXT2KladStFOUIc6gtycMg.jpg'),
(152214, 10858, 'Alexa e Katie S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uBdIfu7Riycn2UvjiPu1ndgkRtH.jpg'),
(152215, 10858, 'Alexa e Katie S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tdvBfss31IrjkPHgrZmMZUXhFn4.jpg'),
(152216, 10858, 'Alexa e Katie S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hCoUel86u35sZTfOb9gUMUVJKUs.jpg'),
(152217, 10858, 'Alexa e Katie S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/399348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8LjU8ucFpbkhXEUeXTtvIQvMz3q.jpg'),
(152218, 10858, 'Alexa e Katie S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jLRzPI9xPy4h8EsUst4jwtoSF0f.jpg'),
(152219, 10858, 'Alexa e Katie S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/399350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nGT2vIvOdjzBNmjNXpJQ8TGZD4O.jpg'),
(152220, 10858, 'Alexa e Katie S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/399351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zRRnqCvNzuoxzADKGFXs98N0bKa.jpg'),
(152221, 10858, 'Alexa e Katie S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/399352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hnNrQZY9ZtkL841XKnHdFGYCfIZ.jpg'),
(152222, 10859, 'Pedaco de Mim S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/399297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wOyD73oL6oVrISaYBDp6P72OVS7.jpg'),
(152223, 10859, 'Pedaco de Mim S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/399298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fy23CsW2PScDXanf0246nBDP4Gn.jpg'),
(152224, 10859, 'Pedaco de Mim S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/399299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eC8ZNCuV8dfDMigIaLJZkaIDRsh.jpg'),
(152225, 10859, 'Pedaco de Mim S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/399300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j6hdMlY6LAQurNcLLrmeXULR3fI.jpg'),
(152226, 10859, 'Pedaco de Mim S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/399301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hkE3T51ONQISSbQoslhKQnuu5Z9.jpg'),
(152227, 10859, 'Pedaco de Mim S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/399302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/461yXlw1wx7ZjlMo6SLKsEBTHEj.jpg'),
(152228, 10859, 'Pedaco de Mim S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/399303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5EYQbLKdgRf1i0GTWiRS0bVRhyL.jpg'),
(152229, 10859, 'Pedaco de Mim S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/399304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2TN1EC4xwivKakSfaa2o6pQvNcy.jpg'),
(152230, 10859, 'Pedaco de Mim S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/399305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/im8vdvWYoX9rumEAzS3Q4bulIyj.jpg'),
(152231, 10859, 'Pedaco de Mim S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/399306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/natAwGVkHKZIXvC4GSiGonn6Oak.jpg'),
(152232, 10859, 'Pedaco de Mim S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/399307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lhjEfcDOtZklBCOmPH54WSObdiH.jpg'),
(152233, 10859, 'Pedaco de Mim S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/399308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/meWOMgFTpZZWXsXUCmvhTpWm8Xy.jpg'),
(152234, 10859, 'Pedaco de Mim S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/399309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ufOp0pjbuKEKe7D0uLP32yy182o.jpg'),
(152235, 10859, 'Pedaco de Mim S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/399310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7wI5qsZoNMjLV5iZcgsDYzmsN21.jpg'),
(152236, 10859, 'Pedaco de Mim S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/399311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2GZfGKClYmEUoo17RTTC09s4CPu.jpg'),
(152237, 10859, 'Pedaco de Mim S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/399312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qaqvqTR8DX9Z8eBHzBtsrDQNm70.jpg'),
(152238, 10859, 'Pedaco de Mim S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/399313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6aVZ3Sb5INMq5lkf44RWTHY6P4b.jpg'),
(152239, 10860, 'Por que Diacho Comprei Essa Casa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/401324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cxMwBvQY078cx0XPdheIOqSdmmm.jpg'),
(152240, 10860, 'Por que Diacho Comprei Essa Casa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/401325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cxMwBvQY078cx0XPdheIOqSdmmm.jpg'),
(152241, 10860, 'Por que Diacho Comprei Essa Casa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/401326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cxMwBvQY078cx0XPdheIOqSdmmm.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(152242, 10860, 'Por que Diacho Comprei Essa Casa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/401327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cxMwBvQY078cx0XPdheIOqSdmmm.jpg'),
(152243, 10860, 'Por que Diacho Comprei Essa Casa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/401328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cxMwBvQY078cx0XPdheIOqSdmmm.jpg'),
(152244, 10860, 'Por que Diacho Comprei Essa Casa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/401329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cxMwBvQY078cx0XPdheIOqSdmmm.jpg'),
(152245, 10860, 'Por que Diacho Comprei Essa Casa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/401330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cxMwBvQY078cx0XPdheIOqSdmmm.jpg'),
(152246, 10861, 'Por que Diacho Comprei Essa Casa S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/433152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cxMwBvQY078cx0XPdheIOqSdmmm.jpg'),
(152247, 10861, 'Por que Diacho Comprei Essa Casa S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/433153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cxMwBvQY078cx0XPdheIOqSdmmm.jpg'),
(152248, 10861, 'Por que Diacho Comprei Essa Casa S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/433154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cxMwBvQY078cx0XPdheIOqSdmmm.jpg'),
(152249, 10861, 'Por que Diacho Comprei Essa Casa S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/433155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cxMwBvQY078cx0XPdheIOqSdmmm.jpg'),
(152250, 10861, 'Por que Diacho Comprei Essa Casa S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/433156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cxMwBvQY078cx0XPdheIOqSdmmm.jpg'),
(152251, 10862, 'Um Corpo que Gera S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/608124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gyyb1RwHlgu8IffDN87MR1rKBfY.jpg'),
(152252, 10862, 'Um Corpo que Gera S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/608125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gyyb1RwHlgu8IffDN87MR1rKBfY.jpg'),
(152253, 10862, 'Um Corpo que Gera S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/608126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gyyb1RwHlgu8IffDN87MR1rKBfY.jpg'),
(152254, 10862, 'Um Corpo que Gera S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/608127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gyyb1RwHlgu8IffDN87MR1rKBfY.jpg'),
(152255, 10862, 'Um Corpo que Gera S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/608128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gyyb1RwHlgu8IffDN87MR1rKBfY.jpg'),
(152256, 10862, 'Um Corpo que Gera S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/608129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gyyb1RwHlgu8IffDN87MR1rKBfY.jpg'),
(152257, 10862, 'Um Corpo que Gera S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/608130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gyyb1RwHlgu8IffDN87MR1rKBfY.jpg'),
(152258, 10862, 'Um Corpo que Gera S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/608131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gyyb1RwHlgu8IffDN87MR1rKBfY.jpg'),
(152259, 10863, 'A Emissaria Divina [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3hA9uOMEOt3GmAEWEXkukiLySMD.jpg'),
(152260, 10863, 'A Emissaria Divina [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zsvY1G7kztYsNpAHmEAVZMymTaP.jpg'),
(152261, 10863, 'A Emissaria Divina [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/405725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhfy8oRb0D0crP1EE22nGFKv2Lu.jpg'),
(152262, 10863, 'A Emissaria Divina [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/405726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7mqnMulIBRmMl98idZMFALM96Bk.jpg'),
(152263, 10863, 'A Emissaria Divina [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/405727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rr9e2mGezNgF7rOimtBUQIiNM6.jpg'),
(152264, 10863, 'A Emissaria Divina [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/405728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f3U2UWAHir15GSk5TjuUHNlQoup.jpg'),
(152265, 10863, 'A Emissaria Divina [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/405729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yx33ChzUjk8SHj6bl1t0qZu5Vm9.jpg'),
(152266, 10863, 'A Emissaria Divina [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/405730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k6yQ3vWPSBWvoncOVe6vOal4TBz.jpg'),
(152267, 10863, 'A Emissaria Divina [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/405731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sT5nZUacvylpYDrWSs3axVU0QfA.jpg'),
(152268, 10863, 'A Emissaria Divina [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/405732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bu7lJxU5XsiIjh2Ljvk4brjkMNJ.jpg'),
(152269, 10863, 'A Emissaria Divina [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/405733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qjHK76uGS0r93tgjKnf5wq3sHKx.jpg'),
(152270, 10863, 'A Emissaria Divina [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/405734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ztW6c2VP7yAoaNmuHbiQUAxlwg2.jpg'),
(152271, 10863, 'A Emissaria Divina [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/405735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ryJtRIxKhAANEkaBtY1HhL6XGPr.jpg'),
(152272, 10863, 'A Emissaria Divina [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/405736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vGt04STEgB6LLVckHamwuZuu89J.jpg'),
(152273, 10863, 'A Emissaria Divina [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/405737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1twKkH2FZV4fjZCEz3J7RPhiXMn.jpg'),
(152274, 10863, 'A Emissaria Divina [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/405738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zKsBocP0llqJxISEYrvNU971ePB.jpg'),
(152275, 10863, 'A Emissaria Divina [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/405739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/orKe7ljAepB0vRug4e3qsCi96p4.jpg'),
(152276, 10863, 'A Emissaria Divina [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/405740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u3Y4oo7BERCDahK0s5OTp4DNsb1.jpg'),
(152277, 10863, 'A Emissaria Divina [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/405741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2wiAOrH0npQe5anIL0dujaSLk4s.jpg'),
(152278, 10863, 'A Emissaria Divina [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/405742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/adQNOZ1vWpb2m3HY14FYPipxMkQ.jpg'),
(152279, 10863, 'A Emissaria Divina [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/405743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jSrDO71qTSR71lmd04peDpY7DCZ.jpg'),
(152280, 10863, 'A Emissaria Divina [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/405744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/me11C2SLW9erJp77Y1ETufvrW45.jpg'),
(152281, 10863, 'A Emissaria Divina [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/405745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zW9Fhz8lIycVzMQZJNNcBRiQX1g.jpg'),
(152282, 10863, 'A Emissaria Divina [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/405746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jRMz4T8GN7bxb60xR5k3aRM6ZVl.jpg'),
(152283, 10864, 'A Journey Through Another World Raising Kids While Adventuring S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ffZgzI432pG7V8Jt7VQRGfnbA6p.jpg'),
(152284, 10864, 'A Journey Through Another World Raising Kids While Adventuring S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5fJCl4DA4Ou7nDTjAMJdWxvzx6d.jpg'),
(152285, 10864, 'A Journey Through Another World Raising Kids While Adventuring S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/413067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uAbyIVfe1LQQnLCX0dlAiUx1yP.jpg'),
(152286, 10864, 'A Journey Through Another World Raising Kids While Adventuring S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uAbyIVfe1LQQnLCX0dlAiUx1yP.jpg'),
(152287, 10864, 'A Journey Through Another World Raising Kids While Adventuring S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/417190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uAbyIVfe1LQQnLCX0dlAiUx1yP.jpg'),
(152288, 10864, 'A Journey Through Another World Raising Kids While Adventuring S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/425599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uAbyIVfe1LQQnLCX0dlAiUx1yP.jpg'),
(152289, 10864, 'A Journey Through Another World Raising Kids While Adventuring S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/432783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uAbyIVfe1LQQnLCX0dlAiUx1yP.jpg'),
(152290, 10864, 'A Journey Through Another World Raising Kids While Adventuring S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/435284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uAbyIVfe1LQQnLCX0dlAiUx1yP.jpg'),
(152291, 10864, 'A Journey Through Another World Raising Kids While Adventuring S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/437724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uAbyIVfe1LQQnLCX0dlAiUx1yP.jpg'),
(152292, 10864, 'A Journey Through Another World Raising Kids While Adventuring S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/445089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uAbyIVfe1LQQnLCX0dlAiUx1yP.jpg'),
(152293, 10864, 'A Journey Through Another World Raising Kids While Adventuring S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/448953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1uAbyIVfe1LQQnLCX0dlAiUx1yP.jpg'),
(152294, 10865, 'Cisne Vermelho [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2jk13NamE0gqeqBtQqVfMZcjzkK.jpg'),
(152295, 10865, 'Cisne Vermelho [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/spqzx9B56I1sUCtej6jqE7JaW1Y.jpg'),
(152296, 10865, 'Cisne Vermelho [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/406421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iulA80d5u4oDHzFUrGOzF1kqUhZ.jpg'),
(152297, 10865, 'Cisne Vermelho [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/406422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iulA80d5u4oDHzFUrGOzF1kqUhZ.jpg'),
(152298, 10865, 'Cisne Vermelho [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/415044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iulA80d5u4oDHzFUrGOzF1kqUhZ.jpg'),
(152299, 10865, 'Cisne Vermelho [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/415045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iulA80d5u4oDHzFUrGOzF1kqUhZ.jpg'),
(152300, 10865, 'Cisne Vermelho [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/415046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iulA80d5u4oDHzFUrGOzF1kqUhZ.jpg'),
(152301, 10865, 'Cisne Vermelho [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/415047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iulA80d5u4oDHzFUrGOzF1kqUhZ.jpg'),
(152302, 10865, 'Cisne Vermelho [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/422315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iulA80d5u4oDHzFUrGOzF1kqUhZ.jpg'),
(152303, 10865, 'Cisne Vermelho [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/422316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iulA80d5u4oDHzFUrGOzF1kqUhZ.jpg'),
(152304, 10866, 'Failure Frame I Became the Strongest and Annihilated Everything With Low Level Spells [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gBY5YNRNnbXOscNbHMRBDsI6ME5.jpg'),
(152305, 10866, 'Failure Frame I Became the Strongest and Annihilated Everything With Low Level Spells [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/408982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9kGH4vpzZMSONC8db29Tj7HySr1.jpg'),
(152306, 10866, 'Failure Frame I Became the Strongest and Annihilated Everything With Low Level Spells [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/415019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9kGH4vpzZMSONC8db29Tj7HySr1.jpg'),
(152307, 10866, 'Failure Frame I Became the Strongest and Annihilated Everything With Low Level Spells [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/415020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9kGH4vpzZMSONC8db29Tj7HySr1.jpg'),
(152308, 10866, 'Failure Frame I Became the Strongest and Annihilated Everything With Low Level Spells [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9kGH4vpzZMSONC8db29Tj7HySr1.jpg'),
(152309, 10866, 'Failure Frame I Became the Strongest and Annihilated Everything With Low Level Spells [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/427857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9kGH4vpzZMSONC8db29Tj7HySr1.jpg'),
(152310, 10866, 'Failure Frame I Became the Strongest and Annihilated Everything With Low Level Spells [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/436963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9kGH4vpzZMSONC8db29Tj7HySr1.jpg'),
(152311, 10866, 'Failure Frame I Became the Strongest and Annihilated Everything With Low Level Spells [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/442733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9kGH4vpzZMSONC8db29Tj7HySr1.jpg'),
(152312, 10866, 'Failure Frame I Became the Strongest and Annihilated Everything With Low Level Spells [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/618780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9kGH4vpzZMSONC8db29Tj7HySr1.jpg'),
(152313, 10866, 'Failure Frame I Became the Strongest and Annihilated Everything With Low Level Spells [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/452638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9kGH4vpzZMSONC8db29Tj7HySr1.jpg'),
(152314, 10866, 'Failure Frame I Became the Strongest and Annihilated Everything With Low Level Spells [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/461413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9kGH4vpzZMSONC8db29Tj7HySr1.jpg'),
(152315, 10866, 'Failure Frame I Became the Strongest and Annihilated Everything With Low Level Spells [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/464415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9kGH4vpzZMSONC8db29Tj7HySr1.jpg'),
(152316, 1044, 'Hackers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9jzaQI5b7VhPtpOk4DJ0Ms7uYaw.jpg'),
(152317, 1044, 'Hackers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3LXMZKIxkplADvhuxQpbr4tUg26.jpg'),
(152318, 1044, 'Hackers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/405700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uRNtTKYTy1U08eM2vc6ZX7ovt0O.jpg'),
(152319, 1044, 'Hackers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/405701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jLfvBqvTNKfiYG8lLSci4puhTsw.jpg'),
(152320, 1044, 'Hackers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/405702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dVeNTWnPGgnOp4oLmACf9YfosF1.jpg'),
(152321, 1044, 'Hackers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/405703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dVeNTWnPGgnOp4oLmACf9YfosF1.jpg'),
(152322, 1044, 'Hackers S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/405704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rPTeBVEq6PazxnRV2qhimOkfsIV.jpg'),
(152323, 1044, 'Hackers S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/405705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mTTvedHnyGKdD6nommQG5cZRH73.jpg'),
(152324, 1044, 'Hackers S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/405706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dsttloQEgcILa21FOFKMgCtj5nK.jpg'),
(152325, 1044, 'Hackers S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/405707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lEFwc57EWj3XIvs9wU3dFAKkEBC.jpg'),
(152326, 1045, 'Hackers S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oauATHx7qRCDrRCO0LlvwlwqwAz.jpg'),
(152327, 1045, 'Hackers S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ywkuUppm6Iqb9vexNFGiFJEJZac.jpg'),
(152328, 1045, 'Hackers S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/405710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5kHCztQNsac8NA8u2SMa9N2e1Tr.jpg'),
(152329, 1045, 'Hackers S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/405711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4RsmTPk8HLwp1e6cCLPqwcHcdWA.jpg'),
(152330, 1045, 'Hackers S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/405712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cqml3sQiNGk07Tc6KuOsZ10gFPk.jpg'),
(152331, 1045, 'Hackers S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/405713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/654keBuCgL5hZUSdQav7TORGOrz.jpg'),
(152332, 1045, 'Hackers S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/405714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xnCIOSru3WdH5rC0xdwFacTHbvz.jpg'),
(152333, 1045, 'Hackers S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/405715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uBxh986POADTuvBzxd8niT2miXG.jpg'),
(152334, 1045, 'Hackers S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/405716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9HzQuBvbiKCjlYLZQM3wuWbB53.jpg'),
(152335, 1045, 'Hackers S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/405717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rWzN2TflSrIgL948igpDUwEpTEm.jpg'),
(152336, 10867, 'Inverno Mortal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zr1QvIFOsJCNUTBWrLzzCAb5Pbf.jpg'),
(152337, 10867, 'Inverno Mortal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/daTUam8aPE1jRNOjajAQFGbSH0D.jpg'),
(152338, 10867, 'Inverno Mortal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/405688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1qVrLsXLqbm0KQE577QAUHiBln8.jpg'),
(152339, 10867, 'Inverno Mortal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/405689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y9a2OX1PDK4E2yjzRFotjPTeDuy.jpg'),
(152340, 10867, 'Inverno Mortal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/405690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rebmi6bDzNRmyWa3UlAcLOkG2mh.jpg'),
(152341, 10867, 'Inverno Mortal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/405691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lfbHahrfGSqeUuI6GzNbT0M1cv7.jpg'),
(152342, 10868, 'Inverno Mortal S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lfbHahrfGSqeUuI6GzNbT0M1cv7.jpg'),
(152343, 10868, 'Inverno Mortal S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/82TjkzP47otKAFNoksdjVDTIECp.jpg'),
(152344, 10868, 'Inverno Mortal S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/405694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bn5EfTGIS1nGPqKIW6JZmNNOea5.jpg'),
(152345, 10868, 'Inverno Mortal S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/405695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/skvs973JP1kTC5AgXZCTa8ldQcF.jpg'),
(152346, 10868, 'Inverno Mortal S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/405696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lfbHahrfGSqeUuI6GzNbT0M1cv7.jpg'),
(152347, 10868, 'Inverno Mortal S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/405697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/scVUeKB7eqmGKvjdIBTTpi9brh9.jpg'),
(152348, 10869, 'Keith e Evan Reformando com o Coracao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152349, 10869, 'Keith e Evan Reformando com o Coracao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152350, 10869, 'Keith e Evan Reformando com o Coracao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/405665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152351, 10869, 'Keith e Evan Reformando com o Coracao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/405666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152352, 10869, 'Keith e Evan Reformando com o Coracao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/405667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152353, 10869, 'Keith e Evan Reformando com o Coracao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/405668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152354, 10869, 'Keith e Evan Reformando com o Coracao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/405669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152355, 10869, 'Keith e Evan Reformando com o Coracao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/405670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152356, 10869, 'Keith e Evan Reformando com o Coracao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/405671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152357, 10870, 'Keith e Evan Reformando com o Coracao S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152358, 10870, 'Keith e Evan Reformando com o Coracao S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152359, 10870, 'Keith e Evan Reformando com o Coracao S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/405674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152360, 10870, 'Keith e Evan Reformando com o Coracao S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/405675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152361, 10870, 'Keith e Evan Reformando com o Coracao S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/405676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152362, 10870, 'Keith e Evan Reformando com o Coracao S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/405677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152363, 10870, 'Keith e Evan Reformando com o Coracao S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/405678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152364, 10870, 'Keith e Evan Reformando com o Coracao S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/405679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152365, 10870, 'Keith e Evan Reformando com o Coracao S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/405680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152366, 10871, 'Keith e Evan Reformando com o Coracao S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152367, 10871, 'Keith e Evan Reformando com o Coracao S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152368, 10871, 'Keith e Evan Reformando com o Coracao S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/405683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152369, 10871, 'Keith e Evan Reformando com o Coracao S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/405684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152370, 10871, 'Keith e Evan Reformando com o Coracao S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/405685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nbhGvADDjZ5Wmv025XLchJ0B694.jpg'),
(152371, 10872, 'Land of Tanabata [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xxa96OjURpixB4taQGTEVt1MBf5.jpg'),
(152372, 10872, 'Land of Tanabata [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/71oCsHyBqoGyaK1g4PV1l5Rhq0i.jpg'),
(152373, 10872, 'Land of Tanabata [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/405662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9hnklrAwckh29JpZcXMEKLnqKl8.jpg'),
(152374, 10872, 'Land of Tanabata [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/408546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kHU9S4Bx77w02H2jjrma9YVqo5b.jpg'),
(152375, 10872, 'Land of Tanabata [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/408547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kHU9S4Bx77w02H2jjrma9YVqo5b.jpg'),
(152376, 10872, 'Land of Tanabata [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/415688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kHU9S4Bx77w02H2jjrma9YVqo5b.jpg'),
(152377, 10872, 'Land of Tanabata [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/415689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kHU9S4Bx77w02H2jjrma9YVqo5b.jpg'),
(152378, 10872, 'Land of Tanabata [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/419489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kHU9S4Bx77w02H2jjrma9YVqo5b.jpg'),
(152379, 10872, 'Land of Tanabata [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/424694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kHU9S4Bx77w02H2jjrma9YVqo5b.jpg'),
(152380, 10873, 'Rebus [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hHglWoy5pRhbowwTX3ioc5NT0k8.jpg'),
(152381, 10873, 'Rebus [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/406182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5zOMfiVSgJieF5hA2Tqh2i0Kzil.jpg'),
(152382, 10873, 'Rebus [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/407168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5zOMfiVSgJieF5hA2Tqh2i0Kzil.jpg'),
(152383, 10873, 'Rebus [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/454025.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hVho01pIdFRZOs3dlepoNWjYVOA.jpg'),
(152384, 10873, 'Rebus [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/454026.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2HvmwPs9dvKdEZY2xZFvQmSAYj7.jpg'),
(152385, 10873, 'Rebus [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/454027.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gMl7LIFLGS4XqFOSKcIZHu2HUb.jpg'),
(152386, 10874, 'Receiver S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bI6yzh7CXSKzSmiIf8jI016HrMO.jpg'),
(152387, 10874, 'Receiver S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bI6yzh7CXSKzSmiIf8jI016HrMO.jpg'),
(152388, 10874, 'Receiver S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/405653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bI6yzh7CXSKzSmiIf8jI016HrMO.jpg'),
(152389, 10874, 'Receiver S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/405654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bI6yzh7CXSKzSmiIf8jI016HrMO.jpg'),
(152390, 10874, 'Receiver S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/405655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bI6yzh7CXSKzSmiIf8jI016HrMO.jpg'),
(152391, 10874, 'Receiver S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/405656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bI6yzh7CXSKzSmiIf8jI016HrMO.jpg'),
(152392, 10874, 'Receiver S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/405657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bI6yzh7CXSKzSmiIf8jI016HrMO.jpg'),
(152393, 10874, 'Receiver S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/405658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bI6yzh7CXSKzSmiIf8jI016HrMO.jpg'),
(152394, 10875, 'Sunny S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/heZViRSkoEk6aWqzl90ILXVLjID.jpg'),
(152395, 10875, 'Sunny S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JwA88CVp8qMOYKBiihrBYdClwI.jpg'),
(152396, 10875, 'Sunny S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/411324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oditMN1mmmil8YjN9yzZzn8GU43.jpg'),
(152397, 10875, 'Sunny S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/414341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oditMN1mmmil8YjN9yzZzn8GU43.jpg'),
(152398, 10875, 'Sunny S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/420604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oditMN1mmmil8YjN9yzZzn8GU43.jpg'),
(152399, 10875, 'Sunny S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/426378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oditMN1mmmil8YjN9yzZzn8GU43.jpg'),
(152400, 10875, 'Sunny S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/428620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oditMN1mmmil8YjN9yzZzn8GU43.jpg'),
(152401, 10875, 'Sunny S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/438655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oditMN1mmmil8YjN9yzZzn8GU43.jpg'),
(152402, 10875, 'Sunny S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/440784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oditMN1mmmil8YjN9yzZzn8GU43.jpg'),
(152403, 10875, 'Sunny S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/449956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oditMN1mmmil8YjN9yzZzn8GU43.jpg'),
(152404, 10876, 'The Mindy Project S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/607899.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3vlygQhN20yTvS79oogAoYfelfx.jpg'),
(152405, 10876, 'The Mindy Project S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/607900.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3xFFw9myiL2qkJDfpx7epjlDdTw.jpg'),
(152406, 10876, 'The Mindy Project S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/607901.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qOYIOM2SuGk0UpFrE3J78t4x2yg.jpg'),
(152407, 10876, 'The Mindy Project S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/607902.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ox2Mo3ruyxfl0dFzDZi9o8bNNNo.jpg'),
(152408, 10876, 'The Mindy Project S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/607903.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jYvpnjpigG4b8zHNOhG4lvX2Aci.jpg'),
(152409, 10876, 'The Mindy Project S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/607904.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ebCBCalThOOOPvvxIZPamKfGWdn.jpg'),
(152410, 10876, 'The Mindy Project S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/607905.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r1VG6HYSwd7y8jnt7MlnKodjoKo.jpg'),
(152411, 10876, 'The Mindy Project S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/607906.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eCK3FORluwg56wcz1nuq4guHmk6.jpg'),
(152412, 10876, 'The Mindy Project S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/607907.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pwCn8S2V3DnLwEa60GS8Pj7zX2T.jpg'),
(152413, 10876, 'The Mindy Project S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/607908.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/todXNHELJXZGoL46TG8vSGS7mSu.jpg'),
(152414, 10876, 'The Mindy Project S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/607909.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aJXNXNXVm1tnUxmGGvzNe5w8BSu.jpg'),
(152415, 10876, 'The Mindy Project S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/607910.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A6ChvSzU3BMGWuORhyEnI432aOU.jpg'),
(152416, 10876, 'The Mindy Project S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/607911.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e4ocYjNar061EGEclvHPhYabudT.jpg'),
(152417, 10876, 'The Mindy Project S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/607912.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m53UcmLNLMGjwpWEVWSdbvHb5hi.jpg'),
(152418, 10876, 'The Mindy Project S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/607913.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/efvZ4Z5qpwsR6wUmxia3H69pZA3.jpg'),
(152419, 10876, 'The Mindy Project S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/607914.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1Ko258WxqTSTPC4c7B5ztZCWxCy.jpg'),
(152420, 10876, 'The Mindy Project S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/607915.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8JS9gop1VDvPn1a13iAz0udb2wu.jpg'),
(152421, 10876, 'The Mindy Project S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/607916.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/umgpsDCDHtSKpVh0WGvV0IEx2fw.jpg'),
(152422, 10876, 'The Mindy Project S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/607917.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kwoJ3pXufqwjjHlc5OheYYSmniY.jpg'),
(152423, 10876, 'The Mindy Project S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/607918.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oTpNpr49N5qNAkq56MUuh0OYctW.jpg'),
(152424, 10876, 'The Mindy Project S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/607919.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vQ0JrYwjz8LCE4rQaTgluajpIxj.jpg'),
(152425, 10876, 'The Mindy Project S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/405553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9CnbnveSuZ61zkoyjoPE4tuaCi.jpg'),
(152426, 10876, 'The Mindy Project S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/405554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ko2TVsqqpmGswEptK3qAtkvKgz9.jpg'),
(152427, 10876, 'The Mindy Project S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/405555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sPXYbUZuZFqsaLyFpMu4xZPCvlC.jpg'),
(152428, 10877, 'The Mindy Project S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8cChQt7Jlwi46rVHxzUhBox4rgh.jpg'),
(152429, 10877, 'The Mindy Project S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m6kfj9CaM3NyiAmeiI8dz4gX45Q.jpg'),
(152430, 10877, 'The Mindy Project S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/405558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b1mwt9T1tPMkYX5xCwSNvsYdVIL.jpg'),
(152431, 10877, 'The Mindy Project S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/405559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gLu1XGuNgD1W2poMkp1aHI5o5om.jpg'),
(152432, 10877, 'The Mindy Project S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/405560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iEN0Frn3fSxnFyIPglMpwCVyu3Y.jpg'),
(152433, 10877, 'The Mindy Project S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/405561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lDBWO01s8IozFtVDL4eEhtGjB34.jpg'),
(152434, 10877, 'The Mindy Project S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/405562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oGd5tRjvtJHXiIwEH6RFf8hUW2.jpg'),
(152435, 10877, 'The Mindy Project S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/607930.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dpJWJVwZaBa4ajimLBo5P9tizdH.jpg'),
(152436, 10877, 'The Mindy Project S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/405564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A8wnbg7BiwOwgQ2ra8yxcKSofm4.jpg'),
(152437, 10877, 'The Mindy Project S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/405565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tO2jJIDpvelZzi6xLMuaXwAoUAp.jpg'),
(152438, 10877, 'The Mindy Project S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/405566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nXeo4foBHIiwsWE4R2eTEVbgqhk.jpg'),
(152439, 10877, 'The Mindy Project S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/405567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3gqlB3Cc2MybBKTEj39XlV1D0Sl.jpg'),
(152440, 10877, 'The Mindy Project S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/405568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eghHCMkMk5jPWoxQ9c3i2YEAqEz.jpg'),
(152441, 10877, 'The Mindy Project S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/405569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hjvF3GF6f647bdQOY7MFLFOmkwW.jpg'),
(152442, 10877, 'The Mindy Project S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/405570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b64hcqY4OwX3GzPoFFEj0OzdwBb.jpg'),
(152443, 10877, 'The Mindy Project S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/405571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8A428Hkbg19gPlOw9m2yYHg8xdP.jpg'),
(152444, 10877, 'The Mindy Project S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/405572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wlkaL6Zqti60DUA5q83ESJXjiRe.jpg'),
(152445, 10877, 'The Mindy Project S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/405573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4vspHdHz8W36JBakLDZ5BW9JoF2.jpg'),
(152446, 10877, 'The Mindy Project S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/405574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bQBu4c6bqnc3nSdtHqNofrpi4k1.jpg'),
(152447, 10877, 'The Mindy Project S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/405575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7sIkjE4oly8RMpL2HtoEjEMKuK.jpg'),
(152448, 10877, 'The Mindy Project S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/405576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/NV98O6n6gtoCMUlbM8wWyieL7J.jpg'),
(152449, 10877, 'The Mindy Project S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/405577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Dhr7A0qwIDF5j4nvUhonkYVsCQ.jpg'),
(152450, 10878, 'The Mindy Project S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rfckEVychiUWyOtlcV3cuske8PD.jpg'),
(152451, 10878, 'The Mindy Project S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JKOTYBJLu0nLJj5OpAIcw2630p.jpg'),
(152452, 10878, 'The Mindy Project S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/405580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1uaregPYgsEIz98OyPAQyw7avT2.jpg'),
(152453, 10878, 'The Mindy Project S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/405581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xh0UYbQlX4kBjbs6EMrRaKgLCvq.jpg'),
(152454, 10878, 'The Mindy Project S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/405582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kV19C3mQkaDSGmBM8QLu2bcSWy0.jpg'),
(152455, 10878, 'The Mindy Project S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/405583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kBRjLagUeXAQqXHwe1pNWOpsP7e.jpg'),
(152456, 10878, 'The Mindy Project S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/405584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zYThXMml5jgDih3vcdSJ8sB7bit.jpg'),
(152457, 10878, 'The Mindy Project S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/405585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a3mDJUuYd9ko9sk7fRfZeWXoBMI.jpg'),
(152458, 10878, 'The Mindy Project S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/405586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iZXv56p4W5OmNNwPEEG05B4v9TH.jpg'),
(152459, 10878, 'The Mindy Project S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/405587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mBf1ppw0VfKvywyPAaKykVsePw8.jpg'),
(152460, 10878, 'The Mindy Project S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/405588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LWLIWiJBcU5cd4yXjZAuSkyYLX.jpg'),
(152461, 10878, 'The Mindy Project S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/405589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wYrToKBGF9Evw6udaj1jFg7TRl.jpg'),
(152462, 10878, 'The Mindy Project S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/405590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xqgdaTbCmbbuEW1tmSryh3Q5eC6.jpg'),
(152463, 10878, 'The Mindy Project S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/405591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/km2v0QSA3uGKEVXxn6GllEjeHZ7.jpg'),
(152464, 10878, 'The Mindy Project S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/405592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tHCDLIWCbaGfEDUAiPzxNUZ9ur1.jpg'),
(152465, 10878, 'The Mindy Project S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/405593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yRMSnVSVHPiVvKC5POP6XkezNJ0.jpg'),
(152466, 10878, 'The Mindy Project S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/405594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vwZomquNp9SNuyOwkA3wcJuMh6I.jpg'),
(152467, 10878, 'The Mindy Project S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/405595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Cb0Wh7f5EbTLPy6CAgXkmU5GAI.jpg'),
(152468, 10878, 'The Mindy Project S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/405596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A3AcQv308rQkDw3VTJaBA4NiRhz.jpg'),
(152469, 10878, 'The Mindy Project S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/405597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q9otSUYNihPniWHTRnJm8VOcMYN.jpg'),
(152470, 10878, 'The Mindy Project S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/405598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vaCG5TORJEv1K0dETLgMLq1WE1Q.jpg'),
(152471, 10879, 'The Mindy Project S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405599.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AawFLO2FxDKdJDn9yviQh57NE17.jpg'),
(152472, 10879, 'The Mindy Project S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405600.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4iLnrI1ZvLepMBbSUYMk6vLiey5.jpg'),
(152473, 10879, 'The Mindy Project S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/405601.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w8nrOe81O7E8AUqQFqdywh0aH5N.jpg'),
(152474, 10879, 'The Mindy Project S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/405602.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/973mjutvlPZnCuRV4YY3MvhoFFY.jpg'),
(152475, 10879, 'The Mindy Project S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/405603.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xEPTGiMNbBN3EacJ32ASROfAEsO.jpg'),
(152476, 10879, 'The Mindy Project S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/405604.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hXY7drYlUsdEv0HNNxkxASQUxNt.jpg'),
(152477, 10879, 'The Mindy Project S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/405605.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fQMbluCJpvHegrwglWD90HF2VmW.jpg'),
(152478, 10879, 'The Mindy Project S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/405606.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/41E3OKUHgyLurU0Pk4nU6lAx9Ut.jpg'),
(152479, 10879, 'The Mindy Project S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/405607.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nzYmFmM79g0rnH20Un4dZmbwOmI.jpg'),
(152480, 10879, 'The Mindy Project S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/405608.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vk5ibuwn0GLbRFvagIW0Dsz6Zzn.jpg'),
(152481, 10879, 'The Mindy Project S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/405609.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sNpn3mdgESIU9itLeoBq5XImMZ.jpg'),
(152482, 10879, 'The Mindy Project S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/405610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cgwcddqIU4dqGG0tMYYH2mg3sCm.jpg'),
(152483, 10879, 'The Mindy Project S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/405611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iPxMUFythxX7j40gHia6571tuQL.jpg'),
(152484, 10879, 'The Mindy Project S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/405612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qbtmLnBpjYPyoZOxeHzqmigI60d.jpg'),
(152485, 10879, 'The Mindy Project S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/405613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c33dzpk0kPX6yEmS9KIFN5tTKHM.jpg'),
(152486, 10879, 'The Mindy Project S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/405614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mdNZIuvau8BQz1TO7TmB6t3GeXS.jpg'),
(152487, 10879, 'The Mindy Project S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/405615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2YF0y0ImmBjYWOoktHGGVtdMNCF.jpg'),
(152488, 10879, 'The Mindy Project S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/405616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mSZKmVK9mSbo8d1Ja63m3Alf3TB.jpg'),
(152489, 10879, 'The Mindy Project S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/405617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lO8F6RD71qHafNi4W4Le8ovktCz.jpg'),
(152490, 10879, 'The Mindy Project S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/405618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ywOOW3HtkmJTQh3ADEM4XSv5Fnx.jpg'),
(152491, 10879, 'The Mindy Project S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/405619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pFHgexLGAZla4CtWPD04FCAuyjM.jpg'),
(152492, 10879, 'The Mindy Project S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/405620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eCEeEnjts4VdI39F11YNjElKWdP.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(152493, 10879, 'The Mindy Project S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/405621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AaSunBW9mzsAzgjTKRS1fWoqXGs.jpg'),
(152494, 10879, 'The Mindy Project S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/405622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pmNfCBL8doxX09STBTfA6SmBgEU.jpg'),
(152495, 10879, 'The Mindy Project S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/405623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8mHbTB2Zn91OLKwmzlaAnDaTvai.jpg'),
(152496, 10879, 'The Mindy Project S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/405624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wVZBfBkQOWztaZU9kXteeM7Oh63.jpg'),
(152497, 10880, 'The Mindy Project S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ucDwhmKcoMyGDxhh7IEKqufOtGD.jpg'),
(152498, 10880, 'The Mindy Project S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sS42vZRO8sIrm5JDef3ZMcj5wJC.jpg'),
(152499, 10880, 'The Mindy Project S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/405627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtRghZfWke1LUcujWSwASDCDnCl.jpg'),
(152500, 10880, 'The Mindy Project S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/405628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fxkwjdm3zGlcYhcWqs3XUMFpsm9.jpg'),
(152501, 10880, 'The Mindy Project S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/405629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qrJ6t8GPNaSbv3iZkVUcpzh2sZy.jpg'),
(152502, 10880, 'The Mindy Project S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/405630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/76IKgwAGUwHrmEH65SCdF5yPAGw.jpg'),
(152503, 10880, 'The Mindy Project S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/405631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dgT0oLC4XGqX1WIV2hwBZnBu2Kl.jpg'),
(152504, 10880, 'The Mindy Project S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/405632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yxrqte4zbn8U4aA2IePtj5jSCC0.jpg'),
(152505, 10880, 'The Mindy Project S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/405633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wBqPBxDIdqN8fLFzWgjgtzBaA3t.jpg'),
(152506, 10880, 'The Mindy Project S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/405634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n8TA1JjEMU9zTqUl3BxgA8LjJ45.jpg'),
(152507, 10880, 'The Mindy Project S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/405635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tAqqozmopEr3P1VccXJA6arWtfS.jpg'),
(152508, 10880, 'The Mindy Project S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/405636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jQ4NPWm2Yo843MneJXLc9E8seb.jpg'),
(152509, 10880, 'The Mindy Project S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/405637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tWhQEYILm61dyweUV53ZlYId8aD.jpg'),
(152510, 10880, 'The Mindy Project S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/405638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qmYNt03WDUtuVV8PnwDKFyROdjT.jpg'),
(152511, 10881, 'The Mindy Project S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/405639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/72YNDZOHgnhHuceNdLsGKKYeenD.jpg'),
(152512, 10881, 'The Mindy Project S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/405640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/NJZoY6UlJkJBRgIkWs3GD5GLsN.jpg'),
(152513, 10881, 'The Mindy Project S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/405641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7yyb1JsJ7EEXVAQqTeFkQZdfUkz.jpg'),
(152514, 10881, 'The Mindy Project S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/405642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/av21Bt9eYzie1umgmS0puOGSBTZ.jpg'),
(152515, 10881, 'The Mindy Project S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/405643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b6wF4jCoGSyVllmKfF91VPIMWDB.jpg'),
(152516, 10881, 'The Mindy Project S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/405644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hzICs4PcsanDhJDHnyiiVr3cvyz.jpg'),
(152517, 10881, 'The Mindy Project S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/405645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/88vXXoZDaI97qg6OWtzRK6WsjrU.jpg'),
(152518, 10881, 'The Mindy Project S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/405646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o03g4w47n0ildGnI4lQ8qyC7Kf3.jpg'),
(152519, 10881, 'The Mindy Project S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/405647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xzwcmnIa9iLTpcdzEjkQBFKotkF.jpg'),
(152520, 10881, 'The Mindy Project S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/405648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/swtnfBI88RJvSNbcIlLrcYNOZZo.jpg'),
(152521, 10882, 'VTuber Legend How I Went Viral after Forgetting to Turn Off My Stream [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/407053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4s97rYWqJAsAOeDn8Is09fkLcsc.jpg'),
(152522, 10882, 'VTuber Legend How I Went Viral after Forgetting to Turn Off My Stream [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/415508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4s97rYWqJAsAOeDn8Is09fkLcsc.jpg'),
(152523, 10882, 'VTuber Legend How I Went Viral after Forgetting to Turn Off My Stream [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4s97rYWqJAsAOeDn8Is09fkLcsc.jpg'),
(152524, 10882, 'VTuber Legend How I Went Viral after Forgetting to Turn Off My Stream [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/422916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4s97rYWqJAsAOeDn8Is09fkLcsc.jpg'),
(152525, 10882, 'VTuber Legend How I Went Viral after Forgetting to Turn Off My Stream [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/430785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4s97rYWqJAsAOeDn8Is09fkLcsc.jpg'),
(152526, 10882, 'VTuber Legend How I Went Viral after Forgetting to Turn Off My Stream [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/432886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4s97rYWqJAsAOeDn8Is09fkLcsc.jpg'),
(152527, 10882, 'VTuber Legend How I Went Viral after Forgetting to Turn Off My Stream [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/438500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4s97rYWqJAsAOeDn8Is09fkLcsc.jpg'),
(152528, 10882, 'VTuber Legend How I Went Viral after Forgetting to Turn Off My Stream [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4s97rYWqJAsAOeDn8Is09fkLcsc.jpg'),
(152529, 10882, 'VTuber Legend How I Went Viral after Forgetting to Turn Off My Stream [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4s97rYWqJAsAOeDn8Is09fkLcsc.jpg'),
(152530, 10882, 'VTuber Legend How I Went Viral after Forgetting to Turn Off My Stream [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/454084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4s97rYWqJAsAOeDn8Is09fkLcsc.jpg'),
(152531, 10882, 'VTuber Legend How I Went Viral after Forgetting to Turn Off My Stream [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/463392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4s97rYWqJAsAOeDn8Is09fkLcsc.jpg'),
(152532, 10883, 'A Festa da Salsicha Comilandia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/406618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lj1ScrW1UFOk6zhLQHgv5VVmibH.jpg'),
(152533, 10883, 'A Festa da Salsicha Comilandia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/406619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8L78jJFKHrPfwl75U22zP5muC4K.jpg'),
(152534, 10883, 'A Festa da Salsicha Comilandia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/406620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13SnmweFElCA0i9HzDLXM7OT1wB.jpg'),
(152535, 10883, 'A Festa da Salsicha Comilandia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/406621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u3sfwkcEEGnsw2YfporQijlJjLx.jpg'),
(152536, 10883, 'A Festa da Salsicha Comilandia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/406622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mPfoJnrRBmgGEKoYrAJQRR3Knmx.jpg'),
(152537, 10883, 'A Festa da Salsicha Comilandia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/406623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h6ehZ9J8TglfotajrOF8IOZWuIn.jpg'),
(152538, 10883, 'A Festa da Salsicha Comilandia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/406624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aREritbMoOjWBK8JH0SPtTNwfF3.jpg'),
(152539, 10883, 'A Festa da Salsicha Comilandia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/406625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/asywjC6DU6iHValCoukI9U10YhW.jpg'),
(152540, 10884, 'A Festa da Salsicha Comilandia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/880613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6kSblgQfbqDSo5gRIQ4vp706KTe.jpg'),
(152541, 10884, 'A Festa da Salsicha Comilandia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/880614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6kSblgQfbqDSo5gRIQ4vp706KTe.jpg'),
(152542, 10884, 'A Festa da Salsicha Comilandia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/880615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6kSblgQfbqDSo5gRIQ4vp706KTe.jpg'),
(152543, 10884, 'A Festa da Salsicha Comilandia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/880616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6kSblgQfbqDSo5gRIQ4vp706KTe.jpg'),
(152544, 10884, 'A Festa da Salsicha Comilandia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/880617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6kSblgQfbqDSo5gRIQ4vp706KTe.jpg'),
(152545, 10884, 'A Festa da Salsicha Comilandia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/880618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6kSblgQfbqDSo5gRIQ4vp706KTe.jpg'),
(152546, 10884, 'A Festa da Salsicha Comilandia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/880619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6kSblgQfbqDSo5gRIQ4vp706KTe.jpg'),
(152547, 10884, 'A Festa da Salsicha Comilandia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/880620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6kSblgQfbqDSo5gRIQ4vp706KTe.jpg'),
(152548, 10885, 'Do Dia Para a Noite S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/406706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gryQdQmeJxnB1dPOrvwTXasGr5y.jpg'),
(152549, 10885, 'Do Dia Para a Noite S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/406707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tHSTcwpHX45hSKqMnHBzrfzME0l.jpg'),
(152550, 10885, 'Do Dia Para a Noite S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/417091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJ1LrNsP0krcV94RPQ2LUXStgl1.jpg'),
(152551, 10885, 'Do Dia Para a Noite S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/417092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJ1LrNsP0krcV94RPQ2LUXStgl1.jpg'),
(152552, 10885, 'Do Dia Para a Noite S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/417093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJ1LrNsP0krcV94RPQ2LUXStgl1.jpg'),
(152553, 10885, 'Do Dia Para a Noite S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/417094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJ1LrNsP0krcV94RPQ2LUXStgl1.jpg'),
(152554, 10885, 'Do Dia Para a Noite S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/425148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJ1LrNsP0krcV94RPQ2LUXStgl1.jpg'),
(152555, 10885, 'Do Dia Para a Noite S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/425149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJ1LrNsP0krcV94RPQ2LUXStgl1.jpg'),
(152556, 10885, 'Do Dia Para a Noite S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/432462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJ1LrNsP0krcV94RPQ2LUXStgl1.jpg'),
(152557, 10885, 'Do Dia Para a Noite S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/432463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJ1LrNsP0krcV94RPQ2LUXStgl1.jpg'),
(152558, 10885, 'Do Dia Para a Noite S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/435080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJ1LrNsP0krcV94RPQ2LUXStgl1.jpg'),
(152559, 10885, 'Do Dia Para a Noite S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/435081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJ1LrNsP0krcV94RPQ2LUXStgl1.jpg'),
(152560, 10885, 'Do Dia Para a Noite S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/436988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJ1LrNsP0krcV94RPQ2LUXStgl1.jpg'),
(152561, 10885, 'Do Dia Para a Noite S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/436989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJ1LrNsP0krcV94RPQ2LUXStgl1.jpg'),
(152562, 10885, 'Do Dia Para a Noite S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/444777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJ1LrNsP0krcV94RPQ2LUXStgl1.jpg'),
(152563, 10885, 'Do Dia Para a Noite S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/444778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tJ1LrNsP0krcV94RPQ2LUXStgl1.jpg'),
(152564, 10886, 'Engenheiros de Hitler Construindo o Terceiro Reich S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/406702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tXTtHniJfA8K3Tuf47COivTks4.jpg'),
(152565, 10886, 'Engenheiros de Hitler Construindo o Terceiro Reich S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/406703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tXTtHniJfA8K3Tuf47COivTks4.jpg'),
(152566, 10886, 'Engenheiros de Hitler Construindo o Terceiro Reich S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/406704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tXTtHniJfA8K3Tuf47COivTks4.jpg'),
(152567, 10886, 'Engenheiros de Hitler Construindo o Terceiro Reich S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/412899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tXTtHniJfA8K3Tuf47COivTks4.jpg'),
(152568, 10886, 'Engenheiros de Hitler Construindo o Terceiro Reich S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/412900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tXTtHniJfA8K3Tuf47COivTks4.jpg'),
(152569, 10886, 'Engenheiros de Hitler Construindo o Terceiro Reich S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/419626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tXTtHniJfA8K3Tuf47COivTks4.jpg'),
(152570, 10887, 'Eu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/406692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pHWRNIypbvCFDHSbklqXhz0K7QV.jpg'),
(152571, 10887, 'Eu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/406693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8K0XuloEEUvpymfLRhxbl1s9KlB.jpg'),
(152572, 10887, 'Eu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/406694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wKk5AnPyFdlu4c9dQIAYJvfwnUb.jpg'),
(152573, 10887, 'Eu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/406695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xIglXMyMl8jpdg7rnL6IOyM575J.jpg'),
(152574, 10887, 'Eu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/406696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yffFpD9DxmbARm4AxjDwoty0SlP.jpg'),
(152575, 10887, 'Eu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/406697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yhOBWMHqA8LWnmoGsoPcIrKlq6R.jpg'),
(152576, 10887, 'Eu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/406698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/usw1COHDRkY95QJXMIgJBUEJ3ll.jpg'),
(152577, 10887, 'Eu S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/406699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sYtAd0n5xVA9KgANCvpAlJPgoAO.jpg'),
(152578, 10887, 'Eu S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/406700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jAMwz8zkktBEAdysp3PhnehuIeR.jpg'),
(152579, 10887, 'Eu S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/406701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/slt3bYfIXcZQUuz3X5ZUKTIEcNx.jpg'),
(152580, 10888, 'Exploding Kittens S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/406683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kAPwPw2YLseGcV1gCcq3678rxj8.jpg'),
(152581, 10888, 'Exploding Kittens S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/406684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/un6A5BQU54gb4TMmW98tScAkO87.jpg'),
(152582, 10888, 'Exploding Kittens S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/406685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vuuhNQggRBzvjEa2e9XQ5PV6cHH.jpg'),
(152583, 10888, 'Exploding Kittens S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/406686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dEOleycZh5DFJ666KH1HGhRLGbD.jpg'),
(152584, 10888, 'Exploding Kittens S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/406687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/39mICR4m1VpGdFOwX1s0q5fgvoh.jpg'),
(152585, 10888, 'Exploding Kittens S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/406688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nNBRwTVFm8wAClz1gVUT3jzrNgh.jpg'),
(152586, 10888, 'Exploding Kittens S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/406689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aT1SnJhtIfJfbWyHEpqZLFJeFw7.jpg'),
(152587, 10888, 'Exploding Kittens S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/406690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mBwrzttLbs3slrFwbgzI2uMCXhK.jpg'),
(152588, 10888, 'Exploding Kittens S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/406691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/llA0IQ1pDEKgxv020puPlgvSn9S.jpg'),
(152589, 10889, 'LALIGA Alem do Campo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/406675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxL2aK45yoH3ExagJZ3yO9bq5p4.jpg'),
(152590, 10889, 'LALIGA Alem do Campo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/406676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxL2aK45yoH3ExagJZ3yO9bq5p4.jpg'),
(152591, 10889, 'LALIGA Alem do Campo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/406677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxL2aK45yoH3ExagJZ3yO9bq5p4.jpg'),
(152592, 10889, 'LALIGA Alem do Campo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/406678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxL2aK45yoH3ExagJZ3yO9bq5p4.jpg'),
(152593, 10889, 'LALIGA Alem do Campo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/406679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxL2aK45yoH3ExagJZ3yO9bq5p4.jpg'),
(152594, 10889, 'LALIGA Alem do Campo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/406680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxL2aK45yoH3ExagJZ3yO9bq5p4.jpg'),
(152595, 10889, 'LALIGA Alem do Campo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/406681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxL2aK45yoH3ExagJZ3yO9bq5p4.jpg'),
(152596, 10889, 'LALIGA Alem do Campo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/406682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxL2aK45yoH3ExagJZ3yO9bq5p4.jpg'),
(152597, 10890, 'Narcoamerica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/406671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/adVkt2LlxmHgSAvf9KlvWV6AsSM.jpg'),
(152598, 10890, 'Narcoamerica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/612179.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u6us98EWpArH8khtNkPm7nBLCrT.jpg'),
(152599, 10890, 'Narcoamerica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/406673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/60cWtpOHM8oYPWAzPcFA2uHYsb.jpg'),
(152600, 10890, 'Narcoamerica S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/406674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vSA9dqyGiwfQEMKk1WD0DENsQmu.jpg'),
(152601, 10891, 'O Misterio da Fazenda Blind Frog S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/406654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152602, 10891, 'O Misterio da Fazenda Blind Frog S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/406655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152603, 10891, 'O Misterio da Fazenda Blind Frog S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/406656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152604, 10891, 'O Misterio da Fazenda Blind Frog S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/406657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152605, 10891, 'O Misterio da Fazenda Blind Frog S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/406658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152606, 10891, 'O Misterio da Fazenda Blind Frog S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/406659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152607, 10892, 'O Misterio da Fazenda Blind Frog S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/406660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152608, 10892, 'O Misterio da Fazenda Blind Frog S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/406661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152609, 10892, 'O Misterio da Fazenda Blind Frog S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/406662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152610, 10892, 'O Misterio da Fazenda Blind Frog S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/406663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152611, 10892, 'O Misterio da Fazenda Blind Frog S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/406664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152612, 10892, 'O Misterio da Fazenda Blind Frog S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/406665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152613, 10892, 'O Misterio da Fazenda Blind Frog S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/406666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152614, 10892, 'O Misterio da Fazenda Blind Frog S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/406667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152615, 10893, 'O Misterio da Fazenda Blind Frog S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/406668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152616, 10893, 'O Misterio da Fazenda Blind Frog S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/406669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152617, 10893, 'O Misterio da Fazenda Blind Frog S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/406670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152618, 10893, 'O Misterio da Fazenda Blind Frog S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/411790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152619, 10893, 'O Misterio da Fazenda Blind Frog S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/414684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152620, 10893, 'O Misterio da Fazenda Blind Frog S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/421154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152621, 10893, 'O Misterio da Fazenda Blind Frog S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/426967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152622, 10893, 'O Misterio da Fazenda Blind Frog S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/435915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152623, 10894, 'O Misterio da Fazenda Blind Frog S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/805851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152624, 10894, 'O Misterio da Fazenda Blind Frog S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/805852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152625, 10894, 'O Misterio da Fazenda Blind Frog S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/805853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152626, 10894, 'O Misterio da Fazenda Blind Frog S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/805854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152627, 10894, 'O Misterio da Fazenda Blind Frog S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/805855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152628, 10894, 'O Misterio da Fazenda Blind Frog S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/805856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xVfxcXJHnapHD1p0zQG18eUIZQz.jpg'),
(152629, 10895, 'Padre Cicero S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/406634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlkU2OFhbPPJy5WVOVjkbtckzFH.jpg'),
(152630, 10895, 'Padre Cicero S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/406635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlkU2OFhbPPJy5WVOVjkbtckzFH.jpg'),
(152631, 10895, 'Padre Cicero S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/406636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlkU2OFhbPPJy5WVOVjkbtckzFH.jpg'),
(152632, 10895, 'Padre Cicero S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/406637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlkU2OFhbPPJy5WVOVjkbtckzFH.jpg'),
(152633, 10895, 'Padre Cicero S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/406638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlkU2OFhbPPJy5WVOVjkbtckzFH.jpg'),
(152634, 10895, 'Padre Cicero S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/406639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlkU2OFhbPPJy5WVOVjkbtckzFH.jpg'),
(152635, 10895, 'Padre Cicero S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/406640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlkU2OFhbPPJy5WVOVjkbtckzFH.jpg'),
(152636, 10895, 'Padre Cicero S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/406641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlkU2OFhbPPJy5WVOVjkbtckzFH.jpg'),
(152637, 10895, 'Padre Cicero S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/406642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlkU2OFhbPPJy5WVOVjkbtckzFH.jpg'),
(152638, 10895, 'Padre Cicero S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/406643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlkU2OFhbPPJy5WVOVjkbtckzFH.jpg'),
(152639, 10895, 'Padre Cicero S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/406644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlkU2OFhbPPJy5WVOVjkbtckzFH.jpg'),
(152640, 10895, 'Padre Cicero S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/406645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlkU2OFhbPPJy5WVOVjkbtckzFH.jpg'),
(152641, 10895, 'Padre Cicero S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/406646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlkU2OFhbPPJy5WVOVjkbtckzFH.jpg'),
(152642, 10895, 'Padre Cicero S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/406647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlkU2OFhbPPJy5WVOVjkbtckzFH.jpg'),
(152643, 10895, 'Padre Cicero S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/406648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlkU2OFhbPPJy5WVOVjkbtckzFH.jpg'),
(152644, 10895, 'Padre Cicero S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/406649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlkU2OFhbPPJy5WVOVjkbtckzFH.jpg'),
(152645, 10895, 'Padre Cicero S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/406650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlkU2OFhbPPJy5WVOVjkbtckzFH.jpg'),
(152646, 10895, 'Padre Cicero S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/406651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlkU2OFhbPPJy5WVOVjkbtckzFH.jpg'),
(152647, 10895, 'Padre Cicero S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/406652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlkU2OFhbPPJy5WVOVjkbtckzFH.jpg'),
(152648, 10895, 'Padre Cicero S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/406653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vlkU2OFhbPPJy5WVOVjkbtckzFH.jpg'),
(152649, 10896, 'Toda Familia Tem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/406627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/noT0S2Iml4xScz2am3V7HY7vhda.jpg'),
(152650, 10896, 'Toda Familia Tem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/406628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/noT0S2Iml4xScz2am3V7HY7vhda.jpg'),
(152651, 10896, 'Toda Familia Tem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/406629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/noT0S2Iml4xScz2am3V7HY7vhda.jpg'),
(152652, 10896, 'Toda Familia Tem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/406630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/noT0S2Iml4xScz2am3V7HY7vhda.jpg'),
(152653, 10896, 'Toda Familia Tem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/406631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/noT0S2Iml4xScz2am3V7HY7vhda.jpg'),
(152654, 10896, 'Toda Familia Tem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/406632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/noT0S2Iml4xScz2am3V7HY7vhda.jpg'),
(152655, 10896, 'Toda Familia Tem S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/406633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/noT0S2Iml4xScz2am3V7HY7vhda.jpg'),
(152656, 10897, 'Eu Estava La S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/412889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3WDAUUrcOfzGfsE352CUwsRUCQk.jpg'),
(152657, 10897, 'Eu Estava La S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/412890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lEfCU1vIdJQii4JdThWVqV7fIz7.jpg'),
(152658, 10897, 'Eu Estava La S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/412891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uvcrA0fQDtVyp2o9huzgfwcV4gp.jpg'),
(152659, 10897, 'Eu Estava La S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/612220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A6rZEAP8as4pzVRM493Ykgc58Iu.jpg'),
(152660, 10897, 'Eu Estava La S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/412893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A6rZEAP8as4pzVRM493Ykgc58Iu.jpg'),
(152661, 10897, 'Eu Estava La S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/412894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A6rZEAP8as4pzVRM493Ykgc58Iu.jpg'),
(152662, 10897, 'Eu Estava La S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/412895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A6rZEAP8as4pzVRM493Ykgc58Iu.jpg'),
(152663, 10897, 'Eu Estava La S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/415028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A6rZEAP8as4pzVRM493Ykgc58Iu.jpg'),
(152664, 10897, 'Eu Estava La S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/415029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A6rZEAP8as4pzVRM493Ykgc58Iu.jpg'),
(152665, 10897, 'Eu Estava La S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/415030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A6rZEAP8as4pzVRM493Ykgc58Iu.jpg'),
(152666, 10897, 'Eu Estava La S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/435062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A6rZEAP8as4pzVRM493Ykgc58Iu.jpg'),
(152667, 10897, 'Eu Estava La S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/435063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A6rZEAP8as4pzVRM493Ykgc58Iu.jpg'),
(152668, 10898, 'Homicidio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lkzo6r0VaTfr5v5fGwB784xcho4.jpg'),
(152669, 10898, 'Homicidio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/612142.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jusBLMSLJajgMzMAwOvjXju9sHI.jpg'),
(152670, 10898, 'Homicidio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/413845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2MgjL2P87XNqWRGl8Mx6anemKRT.jpg'),
(152671, 10898, 'Homicidio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/413846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tvuGQ2TSn4WgmcSdzIViVuhOfIM.jpg'),
(152672, 10898, 'Homicidio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/413847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7yHuvLxUGvZbGWBvJoGEx63cGYy.jpg'),
(152673, 10899, 'Homicidio S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/boYxSNdfwnSpG1WZ1iZrO3apBfy.jpg'),
(152674, 10899, 'Homicidio S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/413849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bqDFuwwT6QJobHdaZEj3B5XkSRq.jpg'),
(152675, 10899, 'Homicidio S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/413850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eZe0ChNEqGZo8AJgSCsOn9BPADu.jpg'),
(152676, 10899, 'Homicidio S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/413851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uZfYpS2pfC2rr9nWf0dwS1cBRQX.jpg'),
(152677, 10899, 'Homicidio S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/413852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qKX3iAHqu3B1EjuAQGGV244STdk.jpg'),
(152678, 10900, 'Kaulitz and Kaulitz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vWsFhq4SIFUXj2nAX12FcWAX2TZ.jpg'),
(152679, 10900, 'Kaulitz and Kaulitz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/413836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vWsFhq4SIFUXj2nAX12FcWAX2TZ.jpg'),
(152680, 10900, 'Kaulitz and Kaulitz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/413837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vWsFhq4SIFUXj2nAX12FcWAX2TZ.jpg'),
(152681, 10900, 'Kaulitz and Kaulitz S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/413838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vWsFhq4SIFUXj2nAX12FcWAX2TZ.jpg'),
(152682, 10900, 'Kaulitz and Kaulitz S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/413839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vWsFhq4SIFUXj2nAX12FcWAX2TZ.jpg'),
(152683, 10900, 'Kaulitz and Kaulitz S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/413840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vWsFhq4SIFUXj2nAX12FcWAX2TZ.jpg'),
(152684, 10900, 'Kaulitz and Kaulitz S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/413841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vWsFhq4SIFUXj2nAX12FcWAX2TZ.jpg'),
(152685, 10900, 'Kaulitz and Kaulitz S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/413842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vWsFhq4SIFUXj2nAX12FcWAX2TZ.jpg'),
(152686, 10901, 'Kaulitz and Kaulitz S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/843054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vWsFhq4SIFUXj2nAX12FcWAX2TZ.jpg'),
(152687, 10901, 'Kaulitz and Kaulitz S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/843055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vWsFhq4SIFUXj2nAX12FcWAX2TZ.jpg'),
(152688, 10901, 'Kaulitz and Kaulitz S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/843056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vWsFhq4SIFUXj2nAX12FcWAX2TZ.jpg'),
(152689, 10901, 'Kaulitz and Kaulitz S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/843057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vWsFhq4SIFUXj2nAX12FcWAX2TZ.jpg'),
(152690, 10901, 'Kaulitz and Kaulitz S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/843058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vWsFhq4SIFUXj2nAX12FcWAX2TZ.jpg'),
(152691, 10901, 'Kaulitz and Kaulitz S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/843059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vWsFhq4SIFUXj2nAX12FcWAX2TZ.jpg'),
(152692, 10901, 'Kaulitz and Kaulitz S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/843060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vWsFhq4SIFUXj2nAX12FcWAX2TZ.jpg'),
(152693, 10901, 'Kaulitz and Kaulitz S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/843061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vWsFhq4SIFUXj2nAX12FcWAX2TZ.jpg'),
(152694, 10902, 'O Assassinato de Yara Gambirasio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oXow6n5ckdqRRTuaxF0Sx6TKLfI.jpg'),
(152695, 10902, 'O Assassinato de Yara Gambirasio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/413831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fGPu2p2MMzikuby5hegSqOhurQU.jpg'),
(152696, 10902, 'O Assassinato de Yara Gambirasio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/413832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w86wtpurKlAdosnfwYRFEqGpQgF.jpg'),
(152697, 10902, 'O Assassinato de Yara Gambirasio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/413833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/elyOMz9Ela081Gd3km9CBiNhKux.jpg'),
(152698, 10902, 'O Assassinato de Yara Gambirasio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/413834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8SH5FxImIL8vXfPNBzCxNqXGz76.jpg'),
(152699, 10903, 'Bicampeas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7xuYyTqM3TMvu8sg7blDRJPHzKq.jpg'),
(152700, 10903, 'Bicampeas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/413801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7xuYyTqM3TMvu8sg7blDRJPHzKq.jpg'),
(152701, 10903, 'Bicampeas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/413802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7xuYyTqM3TMvu8sg7blDRJPHzKq.jpg'),
(152702, 10903, 'Bicampeas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/413803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7xuYyTqM3TMvu8sg7blDRJPHzKq.jpg'),
(152703, 10904, 'Chefe da Casa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aw2inC3XAFtJtTRedvkODL7PfrP.jpg'),
(152704, 10904, 'Chefe da Casa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/413794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCbIqsaCgsEREUqsi6uyEUqa4Yy.jpg'),
(152705, 10904, 'Chefe da Casa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/413795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sOauSm23P1RqWV3ypjCOvicCgWx.jpg'),
(152706, 10904, 'Chefe da Casa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/413796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l5RF8B4b9uwg3s8qZIzsz4X2Rli.jpg'),
(152707, 10904, 'Chefe da Casa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/413797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mIRIoehTvflelkibo8WiDKscT0t.jpg'),
(152708, 10904, 'Chefe da Casa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/413798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/NAm2WnppVBg6QcSz7EDcIL4VUV.jpg'),
(152709, 10904, 'Chefe da Casa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/612123.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/86J5MisQGjhsBkvhh5V5MdrFcCN.jpg'),
(152710, 10905, 'Expedicoes Secretas dos Nazistas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7ghiT6jWyooHBu9VFQErYs7GXfG.jpg'),
(152711, 10905, 'Expedicoes Secretas dos Nazistas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/413788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Fzw5JfrSrdAUUazAzBR3i5jzWx.jpg'),
(152712, 10905, 'Expedicoes Secretas dos Nazistas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/413789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/znWDGscUVAF3wew9MMoOOyA6eMh.jpg'),
(152713, 10905, 'Expedicoes Secretas dos Nazistas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/413790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ltNK0vmD8nj5emnmB3FN1iEmJbZ.jpg'),
(152714, 10905, 'Expedicoes Secretas dos Nazistas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/413791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hKy99pg9QARcb61CrSjOWlbBcRO.jpg'),
(152715, 10905, 'Expedicoes Secretas dos Nazistas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/413792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/maZI8xs7vAX8yTk1rxROMuY4Cp1.jpg'),
(152716, 10906, 'Mafia Spies S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xr0XKb5sO7fqwnEjkYSycKKxnAN.jpg'),
(152717, 10906, 'Mafia Spies S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/413782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b4YsPKtgQe9PpHS04TnwUeLmF1a.jpg'),
(152718, 10906, 'Mafia Spies S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/413783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wgtA2AEZggPsnhOaatdTSr00Vrg.jpg'),
(152719, 10906, 'Mafia Spies S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/413784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3lRG89boUU4EZydMS3iUg8HoUCx.jpg'),
(152720, 10906, 'Mafia Spies S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/413785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wLhGn966ILZ9DnryyvyCtvjyuEG.jpg'),
(152721, 10906, 'Mafia Spies S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/413786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9XYNMPpZ6P86RJhBCAU3C2SKadp.jpg'),
(152722, 10907, 'Muquiranas Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iHfMfWkLcvik5g7RMzcUuKyLxri.jpg'),
(152723, 10907, 'Muquiranas Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/413780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iHfMfWkLcvik5g7RMzcUuKyLxri.jpg'),
(152724, 10907, 'Muquiranas Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/419466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iHfMfWkLcvik5g7RMzcUuKyLxri.jpg'),
(152725, 10907, 'Muquiranas Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/419467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iHfMfWkLcvik5g7RMzcUuKyLxri.jpg'),
(152726, 10907, 'Muquiranas Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/421159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iHfMfWkLcvik5g7RMzcUuKyLxri.jpg'),
(152727, 10907, 'Muquiranas Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/421160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iHfMfWkLcvik5g7RMzcUuKyLxri.jpg'),
(152728, 10907, 'Muquiranas Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/427101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iHfMfWkLcvik5g7RMzcUuKyLxri.jpg'),
(152729, 10907, 'Muquiranas Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/427102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iHfMfWkLcvik5g7RMzcUuKyLxri.jpg'),
(152730, 10908, 'O Lado Obscuro dos Anos 80 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lIqko0AldRoXpMKIdipzQnhwEuT.jpg'),
(152731, 10908, 'O Lado Obscuro dos Anos 80 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/413764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jhybkRk8h4QdbxJu9p5jqT5cW1l.jpg'),
(152732, 10908, 'O Lado Obscuro dos Anos 80 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/413765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/62MYN5fMPNxLbrWmWDDTYtBatIR.jpg'),
(152733, 10908, 'O Lado Obscuro dos Anos 80 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/413766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ivLyTrCXcQ7iuu3nhcCFP0z9HgH.jpg'),
(152734, 10908, 'O Lado Obscuro dos Anos 80 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/413767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/twOJR01FD02a5kyyJTPOXNn5KaV.jpg'),
(152735, 10908, 'O Lado Obscuro dos Anos 80 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/413768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qB8HyyqFxDT6yF8jj5tNv0F5XRt.jpg'),
(152736, 10909, 'O Lado Obscuro dos Anos 80 S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cY6Ssc6E7FfUiK7C4RTspLg5zsS.jpg'),
(152737, 10909, 'O Lado Obscuro dos Anos 80 S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/413770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bs5gR5cvKmtsAJkfSfUc9Taw2vf.jpg'),
(152738, 10909, 'O Lado Obscuro dos Anos 80 S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/413771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ofdkbOCiQv2HY8QVhyo6xXuQ9Rp.jpg'),
(152739, 10909, 'O Lado Obscuro dos Anos 80 S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/413772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4YKqVy1AhTk8UAWxT8NSexbg0w.jpg'),
(152740, 10909, 'O Lado Obscuro dos Anos 80 S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/413773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hCHShHNbHHe7wNn70Vy4Uqwryjn.jpg'),
(152741, 10909, 'O Lado Obscuro dos Anos 80 S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/413774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1hXVCqsqXUh5iXsK7kU7drezjbr.jpg'),
(152742, 10909, 'O Lado Obscuro dos Anos 80 S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/413775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z1TApqtlLrmOXeh9d2Ra2vvAL28.jpg'),
(152743, 10909, 'O Lado Obscuro dos Anos 80 S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/413776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hmEvErO7neRkOh46QYK8sl1MGZt.jpg'),
(152744, 10909, 'O Lado Obscuro dos Anos 80 S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/413777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9eM58pffHncu2BwPIYQdGOWz35R.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(152745, 10909, 'O Lado Obscuro dos Anos 80 S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/413778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xIJg9p2z5EtbCGBfHaFSrGK18r9.jpg'),
(152746, 10910, 'Os Hassums S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2UryN6COS36nLlm9yyEihvBfSDc.jpg'),
(152747, 10910, 'Os Hassums S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/426928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2UryN6COS36nLlm9yyEihvBfSDc.jpg'),
(152748, 10910, 'Os Hassums S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/423299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2UryN6COS36nLlm9yyEihvBfSDc.jpg'),
(152749, 10910, 'Os Hassums S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/426930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2UryN6COS36nLlm9yyEihvBfSDc.jpg'),
(152750, 10910, 'Os Hassums S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/429245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2UryN6COS36nLlm9yyEihvBfSDc.jpg'),
(152751, 10911, 'Perseguicao com John Walsh S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152752, 10911, 'Perseguicao com John Walsh S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/413726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152753, 10911, 'Perseguicao com John Walsh S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/413727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152754, 10911, 'Perseguicao com John Walsh S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/413728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152755, 10911, 'Perseguicao com John Walsh S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/413729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152756, 10911, 'Perseguicao com John Walsh S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/413730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152757, 10911, 'Perseguicao com John Walsh S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/413731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152758, 10911, 'Perseguicao com John Walsh S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/413732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152759, 10911, 'Perseguicao com John Walsh S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/413733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152760, 10911, 'Perseguicao com John Walsh S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/413734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152761, 10911, 'Perseguicao com John Walsh S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/413735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152762, 10911, 'Perseguicao com John Walsh S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/413736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152763, 10912, 'Perseguicao com John Walsh S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152764, 10912, 'Perseguicao com John Walsh S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/413738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152765, 10912, 'Perseguicao com John Walsh S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/413739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152766, 10912, 'Perseguicao com John Walsh S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/413740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152767, 10912, 'Perseguicao com John Walsh S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/413741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152768, 10912, 'Perseguicao com John Walsh S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/413742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152769, 10912, 'Perseguicao com John Walsh S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/413743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152770, 10912, 'Perseguicao com John Walsh S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/413744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152771, 10912, 'Perseguicao com John Walsh S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/413745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152772, 10912, 'Perseguicao com John Walsh S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/413746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152773, 10912, 'Perseguicao com John Walsh S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/413747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152774, 10912, 'Perseguicao com John Walsh S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/413748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152775, 10913, 'Perseguicao com John Walsh S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152776, 10913, 'Perseguicao com John Walsh S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/413750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152777, 10913, 'Perseguicao com John Walsh S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/413751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152778, 10913, 'Perseguicao com John Walsh S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/413752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152779, 10913, 'Perseguicao com John Walsh S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/413753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152780, 10913, 'Perseguicao com John Walsh S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/413754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152781, 10913, 'Perseguicao com John Walsh S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/413755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152782, 10913, 'Perseguicao com John Walsh S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/413756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152783, 10913, 'Perseguicao com John Walsh S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/413757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152784, 10913, 'Perseguicao com John Walsh S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/413758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152785, 10913, 'Perseguicao com John Walsh S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/413759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152786, 10913, 'Perseguicao com John Walsh S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/413760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152787, 10914, 'Perseguicao com John Walsh S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152788, 10914, 'Perseguicao com John Walsh S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/418276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152789, 10914, 'Perseguicao com John Walsh S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/430956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152790, 10914, 'Perseguicao com John Walsh S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/430957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152791, 10914, 'Perseguicao com John Walsh S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/433258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152792, 10914, 'Perseguicao com John Walsh S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/454727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iFnNzTMsth6EhbTqIZL4quiRmHh.jpg'),
(152793, 10915, 'Tesouro Visto do Espaco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wlppTUXnJZpPA5Tb9DeMzLDxhwK.jpg'),
(152794, 10915, 'Tesouro Visto do Espaco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/413710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cuWeNeWSs73UOTBsknjgFLQnRdB.jpg'),
(152795, 10915, 'Tesouro Visto do Espaco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/413711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gPB6hFGxWGxd6Yncr81WaBzpP9Z.jpg'),
(152796, 10915, 'Tesouro Visto do Espaco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/413712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AucMQrDjlpAbw7GsSFju4gWbUdo.jpg'),
(152797, 10915, 'Tesouro Visto do Espaco S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/413713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ghqowmDwPZ6GGgREP3UAapX5W55.jpg'),
(152798, 10915, 'Tesouro Visto do Espaco S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/413714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2rUW2TBUU1XNgaLezF0PvnWISeO.jpg'),
(152799, 10915, 'Tesouro Visto do Espaco S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/413715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quyqXR4zo03EF3JnfvBRoRneWGK.jpg'),
(152800, 10915, 'Tesouro Visto do Espaco S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/413716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quyqXR4zo03EF3JnfvBRoRneWGK.jpg'),
(152801, 10916, 'Tesouro Visto do Espaco S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6rQUYckqCuazSB5Rv5MLp0ZT7V.jpg'),
(152802, 10916, 'Tesouro Visto do Espaco S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/413718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c4eiW1vIrUC3ZcHKL7HpiBp1v55.jpg'),
(152803, 10916, 'Tesouro Visto do Espaco S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/413719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xaWm70Gw2ZRSvvKHQmnqk2l2L9q.jpg'),
(152804, 10916, 'Tesouro Visto do Espaco S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/413720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quyqXR4zo03EF3JnfvBRoRneWGK.jpg'),
(152805, 10916, 'Tesouro Visto do Espaco S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/413721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quyqXR4zo03EF3JnfvBRoRneWGK.jpg'),
(152806, 10916, 'Tesouro Visto do Espaco S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/413722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quyqXR4zo03EF3JnfvBRoRneWGK.jpg'),
(152807, 10916, 'Tesouro Visto do Espaco S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/413723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quyqXR4zo03EF3JnfvBRoRneWGK.jpg'),
(152808, 10916, 'Tesouro Visto do Espaco S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/413724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/quyqXR4zo03EF3JnfvBRoRneWGK.jpg'),
(152809, 10917, 'Uma Escolha do Coracao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kwrvK3CfZFHTZbcr5iePnqh57A.jpg'),
(152810, 10917, 'Uma Escolha do Coracao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/413634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kPf7njDmiRdsrL1kGaLRVdTTT4J.jpg'),
(152811, 10917, 'Uma Escolha do Coracao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/413635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zes4B8MIVMDDA4q6MejFaSb5hFh.jpg'),
(152812, 10917, 'Uma Escolha do Coracao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/413636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4kVH2jC2J4wfa9l2ZBVsAJvBFkQ.jpg'),
(152813, 10917, 'Uma Escolha do Coracao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/413637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/shRwHTXrTAa2Fg0Jo2EwjXNAtDT.jpg'),
(152814, 10917, 'Uma Escolha do Coracao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/413638.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n9vRlv33MKH3r7Q5gXpNN5vrjFD.jpg'),
(152815, 10917, 'Uma Escolha do Coracao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/413639.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3T2p0ZwOhi2GNFi3NmAkL4rHocv.jpg'),
(152816, 10917, 'Uma Escolha do Coracao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/413640.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/GZwwIcbyoe99o9LWQBHiHfz4Gt.jpg'),
(152817, 10917, 'Uma Escolha do Coracao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/413641.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zzM0lCaHVYBSvQxd7iFZETdcFb4.jpg'),
(152818, 10917, 'Uma Escolha do Coracao S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/413642.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kRDyKoK5l2OIJI2Y6pstPLa5usb.jpg'),
(152819, 10917, 'Uma Escolha do Coracao S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/413643.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xZoAVsfPlBOJ3U16RjH7qqNDZWB.jpg'),
(152820, 10917, 'Uma Escolha do Coracao S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/413644.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/19PRVP2N2NunSy1fUK65tUa3iyq.jpg'),
(152821, 10917, 'Uma Escolha do Coracao S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/413645.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sQppT0VJys9YaorXIfkKJjDaLdo.jpg'),
(152822, 10917, 'Uma Escolha do Coracao S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/413646.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fmsrY6MkZgT6eY1ojgqOetPB5Ck.jpg'),
(152823, 10917, 'Uma Escolha do Coracao S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/413647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u8zGvVmlGuO5zv1rh8TbuaOso4L.jpg'),
(152824, 10917, 'Uma Escolha do Coracao S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/413648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aQDUWiNPTcqwFkofcG7lWpvkiUp.jpg'),
(152825, 10917, 'Uma Escolha do Coracao S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/413649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7K24pNzqj0erhhkxHHkVs6APBx.jpg'),
(152826, 10917, 'Uma Escolha do Coracao S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/413650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lvV40zWve2QGSPSacNMHjqJPU5D.jpg'),
(152827, 10917, 'Uma Escolha do Coracao S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/413651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oIOPII8KZTwn0NvFU0CzOYPUkgU.jpg'),
(152828, 10917, 'Uma Escolha do Coracao S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/413652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/detBqRFAyiMU6bzJMEEWIoyjnZi.jpg'),
(152829, 10917, 'Uma Escolha do Coracao S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/413653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bkgRU472p6L4RH77BowEiOaboR9.jpg'),
(152830, 10917, 'Uma Escolha do Coracao S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/413654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hdcd3yYpmMDzWzttvH1aJQ2RG3U.jpg'),
(152831, 10918, 'Uma Escolha do Coracao S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2SeGZuFBcx9q0sq7A8IZNRBI0C4.jpg'),
(152832, 10918, 'Uma Escolha do Coracao S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/413656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mlLhHatOrrVabsM26RK4ARonE1q.jpg'),
(152833, 10918, 'Uma Escolha do Coracao S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/413657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gv5JVZwkOT39efTpm4HMtIwYdeo.jpg'),
(152834, 10918, 'Uma Escolha do Coracao S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/413658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/byDdjSqeE0z8uRgpxt3UFoQujH3.jpg'),
(152835, 10918, 'Uma Escolha do Coracao S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/413659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7a6FJEN0Y86yeT1izqv6Eqt4KTp.jpg'),
(152836, 10918, 'Uma Escolha do Coracao S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/413660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/28QEqnB2PvJDlVtZ0Y9mjOUM8Dj.jpg'),
(152837, 10918, 'Uma Escolha do Coracao S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/413661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hpbuEPtdJH20qHW3syr1yCu27ql.jpg'),
(152838, 10918, 'Uma Escolha do Coracao S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/413662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wN5pOmtRNWHJePnUmR27OPqxJ9E.jpg'),
(152839, 10918, 'Uma Escolha do Coracao S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/413663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oTFzwsDAUbtiftRklrvjA2XG1N0.jpg'),
(152840, 10918, 'Uma Escolha do Coracao S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/413664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xHXsAdkg4kMgJMBRbr6CyCUuJfB.jpg'),
(152841, 10918, 'Uma Escolha do Coracao S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/413665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/DfP4lxHhgBhheQ1kCGr7YUWxcZ.jpg'),
(152842, 10918, 'Uma Escolha do Coracao S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/413666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mCULbxCpbLU1J8oqThAIJPqnPtO.jpg'),
(152843, 10918, 'Uma Escolha do Coracao S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/413667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vIPxMnWBIjyr6E0Eg9dPsOf8JvP.jpg'),
(152844, 10918, 'Uma Escolha do Coracao S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/413668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gei9zrWjuvsiG0N86GPZGYKV7Bl.jpg'),
(152845, 10918, 'Uma Escolha do Coracao S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/413669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9h8bD0C67E65zCqtFRPK3B8JkvE.jpg'),
(152846, 10918, 'Uma Escolha do Coracao S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/413670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Mm4xnyMzGyFAgjrNtaBhz1JPOv.jpg'),
(152847, 10918, 'Uma Escolha do Coracao S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/413671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/icgx8IQw5eavRxIPF1TLPtAbgFI.jpg'),
(152848, 10918, 'Uma Escolha do Coracao S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/413672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jHcnoqDa2OB1qScd67OH3h0WPcl.jpg'),
(152849, 10918, 'Uma Escolha do Coracao S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/413673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDAkHkVIcmqzSZY1UmW7HnVi8mL.jpg'),
(152850, 10918, 'Uma Escolha do Coracao S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/413674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dYIceNOszX1BWAwyXsShjstb83Q.jpg'),
(152851, 10918, 'Uma Escolha do Coracao S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/413675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1I6yV012ngj6zqTc8y8p8pccVlW.jpg'),
(152852, 10918, 'Uma Escolha do Coracao S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/413676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/koksVAW5q2xPSf5ysWgYHl595ll.jpg'),
(152853, 10919, 'Uma Escolha do Coracao S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9dmFo1Xb2d1FyG6sIpKbr2RiuYz.jpg'),
(152854, 10919, 'Uma Escolha do Coracao S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/413678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oHXPMDj2XWfYBWLoMcfJkvaxGM5.jpg'),
(152855, 10919, 'Uma Escolha do Coracao S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/413679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vra59qPUo3ptiRqiejQ1WofLkyb.jpg'),
(152856, 10919, 'Uma Escolha do Coracao S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/413680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rLiWFs4H1Flq8wiFVw7kqPSHAqw.jpg'),
(152857, 10919, 'Uma Escolha do Coracao S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/413681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hN6OkOb1aiyb6X0oDLDbhzmNUCw.jpg'),
(152858, 10919, 'Uma Escolha do Coracao S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/413682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2WmNckktIyMHdMS8aXxxwy4y3n9.jpg'),
(152859, 10919, 'Uma Escolha do Coracao S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/413683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lbekrCTcwQRR92uMRLWG3IC8vhY.jpg'),
(152860, 10919, 'Uma Escolha do Coracao S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/413684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3XSfnO56ONXhQunfLrz42lpjqVu.jpg'),
(152861, 10919, 'Uma Escolha do Coracao S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/413685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hVDZ7ZRZh0kk3KBOuc22xqOoFKa.jpg'),
(152862, 10919, 'Uma Escolha do Coracao S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/413686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lBc2q9CRVGfF3R2D1JvLhbkbrGy.jpg'),
(152863, 10919, 'Uma Escolha do Coracao S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/413687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8HnPZbAL9rSYugM5WCPSPVjrYVi.jpg'),
(152864, 10919, 'Uma Escolha do Coracao S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/413688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8oWehkJ55kFbsaAQze4K3T8H2b6.jpg'),
(152865, 10919, 'Uma Escolha do Coracao S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/413689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w4MQb5F9FwdAnACbktpyS4Wb07n.jpg'),
(152866, 10919, 'Uma Escolha do Coracao S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/413690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6kmcbFHBw9kl26rmZuIo9Fw5Ziw.jpg'),
(152867, 10919, 'Uma Escolha do Coracao S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/413691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3BwOR46vUZKzVu4NuLtKA2hcy5N.jpg'),
(152868, 10919, 'Uma Escolha do Coracao S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/413692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MDTxlbEXXrcQSbdELBOeHsM2Fn.jpg'),
(152869, 10919, 'Uma Escolha do Coracao S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/413693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1FVFbPRTLxnxOpqaaMHxbUt13qG.jpg'),
(152870, 10919, 'Uma Escolha do Coracao S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/413694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zabTTcdHJhqsxIU2TE0BKooEiSS.jpg'),
(152871, 10919, 'Uma Escolha do Coracao S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/413695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sD9xwqcw2LvclgkBIiKIqlr09Jk.jpg'),
(152872, 10919, 'Uma Escolha do Coracao S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/413696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/va9PD0FQ5ZvSRRtBjk9bEB29oBx.jpg'),
(152873, 10919, 'Uma Escolha do Coracao S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/413697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/44guRQvFNuCFloQAqzQbx3baL78.jpg'),
(152874, 10919, 'Uma Escolha do Coracao S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/413698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s9gLzFczOURX1sZDoXht3g605pP.jpg'),
(152875, 10920, 'Uma Escolha do Coracao S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/413699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iDFAodCPN8tcXuqsRhy5VAiES38.jpg'),
(152876, 10920, 'Uma Escolha do Coracao S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/413700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d9MmXqpLEhAcedxNskzVqCpwsWp.jpg'),
(152877, 10920, 'Uma Escolha do Coracao S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/413701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oY6pJD2HhzOzL1cnbclnw2Qk7sV.jpg'),
(152878, 10920, 'Uma Escolha do Coracao S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/413702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Xu48DfXg4RPXQYUrKsyWBdgYkO.jpg'),
(152879, 10920, 'Uma Escolha do Coracao S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/413703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3WzJu8lM6eOuSyxmre6UJAmuEHU.jpg'),
(152880, 10920, 'Uma Escolha do Coracao S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/413704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7W8EzkImNoNEHoI5vY6YJivEGAm.jpg'),
(152881, 10920, 'Uma Escolha do Coracao S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/413705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/afLqm9DQpAWkxVR0g3ymVIHsMOa.jpg'),
(152882, 10920, 'Uma Escolha do Coracao S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/413706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iQeVwp5ZXUNS6F1hN9XRDOmahMJ.jpg'),
(152883, 10920, 'Uma Escolha do Coracao S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/413707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f0kLEuquYHals2GI4DZX6CDeM6M.jpg'),
(152884, 10920, 'Uma Escolha do Coracao S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/413708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uwv4alQIV2lBXaooYKUz8tiwk5n.jpg'),
(152885, 10921, 'Um Contador no Mundo do Crime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/409940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kW1sYnMo7aEHmrGtznbl3l3CA9N.jpg'),
(152886, 10921, 'Um Contador no Mundo do Crime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/409941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v1MGy4EMeuPMCYj9VMrVovUTxcp.jpg'),
(152887, 10921, 'Um Contador no Mundo do Crime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/409942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t9eAugqppupQ9rY96eIWliEvnXy.jpg'),
(152888, 10921, 'Um Contador no Mundo do Crime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/409943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lIFf5uq26nkI8esIfSCkTGFc10N.jpg'),
(152889, 10921, 'Um Contador no Mundo do Crime S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/409944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jjAUDTosBcGz2eN3jYkEAKv4Jmv.jpg'),
(152890, 10921, 'Um Contador no Mundo do Crime S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/409945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLCSyME1SNEi7DPWXehduQzR4sL.jpg'),
(152891, 10921, 'Um Contador no Mundo do Crime S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/409946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rPWgji1nN1G6UvXX0BAqN9EyHDb.jpg'),
(152892, 10921, 'Um Contador no Mundo do Crime S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/409947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/npAKjJistWL5jRmlR0BYU2sqmdZ.jpg'),
(152893, 10921, 'Um Contador no Mundo do Crime S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/409948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iIuDNmI09F2MO6jP6kXvhW5Afgu.jpg'),
(152894, 10922, 'dr4g0n S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/409932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qVR9YYXygK3swiJXUHFegu6vMP3.jpg'),
(152895, 10922, 'dr4g0n S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/610525.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2iMzsKU44RRazkAt6AKPhN1SZTg.jpg'),
(152896, 10922, 'dr4g0n S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/610526.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i5jxUmbzVLxgDOiOiePASaE64XQ.jpg'),
(152897, 10922, 'dr4g0n S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/409935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4pTTDoGN2rK25tMyJw4sl7aI0LI.jpg'),
(152898, 10922, 'dr4g0n S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/409936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iuqkPpKaiG50S63ft8pYyf1tvgg.jpg'),
(152899, 10922, 'dr4g0n S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/610529.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r2W03TAldKbjVVtmbx2Vnbj1nAP.jpg'),
(152900, 10922, 'dr4g0n S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/409938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pHT0grvYP3E64oCyvpWdiZPHI0J.jpg'),
(152901, 10922, 'dr4g0n S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/409939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f48TRhFKciJTvE9Up1sXThVslHt.jpg'),
(152902, 10923, '24 em 24 O Ultimo Chef de Pe S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fDzXYck2NmFFnV9TpRrMfCbt6KL.jpg'),
(152903, 10923, '24 em 24 O Ultimo Chef de Pe S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/419841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fDzXYck2NmFFnV9TpRrMfCbt6KL.jpg'),
(152904, 10923, '24 em 24 O Ultimo Chef de Pe S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fDzXYck2NmFFnV9TpRrMfCbt6KL.jpg'),
(152905, 10923, '24 em 24 O Ultimo Chef de Pe S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fDzXYck2NmFFnV9TpRrMfCbt6KL.jpg'),
(152906, 10923, '24 em 24 O Ultimo Chef de Pe S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fDzXYck2NmFFnV9TpRrMfCbt6KL.jpg'),
(152907, 10923, '24 em 24 O Ultimo Chef de Pe S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/437902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fDzXYck2NmFFnV9TpRrMfCbt6KL.jpg'),
(152908, 10923, '24 em 24 O Ultimo Chef de Pe S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fDzXYck2NmFFnV9TpRrMfCbt6KL.jpg'),
(152909, 10923, '24 em 24 O Ultimo Chef de Pe S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fDzXYck2NmFFnV9TpRrMfCbt6KL.jpg'),
(152910, 10924, '24 em 24 O Ultimo Chef de Pe S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/870981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fDzXYck2NmFFnV9TpRrMfCbt6KL.jpg'),
(152911, 10924, '24 em 24 O Ultimo Chef de Pe S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/870982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fDzXYck2NmFFnV9TpRrMfCbt6KL.jpg'),
(152912, 10924, '24 em 24 O Ultimo Chef de Pe S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/870983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fDzXYck2NmFFnV9TpRrMfCbt6KL.jpg'),
(152913, 10924, '24 em 24 O Ultimo Chef de Pe S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/870984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fDzXYck2NmFFnV9TpRrMfCbt6KL.jpg'),
(152914, 10924, '24 em 24 O Ultimo Chef de Pe S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/870985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fDzXYck2NmFFnV9TpRrMfCbt6KL.jpg'),
(152915, 10924, '24 em 24 O Ultimo Chef de Pe S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/870986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fDzXYck2NmFFnV9TpRrMfCbt6KL.jpg'),
(152916, 10924, '24 em 24 O Ultimo Chef de Pe S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/870987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fDzXYck2NmFFnV9TpRrMfCbt6KL.jpg'),
(152917, 10924, '24 em 24 O Ultimo Chef de Pe S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/870988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fDzXYck2NmFFnV9TpRrMfCbt6KL.jpg'),
(152918, 10924, '24 em 24 O Ultimo Chef de Pe S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/870989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fDzXYck2NmFFnV9TpRrMfCbt6KL.jpg'),
(152919, 10925, 'A Mulher no Lago S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416270.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LWFhfYlYwMXFBHA37akIdJMdl1.jpg'),
(152920, 10925, 'A Mulher no Lago S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416271.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A5hQsDwFVrvYPrLNADtdekODHhi.jpg'),
(152921, 10925, 'A Mulher no Lago S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/419839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a4uoG1kYoMCf8rqPak0hDmcljPC.jpg'),
(152922, 10925, 'A Mulher no Lago S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a4uoG1kYoMCf8rqPak0hDmcljPC.jpg'),
(152923, 10925, 'A Mulher no Lago S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/427999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a4uoG1kYoMCf8rqPak0hDmcljPC.jpg'),
(152924, 10925, 'A Mulher no Lago S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a4uoG1kYoMCf8rqPak0hDmcljPC.jpg'),
(152925, 10925, 'A Mulher no Lago S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/437697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a4uoG1kYoMCf8rqPak0hDmcljPC.jpg'),
(152926, 10926, 'Betty A Feia A Historia Continua S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416268.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6bIp20xc2kwy9nV62osNS8OaQsS.jpg'),
(152927, 10926, 'Betty A Feia A Historia Continua S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416269.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gWa0Z5UvjiwZNMdkbaYl9wRUpns.jpg'),
(152928, 10926, 'Betty A Feia A Historia Continua S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/419790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2jGQO9GzHU8qFjWSgENsdQ49Xzi.jpg'),
(152929, 10926, 'Betty A Feia A Historia Continua S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/419791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2jGQO9GzHU8qFjWSgENsdQ49Xzi.jpg'),
(152930, 10926, 'Betty A Feia A Historia Continua S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2jGQO9GzHU8qFjWSgENsdQ49Xzi.jpg'),
(152931, 10926, 'Betty A Feia A Historia Continua S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/425546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2jGQO9GzHU8qFjWSgENsdQ49Xzi.jpg'),
(152932, 10926, 'Betty A Feia A Historia Continua S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/427880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2jGQO9GzHU8qFjWSgENsdQ49Xzi.jpg'),
(152933, 10926, 'Betty A Feia A Historia Continua S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/427881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2jGQO9GzHU8qFjWSgENsdQ49Xzi.jpg'),
(152934, 10926, 'Betty A Feia A Historia Continua S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/435247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2jGQO9GzHU8qFjWSgENsdQ49Xzi.jpg'),
(152935, 10926, 'Betty A Feia A Historia Continua S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/435248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2jGQO9GzHU8qFjWSgENsdQ49Xzi.jpg'),
(152936, 10927, 'Betty A Feia A Historia Continua S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/880603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2jGQO9GzHU8qFjWSgENsdQ49Xzi.jpg'),
(152937, 10927, 'Betty A Feia A Historia Continua S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/880604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2jGQO9GzHU8qFjWSgENsdQ49Xzi.jpg'),
(152938, 10927, 'Betty A Feia A Historia Continua S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/881247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2jGQO9GzHU8qFjWSgENsdQ49Xzi.jpg'),
(152939, 10927, 'Betty A Feia A Historia Continua S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/881248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2jGQO9GzHU8qFjWSgENsdQ49Xzi.jpg'),
(152940, 10927, 'Betty A Feia A Historia Continua S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/881352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2jGQO9GzHU8qFjWSgENsdQ49Xzi.jpg'),
(152941, 10927, 'Betty A Feia A Historia Continua S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/881353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2jGQO9GzHU8qFjWSgENsdQ49Xzi.jpg'),
(152942, 10927, 'Betty A Feia A Historia Continua S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/883034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2jGQO9GzHU8qFjWSgENsdQ49Xzi.jpg'),
(152943, 10927, 'Betty A Feia A Historia Continua S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/883035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2jGQO9GzHU8qFjWSgENsdQ49Xzi.jpg'),
(152944, 10927, 'Betty A Feia A Historia Continua S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/883830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2jGQO9GzHU8qFjWSgENsdQ49Xzi.jpg'),
(152945, 10927, 'Betty A Feia A Historia Continua S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/883831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2jGQO9GzHU8qFjWSgENsdQ49Xzi.jpg'),
(152946, 10928, 'Homem Pipa Ja E S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416266.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2TfsDSFC4FBn2Jhj4FbDE9VaHVt.jpg'),
(152947, 10928, 'Homem Pipa Ja E S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416267.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zxDw4kxTKeksNyfGk2oAJFfw0g0.jpg'),
(152948, 10928, 'Homem Pipa Ja E S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/419506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eKJCBIe99i9LFQPugUrho4FpCAz.jpg'),
(152949, 10928, 'Homem Pipa Ja E S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/421609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eKJCBIe99i9LFQPugUrho4FpCAz.jpg'),
(152950, 10928, 'Homem Pipa Ja E S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/427635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eKJCBIe99i9LFQPugUrho4FpCAz.jpg'),
(152951, 10928, 'Homem Pipa Ja E S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/429685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eKJCBIe99i9LFQPugUrho4FpCAz.jpg'),
(152952, 10928, 'Homem Pipa Ja E S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/436600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eKJCBIe99i9LFQPugUrho4FpCAz.jpg'),
(152953, 10928, 'Homem Pipa Ja E S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/442308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eKJCBIe99i9LFQPugUrho4FpCAz.jpg'),
(152954, 10928, 'Homem Pipa Ja E S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/447826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eKJCBIe99i9LFQPugUrho4FpCAz.jpg'),
(152955, 10928, 'Homem Pipa Ja E S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/452593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eKJCBIe99i9LFQPugUrho4FpCAz.jpg'),
(152956, 10929, 'No Olho da Tempestade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416265.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hWVf4QGg0utjT33qFKvwjFQqP6l.jpg'),
(152957, 10929, 'No Olho da Tempestade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/419447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rfA0TuQztxbFkt5RfS67ilQ4TS.jpg'),
(152958, 10929, 'No Olho da Tempestade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/424560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rfA0TuQztxbFkt5RfS67ilQ4TS.jpg'),
(152959, 10929, 'No Olho da Tempestade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/432078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rfA0TuQztxbFkt5RfS67ilQ4TS.jpg'),
(152960, 10929, 'No Olho da Tempestade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/434506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rfA0TuQztxbFkt5RfS67ilQ4TS.jpg'),
(152961, 10929, 'No Olho da Tempestade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/436045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rfA0TuQztxbFkt5RfS67ilQ4TS.jpg'),
(152962, 10930, 'No Olho da Tempestade S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/878869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rfA0TuQztxbFkt5RfS67ilQ4TS.jpg'),
(152963, 10930, 'No Olho da Tempestade S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/880388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rfA0TuQztxbFkt5RfS67ilQ4TS.jpg'),
(152964, 10930, 'No Olho da Tempestade S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/880389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rfA0TuQztxbFkt5RfS67ilQ4TS.jpg'),
(152965, 10930, 'No Olho da Tempestade S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/881198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rfA0TuQztxbFkt5RfS67ilQ4TS.jpg'),
(152966, 10930, 'No Olho da Tempestade S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/881312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rfA0TuQztxbFkt5RfS67ilQ4TS.jpg'),
(152967, 10930, 'No Olho da Tempestade S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/882205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1rfA0TuQztxbFkt5RfS67ilQ4TS.jpg'),
(152968, 10931, 'The Duke of Death and His Maid S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416229.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tBiA85MyyqkzE4tc0EQC1XsnR2g.jpg'),
(152969, 10931, 'The Duke of Death and His Maid S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416230.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yxre86PZyJAv1Z9FrNwLkHh7MJA.jpg'),
(152970, 10931, 'The Duke of Death and His Maid S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416231.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/akVn9TFlwaLcmfTb7jmNOgfD9T4.jpg'),
(152971, 10931, 'The Duke of Death and His Maid S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416232.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ylpjETqLOLv4VvcylWnRSonBmJK.jpg'),
(152972, 10931, 'The Duke of Death and His Maid S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416233.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vY32YTu7NhUmFUYbgKpM2FV8FRD.jpg'),
(152973, 10931, 'The Duke of Death and His Maid S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416234.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1mMPfzgqswBoLpoXE6s6h2QrmTw.jpg'),
(152974, 10931, 'The Duke of Death and His Maid S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416235.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mtDpeUkAITLzRFGxmC9sBuhKpsl.jpg'),
(152975, 10931, 'The Duke of Death and His Maid S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416236.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4H7QK0AsbBVBX7w5ChuvK8aznK4.jpg'),
(152976, 10931, 'The Duke of Death and His Maid S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416237.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b7FQ1UQajAuARwDFuw1fdrKJnI5.jpg'),
(152977, 10931, 'The Duke of Death and His Maid S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416238.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rYMdxeHs6AOQ18WQZAVhsYkGB6O.jpg'),
(152978, 10931, 'The Duke of Death and His Maid S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416239.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qWryssJHYHQefquWG3D5REgMlZ2.jpg'),
(152979, 10931, 'The Duke of Death and His Maid S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416240.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iUraugIKx7j3tiR2mzxcCpPKK4W.jpg'),
(152980, 10932, 'The Duke of Death and His Maid S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/610500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(152981, 10932, 'The Duke of Death and His Maid S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/610501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(152982, 10932, 'The Duke of Death and His Maid S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(152983, 10932, 'The Duke of Death and His Maid S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(152984, 10932, 'The Duke of Death and His Maid S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(152985, 10932, 'The Duke of Death and His Maid S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(152986, 10932, 'The Duke of Death and His Maid S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(152987, 10932, 'The Duke of Death and His Maid S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(152988, 10932, 'The Duke of Death and His Maid S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(152989, 10932, 'The Duke of Death and His Maid S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(152990, 10932, 'The Duke of Death and His Maid S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(152991, 10932, 'The Duke of Death and His Maid S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(152992, 10933, 'The Duke of Death and His Maid S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(152993, 10933, 'The Duke of Death and His Maid S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(152994, 10933, 'The Duke of Death and His Maid S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(152995, 10933, 'The Duke of Death and His Maid S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(152996, 10933, 'The Duke of Death and His Maid S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(152997, 10933, 'The Duke of Death and His Maid S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(152998, 10933, 'The Duke of Death and His Maid S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(152999, 10933, 'The Duke of Death and His Maid S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(153000, 10933, 'The Duke of Death and His Maid S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(153001, 10933, 'The Duke of Death and His Maid S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(153002, 10933, 'The Duke of Death and His Maid S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(153003, 10933, 'The Duke of Death and His Maid S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l61yXOVHyGhhB8LIxwjawy5Zbxg.jpg'),
(153004, 10934, 'A Outra Oh Hae Young [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/415474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ioFxoqXKkKw9gfTB9EBfdSlXSuU.jpg'),
(153005, 10934, 'A Outra Oh Hae Young [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/415475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kn4OFvEQsmBCiDBjfZHeeyeuhN1.jpg'),
(153006, 10934, 'A Outra Oh Hae Young [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/415476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tFe4uxMT9VPYWpIJq954okcIctA.jpg'),
(153007, 10934, 'A Outra Oh Hae Young [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/415477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qQcyi9N1uw8317HO7sHy9jEIpfF.jpg'),
(153008, 10934, 'A Outra Oh Hae Young [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/415478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63h0elulJi5863dN1n5ytMWsVcq.jpg'),
(153009, 10934, 'A Outra Oh Hae Young [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/415479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A2weGvuiKYQs6DIKGDshAbf87FY.jpg'),
(153010, 10934, 'A Outra Oh Hae Young [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/415480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4CHZJZC0oPj2xayASJ7U1YaYiQp.jpg'),
(153011, 10934, 'A Outra Oh Hae Young [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/415481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mJdps4mQFfoyQJDOnwUJNWx1ywW.jpg'),
(153012, 10934, 'A Outra Oh Hae Young [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/415482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mioz9766yhwBsVWBOEy1Pqbuaaa.jpg'),
(153013, 10934, 'A Outra Oh Hae Young [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/415483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6MBRyXdLNAVV2aznx5tEKWxUJRD.jpg'),
(153014, 10934, 'A Outra Oh Hae Young [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/415484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/622fmpGcqTrUWJXaVmBokyjyAp9.jpg'),
(153015, 10934, 'A Outra Oh Hae Young [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/415485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iZH8kLPe40Fs2VirKCmRxRrtaZ3.jpg'),
(153016, 10934, 'A Outra Oh Hae Young [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/415486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mosVkSMGjmiJPq8gLLxs5yrZ5Ra.jpg'),
(153017, 10934, 'A Outra Oh Hae Young [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/415487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dhjOFEVSxFYkgO7Rh3fBc9v3wJx.jpg'),
(153018, 10934, 'A Outra Oh Hae Young [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/415488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o0tKVcFQmrZLvSw6BVnZtxpcQcp.jpg'),
(153019, 10934, 'A Outra Oh Hae Young [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/415489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjUiIJMQbyUxgCb9iQFZd1sXp3u.jpg'),
(153020, 10934, 'A Outra Oh Hae Young [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/415490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6ugCE6MUUKl3iRNuc1va3FcYZbr.jpg'),
(153021, 10934, 'A Outra Oh Hae Young [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/415491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AtDUyKLxuiDxIyaNhnweUnL59mr.jpg'),
(153022, 10935, 'Medici Mestres de Florenca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/415400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lTVzbEjy5X87b8wC0DIRAiVfLup.jpg'),
(153023, 10935, 'Medici Mestres de Florenca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/415401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ywPUviBvJlNypU2JkOvW5YZTgBH.jpg'),
(153024, 10935, 'Medici Mestres de Florenca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/415402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3vR8maKe7Rg3ioUtZr9M22Ymeoz.jpg'),
(153025, 10935, 'Medici Mestres de Florenca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/415403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ctvboDWC9WY0lS2Vg7OFpD7J9bv.jpg'),
(153026, 10935, 'Medici Mestres de Florenca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/415404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Ah89vYBcrfZzP4heseKPc0DbuP.jpg'),
(153027, 10935, 'Medici Mestres de Florenca S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/415405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gugtuLfI9TiqnPNIZ8VLNbs0d55.jpg'),
(153028, 10935, 'Medici Mestres de Florenca S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/415406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9eKlSrhulmYcgkUiq3X6o1ovM3N.jpg'),
(153029, 10935, 'Medici Mestres de Florenca S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/415407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f9FOu5mlRIj2JXEOR3sqVAaPoBI.jpg'),
(153030, 10936, 'Medici Mestres de Florenca S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/415408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rTnGvUfdpMeHMU78GwKkctHhu11.jpg'),
(153031, 10936, 'Medici Mestres de Florenca S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/415409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8wVLhvC9ZI7kzyj54dIHTXK7LlJ.jpg'),
(153032, 10936, 'Medici Mestres de Florenca S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/415410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bVrgpN2rcmvoIjawd0Y5pBxjknN.jpg'),
(153033, 10936, 'Medici Mestres de Florenca S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/415411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k6qBg7DeJfMVfSCYKCnncxmhfkE.jpg'),
(153034, 10936, 'Medici Mestres de Florenca S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/415412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h7Bhq4iOaGhENMWgSjcsmRyKhva.jpg'),
(153035, 10936, 'Medici Mestres de Florenca S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/415413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vJ6LJl2bdsy30wtjRrq2N1O2cI1.jpg'),
(153036, 10936, 'Medici Mestres de Florenca S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/415414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9ZLFJDUchZLd0RuBlQ798GYGfol.jpg'),
(153037, 10936, 'Medici Mestres de Florenca S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/415415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/klESpoMoDPCv9pzGy3Za9c7Xy51.jpg'),
(153038, 10937, 'Rizzoli e Isles S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/415324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g1Vsx8iEKxVk6JfxVQEqtPYahqh.jpg'),
(153039, 10937, 'Rizzoli e Isles S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/415325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m0IaEry55iCLPJKEJfxSe63JGwC.jpg'),
(153040, 10937, 'Rizzoli e Isles S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/415326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8M9HuYNqh2VZuzHpwwqTchdBukO.jpg'),
(153041, 10937, 'Rizzoli e Isles S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/415327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bTnJRc0VARSeYeyaga1rrRLgdB1.jpg'),
(153042, 10937, 'Rizzoli e Isles S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/415328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tQTJJei3hpkyNdwzNghnvsBJGAn.jpg'),
(153043, 10937, 'Rizzoli e Isles S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/415329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oV67PKs7cK6nI7QOCxTugsuyd7Q.jpg'),
(153044, 10937, 'Rizzoli e Isles S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/415330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pZgajYfD7WlOZWr62GbAwnrkkn2.jpg'),
(153045, 10937, 'Rizzoli e Isles S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/415331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/noA9G9BsSOkvgm04tslItxUD1FT.jpg'),
(153046, 10937, 'Rizzoli e Isles S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/415332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nQ7GhhGL3yPLjTBC7KMurk5CJi9.jpg'),
(153047, 10937, 'Rizzoli e Isles S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/415333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z00qnlnYnRuWRRT2ZXjIDbjmS7P.jpg'),
(153048, 10938, 'Rizzoli e Isles S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/415334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nvilv0ZDZ0Kj7XFGRl5zmOzAH74.jpg'),
(153049, 10938, 'Rizzoli e Isles S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/415335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1QaN7J0zANUxfT0khGMy2KqfSDy.jpg'),
(153050, 10938, 'Rizzoli e Isles S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/415336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oKEHDXyP1TtfqmG6IgeyZGKw3UL.jpg'),
(153051, 10938, 'Rizzoli e Isles S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/415337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o6HPHLzwHSGkuCK8QdaWvYjFqkp.jpg'),
(153052, 10938, 'Rizzoli e Isles S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/415338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rzrEHeAysJkjK0mWJ7A1BGSZ6uI.jpg'),
(153053, 10938, 'Rizzoli e Isles S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/415339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sl3fXZNq2sFtEbiZUAGWk0zk4zI.jpg'),
(153054, 10938, 'Rizzoli e Isles S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/415340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mz5XDQ8ghwbAwhMzhsExIzVT5Zd.jpg'),
(153055, 10938, 'Rizzoli e Isles S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/415341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dWO1japuoqtpjyY97zuRGepneD8.jpg'),
(153056, 10938, 'Rizzoli e Isles S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/415342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2gJE1laBbW1jCzBLQ367RVQNpus.jpg'),
(153057, 10938, 'Rizzoli e Isles S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/415343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7TEu3TAKFVr3sBLxe6halznV1mS.jpg'),
(153058, 10938, 'Rizzoli e Isles S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/415344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4DXHtGo9VEYHU3gOpABcDEAZusx.jpg'),
(153059, 10938, 'Rizzoli e Isles S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/415345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4yDd46fLSydbB2D4r2mrx7m7eJL.jpg'),
(153060, 10938, 'Rizzoli e Isles S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/415346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Qyz1mfqai7RcIxqPkrOOpfHlAS.jpg'),
(153061, 10938, 'Rizzoli e Isles S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/415347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A4IYiGK0mcEwYhdPg453R7XuSIV.jpg'),
(153062, 10938, 'Rizzoli e Isles S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/415348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rjSfnxDGwSxP5AEQJ3xpukrzMDr.jpg'),
(153063, 10939, 'Rizzoli e Isles S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/415349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4S9g3ncprJZZhWnrKxs5sEiblny.jpg'),
(153064, 10939, 'Rizzoli e Isles S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/415350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s9a8IlPcfdVWSZURXoQgH2SFv8x.jpg'),
(153065, 10939, 'Rizzoli e Isles S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/415351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hc7SvClrvHzPGAEv395CL7vXbq.jpg'),
(153066, 10939, 'Rizzoli e Isles S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/415352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hcAbHvs9nRCo98TCmlKpmqAzrQG.jpg'),
(153067, 10939, 'Rizzoli e Isles S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/415353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Y9RUqd0wbEoGZtS9kpcVuofw23.jpg'),
(153068, 10939, 'Rizzoli e Isles S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/415354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h2DR1KlGzpGC0FMJ40NV7uGtokA.jpg'),
(153069, 10939, 'Rizzoli e Isles S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/415355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Mr3UQ0hUL0dVJg8cj1ZlVT3Tuy.jpg'),
(153070, 10939, 'Rizzoli e Isles S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/415356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/maSub9Y5bALGi0FybSXh8BkDnbu.jpg'),
(153071, 10939, 'Rizzoli e Isles S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/415357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fxGKB3NNU66EUMco5ImdfEIpXYK.jpg'),
(153072, 10939, 'Rizzoli e Isles S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/415358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wqq12wF1L7CEXyihlXVpLsqpzSV.jpg'),
(153073, 10939, 'Rizzoli e Isles S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/415359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ylzLdVubuhUjZzyVeZKNsy4K7G1.jpg'),
(153074, 10939, 'Rizzoli e Isles S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/415360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zNlyOeopBgGyOuwSUp695DpwXc8.jpg'),
(153075, 10939, 'Rizzoli e Isles S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/415361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rRaZD5qP9n4gk4Pm7M9eUE8r61n.jpg'),
(153076, 10939, 'Rizzoli e Isles S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/415362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6dz7sVvq1JESKowxuSHtoeHupK7.jpg'),
(153077, 10939, 'Rizzoli e Isles S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/415363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6Cl3caKkpBMdpIiAEeilKr0JgUa.jpg'),
(153078, 10940, 'Alya Sometimes Hides Her Feelings in Russian [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416988.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aPFDRHyrQnZ4a4mSBrvtLauNDCs.jpg'),
(153079, 10940, 'Alya Sometimes Hides Her Feelings in Russian [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416989.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tUZUQ2lqoey7ePWjDSJnLVuPVO1.jpg'),
(153080, 10940, 'Alya Sometimes Hides Her Feelings in Russian [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416990.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j2My7TsaKigxYRsZzVTsJjEaY8n.jpg'),
(153081, 10940, 'Alya Sometimes Hides Her Feelings in Russian [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416991.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z2DTZ4fajSP2TzEQrvZJC8IeUs7.jpg'),
(153082, 10940, 'Alya Sometimes Hides Her Feelings in Russian [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/422397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvphQkTzkMyeJ1E7YmLDc8nc7SS.jpg'),
(153083, 10940, 'Alya Sometimes Hides Her Feelings in Russian [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/427994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvphQkTzkMyeJ1E7YmLDc8nc7SS.jpg'),
(153084, 10940, 'Alya Sometimes Hides Her Feelings in Russian [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/429973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvphQkTzkMyeJ1E7YmLDc8nc7SS.jpg'),
(153085, 10940, 'Alya Sometimes Hides Her Feelings in Russian [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/437641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvphQkTzkMyeJ1E7YmLDc8nc7SS.jpg'),
(153086, 10940, 'Alya Sometimes Hides Her Feelings in Russian [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/442958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvphQkTzkMyeJ1E7YmLDc8nc7SS.jpg'),
(153087, 10940, 'Alya Sometimes Hides Her Feelings in Russian [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/448812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvphQkTzkMyeJ1E7YmLDc8nc7SS.jpg'),
(153088, 10940, 'Alya Sometimes Hides Her Feelings in Russian [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/452922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvphQkTzkMyeJ1E7YmLDc8nc7SS.jpg'),
(153089, 10940, 'Alya Sometimes Hides Her Feelings in Russian [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/462026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mvphQkTzkMyeJ1E7YmLDc8nc7SS.jpg'),
(153090, 10941, 'Arcana Famiglia [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416975.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9nutRIMHv4MarUW61fq6vseYQIW.jpg'),
(153091, 10941, 'Arcana Famiglia [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416976.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/55xdBpiz5o3NrupkF6Zzbl5lVFu.jpg'),
(153092, 10941, 'Arcana Famiglia [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416977.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/25ZO4NcuBaTf0PK5jwbsLdKcmTI.jpg'),
(153093, 10941, 'Arcana Famiglia [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416978.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hU651TjFBbQsPbqXMf9oQeHCtE6.jpg'),
(153094, 10941, 'Arcana Famiglia [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416979.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/quiJ4HNpzWlX2O3SRxuvPzGnXpy.jpg'),
(153095, 10941, 'Arcana Famiglia [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416980.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fJjpc9QGsb57TbKzF77EZ70KZpu.jpg'),
(153096, 10941, 'Arcana Famiglia [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416981.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yiumNvZGE7NDASC3YqUt3XqyXNy.jpg'),
(153097, 10941, 'Arcana Famiglia [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416982.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/esEcr1dpH7JmxwJzNrLLqOizeLx.jpg'),
(153098, 10941, 'Arcana Famiglia [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416983.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1xUSA0r3Am0fHqGRFyEvC8CaQjt.jpg'),
(153099, 10941, 'Arcana Famiglia [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416984.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uRuez3LmNHqS2DMco8k6yP8IXeO.jpg'),
(153100, 10941, 'Arcana Famiglia [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416985.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hBuMBPzahetSlT5UzdgVRCkjGIF.jpg'),
(153101, 10941, 'Arcana Famiglia [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416986.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s1EKJfDuG1NAVcgEu62yT7ebn3X.jpg'),
(153102, 10941, 'Arcana Famiglia [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/416987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iJQv5pcYzZYfguY8YyV5rlvMBoE.jpg'),
(153103, 10942, 'Bastidores do Pop O Esquema das Boy Bands S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416972.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfkEj0tkKMw9bT7mqcPXf1jlu7F.jpg'),
(153104, 10942, 'Bastidores do Pop O Esquema das Boy Bands S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416973.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/14dtPMh5OKyCAymXAsvmb0OaobU.jpg'),
(153105, 10942, 'Bastidores do Pop O Esquema das Boy Bands S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416974.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hB50NPodhdwMpryQs8C41HiX5cJ.jpg'),
(153106, 10943, 'Blackshore [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416971.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/azVbhVCOuXJWgBxTuQcrbpAJ663.jpg'),
(153107, 10943, 'Blackshore [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9iGqOX3CiSm0s6udKiTd09R3li5.jpg'),
(153108, 10943, 'Blackshore [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9iGqOX3CiSm0s6udKiTd09R3li5.jpg'),
(153109, 10943, 'Blackshore [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/429881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9iGqOX3CiSm0s6udKiTd09R3li5.jpg'),
(153110, 10943, 'Blackshore [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/437518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9iGqOX3CiSm0s6udKiTd09R3li5.jpg'),
(153111, 10943, 'Blackshore [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/437519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9iGqOX3CiSm0s6udKiTd09R3li5.jpg'),
(153112, 10944, 'Bom Parceiro [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416967.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/u4DsDkovKJgclzs4MDT9KObHJdI.jpg'),
(153113, 10944, 'Bom Parceiro [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416968.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/50ZL6qRD7IyF9jcmCbWpfDeZmaX.jpg'),
(153114, 10944, 'Bom Parceiro [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416969.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/NBxoRiYYjVMMfEXqP9vLkLByIg.jpg'),
(153115, 10944, 'Bom Parceiro [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416970.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z18CQEbYfFKBDV3Vn8yfvY2OVWu.jpg'),
(153116, 10944, 'Bom Parceiro [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g9kgACUpBMOWlzzA2MZ9Zd1Cdx3.jpg'),
(153117, 10944, 'Bom Parceiro [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/437209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g9kgACUpBMOWlzzA2MZ9Zd1Cdx3.jpg'),
(153118, 10944, 'Bom Parceiro [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/437210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g9kgACUpBMOWlzzA2MZ9Zd1Cdx3.jpg'),
(153119, 10944, 'Bom Parceiro [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/437211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g9kgACUpBMOWlzzA2MZ9Zd1Cdx3.jpg'),
(153120, 10944, 'Bom Parceiro [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/442813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g9kgACUpBMOWlzzA2MZ9Zd1Cdx3.jpg'),
(153121, 10944, 'Bom Parceiro [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/448374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g9kgACUpBMOWlzzA2MZ9Zd1Cdx3.jpg'),
(153122, 10944, 'Bom Parceiro [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/448375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g9kgACUpBMOWlzzA2MZ9Zd1Cdx3.jpg'),
(153123, 10944, 'Bom Parceiro [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/448376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g9kgACUpBMOWlzzA2MZ9Zd1Cdx3.jpg'),
(153124, 10944, 'Bom Parceiro [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/448377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g9kgACUpBMOWlzzA2MZ9Zd1Cdx3.jpg'),
(153125, 10944, 'Bom Parceiro [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/456398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g9kgACUpBMOWlzzA2MZ9Zd1Cdx3.jpg'),
(153126, 10944, 'Bom Parceiro [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/461672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g9kgACUpBMOWlzzA2MZ9Zd1Cdx3.jpg'),
(153127, 10944, 'Bom Parceiro [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/461673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g9kgACUpBMOWlzzA2MZ9Zd1Cdx3.jpg'),
(153128, 10945, 'Boogiepop wa Warawanai [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416955.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cCrEMHOrK3Lzd8RimuhVRLxJSjE.jpg'),
(153129, 10945, 'Boogiepop wa Warawanai [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416956.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9hef7qIb47nn9nUFtvXzrbXMs1s.jpg'),
(153130, 10945, 'Boogiepop wa Warawanai [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416957.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6DTnIEkT8c76saO6cbWS7llrUNS.jpg'),
(153131, 10945, 'Boogiepop wa Warawanai [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416958.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bIq4uNy3MbRLPO2UssR61toNUqS.jpg'),
(153132, 10945, 'Boogiepop wa Warawanai [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416959.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y34Wlsa5O6RLd7Qty2RX00syXxH.jpg'),
(153133, 10945, 'Boogiepop wa Warawanai [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416960.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uUryw5Ns7BXK5LpvBseAug783Ut.jpg'),
(153134, 10945, 'Boogiepop wa Warawanai [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416961.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6VyIPUlafPPVc84JMWsrJ4Wdnd3.jpg'),
(153135, 10945, 'Boogiepop wa Warawanai [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416962.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ibGaiJyx3CGcAuzafP1lXCO2tAr.jpg'),
(153136, 10945, 'Boogiepop wa Warawanai [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416963.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nadEIRTUeZeBBaAjWBtfWO8EMs3.jpg'),
(153137, 10945, 'Boogiepop wa Warawanai [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416964.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jI5yA1pxayTd0WOyZ9KY7VMEwoh.jpg'),
(153138, 10945, 'Boogiepop wa Warawanai [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416965.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AgMmDnN5kVVRNSYG6mVEDjzQiYV.jpg'),
(153139, 10945, 'Boogiepop wa Warawanai [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416966.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a6Bst9TOvdM9N4bW41rkjeMoQO9.jpg'),
(153140, 10946, 'Bye Bye Earth [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416953.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nRDieEUVvFc0TYY2L9c06xXa8nb.jpg'),
(153141, 10946, 'Bye Bye Earth [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416954.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mTEUUiNnc9PYRYJgKg9itaLQjb0.jpg'),
(153142, 10946, 'Bye Bye Earth [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPFow4Aw7Rq6n5qfpFUhZF3UKdl.jpg'),
(153143, 10946, 'Bye Bye Earth [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPFow4Aw7Rq6n5qfpFUhZF3UKdl.jpg'),
(153144, 10946, 'Bye Bye Earth [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/427873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPFow4Aw7Rq6n5qfpFUhZF3UKdl.jpg'),
(153145, 10946, 'Bye Bye Earth [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPFow4Aw7Rq6n5qfpFUhZF3UKdl.jpg'),
(153146, 10946, 'Bye Bye Earth [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/437203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPFow4Aw7Rq6n5qfpFUhZF3UKdl.jpg'),
(153147, 10946, 'Bye Bye Earth [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/442804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPFow4Aw7Rq6n5qfpFUhZF3UKdl.jpg'),
(153148, 10946, 'Bye Bye Earth [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/448344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPFow4Aw7Rq6n5qfpFUhZF3UKdl.jpg'),
(153149, 10946, 'Bye Bye Earth [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/456384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPFow4Aw7Rq6n5qfpFUhZF3UKdl.jpg'),
(153150, 10947, 'Bye Bye Earth [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/761163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPFow4Aw7Rq6n5qfpFUhZF3UKdl.jpg'),
(153151, 10947, 'Bye Bye Earth [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/768508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPFow4Aw7Rq6n5qfpFUhZF3UKdl.jpg'),
(153152, 10947, 'Bye Bye Earth [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/776996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPFow4Aw7Rq6n5qfpFUhZF3UKdl.jpg'),
(153153, 10947, 'Bye Bye Earth [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/778289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPFow4Aw7Rq6n5qfpFUhZF3UKdl.jpg'),
(153154, 10947, 'Bye Bye Earth [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/793070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPFow4Aw7Rq6n5qfpFUhZF3UKdl.jpg'),
(153155, 10947, 'Bye Bye Earth [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/795586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPFow4Aw7Rq6n5qfpFUhZF3UKdl.jpg'),
(153156, 10947, 'Bye Bye Earth [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/799609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPFow4Aw7Rq6n5qfpFUhZF3UKdl.jpg'),
(153157, 10947, 'Bye Bye Earth [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/808530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPFow4Aw7Rq6n5qfpFUhZF3UKdl.jpg'),
(153158, 10947, 'Bye Bye Earth [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/820032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPFow4Aw7Rq6n5qfpFUhZF3UKdl.jpg'),
(153159, 10947, 'Bye Bye Earth [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/826731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPFow4Aw7Rq6n5qfpFUhZF3UKdl.jpg'),
(153160, 10948, 'C The Money of Soul and Possibility Control [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416942.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4uhJJqbWe4t2JEtZfNRYVr9dXQD.jpg'),
(153161, 10948, 'C The Money of Soul and Possibility Control [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416943.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kfAUpZlCOUcqYlD0fUeeIE2QwBZ.jpg'),
(153162, 10948, 'C The Money of Soul and Possibility Control [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416944.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2a4EZlZK5csqcZg9C1kDn0D9Y9u.jpg'),
(153163, 10948, 'C The Money of Soul and Possibility Control [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416945.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3yuVMYuTCCXIR3XmDh5i3rRgb0p.jpg'),
(153164, 10948, 'C The Money of Soul and Possibility Control [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416946.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3kgvRq2i9BmIxJCmgld5YPNrxj.jpg'),
(153165, 10948, 'C The Money of Soul and Possibility Control [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416947.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g7W9PG0vMa4l2iPKdROhjmHcLem.jpg'),
(153166, 10948, 'C The Money of Soul and Possibility Control [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416948.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m1UWvxzxNdvwWQ44Sh89wmA5HFS.jpg'),
(153167, 10948, 'C The Money of Soul and Possibility Control [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416949.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AohI1yhBgcGCQyYS0HOEaasg4AJ.jpg'),
(153168, 10948, 'C The Money of Soul and Possibility Control [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416950.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kzNaAWwdYihr0PpScVGW7xXlxyp.jpg'),
(153169, 10948, 'C The Money of Soul and Possibility Control [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416951.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pF1FUbzfngg2Ffe5MZ4Qtw9BApW.jpg'),
(153170, 10948, 'C The Money of Soul and Possibility Control [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416952.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3dl6JqG15Dxx3TZemKDueHtrTg0.jpg'),
(153171, 10949, 'Chamadas Criminosas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416926.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2NlRAHqpVVSVrI7s8V6Km71BEyr.jpg'),
(153172, 10949, 'Chamadas Criminosas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416927.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2EalG8hOS49gcVfH51uLvp2wbD8.jpg'),
(153173, 10949, 'Chamadas Criminosas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416928.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ge4gMNEmZz7YG6paoaPZDxD23Ad.jpg'),
(153174, 10949, 'Chamadas Criminosas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416929.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cv5ZhSE8BHWHJMCrApCTRedaufr.jpg'),
(153175, 10949, 'Chamadas Criminosas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416930.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mRh3m5M9whhhE0km3VwE2K3ur8n.jpg'),
(153176, 10949, 'Chamadas Criminosas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416931.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gXZ9fOGy3xYE8AxqbsTjC3MeZIe.jpg'),
(153177, 10950, 'Chamadas Criminosas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416932.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g6nzjtd354ButjuG9R5wz03eKHL.jpg'),
(153178, 10950, 'Chamadas Criminosas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416933.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zF2Yx50SftmHZaiCGwaiKVAzMmV.jpg'),
(153179, 10950, 'Chamadas Criminosas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416934.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udYdnIzxp36AMjc8qQg9lYp8RVw.jpg'),
(153180, 10950, 'Chamadas Criminosas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416935.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m3A0dFiJgdkfTyhH9RU76i3qPox.jpg'),
(153181, 10950, 'Chamadas Criminosas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416936.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kfT0u0AdFy7wGuoC3UzmUV5n92D.jpg'),
(153182, 10950, 'Chamadas Criminosas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416937.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1WyzczxbQdsprmiWU2Gp7unnMU2.jpg'),
(153183, 10950, 'Chamadas Criminosas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416938.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8vpVTB3jWp6BqTG5Ol142r5lHKk.jpg'),
(153184, 10950, 'Chamadas Criminosas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416939.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ktTBMAnyG98RvCKJxXPJxhJSdlh.jpg'),
(153185, 10950, 'Chamadas Criminosas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416940.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUAOqzRM8borhAzTBMNpEfoJDH6.jpg'),
(153186, 10950, 'Chamadas Criminosas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416941.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7IoaPfRLfXBcMLRlRxiajUij1Mx.jpg'),
(153187, 10951, 'Decameron S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416918.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3LBBmEet7SikrnskQTQkFgEKK0T.jpg'),
(153188, 10951, 'Decameron S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416919.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jKWbdFQJNQr1kHXSSahTNIMqLU5.jpg'),
(153189, 10951, 'Decameron S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416920.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gZBySw43OMm7IZRQKw86bq29FL8.jpg'),
(153190, 10951, 'Decameron S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416921.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l8DA7VzN4zoS8t9kgsjWc2qI7eX.jpg'),
(153191, 10951, 'Decameron S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416922.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mJvpJgswMYo1hAgHKhwjz4XvTjU.jpg'),
(153192, 10951, 'Decameron S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416923.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSfE3zaQv1YOoBHKY0PFecXm6MP.jpg'),
(153193, 10951, 'Decameron S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416924.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iAhrV9mrRlc4IVoqx0zqiG86P7q.jpg'),
(153194, 10951, 'Decameron S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416925.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pcsF2zcpMvLL9KzmIjPMNxbK7pD.jpg'),
(153195, 10952, 'Destrancados Um Experimento na Prisao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416910.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kUaYTQIP6VLBaIg6kOZm4JkFmo0.jpg'),
(153196, 10952, 'Destrancados Um Experimento na Prisao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416911.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/TSTqFPSeps7wLxktogdk0SI99X.jpg'),
(153197, 10952, 'Destrancados Um Experimento na Prisao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416912.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dYfZwozcf8sKA6wqxMMKzEDdZEg.jpg'),
(153198, 10952, 'Destrancados Um Experimento na Prisao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416913.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hsILrRCgNvrqTWwShGYgrGmgPYE.jpg'),
(153199, 10952, 'Destrancados Um Experimento na Prisao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416914.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bueiC3AfhBpFSuHHWlAfQawOMTs.jpg'),
(153200, 10952, 'Destrancados Um Experimento na Prisao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416915.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nDH1tedqkEABUoeJQScRxFTxTdW.jpg'),
(153201, 10952, 'Destrancados Um Experimento na Prisao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416916.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2SfsWGXOaPaLBEqN4sclY89182H.jpg'),
(153202, 10952, 'Destrancados Um Experimento na Prisao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416917.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vf1AgjdaI6HuZwVlomgtAbbVQka.jpg'),
(153203, 10953, 'Exposure [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416908.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hNIVXNoxRUdLZfZWCRCCeq6qix4.jpg'),
(153204, 10953, 'Exposure [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416909.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k1qpCbnIVK831Vq09KxoLryiLt7.jpg'),
(153205, 10953, 'Exposure [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zCrRrSv17o9dAbbEp7VrsoHosU0.jpg'),
(153206, 10953, 'Exposure [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zCrRrSv17o9dAbbEp7VrsoHosU0.jpg'),
(153207, 10953, 'Exposure [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zCrRrSv17o9dAbbEp7VrsoHosU0.jpg'),
(153208, 10953, 'Exposure [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/425141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zCrRrSv17o9dAbbEp7VrsoHosU0.jpg'),
(153209, 6300, 'Fairy Tail S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416836.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dmbMIxPQlS5cuygg8iOrvkPvxwb.jpg'),
(153210, 6300, 'Fairy Tail S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416837.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AdhPfHZfHEENQm4SUbDT9r5BVzs.jpg'),
(153211, 6300, 'Fairy Tail S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416838.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/foRfxEmOkrz5OwzbqOse3u5Vmgp.jpg'),
(153212, 6300, 'Fairy Tail S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416839.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2gJ3ldgVB1SzkBr85w6pGuAfptb.jpg'),
(153213, 6300, 'Fairy Tail S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416840.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sOyKpmujFvvzrQoCm0kr0uyrJNT.jpg'),
(153214, 6300, 'Fairy Tail S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416841.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ON4IUnVogii7ai3edsU1xOqu1W.jpg'),
(153215, 6300, 'Fairy Tail S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416842.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uD8wwQFwTIG3jy91xsPN1kK59vl.jpg'),
(153216, 6300, 'Fairy Tail S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a2T2OfQNyRVS7vc0KtnRD6Uivqr.jpg'),
(153217, 6300, 'Fairy Tail S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r6VBb4Duq4MGFnIoMcuCe4fakGj.jpg'),
(153218, 6300, 'Fairy Tail S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/geCQeZBgREuExO32RBnLBYW8ARb.jpg'),
(153219, 6300, 'Fairy Tail S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tS9ZIyJyDnx5krTY2EvaXP181zd.jpg'),
(153220, 6300, 'Fairy Tail S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yPEiw6M6KQc0OXxDmJ1X4epnkLf.jpg'),
(153221, 6300, 'Fairy Tail S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/416848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pDoy0257DumqXXdd5Dm4k2GKJ53.jpg'),
(153222, 6300, 'Fairy Tail S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/416849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/A0uIF9ToDq0ngstnYZ8yCqQwqcH.jpg'),
(153223, 6300, 'Fairy Tail S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/416850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l7uHFrEk5ysCEjNY4mEeumAhyu3.jpg'),
(153224, 6300, 'Fairy Tail S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/416851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xpBgjaOFGjQDmFZK0H8a5H15wu6.jpg'),
(153225, 6300, 'Fairy Tail S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/416852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7n6xsE50A5MJI8TjXUHo7hmeeU3.jpg'),
(153226, 6300, 'Fairy Tail S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/416853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgV8dTELtNrtavHYR4Z35qGcl40.jpg'),
(153227, 6300, 'Fairy Tail S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/416854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tSlBiKZEWkD0lrJATLV0gbu7jT7.jpg'),
(153228, 6300, 'Fairy Tail S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/416855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2oKSafrZMzO13nB0DFxxQ5isSsx.jpg'),
(153229, 6300, 'Fairy Tail S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/416856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sY2nqBiGvnF8sxSWXg38m1bpDVk.jpg'),
(153230, 6300, 'Fairy Tail S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/416857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5aqce0N9trkR3dGbIfx0jN21r4.jpg'),
(153231, 6300, 'Fairy Tail S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/416858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jBV0LcVXRKgIRfnXMhJs3zIvElG.jpg'),
(153232, 6300, 'Fairy Tail S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/416859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e7BYqIN1Bt22yZRfiQk5JYQPGya.jpg'),
(153233, 6300, 'Fairy Tail S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/416860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pummDYEkVqRUsIv6gsAizkh9bQU.jpg'),
(153234, 6300, 'Fairy Tail S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/416861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z1shbfqkrPc3sd3Bh5191UfI92h.jpg'),
(153235, 6300, 'Fairy Tail S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/416862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tuk7K1tdnon6MZygrrKeNPq9oFq.jpg'),
(153236, 6300, 'Fairy Tail S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/416863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m0egXO8mfFlxdxS6gNoQ7jVrJ5F.jpg'),
(153237, 6300, 'Fairy Tail S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/416864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7eiBabEV0f2dfKjvGTRA9dPAm1D.jpg'),
(153238, 6300, 'Fairy Tail S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/416865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnmMvLgjFBQRmcUQAAkyMm3uJas.jpg'),
(153239, 6300, 'Fairy Tail S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/416866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kAsUd5t2dXxDwzmrP0xlGRskuJT.jpg'),
(153240, 6300, 'Fairy Tail S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/416867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/98usArEo4pLXBhzC1nYSq7rm9YO.jpg'),
(153241, 6300, 'Fairy Tail S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/416868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v497XnhRuzQUbkoKUDD2G4dlLRl.jpg'),
(153242, 6300, 'Fairy Tail S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/416869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wuy1DGScgPmcRnGcfICRUuUVcA1.jpg'),
(153243, 6300, 'Fairy Tail S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/416870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2dQFIuqBLtD9hQtaHM5Ofee27qk.jpg'),
(153244, 6300, 'Fairy Tail S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/416871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eRN0iu6CnQoupDRIe5Dfo28tfnF.jpg'),
(153245, 6300, 'Fairy Tail S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/416872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bqISrL8nhb7sJNxWyGHiq8dJRgt.jpg'),
(153246, 6300, 'Fairy Tail S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/416873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZeqK7HVQkhiRP3K6JZZVq6NgW3.jpg'),
(153247, 6300, 'Fairy Tail S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/416874.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8tsNAgxTFAKtKHqctJSb4PN5Sf8.jpg'),
(153248, 6300, 'Fairy Tail S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/416875.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oxHTvY0lsL46fRBUJmNh2qusEIP.jpg'),
(153249, 6300, 'Fairy Tail S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/416876.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hi6u3i48MdDxsQSmXHUmuH8lPkc.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(153250, 6300, 'Fairy Tail S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/416877.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/prvtUQ2UmkPmIqJ60VaPNXACm57.jpg'),
(153251, 6300, 'Fairy Tail S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/416878.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zpmtzzEyzxSeKvf2hwyALgTlTWH.jpg'),
(153252, 6300, 'Fairy Tail S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/416879.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vlZjrVsyoWxe7uloAYTVt9Pkwiz.jpg'),
(153253, 6300, 'Fairy Tail S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/416880.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OvfoJ0Gqe3Z7xJuFZd9xiLmR3Y.jpg'),
(153254, 6300, 'Fairy Tail S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/416881.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xpfAv4fAln6OMFDPuAFyGUPrQQJ.jpg'),
(153255, 6300, 'Fairy Tail S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/416882.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g9FC0cdcr7jQMq4RAPv6k5nDNZH.jpg'),
(153256, 6300, 'Fairy Tail S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/416883.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2IZrRonTcv81d0mct1Shkek9cSd.jpg'),
(153257, 6301, 'Fairy Tail S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416884.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jsSiiO4E0o9FGCD2asSiKTAFZbl.jpg'),
(153258, 6301, 'Fairy Tail S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416885.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nwPXawwpslyK0IrAkVaMglTJ7QG.jpg'),
(153259, 6301, 'Fairy Tail S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416886.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nYjVLnga32ijGoxGPtn8woW2WxF.jpg'),
(153260, 6301, 'Fairy Tail S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416887.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m4fM3Gf9FUMbEMjQ4AUgkGVIitn.jpg'),
(153261, 6301, 'Fairy Tail S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416888.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oxuZMfOYjpRGHTG7w1qvSJAfMQ5.jpg'),
(153262, 6301, 'Fairy Tail S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416889.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mUfQH5YeNXJfY0CMpe1QbEmY7d6.jpg'),
(153263, 6301, 'Fairy Tail S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416890.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kmyTIIuOJuGgLR4vACLOJXKqwGx.jpg'),
(153264, 6301, 'Fairy Tail S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416891.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1AW1dBo6DpVmIWunGF58GY1xwJd.jpg'),
(153265, 6301, 'Fairy Tail S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416892.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oSNk4pCttqXhvxDypouUvYLNcLQ.jpg'),
(153266, 6301, 'Fairy Tail S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416893.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kN4CP0r3SjH0fIu8ohIzLVFNwf1.jpg'),
(153267, 6301, 'Fairy Tail S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416894.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zW94EVzmWAmkZmcNajbaeIHzcf.jpg'),
(153268, 6301, 'Fairy Tail S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416895.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Aj2JlqUz39z7p0CgQ2ji6Qp9MOO.jpg'),
(153269, 6301, 'Fairy Tail S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/416896.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4hIAFeL6Xx3Yd7ETxZp1yLUUk1F.jpg'),
(153270, 6301, 'Fairy Tail S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/416897.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fSy08zf74dZeIUTZBI0Yrr0XgOQ.jpg'),
(153271, 6301, 'Fairy Tail S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/416898.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/weaKOIz8o4pCHmyZjlxpEi73VxJ.jpg'),
(153272, 6301, 'Fairy Tail S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/416899.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bSdj29MDeFzuarMt8No9DvhA69m.jpg'),
(153273, 6301, 'Fairy Tail S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/416900.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/otkjMuKWSZIDJwnJJVsXtukaZYx.jpg'),
(153274, 6301, 'Fairy Tail S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/416901.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jdmCCYTbZZdQ7pXwlsswGGVJLRe.jpg'),
(153275, 6301, 'Fairy Tail S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/416902.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oRvOEi2UOcBBEbaDqA9d1hizTuz.jpg'),
(153276, 6301, 'Fairy Tail S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/416903.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wFiKhbrTFkNhpLnHTDzX6KRfFww.jpg'),
(153277, 6301, 'Fairy Tail S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/416904.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2tLFITcXetDdVQj9WZGukrfKt1a.jpg'),
(153278, 6301, 'Fairy Tail S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/416905.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yRrmRX1mKENsvT695Ci0DoTVfj1.jpg'),
(153279, 6301, 'Fairy Tail S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/416906.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1XSD1eT20dYTyeSLsbIwEphlhSl.jpg'),
(153280, 6301, 'Fairy Tail S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/416907.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sMxbxvL1RTki0Y1tVudRzIQKNI0.jpg'),
(153281, 10954, 'Garavito O Monstro Serial S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416832.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r1INtIald4V7qcXWqOdvSoBYVbu.jpg'),
(153282, 10954, 'Garavito O Monstro Serial S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416833.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ShpQI9WrGUwgQNowyyhXwAbPre.jpg'),
(153283, 10954, 'Garavito O Monstro Serial S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416834.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/78dRumvBe63ufvDQnLdQdPWv0W1.jpg'),
(153284, 10954, 'Garavito O Monstro Serial S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416835.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7zI93vZstqeN1ka0kJA2WFxMCVQ.jpg'),
(153285, 10955, 'Impastor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416822.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1aL8Z5a9M5vYhOQ6zbnYPla0oel.jpg'),
(153286, 10955, 'Impastor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416823.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uR9zzhWhbhMnsl8T4aB74YySkIV.jpg'),
(153287, 10955, 'Impastor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416824.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/orhhZTWhvBNQ6bfRaloDjuLXjSc.jpg'),
(153288, 10955, 'Impastor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416825.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2ndWyaT1uJbDKehtGLkmfT8RyMu.jpg'),
(153289, 10955, 'Impastor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416826.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6cDWjWbNHj2LNmg2KH9JgUSX8qg.jpg'),
(153290, 10955, 'Impastor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416827.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7zMJtc0l4lFNkbsTa37K5ERcr44.jpg'),
(153291, 10955, 'Impastor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416828.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/opG2zvMgyvLkwEOjBoQ7u36ESzu.jpg'),
(153292, 10955, 'Impastor [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416829.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fkpq8n7AfXFFQh4bXjem25Xp2Ai.jpg'),
(153293, 10955, 'Impastor [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416830.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AkWRDuMdNIQY065kfAt9GjG9x3N.jpg'),
(153294, 10955, 'Impastor [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416831.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4n0TtxKyNYKOUiRADQQ2V837lDd.jpg'),
(153295, 10956, 'Liga do Fogao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416806.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oxuZ3kGoYml8zRxoo9m0iMH8Amt.jpg'),
(153296, 10956, 'Liga do Fogao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416807.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8dS4T45vz0uXKIsUTPXjrxQ8veg.jpg'),
(153297, 10956, 'Liga do Fogao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416808.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8j1uIxF69AQgwNFyxNDYIJyDOxv.jpg'),
(153298, 10956, 'Liga do Fogao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416809.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1U66ZfQmpDmCzKmmnS4W0aOdiFW.jpg'),
(153299, 10956, 'Liga do Fogao [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416810.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/40jX1us8nsuualcDAR9XHW4hrrn.jpg'),
(153300, 10956, 'Liga do Fogao [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416811.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eWdIhkZC2OeKRBZ3VlWUdLJrozK.jpg'),
(153301, 10956, 'Liga do Fogao [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416812.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ikCCvRaMNhdka9DcFDgizPhNa2.jpg'),
(153302, 10956, 'Liga do Fogao [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416813.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5hT0qkpXe8hrWT6aIscJEe25ViX.jpg'),
(153303, 10956, 'Liga do Fogao [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416814.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3AADio1fpiMqrV9CK1phvWLxGLX.jpg'),
(153304, 10956, 'Liga do Fogao [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416815.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oqYsJ0oYYi2XkX38DwU98dS3wlS.jpg'),
(153305, 10956, 'Liga do Fogao [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416816.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/db0xOcNljeDx63Hlf8WscB0z287.jpg'),
(153306, 10956, 'Liga do Fogao [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416817.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qHEOpG24yTZdX4whUo2CorK9xad.jpg'),
(153307, 10956, 'Liga do Fogao [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/416818.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/750UbBlOl7hVRpIPls42aeFhqqm.jpg'),
(153308, 10956, 'Liga do Fogao [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/416819.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hsWAZg4TXZfHB8b2aAkOrsPc263.jpg'),
(153309, 10956, 'Liga do Fogao [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/416820.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8hj3vQpR6F0eZH6obX5Bqe2jeG9.jpg'),
(153310, 10956, 'Liga do Fogao [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/416821.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ab76DakspHEIXKalu4PljZyVyqP.jpg'),
(153311, 10957, 'MARIA OLHA POR NOS [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416793.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/58LIeaAzO6D3pI7E3Egw4Gh5p6U.jpg'),
(153312, 10957, 'MARIA OLHA POR NOS [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416794.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pFn874WUEU1eyPEAUbNNif3uESX.jpg'),
(153313, 10957, 'MARIA OLHA POR NOS [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416795.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fbXDJZKE6xrnv0fOeILtv3Yw7dw.jpg'),
(153314, 10957, 'MARIA OLHA POR NOS [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416796.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e2R8fDHEpEP7pUKJpzyL4nulzGW.jpg'),
(153315, 10957, 'MARIA OLHA POR NOS [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416797.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11shTFJfXqumhuhIm4WWETPojcB.jpg'),
(153316, 10957, 'MARIA OLHA POR NOS [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416798.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bY6Qcl8kDMf43AjDsxW99HIMc8S.jpg'),
(153317, 10957, 'MARIA OLHA POR NOS [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416799.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/da4BrzhCm5Zt2igvcvTQ15znr8h.jpg'),
(153318, 10957, 'MARIA OLHA POR NOS [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416800.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ujGf6BBFvshgPkKZ1taYBnbGn8V.jpg'),
(153319, 10957, 'MARIA OLHA POR NOS [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416801.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3MX3rcDUkX8qfIJd9v6mDMx6qHi.jpg'),
(153320, 10957, 'MARIA OLHA POR NOS [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416802.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nKV792kejwg8tzhX1fyB1V8yUoh.jpg'),
(153321, 10957, 'MARIA OLHA POR NOS [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416803.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i720DSXDHNQWBbPPpUDCVzfKwr9.jpg'),
(153322, 10957, 'MARIA OLHA POR NOS [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416804.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lARxqB1Ct72DIThVAAfzj9KKpcW.jpg'),
(153323, 10957, 'MARIA OLHA POR NOS [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/416805.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eqA4pqqK3pomdEDnb9JnkI3wPFf.jpg'),
(153324, 10958, 'Meet You at the Blossom [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416790.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zk0pufZeYIHV1dlNIelFJ3bKKlH.jpg'),
(153325, 10958, 'Meet You at the Blossom [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416791.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Z0iACxiTTB2Qb0g16bZ9paTyZm.jpg'),
(153326, 10958, 'Meet You at the Blossom [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416792.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nTDIuX5EX0BnjdDVYgljGb7ewZZ.jpg'),
(153327, 10959, 'Melissa Etheridge Im Not Broken [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416788.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fVTf8m2OuI99uPJdsIBmC64Djre.jpg'),
(153328, 10959, 'Melissa Etheridge Im Not Broken [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416789.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sHYunI0NagNmIKcQeNa4Uyey57X.jpg'),
(153329, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416762.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2WUknVKrZMphn7TXcUOXAVRx96c.jpg'),
(153330, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416763.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hTP9kR5yjhFqgh3fzUjD1e3mcUC.jpg'),
(153331, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416764.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nJxgE5iE31YUeSBYUc013SeKpMH.jpg'),
(153332, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416765.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5xd6sTeURNfw1RbM4AnVTIvKWBU.jpg'),
(153333, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416766.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nHkMqEmVfLlej0vOiRtccs4MlL.jpg'),
(153334, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416767.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uz9kujLgEq7uopto2cByTYIaMS5.jpg'),
(153335, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416768.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mRBTW9IY4axRH5R7gFO3R3w9D8T.jpg'),
(153336, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416769.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k4CJBv8M7Z9CcBU2M2HIQtx59oc.jpg'),
(153337, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416770.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1GDx2A4fLaF6QDiJ8IEuhGqlwBv.jpg'),
(153338, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416771.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gaSIJXpSEVa6w6ugMYBOe05ANkg.jpg'),
(153339, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416772.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgokDJwOFL9COOcaohkoCOre1c.jpg'),
(153340, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416773.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8QzsBBoIMWusO9ZGZ0qzDSOwmKp.jpg'),
(153341, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/416774.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fHzGjGoCvCgQDJTTuUWJXI2VKHg.jpg'),
(153342, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/416775.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/flXWJrtyJBuqddAx85Zl9qTQC0C.jpg'),
(153343, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/416776.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rkOcOMGGKiN5aXpCGzJluE06bY5.jpg'),
(153344, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/416777.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lGvW8b1pZbUxESfe9BWIt0RLEm7.jpg'),
(153345, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/416778.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l6bLF6qCAGyrSrgD7zbIQPJMJWp.jpg'),
(153346, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/416779.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yLyLRFr2HKBTXF66tJHxLjmveI8.jpg'),
(153347, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/416780.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hBG86VhIMFhY4lvfDW9kjqKKija.jpg'),
(153348, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/416781.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/27CAYsD8POG9pzKgX7k0jvQK5ir.jpg'),
(153349, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/416782.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bL3PlyD8Gx1U93U7r0P06zwq0P4.jpg'),
(153350, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/416783.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kwXTSgc7l5HepRHlsbVTSZZHZ2F.jpg'),
(153351, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/416784.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wtoyCnjRdUw242l52U6TTG9uVDH.jpg'),
(153352, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/416785.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/npo4RuhNSmycvL4PoxjWi78GG3s.jpg'),
(153353, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/416786.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4ztHWyPlAFl8iHxpbbBZXHLNUAr.jpg'),
(153354, 10960, 'Nagi no Asukara Calmaria do Mar [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/416787.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ecyb486CSOda009Glxdnx0MFhRY.jpg'),
(153355, 10961, 'Nazotokine [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416750.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tJSGIkD3Qq4WUxfGbAn9KKsJfMc.jpg'),
(153356, 10961, 'Nazotokine [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416751.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pBiWJGneUgRkOLEmlRGVDSW9xL5.jpg'),
(153357, 10961, 'Nazotokine [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416752.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/efvUQc66nJDiSpSfLBXo0jHY2aH.jpg'),
(153358, 10961, 'Nazotokine [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z5QFRglqcaxjREzsGtJkoJSYUqP.jpg'),
(153359, 10961, 'Nazotokine [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416754.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1cvJ76J4l3I41u5gKLBACUrpXqX.jpg'),
(153360, 10961, 'Nazotokine [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416755.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dQQcXLYFXI0QPi4oF26wq7mODJB.jpg'),
(153361, 10961, 'Nazotokine [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416756.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iDxAjhR3ErsvPgqK5KNnWPRuABa.jpg'),
(153362, 10961, 'Nazotokine [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416757.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8fA3EKq8OJwp3ISrx7OElJ19KZ9.jpg'),
(153363, 10961, 'Nazotokine [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416758.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2Au0FG3Yk68GWKApsGlbX4BaYKK.jpg'),
(153364, 10961, 'Nazotokine [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416759.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eheswnl7IzC9JNmbQT9P2NBFwV6.jpg'),
(153365, 10961, 'Nazotokine [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416760.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vlSfjB1u0uO4dZ50tMB8lhjbPt3.jpg'),
(153366, 10961, 'Nazotokine [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416761.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/szrcJezchy2phid1Ov8ZsZ3V3BZ.jpg'),
(153367, 10962, 'Oi Tonbo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416737.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qSnF9g59KioV06sthEzHSDCFBtk.jpg'),
(153368, 10962, 'Oi Tonbo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416738.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b1w9Qsslgk3VJD8yCKkRMfMfwW.jpg'),
(153369, 10962, 'Oi Tonbo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416739.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8ZlakTPOaBeq1h3zrcryPLsvFkS.jpg'),
(153370, 10962, 'Oi Tonbo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416740.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9TMZsDlFTWRCq8yfGfIZfmTo6W4.jpg'),
(153371, 10962, 'Oi Tonbo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416741.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1dGngRLtloW36an0YPcYTSpDZrF.jpg'),
(153372, 10962, 'Oi Tonbo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416742.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v0V5Nk5upTRYORiiWpXEr8MXWcE.jpg'),
(153373, 10962, 'Oi Tonbo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416743.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rLB3bPEzxPYSfu0yIPYCAfA2YRS.jpg'),
(153374, 10962, 'Oi Tonbo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416744.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jez11zjTIQG64RqcazRAN0Opfek.jpg'),
(153375, 10962, 'Oi Tonbo [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416745.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5uu601B0Dkj39o0JB4RAeXPVLfT.jpg'),
(153376, 10962, 'Oi Tonbo [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416746.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7TfqWj1T40jFPy6XmNS8uu7w8hP.jpg'),
(153377, 10962, 'Oi Tonbo [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416747.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vd0ZVxhm6ouricGYPA6nxH0WR2.jpg'),
(153378, 10962, 'Oi Tonbo [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416748.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tUxkNoIOTxeFR3iN2ZmEGrtAy6N.jpg'),
(153379, 10962, 'Oi Tonbo [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/416749.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/38sUQJFyUjtBAWxgH52A5uaAWvO.jpg'),
(153380, 10963, 'Oi Tonbo [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/667934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z53qdls6kfGTihy8BvvfOe4We9.jpg'),
(153381, 10963, 'Oi Tonbo [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/667935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z53qdls6kfGTihy8BvvfOe4We9.jpg'),
(153382, 10963, 'Oi Tonbo [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/667936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z53qdls6kfGTihy8BvvfOe4We9.jpg'),
(153383, 10963, 'Oi Tonbo [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/667937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z53qdls6kfGTihy8BvvfOe4We9.jpg'),
(153384, 10963, 'Oi Tonbo [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/667938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z53qdls6kfGTihy8BvvfOe4We9.jpg'),
(153385, 10963, 'Oi Tonbo [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/667939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z53qdls6kfGTihy8BvvfOe4We9.jpg'),
(153386, 10963, 'Oi Tonbo [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/667940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z53qdls6kfGTihy8BvvfOe4We9.jpg'),
(153387, 10963, 'Oi Tonbo [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/667941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z53qdls6kfGTihy8BvvfOe4We9.jpg'),
(153388, 10963, 'Oi Tonbo [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/667942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z53qdls6kfGTihy8BvvfOe4We9.jpg'),
(153389, 10963, 'Oi Tonbo [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/667943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z53qdls6kfGTihy8BvvfOe4We9.jpg'),
(153390, 10963, 'Oi Tonbo [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/667944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z53qdls6kfGTihy8BvvfOe4We9.jpg'),
(153391, 10963, 'Oi Tonbo [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/667945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z53qdls6kfGTihy8BvvfOe4We9.jpg'),
(153392, 10963, 'Oi Tonbo [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/667946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Z53qdls6kfGTihy8BvvfOe4We9.jpg'),
(153393, 10964, 'Onivoros [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416729.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cradirI34L1Wn3LDweruiyKUlV5.jpg'),
(153394, 10964, 'Onivoros [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416730.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e2kOX1Ns1JETz8IHuQ9a3e8Qdcn.jpg'),
(153395, 10964, 'Onivoros [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416731.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Gwb3LNrejXusWBozl2mBLVecOq.jpg'),
(153396, 10964, 'Onivoros [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416732.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/14n40utR9agnY6Jny5dXopgaVpN.jpg'),
(153397, 10964, 'Onivoros [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416733.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/91nm2FsiQgLTzhJSFChP3pWLs6T.jpg'),
(153398, 10964, 'Onivoros [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416734.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7Fd4ofviGrRLJSPWuJyCss5uVzF.jpg'),
(153399, 10964, 'Onivoros [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416735.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/irZZt0LgqwbXPxqfykG69chJUao.jpg'),
(153400, 10964, 'Onivoros [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416736.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n0v0eT87ssY8xO7z8May3At1QIH.jpg'),
(153401, 10965, 'Os Auditores [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416723.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rKkjeIENYphatw31ALhWV3hgwAc.jpg'),
(153402, 10965, 'Os Auditores [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416724.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6FM99ujF0W7lk4nrZOhoGb8kjkC.jpg'),
(153403, 10965, 'Os Auditores [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416725.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nOUiAoiaVTwG17Lkt1LPOBAVnSx.jpg'),
(153404, 10965, 'Os Auditores [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416726.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iq29nEGoFj53LyyqKieEtDHmGi8.jpg'),
(153405, 10965, 'Os Auditores [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416727.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n152A6ViLqBUVY9ZDLTfgmi6Wz.jpg'),
(153406, 10965, 'Os Auditores [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416728.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9EcklDjsgaPIgD77I6jHr2PR6VI.jpg'),
(153407, 10965, 'Os Auditores [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/423306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ogzR8jhg8T4t4RmjcriPFU8wkPR.jpg'),
(153408, 10965, 'Os Auditores [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/423307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ogzR8jhg8T4t4RmjcriPFU8wkPR.jpg'),
(153409, 10965, 'Os Auditores [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/423308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ogzR8jhg8T4t4RmjcriPFU8wkPR.jpg'),
(153410, 10965, 'Os Auditores [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/426946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ogzR8jhg8T4t4RmjcriPFU8wkPR.jpg'),
(153411, 10965, 'Os Auditores [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/429264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ogzR8jhg8T4t4RmjcriPFU8wkPR.jpg'),
(153412, 10965, 'Os Auditores [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/429265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ogzR8jhg8T4t4RmjcriPFU8wkPR.jpg'),
(153413, 10966, 'Os Bandidos do Tempo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416721.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dL95sj978n80PiqajSQU4ux28lE.jpg'),
(153414, 10966, 'Os Bandidos do Tempo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416722.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/64X2pepWBJPV0h1FIF1KO6Su89S.jpg'),
(153415, 10966, 'Os Bandidos do Tempo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/421105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0wnI0z7aRbs7PYyG9hK9wZ2Oec.jpg'),
(153416, 10966, 'Os Bandidos do Tempo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/421106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0wnI0z7aRbs7PYyG9hK9wZ2Oec.jpg'),
(153417, 10966, 'Os Bandidos do Tempo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/426935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0wnI0z7aRbs7PYyG9hK9wZ2Oec.jpg'),
(153418, 10966, 'Os Bandidos do Tempo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/426936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0wnI0z7aRbs7PYyG9hK9wZ2Oec.jpg'),
(153419, 10966, 'Os Bandidos do Tempo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/429252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0wnI0z7aRbs7PYyG9hK9wZ2Oec.jpg'),
(153420, 10966, 'Os Bandidos do Tempo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/429253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0wnI0z7aRbs7PYyG9hK9wZ2Oec.jpg'),
(153421, 10966, 'Os Bandidos do Tempo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/435892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0wnI0z7aRbs7PYyG9hK9wZ2Oec.jpg'),
(153422, 10966, 'Os Bandidos do Tempo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/435893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A0wnI0z7aRbs7PYyG9hK9wZ2Oec.jpg'),
(153423, 10967, 'Os Golpistas de Toquio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416714.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qCapq0PbQR5V7w4zhnm9NY6kFUT.jpg'),
(153424, 10967, 'Os Golpistas de Toquio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416715.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lU0hTVVBj7h2vwpTgTFBmap60cd.jpg'),
(153425, 10967, 'Os Golpistas de Toquio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416716.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pZJjTzfvzIIqRF7VqGrGLTfx1w1.jpg'),
(153426, 10967, 'Os Golpistas de Toquio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416717.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AuJzc3UD5onTTOyT1fsPhQGoIS6.jpg'),
(153427, 10967, 'Os Golpistas de Toquio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416718.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzJmFJOpqP4dM09N0BiQuKigIa9.jpg'),
(153428, 10967, 'Os Golpistas de Toquio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416719.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tXVAXCThaHhWONfJA0hawLU8gpF.jpg'),
(153429, 10967, 'Os Golpistas de Toquio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416720.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l1MMPU84EsLdX67erS41cscSmtv.jpg'),
(153430, 10968, 'Otome Yokai Zakuro [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416701.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qT4YqwaHFLf9gtOlBr5I66AJi5z.jpg'),
(153431, 10968, 'Otome Yokai Zakuro [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416702.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9yj26QnknyakN2THTQnUiteTziK.jpg'),
(153432, 10968, 'Otome Yokai Zakuro [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416703.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8tMhy06gtBnZ2jOusAUWIl7Hrm7.jpg'),
(153433, 10968, 'Otome Yokai Zakuro [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416704.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x3yvaVZVFYW63P0dfRGyTv5iiie.jpg'),
(153434, 10968, 'Otome Yokai Zakuro [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416705.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zKc8exG7Lirimw8eJLKb8StlSMq.jpg'),
(153435, 10968, 'Otome Yokai Zakuro [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416706.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2KnWWEdGRyGybwbnfuWCOtapMNO.jpg'),
(153436, 10968, 'Otome Yokai Zakuro [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416707.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/13uyBCriTMV3TG2PzcDPkBfkK0N.jpg'),
(153437, 10968, 'Otome Yokai Zakuro [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416708.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5cdNKdjy8AkJrjdZPpqDaaXjRR.jpg'),
(153438, 10968, 'Otome Yokai Zakuro [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416709.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n5zI43MC5LVe7CIDQbjnteVgQil.jpg'),
(153439, 10968, 'Otome Yokai Zakuro [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416710.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kV2sFqY6dUx0TOdx5xl7Rhu9QX1.jpg'),
(153440, 10968, 'Otome Yokai Zakuro [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416711.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yWYBXM7txVNvlxELjaGYgyCrWlF.jpg'),
(153441, 10968, 'Otome Yokai Zakuro [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416712.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4wyBwI7L6fTQb6oSKEI4BKjOrt.jpg'),
(153442, 10968, 'Otome Yokai Zakuro [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/416713.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ewOJ6Fpv4pgDWjsfgv3PR8MmHLF.jpg'),
(153443, 10969, 'Peoes do Amor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416661.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7qjor25bHgu0dkN7VqnQArF1S2b.jpg'),
(153444, 10969, 'Peoes do Amor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416662.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hSNpYN8Kf3f9w9Yor80xGL9vxoe.jpg'),
(153445, 10969, 'Peoes do Amor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416663.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3LLKcz3WrGraqPR167z60BwEjKY.jpg'),
(153446, 10969, 'Peoes do Amor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416664.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jvpeC71UdkvkCCZw84nIGZMIn3i.jpg'),
(153447, 10969, 'Peoes do Amor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416665.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1jTXSY1L9IEYpxL1DpdnbJeg8hk.jpg'),
(153448, 10969, 'Peoes do Amor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416666.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pRT798EaFwhQiWrpMhUbgakImkC.jpg'),
(153449, 10969, 'Peoes do Amor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416667.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h8zgpk4ukGNcO5Mvmg4IbBT56DW.jpg'),
(153450, 10969, 'Peoes do Amor [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416668.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/j3utkBWkJe1V5axrSpAUMuncXbp.jpg'),
(153451, 10969, 'Peoes do Amor [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416669.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ehxDiF5Dr4lmT0Adit2PHKTSndt.jpg'),
(153452, 10969, 'Peoes do Amor [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416670.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k6SKDLmRxnTJXcMJvIIkMWdsadP.jpg'),
(153453, 10969, 'Peoes do Amor [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416671.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aF9Mye1pm5wAPm0ZYHPS1I5jkL0.jpg'),
(153454, 10969, 'Peoes do Amor [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416672.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gDdjiJNzOK1JgAXR54oAzOZR2FP.jpg'),
(153455, 10969, 'Peoes do Amor [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/416673.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMMv7WczWLdH4X47cYpgCjaEocO.jpg'),
(153456, 10969, 'Peoes do Amor [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/416674.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bt5r2JA4PGO5rx2oLfbPh6vPQgz.jpg'),
(153457, 10969, 'Peoes do Amor [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/416675.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AmfzdpWq3oatBmoZF8xUFRr34wl.jpg'),
(153458, 10969, 'Peoes do Amor [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/416676.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pwVuEvib9x6UdqmXVzjoy3uDJrx.jpg'),
(153459, 10969, 'Peoes do Amor [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/416677.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tq8Dx2nBBBgBjDvxPFfgdAt4pUT.jpg'),
(153460, 10969, 'Peoes do Amor [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/416678.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p2g3Z1knpG4FYPJhKu66oc5Q8if.jpg'),
(153461, 10969, 'Peoes do Amor [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/416679.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uWaiqSMGQFyr1POFPNqeyPWGpOD.jpg'),
(153462, 10969, 'Peoes do Amor [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/416680.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x6bemWu1AFjrwVfMei7Akxflyuu.jpg'),
(153463, 10969, 'Peoes do Amor [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/416681.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v1XVcPVnPoxlEwqhPgkiWlnUn5e.jpg'),
(153464, 10969, 'Peoes do Amor [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/416682.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xecxM1utf9NMV6QPj5QZNwOSTBU.jpg'),
(153465, 10969, 'Peoes do Amor [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/416683.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8VIxy0aPcsrqZYX36CKMqfJCOmh.jpg'),
(153466, 10969, 'Peoes do Amor [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/416684.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/izQluBNn2vk64SV4IvvkwJZy19W.jpg'),
(153467, 10969, 'Peoes do Amor [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/416685.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hvQec4NB0rIsrhZoGMRoSDhIUti.jpg'),
(153468, 10969, 'Peoes do Amor [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/416686.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3hEHc26dDL9xN1aM98ugPGtdrmy.jpg'),
(153469, 10969, 'Peoes do Amor [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/416687.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y4qHG6ZqaAH5ZiUk9QRb86ShQon.jpg'),
(153470, 10969, 'Peoes do Amor [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/416688.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c67i93JCBPVRb5iLSUmRmi4vxT9.jpg'),
(153471, 10969, 'Peoes do Amor [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/416689.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zI3czGzxrVdcYBAMhAgjpq261kv.jpg'),
(153472, 10969, 'Peoes do Amor [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/416690.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AbwrsN7pMO8wz0Pd55frq5Csers.jpg'),
(153473, 10969, 'Peoes do Amor [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/416691.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3KBapE9lRaWdvfKlEuLV5BI7As2.jpg'),
(153474, 10969, 'Peoes do Amor [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/416692.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4OTK3tczfJNln4sxtM1oDIeJkRr.jpg'),
(153475, 10969, 'Peoes do Amor [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/416693.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wlWL6iEBb317KsWcfyFdOiKYbOO.jpg'),
(153476, 10969, 'Peoes do Amor [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/416694.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7nyJ1dMccAeU5OYYYfLvLxHnWF9.jpg'),
(153477, 10969, 'Peoes do Amor [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/416695.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1NrEvdymHLFfNGGjVwMO74MgIz5.jpg'),
(153478, 10969, 'Peoes do Amor [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/416696.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zWjQ3EPpx3TmEgq00sCc56kzuaU.jpg'),
(153479, 10969, 'Peoes do Amor [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/416697.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/asWxGa8hQPJBtYRaJnHIUTRK6xD.jpg'),
(153480, 10969, 'Peoes do Amor [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/416698.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w0z6b3lsyk9bDL3lHvw0dqHtKpI.jpg'),
(153481, 10969, 'Peoes do Amor [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/416699.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zMod3xOvcn9nD6KYaRdiNz8zin1.jpg'),
(153482, 10969, 'Peoes do Amor [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/416700.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2lT78QhixPlYpR3hJEYARopAQQ4.jpg'),
(153483, 10970, 'People Magazine Sobrevivendo a um Serial Killer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416660.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c5xrbSU2yuw0NwgJ40wT3oZf12c.jpg'),
(153484, 10970, 'People Magazine Sobrevivendo a um Serial Killer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/433260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hWqBix8KeZevoEb37XBtk8A9jl.jpg'),
(153485, 10970, 'People Magazine Sobrevivendo a um Serial Killer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/433261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hWqBix8KeZevoEb37XBtk8A9jl.jpg'),
(153486, 10970, 'People Magazine Sobrevivendo a um Serial Killer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/433262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hWqBix8KeZevoEb37XBtk8A9jl.jpg'),
(153487, 10970, 'People Magazine Sobrevivendo a um Serial Killer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hWqBix8KeZevoEb37XBtk8A9jl.jpg'),
(153488, 10970, 'People Magazine Sobrevivendo a um Serial Killer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9hWqBix8KeZevoEb37XBtk8A9jl.jpg'),
(153489, 10971, 'Que Seja Doce S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/609207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153490, 10971, 'Que Seja Doce S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/609208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153491, 10971, 'Que Seja Doce S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/609209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153492, 10971, 'Que Seja Doce S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/609210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153493, 10971, 'Que Seja Doce S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/609211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153494, 10971, 'Que Seja Doce S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/609212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153495, 10971, 'Que Seja Doce S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/609213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153496, 10971, 'Que Seja Doce S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/609214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153497, 10971, 'Que Seja Doce S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/609215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153498, 10971, 'Que Seja Doce S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/609216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153499, 10971, 'Que Seja Doce S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/609217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153500, 10971, 'Que Seja Doce S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/609218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153501, 10971, 'Que Seja Doce S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/609219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153502, 10971, 'Que Seja Doce S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/609220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153503, 10971, 'Que Seja Doce S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/609221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153504, 10971, 'Que Seja Doce S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/609222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153505, 10971, 'Que Seja Doce S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/609223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153506, 10971, 'Que Seja Doce S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/609224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153507, 10971, 'Que Seja Doce S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/609225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153508, 10971, 'Que Seja Doce S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/609226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(153509, 10971, 'Que Seja Doce S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/609227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153510, 10971, 'Que Seja Doce S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/609228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153511, 10971, 'Que Seja Doce S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/609229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153512, 10971, 'Que Seja Doce S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/609230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153513, 10971, 'Que Seja Doce S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/609231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153514, 10971, 'Que Seja Doce S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/609232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153515, 10971, 'Que Seja Doce S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/609233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153516, 10971, 'Que Seja Doce S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/609234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153517, 10971, 'Que Seja Doce S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/609235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153518, 10971, 'Que Seja Doce S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/609236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153519, 10971, 'Que Seja Doce S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/609237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153520, 10971, 'Que Seja Doce S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/609238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153521, 10971, 'Que Seja Doce S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/609239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153522, 10971, 'Que Seja Doce S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/609240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153523, 10971, 'Que Seja Doce S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/609241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153524, 10971, 'Que Seja Doce S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/609242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153525, 10971, 'Que Seja Doce S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/609243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153526, 10971, 'Que Seja Doce S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/609244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153527, 10971, 'Que Seja Doce S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/609245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153528, 10971, 'Que Seja Doce S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/609246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153529, 10971, 'Que Seja Doce S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/609247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153530, 10971, 'Que Seja Doce S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/609248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153531, 10971, 'Que Seja Doce S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/609249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153532, 10971, 'Que Seja Doce S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/609250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153533, 10971, 'Que Seja Doce S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/609251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153534, 10971, 'Que Seja Doce S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/609252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153535, 10972, 'Que Seja Doce S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/609253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153536, 10972, 'Que Seja Doce S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/609254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153537, 10972, 'Que Seja Doce S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/609255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153538, 10972, 'Que Seja Doce S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/609256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153539, 10972, 'Que Seja Doce S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/609257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153540, 10972, 'Que Seja Doce S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/609258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153541, 10972, 'Que Seja Doce S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/609259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153542, 10972, 'Que Seja Doce S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/609260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153543, 10972, 'Que Seja Doce S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/609261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153544, 10972, 'Que Seja Doce S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/609262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153545, 10972, 'Que Seja Doce S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/609263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153546, 10972, 'Que Seja Doce S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/609264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153547, 10972, 'Que Seja Doce S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/609265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153548, 10972, 'Que Seja Doce S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/609266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153549, 10972, 'Que Seja Doce S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/609267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153550, 10972, 'Que Seja Doce S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/609268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153551, 10972, 'Que Seja Doce S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/609269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153552, 10972, 'Que Seja Doce S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/609270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153553, 10972, 'Que Seja Doce S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/609271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153554, 10972, 'Que Seja Doce S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/609272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153555, 10972, 'Que Seja Doce S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/609273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153556, 10972, 'Que Seja Doce S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/609274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153557, 10972, 'Que Seja Doce S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/609275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153558, 10972, 'Que Seja Doce S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/609276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153559, 10972, 'Que Seja Doce S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/609277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153560, 10972, 'Que Seja Doce S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/609278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153561, 10972, 'Que Seja Doce S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/609279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153562, 10972, 'Que Seja Doce S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/609280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153563, 10972, 'Que Seja Doce S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/609281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153564, 10972, 'Que Seja Doce S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/609282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153565, 10972, 'Que Seja Doce S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/609283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153566, 10972, 'Que Seja Doce S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/609284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153567, 10972, 'Que Seja Doce S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/609285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153568, 10972, 'Que Seja Doce S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/609286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153569, 10972, 'Que Seja Doce S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/609287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153570, 10972, 'Que Seja Doce S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/609288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153571, 10972, 'Que Seja Doce S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/609289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153572, 10972, 'Que Seja Doce S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/609290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153573, 10972, 'Que Seja Doce S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/609291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153574, 10973, 'Que Seja Doce S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/609292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153575, 10973, 'Que Seja Doce S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/609293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153576, 10973, 'Que Seja Doce S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/609294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153577, 10973, 'Que Seja Doce S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/609295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153578, 10973, 'Que Seja Doce S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/609296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153579, 10973, 'Que Seja Doce S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/609297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153580, 10973, 'Que Seja Doce S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/609298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153581, 10973, 'Que Seja Doce S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/609299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153582, 10973, 'Que Seja Doce S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/609300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153583, 10973, 'Que Seja Doce S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/609301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153584, 10973, 'Que Seja Doce S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/609302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153585, 10973, 'Que Seja Doce S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/609303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153586, 10973, 'Que Seja Doce S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/609304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153587, 10973, 'Que Seja Doce S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/609305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153588, 10973, 'Que Seja Doce S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/609306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153589, 10973, 'Que Seja Doce S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/609307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153590, 10973, 'Que Seja Doce S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/609308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153591, 10973, 'Que Seja Doce S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/609309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153592, 10973, 'Que Seja Doce S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/609310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153593, 10973, 'Que Seja Doce S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/609311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153594, 10973, 'Que Seja Doce S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/609312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153595, 10973, 'Que Seja Doce S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/609313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153596, 10973, 'Que Seja Doce S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/609314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153597, 10973, 'Que Seja Doce S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/609315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153598, 10973, 'Que Seja Doce S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/609316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153599, 10973, 'Que Seja Doce S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/609317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153600, 10973, 'Que Seja Doce S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/609318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153601, 10973, 'Que Seja Doce S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/609319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153602, 10973, 'Que Seja Doce S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/609320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153603, 10973, 'Que Seja Doce S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/609321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153604, 10973, 'Que Seja Doce S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/609322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153605, 10973, 'Que Seja Doce S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/609323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153606, 10973, 'Que Seja Doce S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/609324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153607, 10973, 'Que Seja Doce S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/609325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153608, 10973, 'Que Seja Doce S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/609326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153609, 10973, 'Que Seja Doce S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/609327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153610, 10973, 'Que Seja Doce S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/609328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153611, 10973, 'Que Seja Doce S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/609329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153612, 10973, 'Que Seja Doce S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/609330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153613, 10973, 'Que Seja Doce S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/609331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153614, 10974, 'Que Seja Doce S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/609332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153615, 10974, 'Que Seja Doce S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/609333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153616, 10974, 'Que Seja Doce S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/609334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153617, 10974, 'Que Seja Doce S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/609335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153618, 10974, 'Que Seja Doce S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/609336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153619, 10974, 'Que Seja Doce S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/609337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153620, 10974, 'Que Seja Doce S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/609338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153621, 10974, 'Que Seja Doce S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/609339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153622, 10974, 'Que Seja Doce S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/609340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153623, 10974, 'Que Seja Doce S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/609341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153624, 10974, 'Que Seja Doce S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/609342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153625, 10974, 'Que Seja Doce S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/609343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153626, 10974, 'Que Seja Doce S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/609344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153627, 10974, 'Que Seja Doce S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/609345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153628, 10974, 'Que Seja Doce S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/609346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153629, 10974, 'Que Seja Doce S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/609347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153630, 10974, 'Que Seja Doce S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/609348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153631, 10974, 'Que Seja Doce S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/609349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153632, 10974, 'Que Seja Doce S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/609350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153633, 10974, 'Que Seja Doce S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/609351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153634, 10974, 'Que Seja Doce S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/609352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153635, 10974, 'Que Seja Doce S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/609353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153636, 10974, 'Que Seja Doce S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/609354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153637, 10974, 'Que Seja Doce S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/609355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153638, 10974, 'Que Seja Doce S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/609356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153639, 10974, 'Que Seja Doce S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/609357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153640, 10974, 'Que Seja Doce S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/609358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153641, 10974, 'Que Seja Doce S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/609359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153642, 10974, 'Que Seja Doce S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/609360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153643, 10974, 'Que Seja Doce S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/609361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153644, 10974, 'Que Seja Doce S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/609362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153645, 10974, 'Que Seja Doce S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/609363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153646, 10974, 'Que Seja Doce S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/609364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153647, 10974, 'Que Seja Doce S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/609365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153648, 10974, 'Que Seja Doce S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/609366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153649, 10974, 'Que Seja Doce S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/609367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153650, 10974, 'Que Seja Doce S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/609368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153651, 10974, 'Que Seja Doce S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/609369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153652, 10974, 'Que Seja Doce S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/609370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153653, 10974, 'Que Seja Doce S04 E40', 'http://sinalprivado.info:80/series/1533784/1533784/609371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153654, 10975, 'Que Seja Doce S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/609372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153655, 10975, 'Que Seja Doce S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/609373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153656, 10975, 'Que Seja Doce S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/609374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153657, 10975, 'Que Seja Doce S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/609375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153658, 10975, 'Que Seja Doce S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/609376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153659, 10975, 'Que Seja Doce S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/609377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153660, 10975, 'Que Seja Doce S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/609378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153661, 10975, 'Que Seja Doce S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/609379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153662, 10975, 'Que Seja Doce S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/609380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153663, 10975, 'Que Seja Doce S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/609381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153664, 10975, 'Que Seja Doce S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/609382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153665, 10975, 'Que Seja Doce S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/609383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153666, 10975, 'Que Seja Doce S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/609384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153667, 10975, 'Que Seja Doce S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/609385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153668, 10975, 'Que Seja Doce S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/609386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153669, 10975, 'Que Seja Doce S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/609387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153670, 10975, 'Que Seja Doce S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/609388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153671, 10975, 'Que Seja Doce S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/609389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153672, 10975, 'Que Seja Doce S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/609390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153673, 10975, 'Que Seja Doce S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/609391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153674, 10975, 'Que Seja Doce S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/609392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153675, 10975, 'Que Seja Doce S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/609393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153676, 10975, 'Que Seja Doce S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/609394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153677, 10975, 'Que Seja Doce S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/609395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153678, 10975, 'Que Seja Doce S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/609396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153679, 10975, 'Que Seja Doce S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/609397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153680, 10975, 'Que Seja Doce S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/609398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153681, 10975, 'Que Seja Doce S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/609399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153682, 10975, 'Que Seja Doce S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/609400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153683, 10975, 'Que Seja Doce S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/609401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153684, 10975, 'Que Seja Doce S05 E31', 'http://sinalprivado.info:80/series/1533784/1533784/609402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153685, 10975, 'Que Seja Doce S05 E32', 'http://sinalprivado.info:80/series/1533784/1533784/609403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153686, 10975, 'Que Seja Doce S05 E33', 'http://sinalprivado.info:80/series/1533784/1533784/609404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153687, 10975, 'Que Seja Doce S05 E34', 'http://sinalprivado.info:80/series/1533784/1533784/609405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153688, 10975, 'Que Seja Doce S05 E35', 'http://sinalprivado.info:80/series/1533784/1533784/609406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153689, 10975, 'Que Seja Doce S05 E36', 'http://sinalprivado.info:80/series/1533784/1533784/609407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153690, 10975, 'Que Seja Doce S05 E37', 'http://sinalprivado.info:80/series/1533784/1533784/609408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153691, 10975, 'Que Seja Doce S05 E38', 'http://sinalprivado.info:80/series/1533784/1533784/609409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153692, 10975, 'Que Seja Doce S05 E39', 'http://sinalprivado.info:80/series/1533784/1533784/609410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153693, 10975, 'Que Seja Doce S05 E40', 'http://sinalprivado.info:80/series/1533784/1533784/609411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153694, 10976, 'Que Seja Doce S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/609412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153695, 10976, 'Que Seja Doce S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/609413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153696, 10976, 'Que Seja Doce S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/609414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153697, 10976, 'Que Seja Doce S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/609415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153698, 10976, 'Que Seja Doce S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/609416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153699, 10976, 'Que Seja Doce S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/609417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153700, 10976, 'Que Seja Doce S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/609418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153701, 10976, 'Que Seja Doce S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/609419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153702, 10976, 'Que Seja Doce S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/609420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153703, 10976, 'Que Seja Doce S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/609421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153704, 10976, 'Que Seja Doce S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/609422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153705, 10976, 'Que Seja Doce S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/609423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153706, 10976, 'Que Seja Doce S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/609424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153707, 10976, 'Que Seja Doce S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/609425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153708, 10976, 'Que Seja Doce S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/609426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153709, 10976, 'Que Seja Doce S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/609429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153710, 10976, 'Que Seja Doce S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/609430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153711, 10976, 'Que Seja Doce S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/609431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153712, 10976, 'Que Seja Doce S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/609432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153713, 10976, 'Que Seja Doce S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/609433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153714, 10976, 'Que Seja Doce S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/609434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153715, 10976, 'Que Seja Doce S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/609435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153716, 10976, 'Que Seja Doce S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/609436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153717, 10976, 'Que Seja Doce S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/609437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153718, 10976, 'Que Seja Doce S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/609438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153719, 10976, 'Que Seja Doce S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/609439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153720, 10976, 'Que Seja Doce S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/609440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153721, 10976, 'Que Seja Doce S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/609441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153722, 10976, 'Que Seja Doce S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/609442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153723, 10976, 'Que Seja Doce S06 E30', 'http://sinalprivado.info:80/series/1533784/1533784/609443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153724, 10976, 'Que Seja Doce S06 E31', 'http://sinalprivado.info:80/series/1533784/1533784/609444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153725, 10976, 'Que Seja Doce S06 E32', 'http://sinalprivado.info:80/series/1533784/1533784/609445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153726, 10976, 'Que Seja Doce S06 E33', 'http://sinalprivado.info:80/series/1533784/1533784/609447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153727, 10976, 'Que Seja Doce S06 E34', 'http://sinalprivado.info:80/series/1533784/1533784/609448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153728, 10976, 'Que Seja Doce S06 E35', 'http://sinalprivado.info:80/series/1533784/1533784/609449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153729, 10976, 'Que Seja Doce S06 E36', 'http://sinalprivado.info:80/series/1533784/1533784/609450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153730, 10977, 'Que Seja Doce S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/609451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153731, 10977, 'Que Seja Doce S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/609452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153732, 10977, 'Que Seja Doce S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/609453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153733, 10977, 'Que Seja Doce S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/609454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153734, 10977, 'Que Seja Doce S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/609455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153735, 10977, 'Que Seja Doce S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/609456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153736, 10977, 'Que Seja Doce S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/609457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153737, 10977, 'Que Seja Doce S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/609458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153738, 10977, 'Que Seja Doce S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/609459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153739, 10977, 'Que Seja Doce S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/609460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153740, 10977, 'Que Seja Doce S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/609461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153741, 10977, 'Que Seja Doce S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/609462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153742, 10977, 'Que Seja Doce S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/609463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153743, 10977, 'Que Seja Doce S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/609464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153744, 10977, 'Que Seja Doce S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/609465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153745, 10977, 'Que Seja Doce S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/609466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153746, 10977, 'Que Seja Doce S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/609467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153747, 10977, 'Que Seja Doce S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/609468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153748, 10977, 'Que Seja Doce S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/609469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153749, 10977, 'Que Seja Doce S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/609470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153750, 10977, 'Que Seja Doce S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/609471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153751, 10977, 'Que Seja Doce S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/609472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153752, 10977, 'Que Seja Doce S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/609473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153753, 10977, 'Que Seja Doce S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/609474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153754, 10977, 'Que Seja Doce S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/609475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153755, 10977, 'Que Seja Doce S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/609476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153756, 10977, 'Que Seja Doce S07 E27', 'http://sinalprivado.info:80/series/1533784/1533784/609477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153757, 10977, 'Que Seja Doce S07 E28', 'http://sinalprivado.info:80/series/1533784/1533784/609478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153758, 10977, 'Que Seja Doce S07 E29', 'http://sinalprivado.info:80/series/1533784/1533784/609479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153759, 10977, 'Que Seja Doce S07 E30', 'http://sinalprivado.info:80/series/1533784/1533784/609480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153760, 10977, 'Que Seja Doce S07 E31', 'http://sinalprivado.info:80/series/1533784/1533784/609481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153761, 10977, 'Que Seja Doce S07 E32', 'http://sinalprivado.info:80/series/1533784/1533784/609482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153762, 10977, 'Que Seja Doce S07 E33', 'http://sinalprivado.info:80/series/1533784/1533784/609483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153763, 10977, 'Que Seja Doce S07 E34', 'http://sinalprivado.info:80/series/1533784/1533784/609484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153764, 10977, 'Que Seja Doce S07 E35', 'http://sinalprivado.info:80/series/1533784/1533784/609485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153765, 10977, 'Que Seja Doce S07 E36', 'http://sinalprivado.info:80/series/1533784/1533784/609486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153766, 10977, 'Que Seja Doce S07 E37', 'http://sinalprivado.info:80/series/1533784/1533784/609487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153767, 10977, 'Que Seja Doce S07 E38', 'http://sinalprivado.info:80/series/1533784/1533784/609488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153768, 10977, 'Que Seja Doce S07 E39', 'http://sinalprivado.info:80/series/1533784/1533784/609489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153769, 10977, 'Que Seja Doce S07 E40', 'http://sinalprivado.info:80/series/1533784/1533784/609490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153770, 10978, 'Que Seja Doce S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/609491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153771, 10978, 'Que Seja Doce S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/609492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153772, 10978, 'Que Seja Doce S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/609493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(153773, 10978, 'Que Seja Doce S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/609494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153774, 10978, 'Que Seja Doce S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/609495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153775, 10978, 'Que Seja Doce S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/609496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153776, 10978, 'Que Seja Doce S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/609497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153777, 10978, 'Que Seja Doce S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/609498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153778, 10978, 'Que Seja Doce S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/609499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153779, 10978, 'Que Seja Doce S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/609500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153780, 10978, 'Que Seja Doce S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/609501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153781, 10978, 'Que Seja Doce S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/609502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153782, 10978, 'Que Seja Doce S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/609503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153783, 10978, 'Que Seja Doce S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/609504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153784, 10978, 'Que Seja Doce S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/609505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153785, 10978, 'Que Seja Doce S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/609506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153786, 10978, 'Que Seja Doce S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/609507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153787, 10978, 'Que Seja Doce S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/609508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153788, 10978, 'Que Seja Doce S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/609509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153789, 10978, 'Que Seja Doce S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/609510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153790, 10978, 'Que Seja Doce S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/609511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153791, 10978, 'Que Seja Doce S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/609512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153792, 10978, 'Que Seja Doce S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/609513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153793, 10978, 'Que Seja Doce S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/609514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153794, 10978, 'Que Seja Doce S08 E25', 'http://sinalprivado.info:80/series/1533784/1533784/609515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153795, 10978, 'Que Seja Doce S08 E26', 'http://sinalprivado.info:80/series/1533784/1533784/609516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153796, 10978, 'Que Seja Doce S08 E27', 'http://sinalprivado.info:80/series/1533784/1533784/609517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153797, 10978, 'Que Seja Doce S08 E28', 'http://sinalprivado.info:80/series/1533784/1533784/609518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153798, 10978, 'Que Seja Doce S08 E29', 'http://sinalprivado.info:80/series/1533784/1533784/609519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153799, 10978, 'Que Seja Doce S08 E30', 'http://sinalprivado.info:80/series/1533784/1533784/609520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153800, 10978, 'Que Seja Doce S08 E31', 'http://sinalprivado.info:80/series/1533784/1533784/609521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153801, 10978, 'Que Seja Doce S08 E32', 'http://sinalprivado.info:80/series/1533784/1533784/609522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153802, 10978, 'Que Seja Doce S08 E33', 'http://sinalprivado.info:80/series/1533784/1533784/609523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153803, 10978, 'Que Seja Doce S08 E34', 'http://sinalprivado.info:80/series/1533784/1533784/609524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153804, 10978, 'Que Seja Doce S08 E35', 'http://sinalprivado.info:80/series/1533784/1533784/609525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153805, 10978, 'Que Seja Doce S08 E36', 'http://sinalprivado.info:80/series/1533784/1533784/609526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153806, 10978, 'Que Seja Doce S08 E37', 'http://sinalprivado.info:80/series/1533784/1533784/609527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153807, 10978, 'Que Seja Doce S08 E38', 'http://sinalprivado.info:80/series/1533784/1533784/609528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153808, 10978, 'Que Seja Doce S08 E39', 'http://sinalprivado.info:80/series/1533784/1533784/609529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153809, 10978, 'Que Seja Doce S08 E40', 'http://sinalprivado.info:80/series/1533784/1533784/609530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153810, 10979, 'Que Seja Doce S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/609531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153811, 10979, 'Que Seja Doce S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/609532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153812, 10979, 'Que Seja Doce S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/609533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153813, 10979, 'Que Seja Doce S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/609534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153814, 10979, 'Que Seja Doce S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/609535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153815, 10979, 'Que Seja Doce S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/609536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153816, 10979, 'Que Seja Doce S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/609537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153817, 10979, 'Que Seja Doce S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/609538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153818, 10979, 'Que Seja Doce S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/609539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153819, 10979, 'Que Seja Doce S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/609540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153820, 10979, 'Que Seja Doce S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/609541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153821, 10979, 'Que Seja Doce S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/609542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153822, 10979, 'Que Seja Doce S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/609543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153823, 10979, 'Que Seja Doce S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/609544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153824, 10979, 'Que Seja Doce S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/609545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153825, 10979, 'Que Seja Doce S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/609546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153826, 10979, 'Que Seja Doce S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/609547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153827, 10979, 'Que Seja Doce S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/609548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153828, 10979, 'Que Seja Doce S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/609549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153829, 10979, 'Que Seja Doce S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/609550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153830, 10979, 'Que Seja Doce S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/609551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153831, 10979, 'Que Seja Doce S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/609552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153832, 10979, 'Que Seja Doce S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/609553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153833, 10979, 'Que Seja Doce S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/609554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153834, 10979, 'Que Seja Doce S09 E25', 'http://sinalprivado.info:80/series/1533784/1533784/609555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153835, 10979, 'Que Seja Doce S09 E26', 'http://sinalprivado.info:80/series/1533784/1533784/609556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153836, 10979, 'Que Seja Doce S09 E27', 'http://sinalprivado.info:80/series/1533784/1533784/609557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153837, 10979, 'Que Seja Doce S09 E28', 'http://sinalprivado.info:80/series/1533784/1533784/609558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153838, 10979, 'Que Seja Doce S09 E29', 'http://sinalprivado.info:80/series/1533784/1533784/609559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153839, 10979, 'Que Seja Doce S09 E30', 'http://sinalprivado.info:80/series/1533784/1533784/609560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153840, 10979, 'Que Seja Doce S09 E31', 'http://sinalprivado.info:80/series/1533784/1533784/609561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153841, 10979, 'Que Seja Doce S09 E32', 'http://sinalprivado.info:80/series/1533784/1533784/609562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153842, 10979, 'Que Seja Doce S09 E33', 'http://sinalprivado.info:80/series/1533784/1533784/609563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153843, 10979, 'Que Seja Doce S09 E34', 'http://sinalprivado.info:80/series/1533784/1533784/609564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153844, 10979, 'Que Seja Doce S09 E35', 'http://sinalprivado.info:80/series/1533784/1533784/609565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153845, 10979, 'Que Seja Doce S09 E36', 'http://sinalprivado.info:80/series/1533784/1533784/609566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153846, 10979, 'Que Seja Doce S09 E37', 'http://sinalprivado.info:80/series/1533784/1533784/609567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153847, 10979, 'Que Seja Doce S09 E38', 'http://sinalprivado.info:80/series/1533784/1533784/609568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153848, 10979, 'Que Seja Doce S09 E39', 'http://sinalprivado.info:80/series/1533784/1533784/609569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153849, 10979, 'Que Seja Doce S09 E40', 'http://sinalprivado.info:80/series/1533784/1533784/609570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153850, 10980, 'Que Seja Doce S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/609571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153851, 10980, 'Que Seja Doce S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/609572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153852, 10980, 'Que Seja Doce S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/609573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153853, 10980, 'Que Seja Doce S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/609574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153854, 10980, 'Que Seja Doce S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/609575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153855, 10980, 'Que Seja Doce S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/609576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153856, 10980, 'Que Seja Doce S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/609577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153857, 10980, 'Que Seja Doce S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/609578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153858, 10980, 'Que Seja Doce S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/609579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153859, 10980, 'Que Seja Doce S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/609580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153860, 10980, 'Que Seja Doce S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/609581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153861, 10980, 'Que Seja Doce S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/609582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153862, 10980, 'Que Seja Doce S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/609583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153863, 10980, 'Que Seja Doce S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/609584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153864, 10980, 'Que Seja Doce S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/609585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153865, 10980, 'Que Seja Doce S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/609586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153866, 10980, 'Que Seja Doce S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/609587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153867, 10980, 'Que Seja Doce S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/609588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153868, 10980, 'Que Seja Doce S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/609589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153869, 10980, 'Que Seja Doce S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/609590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153870, 10980, 'Que Seja Doce S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/609591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153871, 10980, 'Que Seja Doce S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/609592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153872, 10980, 'Que Seja Doce S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/609593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153873, 10980, 'Que Seja Doce S10 E24', 'http://sinalprivado.info:80/series/1533784/1533784/609594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153874, 10980, 'Que Seja Doce S10 E25', 'http://sinalprivado.info:80/series/1533784/1533784/609595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153875, 10980, 'Que Seja Doce S10 E26', 'http://sinalprivado.info:80/series/1533784/1533784/609596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153876, 10980, 'Que Seja Doce S10 E27', 'http://sinalprivado.info:80/series/1533784/1533784/609597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153877, 10980, 'Que Seja Doce S10 E28', 'http://sinalprivado.info:80/series/1533784/1533784/609598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153878, 10980, 'Que Seja Doce S10 E29', 'http://sinalprivado.info:80/series/1533784/1533784/609599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153879, 10980, 'Que Seja Doce S10 E30', 'http://sinalprivado.info:80/series/1533784/1533784/609600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153880, 10980, 'Que Seja Doce S10 E31', 'http://sinalprivado.info:80/series/1533784/1533784/609601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153881, 10980, 'Que Seja Doce S10 E32', 'http://sinalprivado.info:80/series/1533784/1533784/609602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153882, 10980, 'Que Seja Doce S10 E33', 'http://sinalprivado.info:80/series/1533784/1533784/609603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153883, 10980, 'Que Seja Doce S10 E34', 'http://sinalprivado.info:80/series/1533784/1533784/609604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153884, 10980, 'Que Seja Doce S10 E35', 'http://sinalprivado.info:80/series/1533784/1533784/609605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153885, 10980, 'Que Seja Doce S10 E36', 'http://sinalprivado.info:80/series/1533784/1533784/609606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153886, 10980, 'Que Seja Doce S10 E37', 'http://sinalprivado.info:80/series/1533784/1533784/609607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153887, 10980, 'Que Seja Doce S10 E38', 'http://sinalprivado.info:80/series/1533784/1533784/609608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153888, 10980, 'Que Seja Doce S10 E39', 'http://sinalprivado.info:80/series/1533784/1533784/609609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153889, 10980, 'Que Seja Doce S10 E40', 'http://sinalprivado.info:80/series/1533784/1533784/609610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8qjJypqnOkz3li3vtKsHONjULBx.jpg'),
(153890, 10981, 'Registro de Criaturas Fantasticas [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416647.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i1eaGcV27ryzZZ5xwLiFGitDPbF.jpg'),
(153891, 10981, 'Registro de Criaturas Fantasticas [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416648.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Apiqhw21cU0XulFxkxSEoYBj2ga.jpg'),
(153892, 10981, 'Registro de Criaturas Fantasticas [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416649.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5bAaQcoz7QKwUOjK9oBvKeW8Z1T.jpg'),
(153893, 10981, 'Registro de Criaturas Fantasticas [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416650.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s7eUgMmGEfXgVL0w5aGEAmnzicq.jpg'),
(153894, 10981, 'Registro de Criaturas Fantasticas [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416651.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ubbgs4VNFfiBiyN9bE6hLP3RjU.jpg'),
(153895, 10981, 'Registro de Criaturas Fantasticas [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416652.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tnUMw0pYErqUHR8D1Jd5IXCb8VG.jpg'),
(153896, 10981, 'Registro de Criaturas Fantasticas [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416653.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/f4XxeuS7X377OwmQkvhKOOjAtHH.jpg'),
(153897, 10981, 'Registro de Criaturas Fantasticas [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416654.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d1ABrxuWJHVqvMiednIDmQKJAYe.jpg'),
(153898, 10981, 'Registro de Criaturas Fantasticas [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416655.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7c07B8HivH8w6LsSgvsVos8eVJg.jpg'),
(153899, 10981, 'Registro de Criaturas Fantasticas [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416656.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bzFV0CxLebIezpqbKeIwjSsti59.jpg'),
(153900, 10981, 'Registro de Criaturas Fantasticas [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416657.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1uNOd5oWzlbMTwhkL6gZLWGhRB4.jpg'),
(153901, 10981, 'Registro de Criaturas Fantasticas [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416658.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/RHTKeuMCXUKSX36Ye81J8l5OwV.jpg'),
(153902, 10981, 'Registro de Criaturas Fantasticas [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/416659.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rPAgI8yp39PCYlfmNlWrfqlEOiB.jpg'),
(153903, 10982, 'Renascido para o Asfalto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zvKJGYwO8VpUFgWjTKM0JAjLRge.jpg'),
(153904, 10982, 'Renascido para o Asfalto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zvKJGYwO8VpUFgWjTKM0JAjLRge.jpg'),
(153905, 10982, 'Renascido para o Asfalto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zvKJGYwO8VpUFgWjTKM0JAjLRge.jpg'),
(153906, 10982, 'Renascido para o Asfalto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zvKJGYwO8VpUFgWjTKM0JAjLRge.jpg'),
(153907, 10982, 'Renascido para o Asfalto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zvKJGYwO8VpUFgWjTKM0JAjLRge.jpg'),
(153908, 10982, 'Renascido para o Asfalto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zvKJGYwO8VpUFgWjTKM0JAjLRge.jpg'),
(153909, 10982, 'Renascido para o Asfalto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zvKJGYwO8VpUFgWjTKM0JAjLRge.jpg'),
(153910, 10982, 'Renascido para o Asfalto S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zvKJGYwO8VpUFgWjTKM0JAjLRge.jpg'),
(153911, 10983, 'School Days [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416626.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJQr5gWhEaiis6KJBxFcVWAlhfI.jpg'),
(153912, 10983, 'School Days [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416627.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wDwhn9JCKeZX7kX9OEmzSVsW1Xj.jpg'),
(153913, 10983, 'School Days [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416628.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vhpdZ5UN5HFkfMobvuTzP7BneZb.jpg'),
(153914, 10983, 'School Days [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416629.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tkq6olIoSrUWxL4b83c6xLkyhDj.jpg'),
(153915, 10983, 'School Days [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416630.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5LrAyVd6LnDdvD8ZAKBbrCp8uJG.jpg'),
(153916, 10983, 'School Days [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416631.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oKJZCswPrnGJzc8ANzTRZ7vhTRk.jpg'),
(153917, 10983, 'School Days [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416632.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pFhuvZHnGMnWpWLa422Pim7OD9b.jpg'),
(153918, 10983, 'School Days [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416633.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2cZFUOhLDlaJ35UNKQcbrz3ur3P.jpg'),
(153919, 10983, 'School Days [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416634.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/87ZA2x1IPHL5XOfjwnawpwQzOjU.jpg'),
(153920, 10983, 'School Days [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416635.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2KAGusmsuZXsaakzlOXuTyeKjl7.jpg'),
(153921, 10983, 'School Days [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416636.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sPK5MvXAp7uViXZ5Rhh0h0Y35qm.jpg'),
(153922, 10983, 'School Days [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416637.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mIPvgWuFg4YcMkg6da353LudfEE.jpg'),
(153923, 10983, 'School Days [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/416638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdbi0p7w2HTtv6Oh1wUAKRIsc0m.jpg'),
(153924, 10984, 'Search WWW [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416610.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2oFtJoGlVZnKoyHz0TPo2MjUTSG.jpg'),
(153925, 10984, 'Search WWW [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416611.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cA5PavJ02RFc01oML2HXmw87PF7.jpg'),
(153926, 10984, 'Search WWW [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416612.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7J6Q5DmlyDl4Uky9SC8P0sqYxNB.jpg'),
(153927, 10984, 'Search WWW [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416613.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8OtFQVSLy92vo2GXlUyGW3PtegH.jpg'),
(153928, 10984, 'Search WWW [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416614.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/syAcwRg2zRhelQVy8fq27hfb2qB.jpg'),
(153929, 10984, 'Search WWW [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416615.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iv0JgVaD6iJOE8N51Og446IPA41.jpg'),
(153930, 10984, 'Search WWW [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416616.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wnkaao9qrWOQXOU0j9G7Y8cyukK.jpg'),
(153931, 10984, 'Search WWW [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416617.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kTTfEQcHmnmVWlPC6pDNrnTaSKf.jpg'),
(153932, 10984, 'Search WWW [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416618.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uoqVmHc9MFZPTxFYtzgOHRvniGy.jpg'),
(153933, 10984, 'Search WWW [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416619.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kgozeuZNjGvFCuUWnHjYAENRQZj.jpg'),
(153934, 10984, 'Search WWW [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416620.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zDmRK9Ao6sG6uJMKJ9pvDNVDJel.jpg'),
(153935, 10984, 'Search WWW [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416621.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tpOllixONuwCIcTCDFfDxOvUDmA.jpg'),
(153936, 10984, 'Search WWW [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/416622.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gfmGKpxSLXDPMGEctYOBYgW9ioH.jpg'),
(153937, 10984, 'Search WWW [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/416623.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/exFaeXedSfjGpT1fydIASswOqXh.jpg'),
(153938, 10984, 'Search WWW [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/416624.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hUDrKV8MB9juyTNbc7q4N7mMbys.jpg'),
(153939, 10984, 'Search WWW [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/416625.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8qiDUmnZKEbjUuDSGd0nPDEVVyg.jpg'),
(153940, 10985, 'Sobrevivencia Extrema S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6i07z6le7SPwmu2Jb5HmYmdreGN.jpg'),
(153941, 10985, 'Sobrevivencia Extrema S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6i07z6le7SPwmu2Jb5HmYmdreGN.jpg'),
(153942, 10985, 'Sobrevivencia Extrema S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6i07z6le7SPwmu2Jb5HmYmdreGN.jpg'),
(153943, 10985, 'Sobrevivencia Extrema S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6i07z6le7SPwmu2Jb5HmYmdreGN.jpg'),
(153944, 10985, 'Sobrevivencia Extrema S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6i07z6le7SPwmu2Jb5HmYmdreGN.jpg'),
(153945, 10985, 'Sobrevivencia Extrema S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6i07z6le7SPwmu2Jb5HmYmdreGN.jpg'),
(153946, 10985, 'Sobrevivencia Extrema S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6i07z6le7SPwmu2Jb5HmYmdreGN.jpg'),
(153947, 10985, 'Sobrevivencia Extrema S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6i07z6le7SPwmu2Jb5HmYmdreGN.jpg'),
(153948, 10986, 'Soul Land [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416274.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k1vKFVfVvGd6rNvppj2SSuvQMwH.jpg'),
(153949, 10986, 'Soul Land [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416275.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Advy5KxlOsMmpj2DwLTXslhBDyM.jpg'),
(153950, 10986, 'Soul Land [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416276.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/poZE7AWbcujvjC3gR0wra4QkcF3.jpg'),
(153951, 10986, 'Soul Land [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416277.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wv1L9Z9sX7mepoEeuQnxjnOCGYF.jpg'),
(153952, 10986, 'Soul Land [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416278.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5loVxZ7D34bO7IcW7xozeWbAvud.jpg'),
(153953, 10986, 'Soul Land [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416279.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iMdwfcAiCJaEnuWlvywOJDko0Q3.jpg'),
(153954, 10986, 'Soul Land [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416280.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/av9OErJ5Co4ROUNlyXFkYdwzLk2.jpg'),
(153955, 10986, 'Soul Land [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416281.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wsEemIhwQVfYZMZEZPJOGxs7eif.jpg'),
(153956, 10986, 'Soul Land [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416282.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mYHDdPjxXr65hY3quPexitlCoNo.jpg'),
(153957, 10986, 'Soul Land [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416283.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ucmilJdix4t73J9XH0LQxYiz9y0.jpg'),
(153958, 10986, 'Soul Land [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416284.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oGY2KoVUUgpBin9J6pMjR7uwWy1.jpg'),
(153959, 10986, 'Soul Land [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416285.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tRzmc3CzlgFCPm5ILaGDgKYS5p0.jpg'),
(153960, 10986, 'Soul Land [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/416286.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vx2Vp3bEJkOGsGn598VHk5w43H9.jpg'),
(153961, 10986, 'Soul Land [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/416287.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oLbWC4kjSsUsuvksNNiswckn677.jpg'),
(153962, 10986, 'Soul Land [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/416288.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zHuIcSrYg6Q2NronJLGQzHwVu9h.jpg'),
(153963, 10986, 'Soul Land [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/416289.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ecs5wwALjJDUJebuZfCN4gEmcfX.jpg'),
(153964, 10986, 'Soul Land [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/416290.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9EICbyW5yXjYXSRw9Wcsfu8OejY.jpg'),
(153965, 10986, 'Soul Land [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/416291.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sVh91FIcdisVMOC7af2Rn8udq3s.jpg'),
(153966, 10986, 'Soul Land [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/416292.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8CXbFvCpr0rINFONXkI7UXFtdXB.jpg'),
(153967, 10986, 'Soul Land [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/416293.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bRUGjuX8iSYrEWI8oA9Fn2Y5VXB.jpg'),
(153968, 10986, 'Soul Land [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/416294.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/amoP17AG1IjoRaBHXdteN6sEmdn.jpg'),
(153969, 10986, 'Soul Land [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/416295.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3Im0rOo2jRA4n86OltblYc7N11R.jpg'),
(153970, 10986, 'Soul Land [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/416296.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tRkWotZPPCFVRF7V9TdWbD1jRIv.jpg'),
(153971, 10986, 'Soul Land [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/416297.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/43w2Tu2dPMK1UHlYSyfamN6zUXC.jpg'),
(153972, 10986, 'Soul Land [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/416298.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xyGny4vFLdVzlzDJ3agP6xklXTh.jpg'),
(153973, 10986, 'Soul Land [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/416299.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l2HFIG9EI4hLbpumE5hJK7j7450.jpg'),
(153974, 10986, 'Soul Land [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/416300.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zOTO4l3P4ba9UZnLEPxyP3DNm6x.jpg'),
(153975, 10986, 'Soul Land [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/416301.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/15EGBbc51fTJK9NuMTFekxc6KvX.jpg'),
(153976, 10986, 'Soul Land [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/416302.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4vdycJY6Cic9v95KHpaaFmXV4SB.jpg'),
(153977, 10986, 'Soul Land [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/416303.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cQYiA8GQUUyT7OqSwqurW7HfCwH.jpg'),
(153978, 10986, 'Soul Land [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/416304.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mq5M3I8lHl3gILqECn1qkAx9oJd.jpg'),
(153979, 10986, 'Soul Land [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/416305.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jlcDrU0pRxoLy9OBBPHJhsMyKNk.jpg'),
(153980, 10986, 'Soul Land [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/416306.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1D2hVWuRTIegOg9mgwdNsHa5HtC.jpg'),
(153981, 10986, 'Soul Land [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/416307.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bXWz5VJq2h9PTIM8m3ylDU8dCOo.jpg'),
(153982, 10986, 'Soul Land [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/416308.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w94adgk1mkMQWmTffpifUd7MXTK.jpg'),
(153983, 10986, 'Soul Land [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/416309.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qK7KXvHeUurRPkTQ9iK71QiP94P.jpg'),
(153984, 10986, 'Soul Land [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/416310.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hTPYK59U5Rfkla62C1jBkTaxMVG.jpg'),
(153985, 10986, 'Soul Land [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/416311.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9p7Wd1xpdXHXC9Ye3yuNkbyzk12.jpg'),
(153986, 10986, 'Soul Land [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/416312.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t7WmH9VL0Tr0ScN6DDIp4PHZyo6.jpg'),
(153987, 10986, 'Soul Land [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/416313.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mZr4RvgPa3ne0VRCRM6L46ATlPl.jpg'),
(153988, 10986, 'Soul Land [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/416314.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3XL3nHce93a3aG0TfzKE6ctY87y.jpg'),
(153989, 10986, 'Soul Land [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/416315.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3eswdyEgcIAw3EIVU7E75st24Dh.jpg'),
(153990, 10986, 'Soul Land [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/416316.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xnBXeT1EOhkpGXzCW5aTOVVOfvo.jpg'),
(153991, 10986, 'Soul Land [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/416317.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5cYzV6oioCE4N0LVWhUU9x3oFrG.jpg'),
(153992, 10986, 'Soul Land [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/416318.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/opHWlEfYPRJaJBI1Zf4h0IM96cX.jpg'),
(153993, 10986, 'Soul Land [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/416319.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pHyy3yNIsdnzVoUO8wyeA5cnaH9.jpg'),
(153994, 10986, 'Soul Land [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/416320.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kWRpvr1VLiKcCTcGMZruxURLUou.jpg'),
(153995, 10986, 'Soul Land [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/416321.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/azDrGRjjLOP4qRNvowZUuGh9LPf.jpg'),
(153996, 10986, 'Soul Land [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/416322.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aUgmMJ7cRuK0GRPLKZDRbsgOEE8.jpg'),
(153997, 10986, 'Soul Land [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/416323.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/63yLUUVpmQjB9ZdlpOYjKpkhfuO.jpg'),
(153998, 10986, 'Soul Land [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/416324.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oTCR6GGcnyUtjKUnX9yFoJAYMEU.jpg'),
(153999, 10986, 'Soul Land [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/416325.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3kjRbmfxWXxZrIRVU5zd8qm28zc.jpg'),
(154000, 10986, 'Soul Land [L] S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/416326.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/baShRol1kTQQ0RfBJ7jH1xgaLgI.jpg'),
(154001, 10986, 'Soul Land [L] S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/416327.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/helviT8nJRRbmcy6gGEAIS6jDGh.jpg'),
(154002, 10986, 'Soul Land [L] S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/416328.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jSnI9gHdFfydNe7D5HgRgrC1hxU.jpg'),
(154003, 10986, 'Soul Land [L] S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/416329.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1e7AIABWPiJO5UfCnHE3FZLzvEh.jpg'),
(154004, 10986, 'Soul Land [L] S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/416330.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xkhLRemTwiGZvMkUdTKNA6g5nvC.jpg'),
(154005, 10986, 'Soul Land [L] S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/416331.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bxjQrI3rAhK8mmT70QPYeosxdeF.jpg'),
(154006, 10986, 'Soul Land [L] S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/416332.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sNKtgF6LyQUKJzeGzRIizdHCrZG.jpg'),
(154007, 10986, 'Soul Land [L] S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/416333.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6HOf1MvAEfUL3T5c7kR0PzcGj0b.jpg'),
(154008, 10986, 'Soul Land [L] S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/416334.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lewVqSjLO5DiVUdbhyWHUuORLGH.jpg'),
(154009, 10986, 'Soul Land [L] S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/416335.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s63RUJ2Mi1URBHyMBF5IJ7jgYA4.jpg'),
(154010, 10986, 'Soul Land [L] S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/416336.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bhruCJutq2SCXCpIYkQp6FIWnms.jpg'),
(154011, 10986, 'Soul Land [L] S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/416337.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xJM3bku7hm4K1cxaz4imYEYhEL4.jpg'),
(154012, 10986, 'Soul Land [L] S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/416338.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dFxRzQAWpzHjTvieliLigAmG5t6.jpg'),
(154013, 10986, 'Soul Land [L] S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/416339.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wpaOxYCAd2cXOtKjqxQg1gC2aaX.jpg'),
(154014, 10986, 'Soul Land [L] S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/416340.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xlQK4d3LzyVBmZqv7s69wTCU12D.jpg'),
(154015, 10986, 'Soul Land [L] S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/416341.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sbywnevuYqfyyhmeM4Tqofu5tJw.jpg'),
(154016, 10986, 'Soul Land [L] S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/416342.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qnmpcNyzS1oSTY3mOpGNZySBGGx.jpg'),
(154017, 10986, 'Soul Land [L] S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/416343.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bh4DXB8thRwXAATlLZq9jqp31Ua.jpg'),
(154018, 10986, 'Soul Land [L] S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/416344.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4FUar6ycuZJ8g8Xb5UCBju9aRax.jpg'),
(154019, 10986, 'Soul Land [L] S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/416345.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wqkkEfRt4Ub3a78ltcMvkafVRrt.jpg'),
(154020, 10986, 'Soul Land [L] S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/416346.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3rGjImai0xHej0YVGQq8xaIs5GX.jpg'),
(154021, 10986, 'Soul Land [L] S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/416347.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/85uw39gaHsJZqzQUJu8GbuGka34.jpg'),
(154022, 10986, 'Soul Land [L] S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/416348.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7z1SGoWYgs7ou9CNWvaAZHbsnti.jpg'),
(154023, 10986, 'Soul Land [L] S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/416349.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/37agqLnJiJ3Q4qusuyTg7MIRNGq.jpg'),
(154024, 10986, 'Soul Land [L] S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/416350.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4E4X6XDgWHovBzEwAlsnQvrSrFW.jpg'),
(154025, 10986, 'Soul Land [L] S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/416351.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/54ox8AloW24Sx46Q0AECgbOlzyU.jpg'),
(154026, 10986, 'Soul Land [L] S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/416352.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lkcYWgy79qxs8s4n3xH1XPvWBlj.jpg'),
(154027, 10986, 'Soul Land [L] S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/416353.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kg6gzNGpJlCzoZ4vdvkbi2lueJs.jpg'),
(154028, 10986, 'Soul Land [L] S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/416354.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ezJdQezVDtsTaNKab8ctiXPO0Ju.jpg'),
(154029, 10986, 'Soul Land [L] S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/416355.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8jQZ0AI09f9CoKYFKYKRX9ZIZcb.jpg'),
(154030, 10986, 'Soul Land [L] S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/416356.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dueMIzcCa7ZW6reixdODEBH3lOd.jpg'),
(154031, 10986, 'Soul Land [L] S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/416357.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/omHxEQ72MQ9L5Ypuc6Aw1rjlzeT.jpg'),
(154032, 10986, 'Soul Land [L] S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/416358.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1hqpE3ssxP30RfuGDY0qt65e6E0.jpg'),
(154033, 10986, 'Soul Land [L] S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/416359.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/en0kCKsJSTLY2O7qriksNZfgzke.jpg'),
(154034, 10986, 'Soul Land [L] S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/416360.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/79OoAh1LeUFlM6afQyxN6sECyqD.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(154035, 10986, 'Soul Land [L] S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/416361.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8I6BQN7mK4n3nlRlA69KTRYnUXE.jpg'),
(154036, 10986, 'Soul Land [L] S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/416362.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6xoUvvZUHEZtzc0VDJ1PhnAIlRz.jpg'),
(154037, 10986, 'Soul Land [L] S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/416363.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iJnXH6bK5tsOkbKtN0b62JoVJG2.jpg'),
(154038, 10986, 'Soul Land [L] S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/416364.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nczUidWGRbVcPmO7YHW9hJp1ygL.jpg'),
(154039, 10986, 'Soul Land [L] S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/416365.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9sQEWtMNkUd9mUNYoyoHqlsSrAB.jpg'),
(154040, 10986, 'Soul Land [L] S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/416366.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3GBtC1J5R9WgccIAmBl7SD5onKA.jpg'),
(154041, 10986, 'Soul Land [L] S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/416367.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uQmMvoMbIXy6PPxBv4vEmuimyuV.jpg'),
(154042, 10986, 'Soul Land [L] S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/416368.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/amEEwmfg0QC7SGNMjmR4otaL34f.jpg'),
(154043, 10986, 'Soul Land [L] S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/416369.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mABiH9IwrGLUQP2ZpigF9DbLnUe.jpg'),
(154044, 10986, 'Soul Land [L] S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/416370.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6VJpnCy0agJyBWyZTEw2FraLVHt.jpg'),
(154045, 10986, 'Soul Land [L] S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/416371.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lEC69pNM3isAZH711JDnyYFZft2.jpg'),
(154046, 10986, 'Soul Land [L] S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/416372.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9snArmmvXRHUI8SptrbEJffkg9Y.jpg'),
(154047, 10986, 'Soul Land [L] S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/416373.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8o3wWUbgdcAm7NxzFJlh1O9qT8J.jpg'),
(154048, 10986, 'Soul Land [L] S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/416374.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fAQbp4unvgvm70YHRgtHhAlQIC5.jpg'),
(154049, 10986, 'Soul Land [L] S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/416375.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6PysubLdEjBfI5qyv96RQoECDPt.jpg'),
(154050, 10986, 'Soul Land [L] S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/416376.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gG193qjQgQKM0nES3KnsyU6a9ge.jpg'),
(154051, 10986, 'Soul Land [L] S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/416377.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uAUB83GGCDwtExRsBIQyVCr5dDg.jpg'),
(154052, 10986, 'Soul Land [L] S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/416378.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qZGxlTxsLSkknXC3c8hxg7UbSNQ.jpg'),
(154053, 10986, 'Soul Land [L] S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/416379.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xeSxICJQTfOwTuTLjQiPki2LPBs.jpg'),
(154054, 10986, 'Soul Land [L] S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/416380.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8DATzGEbs7Y1fZXcJUvV2Kw5oDV.jpg'),
(154055, 10986, 'Soul Land [L] S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/416381.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vStSmNxbX87oUiwrKdHMcklUxf1.jpg'),
(154056, 10986, 'Soul Land [L] S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/416382.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z9WYOdEtQWdZM9O5O0LMarnEziK.jpg'),
(154057, 10986, 'Soul Land [L] S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/416383.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/x2kru7D5uyGldRrpOn6GV5KL2BP.jpg'),
(154058, 10986, 'Soul Land [L] S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/416384.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vAq2CJ0xOlwpt1el0HxGCSyvIUz.jpg'),
(154059, 10986, 'Soul Land [L] S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/416385.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q7i7qr5V1ZzzoJLHjfbfdrPbijo.jpg'),
(154060, 10986, 'Soul Land [L] S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/416386.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QZnB1Fkl1YFiLRgOm67x8uLFUX.jpg'),
(154061, 10986, 'Soul Land [L] S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/416387.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2LyH6446bLF5ZVUGEylQmoRZ8dy.jpg'),
(154062, 10986, 'Soul Land [L] S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/416388.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9LKjsOKummZDB84aUcr43N9N2Cn.jpg'),
(154063, 10986, 'Soul Land [L] S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/416389.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sDlPHja2lujZ5S7BAlJYfovM0Gk.jpg'),
(154064, 10986, 'Soul Land [L] S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/416390.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mx1NfmPu3CrQnxlu7PLcUuUCq9m.jpg'),
(154065, 10986, 'Soul Land [L] S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/416391.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/snffNHQJhqDYKuq072PHS3KrXcN.jpg'),
(154066, 10986, 'Soul Land [L] S01 E119', 'http://sinalprivado.info:80/series/1533784/1533784/416392.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/60Kn5noyFbLhas1DBtUgo8qd1Sm.jpg'),
(154067, 10986, 'Soul Land [L] S01 E120', 'http://sinalprivado.info:80/series/1533784/1533784/416393.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l955on3u4ymcvl4Tcm8fQ8ajORA.jpg'),
(154068, 10986, 'Soul Land [L] S01 E121', 'http://sinalprivado.info:80/series/1533784/1533784/416394.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oVVeyRTLgJIukSdLuzCj7cVAwYz.jpg'),
(154069, 10986, 'Soul Land [L] S01 E122', 'http://sinalprivado.info:80/series/1533784/1533784/416395.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yY5zb4nNPZKfA0TtR9Dgwy7sZYa.jpg'),
(154070, 10986, 'Soul Land [L] S01 E123', 'http://sinalprivado.info:80/series/1533784/1533784/416396.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jWnCidEFHfA2KLR8TLzDO2JtC3y.jpg'),
(154071, 10986, 'Soul Land [L] S01 E124', 'http://sinalprivado.info:80/series/1533784/1533784/416397.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yg0NVuFhDXXnp5MfSTg0ehtzAPP.jpg'),
(154072, 10986, 'Soul Land [L] S01 E125', 'http://sinalprivado.info:80/series/1533784/1533784/416398.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nVw9ZvdletUSBD7Ul8IijdG5BQL.jpg'),
(154073, 10986, 'Soul Land [L] S01 E126', 'http://sinalprivado.info:80/series/1533784/1533784/416399.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rx1vILl8bVrnhBonC9K9jflAHQw.jpg'),
(154074, 10986, 'Soul Land [L] S01 E127', 'http://sinalprivado.info:80/series/1533784/1533784/416400.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6btarD2SvI7dzQlNeHldyOZA95w.jpg'),
(154075, 10986, 'Soul Land [L] S01 E128', 'http://sinalprivado.info:80/series/1533784/1533784/416401.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9JtemXuO9vYuA8Z3TvL4f37dLFp.jpg'),
(154076, 10986, 'Soul Land [L] S01 E129', 'http://sinalprivado.info:80/series/1533784/1533784/416402.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1KJI7VHM2ZUOg5UHniz039mYhYQ.jpg'),
(154077, 10986, 'Soul Land [L] S01 E130', 'http://sinalprivado.info:80/series/1533784/1533784/416403.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s9MFgANyzzYjgUCMeHx749XSiBe.jpg'),
(154078, 10986, 'Soul Land [L] S01 E131', 'http://sinalprivado.info:80/series/1533784/1533784/416404.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tjr3Z0m9G9vpYE30QE6V0DQrAbH.jpg'),
(154079, 10986, 'Soul Land [L] S01 E132', 'http://sinalprivado.info:80/series/1533784/1533784/416405.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cLaToHCKdLb5NBnChS6XmGWD2kk.jpg'),
(154080, 10986, 'Soul Land [L] S01 E133', 'http://sinalprivado.info:80/series/1533784/1533784/416406.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7poIHi6uAd1IOaFIlbcGoVbUpbD.jpg'),
(154081, 10986, 'Soul Land [L] S01 E134', 'http://sinalprivado.info:80/series/1533784/1533784/416407.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s0fl8D29ye4bH3lhYb3zBtaL1oW.jpg'),
(154082, 10986, 'Soul Land [L] S01 E135', 'http://sinalprivado.info:80/series/1533784/1533784/416408.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/21st3ipXhvkgQjrH7Fl2QeevjXM.jpg'),
(154083, 10986, 'Soul Land [L] S01 E136', 'http://sinalprivado.info:80/series/1533784/1533784/416409.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sQ7dasgslxX85YpseCiBqbAz3WE.jpg'),
(154084, 10986, 'Soul Land [L] S01 E137', 'http://sinalprivado.info:80/series/1533784/1533784/416410.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tdXiwSSiDMjku9D3IjSUsyrxRfZ.jpg'),
(154085, 10986, 'Soul Land [L] S01 E138', 'http://sinalprivado.info:80/series/1533784/1533784/416411.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jVwRpAdIzr6iOpN21Bq2EX0c9Wp.jpg'),
(154086, 10986, 'Soul Land [L] S01 E139', 'http://sinalprivado.info:80/series/1533784/1533784/416412.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xLD1GsALHy9z8IyUpfF6DBHcSWL.jpg'),
(154087, 10986, 'Soul Land [L] S01 E140', 'http://sinalprivado.info:80/series/1533784/1533784/416413.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5bRTzmbhtdF4a4Y80OMrpGECC3e.jpg'),
(154088, 10986, 'Soul Land [L] S01 E141', 'http://sinalprivado.info:80/series/1533784/1533784/416414.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aBLONAQd4yJlsIxcItlggIbp1Zi.jpg'),
(154089, 10986, 'Soul Land [L] S01 E142', 'http://sinalprivado.info:80/series/1533784/1533784/416415.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hakVYP4xVzldX2CFmaSnNw0tscO.jpg'),
(154090, 10986, 'Soul Land [L] S01 E143', 'http://sinalprivado.info:80/series/1533784/1533784/416416.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dZVsQpVdSnXP9sgsloUrD0tFTml.jpg'),
(154091, 10986, 'Soul Land [L] S01 E144', 'http://sinalprivado.info:80/series/1533784/1533784/416417.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oOUXq3RmYOkhfpoZ5Lbj9s7iTBz.jpg'),
(154092, 10986, 'Soul Land [L] S01 E145', 'http://sinalprivado.info:80/series/1533784/1533784/416418.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/y3v53uQExU5qplF1fFf5o6prmDs.jpg'),
(154093, 10986, 'Soul Land [L] S01 E146', 'http://sinalprivado.info:80/series/1533784/1533784/416419.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/stHDfTCmxU93CdcO6v4Lcn1fYRT.jpg'),
(154094, 10986, 'Soul Land [L] S01 E147', 'http://sinalprivado.info:80/series/1533784/1533784/416420.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfeGtj1NgAZpg9u4s9Q3iq43lnZ.jpg'),
(154095, 10986, 'Soul Land [L] S01 E148', 'http://sinalprivado.info:80/series/1533784/1533784/416421.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5ZfMPdCKasp3DftfCP75Xp9RddZ.jpg'),
(154096, 10986, 'Soul Land [L] S01 E149', 'http://sinalprivado.info:80/series/1533784/1533784/416422.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2MV5rhber5hOzhAlTqptKYGgRNn.jpg'),
(154097, 10986, 'Soul Land [L] S01 E150', 'http://sinalprivado.info:80/series/1533784/1533784/416423.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5jphMPaxF92avMARSLMBqU4rcS.jpg'),
(154098, 10986, 'Soul Land [L] S01 E151', 'http://sinalprivado.info:80/series/1533784/1533784/416424.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tc2KBxriLxKN50a8EtJ6daxfaGX.jpg'),
(154099, 10986, 'Soul Land [L] S01 E152', 'http://sinalprivado.info:80/series/1533784/1533784/416425.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g8xafi9pnOZRnLkgXZEQxA6TOHz.jpg'),
(154100, 10986, 'Soul Land [L] S01 E153', 'http://sinalprivado.info:80/series/1533784/1533784/416426.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v12KGyfzpptU0chcA2iwzXYm6kI.jpg'),
(154101, 10986, 'Soul Land [L] S01 E154', 'http://sinalprivado.info:80/series/1533784/1533784/416427.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cPgq8FgCEI8xKzmFRSjS4pJQja0.jpg'),
(154102, 10986, 'Soul Land [L] S01 E155', 'http://sinalprivado.info:80/series/1533784/1533784/416428.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6nxfEAGjtWhUrGbAsnmyl6gfIo1.jpg'),
(154103, 10986, 'Soul Land [L] S01 E156', 'http://sinalprivado.info:80/series/1533784/1533784/416429.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dqB2KK5MgKsR6eMllEqILfqnt5h.jpg'),
(154104, 10986, 'Soul Land [L] S01 E157', 'http://sinalprivado.info:80/series/1533784/1533784/416430.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b5zF0jG5piGtI05JvmK2n37yHPy.jpg'),
(154105, 10986, 'Soul Land [L] S01 E158', 'http://sinalprivado.info:80/series/1533784/1533784/416431.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iy84qSaLfC9khN1kwXKrT5qVo76.jpg'),
(154106, 10986, 'Soul Land [L] S01 E159', 'http://sinalprivado.info:80/series/1533784/1533784/416432.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n0MvwkiaIG7Rea8dSmoSzT08Fp9.jpg'),
(154107, 10986, 'Soul Land [L] S01 E160', 'http://sinalprivado.info:80/series/1533784/1533784/416433.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lhhAS3sGSPNmWfcFVpTy8F4OQOn.jpg'),
(154108, 10986, 'Soul Land [L] S01 E161', 'http://sinalprivado.info:80/series/1533784/1533784/416434.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kYTgwgKHFFF2YBXbfX2BIlMl3rF.jpg'),
(154109, 10986, 'Soul Land [L] S01 E162', 'http://sinalprivado.info:80/series/1533784/1533784/416435.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kxMWmjhQKgqcW6MQrwz7toAarR4.jpg'),
(154110, 10986, 'Soul Land [L] S01 E163', 'http://sinalprivado.info:80/series/1533784/1533784/416436.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xM7RZh65mmYQ6bYwD7fDN3Y9LwB.jpg'),
(154111, 10986, 'Soul Land [L] S01 E164', 'http://sinalprivado.info:80/series/1533784/1533784/416437.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8CooJ0WoZy26IEpSTbtBLvtWGBi.jpg'),
(154112, 10986, 'Soul Land [L] S01 E165', 'http://sinalprivado.info:80/series/1533784/1533784/416438.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/57cEs1jzJTUgsX7sAXe96C9Wosr.jpg'),
(154113, 10986, 'Soul Land [L] S01 E166', 'http://sinalprivado.info:80/series/1533784/1533784/416439.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t1N1L0mdeBvIie0UXygiHNADGry.jpg'),
(154114, 10986, 'Soul Land [L] S01 E167', 'http://sinalprivado.info:80/series/1533784/1533784/416440.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xPcHUOMKS5eu3ZjECDsrlm96xyq.jpg'),
(154115, 10986, 'Soul Land [L] S01 E168', 'http://sinalprivado.info:80/series/1533784/1533784/416441.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zgdsma1zAoGU7xwciOK9NimnVnq.jpg'),
(154116, 10986, 'Soul Land [L] S01 E169', 'http://sinalprivado.info:80/series/1533784/1533784/416442.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rq32FRClEqWRCb7qxN4NlvbM34z.jpg'),
(154117, 10986, 'Soul Land [L] S01 E170', 'http://sinalprivado.info:80/series/1533784/1533784/416443.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kTcyVZkovEyq19U75HF0kT2ooY9.jpg'),
(154118, 10986, 'Soul Land [L] S01 E171', 'http://sinalprivado.info:80/series/1533784/1533784/416444.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k5WAsu9PClAuDwSQOghCCOe5muw.jpg'),
(154119, 10986, 'Soul Land [L] S01 E172', 'http://sinalprivado.info:80/series/1533784/1533784/416445.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fOOZHhn2KE0KfuKFXGgfHPckIld.jpg'),
(154120, 10986, 'Soul Land [L] S01 E173', 'http://sinalprivado.info:80/series/1533784/1533784/416446.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qWnG61JIzdXeKgLEMRbOK58syS1.jpg'),
(154121, 10986, 'Soul Land [L] S01 E174', 'http://sinalprivado.info:80/series/1533784/1533784/416447.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n5MF8Ksr7u8FnMxiuvmC2dZGA3M.jpg'),
(154122, 10986, 'Soul Land [L] S01 E175', 'http://sinalprivado.info:80/series/1533784/1533784/416448.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3SF2D9O7JF9QgzX8wicu92TmCjv.jpg'),
(154123, 10986, 'Soul Land [L] S01 E176', 'http://sinalprivado.info:80/series/1533784/1533784/416449.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qNdHsdc3UbLnfrQRnqL88P7iqDS.jpg'),
(154124, 10986, 'Soul Land [L] S01 E177', 'http://sinalprivado.info:80/series/1533784/1533784/416450.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jESHTbcRFueudbq7yFHw1z2ZtDl.jpg'),
(154125, 10986, 'Soul Land [L] S01 E178', 'http://sinalprivado.info:80/series/1533784/1533784/416451.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/UieA159FnWNFAI5WK6EuzxXApI.jpg'),
(154126, 10986, 'Soul Land [L] S01 E179', 'http://sinalprivado.info:80/series/1533784/1533784/416452.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/viJzxLE1mD6sZTXJIRNoQNsEnk8.jpg'),
(154127, 10986, 'Soul Land [L] S01 E180', 'http://sinalprivado.info:80/series/1533784/1533784/416453.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oOdCh5HuRX7juppteOBPAufB0jy.jpg'),
(154128, 10986, 'Soul Land [L] S01 E181', 'http://sinalprivado.info:80/series/1533784/1533784/416454.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vI7PLlcMPsLrawI8K3MhqcW5mLB.jpg'),
(154129, 10986, 'Soul Land [L] S01 E182', 'http://sinalprivado.info:80/series/1533784/1533784/416455.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9SK9OPcUxRMNoe4m5BgsctRo2v1.jpg'),
(154130, 10986, 'Soul Land [L] S01 E183', 'http://sinalprivado.info:80/series/1533784/1533784/416456.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/BRf0bP3TNzsur4mMHLs4Rqhgix.jpg'),
(154131, 10986, 'Soul Land [L] S01 E184', 'http://sinalprivado.info:80/series/1533784/1533784/416457.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2zVj00S2wOb4A9k7nvJJg0sC2jQ.jpg'),
(154132, 10986, 'Soul Land [L] S01 E185', 'http://sinalprivado.info:80/series/1533784/1533784/416458.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vtce54fwr7zmlEt2l1qp6V0H0EC.jpg'),
(154133, 10986, 'Soul Land [L] S01 E186', 'http://sinalprivado.info:80/series/1533784/1533784/416459.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kOLxF05G1EtzNDvWDpUxtkQIm0n.jpg'),
(154134, 10986, 'Soul Land [L] S01 E187', 'http://sinalprivado.info:80/series/1533784/1533784/416460.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gmpbTW5ICF9nPKgcD9jjpOJNVOK.jpg'),
(154135, 10986, 'Soul Land [L] S01 E188', 'http://sinalprivado.info:80/series/1533784/1533784/416461.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/k3jbem2nbS793SdHyqlDUSAPvfK.jpg'),
(154136, 10986, 'Soul Land [L] S01 E189', 'http://sinalprivado.info:80/series/1533784/1533784/416462.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/r0nYXzwY8b8rjDAehq61ZPz5tWr.jpg'),
(154137, 10986, 'Soul Land [L] S01 E190', 'http://sinalprivado.info:80/series/1533784/1533784/416463.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8rAdnnanIKXuVaApGaTbBWcBpmK.jpg'),
(154138, 10986, 'Soul Land [L] S01 E191', 'http://sinalprivado.info:80/series/1533784/1533784/416464.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a3q5HtxMQRNb1fFsB8NyTYfGBaN.jpg'),
(154139, 10986, 'Soul Land [L] S01 E192', 'http://sinalprivado.info:80/series/1533784/1533784/416465.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vp3RySQF4dJ0e3sTEgzyJWfEGu9.jpg'),
(154140, 10986, 'Soul Land [L] S01 E193', 'http://sinalprivado.info:80/series/1533784/1533784/416466.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/o8cFi5tMHAJ0ZQovVsi0n5r8fFj.jpg'),
(154141, 10986, 'Soul Land [L] S01 E194', 'http://sinalprivado.info:80/series/1533784/1533784/416467.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/NGsOy4PTG2t5QvJ1WnwbOO5dz.jpg'),
(154142, 10986, 'Soul Land [L] S01 E195', 'http://sinalprivado.info:80/series/1533784/1533784/416468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uwAB877o0cTeP4qNOlo1vUJDMzB.jpg'),
(154143, 10986, 'Soul Land [L] S01 E196', 'http://sinalprivado.info:80/series/1533784/1533784/416469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xOXTGHDSdpReIQmUlo7AfpPaMWw.jpg'),
(154144, 10986, 'Soul Land [L] S01 E197', 'http://sinalprivado.info:80/series/1533784/1533784/416470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gqt4kjFENUskJdnyrPtSJDEGc2r.jpg'),
(154145, 10986, 'Soul Land [L] S01 E198', 'http://sinalprivado.info:80/series/1533784/1533784/416471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ekLJvg4FnxNcn4wjC0TMWCfVhL2.jpg'),
(154146, 10986, 'Soul Land [L] S01 E199', 'http://sinalprivado.info:80/series/1533784/1533784/416472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/chb2RsQScoCx3mY2L7JOUyYHE2k.jpg'),
(154147, 10986, 'Soul Land [L] S01 E200', 'http://sinalprivado.info:80/series/1533784/1533784/416473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jEH3PJ8QLV8qkman6qr9bVOQNJC.jpg'),
(154148, 10986, 'Soul Land [L] S01 E201', 'http://sinalprivado.info:80/series/1533784/1533784/416474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fWj1CsxbobI57Kg4ORBd3CQHlDy.jpg'),
(154149, 10986, 'Soul Land [L] S01 E202', 'http://sinalprivado.info:80/series/1533784/1533784/416475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/18Hx0B2I5glCA7KINxLOEkzFCq.jpg'),
(154150, 10986, 'Soul Land [L] S01 E203', 'http://sinalprivado.info:80/series/1533784/1533784/416476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tuppzDRmkQtzn4dtHrEeIo9Lfnb.jpg'),
(154151, 10986, 'Soul Land [L] S01 E204', 'http://sinalprivado.info:80/series/1533784/1533784/416477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jcErYap3Tf1KFYuiRsbbpA5cImb.jpg'),
(154152, 10986, 'Soul Land [L] S01 E205', 'http://sinalprivado.info:80/series/1533784/1533784/416478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/10JrnUf1sp7iwIpF3VgrGM7M8zT.jpg'),
(154153, 10986, 'Soul Land [L] S01 E206', 'http://sinalprivado.info:80/series/1533784/1533784/416479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ak9kJJSVNxWBJkJ8pCCoaFUv2lE.jpg'),
(154154, 10986, 'Soul Land [L] S01 E207', 'http://sinalprivado.info:80/series/1533784/1533784/416480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aa4xOwEhipUjSGXo3rZ4afa1DUp.jpg'),
(154155, 10986, 'Soul Land [L] S01 E208', 'http://sinalprivado.info:80/series/1533784/1533784/416481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rSSWSKGt6hrGs8gLvHPQ4mf7f3y.jpg'),
(154156, 10986, 'Soul Land [L] S01 E209', 'http://sinalprivado.info:80/series/1533784/1533784/416482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dRalpJcGlK9roEF9E0W1z8caozh.jpg'),
(154157, 10986, 'Soul Land [L] S01 E210', 'http://sinalprivado.info:80/series/1533784/1533784/416483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/XaD8bC7rP0wfKwtryrxgtYKeZM.jpg'),
(154158, 10986, 'Soul Land [L] S01 E211', 'http://sinalprivado.info:80/series/1533784/1533784/416484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cvpko5Cj7ln3HgSbtX1Uu5INdoh.jpg'),
(154159, 10986, 'Soul Land [L] S01 E212', 'http://sinalprivado.info:80/series/1533784/1533784/416485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2VuxL9vjtzvSLybBOFTYfHtSUen.jpg'),
(154160, 10986, 'Soul Land [L] S01 E213', 'http://sinalprivado.info:80/series/1533784/1533784/416486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ig9m1Iui2rhyICniT4wDOYP2Wix.jpg'),
(154161, 10986, 'Soul Land [L] S01 E214', 'http://sinalprivado.info:80/series/1533784/1533784/416487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vqH1inLKkE4ulwQIRI7lAeAVCQ3.jpg'),
(154162, 10986, 'Soul Land [L] S01 E215', 'http://sinalprivado.info:80/series/1533784/1533784/416488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pUTgdIFkaR7UFnin3n9kL1usUic.jpg'),
(154163, 10986, 'Soul Land [L] S01 E216', 'http://sinalprivado.info:80/series/1533784/1533784/416489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t2nHHEPREf451tQIqTRyExXNNDO.jpg'),
(154164, 10986, 'Soul Land [L] S01 E217', 'http://sinalprivado.info:80/series/1533784/1533784/416490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/a7x5zj1NtaMMaWrPwS4TSxogIXp.jpg'),
(154165, 10986, 'Soul Land [L] S01 E218', 'http://sinalprivado.info:80/series/1533784/1533784/416491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yH7AD3MKOHMdeunhlbCEAjNzHbT.jpg'),
(154166, 10986, 'Soul Land [L] S01 E219', 'http://sinalprivado.info:80/series/1533784/1533784/416492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1Xr69GVHhW66SkGZdKEhU29Z9kg.jpg'),
(154167, 10986, 'Soul Land [L] S01 E220', 'http://sinalprivado.info:80/series/1533784/1533784/416493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUgnAdRH8KdxsIgwHv9LuQdRGie.jpg'),
(154168, 10986, 'Soul Land [L] S01 E221', 'http://sinalprivado.info:80/series/1533784/1533784/416494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gnrt5RrItChROLZsE3xXHk5Gi6e.jpg'),
(154169, 10986, 'Soul Land [L] S01 E222', 'http://sinalprivado.info:80/series/1533784/1533784/416495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ntJ8kCXKiHQsq3kWeWGkjmkaJ9b.jpg'),
(154170, 10986, 'Soul Land [L] S01 E223', 'http://sinalprivado.info:80/series/1533784/1533784/416496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1hVK7MNSw0QFDuvZYRqwzBWVugH.jpg'),
(154171, 10986, 'Soul Land [L] S01 E224', 'http://sinalprivado.info:80/series/1533784/1533784/416497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9QUPE5euoHFwLr0px5LWDKn9I6M.jpg'),
(154172, 10986, 'Soul Land [L] S01 E225', 'http://sinalprivado.info:80/series/1533784/1533784/416498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7PtuMv8N8SGpSVt9UgeINvJeX2J.jpg'),
(154173, 10986, 'Soul Land [L] S01 E226', 'http://sinalprivado.info:80/series/1533784/1533784/416499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dTKDzpCaXVIMCr90Ixsm2xEld00.jpg'),
(154174, 10986, 'Soul Land [L] S01 E227', 'http://sinalprivado.info:80/series/1533784/1533784/416500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oaBE5tcXoWxpUl6rpYCC5jSRJgM.jpg'),
(154175, 10986, 'Soul Land [L] S01 E228', 'http://sinalprivado.info:80/series/1533784/1533784/416501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zyu4lT8TrDykFsbGOrAkfMrIQQ8.jpg'),
(154176, 10986, 'Soul Land [L] S01 E229', 'http://sinalprivado.info:80/series/1533784/1533784/416502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AmsbkfEQ5G8Qj3nQk8hTrbvLgeN.jpg'),
(154177, 10986, 'Soul Land [L] S01 E230', 'http://sinalprivado.info:80/series/1533784/1533784/416503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pjqJA5Kgoz2m78b0H1ttUS4tzCp.jpg'),
(154178, 10986, 'Soul Land [L] S01 E231', 'http://sinalprivado.info:80/series/1533784/1533784/416504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v6NrwPb4ihg1fJtirp1oiDvomJw.jpg'),
(154179, 10986, 'Soul Land [L] S01 E232', 'http://sinalprivado.info:80/series/1533784/1533784/416505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gw8OqRLCqH9vKQAu4WEZmMdJ3wi.jpg'),
(154180, 10986, 'Soul Land [L] S01 E233', 'http://sinalprivado.info:80/series/1533784/1533784/416506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rCVBAAa2gLfDQeOeI4aYZz5qn9C.jpg'),
(154181, 10986, 'Soul Land [L] S01 E234', 'http://sinalprivado.info:80/series/1533784/1533784/416507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yvtP31DeBWc7CYQOOKZcIOEHz3c.jpg'),
(154182, 10986, 'Soul Land [L] S01 E235', 'http://sinalprivado.info:80/series/1533784/1533784/416508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gw4eMc1lO9GfSoZVDjGv6YEj0Yg.jpg'),
(154183, 10986, 'Soul Land [L] S01 E236', 'http://sinalprivado.info:80/series/1533784/1533784/416509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/khmQlnmMDWGon7F1WbZt6bDnzZW.jpg'),
(154184, 10986, 'Soul Land [L] S01 E237', 'http://sinalprivado.info:80/series/1533784/1533784/416510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hA4cUxssYoePCetuJMiJtFlaXXz.jpg'),
(154185, 10986, 'Soul Land [L] S01 E238', 'http://sinalprivado.info:80/series/1533784/1533784/416511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7nEzfOdcbjogOhbakyQqmzgC6qI.jpg'),
(154186, 10986, 'Soul Land [L] S01 E239', 'http://sinalprivado.info:80/series/1533784/1533784/416512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/w3Xb4CVKhhQ6slzGqyKa2Fbiig2.jpg'),
(154187, 10986, 'Soul Land [L] S01 E240', 'http://sinalprivado.info:80/series/1533784/1533784/416513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yo8gvhX3alNgAdvEXirra6G55Vx.jpg'),
(154188, 10986, 'Soul Land [L] S01 E241', 'http://sinalprivado.info:80/series/1533784/1533784/416514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sfiKWPYoboXEC2t17e4Gy57EzzM.jpg'),
(154189, 10986, 'Soul Land [L] S01 E242', 'http://sinalprivado.info:80/series/1533784/1533784/416515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/3NFhbVtHXHAdcT742s0lNLi05r4.jpg'),
(154190, 10986, 'Soul Land [L] S01 E243', 'http://sinalprivado.info:80/series/1533784/1533784/416516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xk26xALqC3rHUTvQJFAueGWT82Q.jpg'),
(154191, 10986, 'Soul Land [L] S01 E244', 'http://sinalprivado.info:80/series/1533784/1533784/416517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/duzFO12uh8CiiO982eRdWA3GObS.jpg'),
(154192, 10986, 'Soul Land [L] S01 E245', 'http://sinalprivado.info:80/series/1533784/1533784/416518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/et2arJ8IcAqmDllNZwRmxu9EyIx.jpg'),
(154193, 10986, 'Soul Land [L] S01 E246', 'http://sinalprivado.info:80/series/1533784/1533784/416519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qtt0wQO82i1Bxyy6ZsPXGO9ofn9.jpg'),
(154194, 10986, 'Soul Land [L] S01 E247', 'http://sinalprivado.info:80/series/1533784/1533784/416520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/p6qGs9RFzMw3he5gtEr0T9Tt7RU.jpg'),
(154195, 10986, 'Soul Land [L] S01 E248', 'http://sinalprivado.info:80/series/1533784/1533784/416521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cqoifV8I5RDrtKlUL1FClgYJPFY.jpg'),
(154196, 10986, 'Soul Land [L] S01 E249', 'http://sinalprivado.info:80/series/1533784/1533784/416522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q5VhnwZbs6F05fWiSYdDmRWUQVn.jpg'),
(154197, 10986, 'Soul Land [L] S01 E250', 'http://sinalprivado.info:80/series/1533784/1533784/416523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jKT2v0F01pwFtDW3lRVUsN0gEuW.jpg'),
(154198, 10986, 'Soul Land [L] S01 E251', 'http://sinalprivado.info:80/series/1533784/1533784/416524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8xf8aQxuZmFQGYtxAaefGRFsnJ4.jpg'),
(154199, 10986, 'Soul Land [L] S01 E252', 'http://sinalprivado.info:80/series/1533784/1533784/416525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zEHiDSg0l6uiJMkQZWpDPXmOXRP.jpg'),
(154200, 10986, 'Soul Land [L] S01 E253', 'http://sinalprivado.info:80/series/1533784/1533784/416526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7QdISDKPpDJ9zW3tFjbHkosKpAv.jpg'),
(154201, 10986, 'Soul Land [L] S01 E254', 'http://sinalprivado.info:80/series/1533784/1533784/416527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/46P6Dd0zobeLH02y288N2AHEAnJ.jpg'),
(154202, 10986, 'Soul Land [L] S01 E255', 'http://sinalprivado.info:80/series/1533784/1533784/416528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/km7FbUGFutmkHaZcgZ4eMVZd7hE.jpg'),
(154203, 10986, 'Soul Land [L] S01 E256', 'http://sinalprivado.info:80/series/1533784/1533784/416529.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/94y8R4246LHT76Jt2RzQjg1GbPS.jpg'),
(154204, 10986, 'Soul Land [L] S01 E257', 'http://sinalprivado.info:80/series/1533784/1533784/416530.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tUDPwlShY1Z8C9PL2l6UM88DW1S.jpg'),
(154205, 10986, 'Soul Land [L] S01 E258', 'http://sinalprivado.info:80/series/1533784/1533784/416531.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eSOOglc031RVPbr6pUsLVkcpDNx.jpg'),
(154206, 10986, 'Soul Land [L] S01 E259', 'http://sinalprivado.info:80/series/1533784/1533784/416532.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6WxDhHZ2o6tVE8CfTJ8Rk4WymVx.jpg'),
(154207, 10986, 'Soul Land [L] S01 E260', 'http://sinalprivado.info:80/series/1533784/1533784/416533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6XP9M77xleZhgPN4kFgRoUDgGSC.jpg'),
(154208, 10986, 'Soul Land [L] S01 E261', 'http://sinalprivado.info:80/series/1533784/1533784/416534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lhwHjQUAeBiuWb3qIXWCNT4yhwP.jpg'),
(154209, 10986, 'Soul Land [L] S01 E262', 'http://sinalprivado.info:80/series/1533784/1533784/416535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vR2a5tXdHGWM6m1wqnbyKzsevIR.jpg'),
(154210, 10986, 'Soul Land [L] S01 E263', 'http://sinalprivado.info:80/series/1533784/1533784/416536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lSiDAVlM3ZnEPD3MLdFZTg6nCq7.jpg'),
(154211, 10986, 'Soul Land [L] S01 E264', 'http://sinalprivado.info:80/series/1533784/1533784/416537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yugdnpZa8yxRocG00QWaflGr5DW.jpg'),
(154212, 10986, 'Soul Land [L] S01 E265', 'http://sinalprivado.info:80/series/1533784/1533784/416538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o80kcyeLqMHggWtcskg2E9hLQGB.jpg'),
(154213, 10987, 'Teen Torture Inc [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgKOWgz1dIimFM26Fvu8K9JYXnc.jpg'),
(154214, 10987, 'Teen Torture Inc [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgKOWgz1dIimFM26Fvu8K9JYXnc.jpg'),
(154215, 10987, 'Teen Torture Inc [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mgKOWgz1dIimFM26Fvu8K9JYXnc.jpg'),
(154216, 10988, 'The Jetty [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416597.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9l5zorZbDuxh7BrXqJ0bXAM4UwN.jpg'),
(154217, 10988, 'The Jetty [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416598.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7j9fo50MkIxeHHLnI6VpDWWMCVB.jpg'),
(154218, 10988, 'The Jetty [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8NFkGx0L6tobGOeoHohO6ycXt6G.jpg'),
(154219, 10988, 'The Jetty [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8NFkGx0L6tobGOeoHohO6ycXt6G.jpg'),
(154220, 10989, 'Those About to Die [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416592.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qGU2b17L1DaXyldPOlsou8vKWxD.jpg'),
(154221, 10989, 'Those About to Die [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416593.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6H922s5XmSuslOyCWfet8bLHg3L.jpg'),
(154222, 10989, 'Those About to Die [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416594.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eMz4xu5FFBEb8kdDRMPtBXiYyD3.jpg'),
(154223, 10989, 'Those About to Die [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416595.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8gNE80H5YvuUjTaiCoxgb1IUTr5.jpg'),
(154224, 10989, 'Those About to Die [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416596.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mJ4VBsDGEfFqVlNEkUR1wJIdS2r.jpg'),
(154225, 10989, 'Those About to Die [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/422922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvz0m4MJ8sAj6yMcQdwN07bNjRY.jpg'),
(154226, 10989, 'Those About to Die [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/422923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvz0m4MJ8sAj6yMcQdwN07bNjRY.jpg'),
(154227, 10989, 'Those About to Die [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/422924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvz0m4MJ8sAj6yMcQdwN07bNjRY.jpg'),
(154228, 10989, 'Those About to Die [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/422925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvz0m4MJ8sAj6yMcQdwN07bNjRY.jpg'),
(154229, 10989, 'Those About to Die [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/422926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gvz0m4MJ8sAj6yMcQdwN07bNjRY.jpg'),
(154230, 10990, 'Ueno san wa Bukiyou [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416580.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/b16DuUMXZJU1WFbRNujLIR1e6h0.jpg'),
(154231, 10990, 'Ueno san wa Bukiyou [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416581.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/uVYZx1Zm3ab5ur89xnlmyd2IKAt.jpg'),
(154232, 10990, 'Ueno san wa Bukiyou [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416582.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9RQ44j2HKVI6dRaEyBGGW1x7Z3.jpg'),
(154233, 10990, 'Ueno san wa Bukiyou [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416583.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/B3O8UGmzgdU9BO0vUqSkKnGrAB.jpg'),
(154234, 10990, 'Ueno san wa Bukiyou [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416584.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pdmQ1SxvRVjTvGLEbBFJRXuBFSK.jpg'),
(154235, 10990, 'Ueno san wa Bukiyou [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416585.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z8hGW1w62TCWSaaCRw2QNsroJEF.jpg'),
(154236, 10990, 'Ueno san wa Bukiyou [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416586.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nGxiBHeJ86yTsnF8YA6XHapwLYu.jpg'),
(154237, 10990, 'Ueno san wa Bukiyou [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416587.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t0niUuQlSJyjANIMUCpQHs1Lw0w.jpg'),
(154238, 10990, 'Ueno san wa Bukiyou [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416588.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8fTdsmQOjG0rkf4y3b9bMqVdLKg.jpg'),
(154239, 10990, 'Ueno san wa Bukiyou [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416589.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z7VmmsEH2o3CUvhxFzGkMew2cTQ.jpg'),
(154240, 10990, 'Ueno san wa Bukiyou [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416590.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lkKAmw47lADqOqqQHmRxfS7FLti.jpg'),
(154241, 10990, 'Ueno san wa Bukiyou [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416591.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rx9ejSGpS9BpOi3hUaUGsheqJc.jpg'),
(154242, 10991, 'Un Go [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uzsz4NmGe0Q77bLjk7FKa9eV5Gm.jpg'),
(154243, 10991, 'Un Go [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/agea6x2z9x3s8hbhonCvXluduYS.jpg'),
(154244, 10991, 'Un Go [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2nbmTR7sKR9M1G3KrpIG6SNziuy.jpg'),
(154245, 10991, 'Un Go [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mgMruBbfV8HWQYg6b9dCAFrgKI.jpg'),
(154246, 10991, 'Un Go [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5h6Ce4JLlPO57mhbUF4yEwFogy.jpg'),
(154247, 10991, 'Un Go [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AndYBE4DOVEeQ7aCzTIcrDDJqNp.jpg'),
(154248, 10991, 'Un Go [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4rjvLFMxKmz9eTGQoVFyS6o6GjI.jpg'),
(154249, 10991, 'Un Go [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cEJkWOjEiWvx2RBgUkIar3fjFxQ.jpg'),
(154250, 10991, 'Un Go [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ntmYOjrkUZCipyT6ftZt6jgURDA.jpg'),
(154251, 10991, 'Un Go [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416577.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/sr9uulQGOfjceKt1bJJpEgdmQb5.jpg'),
(154252, 10991, 'Un Go [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416578.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c5VXwGuxLuIKPXqMgBnYRgQ7LdP.jpg'),
(154253, 10991, 'Un Go [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416579.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7X2eydoCUsPngX3PuF6unazZzqK.jpg'),
(154254, 10992, 'Vespera [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pMUPozXITqDFqHiscm2K8Qkc5TX.jpg'),
(154255, 10992, 'Vespera [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hmWYSsX4qzM5sDIzVEq2iJDAPNc.jpg'),
(154256, 10992, 'Vespera [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zlZiyar6i7E01SlYz14hz0zS3Rw.jpg'),
(154257, 10992, 'Vespera [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dIQZQWZeSawRjG8zbLmtAr3IuZu.jpg'),
(154258, 10992, 'Vespera [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rZpeUw7G2auhZJB2Brv6kkaNswS.jpg'),
(154259, 10992, 'Vespera [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g6AKu9RDmSqAU7XzXVmEqQxX7y5.jpg'),
(154260, 10992, 'Vespera [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lxtoYPALie73MXmWA5UgsB5132s.jpg'),
(154261, 10992, 'Vespera [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5UMvbaUTTkQsc30KImwUWRk9d0H.jpg'),
(154262, 10992, 'Vespera [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1ejsFOJFbbz7anx8Ha4SCn8i09k.jpg'),
(154263, 10992, 'Vespera [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n5pxYpfjc0FDwGH5ElFlV7rm78M.jpg'),
(154264, 10992, 'Vespera [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pCfyZHjH6ROYoYmlx7zP6Kli2h1.jpg'),
(154265, 10992, 'Vespera [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/l4cgX6otAa172Zjr1xcii56wIE0.jpg'),
(154266, 10992, 'Vespera [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/416564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wt6Ifo75gMnixvE4JN0nSbP9GMl.jpg'),
(154267, 10992, 'Vespera [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/416565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/c03W1JcOVKx7ojsOridKK8fXWp.jpg'),
(154268, 10992, 'Vespera [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/416566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pzWkF67YFIilmDjnEWY94aghhua.jpg'),
(154269, 10992, 'Vespera [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/416567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jgaB4OMpc6TfYi2o1P60a5h71dH.jpg'),
(154270, 10993, 'Wind Breaker S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/416539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/g84xbY09pycSbUHIf37ehvtruoL.jpg'),
(154271, 10993, 'Wind Breaker S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/416540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/9Ld4WJiU31CZKn4kj3iiajlVMg3.jpg'),
(154272, 10993, 'Wind Breaker S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/416541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jDCzX14ewVMUDKeE0lNkUGWUaer.jpg'),
(154273, 10993, 'Wind Breaker S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/416542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zkegatnupvc45ilhARSSaH8ghbC.jpg'),
(154274, 10993, 'Wind Breaker S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/416543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qSVvOx05fLB0YuuCvz5wkQEMcup.jpg'),
(154275, 10993, 'Wind Breaker S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/416544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/AjByIqC431kE3r4XXAxogyvPOwg.jpg'),
(154276, 10993, 'Wind Breaker S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/416545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nceIP73rvOb8v2suNmmJGmNcYGe.jpg'),
(154277, 10993, 'Wind Breaker S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/416546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7azHDs1BZFgDhQcdMCZ1MCJFU47.jpg'),
(154278, 10993, 'Wind Breaker S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/416547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cl4Qk9iAIEBONRFw0ipG1W2UNVB.jpg'),
(154279, 10993, 'Wind Breaker S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/416548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/biWhvQJFdMDtWESbtPjeVPibF0n.jpg'),
(154280, 10993, 'Wind Breaker S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/416549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2okNdGHLbTzb5KdY9kNWkEV19GE.jpg'),
(154281, 10993, 'Wind Breaker S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/416550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ayihh6LIUKJgHPmSZFu04C3Fbto.jpg'),
(154282, 10993, 'Wind Breaker S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/416551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rNIv35v842nTpwUiOSHePaCRwOO.jpg'),
(154283, 10994, 'Wind Breaker S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/867816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(154284, 10994, 'Wind Breaker S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/867817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(154285, 10994, 'Wind Breaker S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/867818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(154286, 10994, 'Wind Breaker S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/867819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(154287, 10994, 'Wind Breaker S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/867820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(154288, 10994, 'Wind Breaker S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/867821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(154289, 10994, 'Wind Breaker S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/867822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(154290, 10994, 'Wind Breaker S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/867823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(154291, 10994, 'Wind Breaker S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/867824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(154292, 10994, 'Wind Breaker S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/867825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(154293, 10994, 'Wind Breaker S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/867826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(154294, 10994, 'Wind Breaker S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/867827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c2wfIKUPcQY0tiyiOmY7ItHtNO9.jpg'),
(154295, 10995, '30 Segundos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/418092.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bE1enTatyakSsmSbb7iTlhjSbMB.jpg'),
(154296, 10995, '30 Segundos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/418093.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5oBHThTxty2KEPnARQOXIMr1Vzj.jpg'),
(154297, 10995, '30 Segundos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/418094.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rGishSFdOZIVsTPSRlugpn2zPHQ.jpg'),
(154298, 10995, '30 Segundos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/418095.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hiJvPf0Zr1PflhyBN9eJRSco6Wa.jpg'),
(154299, 10995, '30 Segundos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/418096.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jHe94yCLOKq5y7EPqMpkGhZCd3l.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(154300, 10996, 'Acumuladores S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/418091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/XJHZ2WgSs7UXcRSfx8t45dFHNh.jpg'),
(154301, 10997, 'Ursos Sem Curso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/420481.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/igXMfJ9e9ufLSF0TmA3oTJ3tEkU.jpg'),
(154302, 10997, 'Ursos Sem Curso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/420482.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qPlu2xYvpeeR0LKnDC3Uv2WLU4G.jpg'),
(154303, 10997, 'Ursos Sem Curso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/420483.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzbgXo27QMO0VKwmeYawYKeFbAi.jpg'),
(154304, 10997, 'Ursos Sem Curso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/420484.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dvpI9kyuJA3sli1rQgneFPIQHh8.jpg'),
(154305, 10997, 'Ursos Sem Curso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/420485.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kv5n7BjXuU8ZUoLBJFTOfNRxOQx.jpg'),
(154306, 10997, 'Ursos Sem Curso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/420486.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5jzByTp8OgjHnNugWFhmnwf9Obn.jpg'),
(154307, 10997, 'Ursos Sem Curso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/420487.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hnuaeXkxTTwJR0GuAHUqMWQH0Lc.jpg'),
(154308, 10997, 'Ursos Sem Curso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/420488.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/goqgfk21SXWOgEa1eqJNLt9npah.jpg'),
(154309, 10997, 'Ursos Sem Curso S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/420489.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/om691TpcgKG8AyZjTBimZAyh5yo.jpg'),
(154310, 10997, 'Ursos Sem Curso S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/420490.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/d41DrMa4uI8xkB5wVS7kIs2JBcA.jpg'),
(154311, 10997, 'Ursos Sem Curso S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/420491.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7XhlORIx7PSk8Rfvbpy1oH0JOSO.jpg'),
(154312, 10997, 'Ursos Sem Curso S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/420492.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cFqENyVFK9c2l3tuPIHd0yxiOYt.jpg'),
(154313, 10997, 'Ursos Sem Curso S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/420493.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fvJa4n3AfKjcpbXLKrZqa99u0NV.jpg'),
(154314, 10997, 'Ursos Sem Curso S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/420494.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/i0Xgi2VN3rt88SzlcJqUf9Wbfid.jpg'),
(154315, 10997, 'Ursos Sem Curso S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/420495.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8Dxtzih5VWsjoVGaUwbIgnRuBCC.jpg'),
(154316, 10997, 'Ursos Sem Curso S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/420496.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qepMjvOdt6NwZa3yop8tcr20bFt.jpg'),
(154317, 10997, 'Ursos Sem Curso S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/420497.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oisfbsqpcYW1BZZJsBLJzYih5Nx.jpg'),
(154318, 10997, 'Ursos Sem Curso S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/420498.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/h0U32t0k3lHWjVs2thJmONVL1Cz.jpg'),
(154319, 10997, 'Ursos Sem Curso S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/420499.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mpRIwSM0yo4Y9ZkJTJEwv79kiF2.jpg'),
(154320, 10997, 'Ursos Sem Curso S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/420500.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fjLqn4ilxe7pOKBYuQrFGGQtf6Z.jpg'),
(154321, 10997, 'Ursos Sem Curso S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/420501.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8gWPvGxccxndkEQbK6MoeCQIUI.jpg'),
(154322, 10997, 'Ursos Sem Curso S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/420502.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vT5hhpbPKIaW1AF4OpgKYSW2riC.jpg'),
(154323, 10997, 'Ursos Sem Curso S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/420503.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tbYHq7EORBoTiM5cfOOkaBpPsPs.jpg'),
(154324, 10997, 'Ursos Sem Curso S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/420504.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2rWLQ314cgvSDreINyzUvvzS753.jpg'),
(154325, 10997, 'Ursos Sem Curso S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/420505.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6okBYWH28mmNX2EbaodgOGzZmBc.jpg'),
(154326, 10998, 'Ursos Sem Curso S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/420506.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/v6RJH6sVNa29P5DI0Gle38ca2pB.jpg'),
(154327, 10998, 'Ursos Sem Curso S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/420507.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/q0e3CiXLCzGrZG6psX7d1d4wmtQ.jpg'),
(154328, 10998, 'Ursos Sem Curso S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/420508.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/jzqa2CjQimEN1r4PkzsYZJAI1Qt.jpg'),
(154329, 10998, 'Ursos Sem Curso S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/420509.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s8n3z5Xn98Gr29LYaDXhxSp2Vdj.jpg'),
(154330, 10998, 'Ursos Sem Curso S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/420510.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8yYe4GBM1oB0HvxkL2rAMRJognf.jpg'),
(154331, 10998, 'Ursos Sem Curso S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/420511.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qhj6G8Sojtq6hVQcTiRoy2Tu2Sm.jpg'),
(154332, 10998, 'Ursos Sem Curso S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/420512.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/grF8m7csTCDtNy6VKx6CSY1kcJ1.jpg'),
(154333, 10998, 'Ursos Sem Curso S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/420513.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tryQuFAiyAEquPq5cg8UhKsQMgX.jpg'),
(154334, 10998, 'Ursos Sem Curso S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/420514.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/n9s3IG5LAOvQ7fkPpIpdevhM4eC.jpg'),
(154335, 10998, 'Ursos Sem Curso S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/420515.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fTKVFLn6EacdQMh9etutvAEMxmW.jpg'),
(154336, 10998, 'Ursos Sem Curso S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/420516.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rcPG2YTevCaXh0SZX7x4rfM6GEp.jpg'),
(154337, 10998, 'Ursos Sem Curso S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/420517.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dtt4tCsowVifA4LYyRquOkKv0eB.jpg'),
(154338, 10998, 'Ursos Sem Curso S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/420518.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8cw2F3kqYWhnw0PoGr2cGiGnLFh.jpg'),
(154339, 10998, 'Ursos Sem Curso S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/420519.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/8wKNGFgf4Oh9hqGYAQO7JUdZ7Eb.jpg'),
(154340, 10998, 'Ursos Sem Curso S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/420520.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/e6TUqlOgXTpLWpRryXiU298PPmy.jpg'),
(154341, 10998, 'Ursos Sem Curso S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/420521.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/18dhxqynLhz5RXAnIl6wGPe1fg7.jpg'),
(154342, 10998, 'Ursos Sem Curso S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/420522.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t8QLNzr7vkvipICRpEZFC2GMoB7.jpg'),
(154343, 10998, 'Ursos Sem Curso S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/420523.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/6OhMFcXPfKq39Qcyzk3QVqAd2Yu.jpg'),
(154344, 10998, 'Ursos Sem Curso S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/420524.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/VA0sW1vCBbEV960qJu3DyIxKxf.jpg'),
(154345, 10998, 'Ursos Sem Curso S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/420525.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aFMQ0yGHEs9looA1lti55Vg47JC.jpg'),
(154346, 10998, 'Ursos Sem Curso S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/420526.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/buEgOhtnKC8dydSw8XeptdLa4Sq.jpg'),
(154347, 10998, 'Ursos Sem Curso S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/420527.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5b8fM0NrKc8zR2MCULDzy3ECH77.jpg'),
(154348, 10998, 'Ursos Sem Curso S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/420528.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vV8Nz6ntd5Mb7PCCYIHDSBo8FFQ.jpg'),
(154349, 10998, 'Ursos Sem Curso S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/420529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zdKZvdezMm2UOysyea63cQqKEHl.jpg'),
(154350, 10998, 'Ursos Sem Curso S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/420530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zdKZvdezMm2UOysyea63cQqKEHl.jpg'),
(154351, 10998, 'Ursos Sem Curso S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/420531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zdKZvdezMm2UOysyea63cQqKEHl.jpg'),
(154352, 10998, 'Ursos Sem Curso S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/420532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zdKZvdezMm2UOysyea63cQqKEHl.jpg'),
(154353, 10999, 'Ursos Sem Curso S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/420533.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dQAnzfW5iyaZ0aYkAcsAvJsCpyz.jpg'),
(154354, 10999, 'Ursos Sem Curso S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/420534.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/mvO6c2gxvFrFkxMLo9m1AcslCbT.jpg'),
(154355, 10999, 'Ursos Sem Curso S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/420535.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bhLn4SJa5jfFDGwJISrLi8OpzrU.jpg'),
(154356, 10999, 'Ursos Sem Curso S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/420536.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ZZ0ABgVdFBygPe8j7jZjwXweee.jpg'),
(154357, 10999, 'Ursos Sem Curso S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/420537.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ct4geHvqj6WELC75Vbd1XVVthMF.jpg'),
(154358, 10999, 'Ursos Sem Curso S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/420538.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/72iXSxr6GO2hi9H3gaywmemipKP.jpg'),
(154359, 10999, 'Ursos Sem Curso S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/420539.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/17MIfXoKiLKFmyqCROtaqld7G6R.jpg'),
(154360, 10999, 'Ursos Sem Curso S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/420540.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lt1uTUnleVS97tfSMVBxVr0jtG9.jpg'),
(154361, 10999, 'Ursos Sem Curso S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/420541.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kqB1M2pyS5xicyiZIteUWGG15JE.jpg'),
(154362, 10999, 'Ursos Sem Curso S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/420542.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wEwlkSz4RNB3wwwQhUCQyakpnSW.jpg'),
(154363, 10999, 'Ursos Sem Curso S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/420543.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s6U5t5zY0MQlEjM5i1Je5LArt1a.jpg'),
(154364, 10999, 'Ursos Sem Curso S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/420544.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4etz9BEz9m7Ikbt5r4vaKdYlJhJ.jpg'),
(154365, 10999, 'Ursos Sem Curso S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/420545.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tx5JF8QDzFnZKRswOqhOAMm80cx.jpg'),
(154366, 10999, 'Ursos Sem Curso S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/420546.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Ag9mPlkRxh3W19WLzMnqDwC7Rdn.jpg'),
(154367, 10999, 'Ursos Sem Curso S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/420547.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/vKHDTcSDJifUuefTryz0Oagw2GO.jpg'),
(154368, 10999, 'Ursos Sem Curso S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/420548.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/cKId1BzjGcuhx63BvxbA2m38EgK.jpg'),
(154369, 10999, 'Ursos Sem Curso S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/420549.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ypM8rmxZ5QC8yDr5sKRjC9bTH5O.jpg'),
(154370, 10999, 'Ursos Sem Curso S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/420550.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yFLBqi5oALFYVPTnGP3aKZFAh8n.jpg'),
(154371, 10999, 'Ursos Sem Curso S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/420551.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/yobzbsY95V9yuLGcwvbfVopiXwf.jpg'),
(154372, 10999, 'Ursos Sem Curso S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/420552.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tehQXXAAu5mRMvEITfKGSeRSSD4.jpg'),
(154373, 10999, 'Ursos Sem Curso S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/420553.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ugcOCK7kN3kGvoajEhRyOn2JShv.jpg'),
(154374, 10999, 'Ursos Sem Curso S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/420554.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ca4Hd11XHgwPzMgSk7DKa7NfQjt.jpg'),
(154375, 10999, 'Ursos Sem Curso S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/420555.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lkzA9QwoKpE8j1wpRl888JQi9F9.jpg'),
(154376, 10999, 'Ursos Sem Curso S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/420556.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2wTrv6jkxlL3u8z2AmIYpJEbAb2.jpg'),
(154377, 10999, 'Ursos Sem Curso S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/420557.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dI8Dq8ADQJS8ZJq5jIylbWefHNI.jpg'),
(154378, 10999, 'Ursos Sem Curso S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/420558.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/xhD9CcMXdwvybg44VjAbrfjCKVl.jpg'),
(154379, 10999, 'Ursos Sem Curso S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/420559.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/11pc1aH0pboiIxTIku8XTIzcrWK.jpg'),
(154380, 10999, 'Ursos Sem Curso S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/420560.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ua5WooXzxkc3Xe1noiQrnThE7Kd.jpg'),
(154381, 10999, 'Ursos Sem Curso S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/420561.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/JDSAfldaUQ3FmmX1T7okBXMBfi.jpg'),
(154382, 10999, 'Ursos Sem Curso S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/420562.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2wQO5UzajAH99CDRpPQ5fqLvjCP.jpg'),
(154383, 10999, 'Ursos Sem Curso S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/420563.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z4UXDLA5LZH4Wf4YzC7G80qi2fP.jpg'),
(154384, 10999, 'Ursos Sem Curso S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/420564.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gQRzbicV59iM8o1TarxGUMd9LJq.jpg'),
(154385, 10999, 'Ursos Sem Curso S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/420565.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pbUWLwKIZcD84HFN4Z3gmoctJiC.jpg'),
(154386, 10999, 'Ursos Sem Curso S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/420566.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zOwkOsdVTo7aDnv7trBNY4Krnjr.jpg'),
(154387, 10999, 'Ursos Sem Curso S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/420567.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/eDDQJ8kXVCTUWIfHPOv7Ka3fcX8.jpg'),
(154388, 10999, 'Ursos Sem Curso S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/420568.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iTV2BbtCWO1OxoRkBUStQ5e22BQ.jpg'),
(154389, 10999, 'Ursos Sem Curso S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/420569.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/luJgWXiquZx7B1XsF9mIMLhgIhq.jpg'),
(154390, 10999, 'Ursos Sem Curso S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/420570.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zDHAwTSIYpKiEQMEuSNntHqdpKk.jpg'),
(154391, 10999, 'Ursos Sem Curso S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/420571.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ahl4WrxYP2RTpc9qkbpGj8wqTIz.jpg'),
(154392, 10999, 'Ursos Sem Curso S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/420572.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ylQEn2ELneuoY8WrtE31zvQxkZk.jpg'),
(154393, 10999, 'Ursos Sem Curso S03 E41', 'http://sinalprivado.info:80/series/1533784/1533784/420573.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lwzEiyoMmJX0YzCzJimJhkLoshX.jpg'),
(154394, 10999, 'Ursos Sem Curso S03 E42', 'http://sinalprivado.info:80/series/1533784/1533784/420574.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pJRLHNgRQ9MYmzT37ozDGzdtiXu.jpg'),
(154395, 10999, 'Ursos Sem Curso S03 E43', 'http://sinalprivado.info:80/series/1533784/1533784/420575.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4pR3pD3eEfQVqa6lZKd6aoTdsja.jpg'),
(154396, 10999, 'Ursos Sem Curso S03 E44', 'http://sinalprivado.info:80/series/1533784/1533784/420576.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/7NimpcW785Nj5VlAUMZdTsPoZ9P.jpg'),
(154397, 11000, 'Os Cavaleiros do Zodíaco: A Saga de Hades S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/420468.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dkRONeqEpjIcPyXdKQDG72aNyl6.jpg'),
(154398, 11000, 'Os Cavaleiros do Zodíaco: A Saga de Hades S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/420469.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/wDMM38PhB7MFgDaOPgSpM38sIUy.jpg'),
(154399, 11000, 'Os Cavaleiros do Zodíaco: A Saga de Hades S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/420470.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dFTNhGQHCgXkTUEOsG0C3Atng6W.jpg'),
(154400, 11000, 'Os Cavaleiros do Zodíaco: A Saga de Hades S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/420471.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/iSqA4LHDQsfqFANktnMgcHHjy0x.jpg'),
(154401, 11000, 'Os Cavaleiros do Zodíaco: A Saga de Hades S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/420472.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/pYkBoS1EHdMSBIfNleQvuMlAfPh.jpg'),
(154402, 11000, 'Os Cavaleiros do Zodíaco: A Saga de Hades S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/420473.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/kjEtDRgKTN1bJXtXa27r5Wh5P9k.jpg'),
(154403, 11000, 'Os Cavaleiros do Zodíaco: A Saga de Hades S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/420474.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/rpfScNFbODaPa1NJ1FxUzt3rvKw.jpg'),
(154404, 11000, 'Os Cavaleiros do Zodíaco: A Saga de Hades S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/420475.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/caP5FVuIWFKQcah7oTNd3jwypby.jpg'),
(154405, 11000, 'Os Cavaleiros do Zodíaco: A Saga de Hades S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/420476.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/z2OT0RsBO2WbfP3qo8V3GVgLOXl.jpg'),
(154406, 11000, 'Os Cavaleiros do Zodíaco: A Saga de Hades S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/420477.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/bLzf0NEIJLzDYBbukGjKxP3ATqR.jpg'),
(154407, 11000, 'Os Cavaleiros do Zodíaco: A Saga de Hades S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/420478.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/gJG1x9T7pPzqLQmfYC3KT0jQs8p.jpg'),
(154408, 11000, 'Os Cavaleiros do Zodíaco: A Saga de Hades S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/420479.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/2jn9si3aLAQLa3hxCy6Ya2RLPcE.jpg'),
(154409, 11000, 'Os Cavaleiros do Zodíaco: A Saga de Hades S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/420480.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nRkRdGy4DutJEkgXoZC0f58mAwj.jpg'),
(154410, 11001, 'Good Trouble [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/419843.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/Vwtqyzcqa0WTZ2GFL65TI4axS5.jpg'),
(154411, 11001, 'Good Trouble [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/419844.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m2PUBSPDPWtIrq1E7Atw9oYyPb1.jpg'),
(154412, 11001, 'Good Trouble [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/419845.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/24oQdwteWEMx3Lf8RjQdxDOpsRI.jpg'),
(154413, 11001, 'Good Trouble [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/419846.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/foI3KrCvk75L3OEpIrlhOxhZWAd.jpg'),
(154414, 11001, 'Good Trouble [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/419847.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/m5gV7kOnTdCiSyC4OAvb6UdR9l8.jpg'),
(154415, 11001, 'Good Trouble [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/419848.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/udhKNa74b3yOs3NBlaWGyyrZhY8.jpg'),
(154416, 11001, 'Good Trouble [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/419849.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5AcoU2Vn5c1lZP4IguEPb9MP9uF.jpg'),
(154417, 11001, 'Good Trouble [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/419850.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/nmFEsdwk9PU5sn0MqEAtwQKIWPu.jpg'),
(154418, 11001, 'Good Trouble [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/419851.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/tYWzejT9jVj4HKpsXhWXna0759q.jpg'),
(154419, 11001, 'Good Trouble [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/419852.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fiREOBs5eifa6t8LHH5eEcXNP3z.jpg'),
(154420, 11001, 'Good Trouble [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/419853.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lZGTA011XaRPs0lanvcFL4u9z9F.jpg'),
(154421, 11001, 'Good Trouble [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/419854.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/lSpCSJ9IEGIgom8F4dzW4HnmfeX.jpg'),
(154422, 11001, 'Good Trouble [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/419855.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1du2EFXqm4AMELHzqZiNuqAkbv6.jpg'),
(154423, 11002, 'Good Trouble [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/419856.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/qVdhnZUz0OUi0dwrM1npz1kL3RR.jpg'),
(154424, 11002, 'Good Trouble [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/419857.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/dRDRugOAc7RQyeMxa4uMKQIO816.jpg'),
(154425, 11002, 'Good Trouble [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/419858.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/36dikvMelG6ppMBVCZfxqb5V8iY.jpg'),
(154426, 11002, 'Good Trouble [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/419859.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/s1apjvqkx2ZfX7GBCYdhQRo0zlD.jpg'),
(154427, 11002, 'Good Trouble [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/419860.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/60Wp8nTGdPhKVH540V63JqeK0V4.jpg'),
(154428, 11002, 'Good Trouble [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/419861.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/4HUptn0OmjA8OKv7GspiLECrev.jpg'),
(154429, 11002, 'Good Trouble [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/419862.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fUWubWuIuQAkFrFFpE8h06nU4qg.jpg'),
(154430, 11002, 'Good Trouble [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/419863.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/t2Jb4UrCCHiHgcdzpG0xGzda5Zh.jpg'),
(154431, 11002, 'Good Trouble [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/419864.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/oPUl4T6QEpgyplOvn6hgGtmrDQZ.jpg'),
(154432, 11002, 'Good Trouble [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/419865.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/ggwUdFopojAXUxbcJsM8WxCaNns.jpg'),
(154433, 11002, 'Good Trouble [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/419866.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/heSTdiooKNylgUZnbbPMLVIuBT3.jpg'),
(154434, 11002, 'Good Trouble [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/419867.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/5UFYp2WVW5UGGZEt3nhJrlKr5JC.jpg'),
(154435, 11002, 'Good Trouble [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/419868.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/fojHyQ8wNoObF1Vk979wgueejbW.jpg'),
(154436, 11002, 'Good Trouble [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/419869.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/1vMUe2tfCOAkkt9Tbp3bm2d3z2v.jpg'),
(154437, 11002, 'Good Trouble [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/419870.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/hKGmwubGJmyJ82xjVbx9fzoD39w.jpg'),
(154438, 11002, 'Good Trouble [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/419871.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aSjmEVLjvwmJymMNEQfo4UnrIkB.jpg'),
(154439, 11002, 'Good Trouble [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/419872.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/zbOKOdjtY3DVGjqgYslG4EzaefJ.jpg'),
(154440, 11002, 'Good Trouble [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/419873.mp4', 'http://image.tmdb.org/t/p/w600_and_h900_bestv2/aPp0MrNbp0vOZ4MQRaHnP1Za5p6.jpg'),
(154441, 11003, 'A Caverna Encantada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154442, 11003, 'A Caverna Encantada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154443, 11003, 'A Caverna Encantada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154444, 11003, 'A Caverna Encantada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154445, 11003, 'A Caverna Encantada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154446, 11003, 'A Caverna Encantada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/428337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154447, 11003, 'A Caverna Encantada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/428338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154448, 11003, 'A Caverna Encantada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/428339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154449, 11003, 'A Caverna Encantada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/428340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154450, 11003, 'A Caverna Encantada S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/428341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154451, 11003, 'A Caverna Encantada S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/430017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154452, 11003, 'A Caverna Encantada S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/629949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154453, 11003, 'A Caverna Encantada S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/430020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154454, 11003, 'A Caverna Encantada S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/435299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154455, 11003, 'A Caverna Encantada S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/435300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154456, 11003, 'A Caverna Encantada S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/437741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154457, 11003, 'A Caverna Encantada S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/437742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154458, 11003, 'A Caverna Encantada S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/437743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154459, 11003, 'A Caverna Encantada S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/437744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154460, 11003, 'A Caverna Encantada S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/443025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154461, 11003, 'A Caverna Encantada S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/443026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154462, 11003, 'A Caverna Encantada S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/443027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154463, 11003, 'A Caverna Encantada S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/445117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154464, 11003, 'A Caverna Encantada S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/445118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154465, 11003, 'A Caverna Encantada S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/445119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154466, 11003, 'A Caverna Encantada S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/448985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154467, 11003, 'A Caverna Encantada S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/448986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154468, 11003, 'A Caverna Encantada S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/448987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154469, 11003, 'A Caverna Encantada S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/448988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154470, 11003, 'A Caverna Encantada S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/453012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154471, 11003, 'A Caverna Encantada S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/453013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154472, 11003, 'A Caverna Encantada S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/453014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154473, 11003, 'A Caverna Encantada S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/453015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154474, 11003, 'A Caverna Encantada S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/456815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154475, 11003, 'A Caverna Encantada S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/456816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154476, 11003, 'A Caverna Encantada S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/458626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154477, 11003, 'A Caverna Encantada S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/458627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154478, 11003, 'A Caverna Encantada S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/462204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154479, 11003, 'A Caverna Encantada S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/462205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154480, 11003, 'A Caverna Encantada S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/462206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154481, 11003, 'A Caverna Encantada S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/468389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154482, 11003, 'A Caverna Encantada S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/468390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154483, 11003, 'A Caverna Encantada S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/468391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154484, 11003, 'A Caverna Encantada S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/468392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154485, 11003, 'A Caverna Encantada S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/468393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154486, 11003, 'A Caverna Encantada S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/471060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154487, 11003, 'A Caverna Encantada S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/471061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154488, 11003, 'A Caverna Encantada S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/479301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154489, 11003, 'A Caverna Encantada S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/479302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154490, 11003, 'A Caverna Encantada S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/479303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154491, 11003, 'A Caverna Encantada S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/479304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154492, 11003, 'A Caverna Encantada S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/479305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154493, 11003, 'A Caverna Encantada S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/479306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154494, 11003, 'A Caverna Encantada S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/479307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154495, 11003, 'A Caverna Encantada S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/479308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154496, 11003, 'A Caverna Encantada S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/483654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154497, 11003, 'A Caverna Encantada S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/483655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154498, 11003, 'A Caverna Encantada S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/483656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154499, 11003, 'A Caverna Encantada S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/486073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154500, 11003, 'A Caverna Encantada S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/486074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154501, 11003, 'A Caverna Encantada S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/491911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154502, 11003, 'A Caverna Encantada S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/491912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154503, 11003, 'A Caverna Encantada S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/491913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154504, 11003, 'A Caverna Encantada S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/491914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154505, 11003, 'A Caverna Encantada S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/491915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154506, 11003, 'A Caverna Encantada S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/493300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154507, 11003, 'A Caverna Encantada S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/493301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154508, 11003, 'A Caverna Encantada S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/493302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154509, 11003, 'A Caverna Encantada S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/495952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154510, 11003, 'A Caverna Encantada S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/495953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154511, 11003, 'A Caverna Encantada S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/495954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154512, 11003, 'A Caverna Encantada S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/630010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154513, 11003, 'A Caverna Encantada S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/499339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154514, 11003, 'A Caverna Encantada S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/499340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154515, 11003, 'A Caverna Encantada S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/501943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154516, 11003, 'A Caverna Encantada S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/501944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154517, 11003, 'A Caverna Encantada S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/501945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154518, 11003, 'A Caverna Encantada S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/501946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154519, 11003, 'A Caverna Encantada S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/501947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154520, 11003, 'A Caverna Encantada S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/508202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zv8aah1oS8ESsAhcYywNtOrjiWe.jpg'),
(154521, 11004, 'A Mulher Bionica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/426062.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9M9OgPrEQWHpBRsZeKrDLUM3H6b.jpg'),
(154522, 11004, 'A Mulher Bionica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/426063.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fpAXZmHibvPVw3DBOQC0jXZWbV9.jpg'),
(154523, 11004, 'A Mulher Bionica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/426064.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fPXPIVPaN07YdZ4gjKaYhgStKqo.jpg'),
(154524, 11004, 'A Mulher Bionica S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/426065.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jVmBLkbtFn4aXIhZ9th77YIlTNx.jpg'),
(154525, 11004, 'A Mulher Bionica S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/426066.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aARzhszBZAzU7aB5ORUHKOesDz3.jpg'),
(154526, 11004, 'A Mulher Bionica S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/426067.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nc0fjo88jmgdju2AsRoYGvjSh7c.jpg'),
(154527, 11004, 'A Mulher Bionica S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/426068.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mQD9aPcbFEZ7U0JDb7dILVUxrgT.jpg'),
(154528, 11004, 'A Mulher Bionica S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/426069.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hVqsskSYRQwvsxY4vNhWXecV8TL.jpg'),
(154529, 11005, 'A Princesa Real [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/426022.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1IGiTZOiUNohAI76JH0Hy7dNniS.jpg'),
(154530, 11005, 'A Princesa Real [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/426023.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5sldlAz9cAJ3v5WQwJZvf2F1U5P.jpg'),
(154531, 11005, 'A Princesa Real [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/426024.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7LtR4fSzXp3Zknfc7DGJbfSDJXh.jpg'),
(154532, 11005, 'A Princesa Real [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/426025.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qHVRW2wMpQmsZFT3cRltb385VQX.jpg'),
(154533, 11005, 'A Princesa Real [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/426026.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8xCZPnysgArHd794xJHlbDrfBcy.jpg'),
(154534, 11005, 'A Princesa Real [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/426027.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vf3Pl2pROnWC39uURRr4lCP7exS.jpg'),
(154535, 11005, 'A Princesa Real [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/426028.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kFYDrazrlPZpmiJUrXyNbeEFMw2.jpg'),
(154536, 11005, 'A Princesa Real [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/426029.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mUG0IaFeI9bHIUWwgHWLVxri2p3.jpg'),
(154537, 11005, 'A Princesa Real [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/426030.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AgkQZEK9k1wDPj4hlrtyMGihQEN.jpg'),
(154538, 11005, 'A Princesa Real [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/426031.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cwq0adL94qetJi2nKkYC8vXRoOc.jpg'),
(154539, 11005, 'A Princesa Real [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/426032.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xMyFNuHrcAt06bISyLDX2IReai7.jpg'),
(154540, 11005, 'A Princesa Real [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/426033.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b3GCYKXJiPosC2DyageUGK4RtZK.jpg'),
(154541, 11005, 'A Princesa Real [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/426034.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vcqrYpbBzEAi6fKnIOJehv3rDp5.jpg'),
(154542, 11005, 'A Princesa Real [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/426035.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wLYMSCEPdHP3w3xuOUNTIobDBU2.jpg'),
(154543, 11005, 'A Princesa Real [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/426036.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vErBeiyiKvYbG8ngnFuL8znkqv1.jpg'),
(154544, 11005, 'A Princesa Real [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/426037.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jdnereX1T9RxTQXKZUOvzhfx5Jb.jpg'),
(154545, 11005, 'A Princesa Real [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/426038.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x4y3MY7BOXcJUuXK4iGdiah7KkR.jpg'),
(154546, 11005, 'A Princesa Real [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/426039.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g7h7F87Bsk9RgpzGbPgMe8tERD6.jpg'),
(154547, 11005, 'A Princesa Real [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/426040.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lJcDKDmHPGJ080S0iQ1YdIU6z8n.jpg'),
(154548, 11005, 'A Princesa Real [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/426041.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xBtJ0vgejRJoZpUcs69dx55ScBt.jpg'),
(154549, 11005, 'A Princesa Real [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/426042.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3G8FphzZhpAz0wu3WUBw9xcAr1J.jpg'),
(154550, 11005, 'A Princesa Real [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/426043.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ivqiAxINrlvnGQcXDL8fn0sRphQ.jpg'),
(154551, 11005, 'A Princesa Real [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/426044.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8PRN3qpUjZ6BzrhPf9vf0FCX5nw.jpg'),
(154552, 11005, 'A Princesa Real [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/426045.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fhUqjvU7wEw3tURM7ndVwtY7Ac1.jpg'),
(154553, 11005, 'A Princesa Real [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/426046.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qRoJs2pUn6CU9fnvQkROnCoCTJQ.jpg'),
(154554, 11005, 'A Princesa Real [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/426047.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hLIrovgiwQBBvOrZnLq9mo2ctl5.jpg'),
(154555, 11005, 'A Princesa Real [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/426048.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zJ5aGOjrX7z2X7xOEmssvJ3XbJN.jpg'),
(154556, 11005, 'A Princesa Real [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/426049.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o9y9xVLYM147RaaQq0f1FsEtqwc.jpg'),
(154557, 11005, 'A Princesa Real [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/426050.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vYkxLNN3Y55A0YuNXAROw0Gh1rQ.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(154558, 11005, 'A Princesa Real [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/426051.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/urR9iH28ftOOzfplpTVNR0fY8SD.jpg'),
(154559, 11005, 'A Princesa Real [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/426052.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qYtA4dr3HtHVGUcDDI4WaEs8Jtu.jpg'),
(154560, 11005, 'A Princesa Real [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/426053.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nT3vZgrhocuHWbPxWeIRVYaLvpN.jpg'),
(154561, 11005, 'A Princesa Real [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/426054.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/58kVatTumIpQlX46ds5XSjyyNUt.jpg'),
(154562, 11005, 'A Princesa Real [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/426055.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ryruCTIoMzAROgnUxQgszDbQdUl.jpg'),
(154563, 11005, 'A Princesa Real [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/426056.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dem80jNgCCwL0cl5VoP4SMxKEHb.jpg'),
(154564, 11005, 'A Princesa Real [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/426057.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/umc1eP8MP7sWY2k3XUz28YQRI2y.jpg'),
(154565, 11005, 'A Princesa Real [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/426058.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gUrj4xHIYBuPPefaqA0zYcKG63z.jpg'),
(154566, 11005, 'A Princesa Real [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/426059.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k5jPA3Gj2amkmqp6GUlhtpMSE37.jpg'),
(154567, 11005, 'A Princesa Real [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/426060.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qpboi2QPsGjoO5YZXX1bS2C3y5X.jpg'),
(154568, 11005, 'A Princesa Real [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/426061.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7WBm8vE3bG0nFdXVcZMUzncrOAm.jpg'),
(154569, 11006, 'Agate [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425992.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hyA1DeiDFqkIPMjRGbGrBhfBocE.jpg'),
(154570, 11006, 'Agate [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425993.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3irYf7o6zaDdVFXiY0rxiFD9ueO.jpg'),
(154571, 11006, 'Agate [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425994.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a2sgOMivjD3TFzuszzjus2a8mKd.jpg'),
(154572, 11006, 'Agate [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425995.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l4apntflKDwgWHFjcJfwv68B6Ok.jpg'),
(154573, 11006, 'Agate [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425996.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nHWirC7QrwdG8mdJCmfcDMUEUI5.jpg'),
(154574, 11006, 'Agate [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/425997.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3e6u72FtIhrorjQaOTPRGxt90Pg.jpg'),
(154575, 11006, 'Agate [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/425998.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g5iuoXR2Tejaf4A5hTMDtyUzWuM.jpg'),
(154576, 11006, 'Agate [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/425999.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aywX9r2YNfSvme3rDu0vD0UPR19.jpg'),
(154577, 11006, 'Agate [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/426000.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/udeCwTgLPTH3cwg4ZAWln2ilDb9.jpg'),
(154578, 11006, 'Agate [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/426001.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nalFEyxNDxPYVIdsrDPl46yuMbV.jpg'),
(154579, 11006, 'Agate [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/426002.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oBycjL2XmoTuhJr8sdptt7x4It5.jpg'),
(154580, 11006, 'Agate [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/426003.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vOzDd4qxiXIEPOCM3WnjCWwaA7B.jpg'),
(154581, 11006, 'Agate [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/426004.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5FJMWVUyxiDSjwQDj17ZcFvD3g7.jpg'),
(154582, 11006, 'Agate [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/426005.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qp1tpUJMs4XIuY8iG5Q7xp7OwaD.jpg'),
(154583, 11006, 'Agate [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/426006.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i1eejeMBkC7uOs2BkKmGWx960R1.jpg'),
(154584, 11007, 'Agate [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/426007.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nb6qZX5bb1USxlWapuVWK34HbcY.jpg'),
(154585, 11007, 'Agate [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/426008.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kUDutVb4Q1ilHELOaZBdKT2FgWs.jpg'),
(154586, 11007, 'Agate [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/426009.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yDlRIjymNycjBP1MW44sUrt3UX1.jpg'),
(154587, 11007, 'Agate [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/426010.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4BOmQf7dg6uiayqdqoz9GTHSG1N.jpg'),
(154588, 11007, 'Agate [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/426011.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kNOx76JpipaOhqRIuTc8QXqWwwf.jpg'),
(154589, 11007, 'Agate [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/426012.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m0IHt69DXEB4QmEOiy02nPCjmQk.jpg'),
(154590, 11007, 'Agate [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/426013.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cuv1Nnn3mOlNym3WcaWvf8Bt9j0.jpg'),
(154591, 11007, 'Agate [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/426014.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/slzoHE124NqSQ0MAS3ane1VNFU.jpg'),
(154592, 11007, 'Agate [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/426015.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eHmp4RLOm6AAioL9BAqal8ma8oe.jpg'),
(154593, 11007, 'Agate [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/426016.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uJMaDPEJyT5tZSuF8Uze3goTYRj.jpg'),
(154594, 11007, 'Agate [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/426017.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4kEqace0E3kAktcBa1uMdXAF8f1.jpg'),
(154595, 11007, 'Agate [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/426018.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8zfA49J4GYDnN7r4IeeFkQvLpU5.jpg'),
(154596, 11007, 'Agate [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/426019.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3u9FLxOjyfvnZhy5XtfCCjuCtQg.jpg'),
(154597, 11007, 'Agate [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/426020.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8RTnoyAWVcaa0PawRCETjOaqe4k.jpg'),
(154598, 11007, 'Agate [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/426021.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qAN2YQ3VlFDmZWR4ero1BJohZCb.jpg'),
(154599, 11008, 'Amor Sem Fim S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425892.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f6iA18ke20nIjhQodp3YAxB9emX.jpg'),
(154600, 11008, 'Amor Sem Fim S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425893.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lRSyNRoyqQrhGQtOZvmH6Qvb3DA.jpg'),
(154601, 11008, 'Amor Sem Fim S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425894.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fYevNx22ESjB0gNC9RXCpBCWbv.jpg'),
(154602, 11008, 'Amor Sem Fim S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425895.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/FkroXMRHDJ5VtUHK81QV1J45SN.jpg'),
(154603, 11008, 'Amor Sem Fim S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425896.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qJwymIQlnsSNm8wKi3Pw2wtYyjS.jpg'),
(154604, 11008, 'Amor Sem Fim S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/425897.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mzYqIjySDXG7oXEVv1N1i1iz3gA.jpg'),
(154605, 11008, 'Amor Sem Fim S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/425898.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fJMK8YcRw1gqm0aauFilLH92b7R.jpg'),
(154606, 11008, 'Amor Sem Fim S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/425899.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mzUBaM70jBCWlTBdL0JRtZBeB8q.jpg'),
(154607, 11008, 'Amor Sem Fim S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/425900.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/reN1PLkNJDErExG7TvX34kg3Zla.jpg'),
(154608, 11008, 'Amor Sem Fim S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/425901.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3m1QIEBzjwBeguARA77l7wO1ppK.jpg'),
(154609, 11008, 'Amor Sem Fim S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/425902.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xyWxiVpRmayFPRrEiMvQRQjJXfD.jpg'),
(154610, 11008, 'Amor Sem Fim S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/425903.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kRJ2zUfXctT0Ig4h4aq2Upjqx0D.jpg'),
(154611, 11008, 'Amor Sem Fim S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/425904.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jiZOtHIkZcj6rFLbtzw7A53U9Cc.jpg'),
(154612, 11008, 'Amor Sem Fim S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/425905.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vvjUHrRUZWSDEp6VCWLXtrnYh9e.jpg'),
(154613, 11008, 'Amor Sem Fim S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/425906.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oMOrksfypOqP04n2bVLvvwkbp1U.jpg'),
(154614, 11008, 'Amor Sem Fim S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/425907.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rPOgqLAdo7wnq4IeHUNLhMgF5W8.jpg'),
(154615, 11008, 'Amor Sem Fim S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/425908.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7WQgFS84y3P9mOIjRAyKaWI6U3g.jpg'),
(154616, 11008, 'Amor Sem Fim S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/425909.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5M2huiOeCCrjtyTsISnzepv9mlo.jpg'),
(154617, 11008, 'Amor Sem Fim S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/425910.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xt63U8B3l2xqpw6c49teWkDwyOZ.jpg'),
(154618, 11008, 'Amor Sem Fim S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/425911.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/84UeShnLkDxPYATdMg1G8s6MAnQ.jpg'),
(154619, 11008, 'Amor Sem Fim S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/425912.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/agHmpU1aow2juKH3Wb9tnCW3zMa.jpg'),
(154620, 11008, 'Amor Sem Fim S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/425913.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lUVrvZNOcqrHRdASN2GlQ66qUJI.jpg'),
(154621, 11008, 'Amor Sem Fim S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/425914.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yjk8kamJXtMY8aT58IrJFW0FfLj.jpg'),
(154622, 11008, 'Amor Sem Fim S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/425915.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qpymlPXxhFPSCCph78jyTZGlWGN.jpg'),
(154623, 11008, 'Amor Sem Fim S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/425916.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/diybDMOc0iHdrLwiKZn9q645Gmk.jpg'),
(154624, 11008, 'Amor Sem Fim S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/425917.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2XM7BIBn0hIDQWkgtf1WddeNq4s.jpg'),
(154625, 11008, 'Amor Sem Fim S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/425918.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3JGYpFvBNsRNEiryW1LFsdXS55W.jpg'),
(154626, 11008, 'Amor Sem Fim S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/425919.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qP2nHeRJYaQmDOlFtIyjl6yBbhj.jpg'),
(154627, 11008, 'Amor Sem Fim S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/425920.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nBfnI9H7Pm88vjrJPCc7jufygQM.jpg'),
(154628, 11008, 'Amor Sem Fim S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/425921.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y3nb8N4e1jZ8PoimeEfGkzo71lB.jpg'),
(154629, 11008, 'Amor Sem Fim S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/425922.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9OEhwdmfJVfU2RCfUFQTCLuCAZP.jpg'),
(154630, 11008, 'Amor Sem Fim S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/425923.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yXHx00a6SDKLW6ptFHBw53IinmV.jpg'),
(154631, 11008, 'Amor Sem Fim S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/425924.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q5XJtRigRy59ilx25BiadMXiDSB.jpg'),
(154632, 11008, 'Amor Sem Fim S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/425925.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/heTT8k22zaS4x2jTB1nLJlvUXPU.jpg'),
(154633, 11008, 'Amor Sem Fim S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/425926.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z2ctMoFaJOdRieLtaj4Kw3NH4Ei.jpg'),
(154634, 11008, 'Amor Sem Fim S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/425927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154635, 11008, 'Amor Sem Fim S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/425928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154636, 11008, 'Amor Sem Fim S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/425929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154637, 11008, 'Amor Sem Fim S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/425930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154638, 11008, 'Amor Sem Fim S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/425931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154639, 11008, 'Amor Sem Fim S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/425932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154640, 11008, 'Amor Sem Fim S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/425933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154641, 11008, 'Amor Sem Fim S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/425934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154642, 11008, 'Amor Sem Fim S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/425935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154643, 11008, 'Amor Sem Fim S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/425936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154644, 11008, 'Amor Sem Fim S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/425937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154645, 11008, 'Amor Sem Fim S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/425938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154646, 11008, 'Amor Sem Fim S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/425939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154647, 11008, 'Amor Sem Fim S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/425940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154648, 11008, 'Amor Sem Fim S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/425941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154649, 11008, 'Amor Sem Fim S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/425942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154650, 11008, 'Amor Sem Fim S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/425943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154651, 11008, 'Amor Sem Fim S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/425944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154652, 11008, 'Amor Sem Fim S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/425945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154653, 11008, 'Amor Sem Fim S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/425946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154654, 11008, 'Amor Sem Fim S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/425947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154655, 11008, 'Amor Sem Fim S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/425948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154656, 11008, 'Amor Sem Fim S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/425949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154657, 11008, 'Amor Sem Fim S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/425950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154658, 11008, 'Amor Sem Fim S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/425951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154659, 11008, 'Amor Sem Fim S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/425952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154660, 11008, 'Amor Sem Fim S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/425953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154661, 11008, 'Amor Sem Fim S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/425954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154662, 11008, 'Amor Sem Fim S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/425955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154663, 11008, 'Amor Sem Fim S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/425956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154664, 11008, 'Amor Sem Fim S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/425957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154665, 11008, 'Amor Sem Fim S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/425958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154666, 11008, 'Amor Sem Fim S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/425959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154667, 11008, 'Amor Sem Fim S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/425960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154668, 11008, 'Amor Sem Fim S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/425961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154669, 11008, 'Amor Sem Fim S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/425962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154670, 11008, 'Amor Sem Fim S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/425963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154671, 11008, 'Amor Sem Fim S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/425964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154672, 11008, 'Amor Sem Fim S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/425965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154673, 11008, 'Amor Sem Fim S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/425966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154674, 11008, 'Amor Sem Fim S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/425967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154675, 11008, 'Amor Sem Fim S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/425968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154676, 11008, 'Amor Sem Fim S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/425969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154677, 11008, 'Amor Sem Fim S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/425970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154678, 11008, 'Amor Sem Fim S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/425971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154679, 11008, 'Amor Sem Fim S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/425972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154680, 11008, 'Amor Sem Fim S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/425973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154681, 11008, 'Amor Sem Fim S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/425974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154682, 11008, 'Amor Sem Fim S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/425975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154683, 11008, 'Amor Sem Fim S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/425976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154684, 11008, 'Amor Sem Fim S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/425977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154685, 11008, 'Amor Sem Fim S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/425978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154686, 11008, 'Amor Sem Fim S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/425979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154687, 11008, 'Amor Sem Fim S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/425980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154688, 11008, 'Amor Sem Fim S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/425981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154689, 11008, 'Amor Sem Fim S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/425982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154690, 11008, 'Amor Sem Fim S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/425983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154691, 11008, 'Amor Sem Fim S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/425984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154692, 11008, 'Amor Sem Fim S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/425985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154693, 11008, 'Amor Sem Fim S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/425986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154694, 11008, 'Amor Sem Fim S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/425987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154695, 11008, 'Amor Sem Fim S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/425988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154696, 11008, 'Amor Sem Fim S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/425989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154697, 11008, 'Amor Sem Fim S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/425990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154698, 11008, 'Amor Sem Fim S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/425991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154699, 11008, 'Amor Sem Fim S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/719309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154700, 11008, 'Amor Sem Fim S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/719310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154701, 11008, 'Amor Sem Fim S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/719311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154702, 11008, 'Amor Sem Fim S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/719312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154703, 11008, 'Amor Sem Fim S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/719313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154704, 11008, 'Amor Sem Fim S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/719314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154705, 11008, 'Amor Sem Fim S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/719315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154706, 11008, 'Amor Sem Fim S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/719316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154707, 11008, 'Amor Sem Fim S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/719317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154708, 11008, 'Amor Sem Fim S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/719318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154709, 11008, 'Amor Sem Fim S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/719319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154710, 11008, 'Amor Sem Fim S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/719320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154711, 11008, 'Amor Sem Fim S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/719321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154712, 11008, 'Amor Sem Fim S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/719322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uDSk3PCQLWbrxyjiNrYzO6GqyR7.jpg'),
(154713, 11009, 'Amor na Ilha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425809.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wgJk9ngnHU8c0pEp2yFK7vl2mfy.jpg'),
(154714, 11009, 'Amor na Ilha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154715, 11009, 'Amor na Ilha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154716, 11009, 'Amor na Ilha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154717, 11009, 'Amor na Ilha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154718, 11009, 'Amor na Ilha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/425814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154719, 11009, 'Amor na Ilha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/425815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154720, 11009, 'Amor na Ilha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/425816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154721, 11009, 'Amor na Ilha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/425817.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jnoVcYGNqjtjsfW721fqbNlWNgf.jpg'),
(154722, 11009, 'Amor na Ilha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/425818.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dMI9HFWQ9ooWFhcoLsjGnpswF0K.jpg'),
(154723, 11009, 'Amor na Ilha S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/425819.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ldkCFYDVBkg77cWVsaXrVZgy2jh.jpg'),
(154724, 11009, 'Amor na Ilha S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/425820.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iU67kq91zAOIZTnX64U2CCbudI8.jpg'),
(154725, 11009, 'Amor na Ilha S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/425821.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5m4wA3Ld3Y4WPW2da9cnCjXNas5.jpg'),
(154726, 11009, 'Amor na Ilha S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/425822.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qHMhP2w7dg2h7Yy55nAjOPwTrki.jpg'),
(154727, 11009, 'Amor na Ilha S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/425823.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/idLEKTmdsm3mK3WWMzbuiEiTd6L.jpg'),
(154728, 11009, 'Amor na Ilha S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/425824.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dOqDoqV1WaZGQvVGxhftVqerZDC.jpg'),
(154729, 11009, 'Amor na Ilha S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/425825.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nT1veA6PRIyFgG12cuqwQHnfL97.jpg'),
(154730, 11009, 'Amor na Ilha S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/425826.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wGPdIudIYafOKbCyh1izJz2DQbg.jpg'),
(154731, 11009, 'Amor na Ilha S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/425827.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w5lT1pfsN7cihG3TA23vj66nWUf.jpg'),
(154732, 11009, 'Amor na Ilha S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/425828.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jRc6DOUz2orV52sGDmPPCqHjWUY.jpg'),
(154733, 11009, 'Amor na Ilha S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/425829.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gtd6vm3sjmF37MCAN3vpaaJT0qa.jpg'),
(154734, 11009, 'Amor na Ilha S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/425830.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/adApVJ2puRA1osMzCG3Qm3USnQa.jpg'),
(154735, 11009, 'Amor na Ilha S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/425831.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5WcbKS7huaVLt36NqM7zg4QRevl.jpg'),
(154736, 11009, 'Amor na Ilha S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/425832.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nUuqemRlHCEaSnkdZ28rfZAiyc0.jpg'),
(154737, 11009, 'Amor na Ilha S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/425833.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sFOGYjzNM8z5EOwZBQoBDC2tUK.jpg'),
(154738, 11009, 'Amor na Ilha S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/425834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154739, 11009, 'Amor na Ilha S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/425835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154740, 11009, 'Amor na Ilha S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/425836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154741, 11009, 'Amor na Ilha S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/425837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154742, 11009, 'Amor na Ilha S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/425838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154743, 11009, 'Amor na Ilha S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/425839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154744, 11009, 'Amor na Ilha S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/425840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154745, 11009, 'Amor na Ilha S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/425841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154746, 11009, 'Amor na Ilha S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/425842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154747, 11009, 'Amor na Ilha S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/425843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154748, 11009, 'Amor na Ilha S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/425844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154749, 11009, 'Amor na Ilha S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/425845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154750, 11009, 'Amor na Ilha S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/425846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154751, 11009, 'Amor na Ilha S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/425847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154752, 11009, 'Amor na Ilha S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/425848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154753, 11009, 'Amor na Ilha S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/425849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154754, 11009, 'Amor na Ilha S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/425850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154755, 11009, 'Amor na Ilha S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/425851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154756, 11009, 'Amor na Ilha S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/425852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154757, 11009, 'Amor na Ilha S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/425853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154758, 11009, 'Amor na Ilha S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/425854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154759, 11009, 'Amor na Ilha S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/425855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154760, 11009, 'Amor na Ilha S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/425856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154761, 11009, 'Amor na Ilha S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/425857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154762, 11009, 'Amor na Ilha S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/425858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154763, 11009, 'Amor na Ilha S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/425859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154764, 11009, 'Amor na Ilha S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/425860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154765, 11009, 'Amor na Ilha S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/425861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154766, 11009, 'Amor na Ilha S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/425862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154767, 11009, 'Amor na Ilha S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/425863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154768, 11009, 'Amor na Ilha S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/425864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154769, 11009, 'Amor na Ilha S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/425865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154770, 11009, 'Amor na Ilha S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/425866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154771, 11009, 'Amor na Ilha S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/425867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154772, 11009, 'Amor na Ilha S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/425868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154773, 11009, 'Amor na Ilha S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/425869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154774, 11009, 'Amor na Ilha S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/425870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154775, 11009, 'Amor na Ilha S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/425871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154776, 11009, 'Amor na Ilha S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/425872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154777, 11009, 'Amor na Ilha S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/425873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154778, 11009, 'Amor na Ilha S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/425874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154779, 11009, 'Amor na Ilha S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/425875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154780, 11009, 'Amor na Ilha S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/425876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154781, 11009, 'Amor na Ilha S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/425877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154782, 11009, 'Amor na Ilha S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/425878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154783, 11009, 'Amor na Ilha S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/425879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154784, 11009, 'Amor na Ilha S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/425880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154785, 11009, 'Amor na Ilha S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/425881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154786, 11009, 'Amor na Ilha S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/425882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154787, 11009, 'Amor na Ilha S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/425883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154788, 11009, 'Amor na Ilha S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/425884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154789, 11009, 'Amor na Ilha S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/425885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154790, 11009, 'Amor na Ilha S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/425886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154791, 11009, 'Amor na Ilha S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/425887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154792, 11009, 'Amor na Ilha S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/425888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154793, 11009, 'Amor na Ilha S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/425889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154794, 11009, 'Amor na Ilha S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/425890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154795, 11009, 'Amor na Ilha S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/425891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JCAXWGyHhBesEdaO6emCejA0Ib.jpg'),
(154796, 11010, 'Batman Cruzado Encapuzado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425799.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zcD9q7PbJzTpnyvkR4kHvFIaNdG.jpg'),
(154797, 11010, 'Batman Cruzado Encapuzado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425800.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bG4ZkMTw1xd3Z5lOKMK6VMv17uA.jpg'),
(154798, 11010, 'Batman Cruzado Encapuzado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425801.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xaf5nnf53DW1Hye4eq4bgCWHsmj.jpg'),
(154799, 11010, 'Batman Cruzado Encapuzado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425802.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/F572Zzh4hnZjICJEgWvHYxX0da.jpg'),
(154800, 11010, 'Batman Cruzado Encapuzado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425803.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xaQKvKCHS2eshwmmp6SsQe1MU1y.jpg'),
(154801, 11010, 'Batman Cruzado Encapuzado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/425804.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/elMi4bMZUW9gbzQif5KQ805IAvX.jpg'),
(154802, 11010, 'Batman Cruzado Encapuzado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/425805.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qXnIBXy84oRTygrhwmRsSymnAt5.jpg'),
(154803, 11010, 'Batman Cruzado Encapuzado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/425806.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rLEZURL0bgHi4CNQ56nBsHfsNph.jpg'),
(154804, 11010, 'Batman Cruzado Encapuzado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/425807.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pjIhPtmXLf4xzgp263lRzvK1X47.jpg'),
(154805, 11010, 'Batman Cruzado Encapuzado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/425808.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v3GwJZzowPArhsP4WUe2EEAkoPt.jpg'),
(154806, 11011, 'Corridas Proibidas Os Melhores da America S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425771.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tq1W1gX9nq2smpHMGBtQINKzXxF.jpg'),
(154807, 11011, 'Corridas Proibidas Os Melhores da America S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425772.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nlms6Zxz4pc8oXZ90T5ckKLIGJc.jpg'),
(154808, 11011, 'Corridas Proibidas Os Melhores da America S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425773.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mgaQVGBiXpe81gyRwDRo1G3ccXl.jpg'),
(154809, 11011, 'Corridas Proibidas Os Melhores da America S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425774.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pILC1wJR1IeJWP05wLJOZf3vQMp.jpg'),
(154810, 11011, 'Corridas Proibidas Os Melhores da America S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425775.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xo1fVwaiXYUXjltjEnIIC25zjWb.jpg'),
(154811, 11011, 'Corridas Proibidas Os Melhores da America S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/425776.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h3wsdnylXEk4dnmyH3PDH5tXHMg.jpg'),
(154812, 11011, 'Corridas Proibidas Os Melhores da America S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/425777.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tiBcrf5DNClukCrgnbD4Wwz5jCJ.jpg'),
(154813, 11011, 'Corridas Proibidas Os Melhores da America S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/425778.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cV8c96rbMRA7an0jrjqqsM0WmyM.jpg'),
(154814, 11011, 'Corridas Proibidas Os Melhores da America S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/425779.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/idQwlGgKfnk5NPlSjBpKmFqtpiG.jpg'),
(154815, 11011, 'Corridas Proibidas Os Melhores da America S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/425780.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6fIxFAxC7Q6zZEoFeuthf0g07pC.jpg'),
(154816, 11011, 'Corridas Proibidas Os Melhores da America S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/425781.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dugyHqVZvVTjm9npR2eBJpo24Vo.jpg'),
(154817, 11011, 'Corridas Proibidas Os Melhores da America S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/425782.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ntVe0vU9J61gnJzjTPY8rDZQGPw.jpg'),
(154818, 11011, 'Corridas Proibidas Os Melhores da America S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/425783.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/myUYqQzPfpx76CEwqbdKL5lFO85.jpg'),
(154819, 11012, 'Corridas Proibidas Os Melhores da America S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425784.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6WBuftqcSqk8ftcBjPNhafNKYkz.jpg'),
(154820, 11012, 'Corridas Proibidas Os Melhores da America S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425785.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4oGI6b57lcucrcMuXKKLoOpyCFP.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(154821, 11012, 'Corridas Proibidas Os Melhores da America S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425786.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/avYmqCXX5XlSY0SyYIcxGh6uLkp.jpg'),
(154822, 11012, 'Corridas Proibidas Os Melhores da America S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425787.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r1Edc8CT9VRDZu32VlHut0jBPh9.jpg'),
(154823, 11012, 'Corridas Proibidas Os Melhores da America S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425788.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dn2NnE9ONva2pMdKP16lmHUyTg9.jpg'),
(154824, 11012, 'Corridas Proibidas Os Melhores da America S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/425789.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m7vrRP156johCJZol63ec3OH7yw.jpg'),
(154825, 11012, 'Corridas Proibidas Os Melhores da America S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/425790.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/za3USYRRzJE8s4ugKKPuSMqqucS.jpg'),
(154826, 11012, 'Corridas Proibidas Os Melhores da America S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/425791.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c4K30YYJALm5b80LkEyHzW7arOx.jpg'),
(154827, 11012, 'Corridas Proibidas Os Melhores da America S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/425792.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qppsqJ4tX9b8x0xsgF2hVKoxB3B.jpg'),
(154828, 11012, 'Corridas Proibidas Os Melhores da America S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/425793.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sv2hMLpO6iFWtt0U7XBfd1BcHXB.jpg'),
(154829, 11012, 'Corridas Proibidas Os Melhores da America S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/425794.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8Axpl3uIlieQEdeCiBZZUE6Y7vw.jpg'),
(154830, 11012, 'Corridas Proibidas Os Melhores da America S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/425795.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9Ejp8je1gblxOXqJ3jCtgWZ4AsI.jpg'),
(154831, 11012, 'Corridas Proibidas Os Melhores da America S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/425796.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4uu4fv9T98aCxCFNr1WcAophI2X.jpg'),
(154832, 11012, 'Corridas Proibidas Os Melhores da America S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/425797.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lNoEQLwuuHgRumjkw7s1p07CQkv.jpg'),
(154833, 11012, 'Corridas Proibidas Os Melhores da America S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/425798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Sk1VXZ6z85RmP2VGjTspmlojnv.jpg'),
(154834, 11013, 'Maes Meninas e Estudantes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/an2ozoFyjc7vLTVNbewLwr8vbCu.jpg'),
(154835, 11013, 'Maes Meninas e Estudantes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/an2ozoFyjc7vLTVNbewLwr8vbCu.jpg'),
(154836, 11013, 'Maes Meninas e Estudantes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/an2ozoFyjc7vLTVNbewLwr8vbCu.jpg'),
(154837, 11013, 'Maes Meninas e Estudantes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/an2ozoFyjc7vLTVNbewLwr8vbCu.jpg'),
(154838, 11013, 'Maes Meninas e Estudantes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/an2ozoFyjc7vLTVNbewLwr8vbCu.jpg'),
(154839, 11014, 'Manual de Assassinato para Boas Garotas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425760.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ezf9qLdQQJsMNLJjK4myEhNokVN.jpg'),
(154840, 11014, 'Manual de Assassinato para Boas Garotas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425761.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jIJVCHfeDI2a2mnHbTZss6pM6by.jpg'),
(154841, 11014, 'Manual de Assassinato para Boas Garotas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425762.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sEBwyQKWVwbw3SlP8JnpIzVBkRe.jpg'),
(154842, 11014, 'Manual de Assassinato para Boas Garotas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425763.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h0hJAEBEAu6OlyorShiWR5cCFTZ.jpg'),
(154843, 11014, 'Manual de Assassinato para Boas Garotas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425764.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uFOcfL4dlmKVadHB18tBKHH6boe.jpg'),
(154844, 11014, 'Manual de Assassinato para Boas Garotas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/425765.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3dfyzqMyCmve488HmXb8Z2ihdXa.jpg'),
(154845, 11015, 'Marasli O Protetor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/424620.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qNnyTYF91UfudFSGgvFsYkUUG65.jpg'),
(154846, 11015, 'Marasli O Protetor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/424621.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jexPjxi5lXWtKpCjg7QxcNOAThC.jpg'),
(154847, 11015, 'Marasli O Protetor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/424622.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Ahw23wovCbnGKlYxezqiv8oN9Iy.jpg'),
(154848, 11015, 'Marasli O Protetor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/424623.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/F6DOpViSEY5gaydv5XuzTjgvnd.jpg'),
(154849, 11015, 'Marasli O Protetor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/424624.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uSMaDqfVMc3LlRiaCuiYMO6VQvJ.jpg'),
(154850, 11015, 'Marasli O Protetor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/424625.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hTUFN9nTr5N9VDttSKzrJePwPK.jpg'),
(154851, 11015, 'Marasli O Protetor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/424626.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9JfjGAasN7rKAyDg4NTKMumTG5H.jpg'),
(154852, 11015, 'Marasli O Protetor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/424627.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mVgnBNDBjGiivaBpkiXRiwsRhOD.jpg'),
(154853, 11015, 'Marasli O Protetor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/424628.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6qBonabIhIerWUGbmPWVQBXHoiX.jpg'),
(154854, 11015, 'Marasli O Protetor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/424629.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5pu9LHKBngtsjiet9ryvnMYtEEG.jpg'),
(154855, 11015, 'Marasli O Protetor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/424630.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8TogewNZaHCjDVNYQDit50cfAKw.jpg'),
(154856, 11015, 'Marasli O Protetor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/424631.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6ZnEgWFWXwCjFqwbJcU80m2c9i4.jpg'),
(154857, 11015, 'Marasli O Protetor S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/424632.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dj9CsxKRVjGFG0JXkar2KNNWDoj.jpg'),
(154858, 11015, 'Marasli O Protetor S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/424633.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1zTRUUaSThrXLG97fJAtssY6hMT.jpg'),
(154859, 11015, 'Marasli O Protetor S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/424634.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oYSlhmksCwD7Q2OYV5LGIL195cr.jpg'),
(154860, 11015, 'Marasli O Protetor S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/424635.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hJ8eucJAHTtU8m8cHHIs8twboGk.jpg'),
(154861, 11015, 'Marasli O Protetor S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/424636.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7qytX4jJ7zDWl4BaVkf2rZ0y27b.jpg'),
(154862, 11015, 'Marasli O Protetor S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/424637.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/75B8UM9UkiF61GyWWsgizSJGmLu.jpg'),
(154863, 11015, 'Marasli O Protetor S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/424638.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/temEeXqqySmMG5uxzK3G8DYTxw.jpg'),
(154864, 11015, 'Marasli O Protetor S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/424639.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1HUckyqPWA3v8xJC0jpVACDpb4c.jpg'),
(154865, 11015, 'Marasli O Protetor S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/424640.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/YX9a4lu4C9N78H6KyC1QsMlF88.jpg'),
(154866, 11015, 'Marasli O Protetor S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/424641.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qdlcVC9KrZqBtlmNC5dttfL3pXe.jpg'),
(154867, 11015, 'Marasli O Protetor S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/424642.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w3rdqhOJbfyFY0hg05ONK2dwUt9.jpg'),
(154868, 11015, 'Marasli O Protetor S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/424643.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ufZiSrcHTl9rKwquxFS2ZP77Sms.jpg'),
(154869, 11015, 'Marasli O Protetor S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/424644.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f7O1TS2HS8oMSEFxNhYXbycXVnp.jpg'),
(154870, 11015, 'Marasli O Protetor S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/424645.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kFSzyOqiTIu6QmoMluGtn0ld5Qz.jpg'),
(154871, 11015, 'Marasli O Protetor S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/424646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154872, 11015, 'Marasli O Protetor S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/424647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154873, 11015, 'Marasli O Protetor S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/424648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154874, 11015, 'Marasli O Protetor S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/424649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154875, 11015, 'Marasli O Protetor S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/424650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154876, 11015, 'Marasli O Protetor S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/424651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154877, 11015, 'Marasli O Protetor S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/424652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154878, 11015, 'Marasli O Protetor S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/424653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154879, 11015, 'Marasli O Protetor S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/424654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154880, 11015, 'Marasli O Protetor S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/424655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154881, 11015, 'Marasli O Protetor S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/424656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154882, 11015, 'Marasli O Protetor S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/424657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154883, 11015, 'Marasli O Protetor S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/424658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154884, 11015, 'Marasli O Protetor S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/424659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154885, 11015, 'Marasli O Protetor S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/424660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154886, 11015, 'Marasli O Protetor S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/424661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154887, 11015, 'Marasli O Protetor S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/424662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154888, 11015, 'Marasli O Protetor S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/424663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154889, 11015, 'Marasli O Protetor S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/424664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154890, 11015, 'Marasli O Protetor S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/424665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154891, 11015, 'Marasli O Protetor S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/424666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154892, 11015, 'Marasli O Protetor S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/424667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154893, 11015, 'Marasli O Protetor S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/424668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154894, 11015, 'Marasli O Protetor S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/424669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154895, 11015, 'Marasli O Protetor S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/424670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154896, 11015, 'Marasli O Protetor S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/424671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154897, 11015, 'Marasli O Protetor S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/424672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154898, 11015, 'Marasli O Protetor S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/424673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154899, 11015, 'Marasli O Protetor S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/424674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154900, 11015, 'Marasli O Protetor S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/424675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154901, 11015, 'Marasli O Protetor S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/427388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154902, 11015, 'Marasli O Protetor S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/427389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154903, 11015, 'Marasli O Protetor S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/427390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154904, 11015, 'Marasli O Protetor S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/427391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154905, 11015, 'Marasli O Protetor S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/427392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154906, 11015, 'Marasli O Protetor S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/427393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154907, 11015, 'Marasli O Protetor S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/427394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154908, 11015, 'Marasli O Protetor S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/427395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154909, 11015, 'Marasli O Protetor S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/427396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154910, 11015, 'Marasli O Protetor S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/427397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154911, 11015, 'Marasli O Protetor S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/429672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154912, 11015, 'Marasli O Protetor S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/429673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154913, 11015, 'Marasli O Protetor S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/429674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154914, 11015, 'Marasli O Protetor S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/429675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154915, 11015, 'Marasli O Protetor S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/429676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154916, 11015, 'Marasli O Protetor S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/429677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154917, 11015, 'Marasli O Protetor S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/429678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154918, 11015, 'Marasli O Protetor S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/429679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8kHGsmdmZhxdteddgQbLIGrrE9.jpg'),
(154919, 11016, 'Mulheres de Azul S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425758.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4G4OO4bfuTX1Wm0RwUFcM7L2fHk.jpg'),
(154920, 11016, 'Mulheres de Azul S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425759.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nQjRsksBfP89njPLDAnpJaaaMFs.jpg'),
(154921, 11016, 'Mulheres de Azul S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/427105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7pXZ2CkLrKvno0jvBOmDNSSARCc.jpg'),
(154922, 11016, 'Mulheres de Azul S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/434510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7pXZ2CkLrKvno0jvBOmDNSSARCc.jpg'),
(154923, 11016, 'Mulheres de Azul S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/436094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7pXZ2CkLrKvno0jvBOmDNSSARCc.jpg'),
(154924, 11016, 'Mulheres de Azul S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/441865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7pXZ2CkLrKvno0jvBOmDNSSARCc.jpg'),
(154925, 11016, 'Mulheres de Azul S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/447297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7pXZ2CkLrKvno0jvBOmDNSSARCc.jpg'),
(154926, 11016, 'Mulheres de Azul S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/452301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7pXZ2CkLrKvno0jvBOmDNSSARCc.jpg'),
(154927, 11016, 'Mulheres de Azul S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/457596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7pXZ2CkLrKvno0jvBOmDNSSARCc.jpg'),
(154928, 11016, 'Mulheres de Azul S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/464089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7pXZ2CkLrKvno0jvBOmDNSSARCc.jpg'),
(154929, 11017, 'My Teen Romantic Comedy SNAFU [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425720.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nBqVYNZY5vEtGDISWauJqiCEb3W.jpg'),
(154930, 11017, 'My Teen Romantic Comedy SNAFU [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425721.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jzyULV5pI9Ve9xU4t8p6ALrF2J7.jpg'),
(154931, 11017, 'My Teen Romantic Comedy SNAFU [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425722.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xHtPdz9TXWsw3hVH6v8pPOG7VaO.jpg'),
(154932, 11017, 'My Teen Romantic Comedy SNAFU [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425723.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dsOtCQZJ4B5LWJQvekHXYmrvDPN.jpg'),
(154933, 11017, 'My Teen Romantic Comedy SNAFU [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425724.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7AjCyMIwp6dVIaCzpzvXlzhgUf1.jpg'),
(154934, 11017, 'My Teen Romantic Comedy SNAFU [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/425725.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lsX00HdNY7Ca9S6Of57rvaResLW.jpg'),
(154935, 11017, 'My Teen Romantic Comedy SNAFU [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/425726.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bQkFatUq62ZWJSbV4vQm9ZFg8x4.jpg'),
(154936, 11017, 'My Teen Romantic Comedy SNAFU [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/425727.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d5CKKYCwHw0fDdtDel58Ec65cVT.jpg'),
(154937, 11017, 'My Teen Romantic Comedy SNAFU [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/425728.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lX627EcrILeHil7Mr4ns6m2JJve.jpg'),
(154938, 11017, 'My Teen Romantic Comedy SNAFU [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/425729.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kvdB3VgIYAgN84OWkJA8dEiAL3.jpg'),
(154939, 11017, 'My Teen Romantic Comedy SNAFU [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/425730.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pOEtJInwTAtwRWPqaCpZ8r3RgTd.jpg'),
(154940, 11017, 'My Teen Romantic Comedy SNAFU [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/425731.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bXEvNXZflXgSAWPZh7PFYbawGdq.jpg'),
(154941, 11017, 'My Teen Romantic Comedy SNAFU [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/425732.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l5LZaLLIPPOQJh6cRBNIfF06HQK.jpg'),
(154942, 11018, 'My Teen Romantic Comedy SNAFU [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425733.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rLD1eykjx8kTa5VI9I9NYB8B5Ip.jpg'),
(154943, 11018, 'My Teen Romantic Comedy SNAFU [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425734.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oz7UEUqkfIlwv54peBnnHJNoXN9.jpg'),
(154944, 11018, 'My Teen Romantic Comedy SNAFU [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425735.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aga3XUSfHCUUvGIyCrAqWw2fHzY.jpg'),
(154945, 11018, 'My Teen Romantic Comedy SNAFU [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425736.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cJlEKGnpHZg7e0SQ68zjwaSBc7V.jpg'),
(154946, 11018, 'My Teen Romantic Comedy SNAFU [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425737.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/49yoBWYLJ6MPoxVm5dupJM3msNp.jpg'),
(154947, 11018, 'My Teen Romantic Comedy SNAFU [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/425738.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2HyrOi12DH5gNPXaFqRvocErxBc.jpg'),
(154948, 11018, 'My Teen Romantic Comedy SNAFU [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/425739.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jfwDkrRWHeSzluJ7E5FD7gFetWh.jpg'),
(154949, 11018, 'My Teen Romantic Comedy SNAFU [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/425740.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4Q8HVgLuyCq2AYLkMjRMeNOwbs4.jpg'),
(154950, 11018, 'My Teen Romantic Comedy SNAFU [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/425741.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4Okccd2Rc0oxQ7uwxb2Hth5HH85.jpg'),
(154951, 11018, 'My Teen Romantic Comedy SNAFU [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/425742.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eiGSznTCfyuZDOdRvhKrabByRm6.jpg'),
(154952, 11018, 'My Teen Romantic Comedy SNAFU [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/425743.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qZg7z8T3YB7QhCwgvwEgISmNIZV.jpg'),
(154953, 11018, 'My Teen Romantic Comedy SNAFU [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/425744.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kVOuAQsRWujxW02LxF5gbwKmJnM.jpg'),
(154954, 11018, 'My Teen Romantic Comedy SNAFU [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/425745.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t5eZjZy1kAVJE4e8x08vUVaNU6i.jpg'),
(154955, 11019, 'My Teen Romantic Comedy SNAFU [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425746.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gfNhUWkDpfJsgBrgaBgJljMOVtA.jpg'),
(154956, 11019, 'My Teen Romantic Comedy SNAFU [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425747.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8aXJCDageb8Wu3XqnbDzyp0q9CE.jpg'),
(154957, 11019, 'My Teen Romantic Comedy SNAFU [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425748.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yVrQsY4EOmRfF65FPGMbmkYC0To.jpg'),
(154958, 11019, 'My Teen Romantic Comedy SNAFU [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425749.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tTsSFkJT5haYQXIsPeRm8OmIWQk.jpg'),
(154959, 11019, 'My Teen Romantic Comedy SNAFU [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425750.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gGWeofDCHguXSPUBxTzXUgGNLP7.jpg'),
(154960, 11019, 'My Teen Romantic Comedy SNAFU [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/425751.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qx2q2zWNo0ubpbC5o9ZdY1CCB03.jpg'),
(154961, 11019, 'My Teen Romantic Comedy SNAFU [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/425752.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8z7HUga81ijRwPI4Auax5rODLzw.jpg'),
(154962, 11019, 'My Teen Romantic Comedy SNAFU [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/425753.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q9OEFsFT5Y4Xz2qNh1JrDjiZIPS.jpg'),
(154963, 11019, 'My Teen Romantic Comedy SNAFU [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/425754.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zH7b96xYXRAPs0OYqEKmkBwTyjM.jpg'),
(154964, 11019, 'My Teen Romantic Comedy SNAFU [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/425755.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xa5j0n3dJ5PUhC3OgMCZc3vmzgd.jpg'),
(154965, 11019, 'My Teen Romantic Comedy SNAFU [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/425756.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s5iz6JhWizxKGbOJ87m7hR4JUlw.jpg'),
(154966, 11019, 'My Teen Romantic Comedy SNAFU [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/425757.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ApwiPG1SHnQsaFB5ubTP0fmv0En.jpg'),
(154967, 11020, 'O Namorado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425710.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lwyUkeKGtR9IWXdulxj9UsODGw0.jpg'),
(154968, 11020, 'O Namorado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425711.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zMyeP9jXymFYb5VsEIafLHq7H1E.jpg'),
(154969, 11020, 'O Namorado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425712.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r7M85Xl7Yd7WyQjn8TTIL6zh1rP.jpg'),
(154970, 11020, 'O Namorado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425713.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/luGAzdI3MgZQD4qBtbOD48n4vQZ.jpg'),
(154971, 11020, 'O Namorado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425714.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nwgkLdHOcExcIS85HV7YPGMbWzM.jpg'),
(154972, 11020, 'O Namorado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/425715.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8qKUnoYKaWZb9c8S9CC7zNwJq2x.jpg'),
(154973, 11020, 'O Namorado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/425716.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2kTCyO84FH6Bstv8pfCXPUvqXAa.jpg'),
(154974, 11020, 'O Namorado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/425717.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i0tvafNfswe2WZgc4YUUa9ZfJ36.jpg'),
(154975, 11020, 'O Namorado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/425718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u3vmYrNBl3AWzYQIp1JpmIpZl6g.jpg'),
(154976, 11020, 'O Namorado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/425719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u3vmYrNBl3AWzYQIp1JpmIpZl6g.jpg'),
(154977, 11021, 'Operacao FBI S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425704.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eLJGD2c3JN2ucBwOV0xUah9t8Ws.jpg'),
(154978, 11021, 'Operacao FBI S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425705.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mkTTqM8VYMEaYk9OXWC9IGEjyUe.jpg'),
(154979, 11021, 'Operacao FBI S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425706.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rhtOBnLIixbn0MekcJUkdxjZ1BK.jpg'),
(154980, 11021, 'Operacao FBI S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425707.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5WjHZKV4v2AMOZHMUG3wdko7Ww9.jpg'),
(154981, 11021, 'Operacao FBI S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425708.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6Xxu3SDIGR5tOS57G1sKYXTN0hL.jpg'),
(154982, 11021, 'Operacao FBI S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/425709.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zKIKDesvrL8B5v4SEzg5F7FBqhL.jpg'),
(154983, 11022, 'Restaurando Casas de Fazenda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(154984, 11022, 'Restaurando Casas de Fazenda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(154985, 11022, 'Restaurando Casas de Fazenda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(154986, 11022, 'Restaurando Casas de Fazenda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(154987, 11022, 'Restaurando Casas de Fazenda S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(154988, 11022, 'Restaurando Casas de Fazenda S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/425695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(154989, 11023, 'Restaurando Casas de Fazenda S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(154990, 11023, 'Restaurando Casas de Fazenda S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(154991, 11023, 'Restaurando Casas de Fazenda S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(154992, 11023, 'Restaurando Casas de Fazenda S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(154993, 11023, 'Restaurando Casas de Fazenda S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(154994, 11023, 'Restaurando Casas de Fazenda S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/425701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(154995, 11023, 'Restaurando Casas de Fazenda S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/425702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(154996, 11023, 'Restaurando Casas de Fazenda S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/425703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(154997, 11024, 'Restaurando Casas de Fazenda S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/463743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(154998, 11024, 'Restaurando Casas de Fazenda S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/463744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(154999, 11024, 'Restaurando Casas de Fazenda S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/463745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(155000, 11024, 'Restaurando Casas de Fazenda S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/463746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(155001, 11024, 'Restaurando Casas de Fazenda S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/463747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(155002, 11024, 'Restaurando Casas de Fazenda S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/463748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(155003, 11024, 'Restaurando Casas de Fazenda S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/463749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(155004, 11024, 'Restaurando Casas de Fazenda S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/463750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bvdPP4Oru7l468hdBFynlP5jNja.jpg'),
(155005, 11025, 'Segredos de Guerra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g4FFzub0ud62CMhmw7Hert4KAiP.jpg'),
(155006, 11025, 'Segredos de Guerra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g4FFzub0ud62CMhmw7Hert4KAiP.jpg'),
(155007, 11025, 'Segredos de Guerra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g4FFzub0ud62CMhmw7Hert4KAiP.jpg'),
(155008, 11025, 'Segredos de Guerra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g4FFzub0ud62CMhmw7Hert4KAiP.jpg'),
(155009, 11026, 'Abraco da Serendipidade [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425683.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kS22j9P5puQzC7MOucawJVrPFXz.jpg'),
(155010, 11026, 'Abraco da Serendipidade [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425684.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iwrMzxz55BPO7Js0BQVhWDbnDwg.jpg'),
(155011, 11026, 'Abraco da Serendipidade [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a4sw7NrCHrJhQn8HUC4xOhO7cUi.jpg'),
(155012, 11026, 'Abraco da Serendipidade [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/442997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a4sw7NrCHrJhQn8HUC4xOhO7cUi.jpg'),
(155013, 11026, 'Abraco da Serendipidade [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/442998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a4sw7NrCHrJhQn8HUC4xOhO7cUi.jpg'),
(155014, 11026, 'Abraco da Serendipidade [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/442999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a4sw7NrCHrJhQn8HUC4xOhO7cUi.jpg'),
(155015, 11026, 'Abraco da Serendipidade [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/443000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a4sw7NrCHrJhQn8HUC4xOhO7cUi.jpg'),
(155016, 11026, 'Abraco da Serendipidade [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/443001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a4sw7NrCHrJhQn8HUC4xOhO7cUi.jpg'),
(155017, 11027, 'Strawberry Panic [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425671.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tRDiDHTsfm5TbtMNAuApMO52enX.jpg'),
(155018, 11027, 'Strawberry Panic [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425672.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2RgMZwhiH7TdyXvvMhxDJKxy4Nh.jpg'),
(155019, 11027, 'Strawberry Panic [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425673.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9rmwbPEiKxoRmsmvxUBl1mgXQ10.jpg'),
(155020, 11027, 'Strawberry Panic [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425674.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aDnBFLs93Z2cLoUTfTh8olwqopA.jpg'),
(155021, 11027, 'Strawberry Panic [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425675.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7uIpuqjroiBeFEVxUII6kOJGZ9v.jpg'),
(155022, 11027, 'Strawberry Panic [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/425676.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oflZ3n9d1g5T5jVb1SvJhmHR2VW.jpg'),
(155023, 11027, 'Strawberry Panic [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/425677.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8qrPWEQnD7eoifMR6F9Pqoiom34.jpg'),
(155024, 11027, 'Strawberry Panic [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/425678.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lLsw20BzM8jTGUrxqc6Lh7kk1oz.jpg'),
(155025, 11027, 'Strawberry Panic [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/425679.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cOwU4LAvDmaMd7lX6LZMStsSDJq.jpg'),
(155026, 11027, 'Strawberry Panic [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/425680.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8wPwzBk723pxolHbsm2z0GV7ewS.jpg'),
(155027, 11027, 'Strawberry Panic [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/425681.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7Y03w3sWKeQMgOlPoSjOJNYz82v.jpg'),
(155028, 11027, 'Strawberry Panic [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/425682.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cAZgQdiua8WcoZSU4FEvcGoDIXG.jpg'),
(155029, 11028, 'Traicao O Marido Perfeito [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425668.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9Av10QfVb761B954fvSPZ90WC3h.jpg'),
(155030, 11028, 'Traicao O Marido Perfeito [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425669.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n97e1l8GOSlGv2mDXttEdohCgAG.jpg'),
(155031, 11028, 'Traicao O Marido Perfeito [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425670.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wIC55uMmYzdBUnTdubCEWkUqHHu.jpg'),
(155032, 11029, 'Um Beijo do Gordo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425664.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hCZLaoFBXC6VbjoiUtpszu18sf1.jpg'),
(155033, 11029, 'Um Beijo do Gordo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425665.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/NEcju3xjSheG5vC553vHwqOJNT.jpg'),
(155034, 11029, 'Um Beijo do Gordo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425666.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wCsoZ31Y5MpMEquacERrzyXX0JY.jpg'),
(155035, 11029, 'Um Beijo do Gordo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425667.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ggYbVTm8uejaV0Yn92PxH5oUG7z.jpg'),
(155036, 11030, 'Wonderful Precure [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/425626.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5ibk4F4yxhyS8s7Ie6nvc3Sje4t.jpg'),
(155037, 11030, 'Wonderful Precure [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/425627.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rZC30QMzaPIfBdLjBiJjNvhHnfG.jpg'),
(155038, 11030, 'Wonderful Precure [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/425628.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4TqdqL4PIts4N2tAEM25PFrlFPL.jpg'),
(155039, 11030, 'Wonderful Precure [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/425629.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dMxYG3aAjUUlSKXAv6KA2UqaAgL.jpg'),
(155040, 11030, 'Wonderful Precure [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/425630.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/48lvbeDjWqoKUWAJ8XTK62rYLlb.jpg'),
(155041, 11030, 'Wonderful Precure [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/425631.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eEw3H0kuD76zAIIbSxffhD7QAf1.jpg'),
(155042, 11030, 'Wonderful Precure [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/425632.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ldFSjSVTbVgu7628t4JiV3zXCcx.jpg'),
(155043, 11030, 'Wonderful Precure [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/425633.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mCQFzZRN4QtKudRAdTZlCJgDZes.jpg'),
(155044, 11030, 'Wonderful Precure [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/425634.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yErTXGrE9OaMfDQFxUUuXwvNUCJ.jpg'),
(155045, 11030, 'Wonderful Precure [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/425635.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yNkZJRquKmgSblI6ozqSu32AAaW.jpg'),
(155046, 11030, 'Wonderful Precure [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/425636.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6KO6Z2gOQri9nKtFWfNGqSSfbVB.jpg'),
(155047, 11030, 'Wonderful Precure [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/425637.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5YdqPCoS0zzVeHGo2d9y5BzTMHT.jpg'),
(155048, 11030, 'Wonderful Precure [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/425638.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2b7Y2mDhZUE1Qv2ffCjgn3KbmQJ.jpg'),
(155049, 11030, 'Wonderful Precure [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/425639.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ctyTkWWVKAl4bqrHemQlBVRT9D3.jpg'),
(155050, 11030, 'Wonderful Precure [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/425640.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mzbkt9lmhfkZzMF06G728zHIHeS.jpg'),
(155051, 11030, 'Wonderful Precure [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/425641.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dFGL1ud0pX9Uu1HUXmFfiX4A6Vr.jpg'),
(155052, 11030, 'Wonderful Precure [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/425642.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9cB19bB4U8eENSP3LnIOMenUXt2.jpg'),
(155053, 11030, 'Wonderful Precure [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/425643.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fgNPrsTbTlu7wTBmb1sEuDtXK7n.jpg'),
(155054, 11030, 'Wonderful Precure [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/425644.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oKctVvKtc2r4xcRCZ9vdwEkly1z.jpg'),
(155055, 11030, 'Wonderful Precure [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/425645.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yk4tXzoukHYy2iV1FcBsubL9GZD.jpg'),
(155056, 11030, 'Wonderful Precure [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/425646.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iOzJEuq4RqtKzRn2OoJgVKIA8B4.jpg'),
(155057, 11030, 'Wonderful Precure [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/425647.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rEnRHhknYv61xajOa2pTj1awodP.jpg'),
(155058, 11030, 'Wonderful Precure [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/425648.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/baH4OxId3whki3PpIg5gzae6poT.jpg'),
(155059, 11030, 'Wonderful Precure [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/425649.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c3LCACAPlMzyRhLzsbQaOtF09r7.jpg'),
(155060, 11030, 'Wonderful Precure [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/425650.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iMq3nUFah0d75zSJGj4RwnwEMnn.jpg'),
(155061, 11030, 'Wonderful Precure [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/425651.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fxRwEPcczD6H9VizzusUoEyQKg7.jpg'),
(155062, 11031, 'Bairros em Guerra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/422910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gz7HoLzH6oGmB0FGJeoSD2R3SIr.jpg'),
(155063, 11031, 'Bairros em Guerra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/422911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gz7HoLzH6oGmB0FGJeoSD2R3SIr.jpg'),
(155064, 11032, 'Devolva me a Vida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/422850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155065, 11032, 'Devolva me a Vida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/422851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155066, 11032, 'Devolva me a Vida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/422852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155067, 11032, 'Devolva me a Vida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/422853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155068, 11032, 'Devolva me a Vida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/422854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155069, 11032, 'Devolva me a Vida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/422855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155070, 11032, 'Devolva me a Vida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/422856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155071, 11032, 'Devolva me a Vida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/422857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(155072, 11032, 'Devolva me a Vida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/422858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155073, 11032, 'Devolva me a Vida S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/422859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155074, 11032, 'Devolva me a Vida S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/422860.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8xOEi24mCQAlRyHwSfU2up3loy4.jpg'),
(155075, 11032, 'Devolva me a Vida S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/422861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155076, 11032, 'Devolva me a Vida S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/422862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155077, 11032, 'Devolva me a Vida S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/422863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155078, 11032, 'Devolva me a Vida S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/422864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155079, 11032, 'Devolva me a Vida S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/422865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155080, 11032, 'Devolva me a Vida S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/422866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155081, 11032, 'Devolva me a Vida S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/422867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155082, 11032, 'Devolva me a Vida S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/422868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155083, 11032, 'Devolva me a Vida S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/422869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155084, 11032, 'Devolva me a Vida S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/422870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155085, 11032, 'Devolva me a Vida S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/422871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155086, 11032, 'Devolva me a Vida S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/422872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155087, 11032, 'Devolva me a Vida S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/422873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155088, 11032, 'Devolva me a Vida S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/422874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155089, 11032, 'Devolva me a Vida S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/422875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155090, 11032, 'Devolva me a Vida S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/422876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155091, 11032, 'Devolva me a Vida S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/422877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155092, 11032, 'Devolva me a Vida S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/422878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155093, 11032, 'Devolva me a Vida S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/422879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155094, 11032, 'Devolva me a Vida S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/422880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155095, 11032, 'Devolva me a Vida S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/422881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155096, 11032, 'Devolva me a Vida S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/422882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155097, 11032, 'Devolva me a Vida S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/422883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155098, 11032, 'Devolva me a Vida S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/422884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155099, 11032, 'Devolva me a Vida S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/422885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155100, 11032, 'Devolva me a Vida S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/422886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155101, 11032, 'Devolva me a Vida S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/422887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155102, 11032, 'Devolva me a Vida S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/422888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155103, 11032, 'Devolva me a Vida S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/422889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155104, 11032, 'Devolva me a Vida S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/422890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155105, 11032, 'Devolva me a Vida S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/422891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155106, 11032, 'Devolva me a Vida S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/422892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155107, 11032, 'Devolva me a Vida S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/422893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155108, 11032, 'Devolva me a Vida S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/422894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155109, 11032, 'Devolva me a Vida S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/422895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155110, 11032, 'Devolva me a Vida S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/422896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155111, 11032, 'Devolva me a Vida S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/422897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155112, 11032, 'Devolva me a Vida S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/422898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155113, 11032, 'Devolva me a Vida S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/422899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155114, 11032, 'Devolva me a Vida S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/422900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155115, 11032, 'Devolva me a Vida S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/422901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155116, 11032, 'Devolva me a Vida S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/422902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155117, 11032, 'Devolva me a Vida S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/422903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155118, 11032, 'Devolva me a Vida S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/422904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155119, 11032, 'Devolva me a Vida S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/422905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155120, 11032, 'Devolva me a Vida S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/422906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155121, 11032, 'Devolva me a Vida S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/422907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155122, 11032, 'Devolva me a Vida S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/422908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155123, 11032, 'Devolva me a Vida S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/422909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oD9LhXvRW7wQtJtELLV2wq20nbK.jpg'),
(155124, 11033, 'Forca de Mulher S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/430518.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3erbQWGOecwuKBzDKlbWVMJyiTe.jpg'),
(155125, 11033, 'Forca de Mulher S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/430519.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kd2EJxMUEygAw2cGWSYfwYXqeAP.jpg'),
(155126, 11033, 'Forca de Mulher S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/430520.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9dnNEmdkPRtJZLyj6SUnUrRThWH.jpg'),
(155127, 11033, 'Forca de Mulher S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/430521.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9TKpCuPJSYmup1Nvh3VBkIoYXLG.jpg'),
(155128, 11033, 'Forca de Mulher S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/430522.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/liwToAJkRoNljLryFbmw4WYs04k.jpg'),
(155129, 11033, 'Forca de Mulher S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/430523.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9kscNy2j7zYURiEmwPNUmQkyUmV.jpg'),
(155130, 11033, 'Forca de Mulher S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/430524.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xB1NUdbxHH914TnSIILXTOqYWo3.jpg'),
(155131, 11033, 'Forca de Mulher S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/430525.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uOuVqF6vf9YKqwAvbM6xizef63I.jpg'),
(155132, 11033, 'Forca de Mulher S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/430526.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vFFhK8LzEyCd31NYCOmvCVycgzS.jpg'),
(155133, 11033, 'Forca de Mulher S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/430527.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3GMm3RdfxJ4kKjKfjg4k0F5U5OZ.jpg'),
(155134, 11033, 'Forca de Mulher S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/430528.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ylQwc4YmuqnntXe0gaqG2EnfOXl.jpg'),
(155135, 11033, 'Forca de Mulher S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/430529.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kndY18twnD1hUseQeffk9YzP5Og.jpg'),
(155136, 11033, 'Forca de Mulher S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/430530.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eYZLzAAHHEeU8xf70PQWxMBMAuI.jpg'),
(155137, 11033, 'Forca de Mulher S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/430531.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bVgj6SKKwXksWVllgy3iIjAXM26.jpg'),
(155138, 11033, 'Forca de Mulher S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/430532.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oTkuObVDStNeJqV1SV9zwjBjX8Z.jpg'),
(155139, 11033, 'Forca de Mulher S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/430533.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cgBX6JtA34a7GOmZRfyCe8MRzL.jpg'),
(155140, 11033, 'Forca de Mulher S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/430534.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tPEdHnZOt6kzkr8ASGyMUyAjPPH.jpg'),
(155141, 11033, 'Forca de Mulher S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/430535.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/liwToAJkRoNljLryFbmw4WYs04k.jpg'),
(155142, 11033, 'Forca de Mulher S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/430536.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yAHkM11rM1mAuBGR38kBsYSYF1Z.jpg'),
(155143, 11033, 'Forca de Mulher S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/430537.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cRFwxsFAgF8cswdfNyphLaictPc.jpg'),
(155144, 11033, 'Forca de Mulher S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/430538.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p3UPGa5v7C7VWiKst3zcGQN2PPb.jpg'),
(155145, 11033, 'Forca de Mulher S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/430539.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5c18bnLXhOZpjZfohEhIYAfkKtW.jpg'),
(155146, 11033, 'Forca de Mulher S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/430540.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kpLwghTyJkOjLYnifxYCtxRexsv.jpg'),
(155147, 11033, 'Forca de Mulher S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/430541.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rCqE8Q7qmrRNFAjWqxfzUI7HqvS.jpg'),
(155148, 11033, 'Forca de Mulher S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/430542.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oK0nTjAOc6p4DIpeozRdrxhc5MX.jpg'),
(155149, 11033, 'Forca de Mulher S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/430543.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kdFMog2NhRKwSFJDeKE6wRpIp0P.jpg'),
(155150, 11033, 'Forca de Mulher S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/430544.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nS7ZMGtsbGcN9VLVrhjmmSWCRsJ.jpg'),
(155151, 11033, 'Forca de Mulher S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/430545.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aJxWAJgl9q6oAHCq02Zy5CKWZ7V.jpg'),
(155152, 11033, 'Forca de Mulher S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/430546.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5z4VYxWE1to3xKU7AUjsd0AmJ5Q.jpg'),
(155153, 11033, 'Forca de Mulher S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/430547.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eGKLJaCIj6kViX2r3T4iE8qRa2a.jpg'),
(155154, 11033, 'Forca de Mulher S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/430548.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eBVv6Aowb9b3UeGHZYhEJLUSUnq.jpg'),
(155155, 11033, 'Forca de Mulher S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/430549.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wjONZWl4hf1X3ZkOQtpKp1yw9f0.jpg'),
(155156, 11033, 'Forca de Mulher S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/430550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155157, 11033, 'Forca de Mulher S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/430551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155158, 11033, 'Forca de Mulher S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/430552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155159, 11033, 'Forca de Mulher S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/430553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155160, 11033, 'Forca de Mulher S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/430554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155161, 11033, 'Forca de Mulher S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/430555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155162, 11033, 'Forca de Mulher S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/430556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155163, 11033, 'Forca de Mulher S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/430557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155164, 11033, 'Forca de Mulher S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/430558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155165, 11033, 'Forca de Mulher S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/430559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155166, 11033, 'Forca de Mulher S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/430560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155167, 11033, 'Forca de Mulher S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/430561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155168, 11033, 'Forca de Mulher S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/430562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155169, 11033, 'Forca de Mulher S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/430563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155170, 11033, 'Forca de Mulher S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/430564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155171, 11033, 'Forca de Mulher S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/430565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155172, 11033, 'Forca de Mulher S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/430566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155173, 11033, 'Forca de Mulher S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/430567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155174, 11033, 'Forca de Mulher S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/430568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155175, 11033, 'Forca de Mulher S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/430569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155176, 11033, 'Forca de Mulher S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/430570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155177, 11033, 'Forca de Mulher S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/430571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155178, 11033, 'Forca de Mulher S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/430572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155179, 11033, 'Forca de Mulher S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/430573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155180, 11033, 'Forca de Mulher S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/430574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155181, 11033, 'Forca de Mulher S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/430575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155182, 11033, 'Forca de Mulher S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/430576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155183, 11033, 'Forca de Mulher S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/430577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155184, 11033, 'Forca de Mulher S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/430578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155185, 11033, 'Forca de Mulher S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/430579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155186, 11033, 'Forca de Mulher S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/430580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155187, 11033, 'Forca de Mulher S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/430581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155188, 11033, 'Forca de Mulher S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/430582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155189, 11033, 'Forca de Mulher S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/430583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155190, 11033, 'Forca de Mulher S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/430584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155191, 11033, 'Forca de Mulher S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/430585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155192, 11033, 'Forca de Mulher S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/430586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155193, 11033, 'Forca de Mulher S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/430587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155194, 11033, 'Forca de Mulher S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/430588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155195, 11033, 'Forca de Mulher S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/430589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155196, 11033, 'Forca de Mulher S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/430590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155197, 11033, 'Forca de Mulher S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/430591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155198, 11033, 'Forca de Mulher S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/430592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155199, 11033, 'Forca de Mulher S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/430593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155200, 11033, 'Forca de Mulher S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/430594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155201, 11033, 'Forca de Mulher S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/430595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155202, 11033, 'Forca de Mulher S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/430596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155203, 11033, 'Forca de Mulher S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/430597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155204, 11033, 'Forca de Mulher S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/430598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155205, 11033, 'Forca de Mulher S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/430599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155206, 11033, 'Forca de Mulher S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/430600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155207, 11033, 'Forca de Mulher S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/430601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155208, 11033, 'Forca de Mulher S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/430602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155209, 11033, 'Forca de Mulher S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/430603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155210, 11033, 'Forca de Mulher S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/430604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155211, 11033, 'Forca de Mulher S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/430605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155212, 11033, 'Forca de Mulher S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/430606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155213, 11033, 'Forca de Mulher S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/430607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155214, 11033, 'Forca de Mulher S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/430608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155215, 11033, 'Forca de Mulher S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/430609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155216, 11033, 'Forca de Mulher S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/430610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155217, 11033, 'Forca de Mulher S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/430611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155218, 11033, 'Forca de Mulher S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/430612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155219, 11033, 'Forca de Mulher S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/430613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155220, 11033, 'Forca de Mulher S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/430614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155221, 11034, 'Forca de Mulher S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/422705.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2yk95ogBkNXGhpwgbuNY4Fuzq4E.jpg'),
(155222, 11034, 'Forca de Mulher S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/422706.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cdMXDWbx3TZcDjU6v3VuzYbZeX3.jpg'),
(155223, 11034, 'Forca de Mulher S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/422707.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xY4WZCkHf2Wv9FgF1r12zcI0pyz.jpg'),
(155224, 11034, 'Forca de Mulher S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/422708.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1YZo4EIJibEH9y7GnchXGAt1aZI.jpg'),
(155225, 11034, 'Forca de Mulher S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/422709.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1JepUvRHLNsUfgDtb5VxLOyg51g.jpg'),
(155226, 11034, 'Forca de Mulher S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/422710.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nQViibDRMS4iIuqvG19U0bm1PAM.jpg'),
(155227, 11034, 'Forca de Mulher S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/422711.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/df3Kmz8LTAk6rVpYnLKTdCHMROe.jpg'),
(155228, 11034, 'Forca de Mulher S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/422712.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jJCvf6UuYYYzi6i4Bt3C0cmKZ9p.jpg'),
(155229, 11034, 'Forca de Mulher S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/422713.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fss2PuadWF0Ri5EPSKMwaPmlByA.jpg'),
(155230, 11034, 'Forca de Mulher S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/422714.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jcJhCaDxMsFPq37l7QjGAJRFrin.jpg'),
(155231, 11034, 'Forca de Mulher S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/422715.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m8cCWojDnBO4qs0FR0ZelIWXiA.jpg'),
(155232, 11034, 'Forca de Mulher S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/422716.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eRxL6FwsgYVRc2WHkXPjCdm0Pxb.jpg'),
(155233, 11034, 'Forca de Mulher S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/422717.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/krZjRsBf1hu342z368sxIiutV6c.jpg'),
(155234, 11034, 'Forca de Mulher S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/422718.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mvJ8H5DGturumDtqpTgLTxE3STB.jpg'),
(155235, 11034, 'Forca de Mulher S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/422719.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1Gv7Rj9dQtgB6dZJuUFWmU2DXPb.jpg'),
(155236, 11034, 'Forca de Mulher S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/422720.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gArmhRvu5SlF2PEM8xTs1qqrauu.jpg'),
(155237, 11034, 'Forca de Mulher S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/422721.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5KO8uZlbhaOVYvPDVAkzRNoroVy.jpg'),
(155238, 11034, 'Forca de Mulher S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/422722.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/YUOgLidFqZHmG3aqMkdLmcgiiL.jpg'),
(155239, 11034, 'Forca de Mulher S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/422723.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uSjmmqISfKBILghcj8WsK4VXT0e.jpg'),
(155240, 11034, 'Forca de Mulher S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/422724.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uyuSJdcBe1llcKIVWInauajqOnS.jpg'),
(155241, 11034, 'Forca de Mulher S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/422725.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qIz0dlcWB88MPWXZBKzTZl08W1f.jpg'),
(155242, 11034, 'Forca de Mulher S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/422726.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fCWGz1zKedFwRKVfzBYWXxcFREg.jpg'),
(155243, 11034, 'Forca de Mulher S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/422727.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jfI6y2C9FtwysbyZA6QNeFc7MCa.jpg'),
(155244, 11034, 'Forca de Mulher S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/422728.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oYnwIVJOujydKx3A80Od9dNAF4x.jpg'),
(155245, 11034, 'Forca de Mulher S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/422729.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g9pLZefiywld9hmx76l8gboI815.jpg'),
(155246, 11034, 'Forca de Mulher S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/422730.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m7nqvKOguUmVxLkewIlHP9H9LqI.jpg'),
(155247, 11034, 'Forca de Mulher S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/422731.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nxhPjmT7oOoVOKkCctmdnlCsMEn.jpg'),
(155248, 11034, 'Forca de Mulher S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/422732.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hGbQKgBHARuYKmJIDNBqXuNlZzk.jpg'),
(155249, 11034, 'Forca de Mulher S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/422733.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6PNJsYTN0NK4cgM4fE4D3TlEjin.jpg'),
(155250, 11034, 'Forca de Mulher S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/422734.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fdckJIHmbdjR5R3BNYaAzLI2Fxe.jpg'),
(155251, 11034, 'Forca de Mulher S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/422735.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nPOpLN9i26QYMyrW2V8qkief770.jpg'),
(155252, 11034, 'Forca de Mulher S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/422736.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ba6htmEbut69qrVrXuz19DollfG.jpg'),
(155253, 11034, 'Forca de Mulher S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/422737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155254, 11034, 'Forca de Mulher S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/422738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155255, 11034, 'Forca de Mulher S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/422739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155256, 11034, 'Forca de Mulher S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/422740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155257, 11034, 'Forca de Mulher S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/422741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155258, 11034, 'Forca de Mulher S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/422742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155259, 11034, 'Forca de Mulher S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/422743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155260, 11034, 'Forca de Mulher S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/422744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155261, 11034, 'Forca de Mulher S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/422745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155262, 11034, 'Forca de Mulher S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/422746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155263, 11034, 'Forca de Mulher S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/422747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155264, 11034, 'Forca de Mulher S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/422748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155265, 11034, 'Forca de Mulher S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/422749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155266, 11034, 'Forca de Mulher S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/422750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155267, 11034, 'Forca de Mulher S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/422751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155268, 11034, 'Forca de Mulher S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/422752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155269, 11034, 'Forca de Mulher S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/422753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155270, 11034, 'Forca de Mulher S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/422754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155271, 11034, 'Forca de Mulher S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/422755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155272, 11034, 'Forca de Mulher S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/422756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155273, 11034, 'Forca de Mulher S02 E53', 'http://sinalprivado.info:80/series/1533784/1533784/422757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155274, 11034, 'Forca de Mulher S02 E54', 'http://sinalprivado.info:80/series/1533784/1533784/422758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155275, 11034, 'Forca de Mulher S02 E55', 'http://sinalprivado.info:80/series/1533784/1533784/422759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155276, 11034, 'Forca de Mulher S02 E56', 'http://sinalprivado.info:80/series/1533784/1533784/422760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155277, 11034, 'Forca de Mulher S02 E57', 'http://sinalprivado.info:80/series/1533784/1533784/422761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155278, 11034, 'Forca de Mulher S02 E58', 'http://sinalprivado.info:80/series/1533784/1533784/422762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155279, 11034, 'Forca de Mulher S02 E59', 'http://sinalprivado.info:80/series/1533784/1533784/422763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155280, 11034, 'Forca de Mulher S02 E60', 'http://sinalprivado.info:80/series/1533784/1533784/422764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155281, 11034, 'Forca de Mulher S02 E61', 'http://sinalprivado.info:80/series/1533784/1533784/422765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155282, 11034, 'Forca de Mulher S02 E62', 'http://sinalprivado.info:80/series/1533784/1533784/422766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155283, 11034, 'Forca de Mulher S02 E63', 'http://sinalprivado.info:80/series/1533784/1533784/422767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155284, 11034, 'Forca de Mulher S02 E64', 'http://sinalprivado.info:80/series/1533784/1533784/422768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155285, 11034, 'Forca de Mulher S02 E65', 'http://sinalprivado.info:80/series/1533784/1533784/422769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155286, 11034, 'Forca de Mulher S02 E66', 'http://sinalprivado.info:80/series/1533784/1533784/422770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155287, 11034, 'Forca de Mulher S02 E67', 'http://sinalprivado.info:80/series/1533784/1533784/422771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155288, 11034, 'Forca de Mulher S02 E68', 'http://sinalprivado.info:80/series/1533784/1533784/422772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155289, 11034, 'Forca de Mulher S02 E69', 'http://sinalprivado.info:80/series/1533784/1533784/422773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155290, 11034, 'Forca de Mulher S02 E70', 'http://sinalprivado.info:80/series/1533784/1533784/422774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155291, 11034, 'Forca de Mulher S02 E71', 'http://sinalprivado.info:80/series/1533784/1533784/422775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155292, 11034, 'Forca de Mulher S02 E72', 'http://sinalprivado.info:80/series/1533784/1533784/422776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155293, 11034, 'Forca de Mulher S02 E73', 'http://sinalprivado.info:80/series/1533784/1533784/422777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155294, 11034, 'Forca de Mulher S02 E74', 'http://sinalprivado.info:80/series/1533784/1533784/422778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155295, 11034, 'Forca de Mulher S02 E75', 'http://sinalprivado.info:80/series/1533784/1533784/422779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155296, 11034, 'Forca de Mulher S02 E76', 'http://sinalprivado.info:80/series/1533784/1533784/422780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155297, 11034, 'Forca de Mulher S02 E77', 'http://sinalprivado.info:80/series/1533784/1533784/422781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155298, 11034, 'Forca de Mulher S02 E78', 'http://sinalprivado.info:80/series/1533784/1533784/422782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155299, 11034, 'Forca de Mulher S02 E79', 'http://sinalprivado.info:80/series/1533784/1533784/422783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155300, 11034, 'Forca de Mulher S02 E80', 'http://sinalprivado.info:80/series/1533784/1533784/422784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155301, 11034, 'Forca de Mulher S02 E81', 'http://sinalprivado.info:80/series/1533784/1533784/422785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155302, 11034, 'Forca de Mulher S02 E82', 'http://sinalprivado.info:80/series/1533784/1533784/422786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155303, 11034, 'Forca de Mulher S02 E83', 'http://sinalprivado.info:80/series/1533784/1533784/422787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155304, 11034, 'Forca de Mulher S02 E84', 'http://sinalprivado.info:80/series/1533784/1533784/422788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155305, 11034, 'Forca de Mulher S02 E85', 'http://sinalprivado.info:80/series/1533784/1533784/422789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155306, 11034, 'Forca de Mulher S02 E86', 'http://sinalprivado.info:80/series/1533784/1533784/422790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155307, 11034, 'Forca de Mulher S02 E87', 'http://sinalprivado.info:80/series/1533784/1533784/422791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155308, 11034, 'Forca de Mulher S02 E88', 'http://sinalprivado.info:80/series/1533784/1533784/422792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155309, 11034, 'Forca de Mulher S02 E89', 'http://sinalprivado.info:80/series/1533784/1533784/422793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155310, 11034, 'Forca de Mulher S02 E90', 'http://sinalprivado.info:80/series/1533784/1533784/422794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155311, 11034, 'Forca de Mulher S02 E91', 'http://sinalprivado.info:80/series/1533784/1533784/422795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155312, 11034, 'Forca de Mulher S02 E92', 'http://sinalprivado.info:80/series/1533784/1533784/422796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155313, 11034, 'Forca de Mulher S02 E93', 'http://sinalprivado.info:80/series/1533784/1533784/422797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155314, 11034, 'Forca de Mulher S02 E94', 'http://sinalprivado.info:80/series/1533784/1533784/422798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155315, 11034, 'Forca de Mulher S02 E95', 'http://sinalprivado.info:80/series/1533784/1533784/422799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155316, 11035, 'Forca de Mulher S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/422800.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jE3XlYUtCGeehLj5A6vn6tTYhWt.jpg'),
(155317, 11035, 'Forca de Mulher S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/422801.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zJxPxNBmPxCaQb8ogGf9RD8BqrU.jpg'),
(155318, 11035, 'Forca de Mulher S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/422802.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2OY6JJaO1SXMHUDtMETNUEe39cS.jpg'),
(155319, 11035, 'Forca de Mulher S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/422803.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A8HwBIvkO8JWQkOE2rugLelddCS.jpg'),
(155320, 11035, 'Forca de Mulher S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/422804.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3SEhkPfDNQnpFVLW4jN9v879J6V.jpg'),
(155321, 11035, 'Forca de Mulher S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/422805.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hLU2RLcGimKLPQ5uz0XEIRJVXBJ.jpg'),
(155322, 11035, 'Forca de Mulher S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/422806.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jggYOdzFq4DjlSN6l4eXp5Uy64c.jpg'),
(155323, 11035, 'Forca de Mulher S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/422807.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bVnBucaxIYatmQPaYY345OYW16X.jpg'),
(155324, 11035, 'Forca de Mulher S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/422808.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uuIOJdXTEbELWM9Tn792JKfLwT8.jpg'),
(155325, 11035, 'Forca de Mulher S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/422809.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gCBbqbIKOz8ssXBOXrLviH8hfni.jpg'),
(155326, 11035, 'Forca de Mulher S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/422810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155327, 11035, 'Forca de Mulher S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/422811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155328, 11035, 'Forca de Mulher S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/422812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155329, 11035, 'Forca de Mulher S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/422813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155330, 11035, 'Forca de Mulher S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/422814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155331, 11035, 'Forca de Mulher S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/422815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155332, 11035, 'Forca de Mulher S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/422816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(155333, 11035, 'Forca de Mulher S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/422817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155334, 11035, 'Forca de Mulher S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/422818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155335, 11035, 'Forca de Mulher S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/422819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155336, 11035, 'Forca de Mulher S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/422820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155337, 11035, 'Forca de Mulher S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/422821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155338, 11035, 'Forca de Mulher S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/422822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155339, 11035, 'Forca de Mulher S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/422823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155340, 11035, 'Forca de Mulher S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/422824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155341, 11035, 'Forca de Mulher S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/422825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155342, 11035, 'Forca de Mulher S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/422826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155343, 11035, 'Forca de Mulher S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/422827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155344, 11035, 'Forca de Mulher S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/422828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155345, 11035, 'Forca de Mulher S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/422829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155346, 11035, 'Forca de Mulher S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/422830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155347, 11035, 'Forca de Mulher S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/422831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155348, 11035, 'Forca de Mulher S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/422832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155349, 11035, 'Forca de Mulher S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/422833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155350, 11035, 'Forca de Mulher S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/422834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155351, 11035, 'Forca de Mulher S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/422835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155352, 11035, 'Forca de Mulher S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/422836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155353, 11035, 'Forca de Mulher S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/422837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155354, 11035, 'Forca de Mulher S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/422838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155355, 11035, 'Forca de Mulher S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/422839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155356, 11035, 'Forca de Mulher S03 E41', 'http://sinalprivado.info:80/series/1533784/1533784/422840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155357, 11035, 'Forca de Mulher S03 E42', 'http://sinalprivado.info:80/series/1533784/1533784/422841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155358, 11035, 'Forca de Mulher S03 E43', 'http://sinalprivado.info:80/series/1533784/1533784/422842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155359, 11035, 'Forca de Mulher S03 E44', 'http://sinalprivado.info:80/series/1533784/1533784/422843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155360, 11035, 'Forca de Mulher S03 E45', 'http://sinalprivado.info:80/series/1533784/1533784/422844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155361, 11035, 'Forca de Mulher S03 E46', 'http://sinalprivado.info:80/series/1533784/1533784/422845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155362, 11035, 'Forca de Mulher S03 E47', 'http://sinalprivado.info:80/series/1533784/1533784/422846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155363, 11035, 'Forca de Mulher S03 E48', 'http://sinalprivado.info:80/series/1533784/1533784/422847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155364, 11035, 'Forca de Mulher S03 E49', 'http://sinalprivado.info:80/series/1533784/1533784/422848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155365, 11035, 'Forca de Mulher S03 E50', 'http://sinalprivado.info:80/series/1533784/1533784/422849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wdd4O3gS2JAJHOZly9FjlwFN4EL.jpg'),
(155366, 11036, 'Guerra dos Tronos Uma Historia Real S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/422702.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kSsFObkHAw3WEdtloRc0gdw9PJT.jpg'),
(155367, 11036, 'Guerra dos Tronos Uma Historia Real S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/422703.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dCdKrv5fOyD7fVteJn0oRoKJk4h.jpg'),
(155368, 11036, 'Guerra dos Tronos Uma Historia Real S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/422704.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dgehEYOlHRbcp3rOonpQrLAm5DT.jpg'),
(155369, 11036, 'Guerra dos Tronos Uma Historia Real S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/434716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vYfbAUhpiQ56YyRB4zjAb5N2cAw.jpg'),
(155370, 11037, 'Guerra dos Tronos Uma Historia Real S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/460978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vYfbAUhpiQ56YyRB4zjAb5N2cAw.jpg'),
(155371, 11037, 'Guerra dos Tronos Uma Historia Real S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/460979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vYfbAUhpiQ56YyRB4zjAb5N2cAw.jpg'),
(155372, 11037, 'Guerra dos Tronos Uma Historia Real S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/460980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vYfbAUhpiQ56YyRB4zjAb5N2cAw.jpg'),
(155373, 11037, 'Guerra dos Tronos Uma Historia Real S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/460981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vYfbAUhpiQ56YyRB4zjAb5N2cAw.jpg'),
(155374, 11037, 'Guerra dos Tronos Uma Historia Real S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/460982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vYfbAUhpiQ56YyRB4zjAb5N2cAw.jpg'),
(155375, 11037, 'Guerra dos Tronos Uma Historia Real S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/460983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vYfbAUhpiQ56YyRB4zjAb5N2cAw.jpg'),
(155376, 11038, 'Medidas Radicais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/422693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9MmfNjs86Q7AEoJ3BWOoct3HDee.jpg'),
(155377, 11038, 'Medidas Radicais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/422694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9MmfNjs86Q7AEoJ3BWOoct3HDee.jpg'),
(155378, 11038, 'Medidas Radicais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/422695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9MmfNjs86Q7AEoJ3BWOoct3HDee.jpg'),
(155379, 11039, 'Medidas Radicais S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/422696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9MmfNjs86Q7AEoJ3BWOoct3HDee.jpg'),
(155380, 11039, 'Medidas Radicais S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/422697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9MmfNjs86Q7AEoJ3BWOoct3HDee.jpg'),
(155381, 11039, 'Medidas Radicais S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/422698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9MmfNjs86Q7AEoJ3BWOoct3HDee.jpg'),
(155382, 11039, 'Medidas Radicais S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/422699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9MmfNjs86Q7AEoJ3BWOoct3HDee.jpg'),
(155383, 11039, 'Medidas Radicais S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/422700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9MmfNjs86Q7AEoJ3BWOoct3HDee.jpg'),
(155384, 11039, 'Medidas Radicais S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/422701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9MmfNjs86Q7AEoJ3BWOoct3HDee.jpg'),
(155385, 11040, 'Missao Aviao S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/422683.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mZmGUo6GK2mdHsu8OoAsO4hy7L6.jpg'),
(155386, 11040, 'Missao Aviao S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/422684.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ixgvMq5ghhpaCPYMVfNyKkEmMZx.jpg'),
(155387, 11040, 'Missao Aviao S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/422685.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aSYyLmajuGgSON986cgQe81cdYK.jpg'),
(155388, 11040, 'Missao Aviao S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/422686.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n4bQ22lawLFauTlAuDBEkmaWp5b.jpg'),
(155389, 11040, 'Missao Aviao S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/422687.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4rrCnpypx71MmDSeepKHCRgJyLl.jpg'),
(155390, 11040, 'Missao Aviao S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/422688.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3l4SLJZLqdRhnfj0Y4gScV31DrL.jpg'),
(155391, 11040, 'Missao Aviao S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/422689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lxaPxPcaTHfR8AyvPXtWdPacgEE.jpg'),
(155392, 11040, 'Missao Aviao S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/422690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lxaPxPcaTHfR8AyvPXtWdPacgEE.jpg'),
(155393, 11040, 'Missao Aviao S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/422691.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/70qidqsUcXK0G6GJLGuHoPxqmAh.jpg'),
(155394, 11040, 'Missao Aviao S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/422692.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ykmkf364RNbgyJjRarOzuqPhYql.jpg'),
(155395, 11041, 'Momma Named Me Sheriff S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/422665.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kWzmYwhCsOTzOYiEjVsUTiydSfC.jpg'),
(155396, 11041, 'Momma Named Me Sheriff S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/422666.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kntsdpld9r8UJpFTlM2bVfK1oy0.jpg'),
(155397, 11041, 'Momma Named Me Sheriff S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/422667.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pksxdmyfKfHarlVkAPwNkuZLQej.jpg'),
(155398, 11041, 'Momma Named Me Sheriff S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/422668.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8xUcBQ8ZIFQ9RuRkYnaLIIfQoVZ.jpg'),
(155399, 11041, 'Momma Named Me Sheriff S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/422669.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pIGc6VRZPJAIHV1E7eqrivbJdoD.jpg'),
(155400, 11041, 'Momma Named Me Sheriff S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/422670.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qmmhCnShsiSyN8bdIZJsm48dJJE.jpg'),
(155401, 11041, 'Momma Named Me Sheriff S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/422671.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sUj5Bu16VtIwPc2YZP0bEarSw94.jpg'),
(155402, 11041, 'Momma Named Me Sheriff S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/422672.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7TVsfYPg13eW6bFtxazaU3q4Xgw.jpg'),
(155403, 11041, 'Momma Named Me Sheriff S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/422673.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r6CNQmFpCuCYhJNXUVMnYyTTXFL.jpg'),
(155404, 11042, 'Momma Named Me Sheriff S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/422674.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i6gKTPhQ5q84KsUoYd6ned4vtK0.jpg'),
(155405, 11042, 'Momma Named Me Sheriff S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/422675.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qK3NdTMRgzxKz5yVRC7RdK2KrPj.jpg'),
(155406, 11042, 'Momma Named Me Sheriff S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/422676.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ds2JKsZ1c1YSADd6epBB6WsPDLg.jpg'),
(155407, 11042, 'Momma Named Me Sheriff S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/422677.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uRtB3BopD8lRgtI6wlalMkUt6u0.jpg'),
(155408, 11042, 'Momma Named Me Sheriff S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/422678.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i0P1Yh6LQHwDT4GF6p8CDMwPAqK.jpg'),
(155409, 11042, 'Momma Named Me Sheriff S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/422679.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A6IiP0MmjQEE41mpcyDud950EiT.jpg'),
(155410, 11042, 'Momma Named Me Sheriff S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/422680.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ecXNgcq3m4b2sSCzFJU9XnBi7tk.jpg'),
(155411, 11042, 'Momma Named Me Sheriff S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/422681.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eGGqx1p9HG55wiwCCfKFTiKNgDy.jpg'),
(155412, 11042, 'Momma Named Me Sheriff S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/422682.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mbLyPwfs6MivGVRC5DUoFT20NhZ.jpg'),
(155413, 11043, 'Os Quebradores da Banca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/422664.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qbd7Iazd7csFwDC9ZA7EkNZxtFS.jpg'),
(155414, 11043, 'Os Quebradores da Banca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/430959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v6ElHlBnmwE7PBD5nZtQUaxEcXr.jpg'),
(155415, 11043, 'Os Quebradores da Banca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/433265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v6ElHlBnmwE7PBD5nZtQUaxEcXr.jpg'),
(155416, 11043, 'Os Quebradores da Banca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v6ElHlBnmwE7PBD5nZtQUaxEcXr.jpg'),
(155417, 11043, 'Os Quebradores da Banca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v6ElHlBnmwE7PBD5nZtQUaxEcXr.jpg'),
(155418, 11043, 'Os Quebradores da Banca S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v6ElHlBnmwE7PBD5nZtQUaxEcXr.jpg'),
(155419, 11044, 'Refens S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/422652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6S63gRYcjkzwCHy2Tb6hXOmw8vU.jpg'),
(155420, 11044, 'Refens S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/422653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6S63gRYcjkzwCHy2Tb6hXOmw8vU.jpg'),
(155421, 11044, 'Refens S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/422654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6S63gRYcjkzwCHy2Tb6hXOmw8vU.jpg'),
(155422, 11044, 'Refens S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/422655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6S63gRYcjkzwCHy2Tb6hXOmw8vU.jpg'),
(155423, 11044, 'Refens S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/422656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6S63gRYcjkzwCHy2Tb6hXOmw8vU.jpg'),
(155424, 11044, 'Refens S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/422657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6S63gRYcjkzwCHy2Tb6hXOmw8vU.jpg'),
(155425, 11044, 'Refens S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/422658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6S63gRYcjkzwCHy2Tb6hXOmw8vU.jpg'),
(155426, 11044, 'Refens S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/422659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6S63gRYcjkzwCHy2Tb6hXOmw8vU.jpg'),
(155427, 11044, 'Refens S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/422660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6S63gRYcjkzwCHy2Tb6hXOmw8vU.jpg'),
(155428, 11044, 'Refens S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/422661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6S63gRYcjkzwCHy2Tb6hXOmw8vU.jpg'),
(155429, 11044, 'Refens S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/422662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6S63gRYcjkzwCHy2Tb6hXOmw8vU.jpg'),
(155430, 11044, 'Refens S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/422663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6S63gRYcjkzwCHy2Tb6hXOmw8vU.jpg'),
(155431, 11045, 'A Batalha dos Chefs Raiz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/426268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xzSLJB0FWBKevAr7UtO4Fw2KVoE.jpg'),
(155432, 11045, 'A Batalha dos Chefs Raiz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/426269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xzSLJB0FWBKevAr7UtO4Fw2KVoE.jpg'),
(155433, 11045, 'A Batalha dos Chefs Raiz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/426270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xzSLJB0FWBKevAr7UtO4Fw2KVoE.jpg'),
(155434, 11045, 'A Batalha dos Chefs Raiz S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/426271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xzSLJB0FWBKevAr7UtO4Fw2KVoE.jpg'),
(155435, 11045, 'A Batalha dos Chefs Raiz S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/426272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xzSLJB0FWBKevAr7UtO4Fw2KVoE.jpg'),
(155436, 11045, 'A Batalha dos Chefs Raiz S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/426273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xzSLJB0FWBKevAr7UtO4Fw2KVoE.jpg'),
(155437, 11045, 'A Batalha dos Chefs Raiz S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/426274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xzSLJB0FWBKevAr7UtO4Fw2KVoE.jpg'),
(155438, 11045, 'A Batalha dos Chefs Raiz S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/426275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xzSLJB0FWBKevAr7UtO4Fw2KVoE.jpg'),
(155439, 11046, 'Guerra Entre Vizinhos S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/426264.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kbsLpgNS2EQmOOjZRmySbe9bPsI.jpg'),
(155440, 11046, 'Guerra Entre Vizinhos S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/426265.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/59QvrQBNXS325IS1XfZPHfBByG0.jpg'),
(155441, 11046, 'Guerra Entre Vizinhos S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/426266.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d0kMO9B5lK02Le26LwentH4kN0F.jpg'),
(155442, 11046, 'Guerra Entre Vizinhos S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/426267.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sm6nUyguLQJSzfgVdAXETM1fmsR.jpg'),
(155443, 11046, 'Guerra Entre Vizinhos S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/434721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckUayMifXsH2XSEX0Ed2Dh2gfKK.jpg'),
(155444, 11046, 'Guerra Entre Vizinhos S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/434722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckUayMifXsH2XSEX0Ed2Dh2gfKK.jpg'),
(155445, 11046, 'Guerra Entre Vizinhos S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/436775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckUayMifXsH2XSEX0Ed2Dh2gfKK.jpg'),
(155446, 11046, 'Guerra Entre Vizinhos S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/436776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckUayMifXsH2XSEX0Ed2Dh2gfKK.jpg'),
(155447, 11046, 'Guerra Entre Vizinhos S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/447835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckUayMifXsH2XSEX0Ed2Dh2gfKK.jpg'),
(155448, 11046, 'Guerra Entre Vizinhos S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/447836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckUayMifXsH2XSEX0Ed2Dh2gfKK.jpg'),
(155449, 11046, 'Guerra Entre Vizinhos S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/456125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckUayMifXsH2XSEX0Ed2Dh2gfKK.jpg'),
(155450, 11046, 'Guerra Entre Vizinhos S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/456126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckUayMifXsH2XSEX0Ed2Dh2gfKK.jpg'),
(155451, 11046, 'Guerra Entre Vizinhos S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/456127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckUayMifXsH2XSEX0Ed2Dh2gfKK.jpg'),
(155452, 11046, 'Guerra Entre Vizinhos S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/456128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckUayMifXsH2XSEX0Ed2Dh2gfKK.jpg'),
(155453, 11046, 'Guerra Entre Vizinhos S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/467439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckUayMifXsH2XSEX0Ed2Dh2gfKK.jpg'),
(155454, 11046, 'Guerra Entre Vizinhos S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/467440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckUayMifXsH2XSEX0Ed2Dh2gfKK.jpg'),
(155455, 11046, 'Guerra Entre Vizinhos S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/467441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckUayMifXsH2XSEX0Ed2Dh2gfKK.jpg'),
(155456, 11046, 'Guerra Entre Vizinhos S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/467442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckUayMifXsH2XSEX0Ed2Dh2gfKK.jpg'),
(155457, 11046, 'Guerra Entre Vizinhos S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/474237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckUayMifXsH2XSEX0Ed2Dh2gfKK.jpg'),
(155458, 11046, 'Guerra Entre Vizinhos S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/474238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckUayMifXsH2XSEX0Ed2Dh2gfKK.jpg'),
(155459, 11046, 'Guerra Entre Vizinhos S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/478048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckUayMifXsH2XSEX0Ed2Dh2gfKK.jpg'),
(155460, 11046, 'Guerra Entre Vizinhos S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/478049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ckUayMifXsH2XSEX0Ed2Dh2gfKK.jpg'),
(155461, 11047, 'Minha Amiga Nokotan e um Cervo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/426258.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jkgh5teSvw3k3ewIerc4LiW0nMe.jpg'),
(155462, 11047, 'Minha Amiga Nokotan e um Cervo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/426259.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fLbhLLOVhdaRFpsrkjquzRo4agn.jpg'),
(155463, 11047, 'Minha Amiga Nokotan e um Cervo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/426260.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8vWBb8GG8PprchAd3Q6HvmXDdqG.jpg'),
(155464, 11047, 'Minha Amiga Nokotan e um Cervo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/426261.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xh6vEEr87dWpOyEXtmlxR1CFuyb.jpg'),
(155465, 11047, 'Minha Amiga Nokotan e um Cervo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/426262.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m4ssW0RP1aTzSoYl92MP8xcy18S.jpg'),
(155466, 11047, 'Minha Amiga Nokotan e um Cervo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/426263.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hduM95AAoXuU56sQPD6CAPgjTCl.jpg'),
(155467, 11047, 'Minha Amiga Nokotan e um Cervo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/434517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cR3KTBZPRhTfzbrRRmnmZR8wx81.jpg'),
(155468, 11047, 'Minha Amiga Nokotan e um Cervo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/436102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cR3KTBZPRhTfzbrRRmnmZR8wx81.jpg'),
(155469, 11047, 'Minha Amiga Nokotan e um Cervo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/441896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cR3KTBZPRhTfzbrRRmnmZR8wx81.jpg'),
(155470, 11047, 'Minha Amiga Nokotan e um Cervo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/447366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cR3KTBZPRhTfzbrRRmnmZR8wx81.jpg'),
(155471, 11047, 'Minha Amiga Nokotan e um Cervo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/452336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cR3KTBZPRhTfzbrRRmnmZR8wx81.jpg'),
(155472, 11047, 'Minha Amiga Nokotan e um Cervo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/460828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cR3KTBZPRhTfzbrRRmnmZR8wx81.jpg'),
(155473, 11048, 'O Misterioso Mundo dos Sons com David Attenborough S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/426255.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fpXiaeOBEbNdnG2UZLk3AljsUwb.jpg'),
(155474, 11048, 'O Misterioso Mundo dos Sons com David Attenborough S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/426256.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mUI7ieHU65f4T3w228Rs3L7jgIt.jpg'),
(155475, 11048, 'O Misterioso Mundo dos Sons com David Attenborough S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/426257.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/71o0D7vgNGxQgkuDBKuCmjwRK8x.jpg'),
(155476, 11049, 'O Pais de Tanabata S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/426245.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xxa96OjURpixB4taQGTEVt1MBf5.jpg'),
(155477, 11049, 'O Pais de Tanabata S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/426246.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/71oCsHyBqoGyaK1g4PV1l5Rhq0i.jpg'),
(155478, 11049, 'O Pais de Tanabata S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/426247.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9hnklrAwckh29JpZcXMEKLnqKl8.jpg'),
(155479, 11049, 'O Pais de Tanabata S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/426248.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1lj0ZJN3rDVJxDQM8zJmvfOx6Ap.jpg'),
(155480, 11049, 'O Pais de Tanabata S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/426249.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dnXIxF3cdu2vn1Mmj6JbBj2XnGE.jpg'),
(155481, 11049, 'O Pais de Tanabata S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/426250.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h6nMYCUpedkVhLi32SZrliu0SWT.jpg'),
(155482, 11049, 'O Pais de Tanabata S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/426251.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eCoPpoVQtJSSequCTYqpq2lNp9h.jpg'),
(155483, 11049, 'O Pais de Tanabata S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/426252.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A0RLl7G5Fs7E6maMln385inEZDk.jpg'),
(155484, 11049, 'O Pais de Tanabata S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/426253.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vSycgonJ2DG3kVLp23uNzKmL9yG.jpg'),
(155485, 11049, 'O Pais de Tanabata S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/426254.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/80E1GpKkmzJeQWQHJCg3zqwm4Bb.jpg'),
(155486, 11050, 'Os Aspones S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/426238.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t1AnJBwyqGE2GcqZf4EzqqNT5sm.jpg'),
(155487, 11050, 'Os Aspones S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/426239.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jpsLkeIR2FLrFHH8ZHMuo5CKr9Q.jpg'),
(155488, 11050, 'Os Aspones S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/426240.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cPnAZCFtQ6EkY27LRTVJqLXZs9s.jpg'),
(155489, 11050, 'Os Aspones S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/426241.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aWONaNJggnLmib3BHVOUmMWiIUI.jpg'),
(155490, 11050, 'Os Aspones S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/426242.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gBA9ugKU7UEgn9VjcIbOmXTOulA.jpg'),
(155491, 11050, 'Os Aspones S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/426243.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xEmnblU5PhwEsix1WWwpJd74AAe.jpg'),
(155492, 11050, 'Os Aspones S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/426244.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zshIjJ0EKw1PfncVXvhYQ4rAH0K.jpg'),
(155493, 11051, 'Sket Dance S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/426183.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aGGadV1UvxJhrD1lXz5oDFrUSCY.jpg'),
(155494, 11051, 'Sket Dance S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/426184.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dKk8MUMSHucLSX3YrrnDyrjqL8x.jpg'),
(155495, 11051, 'Sket Dance S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/426185.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z3Ho2zAGIsQdqp1EjHUzQmU7rI.jpg'),
(155496, 11051, 'Sket Dance S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/426186.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qa6Qeu1azpmUrwhIMt6iNWN49RM.jpg'),
(155497, 11051, 'Sket Dance S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/426187.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dUJInwy8iSh1g1bwxLivce3lnoZ.jpg'),
(155498, 11051, 'Sket Dance S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/426188.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gEfxKgP8HBQyL1jpkjs2Vif2zH4.jpg'),
(155499, 11051, 'Sket Dance S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/426189.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6QUZh7vUMByMeQytRNQIkyM9SuR.jpg'),
(155500, 11051, 'Sket Dance S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/426190.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oZg09wDL6VRFYVciRngbkDOCbzn.jpg'),
(155501, 11051, 'Sket Dance S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/426191.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/igJZJGOJBtashwTJDzSlpbioXAW.jpg'),
(155502, 11051, 'Sket Dance S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/426192.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yREk0eVvOt4sqgCzC3cOKW0lk4H.jpg'),
(155503, 11051, 'Sket Dance S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/426193.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d1HZjBU5Tf4zLADSs5p03UneA4V.jpg'),
(155504, 11051, 'Sket Dance S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/426194.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/265gWOiS6Cdk09hGHl1YfaMDEdL.jpg'),
(155505, 11051, 'Sket Dance S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/426195.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xdmPsiszMD2bnpEvNiQffGPxJqO.jpg'),
(155506, 11051, 'Sket Dance S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/426196.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tJUGjrEWS6FjaDETR7HHBP44wCt.jpg'),
(155507, 11051, 'Sket Dance S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/426197.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6ZEJWIWNJsqpDZdeQvqI3NTZm4X.jpg'),
(155508, 11051, 'Sket Dance S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/426198.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bFgrdvWIa6zOzn3jGuH6BFLTv48.jpg'),
(155509, 11051, 'Sket Dance S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/426199.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yxj6lCTgGxKPDp5aT8QzKLaiTr8.jpg'),
(155510, 11051, 'Sket Dance S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/426200.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gGBmV4VGcrgGVioaVQjjbGhjtxV.jpg'),
(155511, 11051, 'Sket Dance S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/426201.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wEFitdc0jX3Iz3Ly9CX5UHpmKlf.jpg'),
(155512, 11051, 'Sket Dance S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/426202.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aZxOx0NLa9qHCWTP6qG5Nlq9ckO.jpg'),
(155513, 11051, 'Sket Dance S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/426203.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r3Vp9iyoWut6QX9KTacHWA0VHrw.jpg'),
(155514, 11051, 'Sket Dance S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/426204.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/alQknKJOVBrf6DuacpBgtXEuztk.jpg'),
(155515, 11051, 'Sket Dance S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/426205.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nmiMidpYY5iZ3LU2jvQIdQ7pbMj.jpg'),
(155516, 11051, 'Sket Dance S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/426206.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mRvRYnEmO1Hp8Sy66WFXMMlHoaC.jpg'),
(155517, 11051, 'Sket Dance S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/426207.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/75hI3Fax2ACsZm6QgNDIBqJspI5.jpg'),
(155518, 11051, 'Sket Dance S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/426208.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tVZQBlxSkOXeG4eB45KqNSUqTJH.jpg'),
(155519, 11051, 'Sket Dance S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/426209.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3XGjKfiCNYrDOYiGUjqnfLVLzOC.jpg'),
(155520, 11051, 'Sket Dance S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/426210.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xTTDuSbFjFV0l3pqtEs1d5rNmnz.jpg'),
(155521, 11051, 'Sket Dance S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/426211.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vw2V78mkxyd8iSqsi8bDQgvVq9.jpg'),
(155522, 11051, 'Sket Dance S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/426212.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v3jpnnf7b7oIlJDD18lV3krh7tm.jpg'),
(155523, 11051, 'Sket Dance S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/426213.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/58HHpLA3033kn0oaZ3gzFbBF1qK.jpg'),
(155524, 11051, 'Sket Dance S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/426214.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dz2YisQt5KUXl54n8AjJAaCUHrg.jpg'),
(155525, 11051, 'Sket Dance S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/426215.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AfV1mp2PtsxGlMFk7it7CgbaXkb.jpg'),
(155526, 11051, 'Sket Dance S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/426216.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cGdE83UW2vxiAXxYZqVS1NyyA1O.jpg'),
(155527, 11051, 'Sket Dance S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/426217.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3oOa2ei7biBrJ4V0RNsl9LFwkZ.jpg'),
(155528, 11051, 'Sket Dance S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/426218.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ezFXSoF8qCXoXsXjOMX46ViBHod.jpg'),
(155529, 11051, 'Sket Dance S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/426219.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uYeFdc4BexxjlQHVn7Few5vvtBm.jpg'),
(155530, 11051, 'Sket Dance S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/426220.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7Z1imuoBEt2vYZ7QswI3vKIsXVU.jpg'),
(155531, 11051, 'Sket Dance S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/426221.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b7Xzhv46BxvWuDRJc1yWbpTcQ1b.jpg'),
(155532, 11051, 'Sket Dance S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/426222.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8dKsQzBwM8ubJnbyLaMvjKZDzef.jpg'),
(155533, 11051, 'Sket Dance S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/426223.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kumwTaXGryhn9MSqOh9VHuQha8k.jpg'),
(155534, 11051, 'Sket Dance S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/426224.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3DZFvPFY7jY3ia7nsuxH8XtY5wB.jpg'),
(155535, 11051, 'Sket Dance S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/426225.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uaQE4f7XUrI7bmcdkKDEmKijNVc.jpg'),
(155536, 11051, 'Sket Dance S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/426226.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9TX6EGH95UJhsLvBWPsdTl9eGKc.jpg'),
(155537, 11051, 'Sket Dance S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/426227.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/41ZfGpLgk3PFHmXxZf0IOR9mtYb.jpg'),
(155538, 11051, 'Sket Dance S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/426228.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ttqqXKvBZS7jM2GzixIeDk96272.jpg'),
(155539, 11051, 'Sket Dance S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/426229.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iIMBe5wkVeuIoCfDG5XiguOVHrk.jpg'),
(155540, 11051, 'Sket Dance S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/426230.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wZ2WowF9NUnlvS5mQ1wgNJo1Xlm.jpg'),
(155541, 11051, 'Sket Dance S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/426231.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zxjfcAu6uMy8RMnUzubNen3KQJI.jpg'),
(155542, 11051, 'Sket Dance S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/426232.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3klLy0lhcliprDZ3FZjMeT1Kg4B.jpg'),
(155543, 11051, 'Sket Dance S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/426233.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tntxvRAGyRI35JC8zGxDbhpqgIH.jpg'),
(155544, 11051, 'Sket Dance S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/426234.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k5y0zUkkJPKiahtqf9TDaX0kesi.jpg'),
(155545, 11051, 'Sket Dance S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/426235.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i2HAx5eCxjWTMbxVDmO0Yj572K7.jpg'),
(155546, 11051, 'Sket Dance S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/426236.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n7aXLVJPdhwJQFmVqNXYdFEQQVA.jpg'),
(155547, 11051, 'Sket Dance S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/426237.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AnQzKKlJs5pQh7Mf4FHklXgj4sQ.jpg'),
(155548, 11051, 'Sket Dance S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/438743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155549, 11051, 'Sket Dance S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/438744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155550, 11051, 'Sket Dance S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/438745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155551, 11051, 'Sket Dance S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/438746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155552, 11051, 'Sket Dance S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/438747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155553, 11051, 'Sket Dance S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/438748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155554, 11051, 'Sket Dance S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/438749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155555, 11051, 'Sket Dance S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/438751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155556, 11051, 'Sket Dance S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/438752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155557, 11051, 'Sket Dance S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/438753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155558, 11051, 'Sket Dance S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/438754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155559, 11051, 'Sket Dance S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/438755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155560, 11051, 'Sket Dance S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/438756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155561, 11051, 'Sket Dance S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/438757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155562, 11051, 'Sket Dance S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/438758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155563, 11051, 'Sket Dance S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/438759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155564, 11051, 'Sket Dance S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/438760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155565, 11051, 'Sket Dance S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/438761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155566, 11051, 'Sket Dance S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/438762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155567, 11051, 'Sket Dance S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/438763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155568, 11051, 'Sket Dance S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/438764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155569, 11051, 'Sket Dance S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/438765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wYMBMX3s6X3aCTifAIrLRxR5A3f.jpg'),
(155570, 11052, 'Tartarugas Ninjas Historias Mutantes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/426177.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7TzNzkeXQYjfzpdynguII78qBlP.jpg'),
(155571, 11052, 'Tartarugas Ninjas Historias Mutantes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/426178.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wizaG1KSJm6ZnJziusdMUXpyBeQ.jpg'),
(155572, 11052, 'Tartarugas Ninjas Historias Mutantes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/426179.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oxMB90F0QuxpKTkEjfs5cDDW1Iz.jpg'),
(155573, 11052, 'Tartarugas Ninjas Historias Mutantes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/426180.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d5gjmWNHaRuRkVZcQ22Oz1eap18.jpg'),
(155574, 11052, 'Tartarugas Ninjas Historias Mutantes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/426181.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hBX7raJOvwOw1qIZZYSUI8NtGvV.jpg'),
(155575, 11052, 'Tartarugas Ninjas Historias Mutantes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/426182.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s1lg0USQu7fJfTcamKRO9vK8kh9.jpg'),
(155576, 11052, 'Tartarugas Ninjas Historias Mutantes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o0ZlpvK0Ewd3iJYUyYPfwAAeR88.jpg'),
(155577, 11052, 'Tartarugas Ninjas Historias Mutantes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o0ZlpvK0Ewd3iJYUyYPfwAAeR88.jpg'),
(155578, 11052, 'Tartarugas Ninjas Historias Mutantes S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o0ZlpvK0Ewd3iJYUyYPfwAAeR88.jpg'),
(155579, 11052, 'Tartarugas Ninjas Historias Mutantes S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o0ZlpvK0Ewd3iJYUyYPfwAAeR88.jpg'),
(155580, 11052, 'Tartarugas Ninjas Historias Mutantes S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o0ZlpvK0Ewd3iJYUyYPfwAAeR88.jpg'),
(155581, 11052, 'Tartarugas Ninjas Historias Mutantes S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/502941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o0ZlpvK0Ewd3iJYUyYPfwAAeR88.jpg'),
(155582, 11053, 'Tartarugas Ninjas Historias Mutantes S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/895839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o0ZlpvK0Ewd3iJYUyYPfwAAeR88.jpg'),
(155583, 11053, 'Tartarugas Ninjas Historias Mutantes S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/895840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o0ZlpvK0Ewd3iJYUyYPfwAAeR88.jpg'),
(155584, 11053, 'Tartarugas Ninjas Historias Mutantes S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/895841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o0ZlpvK0Ewd3iJYUyYPfwAAeR88.jpg'),
(155585, 11053, 'Tartarugas Ninjas Historias Mutantes S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/895842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o0ZlpvK0Ewd3iJYUyYPfwAAeR88.jpg'),
(155586, 11053, 'Tartarugas Ninjas Historias Mutantes S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/895843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o0ZlpvK0Ewd3iJYUyYPfwAAeR88.jpg'),
(155587, 11053, 'Tartarugas Ninjas Historias Mutantes S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/895844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o0ZlpvK0Ewd3iJYUyYPfwAAeR88.jpg'),
(155588, 11053, 'Tartarugas Ninjas Historias Mutantes S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/895845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o0ZlpvK0Ewd3iJYUyYPfwAAeR88.jpg'),
(155589, 11053, 'Tartarugas Ninjas Historias Mutantes S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/895846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o0ZlpvK0Ewd3iJYUyYPfwAAeR88.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(155590, 11053, 'Tartarugas Ninjas Historias Mutantes S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/895847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o0ZlpvK0Ewd3iJYUyYPfwAAeR88.jpg'),
(155591, 11053, 'Tartarugas Ninjas Historias Mutantes S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/895848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o0ZlpvK0Ewd3iJYUyYPfwAAeR88.jpg'),
(155592, 11053, 'Tartarugas Ninjas Historias Mutantes S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/895849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o0ZlpvK0Ewd3iJYUyYPfwAAeR88.jpg'),
(155593, 11053, 'Tartarugas Ninjas Historias Mutantes S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/895850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o0ZlpvK0Ewd3iJYUyYPfwAAeR88.jpg'),
(155594, 11054, 'Ted A Serie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/613406.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xmBACM8eaKLEMWD1wlDExKHsTJP.jpg'),
(155595, 11054, 'Ted A Serie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/613407.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4Y6aMmHHgM3x1vR7ILBcSUQV8Qk.jpg'),
(155596, 11054, 'Ted A Serie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/613408.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/67bSLKTjX098IecOeQCRo8qIAC2.jpg'),
(155597, 11054, 'Ted A Serie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/613409.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sxPImbleKLJVTMZLi9HcmiBfbb3.jpg'),
(155598, 11054, 'Ted A Serie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/613410.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yM5KTUHICfT3JSU1PkDi00cWx8l.jpg'),
(155599, 11054, 'Ted A Serie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/613411.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/46WncJekJcxpd7z7zUhgFro3VCC.jpg'),
(155600, 11054, 'Ted A Serie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/613412.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/LApNVub2MDov5SlkBW9mOfd6W2.jpg'),
(155601, 11054, 'Ted A Serie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/613413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iGanbz4wM5EyDpSZ0FK3TEsInEb.jpg'),
(155602, 11055, 'Fire Force S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/426121.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2OWHHF5wGZ7cU1VlqDc4L2nwhng.jpg'),
(155603, 11055, 'Fire Force S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/426122.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o0Y2Ln91IMj3uUIM1hJj6eqcHWQ.jpg'),
(155604, 11055, 'Fire Force S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/426123.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6aiFNvCcv5593e4a6CVsN1VvJv7.jpg'),
(155605, 11055, 'Fire Force S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/426124.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cHIyHmCOUaEl3W8bLqIjXZ5J7sk.jpg'),
(155606, 11055, 'Fire Force S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/426125.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5MXiQW13qR4SMLUKMupDGIVX2KR.jpg'),
(155607, 11055, 'Fire Force S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/426126.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ykWfYxu1VGROLptPqOim49yjI8r.jpg'),
(155608, 11055, 'Fire Force S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/426127.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/124ZSqCAPZnrBW35brkVuK0DURQ.jpg'),
(155609, 11055, 'Fire Force S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/426128.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nrrPvzxEwN75T3s0TF5UMzB4xQn.jpg'),
(155610, 11055, 'Fire Force S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/426129.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eWLGY5LrVFKPKs5go4mrwvfjKEy.jpg'),
(155611, 11055, 'Fire Force S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/426130.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9srqqZAzMW7S6snGGr5yDkl0VFy.jpg'),
(155612, 11055, 'Fire Force S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/426131.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4kErkTtZZaMvnJDi0be3EVyZEee.jpg'),
(155613, 11055, 'Fire Force S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/426132.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/biVy4na1k6lS1uZKRZSanai5v6J.jpg'),
(155614, 11055, 'Fire Force S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/426133.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qnbZ77nAPD2nl9sVfIhutZlWr2j.jpg'),
(155615, 11055, 'Fire Force S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/426134.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/duudBJkS71aRder9CUMykMYTxbb.jpg'),
(155616, 11055, 'Fire Force S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/426135.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l0LrgVnbrFh9fWeaq7C5vgqil6K.jpg'),
(155617, 11055, 'Fire Force S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/426136.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fBXakIvdE0UZkeMG3fk2ZD1II9F.jpg'),
(155618, 11055, 'Fire Force S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/426137.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oYMOoCjLQ5nhQTUxOhjH7MuRdVx.jpg'),
(155619, 11055, 'Fire Force S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/426138.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hPShwKq5tm8r4VnohuGanYkpXyy.jpg'),
(155620, 11055, 'Fire Force S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/426139.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uEMHxCagxXalMrKOXqzjQ9NDWbq.jpg'),
(155621, 11055, 'Fire Force S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/426140.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p7YIyNsv4KhYR3OhvtwGViu2rge.jpg'),
(155622, 11055, 'Fire Force S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/426141.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wJ9Z8v6s6liuEYtOpDzsgslaS1X.jpg'),
(155623, 11055, 'Fire Force S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/426142.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AcjSO3Ky8aEXlyJO3DD6rWYbypM.jpg'),
(155624, 11055, 'Fire Force S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/426143.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4BdI9SH6LYCO98ck7ICVXLX5VJB.jpg'),
(155625, 11055, 'Fire Force S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/426144.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9KatPe3wyu7us8bAswBbf9doHXy.jpg'),
(155626, 11056, 'Fire Force S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/426145.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jo8K4aBvvOSdrAvpt5OjgULAZyB.jpg'),
(155627, 11056, 'Fire Force S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/426146.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tD0VFFGtTv24UNdCubHYkrsK4Fb.jpg'),
(155628, 11056, 'Fire Force S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/426147.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fx5qAyWuoIdKBZzdvMX35z5rvdV.jpg'),
(155629, 11056, 'Fire Force S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/426148.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tak2EEsBi6unbA8JhfYLC3dkj4k.jpg'),
(155630, 11056, 'Fire Force S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/426149.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bGaxO6pEanGmIfGMgTgv4AGNUCh.jpg'),
(155631, 11056, 'Fire Force S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/426150.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AmzdHcr98pwN3lnBUKwmFaKqE01.jpg'),
(155632, 11056, 'Fire Force S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/426151.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wqxSI5bd1Erer8D5xS896NoQnPG.jpg'),
(155633, 11056, 'Fire Force S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/426152.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xO0YMWOsHSXj5zDzeYlreWd4JtR.jpg'),
(155634, 11056, 'Fire Force S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/426153.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2kO7UREcg9JnEtsRcrG1d4kVNcz.jpg'),
(155635, 11056, 'Fire Force S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/426154.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pn1x9BNZ35cYgIvHjRGWp7flEm0.jpg'),
(155636, 11056, 'Fire Force S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/426155.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bQUVobVTVvwbvg2rD2lKNLOfm9V.jpg'),
(155637, 11056, 'Fire Force S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/426156.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8kUoM0NQROdtN8O0ZRfcZqmV0x8.jpg'),
(155638, 11056, 'Fire Force S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/426157.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5eE7hRXclt4Owjy5mt2oG8oM2oU.jpg'),
(155639, 11056, 'Fire Force S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/426158.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sgz1440zN1OsWeknO9QCxXolDEx.jpg'),
(155640, 11056, 'Fire Force S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/426159.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jV4YfFN7YHkwnkAyYc0FkWFx4NB.jpg'),
(155641, 11056, 'Fire Force S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/426160.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l1gLwxc3Vkr1KI4dqQuuZcd97nh.jpg'),
(155642, 11056, 'Fire Force S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/426161.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gTXRPeyhozpt4tRjewdpmhsWwd3.jpg'),
(155643, 11056, 'Fire Force S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/426162.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ark0siMtX7c4IDSQcfkHNOErirI.jpg'),
(155644, 11056, 'Fire Force S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/426163.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vnOZSQSvHUEQ594j7a87y6zfKGw.jpg'),
(155645, 11056, 'Fire Force S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/426164.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lM4ChRhala9LEawz9ZQP8pXaBB6.jpg'),
(155646, 11056, 'Fire Force S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/426165.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9CcZxholODXneBPhNrMHQcTTdhA.jpg'),
(155647, 11056, 'Fire Force S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/426166.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jQps7RD3DjW1L4KJNVFO3n69GUO.jpg'),
(155648, 11056, 'Fire Force S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/426167.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qV0fVa0npeuRYo7pNQI874oT2P3.jpg'),
(155649, 11056, 'Fire Force S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/426168.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ijqDQU0RiuaIHWEmZySWhbSDbow.jpg'),
(155650, 11057, 'Fire Force S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/868284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qDNgM4STqdzl4IBMyqCVMIr6uUV.jpg'),
(155651, 11057, 'Fire Force S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/868285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qDNgM4STqdzl4IBMyqCVMIr6uUV.jpg'),
(155652, 11057, 'Fire Force S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/868286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qDNgM4STqdzl4IBMyqCVMIr6uUV.jpg'),
(155653, 11057, 'Fire Force S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/868287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qDNgM4STqdzl4IBMyqCVMIr6uUV.jpg'),
(155654, 11057, 'Fire Force S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/868288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qDNgM4STqdzl4IBMyqCVMIr6uUV.jpg'),
(155655, 11057, 'Fire Force S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/868289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qDNgM4STqdzl4IBMyqCVMIr6uUV.jpg'),
(155656, 11057, 'Fire Force S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/868290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qDNgM4STqdzl4IBMyqCVMIr6uUV.jpg'),
(155657, 11057, 'Fire Force S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/868291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qDNgM4STqdzl4IBMyqCVMIr6uUV.jpg'),
(155658, 11057, 'Fire Force S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/868292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qDNgM4STqdzl4IBMyqCVMIr6uUV.jpg'),
(155659, 11057, 'Fire Force S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/868293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qDNgM4STqdzl4IBMyqCVMIr6uUV.jpg'),
(155660, 11057, 'Fire Force S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/868294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qDNgM4STqdzl4IBMyqCVMIr6uUV.jpg'),
(155661, 11057, 'Fire Force S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/868295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qDNgM4STqdzl4IBMyqCVMIr6uUV.jpg'),
(155662, 11058, 'Do Velho ao Novo O Hotel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/432795.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r5bt5eQEcWwhZSoHpNpmyTeBXhK.jpg'),
(155663, 11058, 'Do Velho ao Novo O Hotel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/432796.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sWTyILIduuYR7sSWQzxECXrSNcU.jpg'),
(155664, 11058, 'Do Velho ao Novo O Hotel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/432797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5hWnPjpbjM7S86T4fBT3in29vzO.jpg'),
(155665, 11058, 'Do Velho ao Novo O Hotel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/432798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5hWnPjpbjM7S86T4fBT3in29vzO.jpg'),
(155666, 11058, 'Do Velho ao Novo O Hotel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/432799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5hWnPjpbjM7S86T4fBT3in29vzO.jpg'),
(155667, 11058, 'Do Velho ao Novo O Hotel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/432800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5hWnPjpbjM7S86T4fBT3in29vzO.jpg'),
(155668, 11059, 'The Traitors S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/432784.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/juxmA709AN4Gfx1W55x2Cg4Sofc.jpg'),
(155669, 11059, 'The Traitors S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/432785.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/krTLf0UfQo1JLTH5prl2tP8b4kw.jpg'),
(155670, 11059, 'The Traitors S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/432786.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nkochYlS8E5Miqruv29SX18X77A.jpg'),
(155671, 11059, 'The Traitors S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/432787.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5cE0EpNfQVQbY99IZ53qcp1mFHZ.jpg'),
(155672, 11059, 'The Traitors S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/432788.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lVCWKWvRHpWLKmBoIc7yvx5941A.jpg'),
(155673, 11059, 'The Traitors S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/432789.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zSUPqCr4VuBlVVjZs0632S3WuBv.jpg'),
(155674, 11059, 'The Traitors S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/631041.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aKiNLS9b6RIfNvCXzw6BU0N5TwR.jpg'),
(155675, 11059, 'The Traitors S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/432791.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9qX3NFjQuRXideOb0wbgi40SHmD.jpg'),
(155676, 11059, 'The Traitors S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/432792.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8I0ZjaGiOoW9cMpfJ9KoT23AkQy.jpg'),
(155677, 11059, 'The Traitors S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/432793.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gMNEUI3jOTPcsRD8LiwcNqr0a6y.jpg'),
(155678, 11059, 'The Traitors S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/631045.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/693std5N1eDY8RY6q2bNXFNotlR.jpg'),
(155679, 11060, 'The Traitors S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/516972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hECtcvv1QXK4MTyE3TYmW9TELVt.jpg'),
(155680, 11060, 'The Traitors S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/516973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hECtcvv1QXK4MTyE3TYmW9TELVt.jpg'),
(155681, 11060, 'The Traitors S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/516974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hECtcvv1QXK4MTyE3TYmW9TELVt.jpg'),
(155682, 11060, 'The Traitors S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/516975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hECtcvv1QXK4MTyE3TYmW9TELVt.jpg'),
(155683, 11060, 'The Traitors S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/516976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hECtcvv1QXK4MTyE3TYmW9TELVt.jpg'),
(155684, 11060, 'The Traitors S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/516977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hECtcvv1QXK4MTyE3TYmW9TELVt.jpg'),
(155685, 11060, 'The Traitors S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/516978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hECtcvv1QXK4MTyE3TYmW9TELVt.jpg'),
(155686, 11060, 'The Traitors S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/516979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hECtcvv1QXK4MTyE3TYmW9TELVt.jpg'),
(155687, 11060, 'The Traitors S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/516980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hECtcvv1QXK4MTyE3TYmW9TELVt.jpg'),
(155688, 11060, 'The Traitors S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/516981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hECtcvv1QXK4MTyE3TYmW9TELVt.jpg'),
(155689, 11060, 'The Traitors S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/516982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hECtcvv1QXK4MTyE3TYmW9TELVt.jpg'),
(155690, 11060, 'The Traitors S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/516983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hECtcvv1QXK4MTyE3TYmW9TELVt.jpg'),
(155691, 11061, 'Digimon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/430195.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fYCDgkGMroaukOlfiPJIEXRaFam.jpg'),
(155692, 11061, 'Digimon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/430196.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qaB6sWNWVnpORc08MVOuQUwKpji.jpg'),
(155693, 11061, 'Digimon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/430197.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/avo4GjEeyEtJcDpn7CkW1x63Ojq.jpg'),
(155694, 11061, 'Digimon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/430198.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kEmeDs6Nn1dgkGlkfp5sWskZQKa.jpg'),
(155695, 11061, 'Digimon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/430199.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sfsIemViX9Yn0Q1kCdNuOQkhtVo.jpg'),
(155696, 11061, 'Digimon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/430200.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dTJJg6wCOfxKCeOfmxtcWO18kWO.jpg'),
(155697, 11061, 'Digimon S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/430201.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t1paGSIi8ZVSbh9oDslDS5ZN5Ma.jpg'),
(155698, 11061, 'Digimon S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/430202.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uZd8OhEBkjFxPRIgJrPhc1zeC8Z.jpg'),
(155699, 11061, 'Digimon S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/430203.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sHKqbeBMY7fkXaQNoaaHn1vQlBV.jpg'),
(155700, 11061, 'Digimon S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/430204.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/At3sGTO67TMAgFJqZsgobtcfn3A.jpg'),
(155701, 11061, 'Digimon S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/430205.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tFrddgS2cck8JnQSgQrCNpD8N8I.jpg'),
(155702, 11061, 'Digimon S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/430206.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cAjyslcjKMtZkFPjpLgRslX2vId.jpg'),
(155703, 11061, 'Digimon S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/430207.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bUuZFPfPu6hmdXnNo9ycnUoWev2.jpg'),
(155704, 11061, 'Digimon S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/430208.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sbyvKAssX57U5x7J4wheUDN965w.jpg'),
(155705, 11061, 'Digimon S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/430209.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7NQFoizUP0zboiGQPfdb9RUjkuY.jpg'),
(155706, 11061, 'Digimon S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/430210.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zKEaV0ksPBxdOdeDoJp5LXHobYS.jpg'),
(155707, 11061, 'Digimon S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/430211.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9eCjbdIWkeHQq9zJhcxvRyPAy4j.jpg'),
(155708, 11061, 'Digimon S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/430212.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k2H1fcdxgtxeCnFWwghfop8CNOo.jpg'),
(155709, 11061, 'Digimon S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/430213.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cAgqwqZKtjY7VxKsp8YKxN7ZoQR.jpg'),
(155710, 11061, 'Digimon S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/430214.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xUPqSLJ0WWkjz77tP1pTRFzsYvS.jpg'),
(155711, 11061, 'Digimon S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/430215.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oBy4CNQXzBRKArcb1Auy0wLOnVf.jpg'),
(155712, 11061, 'Digimon S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/430216.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bkVI2774zb6Hpp3ZnvBxo9Cg1Av.jpg'),
(155713, 11061, 'Digimon S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/430217.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8IM9oZgFqcWNFPNWOKRvoTO3fB.jpg'),
(155714, 11061, 'Digimon S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/430218.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iUwww37V9c990sOD3Lmc5xwlWN2.jpg'),
(155715, 11061, 'Digimon S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/430219.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qFydzIHXeNyvGI60a0lH6dUaZvD.jpg'),
(155716, 11061, 'Digimon S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/430220.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vPtajjrZ0dz0wHoMlmT5qho5P5A.jpg'),
(155717, 11061, 'Digimon S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/430221.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pRRRlKZOIE2CvWcJuGbPnAvqHET.jpg'),
(155718, 11061, 'Digimon S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/430222.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cNac8wPyWfigUeLSXi0gsgmXc5h.jpg'),
(155719, 11061, 'Digimon S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/430223.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lKwwFS6LfDsF4e1pGqn9I1lknEB.jpg'),
(155720, 11061, 'Digimon S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/430224.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jjfuHoGNgPuwzwe7duVvGaGzJjm.jpg'),
(155721, 11061, 'Digimon S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/430225.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1WQq1QQIg58eSijpnmZtpsE4prP.jpg'),
(155722, 11061, 'Digimon S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/430226.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vQg5hZv7cONCH7nkzKj72q4HuFs.jpg'),
(155723, 11061, 'Digimon S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/430227.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aIZMEtofAwYUS61biIGyJvNiTAn.jpg'),
(155724, 11061, 'Digimon S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/430228.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1t0GeLMMaRoaePK2Pp3R7XC39ko.jpg'),
(155725, 11061, 'Digimon S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/430229.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jTVUHEpfDWxJj1f3Sy8Y0nTlA4V.jpg'),
(155726, 11061, 'Digimon S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/430230.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cOXDSYsONTfzRKKxZbMrfwRteoU.jpg'),
(155727, 11061, 'Digimon S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/430231.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AkKlUUR4kSPKme6LtpYkybi8PCC.jpg'),
(155728, 11061, 'Digimon S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/430232.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cm7pTbHiPR90TKPYohv7iBuabSu.jpg'),
(155729, 11061, 'Digimon S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/430233.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/58pyeIXAekuBZ8RJs6nNShA1rf.jpg'),
(155730, 11061, 'Digimon S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/430234.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oXT1mcyUo0lvVV3IYuJSNNFPNYQ.jpg'),
(155731, 11061, 'Digimon S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/430235.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hQTDw3pCAzNRkltzANyaYZhyQlD.jpg'),
(155732, 11061, 'Digimon S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/430236.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sC6wyktc6lx08sQbZevEqnSgylP.jpg'),
(155733, 11061, 'Digimon S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/430237.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nTNb72wMmwbFoDq2UxAqdf7pzn9.jpg'),
(155734, 11061, 'Digimon S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/430238.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7PEuByc0hlFH7GyNthtOSeJIWAd.jpg'),
(155735, 11061, 'Digimon S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/430239.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Ai2svAoB4M9wziXq6jiIXvkaZ1v.jpg'),
(155736, 11061, 'Digimon S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/430240.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7ZAxEg7JLXD6pBBzMWJvVBP6EJm.jpg'),
(155737, 11061, 'Digimon S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/430241.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mDzfS301GAyvFM5uLXIVWkCSShP.jpg'),
(155738, 11061, 'Digimon S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/430242.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eFjGvd138mkjE83XmEQEpj8vmfC.jpg'),
(155739, 11061, 'Digimon S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/430243.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l6F7r1puDadPjfbHcbrTEEP8BUE.jpg'),
(155740, 11061, 'Digimon S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/430244.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dESQ3CiaLWt9e1c6cUkjjSYvl1w.jpg'),
(155741, 11061, 'Digimon S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/430245.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7ZfSeutTb8SajruQDNcM97EskDF.jpg'),
(155742, 11061, 'Digimon S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/430246.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2PRFEiLhZSqCyKSlQyGTsuBSnOx.jpg'),
(155743, 11061, 'Digimon S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/430247.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/roRCF3HQiuM2Y1KE6BDbFcWjKNq.jpg'),
(155744, 11061, 'Digimon S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/430248.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1p8Knbc01WLq4fGjbcdRvnO4s4h.jpg'),
(155745, 11062, 'Digimon S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/430249.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tnSsIKnjok7tysYrOhRieZ1JS9D.jpg'),
(155746, 11062, 'Digimon S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/430250.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4sWTjBKuclnl50jiDLtxHQFr47c.jpg'),
(155747, 11062, 'Digimon S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/430251.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zKq0O0L0PjfkIKONyjmX2EmVWrB.jpg'),
(155748, 11062, 'Digimon S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/430252.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h3HGy6kGJCPej8ke1UaQTKpxr7w.jpg'),
(155749, 11062, 'Digimon S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/430253.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vP5KzX5IxLUk2mqbRVBIgIeQFIM.jpg'),
(155750, 11062, 'Digimon S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/430254.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kmoxyEE6Rivy8KkpgxLUnckIZ7E.jpg'),
(155751, 11062, 'Digimon S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/430255.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wsjB39kBB5TzXweZLFggg5KK02Z.jpg'),
(155752, 11062, 'Digimon S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/430256.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gEQb23Ucg1O7vH35ZbgxuP343GP.jpg'),
(155753, 11062, 'Digimon S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/430257.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xpMquXRZNHTuLZQMd9cQpa5L9D4.jpg'),
(155754, 11062, 'Digimon S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/430258.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/stzKY7g3F0sLJyX6ozuE0wgX9bS.jpg'),
(155755, 11062, 'Digimon S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/430259.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wYFoc2LBvzVxdnLdEQSsPYnm0yY.jpg'),
(155756, 11062, 'Digimon S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/430260.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dU8C4fs05MZyMlvGoQONnVMpxFF.jpg'),
(155757, 11062, 'Digimon S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/430261.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f41IRZusvq1MknvfcCsQVDrxU6d.jpg'),
(155758, 11062, 'Digimon S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/430262.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ce0JgwQuvQyyGgZlFqkbgh92cho.jpg'),
(155759, 11062, 'Digimon S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/430263.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yHdKlCHrlXa9t2q8a3gy0A2T6CO.jpg'),
(155760, 11062, 'Digimon S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/430264.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/umQHbYImzJK5Whm3Ti5cCX3Q2vd.jpg'),
(155761, 11062, 'Digimon S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/430265.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jR6Egu5Om6crZ5YwG0yje7pPKcV.jpg'),
(155762, 11062, 'Digimon S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/430266.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kBRJvZLW6vfn7x5OLsDO5OTiJdX.jpg'),
(155763, 11062, 'Digimon S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/430267.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7j93E9Sed9FDko0ZarIazPUWotj.jpg'),
(155764, 11062, 'Digimon S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/430268.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/62kICripikLKV9VFiMdOt4d2LQ1.jpg'),
(155765, 11062, 'Digimon S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/430269.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q7QUmmSYXeBMOJoFfsp30FlhNtk.jpg'),
(155766, 11062, 'Digimon S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/430270.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rMQjXBD7rNNDPC9nm39xnNIFoe3.jpg'),
(155767, 11062, 'Digimon S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/430271.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yN3xd3a4c9sevYtIkctMKSScREG.jpg'),
(155768, 11062, 'Digimon S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/430272.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sxhjuYY5VaPilXPML89LXA2MxMS.jpg'),
(155769, 11062, 'Digimon S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/430273.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tFXPpxXdnUnPrUAEBFmkTZPuofw.jpg'),
(155770, 11062, 'Digimon S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/430274.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lPhj0VrcJ7UH2uKyjRH2lp1hWWL.jpg'),
(155771, 11062, 'Digimon S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/430275.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/67uRNT2VdXpXJzA1KCpO18Fswib.jpg'),
(155772, 11062, 'Digimon S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/430276.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rbxAhbTGHbYPm3aXwuxgmp3Ogqs.jpg'),
(155773, 11062, 'Digimon S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/430277.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AnOFIabNSALJt3Htp8g5T3Aavaj.jpg'),
(155774, 11062, 'Digimon S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/430278.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mllAvXtZUqTNTiYZz5CdQlSRQ0Z.jpg'),
(155775, 11062, 'Digimon S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/430279.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bfFoZfBuxyj7UxZTd95e499eqHk.jpg'),
(155776, 11062, 'Digimon S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/430280.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/41eqGwPEUFBltF66hFXth3HTxgH.jpg'),
(155777, 11062, 'Digimon S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/430281.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b0FA4FSBNWSpIgPW1xD8oqoONzN.jpg'),
(155778, 11062, 'Digimon S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/430282.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jBJZjqnDRU4niuDu28hIUSW4siZ.jpg'),
(155779, 11062, 'Digimon S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/430283.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/swHk4wYdJfC4Or0nOvKplKAKgCD.jpg'),
(155780, 11062, 'Digimon S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/430284.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9bESQvxXSKkqQvreUQqitDQg4TU.jpg'),
(155781, 11062, 'Digimon S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/430285.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Z7xZvQdNe2s0AnqON1gkDOj7w4.jpg'),
(155782, 11062, 'Digimon S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/430286.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A5ApeQZtfEa1l9qEmSes9KzGgJr.jpg'),
(155783, 11062, 'Digimon S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/430287.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n5djNuXzePqdgchoFm8v77HEF3p.jpg'),
(155784, 11062, 'Digimon S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/430288.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gHhRgaBljoWeARHHC4gtyygvQn4.jpg'),
(155785, 11062, 'Digimon S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/430289.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nvL9JpMLf9sZU19GPcw0dyv9oJl.jpg'),
(155786, 11062, 'Digimon S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/430290.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dLdKu8hhTJkkUvVC7PyeJCc0Nh2.jpg'),
(155787, 11062, 'Digimon S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/430291.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3E7YEUZVyDrNfPW5CaJBnmSrSyc.jpg'),
(155788, 11062, 'Digimon S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/430292.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kkbYl01Xk6iiypZ8BthG7dq3JxY.jpg'),
(155789, 11062, 'Digimon S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/430293.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2SlzApg60RiVR1XvCBie6evUKt6.jpg'),
(155790, 11062, 'Digimon S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/430294.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5a23lYDaEFoGJcXM6LZdvtNuskk.jpg'),
(155791, 11062, 'Digimon S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/430295.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1G6v4bg377yxDBGAQVLVxTAgQan.jpg'),
(155792, 11062, 'Digimon S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/430296.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bsc0zI5HGDDdCWpFalCDDjpI3cX.jpg'),
(155793, 11062, 'Digimon S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/430297.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2jKixxLsZE6vwLGW98IgQ2VWuxT.jpg'),
(155794, 11062, 'Digimon S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/430298.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hahAzeuE7XgWcoWL0srnI9jMPL1.jpg'),
(155795, 11063, 'Digimon S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/430299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155796, 11063, 'Digimon S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/430300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155797, 11063, 'Digimon S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/430301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155798, 11063, 'Digimon S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/430302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155799, 11063, 'Digimon S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/430303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155800, 11063, 'Digimon S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/430304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155801, 11063, 'Digimon S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/430305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155802, 11063, 'Digimon S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/430306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155803, 11063, 'Digimon S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/430307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155804, 11063, 'Digimon S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/430308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155805, 11063, 'Digimon S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/430309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155806, 11063, 'Digimon S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/430310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155807, 11063, 'Digimon S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/430311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155808, 11063, 'Digimon S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/430312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155809, 11063, 'Digimon S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/430313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155810, 11063, 'Digimon S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/430314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155811, 11063, 'Digimon S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/430315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155812, 11063, 'Digimon S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/430316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155813, 11063, 'Digimon S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/430317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155814, 11063, 'Digimon S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/430318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155815, 11063, 'Digimon S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/430319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155816, 11063, 'Digimon S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/430320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155817, 11063, 'Digimon S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/430321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155818, 11063, 'Digimon S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/430322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155819, 11063, 'Digimon S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/430323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155820, 11063, 'Digimon S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/430324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155821, 11063, 'Digimon S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/430325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155822, 11063, 'Digimon S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/430326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155823, 11063, 'Digimon S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/430327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155824, 11063, 'Digimon S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/430328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155825, 11063, 'Digimon S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/430329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155826, 11063, 'Digimon S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/430330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155827, 11063, 'Digimon S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/430331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155828, 11063, 'Digimon S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/430332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155829, 11063, 'Digimon S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/430333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155830, 11063, 'Digimon S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/430334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155831, 11063, 'Digimon S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/430335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155832, 11063, 'Digimon S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/430336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155833, 11063, 'Digimon S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/430337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155834, 11063, 'Digimon S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/430338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155835, 11063, 'Digimon S03 E41', 'http://sinalprivado.info:80/series/1533784/1533784/430339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155836, 11063, 'Digimon S03 E42', 'http://sinalprivado.info:80/series/1533784/1533784/430340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155837, 11063, 'Digimon S03 E43', 'http://sinalprivado.info:80/series/1533784/1533784/430341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155838, 11063, 'Digimon S03 E44', 'http://sinalprivado.info:80/series/1533784/1533784/430342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155839, 11063, 'Digimon S03 E45', 'http://sinalprivado.info:80/series/1533784/1533784/430343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155840, 11063, 'Digimon S03 E46', 'http://sinalprivado.info:80/series/1533784/1533784/430344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155841, 11063, 'Digimon S03 E47', 'http://sinalprivado.info:80/series/1533784/1533784/430345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155842, 11063, 'Digimon S03 E48', 'http://sinalprivado.info:80/series/1533784/1533784/430346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155843, 11063, 'Digimon S03 E49', 'http://sinalprivado.info:80/series/1533784/1533784/430347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155844, 11063, 'Digimon S03 E50', 'http://sinalprivado.info:80/series/1533784/1533784/430348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155845, 11063, 'Digimon S03 E51', 'http://sinalprivado.info:80/series/1533784/1533784/430349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155846, 11064, 'Digimon S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/430350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155847, 11064, 'Digimon S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/430351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155848, 11064, 'Digimon S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/430352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155849, 11064, 'Digimon S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/430353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155850, 11064, 'Digimon S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/430354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155851, 11064, 'Digimon S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/430355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155852, 11064, 'Digimon S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/430356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155853, 11064, 'Digimon S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/430357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155854, 11064, 'Digimon S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/430358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155855, 11064, 'Digimon S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/430359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155856, 11064, 'Digimon S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/430360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155857, 11064, 'Digimon S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/430361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155858, 11064, 'Digimon S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/430362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155859, 11064, 'Digimon S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/430363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(155860, 11064, 'Digimon S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/430364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155861, 11064, 'Digimon S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/430365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155862, 11064, 'Digimon S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/430366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155863, 11064, 'Digimon S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/430367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155864, 11064, 'Digimon S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/430368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155865, 11064, 'Digimon S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/430369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155866, 11064, 'Digimon S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/430370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155867, 11064, 'Digimon S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/430371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155868, 11064, 'Digimon S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/430372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155869, 11064, 'Digimon S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/430373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155870, 11064, 'Digimon S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/430374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155871, 11064, 'Digimon S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/430375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155872, 11064, 'Digimon S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/430376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155873, 11064, 'Digimon S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/430377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155874, 11064, 'Digimon S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/430378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155875, 11064, 'Digimon S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/430379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155876, 11064, 'Digimon S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/430380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155877, 11064, 'Digimon S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/430381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155878, 11064, 'Digimon S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/430382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155879, 11064, 'Digimon S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/430383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155880, 11064, 'Digimon S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/430384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155881, 11064, 'Digimon S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/430385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155882, 11064, 'Digimon S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/430386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155883, 11064, 'Digimon S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/430387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155884, 11064, 'Digimon S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/430388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155885, 11064, 'Digimon S04 E40', 'http://sinalprivado.info:80/series/1533784/1533784/430389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155886, 11064, 'Digimon S04 E41', 'http://sinalprivado.info:80/series/1533784/1533784/430390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155887, 11064, 'Digimon S04 E42', 'http://sinalprivado.info:80/series/1533784/1533784/430391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155888, 11064, 'Digimon S04 E43', 'http://sinalprivado.info:80/series/1533784/1533784/430392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155889, 11064, 'Digimon S04 E44', 'http://sinalprivado.info:80/series/1533784/1533784/430393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155890, 11064, 'Digimon S04 E45', 'http://sinalprivado.info:80/series/1533784/1533784/430394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155891, 11064, 'Digimon S04 E46', 'http://sinalprivado.info:80/series/1533784/1533784/430395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155892, 11064, 'Digimon S04 E47', 'http://sinalprivado.info:80/series/1533784/1533784/430396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155893, 11064, 'Digimon S04 E48', 'http://sinalprivado.info:80/series/1533784/1533784/430397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155894, 11064, 'Digimon S04 E49', 'http://sinalprivado.info:80/series/1533784/1533784/430398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155895, 11064, 'Digimon S04 E50', 'http://sinalprivado.info:80/series/1533784/1533784/430399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155896, 11065, 'Digimon S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/430400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155897, 11065, 'Digimon S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/430401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155898, 11065, 'Digimon S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/430402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155899, 11065, 'Digimon S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/430403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155900, 11065, 'Digimon S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/430404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155901, 11065, 'Digimon S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/430405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155902, 11065, 'Digimon S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/430406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155903, 11065, 'Digimon S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/430407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155904, 11065, 'Digimon S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/430408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155905, 11065, 'Digimon S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/430409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155906, 11065, 'Digimon S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/430410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155907, 11065, 'Digimon S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/430411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155908, 11065, 'Digimon S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/430412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155909, 11065, 'Digimon S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/430413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155910, 11065, 'Digimon S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/430414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155911, 11065, 'Digimon S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/430415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155912, 11065, 'Digimon S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/430416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155913, 11065, 'Digimon S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/430417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155914, 11065, 'Digimon S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/430418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155915, 11065, 'Digimon S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/430419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155916, 11065, 'Digimon S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/430420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155917, 11065, 'Digimon S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/430421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155918, 11065, 'Digimon S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/430422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155919, 11065, 'Digimon S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/430423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155920, 11065, 'Digimon S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/430424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155921, 11065, 'Digimon S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/430425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155922, 11065, 'Digimon S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/430426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155923, 11065, 'Digimon S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/430427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155924, 11065, 'Digimon S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/430428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155925, 11065, 'Digimon S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/430429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155926, 11065, 'Digimon S05 E31', 'http://sinalprivado.info:80/series/1533784/1533784/430430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155927, 11065, 'Digimon S05 E32', 'http://sinalprivado.info:80/series/1533784/1533784/430431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155928, 11065, 'Digimon S05 E33', 'http://sinalprivado.info:80/series/1533784/1533784/430432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155929, 11065, 'Digimon S05 E34', 'http://sinalprivado.info:80/series/1533784/1533784/430433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155930, 11065, 'Digimon S05 E35', 'http://sinalprivado.info:80/series/1533784/1533784/430434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155931, 11065, 'Digimon S05 E36', 'http://sinalprivado.info:80/series/1533784/1533784/430435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155932, 11065, 'Digimon S05 E37', 'http://sinalprivado.info:80/series/1533784/1533784/430436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155933, 11065, 'Digimon S05 E38', 'http://sinalprivado.info:80/series/1533784/1533784/430437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155934, 11065, 'Digimon S05 E39', 'http://sinalprivado.info:80/series/1533784/1533784/430438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155935, 11065, 'Digimon S05 E40', 'http://sinalprivado.info:80/series/1533784/1533784/430439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155936, 11065, 'Digimon S05 E41', 'http://sinalprivado.info:80/series/1533784/1533784/430440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155937, 11065, 'Digimon S05 E42', 'http://sinalprivado.info:80/series/1533784/1533784/430441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155938, 11065, 'Digimon S05 E43', 'http://sinalprivado.info:80/series/1533784/1533784/430442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155939, 11065, 'Digimon S05 E44', 'http://sinalprivado.info:80/series/1533784/1533784/430443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155940, 11065, 'Digimon S05 E45', 'http://sinalprivado.info:80/series/1533784/1533784/430444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155941, 11065, 'Digimon S05 E46', 'http://sinalprivado.info:80/series/1533784/1533784/430445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155942, 11065, 'Digimon S05 E47', 'http://sinalprivado.info:80/series/1533784/1533784/430446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155943, 11065, 'Digimon S05 E48', 'http://sinalprivado.info:80/series/1533784/1533784/430447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AlPYAJYkSfvVYAXK1a3gZqpWwda.jpg'),
(155944, 11066, 'Bad Monkey S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/430193.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7jxH5dObSr6GHbFyNcMOLdJnS5k.jpg'),
(155945, 11066, 'Bad Monkey S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/430194.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yRm7mtKuxUheiz0jhwQCIFlRKov.jpg'),
(155946, 11066, 'Bad Monkey S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/437633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sDbpr5VoxlcQvzvWFECr7bXCAwg.jpg'),
(155947, 11066, 'Bad Monkey S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/442930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sDbpr5VoxlcQvzvWFECr7bXCAwg.jpg'),
(155948, 11066, 'Bad Monkey S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/448802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sDbpr5VoxlcQvzvWFECr7bXCAwg.jpg'),
(155949, 11066, 'Bad Monkey S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/452911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sDbpr5VoxlcQvzvWFECr7bXCAwg.jpg'),
(155950, 11066, 'Bad Monkey S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/458255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sDbpr5VoxlcQvzvWFECr7bXCAwg.jpg'),
(155951, 11066, 'Bad Monkey S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/464800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sDbpr5VoxlcQvzvWFECr7bXCAwg.jpg'),
(155952, 11066, 'Bad Monkey S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/470894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sDbpr5VoxlcQvzvWFECr7bXCAwg.jpg'),
(155953, 11066, 'Bad Monkey S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/479061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sDbpr5VoxlcQvzvWFECr7bXCAwg.jpg'),
(155954, 11067, 'Estrela da Casa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/430191.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3xGcUHhMh83jqEcVkqYxtCHw4Be.jpg'),
(155955, 11067, 'Estrela da Casa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/430192.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7CB0X0u1hjRincpKYcgKwrd44lV.jpg'),
(155956, 11067, 'Estrela da Casa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155957, 11067, 'Estrela da Casa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155958, 11067, 'Estrela da Casa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155959, 11067, 'Estrela da Casa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155960, 11067, 'Estrela da Casa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/436970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155961, 11067, 'Estrela da Casa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/436971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155962, 11067, 'Estrela da Casa S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/436972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155963, 11067, 'Estrela da Casa S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/436973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155964, 11067, 'Estrela da Casa S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/436974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155965, 11067, 'Estrela da Casa S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/436975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155966, 11067, 'Estrela da Casa S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/442792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155967, 11067, 'Estrela da Casa S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/442793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155968, 11067, 'Estrela da Casa S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/442794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155969, 11067, 'Estrela da Casa S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/442795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155970, 11067, 'Estrela da Casa S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/442796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155971, 11067, 'Estrela da Casa S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/444742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155972, 11067, 'Estrela da Casa S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/444743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155973, 11067, 'Estrela da Casa S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/444744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155974, 11067, 'Estrela da Casa S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/448082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155975, 11067, 'Estrela da Casa S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/448083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155976, 11067, 'Estrela da Casa S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/448084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155977, 11067, 'Estrela da Casa S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/448085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155978, 11067, 'Estrela da Casa S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/448086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155979, 11067, 'Estrela da Casa S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/448087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155980, 11067, 'Estrela da Casa S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/448088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155981, 11067, 'Estrela da Casa S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/452666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155982, 11067, 'Estrela da Casa S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/452667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155983, 11067, 'Estrela da Casa S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/452668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155984, 11067, 'Estrela da Casa S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/456325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155985, 11067, 'Estrela da Casa S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/456326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155986, 11067, 'Estrela da Casa S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/456327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155987, 11067, 'Estrela da Casa S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/456328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155988, 11067, 'Estrela da Casa S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/458058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155989, 11067, 'Estrela da Casa S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/458059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155990, 11067, 'Estrela da Casa S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/461450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155991, 11067, 'Estrela da Casa S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/461451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155992, 11067, 'Estrela da Casa S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/461452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155993, 11067, 'Estrela da Casa S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/461453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155994, 11067, 'Estrela da Casa S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/461454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155995, 11067, 'Estrela da Casa S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/467661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155996, 11067, 'Estrela da Casa S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/467662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155997, 11067, 'Estrela da Casa S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/467663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155998, 11067, 'Estrela da Casa S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/467664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(155999, 11067, 'Estrela da Casa S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/467665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156000, 11067, 'Estrela da Casa S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/467666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156001, 11067, 'Estrela da Casa S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/467667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156002, 11067, 'Estrela da Casa S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/470628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156003, 11067, 'Estrela da Casa S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/470629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156004, 11068, 'Estrela da Casa S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/881964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156005, 11068, 'Estrela da Casa S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/881965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156006, 11068, 'Estrela da Casa S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/881966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156007, 11068, 'Estrela da Casa S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/881967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156008, 11068, 'Estrela da Casa S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/881968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156009, 11068, 'Estrela da Casa S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/881969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156010, 11068, 'Estrela da Casa S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/881970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156011, 11068, 'Estrela da Casa S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/882362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156012, 11068, 'Estrela da Casa S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/882363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156013, 11068, 'Estrela da Casa S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/883561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156014, 11068, 'Estrela da Casa S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/883562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156015, 11068, 'Estrela da Casa S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/883563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156016, 11068, 'Estrela da Casa S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/883564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156017, 11068, 'Estrela da Casa S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/883565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156018, 11068, 'Estrela da Casa S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/883806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156019, 11068, 'Estrela da Casa S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/883807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156020, 11068, 'Estrela da Casa S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/884072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156021, 11068, 'Estrela da Casa S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/884073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156022, 11068, 'Estrela da Casa S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/884074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156023, 11068, 'Estrela da Casa S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/884075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156024, 11068, 'Estrela da Casa S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/884076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156025, 11068, 'Estrela da Casa S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/885795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156026, 11068, 'Estrela da Casa S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/885796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156027, 11068, 'Estrela da Casa S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/885797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156028, 11068, 'Estrela da Casa S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/885798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156029, 11068, 'Estrela da Casa S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/885799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156030, 11068, 'Estrela da Casa S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/885800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156031, 11068, 'Estrela da Casa S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/886087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156032, 11068, 'Estrela da Casa S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/886088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156033, 11068, 'Estrela da Casa S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/886089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156034, 11068, 'Estrela da Casa S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/886090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156035, 11068, 'Estrela da Casa S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/886091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156036, 11068, 'Estrela da Casa S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/887597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156037, 11068, 'Estrela da Casa S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/887598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156038, 11068, 'Estrela da Casa S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/887599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156039, 11068, 'Estrela da Casa S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/887600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156040, 11068, 'Estrela da Casa S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/887601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156041, 11068, 'Estrela da Casa S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/887602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156042, 11068, 'Estrela da Casa S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/887748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156043, 11068, 'Estrela da Casa S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/887749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156044, 11068, 'Estrela da Casa S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/888215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156045, 11068, 'Estrela da Casa S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/888216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156046, 11068, 'Estrela da Casa S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/889637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i8HkMKyuZ13i8xpMW3ZmdTXYOL0.jpg'),
(156047, 11069, 'Gleipnir S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/430178.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/db4In46A9sioKKvK5nILF1v8fqq.jpg'),
(156048, 11069, 'Gleipnir S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/430179.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4YA7WxK4UurgBVMUaY0wrD0Pai8.jpg'),
(156049, 11069, 'Gleipnir S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/430180.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/472lkIulAqDWxt3e82kWVNrdV9e.jpg'),
(156050, 11069, 'Gleipnir S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/430181.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8WAJYQgEbdd3ChSoKOML434YaTp.jpg'),
(156051, 11069, 'Gleipnir S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/430182.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rEmTExYHmsUQsOOwTHbnXW2l6DG.jpg'),
(156052, 11069, 'Gleipnir S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/430183.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qYK2T8WvIYqqqf2rzO9duLGZ1jQ.jpg'),
(156053, 11069, 'Gleipnir S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/430184.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sIuVcKrfGPa3yjMKrGOfzSznDBi.jpg'),
(156054, 11069, 'Gleipnir S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/430185.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eqlaifHkQtgw8YgGrZGl1lqjf3C.jpg'),
(156055, 11069, 'Gleipnir S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/430186.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5LbtFLxLAMuTX0bm2Wf3mHXCTth.jpg'),
(156056, 11069, 'Gleipnir S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/430187.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eJyoiMJ5vlFYzIoac8KKd1E2aqv.jpg'),
(156057, 11069, 'Gleipnir S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/430188.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mTcWQ09Rb0tMOWRIHubJJnP7QYk.jpg'),
(156058, 11069, 'Gleipnir S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/430189.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9vfnMODnqfskYiYY9B9NbRyzc9j.jpg'),
(156059, 11069, 'Gleipnir S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/430190.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b8BN8VTZ0M3Ilr8jGfsez3My9eZ.jpg'),
(156060, 11070, 'O Amor Volta para Casa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/430176.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9L7goSyDcGLmXJmS3DGNumUdBb8.jpg'),
(156061, 11070, 'O Amor Volta para Casa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/430177.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5HBOpGY2Ucxper3U1dcMSwUI313.jpg'),
(156062, 11070, 'O Amor Volta para Casa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/434384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4p2MVh0bSaweWwaBV9aFG4t7hww.jpg'),
(156063, 11070, 'O Amor Volta para Casa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/434385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4p2MVh0bSaweWwaBV9aFG4t7hww.jpg'),
(156064, 11070, 'O Amor Volta para Casa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4p2MVh0bSaweWwaBV9aFG4t7hww.jpg'),
(156065, 11070, 'O Amor Volta para Casa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4p2MVh0bSaweWwaBV9aFG4t7hww.jpg'),
(156066, 11070, 'O Amor Volta para Casa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/444392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4p2MVh0bSaweWwaBV9aFG4t7hww.jpg'),
(156067, 11070, 'O Amor Volta para Casa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/447099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4p2MVh0bSaweWwaBV9aFG4t7hww.jpg'),
(156068, 11070, 'O Amor Volta para Casa S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/455895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4p2MVh0bSaweWwaBV9aFG4t7hww.jpg'),
(156069, 11070, 'O Amor Volta para Casa S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/455896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4p2MVh0bSaweWwaBV9aFG4t7hww.jpg'),
(156070, 11070, 'O Amor Volta para Casa S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/455897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4p2MVh0bSaweWwaBV9aFG4t7hww.jpg'),
(156071, 11070, 'O Amor Volta para Casa S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/455898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4p2MVh0bSaweWwaBV9aFG4t7hww.jpg'),
(156072, 11071, 'Reforma na Montanha A Competicao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/430170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AnZUnkxt50g9EceJC70NiRHKGlP.jpg'),
(156073, 11071, 'Reforma na Montanha A Competicao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/430171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AnZUnkxt50g9EceJC70NiRHKGlP.jpg'),
(156074, 11071, 'Reforma na Montanha A Competicao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/430172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AnZUnkxt50g9EceJC70NiRHKGlP.jpg'),
(156075, 11071, 'Reforma na Montanha A Competicao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/430173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AnZUnkxt50g9EceJC70NiRHKGlP.jpg'),
(156076, 11071, 'Reforma na Montanha A Competicao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/430174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AnZUnkxt50g9EceJC70NiRHKGlP.jpg'),
(156077, 11071, 'Reforma na Montanha A Competicao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/430175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AnZUnkxt50g9EceJC70NiRHKGlP.jpg'),
(156078, 11072, 'Diários de uma Apotecária S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435532.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ggj0UKd4j5uwYPEuuS9KmO76Lcn.jpg'),
(156079, 11072, 'Diários de uma Apotecária S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435533.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pYC0kEvnKtVm50uD2rBmtrZZnix.jpg'),
(156080, 11072, 'Diários de uma Apotecária S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435534.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nfrCtoX4yRh7WyF9unECvML4dyG.jpg'),
(156081, 11072, 'Diários de uma Apotecária S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435535.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/56uZXOtpTuUvyuYGEpSLNJtJOBO.jpg'),
(156082, 11072, 'Diários de uma Apotecária S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435536.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/45h60UAouIJHiKRCI8zx6Vb38Nh.jpg'),
(156083, 11072, 'Diários de uma Apotecária S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435537.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lk1dC3AFErQwPjaKlHHc6f7g7rz.jpg'),
(156084, 11072, 'Diários de uma Apotecária S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/435538.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5wBAUmOAlu9z2chOoqke2wwI6G9.jpg'),
(156085, 11072, 'Diários de uma Apotecária S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/435539.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j9m1E9HOJVl4pjnJRhjH445EYmx.jpg'),
(156086, 11072, 'Diários de uma Apotecária S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/435540.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u9rreY8RcnIsmx8kvCDhEy1BvXz.jpg'),
(156087, 11072, 'Diários de uma Apotecária S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/435541.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/brTsGje2MKuCHQuj8UVF1VjTSUv.jpg'),
(156088, 11072, 'Diários de uma Apotecária S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/435542.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9K1ZNqTYK8ty1Olj2jGJAZ3l4y3.jpg'),
(156089, 11072, 'Diários de uma Apotecária S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/435543.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xa9CovqvQIgYENhpHdqun3JTn4A.jpg'),
(156090, 11072, 'Diários de uma Apotecária S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/435544.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wIIuz0ZkiKKdBSUyZfAIH25uPNF.jpg'),
(156091, 11072, 'Diários de uma Apotecária S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/612497.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l3lUDpsjugdQFEn5X44CrLgisx.jpg'),
(156092, 11072, 'Diários de uma Apotecária S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/435546.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ghhWjMzXRuJ8q4sUFydIzLI1QkH.jpg'),
(156093, 11072, 'Diários de uma Apotecária S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/435547.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hpzqYrNAhG9sLiAp1pm0oSWDGxf.jpg'),
(156094, 11072, 'Diários de uma Apotecária S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/435548.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wahEWKAq9HFzMLVxBCexHFWLlWd.jpg'),
(156095, 11072, 'Diários de uma Apotecária S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/435549.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3nVPYisofFOJuLJHf4zx3RvMdMf.jpg'),
(156096, 11072, 'Diários de uma Apotecária S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/435550.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Y1BHMhhCHwWwxAqNoQYGyZvMWk.jpg'),
(156097, 11072, 'Diários de uma Apotecária S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/435551.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kFOrOTXNY7jhLRpe9PzX7bdPtxA.jpg'),
(156098, 11072, 'Diários de uma Apotecária S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/435552.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u1C8TsL5XhXNdZOJrat2q7coqvX.jpg'),
(156099, 11072, 'Diários de uma Apotecária S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/435553.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2g0c1GFAnj6MJkOpnRgcfh5emAP.jpg'),
(156100, 11072, 'Diários de uma Apotecária S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/435554.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gPYAVIMNiBLLfNlF1VVVi9SiECT.jpg'),
(156101, 11072, 'Diários de uma Apotecária S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/435555.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7eVCn6wFG1RFqxj0IMpaJFtelKr.jpg'),
(156102, 11073, 'Diários de uma Apotecária S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/828160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156103, 11073, 'Diários de uma Apotecária S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/828161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156104, 11073, 'Diários de uma Apotecária S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/828162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156105, 11073, 'Diários de uma Apotecária S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/828163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156106, 11073, 'Diários de uma Apotecária S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/828164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156107, 11073, 'Diários de uma Apotecária S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/828165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156108, 11073, 'Diários de uma Apotecária S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/828166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156109, 11073, 'Diários de uma Apotecária S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/828167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156110, 11073, 'Diários de uma Apotecária S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/828168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156111, 11073, 'Diários de uma Apotecária S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/828169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156112, 11073, 'Diários de uma Apotecária S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/828170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156113, 11073, 'Diários de uma Apotecária S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/828171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156114, 11073, 'Diários de uma Apotecária S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/828172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156115, 11073, 'Diários de uma Apotecária S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/828173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156116, 11073, 'Diários de uma Apotecária S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/828174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156117, 11073, 'Diários de uma Apotecária S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/828175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156118, 11073, 'Diários de uma Apotecária S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/828176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156119, 11073, 'Diários de uma Apotecária S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/828177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156120, 11073, 'Diários de uma Apotecária S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/847672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156121, 11073, 'Diários de uma Apotecária S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/847673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(156122, 11073, 'Diários de uma Apotecária S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/855158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156123, 11073, 'Diários de uma Apotecária S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/856391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156124, 11073, 'Diários de uma Apotecária S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/872528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156125, 11073, 'Diários de uma Apotecária S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/878362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xk4wXCwNlPBUEmmtxa8eIoqZtU.jpg'),
(156126, 11074, 'Batalha de Influencers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435351.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eGXefMN0Vqkbc4FLB7hBzEdRXG.jpg'),
(156127, 11074, 'Batalha de Influencers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435352.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2eUuIOFAPjEQJjzhCj71jJSYlxp.jpg'),
(156128, 11074, 'Batalha de Influencers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435353.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nRCmBAGzhjAFwPQXY7OFpgFPnMt.jpg'),
(156129, 11074, 'Batalha de Influencers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435354.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uXdFLiCo0oXCKeAzqYayuxEoNcI.jpg'),
(156130, 11074, 'Batalha de Influencers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435355.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/edIz8QLsRRPDsnRpfnQO9uV7FD8.jpg'),
(156131, 11074, 'Batalha de Influencers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435356.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2zEKTP5X8OCtRTmIloAYw0KKo75.jpg'),
(156132, 11074, 'Batalha de Influencers S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/435357.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lrUkN49Qomr6MCp3lHrAwSc9ybl.jpg'),
(156133, 11075, 'Confissoes de um Crime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435349.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/78k9U9aAPPNSwVRP8HU5zLUlV7e.jpg'),
(156134, 11075, 'Confissoes de um Crime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435350.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q0gKwo4Dbi12EylG5buOgvcpI6w.jpg'),
(156135, 11075, 'Confissoes de um Crime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/437023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f1PU458M3AcnnkFN0oUXtEeBnoD.jpg'),
(156136, 11075, 'Confissoes de um Crime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/448152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f1PU458M3AcnnkFN0oUXtEeBnoD.jpg'),
(156137, 11075, 'Confissoes de um Crime S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/448153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f1PU458M3AcnnkFN0oUXtEeBnoD.jpg'),
(156138, 11075, 'Confissoes de um Crime S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/456334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f1PU458M3AcnnkFN0oUXtEeBnoD.jpg'),
(156139, 11075, 'Confissoes de um Crime S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/467783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f1PU458M3AcnnkFN0oUXtEeBnoD.jpg'),
(156140, 11075, 'Confissoes de um Crime S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/467784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f1PU458M3AcnnkFN0oUXtEeBnoD.jpg'),
(156141, 11075, 'Confissoes de um Crime S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/491341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f1PU458M3AcnnkFN0oUXtEeBnoD.jpg'),
(156142, 11075, 'Confissoes de um Crime S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/491342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f1PU458M3AcnnkFN0oUXtEeBnoD.jpg'),
(156143, 11075, 'Confissoes de um Crime S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/491343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f1PU458M3AcnnkFN0oUXtEeBnoD.jpg'),
(156144, 11075, 'Confissoes de um Crime S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/491344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f1PU458M3AcnnkFN0oUXtEeBnoD.jpg'),
(156145, 11076, 'Dr. Death The Undoctored Story S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435345.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rjHY3ORR5dT3k0FmTidpmWIwamh.jpg'),
(156146, 11076, 'Dr. Death The Undoctored Story S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435346.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jRbHT1zgrTlmfwkqEl5coDGRA09.jpg'),
(156147, 11076, 'Dr. Death The Undoctored Story S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435347.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fD5uoMjW1Aicq8Tc4lygeYfGHP9.jpg'),
(156148, 11076, 'Dr. Death The Undoctored Story S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435348.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x3ncLFZdpO8NjV4LPfK410OmlQR.jpg'),
(156149, 11077, 'Maxima S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435344.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/btQnhBOcSNqNS5vIxNaBH5oY5sq.jpg'),
(156150, 11077, 'Maxima S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/436104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fBG4YjMZk4wRpYOtr3uSlBM5dx0.jpg'),
(156151, 11077, 'Maxima S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/441924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fBG4YjMZk4wRpYOtr3uSlBM5dx0.jpg'),
(156152, 11077, 'Maxima S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/447370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fBG4YjMZk4wRpYOtr3uSlBM5dx0.jpg'),
(156153, 11077, 'Maxima S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/457605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fBG4YjMZk4wRpYOtr3uSlBM5dx0.jpg'),
(156154, 11077, 'Maxima S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/457606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fBG4YjMZk4wRpYOtr3uSlBM5dx0.jpg'),
(156155, 11078, 'O Amor e Melhor na Segunda Vez S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435338.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/clmqieKidTw6QbEu5NfMYqCH25i.jpg'),
(156156, 11078, 'O Amor e Melhor na Segunda Vez S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435339.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/knB3y5fHb12d08W1GFbYpUkdGNj.jpg'),
(156157, 11078, 'O Amor e Melhor na Segunda Vez S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435340.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/si9G07ypuFbtWtVk0fLAfIrMREs.jpg'),
(156158, 11078, 'O Amor e Melhor na Segunda Vez S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435341.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/il7QqFvkG8fSAvrhrdbyI7dUtgo.jpg'),
(156159, 11078, 'O Amor e Melhor na Segunda Vez S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435342.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/97E4t6dODGvGxqMoe20HDG918Eg.jpg'),
(156160, 11078, 'O Amor e Melhor na Segunda Vez S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435343.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nzxHr21jB3IVXLuI0fMFXryPwZP.jpg'),
(156161, 11079, 'Por Tras das Cameras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435328.mp4', 'https://i.ibb.co/8DD3kSb/Design-sem-nome-1.png'),
(156162, 11079, 'Por Tras das Cameras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435329.mp4', 'https://i.ibb.co/8DD3kSb/Design-sem-nome-1.png'),
(156163, 11079, 'Por Tras das Cameras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435330.mp4', 'https://i.ibb.co/8DD3kSb/Design-sem-nome-1.png'),
(156164, 11079, 'Por Tras das Cameras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435331.mp4', 'https://i.ibb.co/8DD3kSb/Design-sem-nome-1.png'),
(156165, 11079, 'Por Tras das Cameras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435332.mp4', 'https://i.ibb.co/8DD3kSb/Design-sem-nome-1.png'),
(156166, 11079, 'Por Tras das Cameras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435333.mp4', 'https://i.ibb.co/8DD3kSb/Design-sem-nome-1.png'),
(156167, 11079, 'Por Tras das Cameras S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/435334.mp4', 'https://i.ibb.co/8DD3kSb/Design-sem-nome-1.png'),
(156168, 11079, 'Por Tras das Cameras S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/435335.mp4', 'https://i.ibb.co/8DD3kSb/Design-sem-nome-1.png'),
(156169, 11079, 'Por Tras das Cameras S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/435336.mp4', 'https://i.ibb.co/8DD3kSb/Design-sem-nome-1.png'),
(156170, 11079, 'Por Tras das Cameras S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/435337.mp4', 'https://i.ibb.co/8DD3kSb/Design-sem-nome-1.png'),
(156171, 11080, 'Takara and Amagi S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435320.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7iovHFZZNBjkGFyZczrZCMNxome.jpg'),
(156172, 11080, 'Takara and Amagi S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435321.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/194BgacP5OcSMNZb1OMHYNbO1F0.jpg'),
(156173, 11080, 'Takara and Amagi S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435322.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qLC0NqLJCkwBX9EJYCtOyOSUhe3.jpg'),
(156174, 11080, 'Takara and Amagi S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435323.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wGXOMz4A6Zib5HeGTklOP4AB8Ss.jpg'),
(156175, 11080, 'Takara and Amagi S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435324.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/prNMjdswtQC46nVAp5q2oZWIshf.jpg'),
(156176, 11080, 'Takara and Amagi S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hl6aq4ot0TRCILcvM61WcrGAKaE.jpg'),
(156177, 11080, 'Takara and Amagi S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/435326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hl6aq4ot0TRCILcvM61WcrGAKaE.jpg'),
(156178, 11080, 'Takara and Amagi S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/435327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hl6aq4ot0TRCILcvM61WcrGAKaE.jpg'),
(156179, 6284, 'Uma Equipe Muito Especial S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435312.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cL151wciTUIc4MLOuQTXqMDlWND.jpg'),
(156180, 6284, 'Uma Equipe Muito Especial S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435313.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a6ZU6OjJ8HauRXO3kCQx7bJKhZM.jpg'),
(156181, 6284, 'Uma Equipe Muito Especial S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435314.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rtPncR81qaj79ZPsMxs4cZXBn0A.jpg'),
(156182, 6284, 'Uma Equipe Muito Especial S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435315.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3KXeWRftU20MUn6wALmaoekcITI.jpg'),
(156183, 6284, 'Uma Equipe Muito Especial S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435316.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aD12FjmQvWI9PiQb0URwiHf0mWN.jpg'),
(156184, 6284, 'Uma Equipe Muito Especial S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435317.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gWVI2XwahqJMJKHoSFMRfoFzid0.jpg'),
(156185, 6284, 'Uma Equipe Muito Especial S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/435318.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sjmqJGq6fanFpXmQmd3wbM9Y8h6.jpg'),
(156186, 6284, 'Uma Equipe Muito Especial S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/435319.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pHu0vi570jF6N6IJZ3XAlRCUcSF.jpg'),
(156187, 11081, 'Wolf S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435306.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xwzOuqlssceNUFgnBx0NTvfzW9Y.jpg'),
(156188, 11081, 'Wolf S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435307.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fYslBQiQHcUcGYKb8apZ6eeBsML.jpg'),
(156189, 11081, 'Wolf S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435308.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rzFu30hX7IxNEkUwwAXTfl6zipz.jpg'),
(156190, 11081, 'Wolf S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435309.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/txZ6j26qtmaSH9dLpr2CkzGwELI.jpg'),
(156191, 11081, 'Wolf S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435310.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/krq6ZbPnhh3id4ir9UwWIZMYcB7.jpg'),
(156192, 11081, 'Wolf S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435311.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wbb3Cv9G20s235UNPfECmwph1f3.jpg'),
(156193, 11082, 'Jornada nas Estrelas A Nova Missao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435557.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5yUZWZIH4V7Hca8SDxEfjYituVx.jpg'),
(156194, 11082, 'Jornada nas Estrelas A Nova Missao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435558.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jPjHNMPOiTLzOtWSeOfuTW7k6g7.jpg'),
(156195, 11082, 'Jornada nas Estrelas A Nova Missao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435559.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tOPzMfkb7N8daVgAVt6JInNPZiu.jpg'),
(156196, 11082, 'Jornada nas Estrelas A Nova Missao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435560.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bgOW3oU8GvSk4TR3vFZLpdU0Nh9.jpg'),
(156197, 11082, 'Jornada nas Estrelas A Nova Missao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435561.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gShDL83BusUx4UJob1sBE3FysWL.jpg'),
(156198, 11082, 'Jornada nas Estrelas A Nova Missao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435562.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uoYQ0wCrdCEqZpCSpY0GR4d4lj8.jpg'),
(156199, 11082, 'Jornada nas Estrelas A Nova Missao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/435563.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4QCsqLFl7FOzWsgZtsvH3aYRqvM.jpg'),
(156200, 11082, 'Jornada nas Estrelas A Nova Missao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/435564.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f7vEXYbENa4exdUSv2BuGyZaSj6.jpg'),
(156201, 11082, 'Jornada nas Estrelas A Nova Missao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/435565.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9aujTBLl9dcMgMC1T33RRtM3LY5.jpg'),
(156202, 11082, 'Jornada nas Estrelas A Nova Missao S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/435566.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pEFikfOZ28X5JJrW7breCym7Lti.jpg'),
(156203, 11082, 'Jornada nas Estrelas A Nova Missao S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/435567.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cfYEuAZCInt8B3gmP1n0h2pQO9F.jpg'),
(156204, 11082, 'Jornada nas Estrelas A Nova Missao S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/435568.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sCOHw7blOk8aQx6xkF2Bo9YOLLm.jpg'),
(156205, 11082, 'Jornada nas Estrelas A Nova Missao S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/435569.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/C1FTaLn7KXtxHqx6sju85JnUVZ.jpg'),
(156206, 11082, 'Jornada nas Estrelas A Nova Missao S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/435570.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5GBDWEepz3j2GxpMpDElvxzV6xz.jpg'),
(156207, 11082, 'Jornada nas Estrelas A Nova Missao S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/435571.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hvCWmfwVBhXQXITGQv6mEzxKpMR.jpg'),
(156208, 11082, 'Jornada nas Estrelas A Nova Missao S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/435572.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zqBvmMMEhFJY50rDjrt1DkjeBDg.jpg'),
(156209, 11082, 'Jornada nas Estrelas A Nova Missao S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/435573.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qpppTQK0oZasjNwaBR4epB6JskN.jpg'),
(156210, 11082, 'Jornada nas Estrelas A Nova Missao S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/435574.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7f15n6sbt1NzZUB8OOQ8JW2wcSN.jpg'),
(156211, 11082, 'Jornada nas Estrelas A Nova Missao S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/435575.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/agAQse7ReQMrLOH1K82F6pJhGTl.jpg'),
(156212, 11083, 'Jornada nas Estrelas A Nova Missao S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435576.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iWlvrNuYKTC1RKq0sK6rOVcJiaM.jpg'),
(156213, 11083, 'Jornada nas Estrelas A Nova Missao S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435577.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8iQdovHiTKdVrbl1kDFne41PwWp.jpg'),
(156214, 11083, 'Jornada nas Estrelas A Nova Missao S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435578.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4clkvwFQso6kPMgLxWWHptPo8RC.jpg'),
(156215, 11083, 'Jornada nas Estrelas A Nova Missao S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435579.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fwAqOeSJmzoMsTBcpMDQhykJmua.jpg'),
(156216, 11083, 'Jornada nas Estrelas A Nova Missao S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435580.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pvZy7UrW1FwTi4O2S3skzSMQPpp.jpg'),
(156217, 11083, 'Jornada nas Estrelas A Nova Missao S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435581.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jEWY8aLPxwBFy0szl8qMsGG5X9s.jpg'),
(156218, 11083, 'Jornada nas Estrelas A Nova Missao S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/435582.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sufRC4IrtJ0zQU0T1IbGa9QzkW6.jpg'),
(156219, 11083, 'Jornada nas Estrelas A Nova Missao S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/435583.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ffm6DZKqOwkOPSi3YG22wCa8LTb.jpg'),
(156220, 11083, 'Jornada nas Estrelas A Nova Missao S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/435584.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8pJOBdan8zkNX4llpdNaMv2i1Zd.jpg'),
(156221, 11083, 'Jornada nas Estrelas A Nova Missao S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/435585.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oznYuQoBp0YIUT7EeMonCPKUvFS.jpg'),
(156222, 11083, 'Jornada nas Estrelas A Nova Missao S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/435586.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/onbpjydhT7ZSui58fMhg5mpKgof.jpg'),
(156223, 11083, 'Jornada nas Estrelas A Nova Missao S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/435587.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u4b2fTgcvBZXOWYmf1MHcv3wKRG.jpg'),
(156224, 11083, 'Jornada nas Estrelas A Nova Missao S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/435588.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iitCTRkxL9UUUnQfPGbbpVvecMs.jpg'),
(156225, 11083, 'Jornada nas Estrelas A Nova Missao S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/435589.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tPGjpfoBgz3zuTb5iRdJCbp2NJ7.jpg'),
(156226, 11083, 'Jornada nas Estrelas A Nova Missao S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/435590.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r9oMjvFZXGzu4y7DxeZ6CYzJEXf.jpg'),
(156227, 11083, 'Jornada nas Estrelas A Nova Missao S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/435591.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c9NXJINKNsivw9hGJC809pttKv0.jpg'),
(156228, 11083, 'Jornada nas Estrelas A Nova Missao S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/435592.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/FhDLV2OYqPXFcrK6T0m0ZAiy4z.jpg'),
(156229, 11083, 'Jornada nas Estrelas A Nova Missao S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/435593.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ihgsoGyV1p6eAandPAoExbGqgPv.jpg'),
(156230, 11083, 'Jornada nas Estrelas A Nova Missao S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/435594.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lIIclVSiFDKAOEzacyOwamt8Cqi.jpg'),
(156231, 11083, 'Jornada nas Estrelas A Nova Missao S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/435595.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wjYYd2FUWgWUgJxMfB8RYDIBxe6.jpg'),
(156232, 11083, 'Jornada nas Estrelas A Nova Missao S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/435596.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w8LHd30Yq5NG6KBOhjBGMl9Xr2O.jpg'),
(156233, 11083, 'Jornada nas Estrelas A Nova Missao S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/435597.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vkpwhDDrwnBenl0bf7X1zj8AnrW.jpg'),
(156234, 11083, 'Jornada nas Estrelas A Nova Missao S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/435598.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rLC4f0LcMIrIM7v9whN6vZLyK6T.jpg'),
(156235, 11083, 'Jornada nas Estrelas A Nova Missao S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/435599.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3nB2ZXnzAqMMAM3KmRMe9C4J2z0.jpg'),
(156236, 11083, 'Jornada nas Estrelas A Nova Missao S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/435600.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vOu5NwdySLKhcojBMFapn1CAsiX.jpg'),
(156237, 11084, 'Jornada nas Estrelas A Nova Missao S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435601.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/srF3LqwdqQMKy48wNVzUmYERmYG.jpg'),
(156238, 11084, 'Jornada nas Estrelas A Nova Missao S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435602.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eDNNz9Thlb55vg2w0TpxpR82phD.jpg'),
(156239, 11084, 'Jornada nas Estrelas A Nova Missao S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435603.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uD9c1a45eidFo8X4kEnMJdflhUI.jpg'),
(156240, 11084, 'Jornada nas Estrelas A Nova Missao S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435604.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/be2qiy7dsflPTlwD5slpm7Iix4q.jpg'),
(156241, 11084, 'Jornada nas Estrelas A Nova Missao S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435605.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z1nnJwt2rVkqo2567PB1VqYV03F.jpg'),
(156242, 11084, 'Jornada nas Estrelas A Nova Missao S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435606.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yssoUu4jL5YyNwc6R5FW56LdQHG.jpg'),
(156243, 11084, 'Jornada nas Estrelas A Nova Missao S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/435607.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gXx0S2noP5e0noRv5OuXmqREbMo.jpg'),
(156244, 11084, 'Jornada nas Estrelas A Nova Missao S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/435608.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qJsrOCn7CLDwqlICVh2wPg4UdSc.jpg'),
(156245, 11084, 'Jornada nas Estrelas A Nova Missao S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/435609.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yoNxCYvDZmnvhkYJd2JleUpF1Rj.jpg'),
(156246, 11084, 'Jornada nas Estrelas A Nova Missao S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/435610.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z4DuTUNHUUbwwH8t48H9r6XwUKw.jpg'),
(156247, 11084, 'Jornada nas Estrelas A Nova Missao S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/435611.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bww1cfWaVs0awRqXtLqhdTG0aPe.jpg'),
(156248, 11084, 'Jornada nas Estrelas A Nova Missao S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/435612.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cS4CXU8qxXOakoWkPwDqXeKwkUp.jpg'),
(156249, 11084, 'Jornada nas Estrelas A Nova Missao S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/435613.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l1H07nI6ZRg4ufXLBz6fcaAS7fZ.jpg'),
(156250, 11084, 'Jornada nas Estrelas A Nova Missao S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/435614.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5J197bdTQUhUfIwumexwGM6czZw.jpg'),
(156251, 11084, 'Jornada nas Estrelas A Nova Missao S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/435615.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t5dXoXqVjbO7P7cnI8PJHZr3Pmu.jpg'),
(156252, 11084, 'Jornada nas Estrelas A Nova Missao S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/435616.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2hMUuYTQ4B0CAZ0Pg2KnJPOuliD.jpg'),
(156253, 11084, 'Jornada nas Estrelas A Nova Missao S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/435617.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/np7ro1PxbbfTMybDU6Gy468Qomw.jpg'),
(156254, 11084, 'Jornada nas Estrelas A Nova Missao S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/435618.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/151vP0a71fOSTUypKI9izhM3rWI.jpg'),
(156255, 11084, 'Jornada nas Estrelas A Nova Missao S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/435619.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2p8N2S93jtyKtGGPgaQHBQRhTlL.jpg'),
(156256, 11084, 'Jornada nas Estrelas A Nova Missao S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/435620.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l5hhJQRDc7mHkSpqhyyOKwWRdUI.jpg'),
(156257, 11084, 'Jornada nas Estrelas A Nova Missao S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/435621.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/amkEiZIyojY7I5IyL0IQCU6AOpu.jpg'),
(156258, 11084, 'Jornada nas Estrelas A Nova Missao S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/435622.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4OcmzJWQ1PUSUqX8TKmq6IpBVri.jpg'),
(156259, 11084, 'Jornada nas Estrelas A Nova Missao S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/435623.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2jKhIUdUIfrarDxJHmZccjs6v21.jpg'),
(156260, 11084, 'Jornada nas Estrelas A Nova Missao S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/435624.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gOnay6TCCCih05EA1kYSS3NhQMJ.jpg'),
(156261, 11084, 'Jornada nas Estrelas A Nova Missao S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/435625.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1OE78mBIRwifwEFGYfKJRENpqLa.jpg'),
(156262, 11084, 'Jornada nas Estrelas A Nova Missao S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/435626.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6WOXFRRmppuce2yMWQO6z2YazZ5.jpg'),
(156263, 11085, 'Jornada nas Estrelas A Nova Missao S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435627.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mIpfHCodrdPGkAQz3b2gAS1sVA2.jpg'),
(156264, 11085, 'Jornada nas Estrelas A Nova Missao S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435628.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fTwXDhximjfRbvl9LgLJSHDxo76.jpg'),
(156265, 11085, 'Jornada nas Estrelas A Nova Missao S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435629.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wGU7ZLJwkyaok3zvdE1PSlADP7l.jpg'),
(156266, 11085, 'Jornada nas Estrelas A Nova Missao S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435630.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f8T7l0IW74wUGpGlmbPXeLM6OZZ.jpg'),
(156267, 11085, 'Jornada nas Estrelas A Nova Missao S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435631.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d3hHh1Xi9Lr8wuTRXVo0zmFGdLP.jpg'),
(156268, 11085, 'Jornada nas Estrelas A Nova Missao S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435632.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gJKqCG5g7jXVJvxEYcRP93nJYbk.jpg'),
(156269, 11085, 'Jornada nas Estrelas A Nova Missao S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/435633.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/or8SE2EFTIbd0tj8DI8efoO9J0z.jpg'),
(156270, 11085, 'Jornada nas Estrelas A Nova Missao S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/435634.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j2tuTdTt2YIlskXDJbZTvnTRBvM.jpg'),
(156271, 11085, 'Jornada nas Estrelas A Nova Missao S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/435635.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6rZyFxp2FYe94ntxbAtK0ldvbmr.jpg'),
(156272, 11085, 'Jornada nas Estrelas A Nova Missao S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/435636.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6IJOMPtRXaI3EwZtaKvCpMjIQ3Y.jpg'),
(156273, 11085, 'Jornada nas Estrelas A Nova Missao S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/435637.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qLMyd2dSdk1FFR0mvJKMSrKqoJJ.jpg'),
(156274, 11085, 'Jornada nas Estrelas A Nova Missao S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/435638.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qy8y4HY9xOS3IJQAadrZY8N5s97.jpg'),
(156275, 11085, 'Jornada nas Estrelas A Nova Missao S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/435639.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6dIa7jJPD9SYsfws72OTXHVjMaM.jpg'),
(156276, 11085, 'Jornada nas Estrelas A Nova Missao S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/435640.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jEdIEbmA6440KUeLKwrUFmCPkTU.jpg'),
(156277, 11085, 'Jornada nas Estrelas A Nova Missao S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/435641.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ddoGPkgAKjLtuuxxKdJsX43IzWG.jpg'),
(156278, 11085, 'Jornada nas Estrelas A Nova Missao S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/435642.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/by8RuxKHdschlzja4Wmeg9krPyl.jpg'),
(156279, 11085, 'Jornada nas Estrelas A Nova Missao S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/435643.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oR0SO8XV12vOugpapWSfBN9ka38.jpg'),
(156280, 11085, 'Jornada nas Estrelas A Nova Missao S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/435644.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8Er6w167CqK6Xpvt1X2YihXqBvf.jpg'),
(156281, 11085, 'Jornada nas Estrelas A Nova Missao S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/435645.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6kL0xbhsgeGdnWhN48u1AaFFPEv.jpg'),
(156282, 11085, 'Jornada nas Estrelas A Nova Missao S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/435646.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m5kyjkbkgJvteeEPkU4Ii8skfE.jpg'),
(156283, 11085, 'Jornada nas Estrelas A Nova Missao S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/435647.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dOd8DuRNSBX7crQrTMX7Y7yhKUh.jpg'),
(156284, 11085, 'Jornada nas Estrelas A Nova Missao S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/435648.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vXtLU5TJ5M0A6G7P2bHS8vftrYg.jpg'),
(156285, 11085, 'Jornada nas Estrelas A Nova Missao S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/435649.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tSMcoQwIZyZOhMve5iGrUWyQQ49.jpg'),
(156286, 11085, 'Jornada nas Estrelas A Nova Missao S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/435650.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mzY9XdAzsXTqmJjmAZ4kwiK9Smr.jpg'),
(156287, 11085, 'Jornada nas Estrelas A Nova Missao S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/435651.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gjO4POsg6Y4VianTjFBFZiRkB2T.jpg'),
(156288, 11086, 'Jornada nas Estrelas A Nova Missao S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435652.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/npYezS5OoXL9m2DqRqX3Wss4BMD.jpg'),
(156289, 11086, 'Jornada nas Estrelas A Nova Missao S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435653.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fCzxkLlC8u3jjTRFPbeCk4xyMRz.jpg'),
(156290, 11086, 'Jornada nas Estrelas A Nova Missao S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435654.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4TWimZ5RkDhIykzmvZs6pSQO3Vu.jpg'),
(156291, 11086, 'Jornada nas Estrelas A Nova Missao S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435655.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4wGGcu4Ye9VTtiqGXD3O3frrwta.jpg'),
(156292, 11086, 'Jornada nas Estrelas A Nova Missao S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435656.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/db9TZIDg3kr4FDKnS0OqWdBKODe.jpg'),
(156293, 11086, 'Jornada nas Estrelas A Nova Missao S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435657.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ynmX0XKDzCLhKCK313GeoPCFGY7.jpg'),
(156294, 11086, 'Jornada nas Estrelas A Nova Missao S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/435658.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2ozNCbv9rwdCpnylbB1IMlgizR5.jpg'),
(156295, 11086, 'Jornada nas Estrelas A Nova Missao S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/435659.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/neCH7EgAIWlQOx2hSYjEglZ7wu3.jpg'),
(156296, 11086, 'Jornada nas Estrelas A Nova Missao S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/435660.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eHh8pp6qru5hYsObSEJEql9uycS.jpg'),
(156297, 11086, 'Jornada nas Estrelas A Nova Missao S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/435661.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i5i2qkhJb0nQxfoq033MTIRlA7H.jpg'),
(156298, 11086, 'Jornada nas Estrelas A Nova Missao S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/435662.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cscjoxHi68XgGOwuqSxI9QZp47G.jpg'),
(156299, 11086, 'Jornada nas Estrelas A Nova Missao S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/435663.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pUU4nheo3ceInsQjDxzlxJUHQen.jpg'),
(156300, 11086, 'Jornada nas Estrelas A Nova Missao S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/435664.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zYnVwdpHMyU14EO7xaHYwAM2m7j.jpg'),
(156301, 11086, 'Jornada nas Estrelas A Nova Missao S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/435665.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/koxFcpl2RcNrumaLEPZnHQ148rz.jpg'),
(156302, 11086, 'Jornada nas Estrelas A Nova Missao S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/435666.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2Y9bs88x084hpJpjxDGfFbYunhr.jpg'),
(156303, 11086, 'Jornada nas Estrelas A Nova Missao S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/435667.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/81MaxB5kjG3O2jgas3M6VhLNLxV.jpg'),
(156304, 11086, 'Jornada nas Estrelas A Nova Missao S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/435668.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nCmObdcGpTAmLT0jBgFmxuEUkzP.jpg'),
(156305, 11086, 'Jornada nas Estrelas A Nova Missao S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/435669.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h9E5tGshKyO2m0MJGn3ueHShym4.jpg'),
(156306, 11086, 'Jornada nas Estrelas A Nova Missao S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/435670.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/esKHoTnJvizyRDjLoGpM60P0ecg.jpg'),
(156307, 11086, 'Jornada nas Estrelas A Nova Missao S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/435671.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sMQyv9TQy1hgC46BAvki1eeK6IF.jpg'),
(156308, 11086, 'Jornada nas Estrelas A Nova Missao S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/435672.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9mJPnBUlJeTZu7LEk141QOkhNtO.jpg'),
(156309, 11086, 'Jornada nas Estrelas A Nova Missao S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/435673.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m4qLN9PDXRtzzydU35DrfRkhc5X.jpg'),
(156310, 11086, 'Jornada nas Estrelas A Nova Missao S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/435674.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kaXH7VT7zRMbs304ckIwArpP5sh.jpg'),
(156311, 11086, 'Jornada nas Estrelas A Nova Missao S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/435675.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1Qj5tfyLEUZR2anQk2CjEjFaVNB.jpg'),
(156312, 11086, 'Jornada nas Estrelas A Nova Missao S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/435676.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qnxejw5FiLFtQ8nYIcMKjdRGxZa.jpg'),
(156313, 11086, 'Jornada nas Estrelas A Nova Missao S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/435677.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vLVON7ZD2s0QIJiijpZMwHHde5K.jpg'),
(156314, 11087, 'Jornada nas Estrelas A Nova Missao S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435678.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5BBBr2735Dn69todi54U0Rzhq3v.jpg'),
(156315, 11087, 'Jornada nas Estrelas A Nova Missao S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435679.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c2AD0e21UV4O3ZFrHFvzT3JS90q.jpg'),
(156316, 11087, 'Jornada nas Estrelas A Nova Missao S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435680.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oPuxur6J59GPW9IABo3MkLdnDrF.jpg'),
(156317, 11087, 'Jornada nas Estrelas A Nova Missao S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435681.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aD1UV1E9BMUxAB9Xlz5lasJpPpq.jpg'),
(156318, 11087, 'Jornada nas Estrelas A Nova Missao S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435682.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cRiLhx5UoHQBlJiS5IkY4a3ZYfE.jpg'),
(156319, 11087, 'Jornada nas Estrelas A Nova Missao S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435683.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5k0sasNCx3qrcxCJSA0hmHP7d8B.jpg'),
(156320, 11087, 'Jornada nas Estrelas A Nova Missao S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/435684.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jxSB5Rscpa2Bu1ghaLrgOAxx5yS.jpg'),
(156321, 11087, 'Jornada nas Estrelas A Nova Missao S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/435685.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iSpBc4yWn5UBiqVe8gZgXfRgraU.jpg'),
(156322, 11087, 'Jornada nas Estrelas A Nova Missao S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/435686.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zxecGLyziOa2PD4d9Jny76XxYCG.jpg'),
(156323, 11087, 'Jornada nas Estrelas A Nova Missao S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/435687.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7cRgQNNOnSa47807WnJKYqTqzCl.jpg'),
(156324, 11087, 'Jornada nas Estrelas A Nova Missao S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/435688.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/obiV0OYUO1BkgdNfQQ1QepefNFh.jpg'),
(156325, 11087, 'Jornada nas Estrelas A Nova Missao S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/435689.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9aGK6GLOnDkhkO4nyyAih2pS7P7.jpg'),
(156326, 11087, 'Jornada nas Estrelas A Nova Missao S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/435690.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t941ILvw9YGeMr6krJkcSqTqE8L.jpg'),
(156327, 11087, 'Jornada nas Estrelas A Nova Missao S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/435691.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uvQgNvQrY04NXrRRbHY4bv40Awe.jpg'),
(156328, 11087, 'Jornada nas Estrelas A Nova Missao S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/435692.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z3sApI3T5JCSPhCa0CHIiwmHGu8.jpg'),
(156329, 11087, 'Jornada nas Estrelas A Nova Missao S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/435693.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oEWVaKddfF9XpzcfytLXNv4fCP1.jpg'),
(156330, 11087, 'Jornada nas Estrelas A Nova Missao S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/435694.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p1Gym85sDzUpRBUbQExZBaCIcvK.jpg'),
(156331, 11087, 'Jornada nas Estrelas A Nova Missao S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/435695.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wIGVw1PdRFZfRV83EWvCOh8Lcsc.jpg'),
(156332, 11087, 'Jornada nas Estrelas A Nova Missao S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/435696.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jPxS2t9kBd8Tx9c7Po58hhSkmO2.jpg'),
(156333, 11087, 'Jornada nas Estrelas A Nova Missao S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/435697.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xORkXotAId5pFYdY44MPuKMOEmv.jpg'),
(156334, 11087, 'Jornada nas Estrelas A Nova Missao S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/435698.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3eyRYuhVVUoOnaiwbgducPOwRf5.jpg'),
(156335, 11087, 'Jornada nas Estrelas A Nova Missao S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/435699.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/95jD2j401ZiCO21lZNNEQK82HTe.jpg'),
(156336, 11087, 'Jornada nas Estrelas A Nova Missao S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/435700.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qnGTWQ4XafGRxkAtzKfFARUwcvI.jpg'),
(156337, 11087, 'Jornada nas Estrelas A Nova Missao S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/435701.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/18hszEqdAFznUsKOMas7PPT2Hj7.jpg'),
(156338, 11087, 'Jornada nas Estrelas A Nova Missao S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/435702.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vdlfsxRjQhgcqPbqs6MTmGvnzkn.jpg'),
(156339, 11087, 'Jornada nas Estrelas A Nova Missao S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/435703.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qiQnPGCEaJ03BP53UcKwZZ9mJSx.jpg'),
(156340, 11088, 'Jornada nas Estrelas A Nova Missao S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435704.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mWJEcuJeCLqa1o31KIoEczyREXw.jpg'),
(156341, 11088, 'Jornada nas Estrelas A Nova Missao S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435705.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9M3e2wcbZoVIwqNoBPPG2d1WpIm.jpg'),
(156342, 11088, 'Jornada nas Estrelas A Nova Missao S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435706.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p8MpRIjHUBE0H7vCiLRhMhHNCeB.jpg'),
(156343, 11088, 'Jornada nas Estrelas A Nova Missao S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435707.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1p8O9zin1737X5F4QmQq9lBfC38.jpg'),
(156344, 11088, 'Jornada nas Estrelas A Nova Missao S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435708.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1ZHTON1JjNcEdakJ438I4bSjLCc.jpg'),
(156345, 11088, 'Jornada nas Estrelas A Nova Missao S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435709.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aaNVkpauWDqaxx48pLvMEd5pirr.jpg'),
(156346, 11088, 'Jornada nas Estrelas A Nova Missao S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/435710.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1LtGEFRXBE7IyWuAfXXTrEDSw6m.jpg'),
(156347, 11088, 'Jornada nas Estrelas A Nova Missao S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/435711.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2k3imQ6eX4EYjpfCUXhBqTG74nH.jpg'),
(156348, 11088, 'Jornada nas Estrelas A Nova Missao S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/435712.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1n6cmySouzQyNRCPTu6Xnkgtxjn.jpg'),
(156349, 11088, 'Jornada nas Estrelas A Nova Missao S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/435713.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hoOElm963tzeeLFz5edVoFnHOC4.jpg'),
(156350, 11088, 'Jornada nas Estrelas A Nova Missao S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/435714.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uQjXNgxPwM7SQyn1gu3qxWq192j.jpg'),
(156351, 11088, 'Jornada nas Estrelas A Nova Missao S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/435715.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qk4MvoUpbKgRAsUlmvY1BmZeUFV.jpg'),
(156352, 11088, 'Jornada nas Estrelas A Nova Missao S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/435716.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nIBzlpq1xUtv2Js3B6dRiFb3cbd.jpg'),
(156353, 11088, 'Jornada nas Estrelas A Nova Missao S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/435717.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8hirexcUy0PjiTRJdYiWl6R6vft.jpg'),
(156354, 11088, 'Jornada nas Estrelas A Nova Missao S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/435718.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4zBViaLCOM3yDxHlMke1az5Jt6T.jpg'),
(156355, 11088, 'Jornada nas Estrelas A Nova Missao S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/435719.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hrAtNjoedbOaTXaYGSci07KcB5P.jpg'),
(156356, 11088, 'Jornada nas Estrelas A Nova Missao S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/435720.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5PMcQItW2wo09eYhj54d9LHwFjv.jpg'),
(156357, 11088, 'Jornada nas Estrelas A Nova Missao S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/435721.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dEYYBx7WmNPQSW2U3IPHAjhONDU.jpg'),
(156358, 11088, 'Jornada nas Estrelas A Nova Missao S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/435722.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hSBKSQnqguBwbfulgBmPJTsg6nM.jpg'),
(156359, 11088, 'Jornada nas Estrelas A Nova Missao S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/435723.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lUasgfkzAmjLTB1g3OhmTGr94Oa.jpg'),
(156360, 11088, 'Jornada nas Estrelas A Nova Missao S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/435724.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1RC3MshHzzK6a29t241I2LTHZQL.jpg'),
(156361, 11088, 'Jornada nas Estrelas A Nova Missao S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/435725.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jEN71VXLrWC89qlNVf4oVEZcW0c.jpg'),
(156362, 11088, 'Jornada nas Estrelas A Nova Missao S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/435726.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jOVQrzaHUob2Fhru939RSwjhLLN.jpg'),
(156363, 11088, 'Jornada nas Estrelas A Nova Missao S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/435727.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1vpXHkqjtiDh1shzFcUXPVKYwwJ.jpg'),
(156364, 11088, 'Jornada nas Estrelas A Nova Missao S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/435728.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6jtutQH9WN0C5CNUnoZyYNK6BSA.jpg'),
(156365, 11089, 'Kengan Ashura S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435729.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sv9r4DxljoGvvMFPnsjKuUOavtV.jpg'),
(156366, 11089, 'Kengan Ashura S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435730.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8GIeAvmUnSEAb0XD2YbilPYEWOL.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(156367, 11089, 'Kengan Ashura S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435731.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bisgbPavdbnckd04hErAc7rwwoF.jpg'),
(156368, 11089, 'Kengan Ashura S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435732.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v1qeKwTi8aKvHESjSgAYi19sxXf.jpg'),
(156369, 11089, 'Kengan Ashura S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435733.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5tI95ZP9ddEYHBnvfh3VjbIkgCa.jpg'),
(156370, 11089, 'Kengan Ashura S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435734.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ejjc88RetY9MMWMeB7CsNPSEEv3.jpg'),
(156371, 11089, 'Kengan Ashura S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/435735.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5lND5x5CBHAFxi5qxz40GRAHX2o.jpg'),
(156372, 11089, 'Kengan Ashura S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/435736.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sPZ5OvIy8wo6IR3PePNanze1mu6.jpg'),
(156373, 11089, 'Kengan Ashura S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/435737.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ophObhUojn7Y00Ltkv2bqfxa466.jpg'),
(156374, 11089, 'Kengan Ashura S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/435738.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v3cyeBTQCezHgNxbvcxawp2MrOe.jpg'),
(156375, 11089, 'Kengan Ashura S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/435739.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j2P3RqMJ55EFq6paGeUrBtUK4VB.jpg'),
(156376, 11089, 'Kengan Ashura S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/435740.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mNaoUhhKfkOZTaJWOfGXzetspSH.jpg'),
(156377, 11089, 'Kengan Ashura S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/435741.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8eGSHBqJwdDZYfnE0pUOaUe8Ggz.jpg'),
(156378, 11089, 'Kengan Ashura S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/435742.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bGuYwftM5lp7ch3nJvfp6TOangk.jpg'),
(156379, 11089, 'Kengan Ashura S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/435743.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s5az4gqNK7gHlIjCPiCUjFWSvjh.jpg'),
(156380, 11089, 'Kengan Ashura S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/435744.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wODwUGbU2VEQ3Y7uczC3whHAdOZ.jpg'),
(156381, 11089, 'Kengan Ashura S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/435745.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sKyxqVR2UVis0mpmF09yPU7jcuI.jpg'),
(156382, 11089, 'Kengan Ashura S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/435746.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bN49nDXhwILNuJyyWHi1ZyF7jT0.jpg'),
(156383, 11089, 'Kengan Ashura S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/435747.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mrmWsstoxohJm3fEnUB3iuJS6DN.jpg'),
(156384, 11089, 'Kengan Ashura S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/435748.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ltidECvVl2VJRDEtpgbTu9h0VpU.jpg'),
(156385, 11089, 'Kengan Ashura S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/435749.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cnR6RcxF4GE3ZmDHwEEghgdOz4a.jpg'),
(156386, 11089, 'Kengan Ashura S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/435750.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qNGab174Cb5TX2f6xpWls4WSjoG.jpg'),
(156387, 11089, 'Kengan Ashura S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/435751.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r46ZZCcKumbhKXPUeQn2zS0tVV8.jpg'),
(156388, 11089, 'Kengan Ashura S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/435752.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nxIEEzjSJCyNvIhlEFzbIYxny63.jpg'),
(156389, 11090, 'Kengan Ashura S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435753.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4ySRuLVN46nzlLho4JPd7VP7DHS.jpg'),
(156390, 11090, 'Kengan Ashura S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435754.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/XK1cj8ea6w0UrF4vxMOEkvKlxD.jpg'),
(156391, 11090, 'Kengan Ashura S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435755.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/38A3yCuFWXEOsz0oFAoWRkivNTE.jpg'),
(156392, 11090, 'Kengan Ashura S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/435756.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lxadimirdoDDUWtVnd5FhVmfPKr.jpg'),
(156393, 11090, 'Kengan Ashura S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/435757.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jN9bgPWkWM6O1rkLaEZTcIuSO1O.jpg'),
(156394, 11090, 'Kengan Ashura S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/435758.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5dF21M6s6tylVbygnLlxjE0VxWa.jpg'),
(156395, 11090, 'Kengan Ashura S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/435759.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qeNfXkXLb6LlHklpZAS5Rk1O36K.jpg'),
(156396, 11090, 'Kengan Ashura S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/435760.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b5DzMsieV17wLLoa1dS2DpWrG0s.jpg'),
(156397, 11090, 'Kengan Ashura S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/435761.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kE8JjvWhZM1i5LfVvKlQsQbo6NS.jpg'),
(156398, 11090, 'Kengan Ashura S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/435762.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8Pnt20MmG9xuu0sL16QCNVIyChp.jpg'),
(156399, 11090, 'Kengan Ashura S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/435763.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pIH7QqcqjVZ4U5sCM4cCmACtWV6.jpg'),
(156400, 11090, 'Kengan Ashura S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/435764.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/swUIwWoHsmUJ5GFf34E2TKFKgeP.jpg'),
(156401, 11090, 'Kengan Ashura S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/435765.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dqDIiM99Fb9lSXxyuizFUnd5QLo.jpg'),
(156402, 11090, 'Kengan Ashura S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/435766.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y8dSn25dm2dPTMkHQfdlupDS4iZ.jpg'),
(156403, 11090, 'Kengan Ashura S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/435767.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g0ZLA7RKglaABIlEaxS5TVFt55i.jpg'),
(156404, 11090, 'Kengan Ashura S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/435768.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pQmvkkggI5mOUZVwyCSFnLgDJRf.jpg'),
(156405, 11090, 'Kengan Ashura S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/435769.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ln5BRamYKGUAvJH9X6ScQqsHfXF.jpg'),
(156406, 11090, 'Kengan Ashura S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/435770.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3yThPstqwfFpZCa3Wl5NxWC7HnC.jpg'),
(156407, 11090, 'Kengan Ashura S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/435771.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zAM4skQJV4Cerw4Rll7Z258CyW1.jpg'),
(156408, 11090, 'Kengan Ashura S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/435772.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mW25QZshc3fcuU2uM3zj3lctRgM.jpg'),
(156409, 11090, 'Kengan Ashura S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/435773.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xrAID8PvJISmwnYOctyeVNh6ypx.jpg'),
(156410, 11090, 'Kengan Ashura S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/435774.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a2AAzLPUO6VWcxOR1yDhpoQgdlw.jpg'),
(156411, 11090, 'Kengan Ashura S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/435775.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w6jZckc3KtJDhFgLiuxRTqoVSNg.jpg'),
(156412, 11090, 'Kengan Ashura S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/435776.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pYiLbDarh9IN2qY27iq0NQp6i6Q.jpg'),
(156413, 11090, 'Kengan Ashura S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/435777.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q53suHyvIY42x9J60MPabxGAXXH.jpg'),
(156414, 11090, 'Kengan Ashura S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/435778.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qX4tp6Y72glu60HocZjTdYkaurD.jpg'),
(156415, 11090, 'Kengan Ashura S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/435779.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2r1HrUTZhkJXeQvBNnLtvhZgczq.jpg'),
(156416, 11090, 'Kengan Ashura S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/435780.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pSyEs1CYAnVNa1OKHDcbTPiP5er.jpg'),
(156417, 11091, 'Wistoria Wand and Sword S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/435781.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ieLlWMtF5bi7DlyJITf21k6Cu3P.jpg'),
(156418, 11091, 'Wistoria Wand and Sword S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/435782.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tcPyVm1aOyBzsKrlYAdDRu5srew.jpg'),
(156419, 11091, 'Wistoria Wand and Sword S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/435783.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7t1iPH7vjBBKTTpNKZi4hBDBEps.jpg'),
(156420, 11091, 'Wistoria Wand and Sword S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iwKgHwuzru7MaSVdFr3RaRdCd9L.jpg'),
(156421, 11091, 'Wistoria Wand and Sword S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iwKgHwuzru7MaSVdFr3RaRdCd9L.jpg'),
(156422, 11091, 'Wistoria Wand and Sword S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/454073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iwKgHwuzru7MaSVdFr3RaRdCd9L.jpg'),
(156423, 11091, 'Wistoria Wand and Sword S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/463380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iwKgHwuzru7MaSVdFr3RaRdCd9L.jpg'),
(156424, 11091, 'Wistoria Wand and Sword S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/468576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iwKgHwuzru7MaSVdFr3RaRdCd9L.jpg'),
(156425, 11091, 'Wistoria Wand and Sword S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/471221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iwKgHwuzru7MaSVdFr3RaRdCd9L.jpg'),
(156426, 11091, 'Wistoria Wand and Sword S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/484737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iwKgHwuzru7MaSVdFr3RaRdCd9L.jpg'),
(156427, 11091, 'Wistoria Wand and Sword S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/487476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iwKgHwuzru7MaSVdFr3RaRdCd9L.jpg'),
(156428, 11092, 'A Voz Ausente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438197.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gqILfs19kUfAB2FewBrVBDT02IX.jpg'),
(156429, 11092, 'A Voz Ausente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438198.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f7ZckbKnWSg6kygOebiNyN9wNJE.jpg'),
(156430, 11092, 'A Voz Ausente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438199.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aWIwNc1JxMdOA9IMe58HVKGfACe.jpg'),
(156431, 11092, 'A Voz Ausente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438200.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q6nsDnH194ycrHRbRbyNYDp5s0D.jpg'),
(156432, 11092, 'A Voz Ausente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438201.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6ogd2jM3cwyUJ71PXEImpLbb9vf.jpg'),
(156433, 11092, 'A Voz Ausente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438202.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gzFsaracrUXXMgzRV8vluqt7EE3.jpg'),
(156434, 11092, 'A Voz Ausente S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/438203.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yYFLLXiFWpaTdqmC2pl4sVDEWH6.jpg'),
(156435, 11093, 'Amada e Ultrajada O Exercito na Historia do Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cvfkZNHNWCQAjBnCBeI4yYeeBpO.jpg'),
(156436, 11093, 'Amada e Ultrajada O Exercito na Historia do Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cvfkZNHNWCQAjBnCBeI4yYeeBpO.jpg'),
(156437, 11093, 'Amada e Ultrajada O Exercito na Historia do Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/510119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cvfkZNHNWCQAjBnCBeI4yYeeBpO.jpg'),
(156438, 11094, 'Cidade de Deus A Luta Nao Para S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bROpzy08O9nSyfDgBUlgUoMp9nw.jpg'),
(156439, 11094, 'Cidade de Deus A Luta Nao Para S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/444806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bROpzy08O9nSyfDgBUlgUoMp9nw.jpg'),
(156440, 11094, 'Cidade de Deus A Luta Nao Para S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/448156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bROpzy08O9nSyfDgBUlgUoMp9nw.jpg'),
(156441, 11094, 'Cidade de Deus A Luta Nao Para S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/456338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bROpzy08O9nSyfDgBUlgUoMp9nw.jpg'),
(156442, 11094, 'Cidade de Deus A Luta Nao Para S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/461563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bROpzy08O9nSyfDgBUlgUoMp9nw.jpg'),
(156443, 11094, 'Cidade de Deus A Luta Nao Para S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/467790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bROpzy08O9nSyfDgBUlgUoMp9nw.jpg'),
(156444, 11095, 'Depois do Acidente S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438184.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tNb6fr6zUawOsOmEShQ8U2ROuiu.jpg'),
(156445, 11095, 'Depois do Acidente S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438185.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uanSmU1b5q0t9lEWLGPXRJvXzWA.jpg'),
(156446, 11095, 'Depois do Acidente S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438186.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r2fV62knHkdnuUnkdoUFU2o3IPE.jpg'),
(156447, 11095, 'Depois do Acidente S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438187.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hifon9BSFBdSNEnXJTihCrudQjt.jpg'),
(156448, 11095, 'Depois do Acidente S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438188.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gINsGkjpgcKpTmhzmMBRPEuCcNZ.jpg'),
(156449, 11095, 'Depois do Acidente S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438189.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rmshtfp2eOdXEOu0LRySK2s75mm.jpg'),
(156450, 11095, 'Depois do Acidente S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/438190.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/th1xDCjMcCiYSESNUBBcq77qILy.jpg'),
(156451, 11095, 'Depois do Acidente S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/438191.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AtFqaST1qnb9qsRWYrbVFcHzE1H.jpg'),
(156452, 11095, 'Depois do Acidente S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/438192.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6rOsr5zCIGp0igHDPHN0A1yvvjD.jpg'),
(156453, 11095, 'Depois do Acidente S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/438193.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/878d8aUgplMvGqVejwa50WqRszL.jpg'),
(156454, 11096, 'Do Nada Gravida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438172.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fmQ4fP6IdhdedqTHcr3LLYmsgoA.jpg'),
(156455, 11096, 'Do Nada Gravida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438173.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ozMOu6dGN3DqyM80ApGw6WZsapU.jpg'),
(156456, 11096, 'Do Nada Gravida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438174.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sn6jQI111TvDGHbmp4VmJY9svE.jpg'),
(156457, 11096, 'Do Nada Gravida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438175.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8Gd9bnHpXt7EwESy1PIsnsSSND2.jpg'),
(156458, 11096, 'Do Nada Gravida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438176.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nU3kGdDf5VWEJMFsA5DkSo5d1tg.jpg'),
(156459, 11096, 'Do Nada Gravida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438177.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2OOveDBphxne0W4CaeaBAyIXOH5.jpg'),
(156460, 11097, 'Do Nada Gravida S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438178.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kTj14kdBgeV13pL1agsDrrspybQ.jpg'),
(156461, 11097, 'Do Nada Gravida S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438179.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hWeVa1VeAfKvrAZaL1P09d6wGup.jpg'),
(156462, 11097, 'Do Nada Gravida S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438180.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eYSh487FkKbYtROmwmOBPolVnD6.jpg'),
(156463, 11097, 'Do Nada Gravida S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438181.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yT0UOsxkiSgQGaKTR4lGeyznhxQ.jpg'),
(156464, 11097, 'Do Nada Gravida S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438182.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/erR3nfP3KFjsKxwPoAE7v5S9Ddz.jpg'),
(156465, 11097, 'Do Nada Gravida S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438183.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7zNzbGZHgjGyCMBPDb8gcAkL42F.jpg'),
(156466, 11098, 'O Misterio de Midwich S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/437991.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yCLjQljbMc1ENThG1znltK1vHzN.jpg'),
(156467, 11098, 'O Misterio de Midwich S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/437992.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b3Dgggmp6ZtNEQZX10Uay4czFv5.jpg'),
(156468, 11098, 'O Misterio de Midwich S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/437993.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wB0Lmgfcsrmg9wPHZoLucEstidK.jpg'),
(156469, 11098, 'O Misterio de Midwich S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/437994.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ujfKb9XZeb2cpdI6OA2439g4pbl.jpg'),
(156470, 11098, 'O Misterio de Midwich S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/437995.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hbbNlbFurO5fVbK2utUVkyz5JER.jpg'),
(156471, 11098, 'O Misterio de Midwich S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/437996.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7amq1pqwTV3oYbjTJY7tc1oYcdi.jpg'),
(156472, 11098, 'O Misterio de Midwich S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/437997.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/laf65TjdpwtLTcnPB5iM2DbGyXt.jpg'),
(156473, 11099, 'O Picapau Amarelo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/437976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156474, 11099, 'O Picapau Amarelo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/437977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156475, 11099, 'O Picapau Amarelo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/437978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156476, 11099, 'O Picapau Amarelo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/437979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156477, 11099, 'O Picapau Amarelo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/437980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156478, 11099, 'O Picapau Amarelo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/437981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156479, 11099, 'O Picapau Amarelo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/437982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156480, 11099, 'O Picapau Amarelo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/437983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156481, 11099, 'O Picapau Amarelo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/437984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156482, 11099, 'O Picapau Amarelo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/437985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156483, 11099, 'O Picapau Amarelo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/437986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156484, 11099, 'O Picapau Amarelo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/437987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156485, 11099, 'O Picapau Amarelo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/437988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156486, 11099, 'O Picapau Amarelo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/437989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156487, 11099, 'O Picapau Amarelo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/437990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156488, 11100, 'O Picapau Amarelo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/855840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156489, 11100, 'O Picapau Amarelo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/855841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156490, 11100, 'O Picapau Amarelo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/855842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156491, 11100, 'O Picapau Amarelo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/855843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156492, 11100, 'O Picapau Amarelo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/855844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156493, 11100, 'O Picapau Amarelo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/855845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156494, 11100, 'O Picapau Amarelo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/855846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156495, 11100, 'O Picapau Amarelo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/855847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156496, 11100, 'O Picapau Amarelo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/855848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156497, 11100, 'O Picapau Amarelo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/855849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ch7H9ukpika24LEGdpPiAPlQbLm.jpg'),
(156498, 11101, 'OceanXplorers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/437970.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/66GAowsDtz6ULj6reSU2nb6yGeP.jpg'),
(156499, 11101, 'OceanXplorers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/437971.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6V95TKYSU5FmzULKaJv2P4OEIVY.jpg'),
(156500, 11101, 'OceanXplorers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/437972.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2vrT4kZzS66tKnltTK2Yd6XxMwo.jpg'),
(156501, 11101, 'OceanXplorers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/437973.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a2Z1uKH035cQX4DfLnYvumlYEez.jpg'),
(156502, 11101, 'OceanXplorers S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/437974.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/urJ8vQzkHJNJ0RjSwVx7sJlObQW.jpg'),
(156503, 11101, 'OceanXplorers S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/437975.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/61NprmjifJlQ6yJiLY0rYACcve9.jpg'),
(156504, 11102, 'Quando Ninguem Ve S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/437962.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6jRngvqHDrqZkdROvhtWR54DUA7.jpg'),
(156505, 11102, 'Quando Ninguem Ve S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/437963.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ijD9EWoD4vgfZcR5xaz5mzVg0mn.jpg'),
(156506, 11102, 'Quando Ninguem Ve S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/437964.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y3GBGuDu6wyektmAkAjx8fLq8BE.jpg'),
(156507, 11102, 'Quando Ninguem Ve S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/437965.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/et8eNqPYonpQTppKGxOqdLIPFPc.jpg'),
(156508, 11102, 'Quando Ninguem Ve S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/437966.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/atgk328XB1KNfuEZP1j6dWniHs6.jpg'),
(156509, 11102, 'Quando Ninguem Ve S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/437967.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iCmaWNi4b8682vLh9LiTu6xTVIq.jpg'),
(156510, 11102, 'Quando Ninguem Ve S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/437968.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9ElTHHZrIHEQ2Mkwy3MjGuSgnmF.jpg'),
(156511, 11102, 'Quando Ninguem Ve S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/437969.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cFbaDDMtG6FlIJMS8kxXaWjSZ46.jpg'),
(156512, 11103, 'Selena Restaurante S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/437959.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9It0nYd4xUJyYSkz5PLDgl68ol0.jpg'),
(156513, 11103, 'Selena Restaurante S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/437960.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pYfhDI6FWWEep2kYkcbIm4aX1ST.jpg'),
(156514, 11103, 'Selena Restaurante S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/437961.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5L6qydkXeWjsPjVHibiAzr4lP0.jpg'),
(156515, 11103, 'Selena Restaurante S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kHorWbe2Sule1KOpGCkdAEHeie9.jpg'),
(156516, 11103, 'Selena Restaurante S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kHorWbe2Sule1KOpGCkdAEHeie9.jpg'),
(156517, 11103, 'Selena Restaurante S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kHorWbe2Sule1KOpGCkdAEHeie9.jpg'),
(156518, 11104, 'Shakespeare Ascensao de um Genio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/437956.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8Lc8eYTHeYTKwY7UV2MyBOsXPG5.jpg'),
(156519, 11104, 'Shakespeare Ascensao de um Genio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/437957.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6I7iFhC4DtZ7Uwi1uLtgyokv2tD.jpg'),
(156520, 11104, 'Shakespeare Ascensao de um Genio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/437958.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9nOzJH5mC6y2F6BrAYgV9p0R111.jpg'),
(156521, 11105, 'Silvio Santos Vale Mais Que Dinheiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/437952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xh0wwmMykRUPMp8DE4rznDg3yvQ.jpg'),
(156522, 11105, 'Silvio Santos Vale Mais Que Dinheiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/437953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xh0wwmMykRUPMp8DE4rznDg3yvQ.jpg'),
(156523, 11105, 'Silvio Santos Vale Mais Que Dinheiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/437954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xh0wwmMykRUPMp8DE4rznDg3yvQ.jpg'),
(156524, 11105, 'Silvio Santos Vale Mais Que Dinheiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/437955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xh0wwmMykRUPMp8DE4rznDg3yvQ.jpg'),
(156525, 11105, 'Silvio Santos Vale Mais Que Dinheiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/521872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xh0wwmMykRUPMp8DE4rznDg3yvQ.jpg'),
(156526, 11105, 'Silvio Santos Vale Mais Que Dinheiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/521873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xh0wwmMykRUPMp8DE4rznDg3yvQ.jpg'),
(156527, 11105, 'Silvio Santos Vale Mais Que Dinheiro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/521874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xh0wwmMykRUPMp8DE4rznDg3yvQ.jpg'),
(156528, 11105, 'Silvio Santos Vale Mais Que Dinheiro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/521875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xh0wwmMykRUPMp8DE4rznDg3yvQ.jpg'),
(156529, 11106, 'Tenho Que Morrer Todas as Noites S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/437944.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a2XPwOEQ9mqINZ1XliLKJReMVuv.jpg'),
(156530, 11106, 'Tenho Que Morrer Todas as Noites S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/437945.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tNYb5VFrJ8ekoMFYe5UTWcZ8W22.jpg'),
(156531, 11106, 'Tenho Que Morrer Todas as Noites S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/437946.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dtbtghHUl9DS4jY9ihH8N1YwPY2.jpg'),
(156532, 11106, 'Tenho Que Morrer Todas as Noites S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/437947.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oAcY9EkMGIiHOiqN25wEvhdCzBI.jpg'),
(156533, 11106, 'Tenho Que Morrer Todas as Noites S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/437948.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aIaTuoR0pRPhVYnf9LecioSdG8e.jpg'),
(156534, 11106, 'Tenho Que Morrer Todas as Noites S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/437949.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oxEBZegFlDrd0yuuH6QyQp49Lv1.jpg'),
(156535, 11106, 'Tenho Que Morrer Todas as Noites S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/437950.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9h8AD9k4kWz24a9ilFbtIdkanuV.jpg'),
(156536, 11106, 'Tenho Que Morrer Todas as Noites S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/437951.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4xZ4ApimJ5WdvVoRoQNgkzirp7G.jpg'),
(156537, 11107, 'Terca do Terror S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/437936.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/twTDwoTvL1wR2XsV3qXhVbMootS.jpg'),
(156538, 11107, 'Terca do Terror S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/437937.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8i2Ygpj0BtaJzxm5Cqqm5mXIudT.jpg'),
(156539, 11107, 'Terca do Terror S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/437938.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xRK7vEgctFVcNyFITZSj9lU1iUu.jpg'),
(156540, 11107, 'Terca do Terror S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/437939.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8BeJviaAojwWvlFjgPuTgJbPoKw.jpg'),
(156541, 11107, 'Terca do Terror S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/437940.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rOLlRKPxpSM4k8rfF7UoQbcfTLl.jpg'),
(156542, 11107, 'Terca do Terror S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/437941.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i829ORTVds2nGSGyuEaEYqC9Cfm.jpg'),
(156543, 11107, 'Terca do Terror S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/437942.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bvbaTwDlBYiscdqVdY0GuVQR8du.jpg'),
(156544, 11107, 'Terca do Terror S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/437943.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/30HWX8g8rCj22zdPnQU124AU8rq.jpg'),
(156545, 11108, 'Um Distrito do Alem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/437930.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/14O8jJonQWspbl01c9bVaKIky94.jpg'),
(156546, 11108, 'Um Distrito do Alem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/437931.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vyIXLy2lB8glKrvMJA2BJjriUOB.jpg'),
(156547, 11108, 'Um Distrito do Alem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/437932.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s1P29rDHzb5UZu23k09nTM1isO6.jpg'),
(156548, 11108, 'Um Distrito do Alem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/437933.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8wjUZ1mw8ltqPcQ8t7BaZrh0XFT.jpg'),
(156549, 11108, 'Um Distrito do Alem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/437934.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vaNE6lgrszKDNRDmpGsSuo8fBbA.jpg'),
(156550, 11108, 'Um Distrito do Alem S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/437935.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hW1nk3JZff0DNdrjFfEXgzEGg6a.jpg'),
(156551, 11109, 'Vidas Bandidas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/437926.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yUTJeaHKHNnmv4cvKW4on0JDTPX.jpg'),
(156552, 11109, 'Vidas Bandidas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/437927.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/traj4SQq1xkRSp3qFNBLlZPE62r.jpg'),
(156553, 11109, 'Vidas Bandidas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/437928.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/GbjiCvD4p0jXRKQuEqoPONxBLD.jpg'),
(156554, 11109, 'Vidas Bandidas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/437929.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aDVkOuF7KB2F8ID45iIEu6ltGzZ.jpg'),
(156555, 11110, 'ZOMBIES A Serie Reanimada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/437921.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fyzK5EKBRjuTlEvh4HK0VKMxlin.jpg'),
(156556, 11110, 'ZOMBIES A Serie Reanimada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/437922.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vwZ7KrWQtxOdcYATE2hI8vKH6tM.jpg'),
(156557, 11110, 'ZOMBIES A Serie Reanimada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/437923.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jUXBUEzlqlhccQUUidHyEskmVtU.jpg'),
(156558, 11110, 'ZOMBIES A Serie Reanimada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/437924.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w2ApJjJQGZlWfuil8AmsNsS9MuM.jpg'),
(156559, 11110, 'ZOMBIES A Serie Reanimada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/437925.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c6URvLYzwCUTcjdqxeEyiaDpaPv.jpg'),
(156560, 11110, 'ZOMBIES A Serie Reanimada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ejfItAeNXK0rrqU4abt7GY2yHM0.jpg'),
(156561, 11110, 'ZOMBIES A Serie Reanimada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/618548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ejfItAeNXK0rrqU4abt7GY2yHM0.jpg'),
(156562, 11110, 'ZOMBIES A Serie Reanimada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/463401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ejfItAeNXK0rrqU4abt7GY2yHM0.jpg'),
(156563, 11110, 'ZOMBIES A Serie Reanimada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/777044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ejfItAeNXK0rrqU4abt7GY2yHM0.jpg'),
(156564, 11110, 'ZOMBIES A Serie Reanimada S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/463402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ejfItAeNXK0rrqU4abt7GY2yHM0.jpg'),
(156565, 11110, 'ZOMBIES A Serie Reanimada S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/463403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ejfItAeNXK0rrqU4abt7GY2yHM0.jpg'),
(156566, 11110, 'ZOMBIES A Serie Reanimada S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/777047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ejfItAeNXK0rrqU4abt7GY2yHM0.jpg'),
(156567, 11110, 'ZOMBIES A Serie Reanimada S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/777048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ejfItAeNXK0rrqU4abt7GY2yHM0.jpg'),
(156568, 11110, 'ZOMBIES A Serie Reanimada S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/777049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ejfItAeNXK0rrqU4abt7GY2yHM0.jpg'),
(156569, 11110, 'ZOMBIES A Serie Reanimada S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/777050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ejfItAeNXK0rrqU4abt7GY2yHM0.jpg'),
(156570, 11110, 'ZOMBIES A Serie Reanimada S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/777051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ejfItAeNXK0rrqU4abt7GY2yHM0.jpg'),
(156571, 11110, 'ZOMBIES A Serie Reanimada S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/777052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ejfItAeNXK0rrqU4abt7GY2yHM0.jpg'),
(156572, 11110, 'ZOMBIES A Serie Reanimada S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/777053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ejfItAeNXK0rrqU4abt7GY2yHM0.jpg'),
(156573, 11110, 'ZOMBIES A Serie Reanimada S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/777054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ejfItAeNXK0rrqU4abt7GY2yHM0.jpg'),
(156574, 11110, 'ZOMBIES A Serie Reanimada S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/777055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ejfItAeNXK0rrqU4abt7GY2yHM0.jpg'),
(156575, 11111, 'Meu Pai e Inventor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/437905.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AvB6PkRRSzOs3lNlHrSZVocWCgl.jpg'),
(156576, 11111, 'Meu Pai e Inventor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/437906.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bNgj2PTamhIrcc8qQP8g7mtCqan.jpg'),
(156577, 11111, 'Meu Pai e Inventor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/437907.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1OZL6v36VTzutKhpWpSUSQDNOXq.jpg'),
(156578, 11111, 'Meu Pai e Inventor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/437908.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kvOlMw59lCnzp5QKuDKZ5hecMsM.jpg'),
(156579, 11111, 'Meu Pai e Inventor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/437909.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kydpNtmDOBbMzLlTYPlDwoQOIbC.jpg'),
(156580, 11111, 'Meu Pai e Inventor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/437910.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j2b0QsTj3GLus4M8swQmM4NwZZu.jpg'),
(156581, 11111, 'Meu Pai e Inventor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/437911.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/efcMMCfVzfcUx276YTXk1mnKoaQ.jpg'),
(156582, 11111, 'Meu Pai e Inventor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/437912.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m9AughPOJWEIotCTHGdWBTVgLfZ.jpg'),
(156583, 11112, 'Meu Pai e Inventor S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/437913.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aXFWpmFZV10ux303lA0JwqpSZKK.jpg'),
(156584, 11112, 'Meu Pai e Inventor S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/437914.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f3OMud65OX7KsvFMXhW7J0XGIxI.jpg'),
(156585, 11112, 'Meu Pai e Inventor S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/437915.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sHLFcb6DRDgDVyXU9UwWG8xW0M2.jpg'),
(156586, 11112, 'Meu Pai e Inventor S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/437916.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/su5v0BOEomDspZ8KlVQeDwFdqNi.jpg'),
(156587, 11112, 'Meu Pai e Inventor S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/437917.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vXjKUj6iWBv0I7V9LXJQBGVrEaF.jpg'),
(156588, 11112, 'Meu Pai e Inventor S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/437918.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rezeoCZVkRp8WHuZ4kyVyaUlV6v.jpg'),
(156589, 11112, 'Meu Pai e Inventor S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/437919.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uR97txeylXjr51XqBhQanZqiSKZ.jpg'),
(156590, 11112, 'Meu Pai e Inventor S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/437920.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bjrlqTm1P7bEJDYs4vcLcJddUd9.jpg'),
(156591, 11113, 'Rick and Morty The Anime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/437903.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oK3gazjYvlldMqgY2gL0SW3fJfw.jpg'),
(156592, 11113, 'Rick and Morty The Anime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/437904.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ga3ebOfX6NkRhNlGKTJTWn9sTUS.jpg'),
(156593, 11113, 'Rick and Morty The Anime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/441159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7D8imzmWsua7Plk5TRDX6q8M97u.jpg'),
(156594, 11113, 'Rick and Morty The Anime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/450501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7D8imzmWsua7Plk5TRDX6q8M97u.jpg'),
(156595, 11113, 'Rick and Morty The Anime S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/454583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7D8imzmWsua7Plk5TRDX6q8M97u.jpg'),
(156596, 11113, 'Rick and Morty The Anime S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/459302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7D8imzmWsua7Plk5TRDX6q8M97u.jpg'),
(156597, 11113, 'Rick and Morty The Anime S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/466542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7D8imzmWsua7Plk5TRDX6q8M97u.jpg'),
(156598, 11113, 'Rick and Morty The Anime S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/472289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7D8imzmWsua7Plk5TRDX6q8M97u.jpg'),
(156599, 11113, 'Rick and Morty The Anime S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/485212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7D8imzmWsua7Plk5TRDX6q8M97u.jpg'),
(156600, 11113, 'Rick and Morty The Anime S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/488418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7D8imzmWsua7Plk5TRDX6q8M97u.jpg'),
(156601, 11114, 'Um Maluco na TV S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438309.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lRE6OaqZvGgYWq53nFx2HPPWdFW.jpg'),
(156602, 11114, 'Um Maluco na TV S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438310.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lcRoLJ7IXcOv9NgMy8tQmz7Hsl3.jpg'),
(156603, 11114, 'Um Maluco na TV S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438311.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zwbcKRHmD5mUE0hvGbT2LweVsTl.jpg'),
(156604, 11114, 'Um Maluco na TV S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438312.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a3zFmJr7hhuoNnH0Mi9dZe1oZQQ.jpg'),
(156605, 11114, 'Um Maluco na TV S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438313.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pg3Mh6nJhr8sj0xDUHQGFsqtw2n.jpg'),
(156606, 11114, 'Um Maluco na TV S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438314.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ojPUhNy87BMz7Z9B4B5GSJHXED9.jpg'),
(156607, 11114, 'Um Maluco na TV S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/438315.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n1YUGzVgH7xoOMSV5GG7NqqLfpO.jpg'),
(156608, 11114, 'Um Maluco na TV S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/438316.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kVR2mw8ZpcX9YfFRhwaPw5aIcM.jpg'),
(156609, 11114, 'Um Maluco na TV S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/438317.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eNPhRghn0diNmaIHptvPrPQePT.jpg'),
(156610, 11114, 'Um Maluco na TV S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/438318.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1aoJDjqVrxF1ip1iqtsGy2dOUX5.jpg'),
(156611, 11114, 'Um Maluco na TV S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/438319.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5S8RSCxELg0eXLKD0IACO2VB9Ra.jpg'),
(156612, 11114, 'Um Maluco na TV S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/438320.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mOrGUUYOUnHn3YZ0KwdnAEgDK0P.jpg'),
(156613, 11114, 'Um Maluco na TV S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/438321.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8OYaBuPO5Gp54GpHgvpMzRwG6x8.jpg'),
(156614, 11114, 'Um Maluco na TV S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/438322.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hDf9VYdf6NSP0u9pTx2YYPHBosT.jpg'),
(156615, 11114, 'Um Maluco na TV S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/438323.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sOGPeONVYQ6bWS52zwOQP05616n.jpg'),
(156616, 11114, 'Um Maluco na TV S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/438324.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bD50momocIEAZUacR1Zvzr6m0hI.jpg'),
(156617, 11114, 'Um Maluco na TV S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/438325.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rbrGunIYnFxiVKVnZJUNzm5WdPH.jpg'),
(156618, 11114, 'Um Maluco na TV S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/438326.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4VvB6Tr93ES4elJoxmIMCmKYJzB.jpg'),
(156619, 11114, 'Um Maluco na TV S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/438327.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zu30il0ifPwbI8LLoEox5eOYzBV.jpg'),
(156620, 11114, 'Um Maluco na TV S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/438328.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kuLdoiqFTsaS36bb4UFo7kw3jp6.jpg'),
(156621, 11114, 'Um Maluco na TV S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/438329.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sTnET9GBF4VIwFx6Ns79nAC0qcI.jpg'),
(156622, 11115, 'Um Maluco na TV S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438330.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fV5jjYhy6kXIl8Ywi4KBZL4eoEO.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(156623, 11115, 'Um Maluco na TV S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438331.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dAV2ThXo8zUJBUWPDZ28AP01bSp.jpg'),
(156624, 11115, 'Um Maluco na TV S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438332.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p6d1OdmP6z1luqU1w2gpvFa2AYU.jpg'),
(156625, 11115, 'Um Maluco na TV S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438333.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hwzGAPZqhDYIyNKzIYuwG97W27K.jpg'),
(156626, 11115, 'Um Maluco na TV S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438334.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lwJapMLX5thJlDa2uwVw1bHO1N4.jpg'),
(156627, 11115, 'Um Maluco na TV S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438335.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dSByCh59j1kFSRJRZBL7rHNxC63.jpg'),
(156628, 11115, 'Um Maluco na TV S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/438336.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/us7UiJkAorRMqOq0KyNs7LitPJS.jpg'),
(156629, 11115, 'Um Maluco na TV S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/438337.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/knp64pOjh9v6efHPnw7bJIq49lP.jpg'),
(156630, 11115, 'Um Maluco na TV S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/438338.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uHqfbe3WDE5TV3XOcNHgciCra8f.jpg'),
(156631, 11115, 'Um Maluco na TV S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/438339.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n3UUtImB9HEwIB9rCTs62A4aZpI.jpg'),
(156632, 11115, 'Um Maluco na TV S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/438340.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/od9aWZbiV7CCCeE1sUdEiGEv3IL.jpg'),
(156633, 11115, 'Um Maluco na TV S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/438341.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kTBdGOxnTlNeb8AI54Bb64kbSVJ.jpg'),
(156634, 11115, 'Um Maluco na TV S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/438342.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lR2dCbvHJQekVCQ1Vd4SIO4lPXF.jpg'),
(156635, 11115, 'Um Maluco na TV S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/438343.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ndtKMZ73VC0OW1NhwZGitLZ6O5u.jpg'),
(156636, 11115, 'Um Maluco na TV S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/438344.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ziBkqU3M1fUXanMFDcDXAkihrfM.jpg'),
(156637, 11116, 'Um Maluco na TV S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438345.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j06RCAo0zSNy2aUGFXRCKfTlBx3.jpg'),
(156638, 11116, 'Um Maluco na TV S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438346.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eAyplHCJWButLkCLIxf7yPbGnNR.jpg'),
(156639, 11116, 'Um Maluco na TV S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438347.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jgd48ud0CDWlNiCXLBhpQcVW3ir.jpg'),
(156640, 11116, 'Um Maluco na TV S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438348.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gMA7DXiQ6Opys4EAj4joDRp5h0L.jpg'),
(156641, 11116, 'Um Maluco na TV S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438349.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o41Vr9WMS6anpI9JXTtrsFnf22Z.jpg'),
(156642, 11116, 'Um Maluco na TV S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438350.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aUY1QV9j4NVJJz40YTiiP2xeeA8.jpg'),
(156643, 11116, 'Um Maluco na TV S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/438351.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vf7mYRoUJvkmESnND3T9nV3DI5.jpg'),
(156644, 11116, 'Um Maluco na TV S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/438352.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zXLAZrO0vVk7qtSQXtvnddMnEoB.jpg'),
(156645, 11116, 'Um Maluco na TV S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/438353.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lpOyJPnQFAUsH868apY6UM1SelL.jpg'),
(156646, 11116, 'Um Maluco na TV S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/438354.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wNhUUYF6seWonCflzUpTE1tnfxJ.jpg'),
(156647, 11116, 'Um Maluco na TV S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/438355.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i0TPX5PyqspM4wWxiGtvwj5kJCy.jpg'),
(156648, 11116, 'Um Maluco na TV S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/438356.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fhuIwRAuWMNGtsXVWKVU6vxPxjo.jpg'),
(156649, 11116, 'Um Maluco na TV S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/438357.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/20L4sCWqUqORtqv9JsPScyaoSs8.jpg'),
(156650, 11116, 'Um Maluco na TV S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/438358.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nXITDNkkO784WCXM82yv7YmVzAx.jpg'),
(156651, 11116, 'Um Maluco na TV S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/438359.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8JTSWLBI3hMLZtQuGGtIqxmWBYE.jpg'),
(156652, 11116, 'Um Maluco na TV S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/438360.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/EyhG7dtiIsB5ILl3QjdB8fjBX9.jpg'),
(156653, 11116, 'Um Maluco na TV S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/438361.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dRcmchtuE6CRekzqU2XxFbhxhYQ.jpg'),
(156654, 11116, 'Um Maluco na TV S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/438362.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5TfATVD0G3WH3Ey4iqcnbFT9ZTV.jpg'),
(156655, 11116, 'Um Maluco na TV S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/438363.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uSPOF9eln5HRP8KQQF5TRknCGVY.jpg'),
(156656, 11116, 'Um Maluco na TV S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/438364.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cZ26OdyEn27i3ofrPeX6LFs8eUE.jpg'),
(156657, 11116, 'Um Maluco na TV S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/438365.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2sqPfmZWgOdhyqHABLy94fk6CaP.jpg'),
(156658, 11116, 'Um Maluco na TV S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/438366.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4cIys6wFb7VqZEGbNpH8DYfbFqy.jpg'),
(156659, 11117, 'Um Maluco na TV S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438367.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yXkXGYdi6E7PolqZqhjwS4n8EjA.jpg'),
(156660, 11117, 'Um Maluco na TV S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438368.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i7OhzMJE1lqMN3pIoNCNYwKePDf.jpg'),
(156661, 11117, 'Um Maluco na TV S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438369.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A9vH7KVRhKwwr1H1meN4znUUiXM.jpg'),
(156662, 11117, 'Um Maluco na TV S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438370.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xdIR1UpRUblGQ8LxX6hOEFD7HLR.jpg'),
(156663, 11117, 'Um Maluco na TV S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438371.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9eZQFj3NwnDNTyCSxz8rWGJsVF1.jpg'),
(156664, 11117, 'Um Maluco na TV S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438372.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eORNXBA4m1kqp7GZjUIq9JwB8gy.jpg'),
(156665, 11117, 'Um Maluco na TV S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/438373.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1SfjSwr0B3udhHvEh34ELJax22t.jpg'),
(156666, 11117, 'Um Maluco na TV S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/438374.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dh9lzhygZBDnNMRCZ9vPJOrcnK9.jpg'),
(156667, 11117, 'Um Maluco na TV S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/438375.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/slVtVXmTdUHbCfg1Iv2JeiSz5Bv.jpg'),
(156668, 11117, 'Um Maluco na TV S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/438376.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uQh33HXkvPyDr68rHXYvlwHNHV8.jpg'),
(156669, 11117, 'Um Maluco na TV S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/438377.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r844WwmZS4L7UqluyguGRomY1KF.jpg'),
(156670, 11117, 'Um Maluco na TV S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/438378.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sPvgs6gNpFuO0INBo1qeTYPjsTA.jpg'),
(156671, 11117, 'Um Maluco na TV S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/438379.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/44y2wO6gmRA38e1IwHpZrIrb5Ot.jpg'),
(156672, 11117, 'Um Maluco na TV S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/438380.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AmlFRbjUrsWPsoNb9R92fQjzSYb.jpg'),
(156673, 11117, 'Um Maluco na TV S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/438381.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6ddsIvQU1eYPxBgI45Qn4X0hnr8.jpg'),
(156674, 11117, 'Um Maluco na TV S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/438382.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ey4iFaHygd4VKvYPMojO0EwDTzW.jpg'),
(156675, 11117, 'Um Maluco na TV S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/438383.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y6vJ2zERLTfQl7T5xlXmTN0Ue5M.jpg'),
(156676, 11117, 'Um Maluco na TV S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/438384.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/reRrrThibYKxrxBW3TYF2wbTDuv.jpg'),
(156677, 11117, 'Um Maluco na TV S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/438385.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jO9Pu2SKg5M69xfopDioW8FpR7k.jpg'),
(156678, 11117, 'Um Maluco na TV S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/438386.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6ZqvFWRi12rI6zuMs6cOhvZSPsw.jpg'),
(156679, 11117, 'Um Maluco na TV S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/438387.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ak4qbdR8oTmgxbD2aychehKy8hl.jpg'),
(156680, 11117, 'Um Maluco na TV S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/438388.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o5mWj1z4nNywhmMz7btIBERhKB0.jpg'),
(156681, 11118, 'Um Maluco na TV S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438389.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u2eXJE75BwQcLjtnTHR1K3CnMbj.jpg'),
(156682, 11118, 'Um Maluco na TV S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438390.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/927BadwWT9MyKwMjvUWEMsUyin4.jpg'),
(156683, 11118, 'Um Maluco na TV S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438391.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wUCZRv3BmqotvUSofo5zNfId4e1.jpg'),
(156684, 11118, 'Um Maluco na TV S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438392.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cV0rAdtTDswKv8WY0zd9OMYwfhG.jpg'),
(156685, 11118, 'Um Maluco na TV S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438393.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xEIsoXbUzGQJ8vQSAvG3BFjZ1dh.jpg'),
(156686, 11118, 'Um Maluco na TV S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438394.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xXE4XjmBXyXAO333tjtzAWraqk.jpg'),
(156687, 11118, 'Um Maluco na TV S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/438395.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nEwBOAwzvYvk5oj8gSoTcVOi3Sl.jpg'),
(156688, 11118, 'Um Maluco na TV S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/438396.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bcr7Zm9bjJRILz70D7g0vpyXTJG.jpg'),
(156689, 11118, 'Um Maluco na TV S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/438397.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xdXkBqecjFQCb9DUl7qHKnCloXC.jpg'),
(156690, 11118, 'Um Maluco na TV S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/438398.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tW6HNxxcL4xSzDGJ1V4f9Mm8FyA.jpg'),
(156691, 11118, 'Um Maluco na TV S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/438399.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rmYhFUdK6e88wtvC8vXUgeocMzI.jpg'),
(156692, 11118, 'Um Maluco na TV S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/438400.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Ai6g12rLtQbp59hI4hT4xOYFxzJ.jpg'),
(156693, 11118, 'Um Maluco na TV S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/438401.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bJAXU41uIj7gnqfSmZGu0ET6pyV.jpg'),
(156694, 11118, 'Um Maluco na TV S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/438402.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mZIjOQThpHncJeljDuCPxj5Diej.jpg'),
(156695, 11118, 'Um Maluco na TV S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/438403.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aN6sZnCH3hCUiHvNFJUyEw44arO.jpg'),
(156696, 11118, 'Um Maluco na TV S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/438404.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lniavudQpeaBcvMqIFEb8zAI3lY.jpg'),
(156697, 11118, 'Um Maluco na TV S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/438405.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zamNvDQuPY5Q4k41HFtieAkhsdk.jpg'),
(156698, 11118, 'Um Maluco na TV S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/438406.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pYHBhTEarzaUd7ZyyguLDnUsLjm.jpg'),
(156699, 11118, 'Um Maluco na TV S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/438407.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/knuwrWim2V53ueHS7WOc30n5IFJ.jpg'),
(156700, 11118, 'Um Maluco na TV S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/438408.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iHsiKGwfIBAE60pS1s1hPedT0yH.jpg'),
(156701, 11118, 'Um Maluco na TV S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/438409.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9mC9aJV1KQin8ewerGpq9VCLjrb.jpg'),
(156702, 11118, 'Um Maluco na TV S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/438410.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/whffjXg8s1wmeQqEeKLrjIxzZTD.jpg'),
(156703, 11118, 'Um Maluco na TV S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/438411.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s0HmRIDFMm2dC6RHovu9geX7pVf.jpg'),
(156704, 11119, 'Um Maluco na TV S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438412.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/trhcoXK0uOaHAr3tJSt3fnaP65d.jpg'),
(156705, 11119, 'Um Maluco na TV S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438413.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/40ePdByUCZgIwzzYPdPT8ahBvyv.jpg'),
(156706, 11119, 'Um Maluco na TV S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438414.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rH8VXS7Dv8vYnpSXdNGoiTwsUpn.jpg'),
(156707, 11119, 'Um Maluco na TV S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438415.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jvWe5huX5zwhVoKa6ZURD9gErHe.jpg'),
(156708, 11119, 'Um Maluco na TV S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438416.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/epSB3b0TJjNI1miN3r9QmMFcRAn.jpg'),
(156709, 11119, 'Um Maluco na TV S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438417.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7MDTFaVHCMHnXyJiQ1wEtyjKSUf.jpg'),
(156710, 11119, 'Um Maluco na TV S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/438418.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hg5Eqv9LXB32fmvkpHH4L4XXixx.jpg'),
(156711, 11119, 'Um Maluco na TV S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/438419.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tuXq3D3SiVsfnJchKXqjTrXRFIH.jpg'),
(156712, 11119, 'Um Maluco na TV S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/438420.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/feiUjRKDqETHYI0jMFyIYx161el.jpg'),
(156713, 11119, 'Um Maluco na TV S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/438421.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dSFDXQCNoRevcQfaaHBiV3CMn59.jpg'),
(156714, 11119, 'Um Maluco na TV S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/438422.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e4EAA0GA9NL95s91COUkWsbI0ox.jpg'),
(156715, 11119, 'Um Maluco na TV S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/438423.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vOqUQBItwa8ux4emAaxQa9rB6Te.jpg'),
(156716, 11119, 'Um Maluco na TV S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/438424.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rrjHehTXnqyH2SF4b3Yn2mTLmxR.jpg'),
(156717, 11119, 'Um Maluco na TV S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/438425.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fldQq11YHS6UE8cbyDt8pNcWPrx.jpg'),
(156718, 11119, 'Um Maluco na TV S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/438426.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9y7MUiEM2ZXZHqehBfYH0f80bpa.jpg'),
(156719, 11119, 'Um Maluco na TV S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/438427.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v8gXbQ9XDAHHRQExDvS4RlKsxum.jpg'),
(156720, 11119, 'Um Maluco na TV S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/438428.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vIqZMaWdgEC1PNArlgPVqlQFxAf.jpg'),
(156721, 11119, 'Um Maluco na TV S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/438429.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ct4XlfPB4cBI0LPB8NRVYIdAxFb.jpg'),
(156722, 11119, 'Um Maluco na TV S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/438430.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e1pSAZxjT7qzFs3iIwReyfBnGJi.jpg'),
(156723, 11119, 'Um Maluco na TV S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/438431.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/css7Mj72lBrhmtxvRMrLllabx8x.jpg'),
(156724, 11119, 'Um Maluco na TV S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/438432.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gGDlKJJLy6ohnvefA4OX2jiZZRC.jpg'),
(156725, 11119, 'Um Maluco na TV S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/438433.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cik97HKQA67DXXEqFkOSu5zWAnT.jpg'),
(156726, 11120, 'Um Maluco na TV S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438434.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5e6VMOitoGdljDbEdGcWUk8ky0e.jpg'),
(156727, 11120, 'Um Maluco na TV S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438435.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wW2cr2q8Mij3eqQB9PeE3BhteDM.jpg'),
(156728, 11120, 'Um Maluco na TV S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438436.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7fqOIY9KZYOQRqq21IUt6ywMlU1.jpg'),
(156729, 11120, 'Um Maluco na TV S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438437.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3HgadVxKGTHUWijj0vH1NyDA7Ja.jpg'),
(156730, 11120, 'Um Maluco na TV S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438438.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bj77mVyBNLJABDDHHfS1M56wkXL.jpg'),
(156731, 11120, 'Um Maluco na TV S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438439.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/51kNUfLVxtIcuPw2InCHaobNJi.jpg'),
(156732, 11120, 'Um Maluco na TV S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/438440.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xsbfTIV8C5TfkTDMx5oQCPKRhKE.jpg'),
(156733, 11120, 'Um Maluco na TV S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/438441.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k9aL5GR0Z5R8UfCsVK2tMXvKARY.jpg'),
(156734, 11120, 'Um Maluco na TV S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/438442.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7mK40MFOhKVyufxdSXIwhl5694J.jpg'),
(156735, 11120, 'Um Maluco na TV S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/438443.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qhZGr764I51AAv9skNRM42a5stJ.jpg'),
(156736, 11120, 'Um Maluco na TV S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/438444.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dcsupeXk5C3krX8IYXTyTRaotER.jpg'),
(156737, 11120, 'Um Maluco na TV S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/438445.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rxVtuopfE1R3DdDZf18hoWAvY2v.jpg'),
(156738, 11120, 'Um Maluco na TV S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/438446.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vK3tRTGfVsXwMXazmeL4hGgY5hr.jpg'),
(156739, 10723, 'Segura a Onda [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438211.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1bFepeqNpx940YCTh0mI2tHgZCa.jpg'),
(156740, 10723, 'Segura a Onda [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438212.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/714jnxgQqyowldnKMmNEomzeE3j.jpg'),
(156741, 10723, 'Segura a Onda [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438213.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3rrhO0WLNiBceTtIaVzneYbfxu0.jpg'),
(156742, 10723, 'Segura a Onda [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438214.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dJDXheFIqCpHwuOSzRjC1ll4ce7.jpg'),
(156743, 10723, 'Segura a Onda [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438215.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yr6MpW5rWhhuA801NMuyOF9YhDq.jpg'),
(156744, 10723, 'Segura a Onda [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438216.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7sMTNc4RJUW6KKXP1v8E2FUBd8g.jpg'),
(156745, 10723, 'Segura a Onda [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/438217.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z9M2G0LjY8hAKQLWumeFKgwH5t6.jpg'),
(156746, 10723, 'Segura a Onda [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/438218.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oOsRhfK7w2sxKsWdexjxhi3BC5y.jpg'),
(156747, 10723, 'Segura a Onda [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/438219.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/coVQKZOVT5uePmDt2Oi0trADvEz.jpg'),
(156748, 10723, 'Segura a Onda [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/438220.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7Ihx1IkvyHAmG23vOT6cs1GW22n.jpg'),
(156749, 10724, 'Segura a Onda [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438221.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rkn1BHbc1aXyocRAQ2tsC1ubp0T.jpg'),
(156750, 10724, 'Segura a Onda [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438222.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9se1m3XAFKEl3yQsVuA4QAwKxNE.jpg'),
(156751, 10724, 'Segura a Onda [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438223.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1GbmXaGBxI8FFh06WYBD7RpCLgI.jpg'),
(156752, 10724, 'Segura a Onda [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438224.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hdB4riK0Zs5RNEBwdcOr87ZhXZX.jpg'),
(156753, 10724, 'Segura a Onda [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438225.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cmbH5yuKZCAiWFxOL2fQSVNXYkT.jpg'),
(156754, 10724, 'Segura a Onda [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438226.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9kCOrDMzHiZTgZV70ZxUSTuWsaK.jpg'),
(156755, 10724, 'Segura a Onda [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/438227.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7ixobf0R2OcPkX6s9fz5FmwbYPd.jpg'),
(156756, 10724, 'Segura a Onda [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/438228.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iHiTUtXlLFYKfz8c5uvUgrFg8po.jpg'),
(156757, 10725, 'Segura a Onda [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438229.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tBRiSBA754KCFZsaQ374G2VsUsl.jpg'),
(156758, 10725, 'Segura a Onda [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438230.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vcxtaiV0vZULMe9iqFMQ4t0ow5Z.jpg'),
(156759, 10725, 'Segura a Onda [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438231.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1oESB8eQaoV3mKDrosCPMmrjyhy.jpg'),
(156760, 10725, 'Segura a Onda [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438232.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ode5Ukjzf6yCa0I3B7AsCqemKDu.jpg'),
(156761, 10725, 'Segura a Onda [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438233.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9L95MraJEuPlXG7GyftpQGlABlW.jpg'),
(156762, 10725, 'Segura a Onda [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438234.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v6RgPbNZbrWh45h79kSuWbeClLK.jpg'),
(156763, 10725, 'Segura a Onda [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/438235.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bbk8A9ZEQUtaiVu27qZoUyOkOqr.jpg'),
(156764, 10725, 'Segura a Onda [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/438236.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/icndQk4tCLmsBEKNMb4zdcD2vLq.jpg'),
(156765, 10725, 'Segura a Onda [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/438237.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wugfMUtw0fV6ljnHE7zZj8AiT3y.jpg'),
(156766, 10725, 'Segura a Onda [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/438238.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t9B7oGJ2WcGHOQvIJaFSJzt5z7w.jpg'),
(156767, 10726, 'Segura a Onda [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438239.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lqGILMuoiymGd8NSY16Len0fIz0.jpg'),
(156768, 10726, 'Segura a Onda [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438240.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9AuleeIjUbcDMHtuf1KKjYY6rTI.jpg'),
(156769, 10726, 'Segura a Onda [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438241.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8VMg3RsHMxCMuyLmQLsbkIZJ9bo.jpg'),
(156770, 10726, 'Segura a Onda [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438242.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3jMl54vJIQE9G9rcCTLyc1dzaMk.jpg'),
(156771, 10726, 'Segura a Onda [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438243.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/73R35C0GYcsxBJzT3zjaDmv1oXk.jpg'),
(156772, 10726, 'Segura a Onda [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438244.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sSHdcZJj4GjTZrvYt8U0SejUefh.jpg'),
(156773, 10726, 'Segura a Onda [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/438245.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6KGNcOuIs6ZYfbb40IWyR1gfeb1.jpg'),
(156774, 10726, 'Segura a Onda [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/438246.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fJWtU4DZwYZxG2dLOgYj91nDlEQ.jpg'),
(156775, 10726, 'Segura a Onda [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/438247.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n6gqLeI6hwR82FvC60nKpe2cTpV.jpg'),
(156776, 10726, 'Segura a Onda [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/438248.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/juwb2bNZ2f80L4uChMr2TY2d6Os.jpg'),
(156777, 10727, 'Segura a Onda [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438249.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xbkhDtczYuWDcz34ts0RqzTAidP.jpg'),
(156778, 10727, 'Segura a Onda [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438250.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m1zqNpqiYlFrsCuRVm8YBuMUj0z.jpg'),
(156779, 10727, 'Segura a Onda [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438251.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sh5Oj1s8DA5vtI6a9VAQjB348kT.jpg'),
(156780, 10727, 'Segura a Onda [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438252.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/huiHoOpY78lmqQZa36CXsqiPJG4.jpg'),
(156781, 10727, 'Segura a Onda [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438253.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zi7wmHONMZog51ZAHqHsEmK5t89.jpg'),
(156782, 10727, 'Segura a Onda [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438254.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6rdqp5U6GVDlxaJlwxaSC0lm8eY.jpg'),
(156783, 10727, 'Segura a Onda [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/438255.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a1RgH4H3PdMJAT6fUcpUo6IuaC9.jpg'),
(156784, 10727, 'Segura a Onda [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/438256.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nd1vSYa2NmoBnOHDaYssFykSzb.jpg'),
(156785, 10727, 'Segura a Onda [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/438257.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fUB10ttQbRbiW3n5ivTcTZKV72N.jpg'),
(156786, 10727, 'Segura a Onda [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/438258.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yWcexca7UFPqqK75Dg5LZX8HGhb.jpg'),
(156787, 10728, 'Segura a Onda [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438259.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yBAJNVysVPX4MKuH4qeG8tCJ0R1.jpg'),
(156788, 10728, 'Segura a Onda [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438260.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rL6RJm6ddZRbLrM9RqNYwFDWVtC.jpg'),
(156789, 10728, 'Segura a Onda [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438261.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cWDLRPPEBK16diojJUJieswDN4q.jpg'),
(156790, 10728, 'Segura a Onda [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438262.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hQtOh4wqFrY80P5lW3eOftyxOVY.jpg'),
(156791, 10728, 'Segura a Onda [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438263.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vF1VmtDyVSceq2pOW9Y3lLG0S4z.jpg'),
(156792, 10728, 'Segura a Onda [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438264.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jgUc7ZmjYJmQynp4xZ49k6vDv6m.jpg'),
(156793, 10728, 'Segura a Onda [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/438265.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dEEKRR3tx46qHotcuWIFSenWZyN.jpg'),
(156794, 10728, 'Segura a Onda [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/438266.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fFV91Nh2UdDpCT9F3yqKwplWE84.jpg'),
(156795, 10728, 'Segura a Onda [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/438267.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cVCIAiziIZpvLXVQgZo6WTAzRUc.jpg'),
(156796, 10728, 'Segura a Onda [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/438268.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1laFScs9OiJYvbvb2WBVISMQ6TQ.jpg'),
(156797, 10729, 'Segura a Onda [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438269.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f26Q4zWYAqpziLu0N8uHqiWWNOQ.jpg'),
(156798, 10729, 'Segura a Onda [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438270.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sqImZ7VBcxh0vwZPouIIjHDOwK6.jpg'),
(156799, 10729, 'Segura a Onda [L] S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438271.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zyxPSQqbrdLVo9kDFkMqGOtjUAC.jpg'),
(156800, 10729, 'Segura a Onda [L] S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438272.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sCRYIpYu7RKTxZQUHKAP5bec9Eg.jpg'),
(156801, 10729, 'Segura a Onda [L] S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438273.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AvDB6ipeS2cOB5dO4dYpjKTJgTT.jpg'),
(156802, 10729, 'Segura a Onda [L] S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438274.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p8zhfsZw8pQCbAQuvz7jdstPWe7.jpg'),
(156803, 10729, 'Segura a Onda [L] S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/438275.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kU61qfc8Jkz4SGmWLtisf0Lzwz.jpg'),
(156804, 10729, 'Segura a Onda [L] S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/438276.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/38FLTM1ugWGR8Q2baeY7Eadahyh.jpg'),
(156805, 10729, 'Segura a Onda [L] S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/438277.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5WrczTc67n3bAl0mjt7Mu2cLkWJ.jpg'),
(156806, 10729, 'Segura a Onda [L] S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/438278.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ignNzLR9B6BSMIyH3VuPwR4kZ38.jpg'),
(156807, 10730, 'Segura a Onda [L] S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438279.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8tIdLgL5ibFrg3lvlKg9Oz1lA0S.jpg'),
(156808, 10730, 'Segura a Onda [L] S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438280.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wyIQETOXBYZ8NLv98TGtO9YKVCV.jpg'),
(156809, 10730, 'Segura a Onda [L] S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438281.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xbIHauuig1oUrRhSQcELYrOJT07.jpg'),
(156810, 10730, 'Segura a Onda [L] S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438282.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rkzWQTQd1m6MRLURmvoKkoPw3mi.jpg'),
(156811, 10730, 'Segura a Onda [L] S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438283.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6L0ByHDbuUPaXfERvYOCsmRTigi.jpg'),
(156812, 10730, 'Segura a Onda [L] S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438284.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uPMvvY48VQj2TuVbr1AjWjGd8NM.jpg'),
(156813, 10730, 'Segura a Onda [L] S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/438285.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bb5gNp1Lz6zbUWwcBjf8jCbZ6qr.jpg'),
(156814, 10730, 'Segura a Onda [L] S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/438286.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tQfYMYX6Jp1QxuNvv1bfG8hnkS4.jpg'),
(156815, 10730, 'Segura a Onda [L] S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/438287.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nBwZjM8pvwdIkSTHdYH3gEAPHia.jpg'),
(156816, 10730, 'Segura a Onda [L] S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/438288.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/exrtSAwFZYqiaKRMOdy26EKy6yn.jpg'),
(156817, 10731, 'Segura a Onda [L] S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438289.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kiGK7Me57rF57EU2W8llj3GkKpN.jpg'),
(156818, 10731, 'Segura a Onda [L] S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438290.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kya15sTIsGqRHl2XgEbIrS8epNt.jpg'),
(156819, 10731, 'Segura a Onda [L] S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438291.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7Fl7rRUkcd7NgSo5QsybKBsJ1QH.jpg'),
(156820, 10731, 'Segura a Onda [L] S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438292.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/upLDgLzHU8EX0rw1SI1Jv4corXp.jpg'),
(156821, 10731, 'Segura a Onda [L] S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438293.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/brYWtcSvusw7U7gtRs8YF14o7If.jpg'),
(156822, 10731, 'Segura a Onda [L] S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438294.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tuYT2aRKV4QxrI1uVWeOFBgXLyp.jpg'),
(156823, 10731, 'Segura a Onda [L] S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/438295.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x5ROJoTw3f8KFNTBNPYbIT7NwHl.jpg'),
(156824, 10731, 'Segura a Onda [L] S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/438296.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vCizeF2xShcjqmmW5y7TDZ9WOUw.jpg'),
(156825, 10731, 'Segura a Onda [L] S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/438297.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gnFvqKGGl6Z9n6lIey8TYmFVNkv.jpg'),
(156826, 10731, 'Segura a Onda [L] S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/438298.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nJs4KwMYdT9SWrMSIcnNxvtM9c7.jpg'),
(156827, 10732, 'Segura a Onda [L] S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438299.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iZYmk7WlKYNVkXjemWcFILJ0w0E.jpg'),
(156828, 10732, 'Segura a Onda [L] S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438300.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6jurDD1TXk0Kq5LthPIvNqB0blX.jpg'),
(156829, 10732, 'Segura a Onda [L] S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438301.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7RO6EPToAQ38yQEfiASJyWb03wB.jpg'),
(156830, 10732, 'Segura a Onda [L] S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438302.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wbEEHZoYQQWnmkmRoJfPBLImYTv.jpg'),
(156831, 10732, 'Segura a Onda [L] S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438303.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rCmxapTGG4s1cCmV1FSfWE4VL2V.jpg'),
(156832, 10732, 'Segura a Onda [L] S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438304.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4hb9vH8cr3CKYRLdWgrOZUso4YY.jpg'),
(156833, 10732, 'Segura a Onda [L] S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/438305.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3tD0hu6bpUBtIKDcOOKQjO4fNzZ.jpg'),
(156834, 10732, 'Segura a Onda [L] S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/438306.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5PIG9U2GQ7dw0PzL2Q3LaP3rsOt.jpg'),
(156835, 10732, 'Segura a Onda [L] S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/438307.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aEaC2uUzMF9FNTYg2ygey5POEKu.jpg'),
(156836, 10732, 'Segura a Onda [L] S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/438308.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7u7E04AknWQA0O1fcBwc0Ok2D19.jpg'),
(156837, 11121, 'Vortex [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/438205.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9ovibD5zARZl2XrQjr21dxkUgv4.jpg'),
(156838, 11121, 'Vortex [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/438206.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l0g4CU49vv2w64JjSUjaNWjSCQE.jpg'),
(156839, 11121, 'Vortex [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/438207.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iMQuxocrXeaRAqxFeIe5yM1l4vu.jpg'),
(156840, 11121, 'Vortex [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/438208.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mVHFDCXhic2k0UmTVTy3bLSH1on.jpg'),
(156841, 11121, 'Vortex [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/438209.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iy6avAh1WCZJSPcFLM6vpslAGRY.jpg'),
(156842, 11121, 'Vortex [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/438210.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sO42un6yoelXeh8W60du7zBpzEr.jpg'),
(156843, 9610, 'A Friend of the Family S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440593.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5wBo5iuWSbfGWzRfxrzWYKNjaKU.jpg'),
(156844, 9610, 'A Friend of the Family S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440594.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qaT9BmbW0GT7mSnVsBTxqE2hGLI.jpg'),
(156845, 11122, 'A Man Who Defies The World of BL [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440586.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vRkDSvghTb0RDA2s0BCUwRSx2yI.jpg'),
(156846, 11122, 'A Man Who Defies The World of BL [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440587.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eTmw3M6TmtPfQRAVrfGkgRzdSg4.jpg'),
(156847, 11122, 'A Man Who Defies The World of BL [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440588.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o0lJ8EbsU24teWPcSV7DNFJ5XV6.jpg'),
(156848, 11122, 'A Man Who Defies The World of BL [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440589.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w5d4A90qE2rMjBhg0Mldc4RxiaH.jpg'),
(156849, 11123, 'A Man Who Defies The World of BL [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xr6A7tBpyiNzVRHKE0IdIQ7mQDr.jpg'),
(156850, 11123, 'A Man Who Defies The World of BL [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xr6A7tBpyiNzVRHKE0IdIQ7mQDr.jpg'),
(156851, 11123, 'A Man Who Defies The World of BL [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xr6A7tBpyiNzVRHKE0IdIQ7mQDr.jpg'),
(156852, 11124, 'A Playthrough of a Certain Dudes VRMMO Life [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440574.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pfa58MPPin1VbePPBh9G2111EhX.jpg'),
(156853, 11124, 'A Playthrough of a Certain Dudes VRMMO Life [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440575.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bWKZZMyYRqD3sllK25oi28Pltlf.jpg'),
(156854, 11124, 'A Playthrough of a Certain Dudes VRMMO Life [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440576.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oc7o0B3GsdlDlqHJOpPe26yWoxS.jpg'),
(156855, 11124, 'A Playthrough of a Certain Dudes VRMMO Life [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440577.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/twqpUxFPSiUAL0LL4smpWacGhLE.jpg'),
(156856, 11124, 'A Playthrough of a Certain Dudes VRMMO Life [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440578.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ldo6zsqFSpBbnBjjVdIeOWK10nu.jpg'),
(156857, 11124, 'A Playthrough of a Certain Dudes VRMMO Life [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440579.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8qKSHjO4A8harCTnjHbVIqFcBGm.jpg'),
(156858, 11124, 'A Playthrough of a Certain Dudes VRMMO Life [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440580.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sIEW7ITB3Vg50G1jdOnEWdef7kC.jpg'),
(156859, 11124, 'A Playthrough of a Certain Dudes VRMMO Life [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440581.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iQ0v4bfoau7ggvjZslCjCaSXFij.jpg'),
(156860, 11124, 'A Playthrough of a Certain Dudes VRMMO Life [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/440582.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/epL78tXTAaKwn1QAreMqk53VVx6.jpg'),
(156861, 11124, 'A Playthrough of a Certain Dudes VRMMO Life [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/440583.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3jM5p5LVFMAsqp0umOy45zWAnof.jpg'),
(156862, 11124, 'A Playthrough of a Certain Dudes VRMMO Life [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/440584.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6rc72CYkAYYGSCkMk4C8Lpa79jD.jpg'),
(156863, 11124, 'A Playthrough of a Certain Dudes VRMMO Life [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/440585.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8Q5vG5ML2NKQJkpiwVvgjpke5Up.jpg'),
(156864, 11125, 'A Princesa Assassina [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440570.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iWvWs756GQSXUvSdZDJLLRyYPcE.jpg'),
(156865, 11125, 'A Princesa Assassina [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440571.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sMHwUAw2XNouxqjanrACvC8OGGX.jpg'),
(156866, 11125, 'A Princesa Assassina [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440572.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8qocn9VOvm4UU01ioLvUVQkcr0P.jpg'),
(156867, 11125, 'A Princesa Assassina [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440573.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xS02T0BoYLUqOp3XFmoh8umlNCc.jpg'),
(156868, 11125, 'A Princesa Assassina [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jy4PvYezI6GhWeJHtoCKNrN38A.jpg'),
(156869, 11125, 'A Princesa Assassina [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/448942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9jy4PvYezI6GhWeJHtoCKNrN38A.jpg'),
(156870, 11126, 'Abandono de Evento [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440566.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7Ps2zTXHAOJYRqcc5vrhTaZ8P7N.jpg'),
(156871, 11126, 'Abandono de Evento [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440567.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fCPmrvo4E72d1bFU3AvKcl3kI9P.jpg'),
(156872, 11126, 'Abandono de Evento [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440568.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mZ2ajn0XK0wMnnRVC47aQDZdpMn.jpg'),
(156873, 11126, 'Abandono de Evento [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440569.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cB5GAkc2aMfJOo2LFyGcLXOB3X6.jpg'),
(156874, 11127, 'Absurdos da Engenharia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440560.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sro7i6VFRZoBJ55bJiXOrb63ju9.jpg'),
(156875, 11127, 'Absurdos da Engenharia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440561.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6H4XFIeXYCYBiJjV7kW9ayTUjt7.jpg'),
(156876, 11127, 'Absurdos da Engenharia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440562.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/57oIPUB7DasDyBQlu6f9mnqMsOK.jpg'),
(156877, 11127, 'Absurdos da Engenharia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440563.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8uginYIJMZ9PBw07pLD4ZM10iNi.jpg'),
(156878, 11127, 'Absurdos da Engenharia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440564.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4F3l13rBrhyxra8gEJGZZqOKZDk.jpg'),
(156879, 11127, 'Absurdos da Engenharia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440565.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dMyUS4rg75PPoXh90Pf9HoIXyp0.jpg'),
(156880, 11128, 'Arsenal Military Academy [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440512.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/90NkgWH1MOa9SK5LMoGi1JckNR7.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(156881, 11128, 'Arsenal Military Academy [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440513.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2wMIuei5FbBUuOxHTBmTWOahtai.jpg'),
(156882, 11128, 'Arsenal Military Academy [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440514.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1Y8zmLW36szHvVflR6zKh4ieHHR.jpg'),
(156883, 11128, 'Arsenal Military Academy [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440515.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bqMN2XHwEog8Mfw4afrB5yMdrLL.jpg'),
(156884, 11128, 'Arsenal Military Academy [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440516.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8aZ0mlJGC3WtxWhJVFXMiZaN2WR.jpg'),
(156885, 11128, 'Arsenal Military Academy [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440517.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q8NOTrGzKwajuI8uuIvCw6EwYyi.jpg'),
(156886, 11128, 'Arsenal Military Academy [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440518.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9m8cbOk9tyYwyU4bRU7GNvoJKN2.jpg'),
(156887, 11128, 'Arsenal Military Academy [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440519.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aAT0pIGdUqv4nEMQQWJSfyE4YPe.jpg'),
(156888, 11128, 'Arsenal Military Academy [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/440520.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pCZTW1GyVvUroaGTTBPUS1RdfXu.jpg'),
(156889, 11128, 'Arsenal Military Academy [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/440521.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j7MDuc93yn4dHwkKdut22MPzQb8.jpg'),
(156890, 11128, 'Arsenal Military Academy [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/440522.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8Vi6OlR18AHICzZfh02941x6xGx.jpg'),
(156891, 11128, 'Arsenal Military Academy [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/440523.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iGoTkxH6RWyX6vJRGevawozG1d3.jpg'),
(156892, 11128, 'Arsenal Military Academy [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/440524.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/60g6dtpGSNfQxSVyDTq9jk3wGpf.jpg'),
(156893, 11128, 'Arsenal Military Academy [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/440525.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/OMkMsKjOpLq93j8sqLLzjqQoan.jpg'),
(156894, 11128, 'Arsenal Military Academy [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/440526.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lhLRk8POshNmyx6TEyzdNEMeaFk.jpg'),
(156895, 11128, 'Arsenal Military Academy [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/440527.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s2kbg6fFV91zOL2SV8YiwddYitv.jpg'),
(156896, 11128, 'Arsenal Military Academy [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/440528.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mKZkmc9LUmunBEqod3homBbO4kh.jpg'),
(156897, 11128, 'Arsenal Military Academy [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/440529.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4cfdkYwf7pi4qvCjwFEYJIZ7KTn.jpg'),
(156898, 11128, 'Arsenal Military Academy [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/440530.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lzDKeCqrjqKJ9KLLIfOuy2xOEYo.jpg'),
(156899, 11128, 'Arsenal Military Academy [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/440531.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1ibJETNZyoupZdom9IGbugLSj1g.jpg'),
(156900, 11128, 'Arsenal Military Academy [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/440532.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bSyg0I3vVnZXcQ9aRHbZa38eRtp.jpg'),
(156901, 11128, 'Arsenal Military Academy [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/440533.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4k4FVcnaHtSb1MCUqdd5WElk8Gs.jpg'),
(156902, 11128, 'Arsenal Military Academy [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/440534.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gDZAs56Psi9YUzbKGkVmgfXK93N.jpg'),
(156903, 11128, 'Arsenal Military Academy [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/440535.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z3Ds3EDefA8cEJMkTpmbYJmse2h.jpg'),
(156904, 11128, 'Arsenal Military Academy [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/440536.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7B1l5IJWA0zyYI99l0qVpu8XMoh.jpg'),
(156905, 11128, 'Arsenal Military Academy [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/440537.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/22Uy0g6J0mBHYDIRvnrjoetiIRX.jpg'),
(156906, 11128, 'Arsenal Military Academy [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/440538.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6g2aZIJ0aBgaTeZdLxOnmiM5ggm.jpg'),
(156907, 11128, 'Arsenal Military Academy [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/440539.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fKUu4QqRN5u5Xs6Bc3nGIEJw4TI.jpg'),
(156908, 11128, 'Arsenal Military Academy [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/440540.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8VuccFNQBl92H3y98FsPi02sMgh.jpg'),
(156909, 11128, 'Arsenal Military Academy [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/440541.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jSC78pY9XetIecIbyX5vGhgiqKq.jpg'),
(156910, 11128, 'Arsenal Military Academy [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/440542.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r6vn5HvX2XvrFkil60QFLsEx5rE.jpg'),
(156911, 11128, 'Arsenal Military Academy [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/440543.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7sM0oEfK9hI1gHqB08vCetSDJsD.jpg'),
(156912, 11128, 'Arsenal Military Academy [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/440544.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9RFkqFZ9ZQBFAJZX2NU1H8rP9nN.jpg'),
(156913, 11128, 'Arsenal Military Academy [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/440545.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qx4bcOhXXwGyB5p9auT8Sf0VVMk.jpg'),
(156914, 11128, 'Arsenal Military Academy [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/440546.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g1rPigyVievMW8MU6y2ak6bX9Uf.jpg'),
(156915, 11128, 'Arsenal Military Academy [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/440547.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f8qk3thPTxBVCnMfhqQoVi6TJFm.jpg'),
(156916, 11128, 'Arsenal Military Academy [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/440548.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/knUYiScR1JKQDWaw1iFm1EUZRef.jpg'),
(156917, 11128, 'Arsenal Military Academy [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/440549.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4dWQIKLINfj6CZFKn8sehJZU8LK.jpg'),
(156918, 11128, 'Arsenal Military Academy [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/440550.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tCjYUwyLhtu7bSKdSAHb16lchVg.jpg'),
(156919, 11128, 'Arsenal Military Academy [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/440551.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ulxZAlhUN0KQccC7f5pUR2vN4NO.jpg'),
(156920, 11128, 'Arsenal Military Academy [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/440552.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bIaQOBhJHCB9cuMuTFg1pZw0JZK.jpg'),
(156921, 11128, 'Arsenal Military Academy [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/440553.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sqvGPxjSDF5IoWsGsPF2VTr9Izp.jpg'),
(156922, 11128, 'Arsenal Military Academy [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/440554.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h0vbmeDcGsLHht8pdwlvbXYK3Ze.jpg'),
(156923, 11128, 'Arsenal Military Academy [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/440555.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w2LnhBLlKDaKIEENxYUi94vtvdy.jpg'),
(156924, 11128, 'Arsenal Military Academy [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/440556.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/thwvxvZUp7e0HCJGxYCsjQ5Hkcq.jpg'),
(156925, 11128, 'Arsenal Military Academy [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/440557.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yu0xky0E59PBM6hWrhi9NsMpr2.jpg'),
(156926, 11128, 'Arsenal Military Academy [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/440558.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6dpkBDE91Q9YlchuEBjv3dhSW1V.jpg'),
(156927, 11128, 'Arsenal Military Academy [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/440559.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nr8kOw9UV35F94e04TPnMKvNJmY.jpg'),
(156928, 11129, 'As Garotas do Surfe Havai [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440508.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fhKFC7VQsVVZK3yfiABPqokSVgv.jpg'),
(156929, 11129, 'As Garotas do Surfe Havai [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440509.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cUR1B6vbbnvmbslSHsuIbUnQIFn.jpg'),
(156930, 11129, 'As Garotas do Surfe Havai [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440510.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hUs7R8bFCyuGceQ7OdwNgVtsmhE.jpg'),
(156931, 11129, 'As Garotas do Surfe Havai [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440511.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fyDrcHG0B22xM7vdWObmlIoFkHG.jpg'),
(156932, 11130, 'BTS In the SOOP [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440496.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6D1JmkrE85GSVCQoBDWaYrJsYdn.jpg'),
(156933, 11130, 'BTS In the SOOP [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440497.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e513ssIlYYNDh4i7fnyalr77Cko.jpg'),
(156934, 11130, 'BTS In the SOOP [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440498.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/16CmBEVBuh25Wfb03vpplTbTi7.jpg'),
(156935, 11130, 'BTS In the SOOP [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440499.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/96JLDW9ZkDvYpIdDj6paOcgSm9n.jpg'),
(156936, 11130, 'BTS In the SOOP [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440500.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wxWcTKr9cDm2IRV3dn3WhuBVOze.jpg'),
(156937, 11130, 'BTS In the SOOP [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440501.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/magWMLQTGishdMzMNdrsC2jc2BI.jpg'),
(156938, 11130, 'BTS In the SOOP [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440502.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5elotnzzYdL3pp1T3JgRlLb6XIW.jpg'),
(156939, 11130, 'BTS In the SOOP [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440503.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/VUtfSylMK9IX4lJwbI1vU5IFP7.jpg'),
(156940, 11131, 'BTS In the SOOP [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440504.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gHwO5kYGdgMfg1kRCc2synX4KGr.jpg'),
(156941, 11131, 'BTS In the SOOP [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440505.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e3rW8GycGlQ1k10JRSFxskvae9O.jpg'),
(156942, 11131, 'BTS In the SOOP [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440506.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pAQ0uYOqYDgK4W2gBrfFKb9vOhx.jpg'),
(156943, 11131, 'BTS In the SOOP [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/snrfWsJvdmg433Fm2L27FYOq2Y3.jpg'),
(156944, 11132, 'Bate Coracao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440480.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gj8WaswEa4LY8dZcSGCKmw0SjmL.jpg'),
(156945, 11132, 'Bate Coracao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440481.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wiNa9n1eBNrZ7AiF6oPEeUMt3Qt.jpg'),
(156946, 11132, 'Bate Coracao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440482.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dVD1g98Wc21FJWCqBj466hWnz7w.jpg'),
(156947, 11132, 'Bate Coracao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440483.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/94Cs8qy3C9ki4dSuVgtymnZKjJP.jpg'),
(156948, 11132, 'Bate Coracao [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440484.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t7DnFWD3AfvXr3Ny5i9OIUYNAHv.jpg'),
(156949, 11132, 'Bate Coracao [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440485.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zfNg1PBorRzICe0BsaMXPayTaVD.jpg'),
(156950, 11132, 'Bate Coracao [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6wMVG6dYAI9nORmRKsUYLQ8Lyq.jpg'),
(156951, 11132, 'Bate Coracao [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q6wMVG6dYAI9nORmRKsUYLQ8Lyq.jpg'),
(156952, 11132, 'Bate Coracao [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/440488.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nPaOgdPigmMR7yAUN1eYzxkxjhx.jpg'),
(156953, 11132, 'Bate Coracao [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/440489.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hhKfprCv2ViQQS8Kr8NCQB9O7Cw.jpg'),
(156954, 11132, 'Bate Coracao [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/440490.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9n3d3Z4sFlT8bPEY4VowwNdF1yU.jpg'),
(156955, 11132, 'Bate Coracao [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/440491.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1SWyJi6q02tvBY1EFYNOLcvDJ3i.jpg'),
(156956, 11132, 'Bate Coracao [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/440492.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/skT2s85xzVII0CSwvD2N3VXb2DD.jpg'),
(156957, 11132, 'Bate Coracao [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/440493.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sbu7HuFpp1EfI8m1KQ7RBMV0bQN.jpg'),
(156958, 11132, 'Bate Coracao [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/440494.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/76RJHu0pFTBGDTJ93QWiI5Sy1Rv.jpg'),
(156959, 11132, 'Bate Coracao [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/440495.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m5AKp0lPmyrjrXMtnaRhbzj2TAy.jpg'),
(156960, 11133, 'Botched By Nature S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440472.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v3vcNVYSE1mboPzxkMv12JiQitX.jpg'),
(156961, 11133, 'Botched By Nature S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440473.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2VKSGrtx60FqMVB6lDo9IVHf0vp.jpg'),
(156962, 11133, 'Botched By Nature S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440474.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kPLxz9q6dzgyakBhWWgiRZhjPAN.jpg'),
(156963, 11133, 'Botched By Nature S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440475.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qAivFzvupoGCpnbyUQrZCA3Kbgr.jpg'),
(156964, 11133, 'Botched By Nature S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440476.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zxXta1hF7BIXbuC7RAFOm45zSYM.jpg'),
(156965, 11133, 'Botched By Nature S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440477.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xZTU4BT5VYZAVEKAvgF1CB57C7R.jpg'),
(156966, 11133, 'Botched By Nature S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440478.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fsOmYAHFVdZO3C2qQipFEDDCrZr.jpg'),
(156967, 11133, 'Botched By Nature S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440479.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fFREPHJObcrdSiSjsOKYoC5bI0U.jpg'),
(156968, 11134, 'Caminantes A Trilha do Medo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440465.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mlRchZQt4SHz6nD3KPNL30dDce3.jpg'),
(156969, 11134, 'Caminantes A Trilha do Medo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440466.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/id0NE9lQ9MxOs9fck9HGwDTOVJi.jpg'),
(156970, 11134, 'Caminantes A Trilha do Medo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440467.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vHDT9RPTwULLUFQjNplhnn4cBlb.jpg'),
(156971, 11134, 'Caminantes A Trilha do Medo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440468.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zuzSXqjv7maZbgwvhfGcI55jq1w.jpg'),
(156972, 11134, 'Caminantes A Trilha do Medo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440469.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b6KUu9Fst1JATbPgemlR5FBXHW9.jpg'),
(156973, 11134, 'Caminantes A Trilha do Medo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440470.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qaYcfrx22Wk3tzete27zgxJqfbG.jpg'),
(156974, 11134, 'Caminantes A Trilha do Medo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440471.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vdkGi7fbITnUvm9S6xvXt9xBCdn.jpg'),
(156975, 11135, 'Candy Color Paradox [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440457.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uZggRmjFURcqfQmad1MytMBowfK.jpg'),
(156976, 11135, 'Candy Color Paradox [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440458.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/26yQFNlSHNOo9sxU8OyxZ17Q5SW.jpg'),
(156977, 11135, 'Candy Color Paradox [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440459.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tv7g4zfWkGrDwM70wDrMeLJNDcF.jpg'),
(156978, 11135, 'Candy Color Paradox [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440460.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7Ai4jvQTD31m0iPn7zGsHk48bE7.jpg'),
(156979, 11135, 'Candy Color Paradox [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440461.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4Qu1VhyttLBnYVCmjmk3gzt4mDV.jpg'),
(156980, 11135, 'Candy Color Paradox [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440462.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hhO2wiYiNut2CtANl94tViqCo8G.jpg'),
(156981, 11135, 'Candy Color Paradox [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440463.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pMjr8jBV0SX6VZT6aTVhcATAnUY.jpg'),
(156982, 11135, 'Candy Color Paradox [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440464.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s1IrZccOMUCDBX9rH4pQgCQQbIk.jpg'),
(156983, 11136, 'Cowboy Cartel [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440453.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qzu1k25g2iVsZHIHmtNT1f4m161.jpg'),
(156984, 11136, 'Cowboy Cartel [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440454.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wrUzcN5jzB8hAGSh8a6AhLonk48.jpg'),
(156985, 11136, 'Cowboy Cartel [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440455.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uFGJz1HrVA9n94IhGJN9WlmvLua.jpg'),
(156986, 11136, 'Cowboy Cartel [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440456.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2kP4lJf9kIF29AEBlgsW7Z5wYO8.jpg'),
(156987, 11137, 'De Repente Pais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(156988, 11137, 'De Repente Pais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(156989, 11137, 'De Repente Pais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(156990, 11137, 'De Repente Pais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(156991, 11137, 'De Repente Pais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(156992, 11137, 'De Repente Pais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(156993, 11137, 'De Repente Pais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(156994, 11137, 'De Repente Pais S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(156995, 11137, 'De Repente Pais S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/440421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(156996, 11137, 'De Repente Pais S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/440422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(156997, 11137, 'De Repente Pais S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/440423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(156998, 11137, 'De Repente Pais S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/440424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(156999, 11137, 'De Repente Pais S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/440425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157000, 11137, 'De Repente Pais S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/440426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157001, 11137, 'De Repente Pais S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/440427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157002, 11137, 'De Repente Pais S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/440428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157003, 11137, 'De Repente Pais S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/440429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157004, 11137, 'De Repente Pais S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/440430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157005, 11137, 'De Repente Pais S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/440431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157006, 11137, 'De Repente Pais S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/440432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157007, 11137, 'De Repente Pais S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/440433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157008, 11137, 'De Repente Pais S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/440434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157009, 11137, 'De Repente Pais S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/440435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157010, 11137, 'De Repente Pais S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/440436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157011, 11137, 'De Repente Pais S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/440437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157012, 11137, 'De Repente Pais S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/440438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157013, 11137, 'De Repente Pais S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/440439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157014, 11137, 'De Repente Pais S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/440440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157015, 11137, 'De Repente Pais S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/440441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157016, 11137, 'De Repente Pais S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/440442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157017, 11137, 'De Repente Pais S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/440443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157018, 11137, 'De Repente Pais S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/440444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157019, 11137, 'De Repente Pais S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/440445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157020, 11137, 'De Repente Pais S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/440446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157021, 11137, 'De Repente Pais S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/440447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157022, 11137, 'De Repente Pais S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/440448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157023, 11137, 'De Repente Pais S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/440449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157024, 11137, 'De Repente Pais S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/440450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157025, 11137, 'De Repente Pais S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/440451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157026, 11137, 'De Repente Pais S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/440452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157027, 11137, 'De Repente Pais S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/448129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157028, 11137, 'De Repente Pais S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/448130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157029, 11137, 'De Repente Pais S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/448131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157030, 11137, 'De Repente Pais S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/448132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157031, 11137, 'De Repente Pais S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/448133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157032, 11137, 'De Repente Pais S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/448134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157033, 11137, 'De Repente Pais S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/448135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157034, 11137, 'De Repente Pais S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/448136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157035, 11137, 'De Repente Pais S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/448137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157036, 11137, 'De Repente Pais S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/448138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157037, 11137, 'De Repente Pais S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/448139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157038, 11137, 'De Repente Pais S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/448140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157039, 11137, 'De Repente Pais S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/448141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157040, 11137, 'De Repente Pais S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/448142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157041, 11137, 'De Repente Pais S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/448143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157042, 11137, 'De Repente Pais S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/448144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157043, 11137, 'De Repente Pais S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/448145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157044, 11137, 'De Repente Pais S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/448146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157045, 11137, 'De Repente Pais S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/448147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157046, 11137, 'De Repente Pais S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/448148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157047, 11137, 'De Repente Pais S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/452769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157048, 11137, 'De Repente Pais S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/452770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157049, 11137, 'De Repente Pais S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/452771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157050, 11137, 'De Repente Pais S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/452772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157051, 11137, 'De Repente Pais S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/452773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157052, 11137, 'De Repente Pais S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/452774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157053, 11137, 'De Repente Pais S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/452775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157054, 11137, 'De Repente Pais S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/452776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157055, 11137, 'De Repente Pais S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/452777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157056, 11137, 'De Repente Pais S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/452778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157057, 11137, 'De Repente Pais S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/452779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157058, 11137, 'De Repente Pais S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/452780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157059, 11137, 'De Repente Pais S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/452781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157060, 11137, 'De Repente Pais S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/452782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157061, 11137, 'De Repente Pais S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/452783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157062, 11137, 'De Repente Pais S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/452784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157063, 11137, 'De Repente Pais S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/452785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157064, 11137, 'De Repente Pais S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/452786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157065, 11137, 'De Repente Pais S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/452787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157066, 11137, 'De Repente Pais S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/452788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157067, 11137, 'De Repente Pais S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/458140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157068, 11137, 'De Repente Pais S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/458141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157069, 11137, 'De Repente Pais S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/458142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157070, 11137, 'De Repente Pais S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/458143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157071, 11137, 'De Repente Pais S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/458144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157072, 11137, 'De Repente Pais S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/458145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157073, 11137, 'De Repente Pais S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/458146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157074, 11137, 'De Repente Pais S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/458147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157075, 11137, 'De Repente Pais S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/458148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157076, 11137, 'De Repente Pais S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/458149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157077, 11137, 'De Repente Pais S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/458150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157078, 11137, 'De Repente Pais S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/458151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157079, 11137, 'De Repente Pais S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/458152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157080, 11137, 'De Repente Pais S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/458153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157081, 11137, 'De Repente Pais S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/458154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157082, 11137, 'De Repente Pais S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/458155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157083, 11137, 'De Repente Pais S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/458156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157084, 11137, 'De Repente Pais S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/458157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157085, 11137, 'De Repente Pais S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/458158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157086, 11137, 'De Repente Pais S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/461554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157087, 11137, 'De Repente Pais S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/461555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157088, 11137, 'De Repente Pais S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/461556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157089, 11137, 'De Repente Pais S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/461557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157090, 11137, 'De Repente Pais S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/461558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A90x0Jf8VxkQzfHTnpLUsdkOgOi.jpg'),
(157091, 11138, 'Designers do Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f2OCDIcHSTMSoawqiNzob3Zw8im.jpg'),
(157092, 11138, 'Designers do Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f2OCDIcHSTMSoawqiNzob3Zw8im.jpg'),
(157093, 11138, 'Designers do Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f2OCDIcHSTMSoawqiNzob3Zw8im.jpg'),
(157094, 11138, 'Designers do Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f2OCDIcHSTMSoawqiNzob3Zw8im.jpg'),
(157095, 11138, 'Designers do Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f2OCDIcHSTMSoawqiNzob3Zw8im.jpg'),
(157096, 11138, 'Designers do Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f2OCDIcHSTMSoawqiNzob3Zw8im.jpg'),
(157097, 11138, 'Designers do Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f2OCDIcHSTMSoawqiNzob3Zw8im.jpg'),
(157098, 11138, 'Designers do Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f2OCDIcHSTMSoawqiNzob3Zw8im.jpg'),
(157099, 11138, 'Designers do Brasil S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/440401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f2OCDIcHSTMSoawqiNzob3Zw8im.jpg'),
(157100, 11138, 'Designers do Brasil S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/440402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f2OCDIcHSTMSoawqiNzob3Zw8im.jpg'),
(157101, 11139, 'Designers do Brasil S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f2OCDIcHSTMSoawqiNzob3Zw8im.jpg'),
(157102, 11139, 'Designers do Brasil S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f2OCDIcHSTMSoawqiNzob3Zw8im.jpg'),
(157103, 11139, 'Designers do Brasil S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f2OCDIcHSTMSoawqiNzob3Zw8im.jpg'),
(157104, 11139, 'Designers do Brasil S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f2OCDIcHSTMSoawqiNzob3Zw8im.jpg'),
(157105, 11139, 'Designers do Brasil S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f2OCDIcHSTMSoawqiNzob3Zw8im.jpg'),
(157106, 11139, 'Designers do Brasil S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f2OCDIcHSTMSoawqiNzob3Zw8im.jpg'),
(157107, 11139, 'Designers do Brasil S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f2OCDIcHSTMSoawqiNzob3Zw8im.jpg'),
(157108, 11139, 'Designers do Brasil S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f2OCDIcHSTMSoawqiNzob3Zw8im.jpg'),
(157109, 11139, 'Designers do Brasil S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/440411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f2OCDIcHSTMSoawqiNzob3Zw8im.jpg'),
(157110, 11139, 'Designers do Brasil S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/440412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/f2OCDIcHSTMSoawqiNzob3Zw8im.jpg'),
(157111, 11140, 'Detectives in Trouble [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKidbJ2hAXqExlMHHCjI4vD3MFm.jpg'),
(157112, 11140, 'Detectives in Trouble [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKidbJ2hAXqExlMHHCjI4vD3MFm.jpg'),
(157113, 11140, 'Detectives in Trouble [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKidbJ2hAXqExlMHHCjI4vD3MFm.jpg'),
(157114, 11140, 'Detectives in Trouble [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKidbJ2hAXqExlMHHCjI4vD3MFm.jpg'),
(157115, 11140, 'Detectives in Trouble [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKidbJ2hAXqExlMHHCjI4vD3MFm.jpg'),
(157116, 11140, 'Detectives in Trouble [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKidbJ2hAXqExlMHHCjI4vD3MFm.jpg'),
(157117, 11140, 'Detectives in Trouble [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKidbJ2hAXqExlMHHCjI4vD3MFm.jpg'),
(157118, 11140, 'Detectives in Trouble [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKidbJ2hAXqExlMHHCjI4vD3MFm.jpg'),
(157119, 11140, 'Detectives in Trouble [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/440385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKidbJ2hAXqExlMHHCjI4vD3MFm.jpg'),
(157120, 11140, 'Detectives in Trouble [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/440386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKidbJ2hAXqExlMHHCjI4vD3MFm.jpg'),
(157121, 11140, 'Detectives in Trouble [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/440387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKidbJ2hAXqExlMHHCjI4vD3MFm.jpg'),
(157122, 11140, 'Detectives in Trouble [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/440388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKidbJ2hAXqExlMHHCjI4vD3MFm.jpg'),
(157123, 11140, 'Detectives in Trouble [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/440389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKidbJ2hAXqExlMHHCjI4vD3MFm.jpg'),
(157124, 11140, 'Detectives in Trouble [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/440390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKidbJ2hAXqExlMHHCjI4vD3MFm.jpg'),
(157125, 11140, 'Detectives in Trouble [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/440391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKidbJ2hAXqExlMHHCjI4vD3MFm.jpg'),
(157126, 11140, 'Detectives in Trouble [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/440392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bKidbJ2hAXqExlMHHCjI4vD3MFm.jpg'),
(157127, 11141, 'Detetive Americano com Joe Kenda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440355.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6JunFoWpTJiCNrCyfKug1bwt6hu.jpg'),
(157128, 11141, 'Detetive Americano com Joe Kenda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440356.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/crOOpJO4tuHA4f8UWkA3qaxblJ8.jpg'),
(157129, 11141, 'Detetive Americano com Joe Kenda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440357.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yW3Rr6Ihd6YhzEAS2iPs6beZU7u.jpg'),
(157130, 11141, 'Detetive Americano com Joe Kenda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440358.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3IxKNwxFqU9t5s8QHdu1eVu3rKQ.jpg'),
(157131, 11141, 'Detetive Americano com Joe Kenda S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440359.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wfDdCxbJqtMzLSTrAAeDZ3qkjg2.jpg'),
(157132, 11141, 'Detetive Americano com Joe Kenda S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440360.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pLewwxsVzdIoFl81vxg8CDRdWJ.jpg'),
(157133, 11141, 'Detetive Americano com Joe Kenda S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440361.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cK2pvZ1b9oUr6yNw9ZHVpNscQUM.jpg'),
(157134, 11141, 'Detetive Americano com Joe Kenda S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440362.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1vFS75MP6CqWJUUY0c3btuyYbT8.jpg'),
(157135, 11141, 'Detetive Americano com Joe Kenda S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/440363.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8scWW7hhxkXdyHiPcGiWXcDX7I5.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(157136, 11141, 'Detetive Americano com Joe Kenda S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/440364.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xfQCA7EXg5izO72aZsJDArObGNV.jpg'),
(157137, 11142, 'Detetive Americano com Joe Kenda S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440365.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2f6wKUtv5pHcnkkQeQm71dBYjWW.jpg'),
(157138, 11142, 'Detetive Americano com Joe Kenda S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440366.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fRqR7u5G1BbRHUrvsA88TrGFTOj.jpg'),
(157139, 11142, 'Detetive Americano com Joe Kenda S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440367.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dSOtRQZiB2sXTDlUDwGVEKdBE79.jpg'),
(157140, 11142, 'Detetive Americano com Joe Kenda S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440368.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r598fZY6X5oi3IXJnzq5w7jALpf.jpg'),
(157141, 11142, 'Detetive Americano com Joe Kenda S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440369.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6L6nefWttw73z3eTJbrvQoESkGw.jpg'),
(157142, 11142, 'Detetive Americano com Joe Kenda S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440370.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lQeNAQNshx3cb4LGwj9hJGiC1Qw.jpg'),
(157143, 11143, 'Detetive Americano com Joe Kenda S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440371.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bIArQ4EOIPNIfmGJCKQL3I0HwKb.jpg'),
(157144, 11143, 'Detetive Americano com Joe Kenda S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440372.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rGQ8c8jrFEkgMljkBwTZDHdPUWd.jpg'),
(157145, 11143, 'Detetive Americano com Joe Kenda S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440373.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bmPA63LkziGP8xUrArOdlxOTr5j.jpg'),
(157146, 11143, 'Detetive Americano com Joe Kenda S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440374.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dhLVkpNg07fw0HnoV9qlHV5GZdn.jpg'),
(157147, 11143, 'Detetive Americano com Joe Kenda S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440375.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vO5gFcbkAmQOONz4zLoaqrsOgOY.jpg'),
(157148, 11143, 'Detetive Americano com Joe Kenda S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440376.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/490lNBOlKNqu9bGR2saVbQom02B.jpg'),
(157149, 11144, 'Detetive Americano com Joe Kenda S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2R9H3bJzAy5iOUvPaF9aVb8AH1X.jpg'),
(157150, 11144, 'Detetive Americano com Joe Kenda S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2R9H3bJzAy5iOUvPaF9aVb8AH1X.jpg'),
(157151, 11144, 'Detetive Americano com Joe Kenda S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2R9H3bJzAy5iOUvPaF9aVb8AH1X.jpg'),
(157152, 11144, 'Detetive Americano com Joe Kenda S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2R9H3bJzAy5iOUvPaF9aVb8AH1X.jpg'),
(157153, 11144, 'Detetive Americano com Joe Kenda S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2R9H3bJzAy5iOUvPaF9aVb8AH1X.jpg'),
(157154, 11144, 'Detetive Americano com Joe Kenda S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2R9H3bJzAy5iOUvPaF9aVb8AH1X.jpg'),
(157155, 11144, 'Detetive Americano com Joe Kenda S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2R9H3bJzAy5iOUvPaF9aVb8AH1X.jpg'),
(157156, 11144, 'Detetive Americano com Joe Kenda S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2R9H3bJzAy5iOUvPaF9aVb8AH1X.jpg'),
(157157, 11144, 'Detetive Americano com Joe Kenda S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/486897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2R9H3bJzAy5iOUvPaF9aVb8AH1X.jpg'),
(157158, 11145, 'Eternal Yesterday [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440347.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tWdDqj1hT6R4Tf1qqmUKFGO3DoA.jpg'),
(157159, 11145, 'Eternal Yesterday [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440348.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7XGAwSffgCXFWSxNgjv0RUUEB9G.jpg'),
(157160, 11145, 'Eternal Yesterday [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440349.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bepoZ45BnSoaLhiPEbne42G90Ao.jpg'),
(157161, 11145, 'Eternal Yesterday [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440350.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/elLVOQm6GihNsZWIOG6roIM6B6q.jpg'),
(157162, 11145, 'Eternal Yesterday [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440351.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jVGOKOtq6OFBJy86N6FZSMHvWb3.jpg'),
(157163, 11145, 'Eternal Yesterday [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440352.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mnpoKUsXiiwzptFprA0WizS8m30.jpg'),
(157164, 11145, 'Eternal Yesterday [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440353.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bvsqkqU0VpSxpjvD9p87FNS5CeT.jpg'),
(157165, 11145, 'Eternal Yesterday [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440354.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9CR9WGckYqgkU04f8UiHtUmc5M1.jpg'),
(157166, 11146, 'Familia Perfeita [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nCODaSrYdJOtWNtTi9uQJKh8mUD.jpg'),
(157167, 11146, 'Familia Perfeita [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nCODaSrYdJOtWNtTi9uQJKh8mUD.jpg'),
(157168, 11146, 'Familia Perfeita [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nCODaSrYdJOtWNtTi9uQJKh8mUD.jpg'),
(157169, 11146, 'Familia Perfeita [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nCODaSrYdJOtWNtTi9uQJKh8mUD.jpg'),
(157170, 11146, 'Familia Perfeita [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/464396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nCODaSrYdJOtWNtTi9uQJKh8mUD.jpg'),
(157171, 11146, 'Familia Perfeita [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/464397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nCODaSrYdJOtWNtTi9uQJKh8mUD.jpg'),
(157172, 11146, 'Familia Perfeita [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/464398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nCODaSrYdJOtWNtTi9uQJKh8mUD.jpg'),
(157173, 11146, 'Familia Perfeita [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/464399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nCODaSrYdJOtWNtTi9uQJKh8mUD.jpg'),
(157174, 11146, 'Familia Perfeita [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/464400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nCODaSrYdJOtWNtTi9uQJKh8mUD.jpg'),
(157175, 11146, 'Familia Perfeita [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/464401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nCODaSrYdJOtWNtTi9uQJKh8mUD.jpg'),
(157176, 11146, 'Familia Perfeita [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/464402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nCODaSrYdJOtWNtTi9uQJKh8mUD.jpg'),
(157177, 11146, 'Familia Perfeita [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/464403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nCODaSrYdJOtWNtTi9uQJKh8mUD.jpg'),
(157178, 11147, 'First Note of Love [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440340.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AcCSzU2TCRXii3Ok9TOx6eTpQHZ.jpg'),
(157179, 11147, 'First Note of Love [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440341.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cpUejzqsN4JmyMXgldcnTBKuR33.jpg'),
(157180, 11147, 'First Note of Love [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440342.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mM2wG6HiEmZoX9KX7wwBYQh1VJ1.jpg'),
(157181, 11147, 'First Note of Love [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/444570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8W9YhOEL2ZDxy64plNNeI5pgTxp.jpg'),
(157182, 11147, 'First Note of Love [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/447841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8W9YhOEL2ZDxy64plNNeI5pgTxp.jpg'),
(157183, 11147, 'First Note of Love [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/447842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8W9YhOEL2ZDxy64plNNeI5pgTxp.jpg'),
(157184, 11147, 'First Note of Love [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/457855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8W9YhOEL2ZDxy64plNNeI5pgTxp.jpg'),
(157185, 11147, 'First Note of Love [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/464366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8W9YhOEL2ZDxy64plNNeI5pgTxp.jpg'),
(157186, 11147, 'First Note of Love [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/470331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8W9YhOEL2ZDxy64plNNeI5pgTxp.jpg'),
(157187, 11147, 'First Note of Love [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/474248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8W9YhOEL2ZDxy64plNNeI5pgTxp.jpg'),
(157188, 11147, 'First Note of Love [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/483188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8W9YhOEL2ZDxy64plNNeI5pgTxp.jpg'),
(157189, 11147, 'First Note of Love [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/491298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8W9YhOEL2ZDxy64plNNeI5pgTxp.jpg'),
(157190, 11148, 'Jewel in the Palace [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440286.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nPV9DSCCJ696dq8YG2t8enOAhr9.jpg'),
(157191, 11148, 'Jewel in the Palace [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440287.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1t4RnboguvjSspqqIu6KfiD1UAF.jpg'),
(157192, 11148, 'Jewel in the Palace [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440288.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8fGm1cqL43zFa4pX9WFqt5qspAa.jpg'),
(157193, 11148, 'Jewel in the Palace [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440289.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6tgonYzWW8HmJPd9oaBP4qFEWz6.jpg'),
(157194, 11148, 'Jewel in the Palace [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440290.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hHXdEY0jiHTzBtMX4xNexlHux17.jpg'),
(157195, 11148, 'Jewel in the Palace [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440291.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/haB5YMFDSGHJHIsDuyOzR6cfzOj.jpg'),
(157196, 11148, 'Jewel in the Palace [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440292.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zAcFSSRgp1af1VJ6Kcw51wqkE7F.jpg'),
(157197, 11148, 'Jewel in the Palace [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440293.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2YbVulUYhUQjqZZBPjHDWaCvjf8.jpg'),
(157198, 11148, 'Jewel in the Palace [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/440294.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/29wBVK53M5TTGVwLG0KzlHkyhYO.jpg'),
(157199, 11148, 'Jewel in the Palace [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/440295.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hkx6IE5ppHUNTnf16jO94XNDuB6.jpg'),
(157200, 11148, 'Jewel in the Palace [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/440296.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9m6qeRFtGTdvW2ZXBCPLpDUNIs2.jpg'),
(157201, 11148, 'Jewel in the Palace [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/440297.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kmG9AC4sxqyPRCiZ0fKmKeNDV2n.jpg'),
(157202, 11148, 'Jewel in the Palace [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/440298.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8elBf0o2MX35ow3BajdSkT9dSiL.jpg'),
(157203, 11148, 'Jewel in the Palace [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/440299.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4s2Xd8g8OdlH3EnbJMu5eAUE148.jpg'),
(157204, 11148, 'Jewel in the Palace [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/440300.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sh4kLO5ZgVXRh9mPG6VLgkFmoCh.jpg'),
(157205, 11148, 'Jewel in the Palace [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/440301.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w5T4HJ723Xw8tShNB0fDOvMjD6L.jpg'),
(157206, 11148, 'Jewel in the Palace [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/440302.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x0gcJkKHAcDaqMTMAU0MP0ZOUSK.jpg'),
(157207, 11148, 'Jewel in the Palace [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/440303.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nm4CApaKN7AvnYMrwkg4NiEnU5K.jpg'),
(157208, 11148, 'Jewel in the Palace [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/440304.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rkt0d7QSSWeHAgAm6DUdXQBZjjT.jpg'),
(157209, 11148, 'Jewel in the Palace [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/440305.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fWr29MJ57B5cUNqrCCnr7YICR4Q.jpg'),
(157210, 11148, 'Jewel in the Palace [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/440306.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rSdwAm0X6JnQalFSevvjcnJE7vy.jpg'),
(157211, 11148, 'Jewel in the Palace [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/440307.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iCfPfvmvdetFUAHP07UqFoR9oJX.jpg'),
(157212, 11148, 'Jewel in the Palace [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/440308.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eZ1O42dzWq1fONffpyr9vk0ugIL.jpg'),
(157213, 11148, 'Jewel in the Palace [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/440309.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e3teFuVvGvKQ8YQ0TbCvWyrLNzc.jpg'),
(157214, 11148, 'Jewel in the Palace [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/440310.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nb0D84gT2Yeiuw9nT8JDq5QQfXc.jpg'),
(157215, 11148, 'Jewel in the Palace [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/440311.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/razW6Cq8FThAFTKVm290IW5OotU.jpg'),
(157216, 11148, 'Jewel in the Palace [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/440312.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cWorFuLZkTEedFL0evLE6v9AmtB.jpg'),
(157217, 11148, 'Jewel in the Palace [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/440313.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/orlpxyqD4fDDNtzwWnNQCMk5kuU.jpg'),
(157218, 11148, 'Jewel in the Palace [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/440314.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/juLLwRWGSStyAFyxixXOnmrtVK.jpg'),
(157219, 11148, 'Jewel in the Palace [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/440315.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q6UFSum6ZXFbk3utnTrkRkAUmrh.jpg'),
(157220, 11148, 'Jewel in the Palace [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/440316.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/LPdSpCkSkjAClvWf5RftOwRkKe.jpg'),
(157221, 11148, 'Jewel in the Palace [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/440317.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nB40jOykRpz4mPMKAmPviBOKUMn.jpg'),
(157222, 11148, 'Jewel in the Palace [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/440318.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pwi9OVJOYd7VkRD6CLe6Dlq0xOn.jpg'),
(157223, 11148, 'Jewel in the Palace [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/440319.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e7FKickB8C7BgYSrhNWFa2RVyXG.jpg'),
(157224, 11148, 'Jewel in the Palace [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/440320.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4jufgcp5arzg683lwu7Wh5gihV7.jpg'),
(157225, 11148, 'Jewel in the Palace [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/440321.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k1yOw42XJ7YDRlo6br2ktDJcOxT.jpg'),
(157226, 11148, 'Jewel in the Palace [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/440322.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4k1veiWlSZ7jw18oeiDdNKqVrEo.jpg'),
(157227, 11148, 'Jewel in the Palace [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/440323.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wMOy32SSPMlvpMOIihZXFcxqwfv.jpg'),
(157228, 11148, 'Jewel in the Palace [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/440324.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nAZ7jS0mg1UH8s0oy1TuiBLdtOh.jpg'),
(157229, 11148, 'Jewel in the Palace [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/440325.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1NdQ52y78G1DSiT9RXkBOuyjzgp.jpg'),
(157230, 11148, 'Jewel in the Palace [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/440326.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9g05dqGbtoetvsRVodqaXwIhjeE.jpg'),
(157231, 11148, 'Jewel in the Palace [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/440327.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tEpbcXqdYJsparJO1hRVxN4g6LI.jpg'),
(157232, 11148, 'Jewel in the Palace [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/440328.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tBjJujxBGUngpKtKFymzlGSzf1J.jpg'),
(157233, 11148, 'Jewel in the Palace [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/440329.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cjVazWDbFKeuJVk4bkTLWJJO5We.jpg'),
(157234, 11148, 'Jewel in the Palace [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/440330.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xVutCPi7WIoZS84SMhkZBHmF1zU.jpg'),
(157235, 11148, 'Jewel in the Palace [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/440331.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rxBjeqNZebUbPl0aM1LzMiubNn0.jpg'),
(157236, 11148, 'Jewel in the Palace [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/440332.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/haxVqFHYDVNtYnCWtAphjfiXYXl.jpg'),
(157237, 11148, 'Jewel in the Palace [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/440333.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l4RwZQ48PBHLOI4b1uXWA42nlfe.jpg'),
(157238, 11148, 'Jewel in the Palace [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/440334.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oE9vfDftdurHAZT2Cu9DIxHssW6.jpg'),
(157239, 11148, 'Jewel in the Palace [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/440335.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y9YOnBj2YiQWsds1LFJfAcEp9pX.jpg'),
(157240, 11148, 'Jewel in the Palace [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/440336.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qf9bsHg2Ar6bMwA4vtvtnh14OD7.jpg'),
(157241, 11148, 'Jewel in the Palace [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/440337.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uBPDptKo5MnxoF32BX4u3EPJ6DR.jpg'),
(157242, 11148, 'Jewel in the Palace [L] S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/440338.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vl9BJRZi1lUz7eJeez2SxTZnLWc.jpg'),
(157243, 11148, 'Jewel in the Palace [L] S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/440339.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lsGVbimmh1QT6BCCbinpDbYeelL.jpg'),
(157244, 11149, 'Kabe Koji [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440278.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2rrKJidxwmK59XT4DEcFBXoiSJJ.jpg'),
(157245, 11149, 'Kabe Koji [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440279.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mPoWdvOXB5JShwEDwEHingv0kVV.jpg'),
(157246, 11149, 'Kabe Koji [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440280.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f7tIhvYQxWTQkeT36CO7IBl7bmt.jpg'),
(157247, 11149, 'Kabe Koji [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440281.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x0omCCYcOxoYHShnBCOHRtUElAq.jpg'),
(157248, 11149, 'Kabe Koji [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440282.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ySqtoZe67eCO0vQIo0Pgy6rlbY6.jpg'),
(157249, 11149, 'Kabe Koji [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440283.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fNETBIuiCcsAYtkUMulJDgyilgu.jpg'),
(157250, 11149, 'Kabe Koji [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440284.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oySM0JGwdLE8dYNlf3zXtWkLJKE.jpg'),
(157251, 11149, 'Kabe Koji [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440285.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jFaQXCOE6Eo9LounD1YDwT4EvPe.jpg'),
(157252, 11150, 'Life Love on the Line [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440274.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7DwFlxY3slIyVsa6WQKZrPLHfQ7.jpg'),
(157253, 11150, 'Life Love on the Line [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440275.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mmFzmjCmfdPAhRorM2GGexwUp8R.jpg'),
(157254, 11150, 'Life Love on the Line [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440276.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5kXmVp3chQ49bEBYF19UvVyQoUU.jpg'),
(157255, 11150, 'Life Love on the Line [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440277.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fRNwsjGu5Je5aS0M3hgsNdDLfXm.jpg'),
(157256, 11151, 'Love in the Moonlight [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440256.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bWoXRs78S9MzbMnNqqhtYJfK962.jpg'),
(157257, 11151, 'Love in the Moonlight [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440257.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bYXuyfGAqh8gmuof0PJjD1xt0Lb.jpg'),
(157258, 11151, 'Love in the Moonlight [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440258.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vekWJEHsysJlcPVog8pwogCYRvr.jpg'),
(157259, 11151, 'Love in the Moonlight [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440259.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pzgDhZUSsUeeqU6UcuuHXzto2S1.jpg'),
(157260, 11151, 'Love in the Moonlight [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440260.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gQsy5vnlLRvZjx7KmnctMZ5GdYc.jpg'),
(157261, 11151, 'Love in the Moonlight [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440261.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5IJZ8AYvIOnCMrF4JfibcYcAKTz.jpg'),
(157262, 11151, 'Love in the Moonlight [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440262.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lEOiczElNUgKH7SYbMcZ5Zskmfm.jpg'),
(157263, 11151, 'Love in the Moonlight [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440263.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3hMv0WYPYzpAtPhhRbFzkzu7JBI.jpg'),
(157264, 11151, 'Love in the Moonlight [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/440264.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jp9RkKq3otHm712reTZwdB3ZVZ4.jpg'),
(157265, 11151, 'Love in the Moonlight [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/440265.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/go3MCFYgyaigLLZj7gOZm8FhvO.jpg'),
(157266, 11151, 'Love in the Moonlight [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/440266.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/buj51ixibPm2vWtobWrbRoasL5J.jpg'),
(157267, 11151, 'Love in the Moonlight [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/440267.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xtxOcB4bSo6RaEdvN3nMZtInZap.jpg'),
(157268, 11151, 'Love in the Moonlight [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/440268.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xX0T1dvCcm1jESalXJRJiFEEo9n.jpg'),
(157269, 11151, 'Love in the Moonlight [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/440269.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rZz2wB4tUxmCDg0hNmJuzOE7jee.jpg'),
(157270, 11151, 'Love in the Moonlight [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/440270.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2Pvd1kEYIrfxKnpZoAVMdYv0fJw.jpg'),
(157271, 11151, 'Love in the Moonlight [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/440271.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eZzPMkGVEADnjOBWyXNzAdL0f8D.jpg'),
(157272, 11151, 'Love in the Moonlight [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/440272.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bXiiYdLS4QevG0Hi6W4g9ggnc7V.jpg'),
(157273, 11151, 'Love in the Moonlight [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/440273.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/39y0AAXkC2Uz4JaWgzoSPjwnwrt.jpg'),
(157274, 11152, 'Meu Meteorologista Pessoal [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440248.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t7ysBvgFjSZrh0hBVQ1z3El6JH2.jpg'),
(157275, 11152, 'Meu Meteorologista Pessoal [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440249.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g0AhfodKqnK1t0Zg1fQ9qsZssqn.jpg'),
(157276, 11152, 'Meu Meteorologista Pessoal [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440250.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p9zusGMHRtrlNbrTEArWLPTlvOr.jpg'),
(157277, 11152, 'Meu Meteorologista Pessoal [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440251.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wnfD8paQG00sw193p5BZYItB1Pj.jpg'),
(157278, 11152, 'Meu Meteorologista Pessoal [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440252.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ylXoRKTQtGuxOuVgOLiM4G7c74m.jpg'),
(157279, 11152, 'Meu Meteorologista Pessoal [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440253.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aOgA0dymb9Hn2MR346nzIYWpHlE.jpg'),
(157280, 11152, 'Meu Meteorologista Pessoal [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440254.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7AB8DyUbBPBuTdho6Chh4Y1mHAn.jpg'),
(157281, 11152, 'Meu Meteorologista Pessoal [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440255.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6pNjcMvwN248rQbbTBusMsrzh93.jpg'),
(157282, 11153, 'Minha Confusao de Amor (2021) [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440238.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pAFqyTdFbWH4W6VN6Gvo6xa6buL.jpg'),
(157283, 11153, 'Minha Confusao de Amor (2021) [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440239.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k5VKJVr1ARz13uhJLOKbs9e66eJ.jpg'),
(157284, 11153, 'Minha Confusao de Amor (2021) [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440240.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/98QrCqXCQAWd7UFFPqGOq0JmKX8.jpg'),
(157285, 11153, 'Minha Confusao de Amor (2021) [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440241.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uPR1gc3TwGLkLcqPFP7m6D27i8g.jpg'),
(157286, 11153, 'Minha Confusao de Amor (2021) [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440242.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d9K8rXTow4bYhnWJXGfK5Ml1fZv.jpg'),
(157287, 11153, 'Minha Confusao de Amor (2021) [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440243.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5trnA1rtZNitkHCOwrwXjqdkAVW.jpg'),
(157288, 11153, 'Minha Confusao de Amor (2021) [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440244.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g23LO8QFToCHiYIOfPcU9HTFZME.jpg'),
(157289, 11153, 'Minha Confusao de Amor (2021) [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440245.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jbh4yB54TpztMmoiSLD0n1VeIlq.jpg'),
(157290, 11153, 'Minha Confusao de Amor (2021) [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/440246.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pgpUqSLAWczFFEsXQhzS8g9zVlx.jpg'),
(157291, 11153, 'Minha Confusao de Amor (2021) [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/440247.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9rjoaMCkb5NqRjKzcH1WoLmhvs.jpg'),
(157292, 11154, 'Mr Unlucky Has No Choice but to Kiss [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440230.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8KGtvdLVOrrExMEVHgirRVvEDVQ.jpg'),
(157293, 11154, 'Mr Unlucky Has No Choice but to Kiss [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440231.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3pCk2v1mauAIHn1r2FhxknvH8np.jpg'),
(157294, 11154, 'Mr Unlucky Has No Choice but to Kiss [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440232.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eESmEsuE1QewGxi9hVX85p44Qel.jpg'),
(157295, 11154, 'Mr Unlucky Has No Choice but to Kiss [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440233.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q7eybgNznWw9U5nakt5FdHzFgf9.jpg'),
(157296, 11154, 'Mr Unlucky Has No Choice but to Kiss [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440234.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pcVCniGL4jiY4Ju2LedXijyMD5Q.jpg'),
(157297, 11154, 'Mr Unlucky Has No Choice but to Kiss [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440235.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jgwLPSp649dA049xqe1nLmldzFG.jpg'),
(157298, 11154, 'Mr Unlucky Has No Choice but to Kiss [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440236.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b1vjcC6xJvhHDIESNeYW1FT6l9K.jpg'),
(157299, 11154, 'Mr Unlucky Has No Choice but to Kiss [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440237.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jJzc1jzTL2cut6SNbGNhwvs1xMP.jpg'),
(157300, 11155, 'Nao Consigo Te Alcancar [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440222.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vvnjA1UYbCToWvbLP6hwa1f3Qp.jpg'),
(157301, 11155, 'Nao Consigo Te Alcancar [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440223.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lGShNhX1DNex8CLAfXrl4eHX0Rk.jpg'),
(157302, 11155, 'Nao Consigo Te Alcancar [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440224.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hH1xvQ49QLrveMjhaSF10Z9C82c.jpg'),
(157303, 11155, 'Nao Consigo Te Alcancar [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440225.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sYaMxOtwXbDfNhZ8AzlItiAIbop.jpg'),
(157304, 11155, 'Nao Consigo Te Alcancar [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440226.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lUxpkp3PBIQrqL6u22WIdvqJ2Po.jpg'),
(157305, 11155, 'Nao Consigo Te Alcancar [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440227.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rRxPhwxxeFl608lmflTTxUcF3EU.jpg'),
(157306, 11155, 'Nao Consigo Te Alcancar [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440228.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/drHcQYbZ5mB0K2UZC6HlBmLSHC2.jpg'),
(157307, 11155, 'Nao Consigo Te Alcancar [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440229.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lU9RzoHGt5XJ5AlWmzVV2zAy5nm.jpg'),
(157308, 11156, 'O Fantasma Do Metro [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440206.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3pFw9D68BZUqVZTWfkMDiyrbEON.jpg'),
(157309, 11156, 'O Fantasma Do Metro [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440207.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4jpgFfFOEXwAJ1SfKv1Eq80ZmxJ.jpg'),
(157310, 11156, 'O Fantasma Do Metro [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440208.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/euMgPh9MSeUJYQiQ259zNzlJh4D.jpg'),
(157311, 11156, 'O Fantasma Do Metro [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440209.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dYr4f8aDCzRaWubBBfFbelwofUx.jpg'),
(157312, 11156, 'O Fantasma Do Metro [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440210.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5TzHqQ3u6BNqBQHO3XN3wa6vub0.jpg'),
(157313, 11156, 'O Fantasma Do Metro [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440211.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nTODxsIrNEedQE0OspjFxQowntD.jpg'),
(157314, 11156, 'O Fantasma Do Metro [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440212.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xYEEEMVnMZEIdUpA9JsPvnqUNbB.jpg'),
(157315, 11156, 'O Fantasma Do Metro [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440213.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/29UXj3cErRLwsvtKO7QH3xjxMJo.jpg'),
(157316, 11156, 'O Fantasma Do Metro [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/440214.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6Bi2OmVGuSayrUewwJOqSxK7hyC.jpg'),
(157317, 11156, 'O Fantasma Do Metro [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/440215.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6SE4mFXFSK0YRZzNzIpkfUfEFmY.jpg'),
(157318, 11156, 'O Fantasma Do Metro [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/440216.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cuq1QfV0rQoxnnnkV7all5JVNR7.jpg'),
(157319, 11156, 'O Fantasma Do Metro [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/440217.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gi8HT6lrrwQWZgqtm9AWGeOjdsw.jpg'),
(157320, 11156, 'O Fantasma Do Metro [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/440218.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4SUjkR5tXMgaGvcfai2o5qyIhnm.jpg'),
(157321, 11156, 'O Fantasma Do Metro [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/440219.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rSGqs6NbFFa5estY7vasmVGE3be.jpg'),
(157322, 11156, 'O Fantasma Do Metro [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/440220.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9rScSIU0DFiN8MhnGuW0JnC6cvH.jpg'),
(157323, 11156, 'O Fantasma Do Metro [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/440221.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cMndTBbnGskQrEYYq3uja7qU2zv.jpg'),
(157324, 11157, 'O Guardiao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157325, 11157, 'O Guardiao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157326, 11157, 'O Guardiao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157327, 11157, 'O Guardiao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157328, 11157, 'O Guardiao [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157329, 11157, 'O Guardiao [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157330, 11157, 'O Guardiao [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157331, 11157, 'O Guardiao [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157332, 11157, 'O Guardiao [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/440182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157333, 11157, 'O Guardiao [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/440183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157334, 11157, 'O Guardiao [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/440184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157335, 11157, 'O Guardiao [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/440185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157336, 11157, 'O Guardiao [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/440186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157337, 11157, 'O Guardiao [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/440187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157338, 11157, 'O Guardiao [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/440188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157339, 11157, 'O Guardiao [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/440189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157340, 11157, 'O Guardiao [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/440190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157341, 11157, 'O Guardiao [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/440191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157342, 11157, 'O Guardiao [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/440192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157343, 11157, 'O Guardiao [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/440193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157344, 11157, 'O Guardiao [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/440194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157345, 11157, 'O Guardiao [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/440195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157346, 11157, 'O Guardiao [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/440196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157347, 11157, 'O Guardiao [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/440197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157348, 11157, 'O Guardiao [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/440198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157349, 11157, 'O Guardiao [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/440199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157350, 11157, 'O Guardiao [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/440200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157351, 11157, 'O Guardiao [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/440201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157352, 11157, 'O Guardiao [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/440202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157353, 11157, 'O Guardiao [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/440203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157354, 11157, 'O Guardiao [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/440204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157355, 11157, 'O Guardiao [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/440205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8LpDWrgaF9F9cIx5lisUdAYI2BU.jpg'),
(157356, 11158, 'Old Fashion Cupcake [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440169.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iz8IepnUfa6O2YJLWvLgovaDAy2.jpg'),
(157357, 11158, 'Old Fashion Cupcake [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440170.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xge7TnBu1AHlkrMLcvhzqmq9AFH.jpg'),
(157358, 11158, 'Old Fashion Cupcake [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440171.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fKHjZOqRBYfzKNcSmz31qZFNwy1.jpg'),
(157359, 11158, 'Old Fashion Cupcake [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440172.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4wWcvxiQ1mH78n13NnNKoPctvQ0.jpg'),
(157360, 11158, 'Old Fashion Cupcake [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440173.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vvOZ9HyZ2lQUPeuT4HO1NuDBaxD.jpg'),
(157361, 11159, 'One Room Angel [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440163.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bErqV4cZ8KC3eD1zuOwM7hgVVQF.jpg'),
(157362, 11159, 'One Room Angel [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440164.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lMbgLb0i1fkuqvAGdvRo1YzapDk.jpg'),
(157363, 11159, 'One Room Angel [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440165.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sOvqEZ1QOnMtFUFT8crJh6dnvej.jpg'),
(157364, 11159, 'One Room Angel [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440166.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tY8pOZEqhMAm5TN73skIC6xWEJN.jpg'),
(157365, 11159, 'One Room Angel [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440167.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2xG5TxrHr50dwj0GM7EaFsIa1IR.jpg'),
(157366, 11159, 'One Room Angel [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440168.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AujMtU75NP3TZLpyYhjilKyjl9n.jpg'),
(157367, 11160, 'Our Skyy 2 [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440147.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jCfh5GopUDFBD8thFD4l7pC6aUm.jpg'),
(157368, 11160, 'Our Skyy 2 [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440148.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9VINHrxdmiQapr9x9T9CPQwlhtE.jpg'),
(157369, 11160, 'Our Skyy 2 [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440149.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hm3aly1jIMPbDWROFibUyq9Qiob.jpg'),
(157370, 11160, 'Our Skyy 2 [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440150.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q8BWHuFmNDUZWHrLKnsPdlr0zzk.jpg'),
(157371, 11160, 'Our Skyy 2 [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440151.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k6L75b4Mat2bRdhHB552hCgucRx.jpg'),
(157372, 11160, 'Our Skyy 2 [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440152.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k6L75b4Mat2bRdhHB552hCgucRx.jpg'),
(157373, 11160, 'Our Skyy 2 [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440153.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gDEkkHeJVVhZpfVfrkVzvNX02Vt.jpg'),
(157374, 11160, 'Our Skyy 2 [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440154.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gDEkkHeJVVhZpfVfrkVzvNX02Vt.jpg'),
(157375, 11160, 'Our Skyy 2 [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/440155.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nQfifyqcUPGDJffoCsgm4aEyAhY.jpg'),
(157376, 11160, 'Our Skyy 2 [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/440156.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nQfifyqcUPGDJffoCsgm4aEyAhY.jpg'),
(157377, 11160, 'Our Skyy 2 [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/440157.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wnfBhyXd3d5kF9HDSLgeJ8h79KU.jpg'),
(157378, 11160, 'Our Skyy 2 [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/440158.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wnfBhyXd3d5kF9HDSLgeJ8h79KU.jpg'),
(157379, 11160, 'Our Skyy 2 [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/440159.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1DSHKl3PiZiCbApT0Yeo5sgW7qb.jpg'),
(157380, 11160, 'Our Skyy 2 [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/440160.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w5HRL1YbcKsWstOc0x2F98J8GYX.jpg'),
(157381, 11160, 'Our Skyy 2 [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/440161.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w5HRL1YbcKsWstOc0x2F98J8GYX.jpg'),
(157382, 11160, 'Our Skyy 2 [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/440162.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6rswK1tGHygPJwer7Nojl3APj4b.jpg'),
(157383, 11161, 'Our Skyy [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440142.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8yH1j0ttzIkGYdiNqVyljuIyE1N.jpg'),
(157384, 11161, 'Our Skyy [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440143.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/39g9Kl9P38ulc0qHBR2DoEkimbO.jpg'),
(157385, 11161, 'Our Skyy [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440144.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/39g9Kl9P38ulc0qHBR2DoEkimbO.jpg'),
(157386, 11161, 'Our Skyy [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440145.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gy9WPjTKUj88zzoDXW7rR1deygm.jpg'),
(157387, 11161, 'Our Skyy [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440146.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z57GxaBhhyfBNK9OngRPcmA9s67.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(157388, 11162, 'Perfect Propose [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440136.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gNFnANs5VMyN4zN9B3jrJrV0sqC.jpg'),
(157389, 11162, 'Perfect Propose [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440137.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lvupbq7vqbyQ1ca4WERHJxOHCin.jpg'),
(157390, 11162, 'Perfect Propose [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440138.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/txYnNor7t6Nriei2AKVIgZ8UUqk.jpg'),
(157391, 11162, 'Perfect Propose [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440139.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2CEqUCmhiqj0KQ63TboVEabFsVI.jpg'),
(157392, 11162, 'Perfect Propose [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440140.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fNs1TBd10fHUCavQyV6S6fSJ0Pd.jpg'),
(157393, 11162, 'Perfect Propose [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440141.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tpV91IMOAWOx8OX1lYSVOwkiCLi.jpg'),
(157394, 11163, 'Rei Charly [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/616583.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pViWvhhdBnSpCvWGsyVrPXWyqCt.jpg'),
(157395, 11163, 'Rei Charly [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/616585.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9sQskrbTzHRCU2v0UtnL2uZItrG.jpg'),
(157396, 11163, 'Rei Charly [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/616588.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yI6FhMTNzYHUXyc2lHNZusILsz.jpg'),
(157397, 11163, 'Rei Charly [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/616589.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5hCZVeJBLmX785oaMqlr2SGQvvW.jpg'),
(157398, 11163, 'Rei Charly [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/616592.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d6evvvHJlGgIMzkayNsX9ACp1B6.jpg'),
(157399, 11163, 'Rei Charly [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/616594.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qZ4zlpdx80Ry2930IpPqZdKpj3l.jpg'),
(157400, 11163, 'Rei Charly [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/616595.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uGrGv1YOR8Z3OOyUArNt6cmMj2Z.jpg'),
(157401, 11163, 'Rei Charly [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/616597.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/PZNLG9aureXlPlvenLF44AH6jK.jpg'),
(157402, 11164, 'Sky in Your Heart [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440112.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ty9shdQumi2P8V3hUkmCjvhgqjO.jpg'),
(157403, 11164, 'Sky in Your Heart [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440113.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3hYd9hG5btpr4PjG5XU3IEYjq5S.jpg'),
(157404, 11164, 'Sky in Your Heart [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440114.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wOE8vqVLHCHkkGVmvMQZZsMYzwm.jpg'),
(157405, 11164, 'Sky in Your Heart [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440115.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aOiy2DYRLxON6PtIrxlkpxBLKEz.jpg'),
(157406, 11164, 'Sky in Your Heart [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440116.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nybA3E4vaDxv9WJWtj7FNzQzNCN.jpg'),
(157407, 11164, 'Sky in Your Heart [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440117.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kiAtZuY3cMxUDrEs3imeCF7PKZO.jpg'),
(157408, 11164, 'Sky in Your Heart [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440118.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dzNW6nEC8dJNYeGubHGtgdl4qcb.jpg'),
(157409, 11164, 'Sky in Your Heart [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440119.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ntOD96sp46uuKoGIwe4Brw46qLn.jpg'),
(157410, 11165, 'Solteira Astuta [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440096.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/znna3iaOGeZKCSz9nFuVyA9u9fN.jpg'),
(157411, 11165, 'Solteira Astuta [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440097.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9EmZkjidSYkEccKI6tynlo4ulrP.jpg'),
(157412, 11165, 'Solteira Astuta [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440098.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/YNrvyUBlLXy9KYiBoaNBSElxMS.jpg'),
(157413, 11165, 'Solteira Astuta [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440099.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1RhiZhlPyXzacecpNIR3otwbr9n.jpg'),
(157414, 11165, 'Solteira Astuta [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440100.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A6UVewrg8QeP0dkIYo1CHIQfYL3.jpg'),
(157415, 11165, 'Solteira Astuta [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440101.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/naknRfFTihg0QXlJ8vaaXd34S4R.jpg'),
(157416, 11165, 'Solteira Astuta [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440102.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g5escPm4QK3VusjhGboR5lfycGl.jpg'),
(157417, 11165, 'Solteira Astuta [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440103.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jjWwAocFfMTAsswU9UEh9LNcaDU.jpg'),
(157418, 11165, 'Solteira Astuta [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/440104.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aylRTufhFIv2VOYnQLkaeEKtGNb.jpg'),
(157419, 11165, 'Solteira Astuta [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/440105.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eZVNYRn0rckMURR7hOtetybI0I6.jpg'),
(157420, 11165, 'Solteira Astuta [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/440106.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yrKMQFiSOFVmARscpOIgIM8p5Zp.jpg'),
(157421, 11165, 'Solteira Astuta [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/440107.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tzUp9ZLeUUdeNg8VBEntuTNTd9B.jpg'),
(157422, 11165, 'Solteira Astuta [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/440108.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5djW0GBTHh7lqFz3Si84qRzRh1x.jpg'),
(157423, 11165, 'Solteira Astuta [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/440109.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x0pPZaJjQH3DplvgCerv2c009h4.jpg'),
(157424, 11165, 'Solteira Astuta [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/440110.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/52Q4wh3XrzbvIxJIXcddaU7GNY1.jpg'),
(157425, 11165, 'Solteira Astuta [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/440111.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fMG8u6WHTa98Tu0Txwz9fCQBmSr.jpg'),
(157426, 11166, 'Su Ji and U Ri [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440066.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d8EYsqqHpyHNSYteyTVqIgoW2jN.jpg'),
(157427, 11166, 'Su Ji and U Ri [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440067.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3jDMDOoxKFVvxEOIkYReUM5eTik.jpg'),
(157428, 11166, 'Su Ji and U Ri [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440068.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/blPdabkNt2v8HPWRwsgMKBinr3K.jpg'),
(157429, 11166, 'Su Ji and U Ri [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440069.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tMAjOLvB7llAI1wVEC6tDXS1xdP.jpg'),
(157430, 11166, 'Su Ji and U Ri [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440070.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zuYaY9uZRkyWPw7g6jc1sMidCnd.jpg'),
(157431, 11166, 'Su Ji and U Ri [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440071.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ajanWvvfXWUwpdrbYKudh9vsnc7.jpg'),
(157432, 11166, 'Su Ji and U Ri [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440072.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ppsgf2A4pnkmpgPtr1EAj6WxrIE.jpg'),
(157433, 11166, 'Su Ji and U Ri [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440073.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7b2q3CAWOj20rEs72yKfMeOZDrS.jpg'),
(157434, 11166, 'Su Ji and U Ri [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/440074.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/C6GBwcN40yKI9kGrmHRyqCpbwk.jpg'),
(157435, 11166, 'Su Ji and U Ri [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/440075.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ehdnIf4ifpbu74Ogg3w5uWEQKpD.jpg'),
(157436, 11166, 'Su Ji and U Ri [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/440076.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aSXyGdaxszDXOwqGC0kYqUyyKmV.jpg'),
(157437, 11166, 'Su Ji and U Ri [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/440077.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8yWibxqqSTIyJb8hRm9wKXk6QUp.jpg'),
(157438, 11166, 'Su Ji and U Ri [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/440078.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kssYpXupZkCm5jVnr3A5lkOghK6.jpg'),
(157439, 11166, 'Su Ji and U Ri [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/440079.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dFNkmgM0Hao5N24p84UMgWiiYXx.jpg'),
(157440, 11166, 'Su Ji and U Ri [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/440080.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ubD8mCzX57i5lmXVcGv7Qkbpzuj.jpg'),
(157441, 11166, 'Su Ji and U Ri [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/440081.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nl2JtH3Snwd2tMeDNltFe8U9Fhm.jpg'),
(157442, 11166, 'Su Ji and U Ri [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/440082.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oHJiDI6tzSRDEBVf2YT0TCyIuKU.jpg'),
(157443, 11166, 'Su Ji and U Ri [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/440083.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p0iQNXESm3lOqjUZCme0Spu75bb.jpg'),
(157444, 11166, 'Su Ji and U Ri [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/440084.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aDUmSMfpnMttD17sPhknDj9MTQo.jpg'),
(157445, 11166, 'Su Ji and U Ri [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/440085.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k3wmy34u5qL06fql4xxjjkG8KbJ.jpg'),
(157446, 11166, 'Su Ji and U Ri [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/440086.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cZCQAwlPPoJvlFYCahtyIxSnRqt.jpg'),
(157447, 11166, 'Su Ji and U Ri [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/440087.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wkmDDbqSfyUL0zHPir2voh4b1Tc.jpg'),
(157448, 11166, 'Su Ji and U Ri [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/440088.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2wXKQwEcRyFPIcmzKjws9B4azSn.jpg'),
(157449, 11166, 'Su Ji and U Ri [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/440089.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7OTFs4G5EZhlOHFrU24wDPdfHFY.jpg'),
(157450, 11166, 'Su Ji and U Ri [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/440090.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7uRas8CELpebtev7J2BOaYFHol1.jpg'),
(157451, 11166, 'Su Ji and U Ri [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/440091.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uCcXOnjEabzQa4oHxbuxFgWpKKF.jpg'),
(157452, 11166, 'Su Ji and U Ri [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/440092.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jKfK0PtwWHR2pkI8rWpczkDVZdz.jpg'),
(157453, 11166, 'Su Ji and U Ri [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/440093.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yHqkcKxEsYoBsrJsvjGdVH4pz8a.jpg'),
(157454, 11166, 'Su Ji and U Ri [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/440094.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cQFdYNmY2RQOGrzDJ2bR1jg1W7A.jpg'),
(157455, 11166, 'Su Ji and U Ri [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/440095.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1xfqJUnVxH0voLcumyfhoYGCuB0.jpg'),
(157456, 11166, 'Su Ji and U Ri [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/445559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157457, 11166, 'Su Ji and U Ri [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/445560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157458, 11166, 'Su Ji and U Ri [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/445561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157459, 11166, 'Su Ji and U Ri [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/445562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157460, 11166, 'Su Ji and U Ri [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/445563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157461, 11166, 'Su Ji and U Ri [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/445564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157462, 11166, 'Su Ji and U Ri [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/445565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157463, 11166, 'Su Ji and U Ri [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/445566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157464, 11166, 'Su Ji and U Ri [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/445567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157465, 11166, 'Su Ji and U Ri [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/445568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157466, 11166, 'Su Ji and U Ri [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/445569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157467, 11166, 'Su Ji and U Ri [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/449729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157468, 11166, 'Su Ji and U Ri [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/449730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157469, 11166, 'Su Ji and U Ri [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/449731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157470, 11166, 'Su Ji and U Ri [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/449732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157471, 11166, 'Su Ji and U Ri [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/449733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157472, 11166, 'Su Ji and U Ri [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/449734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157473, 11166, 'Su Ji and U Ri [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/449735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157474, 11166, 'Su Ji and U Ri [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/449736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157475, 11166, 'Su Ji and U Ri [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/449737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157476, 11166, 'Su Ji and U Ri [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/449738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157477, 11166, 'Su Ji and U Ri [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/449739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157478, 11166, 'Su Ji and U Ri [L] S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/449740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157479, 11166, 'Su Ji and U Ri [L] S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/449741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157480, 11166, 'Su Ji and U Ri [L] S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/451869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157481, 11166, 'Su Ji and U Ri [L] S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/451870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157482, 11166, 'Su Ji and U Ri [L] S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/451871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157483, 11166, 'Su Ji and U Ri [L] S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/451872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157484, 11166, 'Su Ji and U Ri [L] S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/451873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157485, 11166, 'Su Ji and U Ri [L] S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/451874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157486, 11166, 'Su Ji and U Ri [L] S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/451875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157487, 11166, 'Su Ji and U Ri [L] S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/451876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157488, 11166, 'Su Ji and U Ri [L] S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/451877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157489, 11166, 'Su Ji and U Ri [L] S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/451878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157490, 11166, 'Su Ji and U Ri [L] S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/451879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157491, 11166, 'Su Ji and U Ri [L] S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/451880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157492, 11166, 'Su Ji and U Ri [L] S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/451881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157493, 11166, 'Su Ji and U Ri [L] S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/451882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157494, 11166, 'Su Ji and U Ri [L] S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/451883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157495, 11166, 'Su Ji and U Ri [L] S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/451884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157496, 11166, 'Su Ji and U Ri [L] S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/451885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157497, 11166, 'Su Ji and U Ri [L] S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/451886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157498, 11166, 'Su Ji and U Ri [L] S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/451887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157499, 11166, 'Su Ji and U Ri [L] S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/451888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157500, 11166, 'Su Ji and U Ri [L] S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/451889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157501, 11166, 'Su Ji and U Ri [L] S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/451890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157502, 11166, 'Su Ji and U Ri [L] S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/451891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157503, 11166, 'Su Ji and U Ri [L] S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/451892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157504, 11166, 'Su Ji and U Ri [L] S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/451893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157505, 11166, 'Su Ji and U Ri [L] S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/451894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157506, 11166, 'Su Ji and U Ri [L] S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/451895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157507, 11166, 'Su Ji and U Ri [L] S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/451896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157508, 11166, 'Su Ji and U Ri [L] S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/451897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157509, 11166, 'Su Ji and U Ri [L] S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/451898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157510, 11166, 'Su Ji and U Ri [L] S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/451899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157511, 11166, 'Su Ji and U Ri [L] S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/451900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157512, 11166, 'Su Ji and U Ri [L] S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/451901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157513, 11166, 'Su Ji and U Ri [L] S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/451902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157514, 11166, 'Su Ji and U Ri [L] S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/451903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157515, 11166, 'Su Ji and U Ri [L] S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/451904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157516, 11166, 'Su Ji and U Ri [L] S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/451905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157517, 11166, 'Su Ji and U Ri [L] S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/451906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157518, 11166, 'Su Ji and U Ri [L] S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/451907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157519, 11166, 'Su Ji and U Ri [L] S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/451908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157520, 11166, 'Su Ji and U Ri [L] S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/451909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157521, 11166, 'Su Ji and U Ri [L] S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/451910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157522, 11166, 'Su Ji and U Ri [L] S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/451911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157523, 11166, 'Su Ji and U Ri [L] S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/451912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157524, 11166, 'Su Ji and U Ri [L] S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/451913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157525, 11166, 'Su Ji and U Ri [L] S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/451914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157526, 11166, 'Su Ji and U Ri [L] S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/451915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157527, 11166, 'Su Ji and U Ri [L] S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/451916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157528, 11166, 'Su Ji and U Ri [L] S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/451917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157529, 11166, 'Su Ji and U Ri [L] S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/451918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157530, 11166, 'Su Ji and U Ri [L] S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/451919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157531, 11166, 'Su Ji and U Ri [L] S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/451920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157532, 11166, 'Su Ji and U Ri [L] S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/451921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157533, 11166, 'Su Ji and U Ri [L] S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/451922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157534, 11166, 'Su Ji and U Ri [L] S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/451923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157535, 11166, 'Su Ji and U Ri [L] S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/471875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157536, 11166, 'Su Ji and U Ri [L] S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/471876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157537, 11166, 'Su Ji and U Ri [L] S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/471877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157538, 11166, 'Su Ji and U Ri [L] S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/471878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157539, 11166, 'Su Ji and U Ri [L] S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/471879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157540, 11166, 'Su Ji and U Ri [L] S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/471880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157541, 11166, 'Su Ji and U Ri [L] S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/471881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157542, 11166, 'Su Ji and U Ri [L] S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/471882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157543, 11166, 'Su Ji and U Ri [L] S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/471883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157544, 11166, 'Su Ji and U Ri [L] S01 E119', 'http://sinalprivado.info:80/series/1533784/1533784/471884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157545, 11166, 'Su Ji and U Ri [L] S01 E120', 'http://sinalprivado.info:80/series/1533784/1533784/471885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157546, 11166, 'Su Ji and U Ri [L] S01 E121', 'http://sinalprivado.info:80/series/1533784/1533784/471886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157547, 11166, 'Su Ji and U Ri [L] S01 E122', 'http://sinalprivado.info:80/series/1533784/1533784/471887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157548, 11166, 'Su Ji and U Ri [L] S01 E123', 'http://sinalprivado.info:80/series/1533784/1533784/471888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157549, 11166, 'Su Ji and U Ri [L] S01 E124', 'http://sinalprivado.info:80/series/1533784/1533784/471889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157550, 11166, 'Su Ji and U Ri [L] S01 E125', 'http://sinalprivado.info:80/series/1533784/1533784/471890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157551, 11166, 'Su Ji and U Ri [L] S01 E126', 'http://sinalprivado.info:80/series/1533784/1533784/471891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157552, 11166, 'Su Ji and U Ri [L] S01 E127', 'http://sinalprivado.info:80/series/1533784/1533784/471892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157553, 11166, 'Su Ji and U Ri [L] S01 E128', 'http://sinalprivado.info:80/series/1533784/1533784/471893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rSaNeXzL7NBqCyEMy9kD5W4X5w7.jpg'),
(157554, 11167, 'Taxista [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440034.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eF7IwMGnldHNVJH5LxtwIDxyqnU.jpg'),
(157555, 11167, 'Taxista [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440035.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lAYJa6ZUhdMy2WncH7anZqszx4C.jpg'),
(157556, 11167, 'Taxista [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440036.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rjUc73nYQbQkvAlw69i7MGraBG2.jpg'),
(157557, 11167, 'Taxista [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440037.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kftXlz0UVz8dhbMERbEouQ5DDo4.jpg'),
(157558, 11167, 'Taxista [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440038.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kGFcbSgZwLZFuI65DzTW3LkF1O2.jpg'),
(157559, 11167, 'Taxista [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440039.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bQWPKz2wF1Ie1v79EH6KmZDDoBN.jpg'),
(157560, 11167, 'Taxista [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440040.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vNnCIUEfQ69fLwZKFjvKpUFlBfS.jpg'),
(157561, 11167, 'Taxista [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440041.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7xtgaaLwfbk3yC8KbkXq2gtmrWF.jpg'),
(157562, 11167, 'Taxista [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/440042.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b5mnFW5iKZLRW6kOS6DBsOLXI29.jpg'),
(157563, 11167, 'Taxista [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/440043.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/76aS493KzIsjQguatMtL1dXS3SQ.jpg'),
(157564, 11167, 'Taxista [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/440044.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zpq9UypkaeXoviWJU68Yqjcfb2Z.jpg'),
(157565, 11167, 'Taxista [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/440045.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9lPkFoibkupAtHp6ekJE6wPaihC.jpg'),
(157566, 11167, 'Taxista [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/440046.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rattmhTSAGreBU2BhMm010l5o5Y.jpg'),
(157567, 11167, 'Taxista [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/440047.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rhratfHgoIDGJd5Drgv9DCeGlyD.jpg'),
(157568, 11167, 'Taxista [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/440048.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6jO2H4Yxobm8eou4Uj8ooR0SmZm.jpg'),
(157569, 11167, 'Taxista [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/440049.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bLrN2tNMmsijOhXtdXdFQ6pdCyn.jpg'),
(157570, 11168, 'Taxista [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440050.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fVY8GhNx6u650PpnUGXrjpZpLNH.jpg'),
(157571, 11168, 'Taxista [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440051.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gH4L0RQMhgTC0C1SZ99ruBZH0Cd.jpg'),
(157572, 11168, 'Taxista [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440052.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vDn6UeGwpACNcCpypAEqqk6rJYq.jpg'),
(157573, 11168, 'Taxista [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440053.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v2VKIiUynRcMjQrrt0rKAujIFX3.jpg'),
(157574, 11168, 'Taxista [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440054.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hTYhEUPEhA67Esdudt3Y5ZoRcnh.jpg'),
(157575, 11168, 'Taxista [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440055.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gmCI5tWukhCNCtMcgYMwlSRpzER.jpg'),
(157576, 11168, 'Taxista [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440056.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k79bAI6lkun0n1lige7cf65P3mD.jpg'),
(157577, 11168, 'Taxista [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440057.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fhj8VQOrD8hGYlNsOiNxNHUXoEz.jpg'),
(157578, 11168, 'Taxista [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/440058.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sOvU9zHDYonsSVlpqMw3H5pWt6u.jpg'),
(157579, 11168, 'Taxista [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/440059.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nmRG3jo7vEgOVBZ9vDuS5b2cIZ4.jpg'),
(157580, 11168, 'Taxista [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/440060.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8yuj6rxN6g6YdKym1F1MalhQ241.jpg'),
(157581, 11168, 'Taxista [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/440061.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kj00Xcv3MTNJK1G3vYtCHpnzxfm.jpg'),
(157582, 11168, 'Taxista [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/440062.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8fskYmiHpGHDiQ26EQNVYjKZiCy.jpg'),
(157583, 11168, 'Taxista [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/440063.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pLR5zpq8U0n5TCJqI2hVE2tYCZi.jpg'),
(157584, 11168, 'Taxista [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/440064.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aaKifSPdDJhR1MlB9O8xKkaqtKn.jpg'),
(157585, 11168, 'Taxista [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/440065.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2RUS5ltv55WPAexo7orGr4gbPRr.jpg'),
(157586, 11169, 'The Accident [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440030.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3tTpwFxgwoKMqwhCUaItUwMMXS9.jpg'),
(157587, 11169, 'The Accident [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440031.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ArtIpajaH17ZfZq7QDAmfQDZm4n.jpg'),
(157588, 11169, 'The Accident [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440032.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y1QoMBT7ShmT7lhoy6vFMrDkAry.jpg'),
(157589, 11169, 'The Accident [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440033.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7eE4CJGkOeRQg8WXF1MqlmZSG1H.jpg'),
(157590, 11170, 'The On1y One [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440028.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/haQUu3ve7mfJ94JHrj2NJm5PxxR.jpg'),
(157591, 11170, 'The On1y One [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440029.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jt49JwYaW2GgpQHXNI7UJWte1fH.jpg'),
(157592, 11170, 'The On1y One [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jpFsRkgXExjHqi5gdThAqjXZ9XC.jpg'),
(157593, 11170, 'The On1y One [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jpFsRkgXExjHqi5gdThAqjXZ9XC.jpg'),
(157594, 11170, 'The On1y One [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jpFsRkgXExjHqi5gdThAqjXZ9XC.jpg'),
(157595, 11170, 'The On1y One [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jpFsRkgXExjHqi5gdThAqjXZ9XC.jpg'),
(157596, 11170, 'The On1y One [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/451813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jpFsRkgXExjHqi5gdThAqjXZ9XC.jpg'),
(157597, 11170, 'The On1y One [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/451814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jpFsRkgXExjHqi5gdThAqjXZ9XC.jpg'),
(157598, 11170, 'The On1y One [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/458899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jpFsRkgXExjHqi5gdThAqjXZ9XC.jpg'),
(157599, 11170, 'The On1y One [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/458900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jpFsRkgXExjHqi5gdThAqjXZ9XC.jpg'),
(157600, 11170, 'The On1y One [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/463615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jpFsRkgXExjHqi5gdThAqjXZ9XC.jpg'),
(157601, 11170, 'The On1y One [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/463616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jpFsRkgXExjHqi5gdThAqjXZ9XC.jpg'),
(157602, 11171, 'Too Good to Be True [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440024.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gih2qgDHclvjyj0Imv8piGglbJd.jpg'),
(157603, 11171, 'Too Good to Be True [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440025.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ll6JKK1yFVHMrmIFFoQqtELU7f9.jpg'),
(157604, 11171, 'Too Good to Be True [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440026.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xplS9SrA2rU4bOHuZ93n9OgBp3a.jpg'),
(157605, 11171, 'Too Good to Be True [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440027.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1ENjg1vaTJJYf0Vh1xhINmNGHRE.jpg'),
(157606, 11172, 'Toquio em Abril E... [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440016.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9R5n1dSpRhmNRUmO1pI4faNOza9.jpg'),
(157607, 11172, 'Toquio em Abril E... [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zIZNFyXsLaKMDIydKWqYBVw2YcY.jpg'),
(157608, 11172, 'Toquio em Abril E... [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440018.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4VxdCxs5veTMqxxoacrRsFAScLP.jpg'),
(157609, 11172, 'Toquio em Abril E... [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zIZNFyXsLaKMDIydKWqYBVw2YcY.jpg'),
(157610, 11172, 'Toquio em Abril E... [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440020.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xmq0RIPis3Fk5XIMUORkKqJiWOl.jpg'),
(157611, 11172, 'Toquio em Abril E... [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440021.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6XQGBWRCEGEPu6FJSyUkP2CXSxT.jpg'),
(157612, 11172, 'Toquio em Abril E... [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440022.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jUZFwzm5xAPkV2Qp1OQdPE2MUK.jpg'),
(157613, 11172, 'Toquio em Abril E... [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440023.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rV0ZZsfbF8n11dkR6k8ARvN5Vrj.jpg'),
(157614, 11173, 'Troppo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440000.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/be0vvmDcMNfO54D6OXiJIbU2XOi.jpg'),
(157615, 11173, 'Troppo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440001.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zOYro3TDbAqcv04CrsIpdu2kZuT.jpg'),
(157616, 11173, 'Troppo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440002.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5My3IcR3K3tXzCKgMdsqp9xnfHJ.jpg'),
(157617, 11173, 'Troppo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440003.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nkHIZmtmNufbpHWUsmf3lxmbDoi.jpg'),
(157618, 11173, 'Troppo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440004.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7OFxTF0zM9t9Xq45gPHCH4vu4Am.jpg'),
(157619, 11173, 'Troppo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440005.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x7jklxAyEapcv1dXIqBSJ5jziOr.jpg'),
(157620, 11173, 'Troppo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440006.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qaEkTkfle0Yci5FU0d9q0ESmaR7.jpg'),
(157621, 11173, 'Troppo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440007.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qJrVwjfXEqSHk0Wdu6X9Rlr2RTg.jpg'),
(157622, 11174, 'Troppo [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/440008.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wxeiujZpLErLeJmatQecswa6tqu.jpg'),
(157623, 11174, 'Troppo [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/440009.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ql3y4k8plca1JQetsCatO8ltiNR.jpg'),
(157624, 11174, 'Troppo [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/440010.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tovd4egMO7iZ3i1PYli5jOhtd7e.jpg'),
(157625, 11174, 'Troppo [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/440011.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6Q5apo1b7C6bXi0lGmKe5EoaPfg.jpg'),
(157626, 11174, 'Troppo [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/440012.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/suHhSIjFmF6QAZM1JYIL5PTt4ju.jpg'),
(157627, 11174, 'Troppo [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/440013.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7WntUqfZsbI4MRSjMlokB6ldZ7l.jpg'),
(157628, 11174, 'Troppo [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/440014.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8AFq2WxkwWPjieRWMRjLfsSQF12.jpg'),
(157629, 11174, 'Troppo [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/440015.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fGfnFY6QmpaU9Yt9YM1J3FwmSrY.jpg'),
(157630, 11175, 'Um Belo Dia para Morrer [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439968.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ujnUB1IEyLpWQvs97iQr4X2maPD.jpg'),
(157631, 11175, 'Um Belo Dia para Morrer [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439969.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4DGDF91JKbAEofVI2zKoPDF0ks5.jpg'),
(157632, 11175, 'Um Belo Dia para Morrer [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439970.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oabCILYbCtaJlQgDgtrZDL4sle2.jpg'),
(157633, 11175, 'Um Belo Dia para Morrer [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439971.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lltj1qw070ZBtmSa4Hto9h1otPs.jpg'),
(157634, 11175, 'Um Belo Dia para Morrer [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439972.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Er7ibkInG5Px4ZyqGnhl1vu1L4.jpg'),
(157635, 11175, 'Um Belo Dia para Morrer [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439973.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jL81qLoZ18HpO8gNLuWdqDPxiOG.jpg'),
(157636, 11175, 'Um Belo Dia para Morrer [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439974.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kj8lOdTUxBdgyzAuhJ4mdu7uBCH.jpg'),
(157637, 11175, 'Um Belo Dia para Morrer [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/439975.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tOLNXgFCu1y1XRoE47mSwz25ORN.jpg'),
(157638, 11175, 'Um Belo Dia para Morrer [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/439976.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/621O5s94Op3vHU2PHHa22FST6Fd.jpg'),
(157639, 11175, 'Um Belo Dia para Morrer [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/439977.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kb30GfFZ8XOspw45EBBsi1dSAY0.jpg'),
(157640, 11175, 'Um Belo Dia para Morrer [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/439978.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oEjdOiDcCFxAkwKZzA0JuycgnPy.jpg'),
(157641, 11175, 'Um Belo Dia para Morrer [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/439979.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/30AThwJzxovTOFZcJ5ZdpUqQ3Jp.jpg'),
(157642, 11175, 'Um Belo Dia para Morrer [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/439980.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rOQddhJrWVl1zDcKI9nuSkECmOx.jpg'),
(157643, 11175, 'Um Belo Dia para Morrer [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/439981.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hZ5SnD5FsoNyAR7xKHn0yCmfmVW.jpg'),
(157644, 11175, 'Um Belo Dia para Morrer [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/439982.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aSE1967MtsCp2Yu7zu8vX7ZQwfZ.jpg'),
(157645, 11175, 'Um Belo Dia para Morrer [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/439983.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tQhlzh8xLDxaD7FO9lX7DtvaRwn.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(157646, 11175, 'Um Belo Dia para Morrer [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/439984.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3e78GNiAuxSQZqv8334f8F6m7yW.jpg'),
(157647, 11175, 'Um Belo Dia para Morrer [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/439985.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sgN1ZI3kbewJNRDXCCeQu2IQaQr.jpg'),
(157648, 11175, 'Um Belo Dia para Morrer [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/439986.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oH5o70jbFQhLcYPph3sFDNlifkP.jpg'),
(157649, 11175, 'Um Belo Dia para Morrer [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/439987.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tDVREepJSJd1tG6aYEcQwc9zhCo.jpg'),
(157650, 11175, 'Um Belo Dia para Morrer [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/439988.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vI4qZTJ1n8cHQzRxuoIq3CUuYN2.jpg'),
(157651, 11175, 'Um Belo Dia para Morrer [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/439989.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/glmTx0Hq2XFsHprt3BdemQjvpYA.jpg'),
(157652, 11175, 'Um Belo Dia para Morrer [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/439990.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v5on2JVZzxBUg4dyO7wn9JEIv9H.jpg'),
(157653, 11175, 'Um Belo Dia para Morrer [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/439991.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vtNfTqOHReOd7QXk4LIsxQWr3S8.jpg'),
(157654, 11175, 'Um Belo Dia para Morrer [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/439992.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yP16N2Jc1xEeyKSVm3pjTlSTYnL.jpg'),
(157655, 11175, 'Um Belo Dia para Morrer [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/439993.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r2rJ6LTnNZtZhNbPaEMf1WRKMQc.jpg'),
(157656, 11175, 'Um Belo Dia para Morrer [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/439994.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qP8Orv7YOA5q7mRpwhlMSIGhzUH.jpg'),
(157657, 11175, 'Um Belo Dia para Morrer [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/439995.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8eF5oPxfztdzjoDSvnaAfvzNZ4B.jpg'),
(157658, 11175, 'Um Belo Dia para Morrer [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/439996.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hOSw8ZBoai5jux5oUhfdcV1ctAL.jpg'),
(157659, 11175, 'Um Belo Dia para Morrer [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/439997.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7yP2RU2NfonaOvdL5bdlbuWxrfP.jpg'),
(157660, 11175, 'Um Belo Dia para Morrer [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/439998.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lMcZoM5JGG6WFVjdXFwclS09Jbg.jpg'),
(157661, 11175, 'Um Belo Dia para Morrer [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/439999.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uwHlyzdWgee38O2aTvONoyYwWwT.jpg'),
(157662, 8724, 'Um Lobo como Eu [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439955.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xS3KAd1FaZTj2rRYnckICe3enCH.jpg'),
(157663, 8724, 'Um Lobo como Eu [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439956.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hTdD85c6cUiogdXvcgnwALJI87J.jpg'),
(157664, 8724, 'Um Lobo como Eu [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439957.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AdbLTfgxdK1W6glG9PSFPyK9V5R.jpg'),
(157665, 8724, 'Um Lobo como Eu [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439958.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9zhgAYSQIJ0FT9BBM0CCB5X0tpg.jpg'),
(157666, 8724, 'Um Lobo como Eu [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439959.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j2rN07GyP87Ju4X9JzVBz6Dg8RD.jpg'),
(157667, 8724, 'Um Lobo como Eu [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439960.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u3OKzR26v8OeiZues7cdKIsKpYB.jpg'),
(157668, 8725, 'Um Lobo como Eu [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439961.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AkJ1QJDCY6mIlt9PBWCePftwm8q.jpg'),
(157669, 8725, 'Um Lobo como Eu [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439962.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qBmuBpVFuDbPylUuKdVjUra0o4H.jpg'),
(157670, 8725, 'Um Lobo como Eu [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439963.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xhIyG959R754aO0IOSwtB8u42Ka.jpg'),
(157671, 8725, 'Um Lobo como Eu [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439964.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aFFw0dPjqZv9JchLtjespW33xyy.jpg'),
(157672, 8725, 'Um Lobo como Eu [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439965.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ffyL5b5rYAAC3V3bgrM9en7nKBR.jpg'),
(157673, 8725, 'Um Lobo como Eu [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439966.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gGaLEJgNINWcGusTFfDUjkJaQRR.jpg'),
(157674, 8725, 'Um Lobo como Eu [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439967.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fkNJ0L2GV1cbQKIzfy4kHB2h6Qo.jpg'),
(157675, 11176, 'Viver para Dancar [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439950.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AjzD1YRDnXl9LmpBM2BJ4BtzuuT.jpg'),
(157676, 11176, 'Viver para Dancar [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439951.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ihuo6xfYY0PLRo4nPI24bRhkviC.jpg'),
(157677, 11176, 'Viver para Dancar [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439952.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cYpRlxmtkkEoM3MrxgmeOetdZl.jpg'),
(157678, 11176, 'Viver para Dancar [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439953.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iGFdEs01IZ7JVTT9SOUi999vpCJ.jpg'),
(157679, 11176, 'Viver para Dancar [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439954.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y3N6wlTFUVm5QgyVUHNMKyeJQFj.jpg'),
(157680, 11177, 'Whistle [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439936.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fw6FLA8U52ZVrrBFx5HXOci6J4J.jpg'),
(157681, 11177, 'Whistle [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439937.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/68k5w72gmCCfMMZRzCDrkoSlUB8.jpg'),
(157682, 11177, 'Whistle [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439938.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/caEGSRNzm8k3vtn9dL7b6h5H1Cu.jpg'),
(157683, 11177, 'Whistle [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439939.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pqW3m3FUrRnoJbUxF4skuL53Nsu.jpg'),
(157684, 11177, 'Whistle [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439940.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5ZZATbnrSjZ3s0meH1tQ44fBDSj.jpg'),
(157685, 11177, 'Whistle [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439941.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lQ4689LX8vpAINvKkazPDy4jqbS.jpg'),
(157686, 11177, 'Whistle [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439942.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8iuO9oxNA16AsIxk9RTCONUwA6j.jpg'),
(157687, 11177, 'Whistle [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/439943.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hyxRFAsDK6UaET9W5AfMuVc9Fjl.jpg'),
(157688, 11177, 'Whistle [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/439944.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aFsLqunA1veKEgQuAIc0OTTqxDf.jpg'),
(157689, 11177, 'Whistle [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/439945.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lyLrKdNA7xymGOFY3fp0SJrwOL5.jpg'),
(157690, 11177, 'Whistle [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/439946.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hZubi6QAEj0FEDPrx5nOVAjC4Nc.jpg'),
(157691, 11177, 'Whistle [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/439947.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/XFprgMhF4Ap8OEqNkda1H4eoA6.jpg'),
(157692, 11177, 'Whistle [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/439948.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yz6WmuN3D9qTdS6dK0qf902oG10.jpg'),
(157693, 11177, 'Whistle [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/439949.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j8M0e2cAD577Sm8vFOaraPaK9U3.jpg'),
(157694, 11177, 'Whistle [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/463418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157695, 11177, 'Whistle [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/463419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157696, 11177, 'Whistle [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/463420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157697, 11177, 'Whistle [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/463421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157698, 11177, 'Whistle [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/484756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157699, 11177, 'Whistle [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/484757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157700, 11177, 'Whistle [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/484758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157701, 11177, 'Whistle [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/484759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157702, 11177, 'Whistle [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/484760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157703, 11177, 'Whistle [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/637856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157704, 11177, 'Whistle [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/637857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157705, 11177, 'Whistle [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/637858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157706, 11177, 'Whistle [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/637859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157707, 11177, 'Whistle [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/637860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157708, 11177, 'Whistle [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/637861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157709, 11177, 'Whistle [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/637862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157710, 11177, 'Whistle [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/637863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157711, 11177, 'Whistle [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/637864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157712, 11177, 'Whistle [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/637865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157713, 11177, 'Whistle [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/637866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157714, 11177, 'Whistle [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/637867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157715, 11177, 'Whistle [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/637868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157716, 11177, 'Whistle [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/637869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157717, 11177, 'Whistle [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/637870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157718, 11177, 'Whistle [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/637871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hxHonAhV59ISqDLD6i8g1YdF9Dv.jpg'),
(157719, 11178, 'Top of the Lake S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439929.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qdvshHu6UB81PIXaPgkhF44b9S3.jpg'),
(157720, 11178, 'Top of the Lake S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439930.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sl4Y8Lcz22P1c5unFGIemI0cfjb.jpg'),
(157721, 11178, 'Top of the Lake S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439931.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i3sac37jd23BookOIlXARwYxqYS.jpg'),
(157722, 11178, 'Top of the Lake S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439932.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3KynqUbQcQqBomU0YQM4z87lmCE.jpg'),
(157723, 11178, 'Top of the Lake S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439933.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tWqmIumjKnuSDhF9Wplx4FmfcYK.jpg'),
(157724, 11178, 'Top of the Lake S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439934.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hWp2Qfy8QslwXjyEbVPpYocYgWD.jpg'),
(157725, 11178, 'Top of the Lake S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439935.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6TrOakgG7afCpKFUuryRMQEavtI.jpg'),
(157726, 11179, 'Top of the Lake S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449359.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cL7wG41l2eYDDlTEyn310Uay03s.jpg'),
(157727, 11179, 'Top of the Lake S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449360.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/38BO5gCvpVWUsCAhHduupvvOBIw.jpg'),
(157728, 11179, 'Top of the Lake S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449361.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/biD8f0XNdcsF2eVFdkreCwkKfkh.jpg'),
(157729, 11179, 'Top of the Lake S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449362.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nCulsD2l2c6IZZlrFkpSeZpQIkB.jpg'),
(157730, 11179, 'Top of the Lake S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449363.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tlUNp4KxdfpVszermMLKsXiU91v.jpg'),
(157731, 11179, 'Top of the Lake S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449364.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9BKYY2OXBMgC3SLEFdpNEPmgLRC.jpg'),
(157732, 11180, 'A Viuva S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439660.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1wi2bMXivfHp09C57WSLhQYzrxf.jpg'),
(157733, 11181, 'Black Kamen Rider S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157734, 11181, 'Black Kamen Rider S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157735, 11181, 'Black Kamen Rider S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157736, 11181, 'Black Kamen Rider S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157737, 11181, 'Black Kamen Rider S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157738, 11181, 'Black Kamen Rider S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157739, 11181, 'Black Kamen Rider S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157740, 11181, 'Black Kamen Rider S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/439885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157741, 11181, 'Black Kamen Rider S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/439886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157742, 11181, 'Black Kamen Rider S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/439887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157743, 11181, 'Black Kamen Rider S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/439888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157744, 11181, 'Black Kamen Rider S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/439889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157745, 11181, 'Black Kamen Rider S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/439890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157746, 11181, 'Black Kamen Rider S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/439891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157747, 11181, 'Black Kamen Rider S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/439892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157748, 11181, 'Black Kamen Rider S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/439893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157749, 11181, 'Black Kamen Rider S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/439894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157750, 11181, 'Black Kamen Rider S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/439895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157751, 11181, 'Black Kamen Rider S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/439896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157752, 11181, 'Black Kamen Rider S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/439897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157753, 11181, 'Black Kamen Rider S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/439898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157754, 11181, 'Black Kamen Rider S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/439899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157755, 11181, 'Black Kamen Rider S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/439900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157756, 11181, 'Black Kamen Rider S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/439901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157757, 11181, 'Black Kamen Rider S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/439902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157758, 11181, 'Black Kamen Rider S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/439903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157759, 11181, 'Black Kamen Rider S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/439904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157760, 11181, 'Black Kamen Rider S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/439905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157761, 11181, 'Black Kamen Rider S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/439906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157762, 11181, 'Black Kamen Rider S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/439907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157763, 11181, 'Black Kamen Rider S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/439908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157764, 11181, 'Black Kamen Rider S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/439909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157765, 11181, 'Black Kamen Rider S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/439910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157766, 11181, 'Black Kamen Rider S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/439911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157767, 11181, 'Black Kamen Rider S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/439912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157768, 11181, 'Black Kamen Rider S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/439913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157769, 11181, 'Black Kamen Rider S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/439914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157770, 11181, 'Black Kamen Rider S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/439915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157771, 11181, 'Black Kamen Rider S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/439916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157772, 11181, 'Black Kamen Rider S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/439917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157773, 11181, 'Black Kamen Rider S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/439918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157774, 11181, 'Black Kamen Rider S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/439919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157775, 11181, 'Black Kamen Rider S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/439920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157776, 11181, 'Black Kamen Rider S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/439921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157777, 11181, 'Black Kamen Rider S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/439922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157778, 11181, 'Black Kamen Rider S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/439923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157779, 11181, 'Black Kamen Rider S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/439924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157780, 11181, 'Black Kamen Rider S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/439925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157781, 11181, 'Black Kamen Rider S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/439926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157782, 11181, 'Black Kamen Rider S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/439927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157783, 11181, 'Black Kamen Rider S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/439928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bFP1SdtYtJNmWRie89BV77T7UFw.jpg'),
(157784, 11182, 'De Casa Nova Oficina do Ben S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439869.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o3EyCnIiiGo54ufuY4qXbqysnQ2.jpg'),
(157785, 11183, 'De Casa Nova Oficina do Ben S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bXv2Rog06bk9oQB4AjbXlzkHnAX.jpg'),
(157786, 11183, 'De Casa Nova Oficina do Ben S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bXv2Rog06bk9oQB4AjbXlzkHnAX.jpg'),
(157787, 11183, 'De Casa Nova Oficina do Ben S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bXv2Rog06bk9oQB4AjbXlzkHnAX.jpg'),
(157788, 11183, 'De Casa Nova Oficina do Ben S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bXv2Rog06bk9oQB4AjbXlzkHnAX.jpg'),
(157789, 11183, 'De Casa Nova Oficina do Ben S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bXv2Rog06bk9oQB4AjbXlzkHnAX.jpg'),
(157790, 11183, 'De Casa Nova Oficina do Ben S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bXv2Rog06bk9oQB4AjbXlzkHnAX.jpg'),
(157791, 11183, 'De Casa Nova Oficina do Ben S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bXv2Rog06bk9oQB4AjbXlzkHnAX.jpg'),
(157792, 11183, 'De Casa Nova Oficina do Ben S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/439877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bXv2Rog06bk9oQB4AjbXlzkHnAX.jpg'),
(157793, 11184, 'Desafio em Dose Dupla Mexico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7tReuBtXgyLdUSBSszwpQvk6KEx.jpg'),
(157794, 11184, 'Desafio em Dose Dupla Mexico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7tReuBtXgyLdUSBSszwpQvk6KEx.jpg'),
(157795, 11184, 'Desafio em Dose Dupla Mexico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7tReuBtXgyLdUSBSszwpQvk6KEx.jpg'),
(157796, 11184, 'Desafio em Dose Dupla Mexico S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7tReuBtXgyLdUSBSszwpQvk6KEx.jpg'),
(157797, 11184, 'Desafio em Dose Dupla Mexico S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7tReuBtXgyLdUSBSszwpQvk6KEx.jpg'),
(157798, 11184, 'Desafio em Dose Dupla Mexico S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7tReuBtXgyLdUSBSszwpQvk6KEx.jpg'),
(157799, 11185, 'Dot S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157800, 11185, 'Dot S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157801, 11185, 'Dot S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157802, 11185, 'Dot S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157803, 11185, 'Dot S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157804, 11185, 'Dot S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157805, 11185, 'Dot S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157806, 11185, 'Dot S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/439818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157807, 11185, 'Dot S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/439819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157808, 11185, 'Dot S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/439820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157809, 11185, 'Dot S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/439821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157810, 11185, 'Dot S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/439822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157811, 11185, 'Dot S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/439823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157812, 11185, 'Dot S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/439824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157813, 11185, 'Dot S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/439825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157814, 11185, 'Dot S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/439826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157815, 11185, 'Dot S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/439827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157816, 11185, 'Dot S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/439828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157817, 11185, 'Dot S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/439829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157818, 11185, 'Dot S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/439830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157819, 11185, 'Dot S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/439831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157820, 11185, 'Dot S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/439832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157821, 11185, 'Dot S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/439833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157822, 11185, 'Dot S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/439834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157823, 11185, 'Dot S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/439835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157824, 11185, 'Dot S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/439836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157825, 11185, 'Dot S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/439837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157826, 11185, 'Dot S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/439838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157827, 11185, 'Dot S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/439839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157828, 11185, 'Dot S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/439840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157829, 11185, 'Dot S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/439841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157830, 11185, 'Dot S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/439842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157831, 11185, 'Dot S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/439843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157832, 11185, 'Dot S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/439844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157833, 11185, 'Dot S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/439845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157834, 11185, 'Dot S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/439846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157835, 11185, 'Dot S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/439847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157836, 11185, 'Dot S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/439848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157837, 11185, 'Dot S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/439849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157838, 11185, 'Dot S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/439850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157839, 11185, 'Dot S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/439851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157840, 11185, 'Dot S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/439852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157841, 11185, 'Dot S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/439853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157842, 11185, 'Dot S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/439854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157843, 11185, 'Dot S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/439855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157844, 11185, 'Dot S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/439856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157845, 11185, 'Dot S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/439857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157846, 11185, 'Dot S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/439858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157847, 11185, 'Dot S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/439859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157848, 11185, 'Dot S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/439860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157849, 11185, 'Dot S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/439861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157850, 11185, 'Dot S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/439862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q3yGxx4rNbSLFHG2VJ74UxXVnSl.jpg'),
(157851, 11186, 'Escola dos Romances Proibidos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439803.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4wd2M44H15vIMJvdqiguvkwqf1B.jpg'),
(157852, 11186, 'Escola dos Romances Proibidos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439804.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ccMK3lhJUlFXiI4rXKQe2NjfDtd.jpg'),
(157853, 11186, 'Escola dos Romances Proibidos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439805.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/djoToPnbr2v01QHHdPdSwnFYZEd.jpg'),
(157854, 11186, 'Escola dos Romances Proibidos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439806.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8dt0F0Ts7an2vNO6r6hwmcMf4pZ.jpg'),
(157855, 11186, 'Escola dos Romances Proibidos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439807.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t2LqzoYGxA7cTgS1iEXEIpOvJag.jpg'),
(157856, 11186, 'Escola dos Romances Proibidos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439808.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l0g1XGxpZdXslI6kIVlufrZNJxr.jpg'),
(157857, 11186, 'Escola dos Romances Proibidos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439809.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lLaUKi8M7sw49VR8JjiMrQFk7ty.jpg'),
(157858, 11186, 'Escola dos Romances Proibidos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/439810.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mUEKhZqOskxVLJLzcWevInNhY3l.jpg'),
(157859, 11187, 'Exhumed S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69J5VZZ3I9SedQqUzHPcJWhY8qJ.jpg'),
(157860, 11187, 'Exhumed S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69J5VZZ3I9SedQqUzHPcJWhY8qJ.jpg'),
(157861, 11187, 'Exhumed S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69J5VZZ3I9SedQqUzHPcJWhY8qJ.jpg'),
(157862, 11187, 'Exhumed S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69J5VZZ3I9SedQqUzHPcJWhY8qJ.jpg'),
(157863, 11187, 'Exhumed S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69J5VZZ3I9SedQqUzHPcJWhY8qJ.jpg'),
(157864, 11187, 'Exhumed S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69J5VZZ3I9SedQqUzHPcJWhY8qJ.jpg'),
(157865, 11187, 'Exhumed S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69J5VZZ3I9SedQqUzHPcJWhY8qJ.jpg'),
(157866, 11187, 'Exhumed S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/439800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69J5VZZ3I9SedQqUzHPcJWhY8qJ.jpg'),
(157867, 11187, 'Exhumed S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/439801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69J5VZZ3I9SedQqUzHPcJWhY8qJ.jpg'),
(157868, 11187, 'Exhumed S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/439802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69J5VZZ3I9SedQqUzHPcJWhY8qJ.jpg'),
(157869, 11188, 'Isto e Futebol S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439787.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3qQ78oz234ThBE5cY85S54f3btT.jpg'),
(157870, 11188, 'Isto e Futebol S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439788.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ceTm50Bpciph1UU3HqOlUGYwV7Q.jpg'),
(157871, 11188, 'Isto e Futebol S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439789.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1rKokeEfNzLlXw3Y19Pl0DqmGEb.jpg'),
(157872, 11188, 'Isto e Futebol S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439790.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rY2XAAwLS5N84j6bBwMEwXtcZHY.jpg'),
(157873, 11188, 'Isto e Futebol S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439791.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9UOwYFI9fbTmV984Elw8PzHPdw1.jpg'),
(157874, 11188, 'Isto e Futebol S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439792.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mEpu746Z9ZQav0rWNFJDjJQnBfn.jpg'),
(157875, 11189, 'Joan de Arcadia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439742.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/40tbcqfW0ZXM3FpaCz0LVTsNra6.jpg'),
(157876, 11189, 'Joan de Arcadia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439743.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3sOXPyjbfk1tgxbtFEkqVf1kvkt.jpg'),
(157877, 11189, 'Joan de Arcadia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439744.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nUXjwKsmT2EuNGTtfeDrazG9XZ.jpg'),
(157878, 11189, 'Joan de Arcadia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439745.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yPrtM3WKVpaIaeT60DxxohXDPFv.jpg'),
(157879, 11189, 'Joan de Arcadia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439746.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4VMEXnsZYeUrwhKsqQSmIi4K4Tm.jpg'),
(157880, 11189, 'Joan de Arcadia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439747.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sWGfpfceZJMQUWoJyEunsxp1GXN.jpg'),
(157881, 11189, 'Joan de Arcadia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439748.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lpSH3mUE9dG8KWd32iWuWVzL7A6.jpg'),
(157882, 11189, 'Joan de Arcadia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/439749.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yH40hOcYRvXLUThflxKVkHLwI9G.jpg'),
(157883, 11189, 'Joan de Arcadia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/439750.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oKiK10KC1OejEIdtYjw1ZEuoSbw.jpg'),
(157884, 11189, 'Joan de Arcadia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/439751.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j1NL6d06sH2Nz2mRQzAQPeVs5oS.jpg'),
(157885, 11189, 'Joan de Arcadia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/439752.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/54jDgOGSbG4zouRFkBfwXNAFcZ8.jpg'),
(157886, 11189, 'Joan de Arcadia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/439753.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zCVQPv1ceWc5ScTi0od653BMd61.jpg'),
(157887, 11189, 'Joan de Arcadia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/439754.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xl6ut7vFEl694gGFMUDa8Pcda4.jpg'),
(157888, 11189, 'Joan de Arcadia S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/439755.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v1xap8frgEr489lTh5TADDxJTjo.jpg'),
(157889, 11189, 'Joan de Arcadia S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/439756.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dsnIcnYebrMtBBbdsOJQRal6R8S.jpg'),
(157890, 11189, 'Joan de Arcadia S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/439757.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y2fnNz0gx1AIHkTtHpqFWbcfJ2Y.jpg'),
(157891, 11189, 'Joan de Arcadia S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/439758.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3XDiVMOG5ERrftevc0W8lHyFiWT.jpg'),
(157892, 11189, 'Joan de Arcadia S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/439759.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rW19bx19XQrTy7qikMkpOXccdFQ.jpg'),
(157893, 11189, 'Joan de Arcadia S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/439760.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b4M5UvNow0eylGm2SuthvqYvLy8.jpg'),
(157894, 11189, 'Joan de Arcadia S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/439761.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4Fas0f50PvpeeRf5eoH1htvIG7t.jpg'),
(157895, 11189, 'Joan de Arcadia S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/439762.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ympX79ejKknXxldk8yWr8uxWJga.jpg'),
(157896, 11189, 'Joan de Arcadia S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/439763.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/D2wGpvNTWxuMelpLQyCv3vcVOK.jpg'),
(157897, 11189, 'Joan de Arcadia S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/439764.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5AME8ni0dyf3VqI10Z8ivZHG4w1.jpg'),
(157898, 11190, 'Joan de Arcadia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg'),
(157899, 11190, 'Joan de Arcadia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg'),
(157900, 11190, 'Joan de Arcadia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg'),
(157901, 11190, 'Joan de Arcadia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg'),
(157902, 11190, 'Joan de Arcadia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg'),
(157903, 11190, 'Joan de Arcadia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg'),
(157904, 11190, 'Joan de Arcadia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg'),
(157905, 11190, 'Joan de Arcadia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/439772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg'),
(157906, 11190, 'Joan de Arcadia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/439773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg'),
(157907, 11190, 'Joan de Arcadia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/439774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg'),
(157908, 11190, 'Joan de Arcadia S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/439775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(157909, 11190, 'Joan de Arcadia S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/439776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg'),
(157910, 11190, 'Joan de Arcadia S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/439777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg'),
(157911, 11190, 'Joan de Arcadia S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/439778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg'),
(157912, 11190, 'Joan de Arcadia S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/439779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg'),
(157913, 11190, 'Joan de Arcadia S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/439780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg'),
(157914, 11190, 'Joan de Arcadia S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/439781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg'),
(157915, 11190, 'Joan de Arcadia S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/439782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg'),
(157916, 11190, 'Joan de Arcadia S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/439783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg'),
(157917, 11190, 'Joan de Arcadia S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/439784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg'),
(157918, 11190, 'Joan de Arcadia S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/439785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg'),
(157919, 11190, 'Joan de Arcadia S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/439786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/AdSIHbGVuHGrdZs5BXajiCwep75.jpg'),
(157920, 11191, 'KAOS S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439734.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jNLU9ztEbxqJ9yBoGKvOQ8ZT5nF.jpg'),
(157921, 11191, 'KAOS S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439735.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6Kxf4KkkKuw8GBN75httOcUaOFx.jpg'),
(157922, 11191, 'KAOS S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439736.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fUUPnz6u1QDYRkH2BtscEw00dad.jpg'),
(157923, 11191, 'KAOS S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439737.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o3sc8I2klnKN6tMuHfmcxY5SN4j.jpg'),
(157924, 11191, 'KAOS S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439738.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rD7qbkYFioo4O7M0PaJy7aA27Db.jpg'),
(157925, 11191, 'KAOS S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439739.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gu1fujtgcLFusVE2IKXvyJ5roVF.jpg'),
(157926, 11191, 'KAOS S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439740.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pOmTED332lionfOsy8dSuKJRZTu.jpg'),
(157927, 11191, 'KAOS S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/439741.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p42vWPhWZQwPwgaIAs31kDmuP6z.jpg'),
(157928, 11192, 'Money ID A Identidade do Dinheiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dgCqZzwdVIshW4x02vhDRkZCjIm.jpg'),
(157929, 11192, 'Money ID A Identidade do Dinheiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dgCqZzwdVIshW4x02vhDRkZCjIm.jpg'),
(157930, 11192, 'Money ID A Identidade do Dinheiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dgCqZzwdVIshW4x02vhDRkZCjIm.jpg'),
(157931, 11192, 'Money ID A Identidade do Dinheiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/447331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dgCqZzwdVIshW4x02vhDRkZCjIm.jpg'),
(157932, 11193, 'O Som e a Silaba S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439723.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6j3C8gQPT5avjBJPhTLvkmIT6uT.jpg'),
(157933, 11193, 'O Som e a Silaba S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439724.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/txVRr7em4lgTedgczyeIVEWOxVR.jpg'),
(157934, 11193, 'O Som e a Silaba S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439725.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vGS8bNQrGnVbljrGTEbfYcoxYBR.jpg'),
(157935, 11193, 'O Som e a Silaba S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439726.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vBGcXhzUnxl13cNslK9UfnM3VGn.jpg'),
(157936, 11193, 'O Som e a Silaba S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439727.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4mQpUnfSTd5ES73YmVVfG809HZK.jpg'),
(157937, 11193, 'O Som e a Silaba S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439728.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bXuKznOx0DPxC2UlCd2V1QmVYtC.jpg'),
(157938, 11193, 'O Som e a Silaba S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439729.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oK0yhBcN07rFpunDmsbp8eg8xUj.jpg'),
(157939, 11193, 'O Som e a Silaba S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/439730.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nXSRvwayMolOGtYg8GF9AC7XfYo.jpg'),
(157940, 11194, 'O... Coitado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439684.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zU8uNfkDs2zC2thbV64sDk7nL5Y.jpg'),
(157941, 11194, 'O... Coitado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157942, 11194, 'O... Coitado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157943, 11194, 'O... Coitado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157944, 11194, 'O... Coitado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157945, 11194, 'O... Coitado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157946, 11194, 'O... Coitado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157947, 11194, 'O... Coitado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/439691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157948, 11194, 'O... Coitado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/439692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157949, 11194, 'O... Coitado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/439693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157950, 11194, 'O... Coitado S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/439694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157951, 11194, 'O... Coitado S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/439695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157952, 11194, 'O... Coitado S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/439696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157953, 11194, 'O... Coitado S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/439697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157954, 11194, 'O... Coitado S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/439698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157955, 11194, 'O... Coitado S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/439699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157956, 11194, 'O... Coitado S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/439700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157957, 11194, 'O... Coitado S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/439701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157958, 11194, 'O... Coitado S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/439702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157959, 11194, 'O... Coitado S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/439703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157960, 11194, 'O... Coitado S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/439704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157961, 11194, 'O... Coitado S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/439705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157962, 11194, 'O... Coitado S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/439706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157963, 11194, 'O... Coitado S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/439707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157964, 11194, 'O... Coitado S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/439708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157965, 11194, 'O... Coitado S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/439709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157966, 11194, 'O... Coitado S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/439710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157967, 11194, 'O... Coitado S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/439711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157968, 11194, 'O... Coitado S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/439712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157969, 11194, 'O... Coitado S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/439713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157970, 11194, 'O... Coitado S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/439714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157971, 11194, 'O... Coitado S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/439715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157972, 11194, 'O... Coitado S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/439716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157973, 11194, 'O... Coitado S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/439717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157974, 11194, 'O... Coitado S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/439718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157975, 11194, 'O... Coitado S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/439719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157976, 11194, 'O... Coitado S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/439720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157977, 11194, 'O... Coitado S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/439721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157978, 11194, 'O... Coitado S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/439722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/34ErQPDjpOZ4JSmJzZ1q6JyiBbl.jpg'),
(157979, 11195, 'Os Lucros do Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439678.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zcnk9t684xc2Hgn0UMM42F4pia5.jpg'),
(157980, 11195, 'Os Lucros do Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/625888.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1IyDWlYP6hYk2oomPaAAK0iD62q.jpg'),
(157981, 11195, 'Os Lucros do Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r4VtSiGDlV3ElFRFQP358bABUWE.jpg'),
(157982, 11195, 'Os Lucros do Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r4VtSiGDlV3ElFRFQP358bABUWE.jpg'),
(157983, 11195, 'Os Lucros do Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r4VtSiGDlV3ElFRFQP358bABUWE.jpg'),
(157984, 11195, 'Os Lucros do Amor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/452225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r4VtSiGDlV3ElFRFQP358bABUWE.jpg'),
(157985, 11195, 'Os Lucros do Amor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/457387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r4VtSiGDlV3ElFRFQP358bABUWE.jpg'),
(157986, 11195, 'Os Lucros do Amor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/457388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r4VtSiGDlV3ElFRFQP358bABUWE.jpg'),
(157987, 11195, 'Os Lucros do Amor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/464004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r4VtSiGDlV3ElFRFQP358bABUWE.jpg'),
(157988, 11195, 'Os Lucros do Amor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/464005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r4VtSiGDlV3ElFRFQP358bABUWE.jpg'),
(157989, 11195, 'Os Lucros do Amor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/469731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r4VtSiGDlV3ElFRFQP358bABUWE.jpg'),
(157990, 11195, 'Os Lucros do Amor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/469732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r4VtSiGDlV3ElFRFQP358bABUWE.jpg'),
(157991, 11196, 'Os Piores Ex S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439476.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mjgi7q6Msz1f30Gd1fOh67PVXY6.jpg'),
(157992, 11196, 'Os Piores Ex S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439477.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/76bHIqwneKCEVBEpm0e3l5qfUrc.jpg'),
(157993, 11196, 'Os Piores Ex S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439478.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7MKNO3HVVRK7NXOMSuAbVPCyKck.jpg'),
(157994, 11196, 'Os Piores Ex S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439479.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bOUcNkwkGh8QaWghsr0gnHxOUEz.jpg'),
(157995, 11197, 'Quebra Cabeca Criminal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u2jeldnkzYrltpuCb2u5br9INeZ.jpg'),
(157996, 11197, 'Quebra Cabeca Criminal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u2jeldnkzYrltpuCb2u5br9INeZ.jpg'),
(157997, 11197, 'Quebra Cabeca Criminal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u2jeldnkzYrltpuCb2u5br9INeZ.jpg'),
(157998, 11197, 'Quebra Cabeca Criminal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u2jeldnkzYrltpuCb2u5br9INeZ.jpg'),
(157999, 11197, 'Quebra Cabeca Criminal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u2jeldnkzYrltpuCb2u5br9INeZ.jpg'),
(158000, 11197, 'Quebra Cabeca Criminal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u2jeldnkzYrltpuCb2u5br9INeZ.jpg'),
(158001, 11198, 'Quebra Cabeca Criminal S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u2jeldnkzYrltpuCb2u5br9INeZ.jpg'),
(158002, 11198, 'Quebra Cabeca Criminal S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u2jeldnkzYrltpuCb2u5br9INeZ.jpg'),
(158003, 11198, 'Quebra Cabeca Criminal S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u2jeldnkzYrltpuCb2u5br9INeZ.jpg'),
(158004, 11198, 'Quebra Cabeca Criminal S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u2jeldnkzYrltpuCb2u5br9INeZ.jpg'),
(158005, 11198, 'Quebra Cabeca Criminal S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u2jeldnkzYrltpuCb2u5br9INeZ.jpg'),
(158006, 11198, 'Quebra Cabeca Criminal S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u2jeldnkzYrltpuCb2u5br9INeZ.jpg'),
(158007, 11198, 'Quebra Cabeca Criminal S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u2jeldnkzYrltpuCb2u5br9INeZ.jpg'),
(158008, 11198, 'Quebra Cabeca Criminal S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u2jeldnkzYrltpuCb2u5br9INeZ.jpg'),
(158009, 11198, 'Quebra Cabeca Criminal S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/445782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u2jeldnkzYrltpuCb2u5br9INeZ.jpg'),
(158010, 11198, 'Quebra Cabeca Criminal S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/445783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u2jeldnkzYrltpuCb2u5br9INeZ.jpg'),
(158011, 11199, 'Segredos do Arsenal de Espionagem S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cwaMHkbIb82f2bQDZeNl2IxCfdw.jpg'),
(158012, 11199, 'Segredos do Arsenal de Espionagem S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cwaMHkbIb82f2bQDZeNl2IxCfdw.jpg'),
(158013, 11199, 'Segredos do Arsenal de Espionagem S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cwaMHkbIb82f2bQDZeNl2IxCfdw.jpg'),
(158014, 11199, 'Segredos do Arsenal de Espionagem S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/641619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cwaMHkbIb82f2bQDZeNl2IxCfdw.jpg'),
(158015, 11199, 'Segredos do Arsenal de Espionagem S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/641620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cwaMHkbIb82f2bQDZeNl2IxCfdw.jpg'),
(158016, 11200, 'Jornada nas Estrelas Voyager S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439308.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/upAuq9otlYiNmpBAP3PGjgUuaEx.jpg'),
(158017, 11200, 'Jornada nas Estrelas Voyager S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439309.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gkeZyTsb4pvlt4PHF4WBzpJW8oB.jpg'),
(158018, 11200, 'Jornada nas Estrelas Voyager S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439310.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pFIjtvBMYdj0sv8TJqHXffoqYqp.jpg'),
(158019, 11200, 'Jornada nas Estrelas Voyager S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439311.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mEFHQ8DZl5pQHrheM94souyu9BZ.jpg'),
(158020, 11200, 'Jornada nas Estrelas Voyager S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439312.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l7XB1sI9vJTknbMhDVuteCnKLub.jpg'),
(158021, 11200, 'Jornada nas Estrelas Voyager S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439313.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6601rSVnCoFwUdBPIQaV63hbcrR.jpg'),
(158022, 11200, 'Jornada nas Estrelas Voyager S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439314.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kqDickbXlfrpBARvDJFNdqbrVCU.jpg'),
(158023, 11200, 'Jornada nas Estrelas Voyager S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/439315.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hjTBs7oSvsjIv1wcVYhsNX4QdhN.jpg'),
(158024, 11200, 'Jornada nas Estrelas Voyager S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/439316.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4cllsHwBJNLsLRyAt9R0I2XYq5O.jpg'),
(158025, 11200, 'Jornada nas Estrelas Voyager S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/439317.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b4kNyOH8ktCHLfUG7wJOVHPeHeQ.jpg'),
(158026, 11200, 'Jornada nas Estrelas Voyager S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/439318.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gS99wOETjQqoGLzmMzBBTOOwefg.jpg'),
(158027, 11200, 'Jornada nas Estrelas Voyager S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/439319.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qn8VV6w9EymTWHW2sSESJK2e3Bm.jpg'),
(158028, 11200, 'Jornada nas Estrelas Voyager S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/439320.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7Rejv9QC5vgmtJTW1kcX6yC9RKm.jpg'),
(158029, 11200, 'Jornada nas Estrelas Voyager S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/439321.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/XXgaTyqPsHezmY315ILGh4Ut64.jpg'),
(158030, 11200, 'Jornada nas Estrelas Voyager S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/439322.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2rQZwwmpWc8DmwyTJT2HvHr80gj.jpg'),
(158031, 11201, 'Jornada nas Estrelas Voyager S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439323.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jh1ZeHaIQs4KzKbmW3dwPUoDkga.jpg'),
(158032, 11201, 'Jornada nas Estrelas Voyager S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439324.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d4NFcmMLJshYNFDVdb25FzStV47.jpg'),
(158033, 11201, 'Jornada nas Estrelas Voyager S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439325.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jeUhzNQtuZxayQZw08XuoQzagGj.jpg'),
(158034, 11201, 'Jornada nas Estrelas Voyager S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439326.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mNdC0qUaxZlwzU1QL2NKw4rmVXQ.jpg'),
(158035, 11201, 'Jornada nas Estrelas Voyager S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439327.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7dfuxw4EG1Zm40uiTK7Wqv6dWft.jpg'),
(158036, 11201, 'Jornada nas Estrelas Voyager S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439328.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rRQMON3bEE63CAsLaTHMkfKMAGV.jpg'),
(158037, 11201, 'Jornada nas Estrelas Voyager S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439329.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j01eBqhxsqFumZRjrplPYXCJMPN.jpg'),
(158038, 11201, 'Jornada nas Estrelas Voyager S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/439330.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kp8Mlf6NddVZoYQRZ5aQjkwuynC.jpg'),
(158039, 11201, 'Jornada nas Estrelas Voyager S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/439331.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kBSLHUMDcxAuEQA5rFxs5vTVWbk.jpg'),
(158040, 11201, 'Jornada nas Estrelas Voyager S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/439332.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zxLJnIZvuI14P3JsZ6TGKAlhmC4.jpg'),
(158041, 11201, 'Jornada nas Estrelas Voyager S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/439333.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sytt2grnZjo8NOO6hR7kCwUgPvd.jpg'),
(158042, 11201, 'Jornada nas Estrelas Voyager S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/439334.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d5vwdv6kCucRHTY3UA8LAWFsk8k.jpg'),
(158043, 11201, 'Jornada nas Estrelas Voyager S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/439335.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a7PirR7uJlMoGlmnWkRrZwx9DpZ.jpg'),
(158044, 11201, 'Jornada nas Estrelas Voyager S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/439336.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4ZXE2B0pSUUdoOUenT41UoWwD6T.jpg'),
(158045, 11201, 'Jornada nas Estrelas Voyager S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/439337.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5exCwmFe3PCh2xoSg21qNbmzd4X.jpg'),
(158046, 11201, 'Jornada nas Estrelas Voyager S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/439338.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/edKJCJe1E8ozsESRB1t8PiF6F3D.jpg'),
(158047, 11201, 'Jornada nas Estrelas Voyager S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/439339.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aTYR5nEG34Ovy5LQHRqPMWxlek8.jpg'),
(158048, 11201, 'Jornada nas Estrelas Voyager S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/439340.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5FfcFxqV4Ph3TtcmSp6Xrqb2AZB.jpg'),
(158049, 11201, 'Jornada nas Estrelas Voyager S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/439341.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aYPezg7wRmuJlm9VPVzurGspM3.jpg'),
(158050, 11201, 'Jornada nas Estrelas Voyager S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/439342.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aBVCEAI8TZDJx1LbYLgFdVhakbn.jpg'),
(158051, 11201, 'Jornada nas Estrelas Voyager S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/439343.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sP7agmsK54OnjCeUXsghEU6N0U9.jpg'),
(158052, 11201, 'Jornada nas Estrelas Voyager S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/439344.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rlKXioZIuydSRHvvMA717YJI50A.jpg'),
(158053, 11201, 'Jornada nas Estrelas Voyager S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/439345.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4AvnNplUWm8aZT3bW1nqjYkFdhD.jpg'),
(158054, 11201, 'Jornada nas Estrelas Voyager S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/439346.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bPaaS9BNalxgx9ErtCcLeRmbY0n.jpg'),
(158055, 11201, 'Jornada nas Estrelas Voyager S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/439347.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yOEoMiAsuRpwOAL3sDFdJtdgiVO.jpg'),
(158056, 11201, 'Jornada nas Estrelas Voyager S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/439348.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3jW7GFvnQlAwzu0Qyoi2TIQt0kI.jpg'),
(158057, 11202, 'Jornada nas Estrelas Voyager S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439349.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3o64f20oUgJ6GWu9elBYTytJmsU.jpg'),
(158058, 11202, 'Jornada nas Estrelas Voyager S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439350.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4HXYctcM8LOiPwUL8L1aakjuhlF.jpg'),
(158059, 11202, 'Jornada nas Estrelas Voyager S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439351.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3rb8PKtVCAZKHhLvr4c58giZfX9.jpg'),
(158060, 11202, 'Jornada nas Estrelas Voyager S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439352.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rf4a8xCUu4twHnY48HLlHHZhPay.jpg'),
(158061, 11202, 'Jornada nas Estrelas Voyager S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439353.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nsAaT6VcAflOxO5gJwpjx8IRAwq.jpg'),
(158062, 11202, 'Jornada nas Estrelas Voyager S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439354.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4P6OUCdP1xltBdWrahzsnSoKKkz.jpg'),
(158063, 11202, 'Jornada nas Estrelas Voyager S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439355.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qdVMyDhjISjG14ziGdAZMq17Vdi.jpg'),
(158064, 11202, 'Jornada nas Estrelas Voyager S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/439356.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cdSfXnDi8dJ4K0HdXN0QS3vPSaC.jpg'),
(158065, 11202, 'Jornada nas Estrelas Voyager S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/439357.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w6l6U2maD5QozwYg5zOlF1SZ0GL.jpg'),
(158066, 11202, 'Jornada nas Estrelas Voyager S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/439358.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7xlCw3APzGuqdj0OqFekx0WgqJD.jpg'),
(158067, 11202, 'Jornada nas Estrelas Voyager S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/439359.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m244YsYSWnAl4X8kxNmDH9wiTvb.jpg'),
(158068, 11202, 'Jornada nas Estrelas Voyager S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/439360.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gZ6gbLZCByUltHLys2FrAdYoFka.jpg'),
(158069, 11202, 'Jornada nas Estrelas Voyager S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/439361.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/83hsr1K2zL9WQKQzGj3QzR6gqIa.jpg'),
(158070, 11202, 'Jornada nas Estrelas Voyager S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/439362.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1LJs2OsC6rPThJ7hEhTGONVrU3N.jpg'),
(158071, 11202, 'Jornada nas Estrelas Voyager S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/439363.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nIPzuZHjRuJKFBuPMaKv9tfjggK.jpg'),
(158072, 11202, 'Jornada nas Estrelas Voyager S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/439364.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3BvzLMYsIedt15au18UgxGzjm5a.jpg'),
(158073, 11202, 'Jornada nas Estrelas Voyager S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/439365.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vmHVkFIurnEnQjcVbxCu7mm8J0B.jpg'),
(158074, 11202, 'Jornada nas Estrelas Voyager S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/439366.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/73uTppPPpBCeTeOQCmUKd3acNOE.jpg'),
(158075, 11202, 'Jornada nas Estrelas Voyager S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/439367.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pWLRUa3nGnvcx6Tg7zHjrRNxdgG.jpg'),
(158076, 11202, 'Jornada nas Estrelas Voyager S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/439368.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9R8IHbI8FpCMjtOGvRsFe3MzxBh.jpg'),
(158077, 11202, 'Jornada nas Estrelas Voyager S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/439369.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l7XYxgn4q3h3rKuzN2zFcaTYiGX.jpg'),
(158078, 11202, 'Jornada nas Estrelas Voyager S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/439370.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jUQFxM2WoIlYESo4WvVxPjpAd9w.jpg'),
(158079, 11202, 'Jornada nas Estrelas Voyager S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/439371.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eHSr2exmlPzFMULXLL50cNDMV9x.jpg'),
(158080, 11202, 'Jornada nas Estrelas Voyager S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/439372.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gmCJLVWIIEyzQ2d5Uo3Uu2ZWSMg.jpg'),
(158081, 11202, 'Jornada nas Estrelas Voyager S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/439373.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pescCFlhI1WWhAjcwUNhlAVagit.jpg'),
(158082, 11202, 'Jornada nas Estrelas Voyager S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/439374.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9CFvFsziHiLRix94HwqUcp4Xrgb.jpg'),
(158083, 11203, 'Jornada nas Estrelas Voyager S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439375.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xQafP3sSBBVYUV15CbY7vIJCxtQ.jpg'),
(158084, 11203, 'Jornada nas Estrelas Voyager S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439376.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zRZHD9uger47nW14QjAFJbuJscS.jpg'),
(158085, 11203, 'Jornada nas Estrelas Voyager S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439377.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aPz1mnkJZm8xmGCOhnYxcoxM3fV.jpg'),
(158086, 11203, 'Jornada nas Estrelas Voyager S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439378.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fd80XoFshQah6zrP0xidruSJAOW.jpg'),
(158087, 11203, 'Jornada nas Estrelas Voyager S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439379.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pitiVOUdpgJwSuEtYbPzWTTLvP8.jpg'),
(158088, 11203, 'Jornada nas Estrelas Voyager S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439380.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nx0waAZHdRcfbpPpe1mL4WztE35.jpg'),
(158089, 11203, 'Jornada nas Estrelas Voyager S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439381.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A6wTXMQHBTMYoRsW3bfJo3TmUSd.jpg'),
(158090, 11203, 'Jornada nas Estrelas Voyager S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/439382.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uOwBd85M29da3bUTl0S3dCFNBTK.jpg'),
(158091, 11203, 'Jornada nas Estrelas Voyager S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/439383.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qt4B5gW4KRFFVWGUWtaNEambz6J.jpg'),
(158092, 11203, 'Jornada nas Estrelas Voyager S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/439384.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rLRtWajTty6vkLBYgTFXcqKjMbE.jpg'),
(158093, 11203, 'Jornada nas Estrelas Voyager S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/439385.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wfO6yQoiQH9EckqYDqFriaLNWgU.jpg'),
(158094, 11203, 'Jornada nas Estrelas Voyager S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/439386.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/avUxEBBdi0Li7BFDSgfVvQTm7rW.jpg'),
(158095, 11203, 'Jornada nas Estrelas Voyager S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/439387.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mXLfFlf0XYuIXzfvQ4eswmTqWBX.jpg'),
(158096, 11203, 'Jornada nas Estrelas Voyager S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/439388.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hz1Q1K8B6OrcewBphUKba72gppn.jpg'),
(158097, 11203, 'Jornada nas Estrelas Voyager S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/439389.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wKLmxorqWzMXLXXO6AF1CaRRqyO.jpg'),
(158098, 11203, 'Jornada nas Estrelas Voyager S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/439390.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w6XiKeNWP91zDGVexc2SoD3OVYj.jpg'),
(158099, 11203, 'Jornada nas Estrelas Voyager S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/439391.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uJN4PyX6AxZwo0jrfbldiS3W2QH.jpg'),
(158100, 11203, 'Jornada nas Estrelas Voyager S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/439392.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dirT42ikTiqfHRnmHkBtJQMLlwe.jpg'),
(158101, 11203, 'Jornada nas Estrelas Voyager S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/439393.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7xf0o9LSu39ARQqwQDwcYxh1DNi.jpg'),
(158102, 11203, 'Jornada nas Estrelas Voyager S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/439394.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vdowoXiAV4BQBDw1OTzDOwYcoEJ.jpg'),
(158103, 11203, 'Jornada nas Estrelas Voyager S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/439395.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/inki1yPwdli0cEscN6PY10PIbjn.jpg'),
(158104, 11203, 'Jornada nas Estrelas Voyager S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/439396.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jSS0B7D10G2H4RiSblMbeolkD5V.jpg'),
(158105, 11203, 'Jornada nas Estrelas Voyager S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/439397.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/80zdz9Y9ZI59HiqQhgUzlZE5VMw.jpg'),
(158106, 11203, 'Jornada nas Estrelas Voyager S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/439398.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/297PceYSmwBvqCIcrUX8ZOcch8o.jpg'),
(158107, 11203, 'Jornada nas Estrelas Voyager S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/439399.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/shvi1ZSFxoGIKBpPRDNWSeUixqb.jpg'),
(158108, 11203, 'Jornada nas Estrelas Voyager S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/439400.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ew6HVWh1AetHPs8Z4UGkg4kWqNu.jpg'),
(158109, 11204, 'Jornada nas Estrelas Voyager S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439401.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7R13nnV8xTGfNeEMToC2n2ahQ0j.jpg'),
(158110, 11204, 'Jornada nas Estrelas Voyager S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439402.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eBH4PB5J3B2F4uPTg89eTXjpwvm.jpg'),
(158111, 11204, 'Jornada nas Estrelas Voyager S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439403.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/odj9qZMmvq4Erxhw2HCIyPqE6ej.jpg'),
(158112, 11204, 'Jornada nas Estrelas Voyager S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439404.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/whvzxt3KyJZC6UPuq4eHUxZx0N8.jpg'),
(158113, 11204, 'Jornada nas Estrelas Voyager S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439405.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5ZnyFUZxHfSO732xtsM5ou4BHtc.jpg'),
(158114, 11204, 'Jornada nas Estrelas Voyager S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439406.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tj5Sk4uxbDWLLil4l3Tpz7mFL24.jpg'),
(158115, 11204, 'Jornada nas Estrelas Voyager S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439407.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AnjGzjybEKgaQiWOgwkxWWZVsUb.jpg'),
(158116, 11204, 'Jornada nas Estrelas Voyager S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/439408.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yVx9tvphU2skky0yUMJGRUyhVWl.jpg'),
(158117, 11204, 'Jornada nas Estrelas Voyager S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/439409.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9o73bwfLIwB42kxeHcaI1Djorir.jpg'),
(158118, 11204, 'Jornada nas Estrelas Voyager S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/439410.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vQSa5WpJMabW8Sz2cMH8Gl90AMt.jpg'),
(158119, 11204, 'Jornada nas Estrelas Voyager S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/439411.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3zxsLjnlXXO9nbNI3h03LfwVTBS.jpg'),
(158120, 11204, 'Jornada nas Estrelas Voyager S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/439412.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A1L03nPWIHeGtT5A9X3lmeZIruY.jpg'),
(158121, 11204, 'Jornada nas Estrelas Voyager S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/439413.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uTar8LJrjAHKlwYqb6jU043fb2N.jpg'),
(158122, 11204, 'Jornada nas Estrelas Voyager S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/439414.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lS3HpHkExv6nbTehHNnUndws1c1.jpg'),
(158123, 11204, 'Jornada nas Estrelas Voyager S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/439415.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vSKtLtWZ4KLBio7LcoVnl0mPzi9.jpg'),
(158124, 11204, 'Jornada nas Estrelas Voyager S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/439416.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mcY2yjWfUjRGlHckn3o86dmS57L.jpg'),
(158125, 11204, 'Jornada nas Estrelas Voyager S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/439417.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mUqhIYoK8OXUmVtWMqtvffMd1lw.jpg'),
(158126, 11204, 'Jornada nas Estrelas Voyager S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/439418.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tweBPCC59c1cN858iG3QNaDPN6c.jpg'),
(158127, 11204, 'Jornada nas Estrelas Voyager S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/439419.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pfSLRpNkDbhGXqaAvqcIiyvfGGt.jpg'),
(158128, 11204, 'Jornada nas Estrelas Voyager S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/439420.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/spJIHhjMyv9NPGHejX322NFfqg2.jpg'),
(158129, 11204, 'Jornada nas Estrelas Voyager S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/439421.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eJB582bm44FYNE7Q0507M40oumG.jpg'),
(158130, 11204, 'Jornada nas Estrelas Voyager S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/439422.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yMzzyV0KaZhdEPVdL2whKQ2MGvY.jpg'),
(158131, 11204, 'Jornada nas Estrelas Voyager S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/439423.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qCmNybnvFRI8yUtZVilG6Fx2Inx.jpg'),
(158132, 11204, 'Jornada nas Estrelas Voyager S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/439424.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uTGXjq3KSEJ1Vpvobj88hZflbS.jpg'),
(158133, 11204, 'Jornada nas Estrelas Voyager S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/439425.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6eQWSwTFV4CBFifDaA5tMBbPisx.jpg'),
(158134, 11205, 'Jornada nas Estrelas Voyager S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439426.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/foIshcTRAch5oQz8kNyDUCDVO8z.jpg'),
(158135, 11205, 'Jornada nas Estrelas Voyager S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439427.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v5YwdKknFBZJZovDxj5fkiGanh7.jpg'),
(158136, 11205, 'Jornada nas Estrelas Voyager S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439428.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uzbIvSsVIgK1EisGa2vZNap2BpN.jpg'),
(158137, 11205, 'Jornada nas Estrelas Voyager S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439429.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fXBUqPbjCDKOz3MOLl7V03WbisX.jpg'),
(158138, 11205, 'Jornada nas Estrelas Voyager S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439430.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2peHmxA5UD70VHj3FcUzdiJhHNT.jpg'),
(158139, 11205, 'Jornada nas Estrelas Voyager S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439431.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1dnpplTtJGVMEpx11LRiGLNH4TW.jpg'),
(158140, 11205, 'Jornada nas Estrelas Voyager S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439432.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/huUi1aU9Dvps7QEY3w0CHAnX4aB.jpg'),
(158141, 11205, 'Jornada nas Estrelas Voyager S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/439433.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6Y3pzuJBnRGMJgChEw57BuddDyk.jpg'),
(158142, 11205, 'Jornada nas Estrelas Voyager S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/439434.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3aToXyZuNqYYwNBXSbm2JmBrF1z.jpg'),
(158143, 11205, 'Jornada nas Estrelas Voyager S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/439435.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aDRgIXLpuekEjXHagDJKQT0xdph.jpg'),
(158144, 11205, 'Jornada nas Estrelas Voyager S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/439436.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kBoZzSDs2h6nRNZ7gt5Zb6o8xF9.jpg'),
(158145, 11205, 'Jornada nas Estrelas Voyager S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/439437.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9ItKiAArbHmMSPwAj1XUtDU2YQo.jpg'),
(158146, 11205, 'Jornada nas Estrelas Voyager S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/439438.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p8A9JZBLpEHX6OKigPQULdaehZr.jpg'),
(158147, 11205, 'Jornada nas Estrelas Voyager S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/439439.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2ccXomkRAL6vBFtAH7O5mOyU3p8.jpg'),
(158148, 11205, 'Jornada nas Estrelas Voyager S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/439440.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ext9UB8WrJJcp5hWpSB7yFtMmKL.jpg'),
(158149, 11205, 'Jornada nas Estrelas Voyager S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/439441.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tRlgPoKFItMzle9rjOqMzT9CLBB.jpg'),
(158150, 11205, 'Jornada nas Estrelas Voyager S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/439442.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bOAeCrw8rgH6d8eJZ2fiuklVF2j.jpg'),
(158151, 11205, 'Jornada nas Estrelas Voyager S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/439443.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wVSfnLBBkzYgLkLT1o1NeNlJkmD.jpg'),
(158152, 11205, 'Jornada nas Estrelas Voyager S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/439444.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1JMe4dkLTYDtgHgxiVH9Ow0kYLN.jpg'),
(158153, 11205, 'Jornada nas Estrelas Voyager S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/439445.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9o0tyY1r0JtLT5iV4SgT201xvKi.jpg'),
(158154, 11205, 'Jornada nas Estrelas Voyager S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/439446.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k11Z2FCOSYJ6BTFuFoSZ7mQVaA1.jpg'),
(158155, 11205, 'Jornada nas Estrelas Voyager S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/439447.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1XIEP0we7q8AJ4E2DfK0kY66cu0.jpg'),
(158156, 11205, 'Jornada nas Estrelas Voyager S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/439448.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t2HGdRCgiO4D6JvhpKMBARTvenK.jpg'),
(158157, 11205, 'Jornada nas Estrelas Voyager S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/439449.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wqeQmglN3QkgTVMEabynaOSwGox.jpg'),
(158158, 11205, 'Jornada nas Estrelas Voyager S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/439450.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xmA7li95Y813g4Dbjl4nVYL99er.jpg'),
(158159, 11205, 'Jornada nas Estrelas Voyager S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/439451.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8y27Rm2rmqSQrOJPyDhlZJpIRQT.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(158160, 11206, 'Jornada nas Estrelas Voyager S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/439452.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j8kWCHjXXTkfMq5pWElCyp597b4.jpg'),
(158161, 11206, 'Jornada nas Estrelas Voyager S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/439453.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hYTVl2qwIIpl5Oj8Ek6ZQZwBmGz.jpg'),
(158162, 11206, 'Jornada nas Estrelas Voyager S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/439454.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/icPi44c5DHpcO6cDZ5jIBNeXhWg.jpg'),
(158163, 11206, 'Jornada nas Estrelas Voyager S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/439455.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yme46ra6aasinaJsmi2YygZDC7Z.jpg'),
(158164, 11206, 'Jornada nas Estrelas Voyager S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/439456.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zZdk3u2CzpsJjC2SatrSXQV2Cg8.jpg'),
(158165, 11206, 'Jornada nas Estrelas Voyager S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/439457.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t6VkMHJigWDyFLMAVFfzykV26sm.jpg'),
(158166, 11206, 'Jornada nas Estrelas Voyager S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/439458.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n1SeIVwufrnFH41fzgsoJr60ovc.jpg'),
(158167, 11206, 'Jornada nas Estrelas Voyager S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/439459.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wkE8WcbguYUVuJA2THHlS34PbQk.jpg'),
(158168, 11206, 'Jornada nas Estrelas Voyager S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/439460.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pXAfLfZBjbchZwwW8KJVdNCgaK.jpg'),
(158169, 11206, 'Jornada nas Estrelas Voyager S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/439461.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qf8kRspIy3BykrlClHmdqiIumiJ.jpg'),
(158170, 11206, 'Jornada nas Estrelas Voyager S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/439462.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3AbT1UFYGsgrKRFFywIQRSXuhQz.jpg'),
(158171, 11206, 'Jornada nas Estrelas Voyager S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/439463.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ddYCVAY8JsBOoIuqMdCqT4IFm1Y.jpg'),
(158172, 11206, 'Jornada nas Estrelas Voyager S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/439464.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tIk55IWJfhXgP0zerXhkS7St80K.jpg'),
(158173, 11206, 'Jornada nas Estrelas Voyager S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/439465.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tcjXtweYujsYnxl3IPPCWT0NosO.jpg'),
(158174, 11206, 'Jornada nas Estrelas Voyager S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/439466.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y6rQoypL4m8EewCZBoWV6JvZhpX.jpg'),
(158175, 11206, 'Jornada nas Estrelas Voyager S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/439467.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xKZLZSxlNmdz1kB4f8N6veYXy5V.jpg'),
(158176, 11206, 'Jornada nas Estrelas Voyager S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/439468.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iyNi6D8ewsMBrmb7NRXUoFaPCRC.jpg'),
(158177, 11206, 'Jornada nas Estrelas Voyager S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/439469.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pKlmTSPJ4RdkUeOmvw7ztBbbkPA.jpg'),
(158178, 11206, 'Jornada nas Estrelas Voyager S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/439470.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qK4hk3nDr5T2cOrl3VRsLR38bwO.jpg'),
(158179, 11206, 'Jornada nas Estrelas Voyager S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/439471.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s0RkI18bJtfENV2tg5DBtjEWFz5.jpg'),
(158180, 11206, 'Jornada nas Estrelas Voyager S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/439472.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tq8YUpozIdUPuaVpX61RUu05x8p.jpg'),
(158181, 11206, 'Jornada nas Estrelas Voyager S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/439473.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vGMP19rPWucChPA3UUP2vLc297d.jpg'),
(158182, 11206, 'Jornada nas Estrelas Voyager S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/439474.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/amO5SHWTpiALuUE9CHl3RONig1P.jpg'),
(158183, 11206, 'Jornada nas Estrelas Voyager S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/439475.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/leMMPVwov3SjLqbXgRynNy4b8I8.jpg'),
(158184, 11207, 'A Maior Companhia de Navegacao do Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445290.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/90VA5RqSEVh4ptjxyoWIXiS9NS1.jpg'),
(158185, 11207, 'A Maior Companhia de Navegacao do Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LvGPFHpG4Qdnsub5ceUQqZcxsp.jpg'),
(158186, 11207, 'A Maior Companhia de Navegacao do Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LvGPFHpG4Qdnsub5ceUQqZcxsp.jpg'),
(158187, 11207, 'A Maior Companhia de Navegacao do Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LvGPFHpG4Qdnsub5ceUQqZcxsp.jpg'),
(158188, 11207, 'A Maior Companhia de Navegacao do Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LvGPFHpG4Qdnsub5ceUQqZcxsp.jpg'),
(158189, 11207, 'A Maior Companhia de Navegacao do Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5LvGPFHpG4Qdnsub5ceUQqZcxsp.jpg'),
(158190, 11208, 'American Playboy A historia de Hugh Hefner [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445280.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5i4w3ENESxO1hZTjRxHGOc2HNdn.jpg'),
(158191, 11208, 'American Playboy A historia de Hugh Hefner [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445281.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e5prevNUF0jurXX6bqqddcUp7Bu.jpg'),
(158192, 11208, 'American Playboy A historia de Hugh Hefner [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445282.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rvWFPLKjkAHICLkBkuv6IIxOXKo.jpg'),
(158193, 11208, 'American Playboy A historia de Hugh Hefner [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445283.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fjHzup4BKLYAV1ONVoyYDJRPwId.jpg'),
(158194, 11208, 'American Playboy A historia de Hugh Hefner [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445284.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2U4uWWlLcVedHWmiaKm7PSkJjQ8.jpg'),
(158195, 11208, 'American Playboy A historia de Hugh Hefner [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445285.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vszckdANFShudab7smgdY0p5Jim.jpg'),
(158196, 11208, 'American Playboy A historia de Hugh Hefner [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445286.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e7hbFLYuOEf3TBemyptyihavyse.jpg'),
(158197, 11208, 'American Playboy A historia de Hugh Hefner [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445287.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rhgTTjJvqhGdfzOQxfkfPonODsl.jpg'),
(158198, 11208, 'American Playboy A historia de Hugh Hefner [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/445288.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/teAYqSqXYyTICdphJzNk9EQMZG7.jpg'),
(158199, 11208, 'American Playboy A historia de Hugh Hefner [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/445289.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/npA3MK0UhRxGyunIOhAT3yo9UHX.jpg'),
(158200, 11209, 'Cazalbe O Herdeiro da Graca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7kZP39oJP3f0IgzgR33Cm0MMWzv.jpg'),
(158201, 11209, 'Cazalbe O Herdeiro da Graca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7kZP39oJP3f0IgzgR33Cm0MMWzv.jpg'),
(158202, 11209, 'Cazalbe O Herdeiro da Graca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7kZP39oJP3f0IgzgR33Cm0MMWzv.jpg'),
(158203, 11209, 'Cazalbe O Herdeiro da Graca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7kZP39oJP3f0IgzgR33Cm0MMWzv.jpg'),
(158204, 11209, 'Cazalbe O Herdeiro da Graca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7kZP39oJP3f0IgzgR33Cm0MMWzv.jpg'),
(158205, 11210, 'Minha Estranha Obsessao Como Eles Estao Agora S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445274.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dCW71FUtwfOuE5lSgCaxj2IGIif.jpg'),
(158206, 11210, 'Minha Estranha Obsessao Como Eles Estao Agora S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/447356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qm1wNLLTDPiTbgKr6k8Ll23w1yx.jpg'),
(158207, 11210, 'Minha Estranha Obsessao Como Eles Estao Agora S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/456066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qm1wNLLTDPiTbgKr6k8Ll23w1yx.jpg'),
(158208, 11210, 'Minha Estranha Obsessao Como Eles Estao Agora S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/457600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qm1wNLLTDPiTbgKr6k8Ll23w1yx.jpg'),
(158209, 11210, 'Minha Estranha Obsessao Como Eles Estao Agora S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/467282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qm1wNLLTDPiTbgKr6k8Ll23w1yx.jpg'),
(158210, 11210, 'Minha Estranha Obsessao Como Eles Estao Agora S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/477528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qm1wNLLTDPiTbgKr6k8Ll23w1yx.jpg'),
(158211, 11211, 'Mirzapur [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445245.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/704HcYmXb8vq8pBP0ECq1XHXdsz.jpg'),
(158212, 11211, 'Mirzapur [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445246.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yTwf1rLjhl21lBak3Tn3cQ8Auj6.jpg'),
(158213, 11211, 'Mirzapur [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445247.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iiMwUfG86g8Zc9HkjNQo3nkEqem.jpg'),
(158214, 11211, 'Mirzapur [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445248.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iPXH1U4hXevtSVZ76AjSVfSwhvN.jpg'),
(158215, 11211, 'Mirzapur [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445249.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AeniXA09PeImwSurxgZG2Kgh0rv.jpg'),
(158216, 11211, 'Mirzapur [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445250.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jA1UpXFTZnZia3UIecBrcjXvoFX.jpg'),
(158217, 11211, 'Mirzapur [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445251.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4e1Y7UZS90uSiG2WKTZctXAXFdq.jpg'),
(158218, 11211, 'Mirzapur [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445252.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hTUvY7f25c3xSr6ooJZBwRX9ZSt.jpg'),
(158219, 11211, 'Mirzapur [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/445253.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AwhCp0swqRY8qWlcCsAd4eCAxvW.jpg'),
(158220, 11212, 'Mirzapur [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445254.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ed2fw6xL6vLj0pj3ljBXA7ZSlxB.jpg'),
(158221, 11212, 'Mirzapur [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445255.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gHO3fNtKJhU6N6mgcuJbxBzo800.jpg'),
(158222, 11212, 'Mirzapur [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445256.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jDazI8j1qN6f7UqpdyHzKFPwCbm.jpg'),
(158223, 11212, 'Mirzapur [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445257.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3EusBkqpmhYPisjFIEd5GGPQpDx.jpg'),
(158224, 11212, 'Mirzapur [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445258.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4sUKhtN1CxUlH520aNZ7chbEQoE.jpg'),
(158225, 11212, 'Mirzapur [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445259.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bglGOcqVcivMN4vuGpJp75g2XSA.jpg'),
(158226, 11212, 'Mirzapur [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445260.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rDaZL4sezFShY2OqCsDvpRyaSXw.jpg'),
(158227, 11212, 'Mirzapur [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445261.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lIAcMBOrBU3qj2XTudSxNZfVvGo.jpg'),
(158228, 11212, 'Mirzapur [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/445262.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8QbcOwQvr5Th4SLRrmUo3QmJzHC.jpg'),
(158229, 11212, 'Mirzapur [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/445263.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fcOb3i3Fc5z5W0oqhDaOcP31Eyw.jpg'),
(158230, 11213, 'Mirzapur [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445264.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r64q0CCltNbCiGPtBJuSRkfsZgg.jpg'),
(158231, 11213, 'Mirzapur [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445265.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Q0DvQtINXgcDbCY6bXqYgUP6Sa.jpg'),
(158232, 11213, 'Mirzapur [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445266.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9670IbjdSU1ZJL0kjccHIRRwbKX.jpg'),
(158233, 11213, 'Mirzapur [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445267.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5wgBLvyHKEDvuzGNzggoe12xzIU.jpg'),
(158234, 11213, 'Mirzapur [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445268.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eiMFiJUQTLYWfOZNH6k2Rn7MCs8.jpg'),
(158235, 11213, 'Mirzapur [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445269.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/27s8VYntlnCw4A40j9O8XW7MftJ.jpg'),
(158236, 11213, 'Mirzapur [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445270.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aDj2WjYA4HlWpY9Te97QiUXcnKk.jpg'),
(158237, 11213, 'Mirzapur [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445271.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jLion9LPUyFDdFccO3wRMqZmjiH.jpg'),
(158238, 11213, 'Mirzapur [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/445272.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/91bLYMo6rEAWCTeflnz8Cn6mpMO.jpg'),
(158239, 11213, 'Mirzapur [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/445273.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Ah0pv7ERodn0abJ1i5suMFHJYs.jpg'),
(158240, 11214, 'O Amor Mora ao Lado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445243.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lygWzI87b3tweRfUJlOgMcow6De.jpg'),
(158241, 11214, 'O Amor Mora ao Lado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445244.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ckcwSEmcmuPu295HVoAOnI9ZsxF.jpg'),
(158242, 11214, 'O Amor Mora ao Lado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/447102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lHSnzui4skTidHkAwQ2Qaccdokr.jpg'),
(158243, 11214, 'O Amor Mora ao Lado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/447103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lHSnzui4skTidHkAwQ2Qaccdokr.jpg'),
(158244, 11214, 'O Amor Mora ao Lado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/455903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lHSnzui4skTidHkAwQ2Qaccdokr.jpg'),
(158245, 11214, 'O Amor Mora ao Lado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/455904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lHSnzui4skTidHkAwQ2Qaccdokr.jpg'),
(158246, 11214, 'O Amor Mora ao Lado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/460649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lHSnzui4skTidHkAwQ2Qaccdokr.jpg'),
(158247, 11214, 'O Amor Mora ao Lado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/460650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lHSnzui4skTidHkAwQ2Qaccdokr.jpg'),
(158248, 11214, 'O Amor Mora ao Lado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/467103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lHSnzui4skTidHkAwQ2Qaccdokr.jpg'),
(158249, 11214, 'O Amor Mora ao Lado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/467104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lHSnzui4skTidHkAwQ2Qaccdokr.jpg'),
(158250, 11214, 'O Amor Mora ao Lado S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/473923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lHSnzui4skTidHkAwQ2Qaccdokr.jpg'),
(158251, 11214, 'O Amor Mora ao Lado S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/473924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lHSnzui4skTidHkAwQ2Qaccdokr.jpg'),
(158252, 11214, 'O Amor Mora ao Lado S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/477325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lHSnzui4skTidHkAwQ2Qaccdokr.jpg'),
(158253, 11214, 'O Amor Mora ao Lado S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/477326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lHSnzui4skTidHkAwQ2Qaccdokr.jpg'),
(158254, 11214, 'O Amor Mora ao Lado S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/488525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lHSnzui4skTidHkAwQ2Qaccdokr.jpg'),
(158255, 11214, 'O Amor Mora ao Lado S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/488526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lHSnzui4skTidHkAwQ2Qaccdokr.jpg'),
(158256, 11215, 'O Segredo de Feriha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158257, 11215, 'O Segredo de Feriha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158258, 11215, 'O Segredo de Feriha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158259, 11215, 'O Segredo de Feriha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158260, 11215, 'O Segredo de Feriha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158261, 11215, 'O Segredo de Feriha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158262, 11215, 'O Segredo de Feriha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158263, 11215, 'O Segredo de Feriha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158264, 11215, 'O Segredo de Feriha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/445236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158265, 11215, 'O Segredo de Feriha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/445237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158266, 11215, 'O Segredo de Feriha S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/445238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158267, 11215, 'O Segredo de Feriha S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/445239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158268, 11215, 'O Segredo de Feriha S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/445240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158269, 11215, 'O Segredo de Feriha S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/445241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158270, 11215, 'O Segredo de Feriha S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/445242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158271, 11215, 'O Segredo de Feriha S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/447082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158272, 11215, 'O Segredo de Feriha S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/447083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158273, 11215, 'O Segredo de Feriha S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/447084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158274, 11215, 'O Segredo de Feriha S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/447085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158275, 11215, 'O Segredo de Feriha S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/447086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158276, 11215, 'O Segredo de Feriha S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/452292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158277, 11215, 'O Segredo de Feriha S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/452293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158278, 11215, 'O Segredo de Feriha S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/455884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158279, 11215, 'O Segredo de Feriha S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/455885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158280, 11215, 'O Segredo de Feriha S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/455886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158281, 11215, 'O Segredo de Feriha S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/457448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158282, 11215, 'O Segredo de Feriha S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/457449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158283, 11215, 'O Segredo de Feriha S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/460631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158284, 11215, 'O Segredo de Feriha S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/460632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158285, 11215, 'O Segredo de Feriha S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/467067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158286, 11215, 'O Segredo de Feriha S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/467068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158287, 11215, 'O Segredo de Feriha S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/467069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158288, 11215, 'O Segredo de Feriha S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/467070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158289, 11215, 'O Segredo de Feriha S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/467071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158290, 11215, 'O Segredo de Feriha S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/467072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158291, 11215, 'O Segredo de Feriha S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/469820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158292, 11215, 'O Segredo de Feriha S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/469821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158293, 11215, 'O Segredo de Feriha S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/469822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158294, 11215, 'O Segredo de Feriha S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/473875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158295, 11215, 'O Segredo de Feriha S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/473876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158296, 11215, 'O Segredo de Feriha S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/477282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158297, 11215, 'O Segredo de Feriha S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/477283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158298, 11215, 'O Segredo de Feriha S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/477284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158299, 11215, 'O Segredo de Feriha S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/477285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158300, 11215, 'O Segredo de Feriha S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/477286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158301, 11215, 'O Segredo de Feriha S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/482464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158302, 11215, 'O Segredo de Feriha S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/482465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158303, 11215, 'O Segredo de Feriha S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/482466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158304, 11215, 'O Segredo de Feriha S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/488481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158305, 11215, 'O Segredo de Feriha S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/488482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158306, 11215, 'O Segredo de Feriha S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/490591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158307, 11215, 'O Segredo de Feriha S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/490592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158308, 11215, 'O Segredo de Feriha S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/490593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158309, 11215, 'O Segredo de Feriha S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/490594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158310, 11215, 'O Segredo de Feriha S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/490595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158311, 11215, 'O Segredo de Feriha S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/492032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158312, 11215, 'O Segredo de Feriha S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/492033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158313, 11215, 'O Segredo de Feriha S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/492034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158314, 11215, 'O Segredo de Feriha S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/492035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158315, 11215, 'O Segredo de Feriha S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/496452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158316, 11215, 'O Segredo de Feriha S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/498989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158317, 11215, 'O Segredo de Feriha S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/498990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158318, 11215, 'O Segredo de Feriha S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/498991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158319, 11215, 'O Segredo de Feriha S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/498992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158320, 11215, 'O Segredo de Feriha S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/505491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158321, 11215, 'O Segredo de Feriha S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/505492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158322, 11215, 'O Segredo de Feriha S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/505493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158323, 11215, 'O Segredo de Feriha S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/505494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158324, 11215, 'O Segredo de Feriha S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/505495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158325, 11215, 'O Segredo de Feriha S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/507713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158326, 11215, 'O Segredo de Feriha S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/511509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158327, 11215, 'O Segredo de Feriha S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/511510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158328, 11215, 'O Segredo de Feriha S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/511511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158329, 11215, 'O Segredo de Feriha S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/511512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158330, 11215, 'O Segredo de Feriha S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/511513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158331, 11215, 'O Segredo de Feriha S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/517769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158332, 11215, 'O Segredo de Feriha S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/517770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158333, 11215, 'O Segredo de Feriha S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/517771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158334, 11215, 'O Segredo de Feriha S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/517772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158335, 11215, 'O Segredo de Feriha S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/517773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158336, 11215, 'O Segredo de Feriha S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/517774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158337, 11215, 'O Segredo de Feriha S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/517775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158338, 11215, 'O Segredo de Feriha S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/517776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158339, 11215, 'O Segredo de Feriha S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/641704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158340, 11215, 'O Segredo de Feriha S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/641705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158341, 11215, 'O Segredo de Feriha S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/641706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158342, 11215, 'O Segredo de Feriha S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/641707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158343, 11215, 'O Segredo de Feriha S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/641708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158344, 11215, 'O Segredo de Feriha S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/641709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158345, 11215, 'O Segredo de Feriha S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/641710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158346, 11215, 'O Segredo de Feriha S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/641711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158347, 11215, 'O Segredo de Feriha S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/641712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158348, 11215, 'O Segredo de Feriha S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/641713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158349, 11215, 'O Segredo de Feriha S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/641714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158350, 11215, 'O Segredo de Feriha S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/641715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158351, 11215, 'O Segredo de Feriha S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/731842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158352, 11215, 'O Segredo de Feriha S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/731843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158353, 11215, 'O Segredo de Feriha S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/731844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158354, 11215, 'O Segredo de Feriha S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/731845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158355, 11215, 'O Segredo de Feriha S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/731846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158356, 11215, 'O Segredo de Feriha S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/731847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158357, 11215, 'O Segredo de Feriha S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/731848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158358, 11215, 'O Segredo de Feriha S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/731849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158359, 11215, 'O Segredo de Feriha S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/731850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158360, 11215, 'O Segredo de Feriha S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/731851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158361, 11215, 'O Segredo de Feriha S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/731852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158362, 11215, 'O Segredo de Feriha S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/731853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158363, 11215, 'O Segredo de Feriha S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/731854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158364, 11215, 'O Segredo de Feriha S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/731855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158365, 11215, 'O Segredo de Feriha S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/731856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158366, 11215, 'O Segredo de Feriha S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/731857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158367, 11215, 'O Segredo de Feriha S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/731858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158368, 11215, 'O Segredo de Feriha S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/731859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158369, 11215, 'O Segredo de Feriha S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/731860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158370, 11215, 'O Segredo de Feriha S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/731861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158371, 11215, 'O Segredo de Feriha S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/731862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158372, 11215, 'O Segredo de Feriha S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/731863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158373, 11215, 'O Segredo de Feriha S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/731864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158374, 11215, 'O Segredo de Feriha S01 E119', 'http://sinalprivado.info:80/series/1533784/1533784/731865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158375, 11215, 'O Segredo de Feriha S01 E120', 'http://sinalprivado.info:80/series/1533784/1533784/731866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158376, 11215, 'O Segredo de Feriha S01 E121', 'http://sinalprivado.info:80/series/1533784/1533784/731867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158377, 11215, 'O Segredo de Feriha S01 E122', 'http://sinalprivado.info:80/series/1533784/1533784/731868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158378, 11215, 'O Segredo de Feriha S01 E123', 'http://sinalprivado.info:80/series/1533784/1533784/731869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158379, 11215, 'O Segredo de Feriha S01 E124', 'http://sinalprivado.info:80/series/1533784/1533784/731870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158380, 11215, 'O Segredo de Feriha S01 E125', 'http://sinalprivado.info:80/series/1533784/1533784/731871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158381, 11215, 'O Segredo de Feriha S01 E126', 'http://sinalprivado.info:80/series/1533784/1533784/697712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158382, 11215, 'O Segredo de Feriha S01 E127', 'http://sinalprivado.info:80/series/1533784/1533784/697713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158383, 11215, 'O Segredo de Feriha S01 E128', 'http://sinalprivado.info:80/series/1533784/1533784/697714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158384, 11215, 'O Segredo de Feriha S01 E129', 'http://sinalprivado.info:80/series/1533784/1533784/697715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158385, 11215, 'O Segredo de Feriha S01 E130', 'http://sinalprivado.info:80/series/1533784/1533784/697716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158386, 11215, 'O Segredo de Feriha S01 E131', 'http://sinalprivado.info:80/series/1533784/1533784/697717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158387, 11215, 'O Segredo de Feriha S01 E132', 'http://sinalprivado.info:80/series/1533784/1533784/697718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158388, 11215, 'O Segredo de Feriha S01 E133', 'http://sinalprivado.info:80/series/1533784/1533784/697719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158389, 11215, 'O Segredo de Feriha S01 E134', 'http://sinalprivado.info:80/series/1533784/1533784/697720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158390, 11215, 'O Segredo de Feriha S01 E135', 'http://sinalprivado.info:80/series/1533784/1533784/697721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158391, 11215, 'O Segredo de Feriha S01 E136', 'http://sinalprivado.info:80/series/1533784/1533784/704529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158392, 11215, 'O Segredo de Feriha S01 E137', 'http://sinalprivado.info:80/series/1533784/1533784/704530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158393, 11215, 'O Segredo de Feriha S01 E138', 'http://sinalprivado.info:80/series/1533784/1533784/704531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158394, 11215, 'O Segredo de Feriha S01 E139', 'http://sinalprivado.info:80/series/1533784/1533784/704532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158395, 11215, 'O Segredo de Feriha S01 E140', 'http://sinalprivado.info:80/series/1533784/1533784/704533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158396, 11215, 'O Segredo de Feriha S01 E141', 'http://sinalprivado.info:80/series/1533784/1533784/717871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158397, 11215, 'O Segredo de Feriha S01 E142', 'http://sinalprivado.info:80/series/1533784/1533784/717872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158398, 11215, 'O Segredo de Feriha S01 E143', 'http://sinalprivado.info:80/series/1533784/1533784/717873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158399, 11215, 'O Segredo de Feriha S01 E144', 'http://sinalprivado.info:80/series/1533784/1533784/717874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158400, 11215, 'O Segredo de Feriha S01 E145', 'http://sinalprivado.info:80/series/1533784/1533784/717875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158401, 11215, 'O Segredo de Feriha S01 E146', 'http://sinalprivado.info:80/series/1533784/1533784/779063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158402, 11215, 'O Segredo de Feriha S01 E147', 'http://sinalprivado.info:80/series/1533784/1533784/779064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158403, 11215, 'O Segredo de Feriha S01 E148', 'http://sinalprivado.info:80/series/1533784/1533784/779065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158404, 11215, 'O Segredo de Feriha S01 E149', 'http://sinalprivado.info:80/series/1533784/1533784/779066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158405, 11215, 'O Segredo de Feriha S01 E150', 'http://sinalprivado.info:80/series/1533784/1533784/779067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158406, 11215, 'O Segredo de Feriha S01 E151', 'http://sinalprivado.info:80/series/1533784/1533784/779068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158407, 11215, 'O Segredo de Feriha S01 E152', 'http://sinalprivado.info:80/series/1533784/1533784/779069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158408, 11215, 'O Segredo de Feriha S01 E153', 'http://sinalprivado.info:80/series/1533784/1533784/779070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158409, 11215, 'O Segredo de Feriha S01 E154', 'http://sinalprivado.info:80/series/1533784/1533784/779071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158410, 11215, 'O Segredo de Feriha S01 E155', 'http://sinalprivado.info:80/series/1533784/1533784/779072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158411, 11215, 'O Segredo de Feriha S01 E156', 'http://sinalprivado.info:80/series/1533784/1533784/779073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(158412, 11215, 'O Segredo de Feriha S01 E157', 'http://sinalprivado.info:80/series/1533784/1533784/779074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158413, 11215, 'O Segredo de Feriha S01 E158', 'http://sinalprivado.info:80/series/1533784/1533784/779075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158414, 11215, 'O Segredo de Feriha S01 E159', 'http://sinalprivado.info:80/series/1533784/1533784/779076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158415, 11215, 'O Segredo de Feriha S01 E160', 'http://sinalprivado.info:80/series/1533784/1533784/779077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158416, 11215, 'O Segredo de Feriha S01 E161', 'http://sinalprivado.info:80/series/1533784/1533784/779078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158417, 11215, 'O Segredo de Feriha S01 E162', 'http://sinalprivado.info:80/series/1533784/1533784/779079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158418, 11215, 'O Segredo de Feriha S01 E163', 'http://sinalprivado.info:80/series/1533784/1533784/779080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158419, 11215, 'O Segredo de Feriha S01 E164', 'http://sinalprivado.info:80/series/1533784/1533784/779081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158420, 11215, 'O Segredo de Feriha S01 E165', 'http://sinalprivado.info:80/series/1533784/1533784/779082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158421, 11215, 'O Segredo de Feriha S01 E166', 'http://sinalprivado.info:80/series/1533784/1533784/779083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158422, 11215, 'O Segredo de Feriha S01 E167', 'http://sinalprivado.info:80/series/1533784/1533784/779084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158423, 11215, 'O Segredo de Feriha S01 E168', 'http://sinalprivado.info:80/series/1533784/1533784/779085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158424, 11215, 'O Segredo de Feriha S01 E169', 'http://sinalprivado.info:80/series/1533784/1533784/779086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158425, 11215, 'O Segredo de Feriha S01 E170', 'http://sinalprivado.info:80/series/1533784/1533784/779087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158426, 11215, 'O Segredo de Feriha S01 E171', 'http://sinalprivado.info:80/series/1533784/1533784/779088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158427, 11215, 'O Segredo de Feriha S01 E172', 'http://sinalprivado.info:80/series/1533784/1533784/779089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158428, 11215, 'O Segredo de Feriha S01 E173', 'http://sinalprivado.info:80/series/1533784/1533784/779090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158429, 11215, 'O Segredo de Feriha S01 E174', 'http://sinalprivado.info:80/series/1533784/1533784/779091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s7idyoMLHLsI65xXj1ApBwedTmm.jpg'),
(158430, 11216, 'Operacao Fronteira Suecia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bUkxnNVzaH5q5rNqwigX3oDuzRc.jpg'),
(158431, 11216, 'Operacao Fronteira Suecia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bUkxnNVzaH5q5rNqwigX3oDuzRc.jpg'),
(158432, 11216, 'Operacao Fronteira Suecia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/454742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bUkxnNVzaH5q5rNqwigX3oDuzRc.jpg'),
(158433, 11216, 'Operacao Fronteira Suecia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/459423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bUkxnNVzaH5q5rNqwigX3oDuzRc.jpg'),
(158434, 11216, 'Operacao Fronteira Suecia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/467037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bUkxnNVzaH5q5rNqwigX3oDuzRc.jpg'),
(158435, 11216, 'Operacao Fronteira Suecia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/525144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bUkxnNVzaH5q5rNqwigX3oDuzRc.jpg'),
(158436, 11216, 'Operacao Fronteira Suecia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/633658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bUkxnNVzaH5q5rNqwigX3oDuzRc.jpg'),
(158437, 11216, 'Operacao Fronteira Suecia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/503701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bUkxnNVzaH5q5rNqwigX3oDuzRc.jpg'),
(158438, 11216, 'Operacao Fronteira Suecia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/503702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bUkxnNVzaH5q5rNqwigX3oDuzRc.jpg'),
(158439, 11216, 'Operacao Fronteira Suecia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/503703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bUkxnNVzaH5q5rNqwigX3oDuzRc.jpg'),
(158440, 11216, 'Operacao Fronteira Suecia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/511434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bUkxnNVzaH5q5rNqwigX3oDuzRc.jpg'),
(158441, 11216, 'Operacao Fronteira Suecia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/514240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bUkxnNVzaH5q5rNqwigX3oDuzRc.jpg'),
(158442, 11216, 'Operacao Fronteira Suecia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/517687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bUkxnNVzaH5q5rNqwigX3oDuzRc.jpg'),
(158443, 11216, 'Operacao Fronteira Suecia S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/525152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bUkxnNVzaH5q5rNqwigX3oDuzRc.jpg'),
(158444, 11217, 'Respira S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445219.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hQXhEE2VaPWTIT8K0Qg2PtTja3w.jpg'),
(158445, 11217, 'Respira S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445220.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3cvc55OwatX7Zp2F5GM5crhauxB.jpg'),
(158446, 11217, 'Respira S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445221.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fGJhjqHGSycSBjplpsvV5oSyCeM.jpg'),
(158447, 11217, 'Respira S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445222.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1qeEqRXMPKG4yF6MvXDYSTxjI9B.jpg'),
(158448, 11217, 'Respira S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445223.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aOPSQNSp0CgJh303SIqFfLHX56r.jpg'),
(158449, 11217, 'Respira S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445224.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yhSTMxvGNXkuZtFk9YNrEMj2p8T.jpg'),
(158450, 11217, 'Respira S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445225.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jbmPQNB3yQJMOzOY4mTaMFeqvus.jpg'),
(158451, 11217, 'Respira S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445226.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1oz48R3EXcrYUlp61No6gCju6XN.jpg'),
(158452, 11218, 'Respira S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/891838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agMDJ2ivB4idDv5Fvzuh4DI7pHs.jpg'),
(158453, 11218, 'Respira S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/891839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agMDJ2ivB4idDv5Fvzuh4DI7pHs.jpg'),
(158454, 11218, 'Respira S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/891840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agMDJ2ivB4idDv5Fvzuh4DI7pHs.jpg'),
(158455, 11218, 'Respira S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/891841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agMDJ2ivB4idDv5Fvzuh4DI7pHs.jpg'),
(158456, 11218, 'Respira S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/891842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agMDJ2ivB4idDv5Fvzuh4DI7pHs.jpg'),
(158457, 11218, 'Respira S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/891843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agMDJ2ivB4idDv5Fvzuh4DI7pHs.jpg'),
(158458, 11218, 'Respira S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/891844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agMDJ2ivB4idDv5Fvzuh4DI7pHs.jpg'),
(158459, 11218, 'Respira S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/891845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/agMDJ2ivB4idDv5Fvzuh4DI7pHs.jpg'),
(158460, 11219, 'Scooby Doo Cade Voce S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445194.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uf8aafMtP5HWQGTuf8XXLJ4QNhZ.jpg'),
(158461, 11219, 'Scooby Doo Cade Voce S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445195.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/av3eALxJhGetZbqx88FzDWDa3xm.jpg'),
(158462, 11219, 'Scooby Doo Cade Voce S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445196.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4bKESPJvgGB1ZWANt03h4BUz7g0.jpg'),
(158463, 11219, 'Scooby Doo Cade Voce S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445197.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zrxvOTFklmu1ZGEsl7W00wWWT6h.jpg'),
(158464, 11219, 'Scooby Doo Cade Voce S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445198.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uNS3lBcKkNkCjSUhjnVVoyesReI.jpg'),
(158465, 11219, 'Scooby Doo Cade Voce S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445199.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n8y16gRSwjvvOQNyBPp94M4yJEL.jpg'),
(158466, 11219, 'Scooby Doo Cade Voce S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445200.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fokQiBZYPlzDDieJGtK4Om1ud0s.jpg'),
(158467, 11219, 'Scooby Doo Cade Voce S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445201.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6L1ZTxiLuZ33Gr9LeZY0MWKhXA0.jpg'),
(158468, 11219, 'Scooby Doo Cade Voce S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/445202.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o7KFIutof2bYAiJJ0wIoCtqkqzo.jpg'),
(158469, 11219, 'Scooby Doo Cade Voce S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/445203.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pvGSse0lJ91fqZrDveulonG012q.jpg'),
(158470, 11219, 'Scooby Doo Cade Voce S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/445204.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tzoIfrOUNQe804iU3eWaTB0CoKo.jpg'),
(158471, 11219, 'Scooby Doo Cade Voce S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/445205.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nbAA5fSg4UNYkTaeeic2dkdCKHN.jpg'),
(158472, 11219, 'Scooby Doo Cade Voce S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/445206.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ajKOMFuUszZDRD3PWP8SpNv1B6Q.jpg'),
(158473, 11219, 'Scooby Doo Cade Voce S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/445207.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tXVrzzNEAqFcRzg8f8f2f00Az8l.jpg'),
(158474, 11219, 'Scooby Doo Cade Voce S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/445208.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qVS4RS5whChk3D8jhW7SVbpo0u8.jpg'),
(158475, 11219, 'Scooby Doo Cade Voce S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/445209.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qMduSNHcAvVK7LtAwCdFBzwVdix.jpg'),
(158476, 11219, 'Scooby Doo Cade Voce S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/445210.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/txCetFLBQ5jxqWIOOEdO7u2cuhA.jpg'),
(158477, 11220, 'Scooby Doo Cade Voce S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445211.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wVg7LXoqmoAG88PKdsfYYH8ul3l.jpg'),
(158478, 11220, 'Scooby Doo Cade Voce S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445212.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zySWAWgXMtDH6NEyRE8tgqmDrdW.jpg'),
(158479, 11220, 'Scooby Doo Cade Voce S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445213.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ibmqsVhr7io3hluRpEFLP95JQtA.jpg'),
(158480, 11220, 'Scooby Doo Cade Voce S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445214.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gi7jIQnW4Pu99Od0Xjet6IdE31I.jpg'),
(158481, 11220, 'Scooby Doo Cade Voce S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445215.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eMFUfm7tOhqG3Zdaplcd5Nq8UfG.jpg'),
(158482, 11220, 'Scooby Doo Cade Voce S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445216.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5MxMAoLSDWbqkTHnMXQwS92WESP.jpg'),
(158483, 11220, 'Scooby Doo Cade Voce S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445217.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x0UnYb2Hy1rrHF3itwmM3Vwuw1j.jpg'),
(158484, 11220, 'Scooby Doo Cade Voce S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445218.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gwiY4jUwCc538hwTcHC6JCJFo9p.jpg'),
(158485, 11221, 'SurrealEstate S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445184.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oZd2nMyCFATKqSFDY4xV3xMGcet.jpg'),
(158486, 11221, 'SurrealEstate S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445185.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mgT9FUJ05FBIqwXPSQ696h3Rgm9.jpg'),
(158487, 11221, 'SurrealEstate S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445186.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qJIPxAwPDH1vIdunFuzF7BAZb1B.jpg'),
(158488, 11221, 'SurrealEstate S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445187.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kvS237P4UgcOBjebsOMcup1UXcZ.jpg'),
(158489, 11221, 'SurrealEstate S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445188.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/adj0iVzo4SYzTTHlGQk9W2VZcUj.jpg'),
(158490, 11221, 'SurrealEstate S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445189.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Aw9yQ8Yptm2BVzFm7pCxKJnAJxs.jpg'),
(158491, 11221, 'SurrealEstate S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445190.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yyjSsx4vOJoNChVoNDU5diGXL6c.jpg'),
(158492, 11221, 'SurrealEstate S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445191.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1PlOBsDcsxKyckCT1iBdMHYNo06.jpg'),
(158493, 11221, 'SurrealEstate S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/445192.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iZ4oA1LaqEWLCrN8JfGCJj8xYHS.jpg'),
(158494, 11221, 'SurrealEstate S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/445193.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6HBqAoigcIyIv3D7I477PhaMxab.jpg'),
(158495, 11222, 'SurrealEstate S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/463627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yrwNLzth5FjydiXJK1I1tOKdAFs.jpg'),
(158496, 11222, 'SurrealEstate S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/463628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yrwNLzth5FjydiXJK1I1tOKdAFs.jpg'),
(158497, 11222, 'SurrealEstate S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/463629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yrwNLzth5FjydiXJK1I1tOKdAFs.jpg'),
(158498, 11222, 'SurrealEstate S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/469146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yrwNLzth5FjydiXJK1I1tOKdAFs.jpg'),
(158499, 11222, 'SurrealEstate S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/480951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yrwNLzth5FjydiXJK1I1tOKdAFs.jpg'),
(158500, 11222, 'SurrealEstate S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/480952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yrwNLzth5FjydiXJK1I1tOKdAFs.jpg'),
(158501, 11222, 'SurrealEstate S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/490027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yrwNLzth5FjydiXJK1I1tOKdAFs.jpg'),
(158502, 11222, 'SurrealEstate S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/494923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yrwNLzth5FjydiXJK1I1tOKdAFs.jpg'),
(158503, 11222, 'SurrealEstate S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/494924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yrwNLzth5FjydiXJK1I1tOKdAFs.jpg'),
(158504, 11222, 'SurrealEstate S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/504687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yrwNLzth5FjydiXJK1I1tOKdAFs.jpg'),
(158505, 11223, 'SurrealEstate S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/889604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yrwNLzth5FjydiXJK1I1tOKdAFs.jpg'),
(158506, 11223, 'SurrealEstate S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/889605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yrwNLzth5FjydiXJK1I1tOKdAFs.jpg'),
(158507, 11223, 'SurrealEstate S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/889606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yrwNLzth5FjydiXJK1I1tOKdAFs.jpg'),
(158508, 11223, 'SurrealEstate S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/889607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yrwNLzth5FjydiXJK1I1tOKdAFs.jpg'),
(158509, 11223, 'SurrealEstate S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/889608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yrwNLzth5FjydiXJK1I1tOKdAFs.jpg'),
(158510, 11223, 'SurrealEstate S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/889609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yrwNLzth5FjydiXJK1I1tOKdAFs.jpg'),
(158511, 11223, 'SurrealEstate S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/889610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yrwNLzth5FjydiXJK1I1tOKdAFs.jpg'),
(158512, 11223, 'SurrealEstate S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/889611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yrwNLzth5FjydiXJK1I1tOKdAFs.jpg'),
(158513, 11223, 'SurrealEstate S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/889612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yrwNLzth5FjydiXJK1I1tOKdAFs.jpg'),
(158514, 11223, 'SurrealEstate S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/889613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yrwNLzth5FjydiXJK1I1tOKdAFs.jpg'),
(158515, 1327, 'The Deuce S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445159.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4m6BJzB01cMIxEzHSe3gIN7V4Ec.jpg'),
(158516, 1327, 'The Deuce S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445160.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x3B9pWu3jq9GGK55yPSXKBC6HQL.jpg'),
(158517, 1327, 'The Deuce S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445161.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/41KsdGhUM04NwwAOM0uqHGicolM.jpg'),
(158518, 1327, 'The Deuce S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445162.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hDXriUF3BUceUyyteYjF6B9bObf.jpg'),
(158519, 1327, 'The Deuce S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445163.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lEeYe1wOBdvFgeQDm5KeYMEsB9W.jpg'),
(158520, 1327, 'The Deuce S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445164.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hv9iZxz4CETjYCGwQBjrB4XsD8i.jpg'),
(158521, 1327, 'The Deuce S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445165.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yMe8zWKOEqWG06d6bSmRbsSb4lH.jpg'),
(158522, 1327, 'The Deuce S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445166.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2vLCGGdEM9qSHAB5nF1mwN7n91o.jpg'),
(158523, 1328, 'The Deuce S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445167.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/spg6PKsfov4oNiNKdWXkkzrKJLh.jpg'),
(158524, 1328, 'The Deuce S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445168.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jVX2bwzFyxvPaYJn58lKNjMNU6z.jpg'),
(158525, 1328, 'The Deuce S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445169.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zhkAXJZetI0ihcWL6hfKculmjvG.jpg'),
(158526, 1328, 'The Deuce S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445170.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cqkf0YomptwZq6F7seU8pl3Tgbr.jpg'),
(158527, 1328, 'The Deuce S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445171.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1A3HEY0LXT2aEiXHOtQlCbmpNcL.jpg'),
(158528, 1328, 'The Deuce S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445172.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3DMh2FTJ4uz1tXtuoRoDjqmpbAa.jpg'),
(158529, 1328, 'The Deuce S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445173.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fXJVhgfCxPfkdEVPirXuayjEtpv.jpg'),
(158530, 1328, 'The Deuce S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445174.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vF2CF1Y1jL3PZIbbfp6GqCFM5PM.jpg'),
(158531, 1328, 'The Deuce S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/445175.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cUJdQNymLQGQ7heYDifWKeI9e9U.jpg'),
(158532, 1329, 'The Deuce S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445176.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/feZRnEEIyOYwRsuuB8fs5nB4QN4.jpg'),
(158533, 1329, 'The Deuce S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445177.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/56oQQGLtFdJHenDoU2rJahAkwbw.jpg'),
(158534, 1329, 'The Deuce S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445178.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ok3DjEUa5K3udorpDUWF4im7ArM.jpg'),
(158535, 1329, 'The Deuce S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445179.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1SnnHglnPjXYSlvlS2BAf6ay0Qs.jpg'),
(158536, 1329, 'The Deuce S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445180.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wOEkRHXQT2mjVnSbG38j41Nu8Un.jpg'),
(158537, 1329, 'The Deuce S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445181.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xAGsX7hlDjPG6PKHpOrt5VRVMPL.jpg'),
(158538, 1329, 'The Deuce S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445182.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zVEWLXrxzkhRNqqc3cEeoEBecQ5.jpg'),
(158539, 1329, 'The Deuce S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445183.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m1WTESRUWi0Xw9mdlWcmtnPBAQm.jpg'),
(158540, 11224, 'Utopia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445151.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yU2tuM5kdREp1ZwQLJ8E1Msf9tJ.jpg'),
(158541, 11224, 'Utopia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445152.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l4ZWlXj69rsptLGfnT9136vb6IR.jpg'),
(158542, 11224, 'Utopia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445153.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/duU1EB64AiEu8KqNsA65a22D9Mo.jpg'),
(158543, 11224, 'Utopia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445154.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qS0mYAdykMX2d0QgPVOv688o1yT.jpg'),
(158544, 11224, 'Utopia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445155.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lw1ai5iGv5CyXNezmmwUgGmhj2z.jpg'),
(158545, 11224, 'Utopia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445156.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/egsWRv30Isvgpp50KlOJiP7kUZf.jpg'),
(158546, 11224, 'Utopia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445157.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6XesRgbnnr7fbdRryBRkNVn7bzO.jpg'),
(158547, 11224, 'Utopia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445158.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xsj4UkAcZTmGDzarrSVRD5fPGRd.jpg'),
(158548, 11225, 'Vienna Blood [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445140.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5ULdyAyVml2OZqZdWR51ICvdGCB.jpg'),
(158549, 11225, 'Vienna Blood [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445141.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qy2xq2VI4O1s7xadPSrN2ETjfeS.jpg'),
(158550, 11225, 'Vienna Blood [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445142.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n5Enx65q3Cww2iLgtkCIkevcyf.jpg'),
(158551, 11226, 'Vienna Blood [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445143.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pfCIK1q8Vt3ghmmnIojTzJrr6Xq.jpg'),
(158552, 11226, 'Vienna Blood [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445144.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lwB0fDhYzGxg59k4gQD8I57cuWb.jpg'),
(158553, 11226, 'Vienna Blood [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445145.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wAT4XOe4uomNZm6cWzDnVJV2vdf.jpg'),
(158554, 11227, 'Vienna Blood [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445146.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eJcyGkqpaIGki2hfexKUytB0vUu.jpg'),
(158555, 11227, 'Vienna Blood [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445147.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8tvupcFTN6TqyYoOFYwmlKVKKGZ.jpg'),
(158556, 11227, 'Vienna Blood [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445148.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iUdhXbZ8OAJs6ThVLUkTCnrxPnX.jpg'),
(158557, 11228, 'Vienna Blood [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445149.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w3J5NmtBsDrO983Kio9e0nxp9Dw.jpg'),
(158558, 11228, 'Vienna Blood [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445150.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sofJQR3xpMQ5No8i23gFQFJcvvv.jpg'),
(158559, 11229, 'Voo IC 814 Sequestro a Bordo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445134.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2LmPZemikgBNMUDJoiZN6EbElTr.jpg'),
(158560, 11229, 'Voo IC 814 Sequestro a Bordo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445135.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sYMYGEUgd3vD9rWHHRqUc9RXgiJ.jpg'),
(158561, 11229, 'Voo IC 814 Sequestro a Bordo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445136.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/phLFSFRQbGMTfZE1VurOHBeoRtX.jpg'),
(158562, 11229, 'Voo IC 814 Sequestro a Bordo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445137.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jq3TXxnHvrEfZ2ePC7vSPIFdtBo.jpg'),
(158563, 11229, 'Voo IC 814 Sequestro a Bordo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445138.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nzGFoVLBb81eFOeZjqNOSreruLK.jpg'),
(158564, 11229, 'Voo IC 814 Sequestro a Bordo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445139.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/keAz2j8QLUeEF9sA4THDRGHlPXW.jpg'),
(158565, 11230, 'World Dice Tour [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445120.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9xYovOafLcittHU7sybVU6Bpv5b.jpg'),
(158566, 11230, 'World Dice Tour [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445121.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lr23Cyhr55BshkEuDsENLDtq9U8.jpg'),
(158567, 11230, 'World Dice Tour [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445122.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zWLQbdKpNn6nGKKhRGiI7znGMBS.jpg'),
(158568, 11230, 'World Dice Tour [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445123.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/psZVuHouIYvJebtceIyGziRvEmG.jpg'),
(158569, 11230, 'World Dice Tour [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445124.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rZeNCxpbwBRY1LlWeCwPNtaZq7a.jpg'),
(158570, 11230, 'World Dice Tour [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445125.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rk27qgj9mPuJxnkO8gB1KQ6r7VE.jpg'),
(158571, 11230, 'World Dice Tour [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445126.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2WKSgyUU3GpSCba9GjKQWRMqGbY.jpg'),
(158572, 11230, 'World Dice Tour [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445127.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/39ZOQWrLaHFk72g7xZeLlrCyC4D.jpg'),
(158573, 11230, 'World Dice Tour [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/445128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/khzTQ4y7KdRN78Z70ZRARjhmhdp.jpg'),
(158574, 11230, 'World Dice Tour [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/445129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/khzTQ4y7KdRN78Z70ZRARjhmhdp.jpg'),
(158575, 11230, 'World Dice Tour [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/445130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/khzTQ4y7KdRN78Z70ZRARjhmhdp.jpg'),
(158576, 11230, 'World Dice Tour [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/445131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/khzTQ4y7KdRN78Z70ZRARjhmhdp.jpg'),
(158577, 11230, 'World Dice Tour [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/445132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/khzTQ4y7KdRN78Z70ZRARjhmhdp.jpg'),
(158578, 11230, 'World Dice Tour [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/445133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/khzTQ4y7KdRN78Z70ZRARjhmhdp.jpg'),
(158579, 11231, 'Diarios de um Vampiro [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445302.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zaVO5tSSSjgLLSXRBvDDCzyBqfX.jpg'),
(158580, 11231, 'Diarios de um Vampiro [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445303.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aIwKvdwGCvxQZDZzh89DrGgm74x.jpg'),
(158581, 11231, 'Diarios de um Vampiro [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445304.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6m8fd1s5pyXLDOBFDXu9panIxeu.jpg'),
(158582, 11231, 'Diarios de um Vampiro [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445305.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/80Mag2jbHid3X4NxWC031C785FK.jpg'),
(158583, 11231, 'Diarios de um Vampiro [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445306.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sybpzVMdYQRYWKZrGBGHFL4OhtD.jpg'),
(158584, 11231, 'Diarios de um Vampiro [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445307.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/flHYnuvIOm4MmEnDlPFOSHoOgvi.jpg'),
(158585, 11231, 'Diarios de um Vampiro [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445308.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z4Ye1TyS6MfzfCikqULL3t26l4e.jpg'),
(158586, 11231, 'Diarios de um Vampiro [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445309.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/87GU0EHVzAma2sNbPLwDLftk8bO.jpg'),
(158587, 11231, 'Diarios de um Vampiro [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/445310.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kBJfC9tvqnc5itDAL4iXO85yP5z.jpg'),
(158588, 11231, 'Diarios de um Vampiro [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/445311.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2V05XM7YpzNe6okZ5AWuT9ef6xT.jpg'),
(158589, 11231, 'Diarios de um Vampiro [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/445312.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2vdRPTaLsI7la5256ROQm6Duyxl.jpg'),
(158590, 11231, 'Diarios de um Vampiro [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/445313.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ajc7kRmV9cUUJ4vCJIFdDoWd9uG.jpg'),
(158591, 11231, 'Diarios de um Vampiro [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/445314.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s8nLnmIOEjNbWIkNfKDVImCytcx.jpg'),
(158592, 11231, 'Diarios de um Vampiro [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/445315.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gs5ATQ6o9jYjLFkBksJ9mpOZWIZ.jpg'),
(158593, 11231, 'Diarios de um Vampiro [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/445316.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tD85NQGA80RJ5Zn5OL1FZ8MG30m.jpg'),
(158594, 11231, 'Diarios de um Vampiro [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/445317.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8ONScjLxYLJm1XJPWC3U1X4oGoO.jpg'),
(158595, 11231, 'Diarios de um Vampiro [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/445318.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dmBppkCRAzv0AQOoHCcyKwfV4Km.jpg'),
(158596, 11231, 'Diarios de um Vampiro [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/445319.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qJd9EK7510ksj5IuFACiYZjn1kp.jpg'),
(158597, 11231, 'Diarios de um Vampiro [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/445320.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/72rm2L0mLGTIBdFPmNqcA9vunlb.jpg'),
(158598, 11231, 'Diarios de um Vampiro [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/445321.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2W7ZtD84NAnErAuuFBAH1988fpn.jpg'),
(158599, 11231, 'Diarios de um Vampiro [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/445322.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gY9mTBmhAqGrTcj9YUbQnNyp9lz.jpg'),
(158600, 11231, 'Diarios de um Vampiro [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/445323.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sSuxMVbLGMHosZvJWYKhYODOen3.jpg'),
(158601, 11232, 'Diarios de um Vampiro [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445324.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jzYV2jaQkIvo6T9JvuxkRzv8r4f.jpg'),
(158602, 11232, 'Diarios de um Vampiro [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445325.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3xcKbK4jtFyGWBCoh4OgZoccIw9.jpg'),
(158603, 11232, 'Diarios de um Vampiro [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445326.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6dnyl5JdxNGcis4FrRlfgfBGkA7.jpg'),
(158604, 11232, 'Diarios de um Vampiro [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445327.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tchtbS3z0HgmZzwhQBivLZKtyxG.jpg'),
(158605, 11232, 'Diarios de um Vampiro [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445328.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cjntdE8fsbRbbgOV5UqBKgzbj1I.jpg'),
(158606, 11232, 'Diarios de um Vampiro [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445329.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y9D4nhgd4GyHlfowyYKCwtCLBZo.jpg'),
(158607, 11232, 'Diarios de um Vampiro [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445330.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/siWtHdsWpLSRgha7HLSdC98zJEs.jpg'),
(158608, 11232, 'Diarios de um Vampiro [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445331.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7xyMZKjeI8GtGd1lEAYiK0tBWsr.jpg'),
(158609, 11232, 'Diarios de um Vampiro [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/445332.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6FnMiaKfMWYEj3VuBQWAqk91cGe.jpg'),
(158610, 11232, 'Diarios de um Vampiro [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/445333.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uxTWfbs9oaijIezZuiEdk7pfaQL.jpg'),
(158611, 11232, 'Diarios de um Vampiro [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/445334.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hjA38vdL4QB1Pa2Fzl7XtcmzZnM.jpg'),
(158612, 11232, 'Diarios de um Vampiro [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/445335.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/svNt0Ask7rtubnMBCuZYmtTb2we.jpg'),
(158613, 11232, 'Diarios de um Vampiro [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/445336.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mNqQy7dKFBhW26pcmGvnO4xLGxy.jpg'),
(158614, 11232, 'Diarios de um Vampiro [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/445337.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k2ThDAoMkFrys9RKqoAV8hysixm.jpg'),
(158615, 11232, 'Diarios de um Vampiro [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/445338.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3EzuCDFxcYPb1OGyENQNgN1nTGh.jpg'),
(158616, 11232, 'Diarios de um Vampiro [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/445339.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tfj6V04SkFDVZXNG5LRR48jDKJu.jpg'),
(158617, 11232, 'Diarios de um Vampiro [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/445340.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lP7xv2HrNCgy8MdggcqWudsJbBM.jpg'),
(158618, 11232, 'Diarios de um Vampiro [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/445341.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ajBKbPUY6029KqeV8ins8L9Pezs.jpg'),
(158619, 11232, 'Diarios de um Vampiro [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/445342.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lFSzwf46I87amME9MZo8gq48gc1.jpg'),
(158620, 11232, 'Diarios de um Vampiro [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/445343.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3aEE2qiHXpkYObbA91drnj3w3Y9.jpg'),
(158621, 11232, 'Diarios de um Vampiro [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/445344.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9xKHHourvTu0eAUNVEk9MCAomyw.jpg'),
(158622, 11232, 'Diarios de um Vampiro [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/445345.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g12uWQ03NbtVrohzHE848EUx0NO.jpg'),
(158623, 11233, 'Diarios de um Vampiro [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445346.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jjFUXe0LjHeLnyrvtS1O9dwe3u3.jpg'),
(158624, 11233, 'Diarios de um Vampiro [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445347.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ybF8slgzyNiqE1ZKduFn34VjuVZ.jpg'),
(158625, 11233, 'Diarios de um Vampiro [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445348.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4S8dGtLEkSY6t5F8ITTWqyNSi61.jpg'),
(158626, 11233, 'Diarios de um Vampiro [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445349.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jLetnMUISh8DMG59dQWpY4h5BQJ.jpg'),
(158627, 11233, 'Diarios de um Vampiro [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445350.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/taGFTflONzldqWeDZJVbvhhvzRx.jpg'),
(158628, 11233, 'Diarios de um Vampiro [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445351.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kZlWCltDNTtfU5IINhTKhMqMAsR.jpg'),
(158629, 11233, 'Diarios de um Vampiro [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445352.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7v7quqiIifxMje8y8eHMBybUZPj.jpg'),
(158630, 11233, 'Diarios de um Vampiro [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445353.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gJ02SHb87mK1wEQfWjtlofx0W9P.jpg'),
(158631, 11233, 'Diarios de um Vampiro [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/445354.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fp1BgYOBqhvvaXfIRC8s0Zcu5ZC.jpg'),
(158632, 11233, 'Diarios de um Vampiro [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/445355.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3c5Sr8x0BTb1BtldMXlb4euosqB.jpg'),
(158633, 11233, 'Diarios de um Vampiro [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/445356.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v2mKsvW4jLm2vUnu7T637WHzycM.jpg'),
(158634, 11233, 'Diarios de um Vampiro [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/445357.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z7jVa6jqXPQWGJkCJRZQlOmFUSD.jpg'),
(158635, 11233, 'Diarios de um Vampiro [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/445358.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z1ycCdnCIZSSJnpjfoqUeeb9thi.jpg'),
(158636, 11233, 'Diarios de um Vampiro [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/445359.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wuZLqv10vAIMSSLg55vbOrKC7Eg.jpg'),
(158637, 11233, 'Diarios de um Vampiro [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/445360.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jaKSkqujNQhVmLlvikRin3FUUD8.jpg'),
(158638, 11233, 'Diarios de um Vampiro [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/445361.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ohqHQYuY94204LMCJVRGkhViCWM.jpg'),
(158639, 11233, 'Diarios de um Vampiro [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/445362.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t9ycBJkbgWDW8qGAw0PccKYchCi.jpg'),
(158640, 11233, 'Diarios de um Vampiro [L] S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/445363.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9j1xqXiKC4kgzO6VkQ2UDG2Gv8O.jpg'),
(158641, 11233, 'Diarios de um Vampiro [L] S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/445364.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cKPPwOXB6ytKJGOKtLmlySB182d.jpg'),
(158642, 11233, 'Diarios de um Vampiro [L] S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/445365.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zxDGK2rm07zwEYVPNFKKCQigRx8.jpg'),
(158643, 11233, 'Diarios de um Vampiro [L] S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/445366.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y7UVo4A8XPRmzTbQsnz2FMD3Veh.jpg'),
(158644, 11233, 'Diarios de um Vampiro [L] S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/445367.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mwu9oQJADUZAh71z5K29mZQs9Vj.jpg'),
(158645, 11234, 'Diarios de um Vampiro [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445368.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qPSpDJ554ffN1Fi1IvFhc0n883V.jpg'),
(158646, 11234, 'Diarios de um Vampiro [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445369.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uM9O9fcMseTXt1YxjXHiASiUbqY.jpg'),
(158647, 11234, 'Diarios de um Vampiro [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445370.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qu3LmH76u5Vqd5DhdIqgwOsHn2b.jpg'),
(158648, 11234, 'Diarios de um Vampiro [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445371.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rfx4pGTnKdAw3DDT00vyoKZubCS.jpg'),
(158649, 11234, 'Diarios de um Vampiro [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445372.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gywtzCdYMIeTOKXcDVn4sdXAINC.jpg'),
(158650, 11234, 'Diarios de um Vampiro [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445373.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/34wEYCld6s5uxnFVRz8olDhnBLN.jpg'),
(158651, 11234, 'Diarios de um Vampiro [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445374.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hUdCM10dxRIQHPCF6hrCzxvqbEZ.jpg'),
(158652, 11234, 'Diarios de um Vampiro [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445375.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/81Lpn6x2CFNCVyUlBqXkaaEUjpu.jpg'),
(158653, 11234, 'Diarios de um Vampiro [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/445376.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vKxgBLya9Pes3smWsPRbh7axd1j.jpg'),
(158654, 11234, 'Diarios de um Vampiro [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/445377.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6HARNLUhuehHXtpCoFYTD6JqOaD.jpg'),
(158655, 11234, 'Diarios de um Vampiro [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/445378.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u4sOFJxGRh9WaBLujsgddOV6L25.jpg'),
(158656, 11234, 'Diarios de um Vampiro [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/445379.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j3UJNmQqZ1NHKMl84VgjEkLpSlf.jpg'),
(158657, 11234, 'Diarios de um Vampiro [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/445380.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nznifbpydqoJWhtSBB3JocviNdY.jpg'),
(158658, 11234, 'Diarios de um Vampiro [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/445381.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tOD4L01yDMepCfIo3bPqYDIIEN0.jpg'),
(158659, 11234, 'Diarios de um Vampiro [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/445382.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/53AWyK46dW3IqzbcxpMdMLKRyLw.jpg'),
(158660, 11234, 'Diarios de um Vampiro [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/445383.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yJp8noPFKcwwoCgVsqVCEnZTQl.jpg'),
(158661, 11234, 'Diarios de um Vampiro [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/445384.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y8EtLYGYng8RIW3yS3YqRoPFRyr.jpg'),
(158662, 11234, 'Diarios de um Vampiro [L] S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/445385.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z0x7ThVMaoadMags0pTXzu29dOu.jpg'),
(158663, 11234, 'Diarios de um Vampiro [L] S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/445386.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w8VKZ8EkM4OeLV7pZHQGJhPbLYm.jpg'),
(158664, 11234, 'Diarios de um Vampiro [L] S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/445387.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1g67PMIHQ1pt2kuFeDdOhocuH73.jpg'),
(158665, 11234, 'Diarios de um Vampiro [L] S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/445388.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sagHatrFTJIpTO9UNBP6BIy3Nyw.jpg'),
(158666, 11234, 'Diarios de um Vampiro [L] S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/445389.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/blI2xjuPKqgVHTd78ZPFr2n2eiY.jpg'),
(158667, 11234, 'Diarios de um Vampiro [L] S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/445390.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gPX1nGAPQcWa7kEnbRUoY0Ib1yK.jpg'),
(158668, 11235, 'Diarios de um Vampiro [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445391.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u9NvoMcRubojFSqCNH7aAdmfr0l.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(158669, 11235, 'Diarios de um Vampiro [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445392.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hueePtNS8PHjExz57VOYA3NeB2r.jpg'),
(158670, 11235, 'Diarios de um Vampiro [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445393.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tlkvmSsjY34rknEvicDSc3oMZKw.jpg'),
(158671, 11235, 'Diarios de um Vampiro [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445394.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3cfz2hBw5h3Emjqw4K2O2eEl0Hs.jpg'),
(158672, 11235, 'Diarios de um Vampiro [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445395.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bXbgalz0W1cYgqwSvO7pVX2SKl6.jpg'),
(158673, 11235, 'Diarios de um Vampiro [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445396.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4s0YMkd9tFrUiDN81z2qWowHfgG.jpg'),
(158674, 11235, 'Diarios de um Vampiro [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445397.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/920LRNJtNtdC9C5ou2NfBYzJVfp.jpg'),
(158675, 11235, 'Diarios de um Vampiro [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445398.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x0qZrlGrl8UZ7pQDmNex6u4WP8k.jpg'),
(158676, 11235, 'Diarios de um Vampiro [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/445399.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iMeoiC8yGEitUcmcy7G1ipUYa2O.jpg'),
(158677, 11235, 'Diarios de um Vampiro [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/445400.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pwhIg1s9uieTSzBGZuT1N7gbphG.jpg'),
(158678, 11235, 'Diarios de um Vampiro [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/445401.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qU5gNsW0UTmbuZGxgi9DjyhZ9DC.jpg'),
(158679, 11235, 'Diarios de um Vampiro [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/445402.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yuSDk7w3r1iQmYZAP3SwwDHiCSX.jpg'),
(158680, 11235, 'Diarios de um Vampiro [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/445403.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2D5WPHyQKrbvf1LpBoHujVszakU.jpg'),
(158681, 11235, 'Diarios de um Vampiro [L] S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/445404.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o0Yb8oNMmemW7GEoy9iVph1udO.jpg'),
(158682, 11235, 'Diarios de um Vampiro [L] S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/445405.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AqD2C7E3hLZvltZminucfLusvp4.jpg'),
(158683, 11235, 'Diarios de um Vampiro [L] S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/445406.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i3HTKxQB87Q6NzYC5o5oZdrFtlV.jpg'),
(158684, 11235, 'Diarios de um Vampiro [L] S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/445407.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tI1Q397ShAypOauekXzhX1ifc90.jpg'),
(158685, 11235, 'Diarios de um Vampiro [L] S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/445408.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v1yGRrjYvjSScjlijuooTO8yHK6.jpg'),
(158686, 11235, 'Diarios de um Vampiro [L] S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/445409.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wAqQ28Lph0moF7wbzifDYUsECMV.jpg'),
(158687, 11235, 'Diarios de um Vampiro [L] S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/445410.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iSdXEANr45Uy1V1jsu3Sq9RKGcr.jpg'),
(158688, 11235, 'Diarios de um Vampiro [L] S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/445411.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yiqKaXOxeZ2r0Fdl8FauhFALM2y.jpg'),
(158689, 11235, 'Diarios de um Vampiro [L] S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/445412.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3ZZZID53t1NnyOmxzlEGYPD13PL.jpg'),
(158690, 11236, 'Diarios de um Vampiro [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445413.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/scFp7IqKCAisFSVsknU2KNX0y84.jpg'),
(158691, 11236, 'Diarios de um Vampiro [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445414.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lUz3MfHQ6tcPPwa6bTO6Zn9TgjK.jpg'),
(158692, 11236, 'Diarios de um Vampiro [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445415.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sBluHD9qYQP0yyCjORLEiKIYTKC.jpg'),
(158693, 11236, 'Diarios de um Vampiro [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445416.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d72vLEdFWKqQ7FynGV4s0Uo3D4f.jpg'),
(158694, 11236, 'Diarios de um Vampiro [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445417.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rwDGSSEdwLtQkVpV79oAojGga7v.jpg'),
(158695, 11236, 'Diarios de um Vampiro [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445418.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hFoQWfUzOBU9K2hfwO345BqQ2ac.jpg'),
(158696, 11236, 'Diarios de um Vampiro [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445419.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/QfwW0E2YcYVlCN748DpSJAKq11.jpg'),
(158697, 11236, 'Diarios de um Vampiro [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445420.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3SLmwHxIdBSp12glf4vx1ePTNmQ.jpg'),
(158698, 11236, 'Diarios de um Vampiro [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/445421.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mfYxCzoHxqck8o68CNwvcAxeKT9.jpg'),
(158699, 11236, 'Diarios de um Vampiro [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/445422.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8rhuXYOp0r006iBmiee4KYUU1Ur.jpg'),
(158700, 11236, 'Diarios de um Vampiro [L] S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/445423.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tJ86ax1lwKO40fSEGrpnN56UZ01.jpg'),
(158701, 11236, 'Diarios de um Vampiro [L] S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/445424.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nHkBrgSGELgRfLVcyK6Z19jsuO2.jpg'),
(158702, 11236, 'Diarios de um Vampiro [L] S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/445425.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wLlC3p2KIdWTxlxA8Upsae2redi.jpg'),
(158703, 11236, 'Diarios de um Vampiro [L] S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/445426.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pnhvv7kXECvN6JSPcvvjuAnDSIH.jpg'),
(158704, 11236, 'Diarios de um Vampiro [L] S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/445427.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wb1KtGFUJUPQP5GsSKCSKmNq8ho.jpg'),
(158705, 11236, 'Diarios de um Vampiro [L] S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/445428.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rufAOUx6Yp0FKMVxkAW7SsDoPv8.jpg'),
(158706, 11236, 'Diarios de um Vampiro [L] S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/445429.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5GbtNX27ivEEhT70DQ311r49Dmh.jpg'),
(158707, 11236, 'Diarios de um Vampiro [L] S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/445430.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oHzZ3DayXKcXAftH2viw2NUFOwi.jpg'),
(158708, 11236, 'Diarios de um Vampiro [L] S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/445431.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dHxXjYU84nqaJwUjcMkC33KWkmN.jpg'),
(158709, 11236, 'Diarios de um Vampiro [L] S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/445432.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c5x1cO7jwMiKlx3O71yetrs2L5K.jpg'),
(158710, 11236, 'Diarios de um Vampiro [L] S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/445433.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nhycrhNSd6zqNNwwOOTd5iCNNU5.jpg'),
(158711, 11236, 'Diarios de um Vampiro [L] S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/445434.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tMLo4oFvXfMLXzX3OJPBEkRlW60.jpg'),
(158712, 11237, 'Diarios de um Vampiro [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445435.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mPH5o0CXDUiMFMQLcJHI33BnyIS.jpg'),
(158713, 11237, 'Diarios de um Vampiro [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445436.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e1Me8sElp2vs6zNi9mKGggv0bzL.jpg'),
(158714, 11237, 'Diarios de um Vampiro [L] S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445437.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vFoNjRCgXtbWmlk22kzbx6FNodK.jpg'),
(158715, 11237, 'Diarios de um Vampiro [L] S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445438.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hxb9qu7GPLpABhLbGkXSxcLXxUu.jpg'),
(158716, 11237, 'Diarios de um Vampiro [L] S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445439.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nk9gRCLOrm2OZ9M3tWVsT3R2ZS6.jpg'),
(158717, 11237, 'Diarios de um Vampiro [L] S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445440.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qmOYQBt6M3lDZOs31M0ioyNmc00.jpg'),
(158718, 11237, 'Diarios de um Vampiro [L] S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445441.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AhXud6g2xQRdiL5Oz8MW9MuIRjN.jpg'),
(158719, 11237, 'Diarios de um Vampiro [L] S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445442.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gfWUr0Bi6vP5XDejiyiznwYU2N1.jpg'),
(158720, 11237, 'Diarios de um Vampiro [L] S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/445443.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hIaCLyD4Cc0useawqHQXYAEqSVf.jpg'),
(158721, 11237, 'Diarios de um Vampiro [L] S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/445444.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3iex8eSwjt44K7l6CuE468wvFiJ.jpg'),
(158722, 11237, 'Diarios de um Vampiro [L] S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/445445.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oOTcJij6IVCeTCDCvZRGpmdtp1v.jpg'),
(158723, 11237, 'Diarios de um Vampiro [L] S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/445446.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pWkFcdgyS2ESTgVfldKvSPOPlk2.jpg'),
(158724, 11237, 'Diarios de um Vampiro [L] S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/445447.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w4jKYeWAy1IAGc8BlVzj0NVtqDd.jpg'),
(158725, 11237, 'Diarios de um Vampiro [L] S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/445448.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pzqpXSzrrhHRZf0JBO5JBOGwkQa.jpg'),
(158726, 11237, 'Diarios de um Vampiro [L] S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/445449.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e5QR80E4fp1MwXhfmypopnIHcyS.jpg'),
(158727, 11237, 'Diarios de um Vampiro [L] S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/445450.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o6Yf8YqfOJdZQigXNZdiVSq7qF2.jpg'),
(158728, 11237, 'Diarios de um Vampiro [L] S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/445451.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tLC3pZr2niKgvWrIdkzgakr6pst.jpg'),
(158729, 11237, 'Diarios de um Vampiro [L] S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/445452.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n1xRHTwTfq4CzxeUczctWibYVxy.jpg'),
(158730, 11237, 'Diarios de um Vampiro [L] S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/445453.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kx5cfvattitaZjMiQ5L1LLpW4nM.jpg'),
(158731, 11237, 'Diarios de um Vampiro [L] S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/445454.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ddCxUlxgSTjTAf1WIUNpMLvXC6W.jpg'),
(158732, 11237, 'Diarios de um Vampiro [L] S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/445455.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pr03NGpdJqhKXgkJvCFU6eRfje1.jpg'),
(158733, 11237, 'Diarios de um Vampiro [L] S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/445456.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hrL2fJfXKM6cYnGH0diOig4xGQc.jpg'),
(158734, 11238, 'Diarios de um Vampiro [L] S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445457.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/epatMhJ0r0ktm2CxnsHTUutsneo.jpg'),
(158735, 11238, 'Diarios de um Vampiro [L] S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445458.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5PTMFQ2AbbCY6AshSoSht7ZpWpy.jpg'),
(158736, 11238, 'Diarios de um Vampiro [L] S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445459.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pxBILNOt3fLq1vMQ4I6oPLitROe.jpg'),
(158737, 11238, 'Diarios de um Vampiro [L] S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445460.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9brcEYRHEjilpaV70SsoJEsdfBX.jpg'),
(158738, 11238, 'Diarios de um Vampiro [L] S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445461.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ls2HYDf6oJfX0NjdzG5p3gmwGUr.jpg'),
(158739, 11238, 'Diarios de um Vampiro [L] S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445462.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qKWK5Lj8bILYjTqrRTEF6DLu5Zu.jpg'),
(158740, 11238, 'Diarios de um Vampiro [L] S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445463.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lHroY6Lr1s8nSnBqg9iEPPIwWe9.jpg'),
(158741, 11238, 'Diarios de um Vampiro [L] S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445464.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nNdRhAW3Ksu3p5KTKiBXBNLyK41.jpg'),
(158742, 11238, 'Diarios de um Vampiro [L] S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/445465.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lgggxnRa0uQ0FZ2aOCRYKSl1T71.jpg'),
(158743, 11238, 'Diarios de um Vampiro [L] S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/445466.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/odRImZYmcINrJFJPTBOG8X0o8T0.jpg'),
(158744, 11238, 'Diarios de um Vampiro [L] S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/445467.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1R7JQvh54URuDmjakk0wu68JHHP.jpg'),
(158745, 11238, 'Diarios de um Vampiro [L] S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/445468.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oAgC2OYktMHfgA8dDdNxR42dAsb.jpg'),
(158746, 11238, 'Diarios de um Vampiro [L] S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/445469.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1wvcHTTgagTB8v1g8UaKnyEYZzo.jpg'),
(158747, 11238, 'Diarios de um Vampiro [L] S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/445470.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ksAzE7dwcBMLf7R7lTTCbOgX879.jpg'),
(158748, 11238, 'Diarios de um Vampiro [L] S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/445471.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AkDMnPhvq14mpG7zVseRJVA7poX.jpg'),
(158749, 11238, 'Diarios de um Vampiro [L] S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/445472.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xtM5p58DvX8Q4vxM14ifpEt8ARO.jpg'),
(158750, 11239, 'The Ossan Newbie Adventurer Trained to Death by the Most Powerful Party Became Invincible [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445297.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yIF9hIOyUr1aOixKqtqHNAzrenN.jpg'),
(158751, 11239, 'The Ossan Newbie Adventurer Trained to Death by the Most Powerful Party Became Invincible [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445298.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q91oofZRdbrduGbuNWQNqkd0MDp.jpg'),
(158752, 11239, 'The Ossan Newbie Adventurer Trained to Death by the Most Powerful Party Became Invincible [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445299.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xFrEQUwaX5Tz0an6DWV5Ofnan7F.jpg'),
(158753, 11239, 'The Ossan Newbie Adventurer Trained to Death by the Most Powerful Party Became Invincible [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445300.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fw3bq70Cp3qoEYX5GJTekIx7boF.jpg'),
(158754, 11239, 'The Ossan Newbie Adventurer Trained to Death by the Most Powerful Party Became Invincible [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445301.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aVWQDxGzYuVmQvK69ZzCqGtRk0r.jpg'),
(158755, 11239, 'The Ossan Newbie Adventurer Trained to Death by the Most Powerful Party Became Invincible [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449370.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5UxLCqE5YPYJowpiZVr92139LWM.jpg'),
(158756, 11239, 'The Ossan Newbie Adventurer Trained to Death by the Most Powerful Party Became Invincible [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449371.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5yNAIB2gEQLdcDoUnc3PRX5vyLB.jpg'),
(158757, 11239, 'The Ossan Newbie Adventurer Trained to Death by the Most Powerful Party Became Invincible [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449372.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oCHYNjUi1E17yUFQDoNcWpXr5xV.jpg'),
(158758, 11239, 'The Ossan Newbie Adventurer Trained to Death by the Most Powerful Party Became Invincible [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449373.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zIZ4LjEmkHro74bIeyI6VNzlOFm.jpg'),
(158759, 11239, 'The Ossan Newbie Adventurer Trained to Death by the Most Powerful Party Became Invincible [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/892014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s8xzLIzqnW5IufJJAku1CcNCICR.jpg'),
(158760, 11239, 'The Ossan Newbie Adventurer Trained to Death by the Most Powerful Party Became Invincible [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/892015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vJIobcNPaUmfv1lp4G3Mw1T5qsI.jpg'),
(158761, 11239, 'The Ossan Newbie Adventurer Trained to Death by the Most Powerful Party Became Invincible [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/892016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d7eklTNStRK0I1k7Lq9xzw9dX8c.jpg'),
(158762, 11240, 'Ate Onde Ela Vai S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMblYiFvf0Jk1nu8aAckAZaQMOB.jpg'),
(158763, 11240, 'Ate Onde Ela Vai S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMblYiFvf0Jk1nu8aAckAZaQMOB.jpg'),
(158764, 11240, 'Ate Onde Ela Vai S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMblYiFvf0Jk1nu8aAckAZaQMOB.jpg'),
(158765, 11240, 'Ate Onde Ela Vai S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMblYiFvf0Jk1nu8aAckAZaQMOB.jpg'),
(158766, 11240, 'Ate Onde Ela Vai S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMblYiFvf0Jk1nu8aAckAZaQMOB.jpg'),
(158767, 11240, 'Ate Onde Ela Vai S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMblYiFvf0Jk1nu8aAckAZaQMOB.jpg'),
(158768, 11240, 'Ate Onde Ela Vai S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMblYiFvf0Jk1nu8aAckAZaQMOB.jpg'),
(158769, 11240, 'Ate Onde Ela Vai S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMblYiFvf0Jk1nu8aAckAZaQMOB.jpg'),
(158770, 11240, 'Ate Onde Ela Vai S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/445848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMblYiFvf0Jk1nu8aAckAZaQMOB.jpg'),
(158771, 11240, 'Ate Onde Ela Vai S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/445849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMblYiFvf0Jk1nu8aAckAZaQMOB.jpg'),
(158772, 11241, 'Herois Eternos Homens dos Quais o Mundo Nao Era Digno S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/omz4OhaY1xPzaJqTeSeIru1Gr4Q.jpg'),
(158773, 11241, 'Herois Eternos Homens dos Quais o Mundo Nao Era Digno S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/omz4OhaY1xPzaJqTeSeIru1Gr4Q.jpg'),
(158774, 11241, 'Herois Eternos Homens dos Quais o Mundo Nao Era Digno S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/omz4OhaY1xPzaJqTeSeIru1Gr4Q.jpg'),
(158775, 11241, 'Herois Eternos Homens dos Quais o Mundo Nao Era Digno S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/omz4OhaY1xPzaJqTeSeIru1Gr4Q.jpg'),
(158776, 11241, 'Herois Eternos Homens dos Quais o Mundo Nao Era Digno S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/omz4OhaY1xPzaJqTeSeIru1Gr4Q.jpg'),
(158777, 11241, 'Herois Eternos Homens dos Quais o Mundo Nao Era Digno S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/omz4OhaY1xPzaJqTeSeIru1Gr4Q.jpg'),
(158778, 11241, 'Herois Eternos Homens dos Quais o Mundo Nao Era Digno S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/omz4OhaY1xPzaJqTeSeIru1Gr4Q.jpg'),
(158779, 11241, 'Herois Eternos Homens dos Quais o Mundo Nao Era Digno S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/445826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/omz4OhaY1xPzaJqTeSeIru1Gr4Q.jpg'),
(158780, 11241, 'Herois Eternos Homens dos Quais o Mundo Nao Era Digno S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/445827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/omz4OhaY1xPzaJqTeSeIru1Gr4Q.jpg'),
(158781, 11241, 'Herois Eternos Homens dos Quais o Mundo Nao Era Digno S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/445828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/omz4OhaY1xPzaJqTeSeIru1Gr4Q.jpg'),
(158782, 11241, 'Herois Eternos Homens dos Quais o Mundo Nao Era Digno S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/445829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/omz4OhaY1xPzaJqTeSeIru1Gr4Q.jpg'),
(158783, 11241, 'Herois Eternos Homens dos Quais o Mundo Nao Era Digno S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/445830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/omz4OhaY1xPzaJqTeSeIru1Gr4Q.jpg'),
(158784, 11241, 'Herois Eternos Homens dos Quais o Mundo Nao Era Digno S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/445831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/omz4OhaY1xPzaJqTeSeIru1Gr4Q.jpg'),
(158785, 11241, 'Herois Eternos Homens dos Quais o Mundo Nao Era Digno S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/445832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/omz4OhaY1xPzaJqTeSeIru1Gr4Q.jpg'),
(158786, 11241, 'Herois Eternos Homens dos Quais o Mundo Nao Era Digno S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/445833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/omz4OhaY1xPzaJqTeSeIru1Gr4Q.jpg'),
(158787, 11241, 'Herois Eternos Homens dos Quais o Mundo Nao Era Digno S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/445834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/omz4OhaY1xPzaJqTeSeIru1Gr4Q.jpg'),
(158788, 11241, 'Herois Eternos Homens dos Quais o Mundo Nao Era Digno S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/445835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/omz4OhaY1xPzaJqTeSeIru1Gr4Q.jpg'),
(158789, 11241, 'Herois Eternos Homens dos Quais o Mundo Nao Era Digno S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/445836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/omz4OhaY1xPzaJqTeSeIru1Gr4Q.jpg'),
(158790, 11241, 'Herois Eternos Homens dos Quais o Mundo Nao Era Digno S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/445837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/omz4OhaY1xPzaJqTeSeIru1Gr4Q.jpg'),
(158791, 11241, 'Herois Eternos Homens dos Quais o Mundo Nao Era Digno S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/445838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/omz4OhaY1xPzaJqTeSeIru1Gr4Q.jpg'),
(158792, 11241, 'Herois Eternos Homens dos Quais o Mundo Nao Era Digno S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/445839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/omz4OhaY1xPzaJqTeSeIru1Gr4Q.jpg'),
(158793, 11242, 'Margarita S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445814.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9Axn6NuR7PQpkqVMxB6yhhM8Zsv.jpg'),
(158794, 11242, 'Margarita S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445815.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wvcvyhcV8dulTPX05VGKSjreGKh.jpg'),
(158795, 11242, 'Margarita S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445816.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gvrCRSbehfrc81xEDnpOIoRe2Dr.jpg'),
(158796, 11242, 'Margarita S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445817.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2Vic3rlWUbQh011WEUd6149yYRV.jpg'),
(158797, 11242, 'Margarita S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445818.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zqcTrJaF7q8YkIfGwEsjP9ma1qr.jpg'),
(158798, 11242, 'Margarita S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/496646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158799, 11242, 'Margarita S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/496647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158800, 11242, 'Margarita S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/496648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158801, 11242, 'Margarita S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/496649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158802, 11242, 'Margarita S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/496650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158803, 11242, 'Margarita S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/496651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158804, 11242, 'Margarita S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/496652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158805, 11242, 'Margarita S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/496653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158806, 11242, 'Margarita S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/496654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158807, 11242, 'Margarita S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/496655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158808, 11242, 'Margarita S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/496656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158809, 11242, 'Margarita S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/496657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158810, 11242, 'Margarita S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/496658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158811, 11242, 'Margarita S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/496659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158812, 11242, 'Margarita S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/496660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158813, 11242, 'Margarita S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/496661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158814, 11242, 'Margarita S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/496662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158815, 11242, 'Margarita S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/496663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158816, 11242, 'Margarita S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/496664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158817, 11242, 'Margarita S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/496665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158818, 11242, 'Margarita S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/496666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158819, 11242, 'Margarita S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/496667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158820, 11242, 'Margarita S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/496668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158821, 11242, 'Margarita S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/496669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158822, 11242, 'Margarita S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/496670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158823, 11242, 'Margarita S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/496671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158824, 11242, 'Margarita S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/496672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158825, 11242, 'Margarita S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/496673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158826, 11242, 'Margarita S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/496674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158827, 11242, 'Margarita S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/496675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158828, 11242, 'Margarita S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/496676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158829, 11242, 'Margarita S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/496677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158830, 11242, 'Margarita S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/496678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158831, 11242, 'Margarita S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/496679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158832, 11242, 'Margarita S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/496680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4wnkSL5NEHIRuEJ5A13R580WmXh.jpg'),
(158833, 11243, 'Mary e George S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445807.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4EcbxAhHKBAIBHTFwzPcODzfsdl.jpg'),
(158834, 11243, 'Mary e George S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445808.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zguMAvAqPcEDjEK8fjUlXXNMvZA.jpg'),
(158835, 11243, 'Mary e George S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445809.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sHmQGsYxpi34hVTCjTGKrQ6Bq9G.jpg'),
(158836, 11243, 'Mary e George S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445810.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mwwC3xZwfKirXMskQFb9FwumIHC.jpg'),
(158837, 11243, 'Mary e George S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445811.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qRcOY28Eh0lYytiFg0flSTgAPc0.jpg'),
(158838, 11243, 'Mary e George S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445812.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sz6qPwHDzRwP1tClRwAxZAg8KNK.jpg'),
(158839, 11243, 'Mary e George S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/445813.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9xAWEySeRh35gaQQglXeUA0aTbr.jpg'),
(158840, 11244, 'O Casal Perfeito S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445801.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nxFWYtGhk8rERddq0TWihtHjsuG.jpg'),
(158841, 11244, 'O Casal Perfeito S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445802.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2wzelcbQ6hDPrkn9OgsYDIoAp6d.jpg'),
(158842, 11244, 'O Casal Perfeito S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445803.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jfQgl6OFEDWtOnoPNUgEtAJWb80.jpg'),
(158843, 11244, 'O Casal Perfeito S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445804.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dtkcyk1TU4q1OcaKNF9LxKnoMOh.jpg'),
(158844, 11244, 'O Casal Perfeito S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/445805.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iUrLRbaQ8YGcym0JGiqAKCXLmOo.jpg'),
(158845, 11244, 'O Casal Perfeito S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/445806.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aFHJyNQUoYCNsGqyaZLnWU8BjvE.jpg'),
(158846, 11245, 'O Mal na sua Essencia A Historia de Hadden Clark S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/445797.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1dsMKBgNCdPr4ZH1ZcUHt9WIqkW.jpg'),
(158847, 11245, 'O Mal na sua Essencia A Historia de Hadden Clark S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/445798.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bWLnm74v0sNydXxID01CPdPdS5L.jpg'),
(158848, 11245, 'O Mal na sua Essencia A Historia de Hadden Clark S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/445799.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tHUxfUBpUN59LVCpz916pKjKfC5.jpg'),
(158849, 11245, 'O Mal na sua Essencia A Historia de Hadden Clark S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/445800.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2DCTbYt1rlbdY6bFDPzT3n7dhfP.jpg'),
(158850, 11245, 'O Mal na sua Essencia A Historia de Hadden Clark S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/447091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iYzkAGHHtyOmcay07swpGW9peMI.jpg'),
(158851, 11246, 'Hudson e Rex [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449390.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/21fH8bICYjdKqhYjWbXZ5fEUUEK.jpg'),
(158852, 11246, 'Hudson e Rex [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449391.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7MbnUnY6OG5IHIgaPvkk8S5UPCH.jpg'),
(158853, 11246, 'Hudson e Rex [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449392.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tXg8NbuJShSRYpylyH0xByAxPnJ.jpg'),
(158854, 11246, 'Hudson e Rex [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449393.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b0HUBnSA25C3UKoST67KVCvMvqE.jpg'),
(158855, 11246, 'Hudson e Rex [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449394.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uUrbWRyjQKRpbjTrHmIAg1oLun1.jpg'),
(158856, 11246, 'Hudson e Rex [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449395.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uOTvy4PVFNuj62OzQgRhHfaIXd3.jpg'),
(158857, 11246, 'Hudson e Rex [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449396.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xUsnHZqiDGjVk5C8mjEx22ebWDd.jpg'),
(158858, 11246, 'Hudson e Rex [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449397.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zNNqncvsJaztAkDYues6dauT7J.jpg'),
(158859, 11246, 'Hudson e Rex [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449398.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pk7g3VWogakMOGmVvdeERPo2U0n.jpg'),
(158860, 11246, 'Hudson e Rex [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/449399.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dqy3F4Yt8g4vIsTQxvBsEAYIEVi.jpg'),
(158861, 11246, 'Hudson e Rex [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/449400.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hr6fcIOx6q0YQ3tASlnv11Z4KTp.jpg'),
(158862, 11246, 'Hudson e Rex [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/449401.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jSlUJbWnW8PcrCFNoZkxkYnCQNb.jpg'),
(158863, 11246, 'Hudson e Rex [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/449402.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/shdM3nXht0NLqFjTNL1TPktEcLD.jpg'),
(158864, 11247, 'Hudson e Rex [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449403.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xWojQ4Y7EZ7N3avyg4jV1L5ArYP.jpg'),
(158865, 11247, 'Hudson e Rex [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449404.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2fBKpox1Ad1F9NU4FBIjBBFcIQ.jpg'),
(158866, 11247, 'Hudson e Rex [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449405.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uqOyqHCYMSCIKblHlDQElC6qWbB.jpg'),
(158867, 11247, 'Hudson e Rex [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449406.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k91VX7OxqoEf92obtREkalhpJ1W.jpg'),
(158868, 11247, 'Hudson e Rex [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449407.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ttWQVf2LjQD6m4NmTD5zjjSKFtr.jpg'),
(158869, 11247, 'Hudson e Rex [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449408.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8R7Dz4EePAN4szkap4Qyyrc3oAf.jpg'),
(158870, 11247, 'Hudson e Rex [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449409.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hGu4WuQRd8M3KbHepkD0FhgDP4V.jpg'),
(158871, 11247, 'Hudson e Rex [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449410.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n9t5NAxipKK0GOkJx76FXrSCEMG.jpg'),
(158872, 11247, 'Hudson e Rex [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449411.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/84ivAGBoiOXAWVyeIEq4hyZgdB9.jpg'),
(158873, 11247, 'Hudson e Rex [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/449412.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/llVBAiPBRzzAWttxFoM2rFcFaOF.jpg'),
(158874, 11247, 'Hudson e Rex [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/449413.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/12iavupH148TmCjkZcZgMuClDhd.jpg'),
(158875, 11247, 'Hudson e Rex [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/449414.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8TO9yPy3f01ftMrK0fprbUP1IV2.jpg'),
(158876, 11247, 'Hudson e Rex [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/449415.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gXOG6zd6m85JfUTvVqM3WmvJ9Xf.jpg'),
(158877, 11247, 'Hudson e Rex [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/449416.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yQH6IXc3ERtdYgkKO6CT3TYRoE7.jpg'),
(158878, 11247, 'Hudson e Rex [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/449417.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mIkVOu9YWPV1Mk8Ji9oCUKZoc49.jpg'),
(158879, 11247, 'Hudson e Rex [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/449418.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rP6zmElLzrrWhrLs2efMO8m42yC.jpg'),
(158880, 11247, 'Hudson e Rex [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/449419.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tfDoOeTsZsjuLW6RaYN5E2R7xO5.jpg'),
(158881, 11247, 'Hudson e Rex [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/449420.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eSD0vPpFFQ1uRaN4AJfC5nyPAyV.jpg'),
(158882, 11247, 'Hudson e Rex [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/449421.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bVHgK4z5IICSqnKqP97M1TNoIPU.jpg'),
(158883, 11248, 'She Would Never Know [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAbz1alcyUhiXFkQUmTPhLBTK0u.jpg'),
(158884, 11248, 'She Would Never Know [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAbz1alcyUhiXFkQUmTPhLBTK0u.jpg'),
(158885, 11248, 'She Would Never Know [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAbz1alcyUhiXFkQUmTPhLBTK0u.jpg'),
(158886, 11248, 'She Would Never Know [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAbz1alcyUhiXFkQUmTPhLBTK0u.jpg'),
(158887, 11248, 'She Would Never Know [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAbz1alcyUhiXFkQUmTPhLBTK0u.jpg'),
(158888, 11248, 'She Would Never Know [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAbz1alcyUhiXFkQUmTPhLBTK0u.jpg'),
(158889, 11248, 'She Would Never Know [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAbz1alcyUhiXFkQUmTPhLBTK0u.jpg'),
(158890, 11248, 'She Would Never Know [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAbz1alcyUhiXFkQUmTPhLBTK0u.jpg'),
(158891, 11248, 'She Would Never Know [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAbz1alcyUhiXFkQUmTPhLBTK0u.jpg'),
(158892, 11248, 'She Would Never Know [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/449383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAbz1alcyUhiXFkQUmTPhLBTK0u.jpg'),
(158893, 11248, 'She Would Never Know [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/449384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAbz1alcyUhiXFkQUmTPhLBTK0u.jpg'),
(158894, 11248, 'She Would Never Know [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/449385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAbz1alcyUhiXFkQUmTPhLBTK0u.jpg'),
(158895, 11248, 'She Would Never Know [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/449386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAbz1alcyUhiXFkQUmTPhLBTK0u.jpg'),
(158896, 11248, 'She Would Never Know [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/449387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAbz1alcyUhiXFkQUmTPhLBTK0u.jpg'),
(158897, 11248, 'She Would Never Know [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/449388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAbz1alcyUhiXFkQUmTPhLBTK0u.jpg'),
(158898, 11248, 'She Would Never Know [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/449389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aAbz1alcyUhiXFkQUmTPhLBTK0u.jpg'),
(158899, 11249, 'Cacadores de Fantasmas S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158900, 11249, 'Cacadores de Fantasmas S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158901, 11249, 'Cacadores de Fantasmas S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158902, 11249, 'Cacadores de Fantasmas S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158903, 11249, 'Cacadores de Fantasmas S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158904, 11249, 'Cacadores de Fantasmas S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158905, 11249, 'Cacadores de Fantasmas S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158906, 11249, 'Cacadores de Fantasmas S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158907, 11249, 'Cacadores de Fantasmas S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158908, 11249, 'Cacadores de Fantasmas S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/449306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158909, 11249, 'Cacadores de Fantasmas S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/449307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158910, 11249, 'Cacadores de Fantasmas S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/449308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158911, 11249, 'Cacadores de Fantasmas S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/449309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158912, 11250, 'Cacadores de Fantasmas S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158913, 11250, 'Cacadores de Fantasmas S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158914, 11250, 'Cacadores de Fantasmas S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158915, 11250, 'Cacadores de Fantasmas S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(158916, 11250, 'Cacadores de Fantasmas S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158917, 11250, 'Cacadores de Fantasmas S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158918, 11250, 'Cacadores de Fantasmas S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158919, 11250, 'Cacadores de Fantasmas S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158920, 11251, 'Cacadores de Fantasmas S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158921, 11251, 'Cacadores de Fantasmas S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158922, 11251, 'Cacadores de Fantasmas S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158923, 11251, 'Cacadores de Fantasmas S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158924, 11251, 'Cacadores de Fantasmas S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158925, 11251, 'Cacadores de Fantasmas S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158926, 11251, 'Cacadores de Fantasmas S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158927, 11251, 'Cacadores de Fantasmas S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4tl8Jg5LLEG9lidcfncysMQYBpY.jpg'),
(158928, 11252, 'Hercules A Lendaria Jornada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2vyxteXmZVh8zBSK9yA827Rs1sl.jpg'),
(158929, 11252, 'Hercules A Lendaria Jornada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449187.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i8vP1a149yOC0vKDXGdjyzvhydf.jpg'),
(158930, 11252, 'Hercules A Lendaria Jornada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449188.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oUhc35KjFswnco2aUtweU09Cmff.jpg'),
(158931, 11252, 'Hercules A Lendaria Jornada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449189.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sRuRT5W3LRcUNMjPEEiS4PFE7Hc.jpg'),
(158932, 11252, 'Hercules A Lendaria Jornada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449190.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nLPutPTinTsEvLC00z2mKLvCbic.jpg'),
(158933, 11252, 'Hercules A Lendaria Jornada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449191.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qG2xQSDVeEroc8idFJs9qpQcYSU.jpg'),
(158934, 11252, 'Hercules A Lendaria Jornada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449192.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wYAD99k2TExk4TC2wEA5CITLXcK.jpg'),
(158935, 11252, 'Hercules A Lendaria Jornada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449193.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bE6vf6hPoS6rtEk3YJZyV5vpzm.jpg'),
(158936, 11252, 'Hercules A Lendaria Jornada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449194.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tvBDVGEjjBwvWuIfL38xLyNshd7.jpg'),
(158937, 11252, 'Hercules A Lendaria Jornada S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/449195.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8WtQ0ceogyZAVkOw3o4PiRull2z.jpg'),
(158938, 11252, 'Hercules A Lendaria Jornada S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/449196.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zPtVjNhmrGTL7cZRWob4ZnMOgDD.jpg'),
(158939, 11252, 'Hercules A Lendaria Jornada S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/449197.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uMDqS0Pyvgjm3sgZjfMBtVOc0Id.jpg'),
(158940, 11252, 'Hercules A Lendaria Jornada S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/449198.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pwVlfvm7Z7d2NvXkv0Eo6ShsAwh.jpg'),
(158941, 11253, 'Hercules A Lendaria Jornada S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449199.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tkOlkXbCWzQVABTbuMo3hn6jg9M.jpg'),
(158942, 11253, 'Hercules A Lendaria Jornada S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449200.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3sNySfW0GAEafrOEk9sxNvoNxZu.jpg'),
(158943, 11253, 'Hercules A Lendaria Jornada S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449201.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dJ768qXZNirVa7ctfXMYUkBTREB.jpg'),
(158944, 11253, 'Hercules A Lendaria Jornada S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449202.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/puOI4dldJGWkkc2EjbaA6YDwlCU.jpg'),
(158945, 11253, 'Hercules A Lendaria Jornada S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449203.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cEg8jyUHjOZ20HlVrVeMF9bREtF.jpg'),
(158946, 11253, 'Hercules A Lendaria Jornada S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449204.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m30Nn2EQtd82jRlK8O0KLQDFc9z.jpg'),
(158947, 11253, 'Hercules A Lendaria Jornada S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449205.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A9eMD9oBxsvLV9YCqZW85rNEHY2.jpg'),
(158948, 11253, 'Hercules A Lendaria Jornada S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449206.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lB5Wn7P3mdAxpA6YK3iVptyDnv2.jpg'),
(158949, 11253, 'Hercules A Lendaria Jornada S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449207.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lTAczXoRYmRTgyEemyCB4bT7687.jpg'),
(158950, 11253, 'Hercules A Lendaria Jornada S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/449208.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dcnimQYyi4MzWcG7H7tQuorWXs7.jpg'),
(158951, 11253, 'Hercules A Lendaria Jornada S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/449209.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tfksgMpXoqZOnGNEpM9CExRvceu.jpg'),
(158952, 11253, 'Hercules A Lendaria Jornada S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/449210.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s9VSRu1uaNcFYTgeuBUoak7zlTS.jpg'),
(158953, 11253, 'Hercules A Lendaria Jornada S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/449211.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gyV9kwcye59xK4eOhIFGCFM832e.jpg'),
(158954, 11253, 'Hercules A Lendaria Jornada S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/449212.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o2CMVLuhLKfZu1nGaNG6LuoBKzg.jpg'),
(158955, 11253, 'Hercules A Lendaria Jornada S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/449213.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sMrc0AbEbp0JHG8bRMHntj9D2R7.jpg'),
(158956, 11253, 'Hercules A Lendaria Jornada S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/449214.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eDdkPKwj9LoxNE0ijESEAGli6SM.jpg'),
(158957, 11253, 'Hercules A Lendaria Jornada S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/449215.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pUVtSWYU4ZqHjfytxjeqPha83Us.jpg'),
(158958, 11253, 'Hercules A Lendaria Jornada S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/449216.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8B9Qep9KweFxOUviLnYt5hHbyo5.jpg'),
(158959, 11253, 'Hercules A Lendaria Jornada S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/449217.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dbM13L0s4yqZELcJrzROu5fqNYV.jpg'),
(158960, 11253, 'Hercules A Lendaria Jornada S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/449218.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9Oie0pDKa6z9b1OftZyq4tWLrhO.jpg'),
(158961, 11253, 'Hercules A Lendaria Jornada S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/449219.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t3OC3TQ4rAAL5WBhn8MRbck0sSe.jpg'),
(158962, 11253, 'Hercules A Lendaria Jornada S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/449220.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3UHtZLcV1DwH5IQa59YDYMNgaXm.jpg'),
(158963, 11253, 'Hercules A Lendaria Jornada S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/449221.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f5jfVmgHkrnfIAZltBNX2X6b84o.jpg'),
(158964, 11253, 'Hercules A Lendaria Jornada S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/449222.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l40WFTIO0QdwOjUKUWyvyHu8Ntc.jpg'),
(158965, 11254, 'Hercules A Lendaria Jornada S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449223.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nIU5jdSLcm4oEpxZwesPWXgKubS.jpg'),
(158966, 11254, 'Hercules A Lendaria Jornada S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449224.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jvkQioaDGXsZSVL4mBLihWLfjqh.jpg'),
(158967, 11254, 'Hercules A Lendaria Jornada S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449225.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ogNBMXGYBkQiD5xgfolxBukoOQ8.jpg'),
(158968, 11254, 'Hercules A Lendaria Jornada S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449226.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wQqWNTEfMNcXFOGhgMfCrp3FtS5.jpg'),
(158969, 11254, 'Hercules A Lendaria Jornada S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449227.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/90M2kbztO2lnOnOD1XNMHSjyMw9.jpg'),
(158970, 11254, 'Hercules A Lendaria Jornada S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449228.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fdAkzmx2UQe6P00WrH5gJXpswKp.jpg'),
(158971, 11254, 'Hercules A Lendaria Jornada S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449229.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nDYgDEUjyH3AHaymrPARfhaIfOe.jpg'),
(158972, 11254, 'Hercules A Lendaria Jornada S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449230.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2SXOOwV3DBzzDZzhMxKjrARmukI.jpg'),
(158973, 11254, 'Hercules A Lendaria Jornada S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449231.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lqjCsAvGgCBbCpr07LXXbMEIksF.jpg'),
(158974, 11254, 'Hercules A Lendaria Jornada S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/449232.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7Uhrxu6UjubHRL4A9DnUDHxm0z1.jpg'),
(158975, 11254, 'Hercules A Lendaria Jornada S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/449233.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/klXIiNMCJD7tRTUYjtPDzkqfy4c.jpg'),
(158976, 11254, 'Hercules A Lendaria Jornada S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/449234.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9w1AOLR3brFRDNTAjP6Q3DO189p.jpg'),
(158977, 11254, 'Hercules A Lendaria Jornada S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/449235.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pVpMM0tXDDBYVxB6Jm2eJ4r63E5.jpg'),
(158978, 11254, 'Hercules A Lendaria Jornada S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/449236.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8HCCovhkxIXnEfWLsfeiqkWwO6x.jpg'),
(158979, 11254, 'Hercules A Lendaria Jornada S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/449237.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lc3Axoh6BQDpKeqizWrMR2jghUX.jpg'),
(158980, 11254, 'Hercules A Lendaria Jornada S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/449238.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/36SBIqrxcF1PlOy6PnOsuakcMCT.jpg'),
(158981, 11254, 'Hercules A Lendaria Jornada S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/449239.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2q3RvxEv3AeXHpnM1mLm4LbAON6.jpg'),
(158982, 11254, 'Hercules A Lendaria Jornada S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/449240.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e4nCBlvIPdsTeSFDbJvxZlDc3ka.jpg'),
(158983, 11254, 'Hercules A Lendaria Jornada S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/449241.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v0AXNp9d6UMliJMSFCTEWiRyyXM.jpg'),
(158984, 11254, 'Hercules A Lendaria Jornada S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/449242.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9yxMm2lJw52ftsrHt1z0BPEjbU0.jpg'),
(158985, 11254, 'Hercules A Lendaria Jornada S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/449243.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dZaqyydNEB39418Huhzd9C46vZO.jpg'),
(158986, 11254, 'Hercules A Lendaria Jornada S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/449244.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/40p0akYemdEsoeQM6wOGj2Tdx6K.jpg'),
(158987, 11255, 'Hercules A Lendaria Jornada S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449245.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yFK8SlYtfh0fmHHVA7v6GstnbN2.jpg'),
(158988, 11255, 'Hercules A Lendaria Jornada S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449246.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fEZd1eBQoG6UTMtg6ITosR35mKX.jpg'),
(158989, 11255, 'Hercules A Lendaria Jornada S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449247.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/275IGlxJjNGiyq5KX2FQk216ijo.jpg'),
(158990, 11255, 'Hercules A Lendaria Jornada S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449248.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ebf9r5rdWf5lcEx74XUoayWXDMx.jpg'),
(158991, 11255, 'Hercules A Lendaria Jornada S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449249.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vFyfo8XDXgCxbWJKeAhGxPzXRYv.jpg'),
(158992, 11255, 'Hercules A Lendaria Jornada S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449250.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bUjCoxvaZ9yJ1LhHaR4vrBLT3Is.jpg'),
(158993, 11255, 'Hercules A Lendaria Jornada S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449251.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wglpX89sgTgfrS4bhESTn2Q7fdF.jpg'),
(158994, 11255, 'Hercules A Lendaria Jornada S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449252.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r2GqHP0uOf9GYPhk2PIRnfiIaQS.jpg'),
(158995, 11255, 'Hercules A Lendaria Jornada S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449253.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ok6wtNP6wSdFhcP0Bn2MdGYmX11.jpg'),
(158996, 11255, 'Hercules A Lendaria Jornada S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/449254.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2wGVKBs587G95VKkKACQzWcBBBc.jpg'),
(158997, 11255, 'Hercules A Lendaria Jornada S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/449255.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8uznsbepStC3f0eyINyKUUh9xXC.jpg'),
(158998, 11255, 'Hercules A Lendaria Jornada S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/449256.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rZ6N9utGsgziOgh1w0fL81X1qLG.jpg'),
(158999, 11255, 'Hercules A Lendaria Jornada S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/449257.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4b5nsXUoZJir4Q3uv5Qbtwl8c2P.jpg'),
(159000, 11255, 'Hercules A Lendaria Jornada S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/449258.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s7ZJc0r4xJWtuoyFJz8cPbVD2CS.jpg'),
(159001, 11255, 'Hercules A Lendaria Jornada S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/449259.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1HTWwg2JwC85jegRl0Vt0y0s8S9.jpg'),
(159002, 11255, 'Hercules A Lendaria Jornada S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/449260.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iRUcjDwv5P5erqUjY8EB5UGpzPn.jpg'),
(159003, 11255, 'Hercules A Lendaria Jornada S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/449261.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fuRw7yIVpq6GkppKWrN8NLA3Ml5.jpg'),
(159004, 11255, 'Hercules A Lendaria Jornada S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/449262.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o7DM4hMBXMoqp3HNmjD0r0BsNC8.jpg'),
(159005, 11255, 'Hercules A Lendaria Jornada S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/449263.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hudAUfwhUVxIgR280Mp8ubHIWg2.jpg'),
(159006, 11255, 'Hercules A Lendaria Jornada S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/449264.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gDfV0XYnvIQPb5Md4dUkiiS2dam.jpg'),
(159007, 11255, 'Hercules A Lendaria Jornada S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/449265.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pZSl9LndxzfpVGQoCUUcKgj9vQQ.jpg'),
(159008, 11255, 'Hercules A Lendaria Jornada S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/449266.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sBlQvrBqO7BSYfQIjBVkCwNcWV.jpg'),
(159009, 11256, 'Hercules A Lendaria Jornada S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449267.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vqS3Dfrq3A9fl2TkR5o1oUbUjpV.jpg'),
(159010, 11256, 'Hercules A Lendaria Jornada S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449268.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j6gSCGknvubVHXPNH3iowpyl7dY.jpg'),
(159011, 11256, 'Hercules A Lendaria Jornada S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449269.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iHNeFiY4Sb81ZDK662osiag8RGF.jpg'),
(159012, 11256, 'Hercules A Lendaria Jornada S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449270.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a2iANZDj3izLFCPA7Yf2EU9XH1f.jpg'),
(159013, 11256, 'Hercules A Lendaria Jornada S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449271.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/45H4ssRUbuikOFi2SwDT3xokI1n.jpg'),
(159014, 11256, 'Hercules A Lendaria Jornada S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449272.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8U7dmeAiRWTn0JuplyRbNhNV4ww.jpg'),
(159015, 11256, 'Hercules A Lendaria Jornada S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449273.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eF0OwP6eM1oxjFg07kE6qwPdZLs.jpg'),
(159016, 11256, 'Hercules A Lendaria Jornada S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449274.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bsONNFJhSvcAr9mgE5YdWNyBPku.jpg'),
(159017, 11256, 'Hercules A Lendaria Jornada S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449275.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8QHGLyqOMZnWsqgFXjyw3BA6Qo1.jpg'),
(159018, 11256, 'Hercules A Lendaria Jornada S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/449276.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gxEMtTUn1TPFx2PgRzFOjrN3tHA.jpg'),
(159019, 11256, 'Hercules A Lendaria Jornada S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/449277.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2183Gv1Uq5UeBipnbA2RwkxcZbQ.jpg'),
(159020, 11256, 'Hercules A Lendaria Jornada S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/449278.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nVzIF30H2vVhIlOgjDs18m6mlDs.jpg'),
(159021, 11256, 'Hercules A Lendaria Jornada S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/449279.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/60WHOPPwDxiQrbMGcEY9wP5fJWW.jpg'),
(159022, 11256, 'Hercules A Lendaria Jornada S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/449280.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iOFYzEQ6JeInEEfQ5mRIdwqZDyy.jpg'),
(159023, 11256, 'Hercules A Lendaria Jornada S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/449281.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rz8sv9Ybi4Sjrm3sTCmgwjZbpzy.jpg'),
(159024, 11256, 'Hercules A Lendaria Jornada S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/449282.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1N3uv9shZApGCo25aC7PzRHIqVB.jpg'),
(159025, 11256, 'Hercules A Lendaria Jornada S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/449283.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1bTT1qS3DC0CFuvm20YWTEJwNj5.jpg'),
(159026, 11256, 'Hercules A Lendaria Jornada S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/449284.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/osZYNvNRPER6IHXKTmo8Gfcfu9d.jpg'),
(159027, 11256, 'Hercules A Lendaria Jornada S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/449285.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9slP5M0VafLycQdCRNd1acZXOd8.jpg'),
(159028, 11256, 'Hercules A Lendaria Jornada S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/449286.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/18poFmNIWY4wNpKnE4DFvP6LMP1.jpg'),
(159029, 11256, 'Hercules A Lendaria Jornada S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/449287.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dCxmv3gHk8TU45dnsA8fJMs7u0W.jpg'),
(159030, 11256, 'Hercules A Lendaria Jornada S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/449288.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ywdxP7xHVioQHY2IjkA8FVPCi1m.jpg'),
(159031, 11257, 'Hercules A Lendaria Jornada S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449289.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uQbwaEPd00LeJaFjiCv5vQYZtAv.jpg'),
(159032, 11257, 'Hercules A Lendaria Jornada S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449290.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c3N3yIuyx6c6rS6u1caBm2Rap62.jpg'),
(159033, 11257, 'Hercules A Lendaria Jornada S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449291.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9kD7StnIhyhbFoOx5P6eI0RS1Ub.jpg'),
(159034, 11257, 'Hercules A Lendaria Jornada S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449292.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hpBGw1aY3lT4nR2gsoOdXqIJ9CK.jpg'),
(159035, 11257, 'Hercules A Lendaria Jornada S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449293.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nhAk5WQiuL5ZsVriFGkupihmbfg.jpg'),
(159036, 11257, 'Hercules A Lendaria Jornada S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449294.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2btPkR2XqYMZbxL0UmpcjQw4Ugh.jpg'),
(159037, 11257, 'Hercules A Lendaria Jornada S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449295.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dDnFafwdJqJTCt5mPuyhfuKPdTX.jpg'),
(159038, 11257, 'Hercules A Lendaria Jornada S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449296.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3l7LMunVPmuzQqbM1g6VZgLIzdM.jpg'),
(159039, 11258, 'LEGO Pixar BrickToons S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449181.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fgjq2gTulKgkbKeoMHnirFw5mtk.jpg'),
(159040, 11258, 'LEGO Pixar BrickToons S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449182.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rkYB6LigcaLaRMA98RSsrUPuQvo.jpg'),
(159041, 11258, 'LEGO Pixar BrickToons S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449183.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A5dMSoUfWhS99iQn6C5BcUVXhm.jpg'),
(159042, 11258, 'LEGO Pixar BrickToons S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449184.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6EEFMysQS22aFxhrtU4BJhrtnj9.jpg'),
(159043, 11258, 'LEGO Pixar BrickToons S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449185.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dJHX1LKpD66453nq26ZIzKISIcn.jpg'),
(159044, 11259, 'Megamente Domina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449173.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ArLFvzk1LAyN8wWkEfR6t95cP7F.jpg'),
(159045, 11259, 'Megamente Domina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449174.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/602g0nAaAlfjMMNQXY1yLJlzyDk.jpg'),
(159046, 11259, 'Megamente Domina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449175.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wgYifGOBzKG2Jl0lC4thMqE3y3y.jpg'),
(159047, 11259, 'Megamente Domina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449176.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sEqDDXyitWDutRiY11TkynfaAWT.jpg'),
(159048, 11259, 'Megamente Domina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449177.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bXrERubjbUXED4jFsIRsgsix3xl.jpg'),
(159049, 11259, 'Megamente Domina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449178.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uZ7J16u8tHFiqDXqJEFSmm9u9RD.jpg'),
(159050, 11259, 'Megamente Domina S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449179.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x6t0xsZYH5lZfwlj0NfjYsvKLox.jpg'),
(159051, 11259, 'Megamente Domina S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449180.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vkmSp4Ryu0JuGMzC52VtFQV2fVL.jpg'),
(159052, 11260, 'Submarinos Perdidos da Segunda Guerra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449170.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wwtU1AuBSSZmN2Z2M89PRBhVLa7.jpg'),
(159053, 11260, 'Submarinos Perdidos da Segunda Guerra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449171.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rtRFXSigjvfMgjGsH6Xm82Z7nUk.jpg'),
(159054, 11260, 'Submarinos Perdidos da Segunda Guerra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449172.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rM6O7Qa7aIdCJsmolepraAyvMzJ.jpg'),
(159055, 11261, 'Caras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449676.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yRpUqMoNdtNJJCP1yVlyjB0VyV9.jpg'),
(159056, 11261, 'Caras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449677.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3bhEYa9oNQDhHpLfoOStSnsIIWb.jpg'),
(159057, 11261, 'Caras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449678.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sSxKHoDDSNZgSmloobxVrWwWNkQ.jpg'),
(159058, 11261, 'Caras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449679.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ffQqDSsbLPLTsDNGMDzKfTJb9Lz.jpg'),
(159059, 11261, 'Caras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449680.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kRsOYSzs8eeNVYDvqGefxUIEtJU.jpg'),
(159060, 11261, 'Caras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449681.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lyMi8LZr64pFSpLCYbexMwRpkh6.jpg'),
(159061, 11262, 'Caras S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dk6bH5y7Q7bNYpQ3u5L4NLS1Roq.jpg'),
(159062, 11262, 'Caras S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dk6bH5y7Q7bNYpQ3u5L4NLS1Roq.jpg'),
(159063, 11262, 'Caras S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dk6bH5y7Q7bNYpQ3u5L4NLS1Roq.jpg'),
(159064, 11262, 'Caras S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dk6bH5y7Q7bNYpQ3u5L4NLS1Roq.jpg'),
(159065, 11262, 'Caras S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dk6bH5y7Q7bNYpQ3u5L4NLS1Roq.jpg'),
(159066, 11262, 'Caras S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dk6bH5y7Q7bNYpQ3u5L4NLS1Roq.jpg'),
(159067, 11263, 'Guga por Kuerten S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449671.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lmGgHLq0oNvEjUP63avLhh2X80H.jpg'),
(159068, 11263, 'Guga por Kuerten S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449672.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sTe91SJZGHuwzzlZoU1eKdOypzX.jpg'),
(159069, 11263, 'Guga por Kuerten S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449673.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zHnvwfSeeyVhf8dCz282WITVPOs.jpg'),
(159070, 11263, 'Guga por Kuerten S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449674.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1LTMsi2YA3JzBLyWjLIGXZslVR6.jpg'),
(159071, 11263, 'Guga por Kuerten S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449675.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zLUaqT5mmkktvRAMXAbKg9kZCZN.jpg'),
(159072, 11264, 'Israel Nos Passos de Jesus S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449666.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6GhsLmqjnQ5MUPPMg1s5Wrys45e.jpg'),
(159073, 11264, 'Israel Nos Passos de Jesus S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449667.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vf95pU5rn9XPEeKX4y0wegPFbRY.jpg'),
(159074, 11264, 'Israel Nos Passos de Jesus S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449668.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f3HDskvpZG6KlrwbMgdKp8fOXAa.jpg'),
(159075, 11264, 'Israel Nos Passos de Jesus S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449669.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/puofmDFfQwCggcRmmZUjkVeeh22.jpg'),
(159076, 11264, 'Israel Nos Passos de Jesus S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449670.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/caQUbRrAV7wDQnpTyhsb3trDmIs.jpg'),
(159077, 11265, 'Batalha dos Cozinheiros America Latina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4NYXW6vLAv7TdrUSEiDeEmUxwc3.jpg'),
(159078, 11265, 'Batalha dos Cozinheiros America Latina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4NYXW6vLAv7TdrUSEiDeEmUxwc3.jpg'),
(159079, 11265, 'Batalha dos Cozinheiros America Latina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4NYXW6vLAv7TdrUSEiDeEmUxwc3.jpg'),
(159080, 11265, 'Batalha dos Cozinheiros America Latina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4NYXW6vLAv7TdrUSEiDeEmUxwc3.jpg'),
(159081, 11265, 'Batalha dos Cozinheiros America Latina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4NYXW6vLAv7TdrUSEiDeEmUxwc3.jpg'),
(159082, 11265, 'Batalha dos Cozinheiros America Latina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4NYXW6vLAv7TdrUSEiDeEmUxwc3.jpg'),
(159083, 11265, 'Batalha dos Cozinheiros America Latina S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4NYXW6vLAv7TdrUSEiDeEmUxwc3.jpg'),
(159084, 11266, 'Breathe S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449589.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dVB6Zcisa6NwjkrKyQqgiyMGBmg.jpg'),
(159085, 11266, 'Breathe S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449590.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/FYejsYcIFtos5pgBgmnPGq4AqO.jpg'),
(159086, 11266, 'Breathe S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449591.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lFHukoXht1czK9JHRzywAUsrXR4.jpg'),
(159087, 11266, 'Breathe S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449592.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dbFKYl2A7lEJlDJLn70PfCtLUjx.jpg'),
(159088, 11266, 'Breathe S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449593.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vSyeoCyTGUSSMURFaYtz7IvxSNO.jpg'),
(159089, 11266, 'Breathe S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449594.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zncJa4pgQnvGQwEhn1TNQSN6rso.jpg'),
(159090, 11266, 'Breathe S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449595.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oi9oIBZ7pUOmkTUmOF4xkNToaRF.jpg'),
(159091, 11266, 'Breathe S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449596.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pnyMM70JeyssCcQDxExopJLLoIn.jpg'),
(159092, 11267, 'Brickleberry S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449553.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9qIDgQxFQuYEl6cYvrNsvSsxZMW.jpg'),
(159093, 11267, 'Brickleberry S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449554.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gOekAkv5DsNfFveipfp066YNiqN.jpg'),
(159094, 11267, 'Brickleberry S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449555.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u2TG1bcFkAlBsv1ROLNQLYc0MBu.jpg'),
(159095, 11267, 'Brickleberry S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449556.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vnVjBXSWMlRWKZQHnKb967tIThO.jpg'),
(159096, 11267, 'Brickleberry S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449557.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/unN698aWZRQeG2CnCC9VrpCCUxj.jpg'),
(159097, 11267, 'Brickleberry S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449558.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qTtwWk7qArCYNbw59sapaqvOe1Z.jpg'),
(159098, 11267, 'Brickleberry S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449559.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vqChoQWH6v6zM28vzFOsJ9rVVjN.jpg'),
(159099, 11267, 'Brickleberry S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449560.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u56Ml1i59esoWEcVTyI0g6a7Vts.jpg'),
(159100, 11267, 'Brickleberry S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449561.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3jhPJKWrZl0XJEAo1zwysjU7uJy.jpg'),
(159101, 11267, 'Brickleberry S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/449562.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lYGWdMtAZEHHu9jgNELOKqojkBL.jpg'),
(159102, 11268, 'Brickleberry S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449563.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xr6RYxOy8lRiNphqAEjq6wYJTdg.jpg'),
(159103, 11268, 'Brickleberry S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449564.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kSn51bgMvRmJADZvqCx2om32QqA.jpg'),
(159104, 11268, 'Brickleberry S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449565.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kFVFNVxzXs1NA5DKCywyLSJyReO.jpg'),
(159105, 11268, 'Brickleberry S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449566.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/id69ceP14NHurVSE5uaU2naFttb.jpg'),
(159106, 11268, 'Brickleberry S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449567.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9SRgnAVChcIUjovOlGvESKal1OB.jpg'),
(159107, 11268, 'Brickleberry S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449568.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6XnoEj4dsdwlblah4PFH8LPtfvl.jpg'),
(159108, 11268, 'Brickleberry S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449569.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4sbHx62rn1QIIU0NIAfMe5469Jz.jpg'),
(159109, 11268, 'Brickleberry S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449570.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z6WV3YJGQH4D9Bm9LLXIGKEbVlB.jpg'),
(159110, 11268, 'Brickleberry S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449571.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/flfOJYmduqwOSBz96EudaPxbznk.jpg'),
(159111, 11268, 'Brickleberry S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/449572.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9zcIPCyPpfLZE8541bd96iErSHg.jpg'),
(159112, 11268, 'Brickleberry S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/449573.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ubJDUZIARnlQ6BRrDQ5MJPNRfay.jpg'),
(159113, 11268, 'Brickleberry S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/449574.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/SRMtdVRFEpOrCFXluKlccxzjrW.jpg'),
(159114, 11268, 'Brickleberry S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/449575.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tJQXg00b5GDH8Qb9aV2VKj6O0iA.jpg'),
(159115, 11269, 'Brickleberry S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449576.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o5MIixiUrTcW7I5B7iPfjAUk6H7.jpg'),
(159116, 11269, 'Brickleberry S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449577.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g3b5uaHF1yzG2XOERwzFWtGJsxJ.jpg'),
(159117, 11269, 'Brickleberry S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449578.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f3JUDMzkUEFdmY8eVYdG6k9gL1L.jpg'),
(159118, 11269, 'Brickleberry S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449579.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kSWouuZC86Ho1NmHZpmqWE9wKJR.jpg'),
(159119, 11269, 'Brickleberry S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449580.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x9ADgyHz4OLBFbzGSrCTBEPDVjy.jpg'),
(159120, 11269, 'Brickleberry S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449581.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ejdmM9QqmW3ZNs1aB472WZy25TJ.jpg'),
(159121, 11269, 'Brickleberry S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449582.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hjgR6WaJogsSagXYtRyqeMZRpig.jpg'),
(159122, 11269, 'Brickleberry S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449583.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/msuZtpFcL9K5ToCd1YTUsQbhejJ.jpg'),
(159123, 11269, 'Brickleberry S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449584.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wj0c5pYW9KPiDCSKQA3FjYNdpS0.jpg'),
(159124, 11269, 'Brickleberry S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/449585.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m9kC9MfipcEfHVhpoXnTu9mWRBS.jpg'),
(159125, 11269, 'Brickleberry S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/449586.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2SvadYyyJFhTiQeOc6stesUXpyI.jpg'),
(159126, 11269, 'Brickleberry S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/449587.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q25MBsEmi6KQJ1CWAcFW2wRrYx8.jpg'),
(159127, 11269, 'Brickleberry S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/449588.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oSPOci6c4gx4AA0n9UlPsJQFtvN.jpg'),
(159128, 11270, 'Chimp Crazy S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449549.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mINM6iEO7rFZFWWfwZTtSRmeFGi.jpg'),
(159129, 11270, 'Chimp Crazy S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdiqhuYK7WDCSihybbBsXBII0Zq.jpg'),
(159130, 11270, 'Chimp Crazy S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdiqhuYK7WDCSihybbBsXBII0Zq.jpg'),
(159131, 11270, 'Chimp Crazy S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdiqhuYK7WDCSihybbBsXBII0Zq.jpg'),
(159132, 11271, 'Delicias da Miss Brown S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159133, 11271, 'Delicias da Miss Brown S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159134, 11271, 'Delicias da Miss Brown S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159135, 11271, 'Delicias da Miss Brown S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159136, 11271, 'Delicias da Miss Brown S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159137, 11271, 'Delicias da Miss Brown S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159138, 11272, 'Delicias da Miss Brown S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159139, 11272, 'Delicias da Miss Brown S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159140, 11272, 'Delicias da Miss Brown S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159141, 11272, 'Delicias da Miss Brown S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159142, 11272, 'Delicias da Miss Brown S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159143, 11272, 'Delicias da Miss Brown S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159144, 11272, 'Delicias da Miss Brown S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159145, 11272, 'Delicias da Miss Brown S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159146, 11272, 'Delicias da Miss Brown S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159147, 11272, 'Delicias da Miss Brown S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/449519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159148, 11272, 'Delicias da Miss Brown S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/449520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159149, 11272, 'Delicias da Miss Brown S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/449521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159150, 11272, 'Delicias da Miss Brown S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/449522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159151, 11273, 'Delicias da Miss Brown S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159152, 11273, 'Delicias da Miss Brown S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159153, 11273, 'Delicias da Miss Brown S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159154, 11273, 'Delicias da Miss Brown S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159155, 11273, 'Delicias da Miss Brown S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159156, 11273, 'Delicias da Miss Brown S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159157, 11273, 'Delicias da Miss Brown S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159158, 11273, 'Delicias da Miss Brown S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159159, 11273, 'Delicias da Miss Brown S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159160, 11273, 'Delicias da Miss Brown S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/449532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159161, 11273, 'Delicias da Miss Brown S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/449533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159162, 11273, 'Delicias da Miss Brown S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/449534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159163, 11273, 'Delicias da Miss Brown S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/449535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159164, 11274, 'Delicias da Miss Brown S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159165, 11274, 'Delicias da Miss Brown S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159166, 11274, 'Delicias da Miss Brown S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159167, 11274, 'Delicias da Miss Brown S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159168, 11274, 'Delicias da Miss Brown S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(159169, 11274, 'Delicias da Miss Brown S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159170, 11274, 'Delicias da Miss Brown S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159171, 11274, 'Delicias da Miss Brown S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159172, 11274, 'Delicias da Miss Brown S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159173, 11274, 'Delicias da Miss Brown S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/449545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159174, 11274, 'Delicias da Miss Brown S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/449546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159175, 11274, 'Delicias da Miss Brown S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/449547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159176, 11274, 'Delicias da Miss Brown S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/449548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159177, 11275, 'Delicias da Miss Brown S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/665346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159178, 11275, 'Delicias da Miss Brown S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/665347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159179, 11275, 'Delicias da Miss Brown S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/665348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159180, 11275, 'Delicias da Miss Brown S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/665349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159181, 11275, 'Delicias da Miss Brown S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/665350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159182, 11275, 'Delicias da Miss Brown S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/665351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159183, 11275, 'Delicias da Miss Brown S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/665352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159184, 11275, 'Delicias da Miss Brown S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/665353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159185, 11275, 'Delicias da Miss Brown S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/665354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159186, 11275, 'Delicias da Miss Brown S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/665355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159187, 11275, 'Delicias da Miss Brown S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/665356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159188, 11275, 'Delicias da Miss Brown S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/665357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159189, 11275, 'Delicias da Miss Brown S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/665358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bWH6ia5laX0zHWSAe1ioGI0paVN.jpg'),
(159190, 11276, 'Despedacado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449498.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h10fX1IeoRDiVNOqez3nrRm3di7.jpg'),
(159191, 11276, 'Despedacado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449499.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oJ3QD60RoU824SgFNCouptScLZC.jpg'),
(159192, 11276, 'Despedacado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449500.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ulkLnCHIukfA0rqpJICyPsqzsjZ.jpg'),
(159193, 11276, 'Despedacado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449501.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oHqliELAjYRbTTQkTgwWHzX713H.jpg'),
(159194, 11276, 'Despedacado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449502.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fiarFlm76dGZuiCwPYW3U4PetQm.jpg'),
(159195, 11276, 'Despedacado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449503.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rGXOZocudLhh0ErhbjFKdx4UWkS.jpg'),
(159196, 11277, 'Homem de Familia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449479.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1MJbPGkY2OuQgGuVWFBEPswKLqc.jpg'),
(159197, 11277, 'Homem de Familia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449480.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qReJFgdX5auzfj4HNFJ19OjrWSx.jpg'),
(159198, 11277, 'Homem de Familia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449481.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fHfPHtpvAWbp1ktXUOD4o3Y8IPa.jpg'),
(159199, 11277, 'Homem de Familia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449482.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8IdXsGPeiXczlgGlYNQCVlg6aiI.jpg'),
(159200, 11277, 'Homem de Familia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449483.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jvqa8JlQnvIARI9qDrwBrfIIZgC.jpg'),
(159201, 11277, 'Homem de Familia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449484.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uU6ex6ImkXNtCa2KZCETvFeMZa7.jpg'),
(159202, 11277, 'Homem de Familia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449485.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m8sKZVvRkUsC5SRCeCGWpSIJxoh.jpg'),
(159203, 11277, 'Homem de Familia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449486.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5LXtMbRBgkiv7bvioTTfJ8bmiRg.jpg'),
(159204, 11277, 'Homem de Familia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449487.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lXfiWlZWmyR9GUleupct4AE5rXe.jpg'),
(159205, 11277, 'Homem de Familia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/449488.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xww2L0y9GfzF84LVk7Hr7Qe74vZ.jpg'),
(159206, 11278, 'Homem de Familia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449489.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bbr80pJIh8A2SzfvVRcHbKlf0Rj.jpg'),
(159207, 11278, 'Homem de Familia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449490.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p1byhmzvGVfkkxMKsOs6Yn8NgZL.jpg'),
(159208, 11278, 'Homem de Familia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449491.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2qsrT3mxe4xGGwKS2A1Q1rDydib.jpg'),
(159209, 11278, 'Homem de Familia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449492.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8dFCadbhtLFOaSUfM6owfQQ3deF.jpg'),
(159210, 11278, 'Homem de Familia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449493.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pkwmzHBB8m8GGvWlphb7msYqA30.jpg'),
(159211, 11278, 'Homem de Familia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449494.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nolVfr5J1fRw8xUXBUHlNka4o3S.jpg'),
(159212, 11278, 'Homem de Familia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449495.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/29WxgoDm75GDjfzBaDTKPlNPGg7.jpg'),
(159213, 11278, 'Homem de Familia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449496.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/laLFbXNVH91H8Ek3qm3v2fjjGOI.jpg'),
(159214, 11278, 'Homem de Familia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449497.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/63lHczSAEBqOt6z4ULswU28l79q.jpg'),
(159215, 11279, 'Ilha de Peixe Grande S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449473.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xG9zx2vOceXZ13xnScTQcx0gB0t.jpg'),
(159216, 11279, 'Ilha de Peixe Grande S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449474.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ad8ITWM9QhrIu0DzqFSORhM3t3N.jpg'),
(159217, 11279, 'Ilha de Peixe Grande S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449475.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bCScvA0Wry5lYQuFrenPq08Mc9Y.jpg'),
(159218, 11279, 'Ilha de Peixe Grande S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449476.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f1VvNQH7DProePctpzkcNFukUlk.jpg'),
(159219, 11279, 'Ilha de Peixe Grande S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449477.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cGx4WTsr44B3LZv2VmZQqsyrX6c.jpg'),
(159220, 11279, 'Ilha de Peixe Grande S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449478.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1kZW1JJB9HKEJfN69tILJjkyXP0.jpg'),
(159221, 11280, 'Os Ho ho limpicos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449449.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lpRTr094hZZw1Up92uwog3qiUUY.jpg'),
(159222, 11280, 'Os Ho ho limpicos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449450.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hHaVIg2W3AfCGl34IZE8py0dFiG.jpg'),
(159223, 11280, 'Os Ho ho limpicos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449451.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k9COk0WZENvUZXk0kb079RTHocg.jpg'),
(159224, 11280, 'Os Ho ho limpicos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVi53MC0rKF2iylwseT8eaFxKOX.jpg'),
(159225, 11280, 'Os Ho ho limpicos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVi53MC0rKF2iylwseT8eaFxKOX.jpg'),
(159226, 11280, 'Os Ho ho limpicos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449454.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/da2pAANuQVY4f92QnlNn9qfRGof.jpg'),
(159227, 11280, 'Os Ho ho limpicos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449455.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7ZAKRoyaImdJwCSVYC4qCcOuINR.jpg'),
(159228, 11280, 'Os Ho ho limpicos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449456.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/flaoCjLpRd90b1VgZkx13MTlatv.jpg'),
(159229, 11280, 'Os Ho ho limpicos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVi53MC0rKF2iylwseT8eaFxKOX.jpg'),
(159230, 11280, 'Os Ho ho limpicos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/449458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVi53MC0rKF2iylwseT8eaFxKOX.jpg'),
(159231, 11280, 'Os Ho ho limpicos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/449459.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jdNVzQnPCfvJwHOmQHt5FO40Tcy.jpg'),
(159232, 11280, 'Os Ho ho limpicos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/449460.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/44KyVGp9GuqGXr257KgbYaHkfPH.jpg'),
(159233, 11280, 'Os Ho ho limpicos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/449461.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/92erXDe2ZG0yi1GhAZqfruhBvA.jpg'),
(159234, 11280, 'Os Ho ho limpicos S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/449462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVi53MC0rKF2iylwseT8eaFxKOX.jpg'),
(159235, 11280, 'Os Ho ho limpicos S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/449463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVi53MC0rKF2iylwseT8eaFxKOX.jpg'),
(159236, 11280, 'Os Ho ho limpicos S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/449464.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6mg4cMbp2JjOFQr3JYEc9LoEmt0.jpg'),
(159237, 11281, 'Os Ho ho limpicos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449465.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d0Q178yNcmVyyDcK2gajUWKqRel.jpg'),
(159238, 11281, 'Os Ho ho limpicos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449466.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1MRjgBLd4UX0iT5zXXAENCLqB.jpg'),
(159239, 11281, 'Os Ho ho limpicos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449467.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lnJa7lbc33QcTxX6nezFo7ypIBB.jpg'),
(159240, 11281, 'Os Ho ho limpicos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVi53MC0rKF2iylwseT8eaFxKOX.jpg'),
(159241, 11281, 'Os Ho ho limpicos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449469.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9JvjhBpzIl1loSyy0p7DkKw6Y8w.jpg'),
(159242, 11281, 'Os Ho ho limpicos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449470.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dUf3q7hL5jR6szsXnAHBPBUc3tE.jpg'),
(159243, 11281, 'Os Ho ho limpicos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449471.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tfW48G4xZwE585UAcQMExtuvkvg.jpg'),
(159244, 11281, 'Os Ho ho limpicos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eVi53MC0rKF2iylwseT8eaFxKOX.jpg'),
(159245, 11282, 'Salsicha e Scooby Atras das Pistas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159246, 11282, 'Salsicha e Scooby Atras das Pistas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159247, 11282, 'Salsicha e Scooby Atras das Pistas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159248, 11282, 'Salsicha e Scooby Atras das Pistas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159249, 11282, 'Salsicha e Scooby Atras das Pistas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159250, 11282, 'Salsicha e Scooby Atras das Pistas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159251, 11282, 'Salsicha e Scooby Atras das Pistas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159252, 11282, 'Salsicha e Scooby Atras das Pistas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159253, 11282, 'Salsicha e Scooby Atras das Pistas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159254, 11282, 'Salsicha e Scooby Atras das Pistas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/449432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159255, 11282, 'Salsicha e Scooby Atras das Pistas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/449433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159256, 11282, 'Salsicha e Scooby Atras das Pistas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/449434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159257, 11282, 'Salsicha e Scooby Atras das Pistas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/449435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159258, 11283, 'Salsicha e Scooby Atras das Pistas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/449436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159259, 11283, 'Salsicha e Scooby Atras das Pistas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/449437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159260, 11283, 'Salsicha e Scooby Atras das Pistas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/449438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159261, 11283, 'Salsicha e Scooby Atras das Pistas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/449439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159262, 11283, 'Salsicha e Scooby Atras das Pistas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/449440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159263, 11283, 'Salsicha e Scooby Atras das Pistas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/449441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159264, 11283, 'Salsicha e Scooby Atras das Pistas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/449442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159265, 11283, 'Salsicha e Scooby Atras das Pistas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/449443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159266, 11283, 'Salsicha e Scooby Atras das Pistas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/449444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159267, 11283, 'Salsicha e Scooby Atras das Pistas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/449445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159268, 11283, 'Salsicha e Scooby Atras das Pistas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/449446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159269, 11283, 'Salsicha e Scooby Atras das Pistas S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/449447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159270, 11283, 'Salsicha e Scooby Atras das Pistas S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/449448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8zlUvWnU0OR3d8ud5sR6aJfHOc1.jpg'),
(159271, 11284, 'Better Than Us S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/453993.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fOkYNsb4kVrnpAe0uTN3Ws3fCWF.jpg'),
(159272, 11284, 'Better Than Us S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/453994.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qE8VpIfPITpt0JcAKk4IUleWA1C.jpg'),
(159273, 11284, 'Better Than Us S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/453995.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uH4YCbqEPvijldX5zj7a0BFzmff.jpg'),
(159274, 11284, 'Better Than Us S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/453996.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/886YUYydo4E0jtzE25jorzt6qj8.jpg'),
(159275, 11284, 'Better Than Us S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/453997.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p13bLLx4giklZIAYIQI3Ns4ldf3.jpg'),
(159276, 11284, 'Better Than Us S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/453998.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/idia8KGHoP7P08UI1N6TTDohzXA.jpg'),
(159277, 11284, 'Better Than Us S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/453999.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9pKHf23GYbKO63QHTzwvTYY3iIh.jpg'),
(159278, 11284, 'Better Than Us S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/454000.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mtTwJ0SZCtwrr7nQSyfujrVOIcT.jpg'),
(159279, 11284, 'Better Than Us S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/454001.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6KlQZuuE2wLzApGEGE7tpWncqUu.jpg'),
(159280, 11284, 'Better Than Us S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/454002.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/12rbzI5heqQsmabyKUVgJCASEpH.jpg'),
(159281, 11284, 'Better Than Us S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/454003.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8LjtIMXNSTwxYHWwwq1VUYEEDCd.jpg'),
(159282, 11284, 'Better Than Us S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/454004.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pGJLZ88KUwvLSOJLQxZxgvnczrK.jpg'),
(159283, 11284, 'Better Than Us S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/454005.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zYWYmQ6Bh4YA6nAMvWtxbz7g2cA.jpg'),
(159284, 11284, 'Better Than Us S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/454006.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2qXqherxEVPDkV1VTJDUff5JXYc.jpg'),
(159285, 11284, 'Better Than Us S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/454007.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/coExKnb8lTCm6tXECjPYSBhr0kE.jpg'),
(159286, 11284, 'Better Than Us S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/454008.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tyDXo6PA5TjPKdMPYL7LctPLd18.jpg'),
(159287, 11285, 'Os Cavaleiros do Zodiaco Alma de Ouro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/453980.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2QYaMnTTgwnYhTfXwLo0vpOb57b.jpg'),
(159288, 11285, 'Os Cavaleiros do Zodiaco Alma de Ouro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/453981.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1KuCuO40cK7RiRml2WjzldA3FzM.jpg'),
(159289, 11285, 'Os Cavaleiros do Zodiaco Alma de Ouro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/453982.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lE6V4qTlYAHVI4RBU1X5fH0UMBn.jpg'),
(159290, 11285, 'Os Cavaleiros do Zodiaco Alma de Ouro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/453983.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5p6CoHS9MyjEacwzsBuKPOTHez0.jpg'),
(159291, 11285, 'Os Cavaleiros do Zodiaco Alma de Ouro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/453984.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gUHWziAfXl7CFyesQoI6m1cCPBR.jpg'),
(159292, 11285, 'Os Cavaleiros do Zodiaco Alma de Ouro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/453985.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h722FoAZsy6tADRM3SaXXjJ7e9m.jpg'),
(159293, 11285, 'Os Cavaleiros do Zodiaco Alma de Ouro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/453986.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/khMQAEeQy8UwRkIDeBJjGHLiGay.jpg'),
(159294, 11285, 'Os Cavaleiros do Zodiaco Alma de Ouro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/453987.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/46IH2mZF0jSaBFCYk36ZEOpQq2a.jpg'),
(159295, 11285, 'Os Cavaleiros do Zodiaco Alma de Ouro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/453988.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rSuxVno8MunZBJbRr7SOgwRaLmM.jpg'),
(159296, 11285, 'Os Cavaleiros do Zodiaco Alma de Ouro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/453989.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o585qN0TrRigBlkhE8CABPfVAOa.jpg'),
(159297, 11285, 'Os Cavaleiros do Zodiaco Alma de Ouro S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/453990.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bY3C9A07xQCO0GmGLng6x7fVsIi.jpg'),
(159298, 11285, 'Os Cavaleiros do Zodiaco Alma de Ouro S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/453991.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7kTjWUTA37CQ5uMFGPPGcHuF0b7.jpg'),
(159299, 11285, 'Os Cavaleiros do Zodiaco Alma de Ouro S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/453992.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/spmrybnGSEjmSsQaDpomOMtbZcD.jpg'),
(159300, 11286, 'Bocchi The Rock [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/453849.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/svwWmmG7pzDKm3DUdgUEvk3h0ZM.jpg'),
(159301, 11286, 'Bocchi The Rock [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/453850.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cI5fIuAqxZuzSEvwIPuZC4UiYqA.jpg'),
(159302, 11286, 'Bocchi The Rock [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/453851.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rrPaFc6urB9cBNJfCrgNyTocnRj.jpg'),
(159303, 11286, 'Bocchi The Rock [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/453852.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j2wgQD6aKKJJPCQq7Q2hrVyHYcv.jpg'),
(159304, 11286, 'Bocchi The Rock [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/453853.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zPGwda7qVnEjkKJ542tXaWHtg1h.jpg'),
(159305, 11286, 'Bocchi The Rock [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/453854.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1iCTbCd7aPNuhxK6MImUP0lcGRK.jpg'),
(159306, 11286, 'Bocchi The Rock [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/453855.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d4HtnohyUi16bDNYc9KSfYS6Nie.jpg'),
(159307, 11286, 'Bocchi The Rock [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/453856.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oDaDrtdD5x8Y436JqZDLaPEdd9b.jpg'),
(159308, 11286, 'Bocchi The Rock [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/453857.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/baaLPQ8H0fmn8manNreFNJk909w.jpg'),
(159309, 11286, 'Bocchi The Rock [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/453858.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sjq5mF0VltXYsWVuFDv7Ua43jBS.jpg'),
(159310, 11286, 'Bocchi The Rock [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/453859.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4IhuRiskwbCSUd7oncZpMVUmwTW.jpg'),
(159311, 11286, 'Bocchi The Rock [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/453860.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b91lQ5mgRNYFlaX6OQCkvCvgwA8.jpg'),
(159312, 11287, 'Goblin [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/453833.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jwNbR9M0oii83RjB3kTlbHFzHRV.jpg'),
(159313, 11287, 'Goblin [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/453834.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2MM3LpRNh66eOd97zglynTMmCEY.jpg'),
(159314, 11287, 'Goblin [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/453835.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sOs5aGq32pzc0VR5QJy04VQ0UIj.jpg'),
(159315, 11287, 'Goblin [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/453836.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kfzWV0OqIP5GkqIeQqWOPR33mCz.jpg'),
(159316, 11287, 'Goblin [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/453837.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/65rYZvRj7C6cfNSkEdIIssOSJLn.jpg'),
(159317, 11287, 'Goblin [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/453838.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qJ6t7DdOjd8iZ58wRQ8cLJWeXrn.jpg'),
(159318, 11287, 'Goblin [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/453839.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o9GLTZzZQmvda8GUycUSD2vm8qs.jpg'),
(159319, 11287, 'Goblin [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/453840.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2EkpltAxDdvCS93lzaRrFhksfKn.jpg'),
(159320, 11287, 'Goblin [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/453841.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ytpd3tVDEV2MzQKyfjN3VSS9Lpz.jpg'),
(159321, 11287, 'Goblin [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/453842.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rlykIO7ze7HNrPiNuMmyRYHj1qs.jpg'),
(159322, 11287, 'Goblin [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/453843.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/odvchSAiaw1Hj1h6CGN7ivZAPS0.jpg'),
(159323, 11287, 'Goblin [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/453844.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a4YM9wBq0mLopKgRFXaY5fuBqmq.jpg'),
(159324, 11287, 'Goblin [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/453845.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7UfNPEjuDWXnOIKFwT3Qm35lobv.jpg'),
(159325, 11287, 'Goblin [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/453846.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/otZ61Ha45nIiEqIyp6N2Il1m86L.jpg'),
(159326, 11287, 'Goblin [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/453847.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bSPzfM3pH8NvC082BAPXvjHI31u.jpg'),
(159327, 11287, 'Goblin [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/453848.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8l61HYXZYaL8ny7heALzz9OqVvL.jpg'),
(159328, 11288, 'Angel Di Maria Quebrando a Barreira S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/453490.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j7lWW3MOanjGRq5GAxa3hxO618n.jpg'),
(159329, 11288, 'Angel Di Maria Quebrando a Barreira S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/453491.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oJiog9mJEKR1nQgHCvfh1OlTKtr.jpg'),
(159330, 11288, 'Angel Di Maria Quebrando a Barreira S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/453492.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/akHz9XyG9qQtcLd7vI1CucuwqlS.jpg'),
(159331, 11289, 'Community S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/453381.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A12swtL9RRRhwM5StDk6EJtL1LY.jpg'),
(159332, 11289, 'Community S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/453382.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1puZjqE3ONkKpUJRazYnINCzEP3.jpg'),
(159333, 11289, 'Community S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/453383.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jXPLlmOz8mJgZmD7N1EDpirqBnF.jpg'),
(159334, 11289, 'Community S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/453384.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zL2rqq9i4zJ50YVP3m8QkfuXoZA.jpg'),
(159335, 11289, 'Community S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/453385.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8ZxS87IxvFDdNrWfCnWrPrCgSdA.jpg'),
(159336, 11289, 'Community S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/453386.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mYaGaG8fE3cLfVfogD3e1mzIOua.jpg'),
(159337, 11289, 'Community S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/453387.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xlTV3fMBekUefKtar34sTcnIwVi.jpg'),
(159338, 11289, 'Community S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/453388.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/80H9lKNIczrIZV2Ix0NwYeL0abK.jpg'),
(159339, 11289, 'Community S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/453389.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mKpqBT4nhILaqlugi1gSmS4bJQr.jpg'),
(159340, 11289, 'Community S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/453390.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A3KYniJFNZf9CUoyGLDq2h37sGt.jpg'),
(159341, 11289, 'Community S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/453391.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cNj0rFq6le93BIkVZVaKP6Dtrjj.jpg'),
(159342, 11289, 'Community S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/453392.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eMT9KNrLlZq22ytGQyUVXXqIMWb.jpg'),
(159343, 11289, 'Community S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/453393.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8DNmhzUZn9GVgXK3ZYGPWkeAwJN.jpg'),
(159344, 11289, 'Community S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/453394.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2hVC5JyV7VsyngjzmJjmOEMPHUS.jpg'),
(159345, 11289, 'Community S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/453395.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l7k3sB0PQFbko2cC5xabbbpRxfO.jpg'),
(159346, 11289, 'Community S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/453396.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c35AD5v6jICDSZnIuSWXv3tjpNY.jpg'),
(159347, 11289, 'Community S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/453397.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ucJzpI6ngF2jn7Q3XYQqnehaf80.jpg'),
(159348, 11289, 'Community S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/453398.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/66PxgnSeQwSpLl9PxKUq34Nsqqj.jpg'),
(159349, 11289, 'Community S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/453399.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A7X7VwGzzFor68CPv0NwdWXKkCq.jpg'),
(159350, 11289, 'Community S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/453400.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6lORj6XTPrmxluvrH9mpMJBxJN9.jpg'),
(159351, 11289, 'Community S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/453401.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/opiT1LRO94iK65aASXx1dnycRqu.jpg'),
(159352, 11289, 'Community S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/453402.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kBxtI4M3yc8Jvy4S8CWoIjMpsLi.jpg'),
(159353, 11289, 'Community S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/453403.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pBH5B2LvqfpIviHKj8kBrycLall.jpg'),
(159354, 11289, 'Community S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/453404.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/diJ8I21giUDcuaM1KVAz3d2X8yl.jpg'),
(159355, 11290, 'Community S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/453405.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cOskgkE9MO4TzXqOwH12BOjTid4.jpg'),
(159356, 11290, 'Community S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/453406.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/XVL2T0nGihfwjbdyoKbxSxANOX.jpg'),
(159357, 11290, 'Community S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/453407.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8wbuJHaNYFxXti19ccIPlTZzsUK.jpg'),
(159358, 11290, 'Community S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/453408.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vfGODB9Fg0ldxHBGASMjKXcxXlU.jpg'),
(159359, 11290, 'Community S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/453409.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dnhUUjomcK4Lfz8DOLdqVMjkrl3.jpg'),
(159360, 11290, 'Community S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/453410.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cqN8KqVfTwhLjrbnHA5N99YlC9P.jpg'),
(159361, 11290, 'Community S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/453411.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qjtboUo5D7EH7zLNM0NQLZw0PQS.jpg'),
(159362, 11290, 'Community S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/453412.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lN7M8NttXzCOij4CFXpkjaVcZ8q.jpg'),
(159363, 11290, 'Community S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/453413.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wh2x88oGf37eWGls1pngncfTsE4.jpg'),
(159364, 11290, 'Community S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/453414.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/VCP1QCMukiq0yj4SJjd0uWhQsV.jpg'),
(159365, 11290, 'Community S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/453415.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t8Qq25puHO3l1UDeuk3YLFIWYTl.jpg'),
(159366, 11290, 'Community S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/453416.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1Mv7LUmsAGnAbuNfHpH7EJDDiET.jpg'),
(159367, 11290, 'Community S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/453417.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jj9HY6zeOHUpzFqVxjlBoctmSzN.jpg'),
(159368, 11290, 'Community S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/453418.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iRCm95sF1bhLYPpbCrYAd01iUuz.jpg'),
(159369, 11290, 'Community S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/453419.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1rcR4Fkv2ls6SmgPnIQoMfpfkSh.jpg'),
(159370, 11290, 'Community S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/453420.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cGZTMoZ8Iqb4CDXGoDTAIXlqJtT.jpg'),
(159371, 11290, 'Community S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/453421.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/icaziPp0yWcMz35NZnWw4SaI5Or.jpg'),
(159372, 11290, 'Community S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/453422.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3UjFqQPNNpfX7RDzDmPkeyKyjRw.jpg'),
(159373, 11290, 'Community S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/453423.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5NtUE9V9keOiVVfVCEU1nMTXrkT.jpg'),
(159374, 11290, 'Community S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/453424.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gGyDNVtNzT7oSuewS0xlcGw9sAH.jpg'),
(159375, 11290, 'Community S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/453425.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lv6EHXwtkqAaYIBuVbKo7JHP2mL.jpg'),
(159376, 11290, 'Community S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/453426.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/poYbr5qCKJHVl0Ha3HqLHBYtob1.jpg'),
(159377, 11290, 'Community S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/453427.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/glb0o83mnpPhw7vKd6ehQvh2949.jpg'),
(159378, 11290, 'Community S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/453428.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f3KasJyED19GEi6ZJCnE6rKfcpk.jpg'),
(159379, 11291, 'Community S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/453429.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dTRmmZrlqBJpbqT7CUmTiZ7LIw8.jpg'),
(159380, 11291, 'Community S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/453430.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/merKMKgmhzPDi3PnFbk6DttwLQ9.jpg'),
(159381, 11291, 'Community S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/453431.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nvAR4lK18iSOlBZFl16A5bi1jYn.jpg'),
(159382, 11291, 'Community S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/453432.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4HOHWTjmSBPLgaH2z4Y01Bmp6ge.jpg'),
(159383, 11291, 'Community S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/453433.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zaKAF3UUVSGy1PxDFjREllUSUVm.jpg'),
(159384, 11291, 'Community S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/453434.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t7AxhTQBjIcaAf82gqRv9231RVP.jpg'),
(159385, 11291, 'Community S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/453435.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/arAzgMEvNiSvcXGw2jr4tokYAE7.jpg'),
(159386, 11291, 'Community S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/453436.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bDDv2nTeOvDPP6NoqwtVeCppK4J.jpg'),
(159387, 11291, 'Community S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/453437.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fXQ9v9wRHQxaEJKbnddCEsAwbs.jpg'),
(159388, 11291, 'Community S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/453438.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x36Gae882wx7sIcCNZsQsOjH1DU.jpg'),
(159389, 11291, 'Community S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/453439.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gByQ3h8DuVNDkchyrAdUS4O3KFK.jpg'),
(159390, 11291, 'Community S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/453440.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hkeo2pJN6gL6z4X5RPLrJz0S8Ob.jpg'),
(159391, 11291, 'Community S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/453441.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/flspxnPSTg25OH4hG4IRLMxeSNI.jpg'),
(159392, 11291, 'Community S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/453442.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4PsOx6Xot9XTHY0FVajb2cq1wJY.jpg'),
(159393, 11291, 'Community S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/453443.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kNe3FuJPREssXiHQsKGVZH2njwx.jpg'),
(159394, 11291, 'Community S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/453444.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q2eRhGAAiwyHUOQ4Wz81xAULNlp.jpg'),
(159395, 11291, 'Community S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/453445.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eczD5Uam5EmxsehDvkPJ5oMmTpC.jpg'),
(159396, 11291, 'Community S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/453446.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qeGuk6VSKxKkBuGCLsv51oSWKSG.jpg'),
(159397, 11291, 'Community S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/453447.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hSEqtCBl0uwpF3tPIn06M3c8Qa4.jpg'),
(159398, 11291, 'Community S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/453448.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6vV57fEv51G2prHAIhGsbYA2NtB.jpg'),
(159399, 11291, 'Community S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/453449.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eCWE0K0eWSesVB7VsdFl5zHyF2h.jpg'),
(159400, 11291, 'Community S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/453450.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4jPDSA48gVXCfcZudfwRMLGQ6Jv.jpg'),
(159401, 11292, 'Community S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/453451.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qTMfgZ7D9uwFbjsktBmFYbutwCO.jpg'),
(159402, 11292, 'Community S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/453452.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1MBNIV2GAHrGkzWEQAGLgqfT3WU.jpg'),
(159403, 11292, 'Community S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/453453.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vWojIPPMKNdKJCGR30XxjTiSyUL.jpg'),
(159404, 11292, 'Community S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/453454.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/67Q53zC2bCB769Ln5ZxW0CDxNP4.jpg'),
(159405, 11292, 'Community S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/453455.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9q1Ca7wdtUk7mvZP7e8gg86rxsl.jpg'),
(159406, 11292, 'Community S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/453456.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iKCh4pxP8mMvdDMXRfZUcjoZtwB.jpg'),
(159407, 11292, 'Community S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/453457.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pOv5OISLiHb4k0SogQM9YrGV2if.jpg'),
(159408, 11292, 'Community S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/453458.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2Bb3l7dt5nnEIp81WXngHC1JqYr.jpg'),
(159409, 11292, 'Community S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/453459.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/21uKPhMG9s4B8vXkA8c8gIcDJjb.jpg'),
(159410, 11292, 'Community S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/453460.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9wuDMCoLvOVsKs0USoUdazWuSXD.jpg'),
(159411, 11292, 'Community S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/453461.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jrXQtMSH20qOTs9DnFvFH5yVYtU.jpg'),
(159412, 11292, 'Community S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/453462.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qpxDLoLfWTjJS8VvHTUWmEBbhYB.jpg'),
(159413, 11292, 'Community S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/453463.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gVi2VDRef3TFZZjDExn1wZU7gLx.jpg'),
(159414, 11293, 'Community S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/453464.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j3Ycr7XjgkVd3Fqiox8JQtUleLb.jpg'),
(159415, 11293, 'Community S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/453465.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a3N352YGjSEz6h16GAXIlSx5lql.jpg'),
(159416, 11293, 'Community S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/453466.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lfTFL0iWRuQm4aNsDi2ZguR0oam.jpg'),
(159417, 11293, 'Community S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/453467.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9OA3OPsi2GKV50NzJEaLfoiFI9e.jpg'),
(159418, 11293, 'Community S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/453468.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4cDSb7GZhPlA1XA4oAWJ6H0ZWul.jpg'),
(159419, 11293, 'Community S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/453469.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yBbaHGftSE4fQHHpoyHinRhZT8A.jpg'),
(159420, 11293, 'Community S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/453470.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vaiyvrxMbTV37evu8deZWjh0d6w.jpg'),
(159421, 11293, 'Community S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/453471.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y0OPGULMRp8i946KfeLWPgevaKN.jpg'),
(159422, 11293, 'Community S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/453472.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ioUfmyzqLey13hcxj0uhxFJsKBn.jpg'),
(159423, 11293, 'Community S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/453473.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d8dBXhGrXnTd47RXLkuR8jseJ0s.jpg'),
(159424, 11293, 'Community S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/453474.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2GiIhRgltUSJ3dB6PiVW6FBi1ZI.jpg'),
(159425, 11293, 'Community S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/453475.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vJQpygFCQAQdnet70ZGL1GynxZN.jpg'),
(159426, 11293, 'Community S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/453476.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nlpUMv1w0DKbMFD4yLTaaMOBuYh.jpg'),
(159427, 11294, 'Community S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/453477.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n3W3AEGs8ep5hIUTKwL24yU52QB.jpg'),
(159428, 11294, 'Community S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/453478.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uDlsVSYVZBXZWDV1QXe8zrw9Dgz.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(159429, 11294, 'Community S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/453479.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4ykTtywOlJNTYFw1akTcdIxaVPJ.jpg'),
(159430, 11294, 'Community S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/453480.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8dRoodFkyB8TByTjBxv8URTbnIT.jpg'),
(159431, 11294, 'Community S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/453481.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mkavbFr9gWo9VpXq9r3aqDoa8It.jpg'),
(159432, 11294, 'Community S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/453482.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pi0BRpV8H29hCbnm6kkj2trC2qk.jpg'),
(159433, 11294, 'Community S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/453483.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2YRGTQPmrtkPExFu8bfBRfCR0Kt.jpg'),
(159434, 11294, 'Community S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/453484.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/veN14iL5km4MXST0iFGOxlLm8qh.jpg'),
(159435, 11294, 'Community S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/453485.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wv5NQlqc45hJktyYSLAQVT5LcE0.jpg'),
(159436, 11294, 'Community S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/453486.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/akyypVKvEHnGOiQKtB2ey57ZFLQ.jpg'),
(159437, 11294, 'Community S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/453487.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9h56aPfIQjTLhn88rpyXEDzNMvn.jpg'),
(159438, 11294, 'Community S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/453488.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1s9OCk1SS4IqRybCAxmI9vBuAsJ.jpg'),
(159439, 11294, 'Community S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/453489.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/upqXb246SG05ckyOvgmk5V4yBwk.jpg'),
(159440, 11295, 'Herois da Biblia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/453376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nN6fwGTZoHEYE9pv2fkxXFKU6yf.jpg'),
(159441, 11295, 'Herois da Biblia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/453377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nN6fwGTZoHEYE9pv2fkxXFKU6yf.jpg'),
(159442, 11295, 'Herois da Biblia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/453378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nN6fwGTZoHEYE9pv2fkxXFKU6yf.jpg'),
(159443, 11295, 'Herois da Biblia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/453379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nN6fwGTZoHEYE9pv2fkxXFKU6yf.jpg'),
(159444, 11295, 'Herois da Biblia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/453380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nN6fwGTZoHEYE9pv2fkxXFKU6yf.jpg'),
(159445, 11296, 'Hot Wheels Velocidade Maxima S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/453361.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iaZ7sbiWAI64TgRmT1JavRVBC40.jpg'),
(159446, 11296, 'Hot Wheels Velocidade Maxima S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/453362.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ogtCZ1uClL9jLZ8K0j3FOK8lz0B.jpg'),
(159447, 11296, 'Hot Wheels Velocidade Maxima S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/453363.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5t08WGxpYdAhR6DrWODTJ1iGDCp.jpg'),
(159448, 11296, 'Hot Wheels Velocidade Maxima S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/453364.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aTk6FIdscqNDAEB1xkRVh8PrrLA.jpg'),
(159449, 11296, 'Hot Wheels Velocidade Maxima S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/453365.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zBBcaCI6x45lCIY1hTVk0FKvvDb.jpg'),
(159450, 11296, 'Hot Wheels Velocidade Maxima S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/453366.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kLlVoPxa4m0l4PeNOaqZeNHgqRA.jpg'),
(159451, 11296, 'Hot Wheels Velocidade Maxima S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/453367.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tDe5stnMcm6452g23wbRGChjuCs.jpg'),
(159452, 11296, 'Hot Wheels Velocidade Maxima S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/453368.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uBS1KaKsveKRQl2Pay4FRdINTF.jpg'),
(159453, 11296, 'Hot Wheels Velocidade Maxima S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/453369.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zzLNyVR18R6jQytvF26vbRYSoyu.jpg'),
(159454, 11296, 'Hot Wheels Velocidade Maxima S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/453370.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wmsaNr8AjUTGBQwCJV7pi1UxM9Y.jpg'),
(159455, 11297, 'Hot Wheels Velocidade Maxima S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/453371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lsYDS5spQ1SFiHPclzx5ySJBOyR.jpg'),
(159456, 11297, 'Hot Wheels Velocidade Maxima S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/453372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lsYDS5spQ1SFiHPclzx5ySJBOyR.jpg'),
(159457, 11297, 'Hot Wheels Velocidade Maxima S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/453373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lsYDS5spQ1SFiHPclzx5ySJBOyR.jpg'),
(159458, 11297, 'Hot Wheels Velocidade Maxima S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/453374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lsYDS5spQ1SFiHPclzx5ySJBOyR.jpg'),
(159459, 11297, 'Hot Wheels Velocidade Maxima S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/453375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lsYDS5spQ1SFiHPclzx5ySJBOyR.jpg'),
(159460, 11298, 'Hot Wheels Velocidade Maxima S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/718123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lsYDS5spQ1SFiHPclzx5ySJBOyR.jpg'),
(159461, 11298, 'Hot Wheels Velocidade Maxima S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/718124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lsYDS5spQ1SFiHPclzx5ySJBOyR.jpg'),
(159462, 11298, 'Hot Wheels Velocidade Maxima S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/718125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lsYDS5spQ1SFiHPclzx5ySJBOyR.jpg'),
(159463, 11298, 'Hot Wheels Velocidade Maxima S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/718126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lsYDS5spQ1SFiHPclzx5ySJBOyR.jpg'),
(159464, 11298, 'Hot Wheels Velocidade Maxima S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/718127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lsYDS5spQ1SFiHPclzx5ySJBOyR.jpg'),
(159465, 11299, 'O Ultimo Ano de Hitler S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/453359.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vbKS5Kzm6rJu3m9AJHpod7hgw9d.jpg'),
(159466, 11299, 'O Ultimo Ano de Hitler S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/453360.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rxUAhCPW0UovUPgDobmISRYT4HH.jpg'),
(159467, 11300, 'Que Legal Scooby Doo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/453309.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hc5xZUlmmp7JnxaU16YwmLhHyMi.jpg'),
(159468, 11300, 'Que Legal Scooby Doo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/453310.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yvPTVqiG8oS3U5llDeXD65uXzI5.jpg'),
(159469, 11300, 'Que Legal Scooby Doo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/453311.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b1RIj25EzPoYeQZJzNEAlhP0nz7.jpg'),
(159470, 11300, 'Que Legal Scooby Doo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/453312.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oOhTA568Wp6C8SzNZtFMicoAof2.jpg'),
(159471, 11300, 'Que Legal Scooby Doo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/453313.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ao4WWSI1RH7dT4VFPk7tfkmvj0h.jpg'),
(159472, 11300, 'Que Legal Scooby Doo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/453314.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kzUUxlPDTHg2zq07UZWw7SBo0i4.jpg'),
(159473, 11300, 'Que Legal Scooby Doo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/453315.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oCRF2GYxFmWOzybwrPBFJHnCFLw.jpg'),
(159474, 11300, 'Que Legal Scooby Doo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/453316.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d56sV0elMfhM4LFTv6ZH0BzPpMd.jpg'),
(159475, 11300, 'Que Legal Scooby Doo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/453317.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/guqnO2YqNw7IN5UvrYqf5dV7iID.jpg'),
(159476, 11300, 'Que Legal Scooby Doo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/453318.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o2zmzzyt9ALWP0Lm7qd0vcJrx9S.jpg'),
(159477, 11300, 'Que Legal Scooby Doo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/453319.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7XmAKlO6E8kHq1agWA4OJXNWJBp.jpg'),
(159478, 11300, 'Que Legal Scooby Doo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/453320.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iyJhPSPnY2NqNQeGsnjmcQJjTu3.jpg'),
(159479, 11300, 'Que Legal Scooby Doo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/453321.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aiEdZW0z0vbEaIL888kZnTSOEi6.jpg'),
(159480, 11300, 'Que Legal Scooby Doo S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/453322.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yqpVabRUq9XRvsvUiXOjoGkUyXW.jpg'),
(159481, 11300, 'Que Legal Scooby Doo S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/453323.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o9cBXMhh9Ke02IVNtxu0APafKpK.jpg'),
(159482, 11300, 'Que Legal Scooby Doo S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/453324.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pRCKBN7qu8UXk5U01YOSXWyIzTz.jpg'),
(159483, 11300, 'Que Legal Scooby Doo S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/453325.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bK6X6I4TEeQey3XXtsn6Yy5ftZ1.jpg'),
(159484, 11300, 'Que Legal Scooby Doo S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/453326.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bDVA3wwZnVZ640AXNQm2GMyUKWk.jpg'),
(159485, 11300, 'Que Legal Scooby Doo S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/453327.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r0fRdlLkHxSB8UnY8dw3mEEE02G.jpg'),
(159486, 11300, 'Que Legal Scooby Doo S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/453328.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8kZ8UaeEMQRU6EuxTwIbgJzSTPe.jpg'),
(159487, 11300, 'Que Legal Scooby Doo S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/453329.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/44NLU1BqOlgiWaKA9oD52gMYVrJ.jpg'),
(159488, 11300, 'Que Legal Scooby Doo S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/453330.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/buCe0EoFxIJYOorsTgGPENK8yPl.jpg'),
(159489, 11300, 'Que Legal Scooby Doo S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/453331.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wSKBLG1Ge4NdVrC6KkquLI034BR.jpg'),
(159490, 11300, 'Que Legal Scooby Doo S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/453332.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8XQXkleU9866VheAeLsnQSP4Bfq.jpg'),
(159491, 11300, 'Que Legal Scooby Doo S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/453333.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2yMeflfq1sbGJTU3gom3rFz6cYs.jpg'),
(159492, 11300, 'Que Legal Scooby Doo S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/453334.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m1pKTyfltBPEp1CBJ3dKfrwhbGw.jpg'),
(159493, 11301, 'Que Legal Scooby Doo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/453335.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3mNJRjqvNbR6Gea9GP5Qht2iQ7K.jpg'),
(159494, 11301, 'Que Legal Scooby Doo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/453336.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/md1oH7ZFQ8mwPiVeUorVA7jTvP1.jpg'),
(159495, 11301, 'Que Legal Scooby Doo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/453337.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n50yNMoMbYbtUcs9IResFCTi99y.jpg'),
(159496, 11301, 'Que Legal Scooby Doo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/453338.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7CcuKctIEdwYEppcdWzDYAO0ZJg.jpg'),
(159497, 11301, 'Que Legal Scooby Doo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/453339.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bKNBsIEDqrXikmMv2zvM2bxAGYs.jpg'),
(159498, 11301, 'Que Legal Scooby Doo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/453340.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pXlBH8JpTcIfTg5Bd9KzO78QrXY.jpg'),
(159499, 11301, 'Que Legal Scooby Doo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/453341.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t8GnNTPsjm76rzUKCC0CJRDGI0Q.jpg'),
(159500, 11301, 'Que Legal Scooby Doo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/453342.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eivPx9fHX6OhWXISQfmc2hUiirv.jpg'),
(159501, 11301, 'Que Legal Scooby Doo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/453343.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h3DtnqrxXjFEPRcVBJxhWXv63ZT.jpg'),
(159502, 11301, 'Que Legal Scooby Doo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/453344.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6KzS7Yw6MbkSvpfe9F2w62eR4Oi.jpg'),
(159503, 11301, 'Que Legal Scooby Doo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/453345.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q41EWrk1KsqVGboUmt55fv4X78N.jpg'),
(159504, 11301, 'Que Legal Scooby Doo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/453346.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A7WWMoZHzwLC9058QydZdlOuFEk.jpg'),
(159505, 11301, 'Que Legal Scooby Doo S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/453347.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tPCkg8AjBVfpgDobzJl1wV1nf6M.jpg'),
(159506, 11301, 'Que Legal Scooby Doo S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/453348.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3gUBsPgEBYeWQEaS3w9jHea8vl2.jpg'),
(159507, 11301, 'Que Legal Scooby Doo S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/453349.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9TOzXdkDpJ3ye5ZdanuoVfZOczW.jpg'),
(159508, 11301, 'Que Legal Scooby Doo S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/453350.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fkVCsL9ox8mGHJhYwD4UnV9hKa6.jpg'),
(159509, 11301, 'Que Legal Scooby Doo S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/453351.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/shFn4fXrw8L0QxgZjd1f94mt9mz.jpg'),
(159510, 11301, 'Que Legal Scooby Doo S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/453352.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8G2kRbU7RNdvTrIKEOqD2KQbwjV.jpg'),
(159511, 11301, 'Que Legal Scooby Doo S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/453353.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6iX0gbHXf78OElvU99O1Jyp7oMV.jpg'),
(159512, 11301, 'Que Legal Scooby Doo S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/453354.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJFCyXmtwUDsg06U58avCIkTXh.jpg'),
(159513, 11301, 'Que Legal Scooby Doo S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/453355.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qdrV1Ydk2I8iw0ALuyYroF2ZAmo.jpg'),
(159514, 11301, 'Que Legal Scooby Doo S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/453356.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3GDs6Uf9jJXbgiUcd8kmpyCSh7C.jpg'),
(159515, 11301, 'Que Legal Scooby Doo S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/453357.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/feIxjfNZt6ehh84cDDwTQrI4sT2.jpg'),
(159516, 11301, 'Que Legal Scooby Doo S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/453358.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4kKdawrl1pAFhOESejkmGdnnUWL.jpg'),
(159517, 10037, 'Doc Investigacao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/454037.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8kfkToenvz6TgxiepJWmWJ1b8m.jpg'),
(159518, 10037, 'Doc Investigacao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/454038.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wPLru9UtFzsB6Zy6KS9cyVg3j6p.jpg'),
(159519, 10037, 'Doc Investigacao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/454039.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/em8UOMAUiM0lqPN8uD2qXdyKfqK.jpg'),
(159520, 10037, 'Doc Investigacao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/454040.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pifkLvfAfo8aaKa1Fp0MrDYZ3xh.jpg'),
(159521, 10037, 'Doc Investigacao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/454041.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/swzhRivMdylVCbVSbqy9h90aRwH.jpg'),
(159522, 10037, 'Doc Investigacao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/454042.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3fwf2OeHMgNoWyc8Lv2Tn47l90M.jpg'),
(159523, 10037, 'Doc Investigacao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/454043.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ktakzShOhHsQYSmddSf8ke2UABB.jpg'),
(159524, 10037, 'Doc Investigacao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/454044.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aZF8IhpRGoRIp0jVrenC6WQxwh0.jpg'),
(159525, 10037, 'Doc Investigacao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/454045.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4xmzOGdRhrUb19Ug6hV5tM4DpfG.jpg'),
(159526, 10037, 'Doc Investigacao S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/454046.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rjyhM9zVvqsqYQBfhgDDHF53iDo.jpg'),
(159527, 10037, 'Doc Investigacao S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/454047.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v7qy8L9GExLesTh7AzfZnOOvB5W.jpg'),
(159528, 10037, 'Doc Investigacao S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/454048.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vP02p0eqOsjeOUDaxOx0GE7Y54M.jpg'),
(159529, 11302, 'Doc Investigacao S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/872481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6iTSO0eb17hVnArL4DI7wDRFf7w.jpg'),
(159530, 11302, 'Doc Investigacao S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/874594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6iTSO0eb17hVnArL4DI7wDRFf7w.jpg'),
(159531, 11302, 'Doc Investigacao S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/879041.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6iTSO0eb17hVnArL4DI7wDRFf7w.jpg'),
(159532, 11302, 'Doc Investigacao S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/879995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6iTSO0eb17hVnArL4DI7wDRFf7w.jpg'),
(159533, 11302, 'Doc Investigacao S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/880404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6iTSO0eb17hVnArL4DI7wDRFf7w.jpg'),
(159534, 11302, 'Doc Investigacao S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/881233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6iTSO0eb17hVnArL4DI7wDRFf7w.jpg'),
(159535, 11302, 'Doc Investigacao S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/881342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6iTSO0eb17hVnArL4DI7wDRFf7w.jpg'),
(159536, 11303, 'Inexplicavel Misterios do Universo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/454035.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1r0OwDdy8ueQD6zjRKc3m63uE2v.jpg'),
(159537, 11303, 'Inexplicavel Misterios do Universo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/454036.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iWDaFCJJV7YMa0O6BdkVtf5UNxF.jpg'),
(159538, 11303, 'Inexplicavel Misterios do Universo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/467376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA1nm9dCfmjRmOvuuEK3Th8VYH0.jpg'),
(159539, 11303, 'Inexplicavel Misterios do Universo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/470288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA1nm9dCfmjRmOvuuEK3Th8VYH0.jpg'),
(159540, 11303, 'Inexplicavel Misterios do Universo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/523461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA1nm9dCfmjRmOvuuEK3Th8VYH0.jpg'),
(159541, 11303, 'Inexplicavel Misterios do Universo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/523462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA1nm9dCfmjRmOvuuEK3Th8VYH0.jpg'),
(159542, 11303, 'Inexplicavel Misterios do Universo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/523463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA1nm9dCfmjRmOvuuEK3Th8VYH0.jpg'),
(159543, 11303, 'Inexplicavel Misterios do Universo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/523464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nA1nm9dCfmjRmOvuuEK3Th8VYH0.jpg'),
(159544, 11304, 'Pra Sempre Paquitas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/454030.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uYJe0ZZOm8h6EcLQQcpUG7AFXVU.jpg'),
(159545, 11304, 'Pra Sempre Paquitas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/454031.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dhPpr6FAEmCmjFkrh3NtQrTFwr8.jpg'),
(159546, 11304, 'Pra Sempre Paquitas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/454032.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2zlwxVzcCCvAuElX2ZBJ1dgbgvW.jpg'),
(159547, 11304, 'Pra Sempre Paquitas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/454033.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p1WPnXC4LY2fvYAIk04pCLJEp8W.jpg'),
(159548, 11304, 'Pra Sempre Paquitas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/454034.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ibHjcIQ4aFhEiXms4AWV20TxVbo.jpg'),
(159549, 11305, 'Selena e Yolanda Os Segredos Entre Elas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/454028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8tDzbt1dPmtNLMK7292I1QOk220.jpg'),
(159550, 11305, 'Selena e Yolanda Os Segredos Entre Elas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/454029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8tDzbt1dPmtNLMK7292I1QOk220.jpg'),
(159551, 11306, 'RuPauls Drag Race All Stars [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/454016.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cjAZBatZ7y82Femip8H0Yk3ctyz.jpg'),
(159552, 11306, 'RuPauls Drag Race All Stars [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/454017.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6zToN1mUWoHRu9nh7CdygDZStRP.jpg'),
(159553, 11306, 'RuPauls Drag Race All Stars [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/454018.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rs55Qby9YoGHqA1H8XWBLjUrWQT.jpg'),
(159554, 11306, 'RuPauls Drag Race All Stars [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/454019.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/B349uguxPrikKwSOCfv6LzqLe4.jpg'),
(159555, 11306, 'RuPauls Drag Race All Stars [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/454020.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qXkn7hqEOIOPbtlwyTFfRI9bcwM.jpg'),
(159556, 11306, 'RuPauls Drag Race All Stars [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/454021.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ua1zxuNnF84vSkk2KimzgXdUDJL.jpg'),
(159557, 11307, 'Invejosa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/458763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159558, 11307, 'Invejosa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/458764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159559, 11307, 'Invejosa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/458765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159560, 11307, 'Invejosa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/458766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159561, 11307, 'Invejosa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/458767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159562, 11307, 'Invejosa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/458768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159563, 11307, 'Invejosa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/458769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159564, 11307, 'Invejosa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/458770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159565, 11307, 'Invejosa S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/458771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159566, 11307, 'Invejosa S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/458772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159567, 11307, 'Invejosa S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/458773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159568, 11307, 'Invejosa S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/458774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159569, 11308, 'Invejosa S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/684661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159570, 11308, 'Invejosa S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/684662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159571, 11308, 'Invejosa S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/684663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159572, 11308, 'Invejosa S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/684664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159573, 11308, 'Invejosa S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/684665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159574, 11308, 'Invejosa S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/684666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159575, 11308, 'Invejosa S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/684667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159576, 11308, 'Invejosa S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/684668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159577, 11308, 'Invejosa S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/684669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159578, 11308, 'Invejosa S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/684670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159579, 11308, 'Invejosa S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/684671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159580, 11309, 'Invejosa S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/893121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159581, 11309, 'Invejosa S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/893122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159582, 11309, 'Invejosa S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/893123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159583, 11309, 'Invejosa S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/893124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159584, 11309, 'Invejosa S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/893125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159585, 11309, 'Invejosa S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/893126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159586, 11309, 'Invejosa S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/893127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159587, 11309, 'Invejosa S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/893128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159588, 11309, 'Invejosa S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/893129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159589, 11309, 'Invejosa S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/893130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/as8cTNJrvVc4mRsU6V1f8puPK4X.jpg'),
(159590, 11310, 'O Futuro de Bill Gates S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/458758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/24m1rwOZmb6jXsVrRlwGxf1GOP3.jpg'),
(159591, 11310, 'O Futuro de Bill Gates S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/458759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/24m1rwOZmb6jXsVrRlwGxf1GOP3.jpg'),
(159592, 11310, 'O Futuro de Bill Gates S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/458760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/24m1rwOZmb6jXsVrRlwGxf1GOP3.jpg'),
(159593, 11310, 'O Futuro de Bill Gates S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/458761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/24m1rwOZmb6jXsVrRlwGxf1GOP3.jpg'),
(159594, 11310, 'O Futuro de Bill Gates S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/458762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/24m1rwOZmb6jXsVrRlwGxf1GOP3.jpg'),
(159595, 11311, 'Os 13 Fantasmas do Scooby Doo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/458745.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z6GoXX4PuGJUNTIgxAcguBFQco8.jpg'),
(159596, 11311, 'Os 13 Fantasmas do Scooby Doo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/458746.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tKu3O3AEqW9mlN13P1SF4UzfqNb.jpg'),
(159597, 11311, 'Os 13 Fantasmas do Scooby Doo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/458747.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rsN5WKjMBu0TH2OlEnEp6cGjGvN.jpg'),
(159598, 11311, 'Os 13 Fantasmas do Scooby Doo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/458748.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rrJdYyDaDUgfCPxlu7xM8eCxvdr.jpg'),
(159599, 11311, 'Os 13 Fantasmas do Scooby Doo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/458749.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/18oLLTsKdxUgVJspwmTGq6FZyVA.jpg'),
(159600, 11311, 'Os 13 Fantasmas do Scooby Doo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/458750.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uTKAS2JO3YFsBIyoTSda6PqTN10.jpg'),
(159601, 11311, 'Os 13 Fantasmas do Scooby Doo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/458751.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p4NC8bqqVrQHfJfN2wYr090VQXu.jpg'),
(159602, 11311, 'Os 13 Fantasmas do Scooby Doo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/458752.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rbhuUqI2G6lbQKvSpdRaUDAzIxc.jpg'),
(159603, 11311, 'Os 13 Fantasmas do Scooby Doo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/458753.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fzKER415Zq0ljMEWldEk7efiSmx.jpg'),
(159604, 11311, 'Os 13 Fantasmas do Scooby Doo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/458754.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s9Vk9Yulv2Ar85MzFQw7iempPdw.jpg'),
(159605, 11311, 'Os 13 Fantasmas do Scooby Doo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/458755.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nN4wARqudbLylSqnhJbZ5N2ou4l.jpg'),
(159606, 11311, 'Os 13 Fantasmas do Scooby Doo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/458756.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pEx9NACI0cab54DBm7cRIcVOGlT.jpg'),
(159607, 11311, 'Os 13 Fantasmas do Scooby Doo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/458757.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u7QpDte41SnH4UHI7y29n1Yu8Am.jpg'),
(159608, 11312, 'Unitopia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/458743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9J1of3PcaaYrCkl8vimOJoEB8sM.jpg'),
(159609, 11312, 'Unitopia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/458744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9J1of3PcaaYrCkl8vimOJoEB8sM.jpg'),
(159610, 11313, 'A Casa de Moda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462449.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/KdPBpog0s0FmSXqMGGdrNrT2KX.jpg'),
(159611, 11313, 'A Casa de Moda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462450.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s8xqL3QFqfg4TEfZF0PAZTWvYZ0.jpg'),
(159612, 11313, 'A Casa de Moda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/468396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pZVYs4UQIpCFRLoO8mgZXVr5Yj.jpg'),
(159613, 11313, 'A Casa de Moda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/475385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pZVYs4UQIpCFRLoO8mgZXVr5Yj.jpg'),
(159614, 11313, 'A Casa de Moda S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pZVYs4UQIpCFRLoO8mgZXVr5Yj.jpg'),
(159615, 11313, 'A Casa de Moda S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pZVYs4UQIpCFRLoO8mgZXVr5Yj.jpg'),
(159616, 11313, 'A Casa de Moda S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/491922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pZVYs4UQIpCFRLoO8mgZXVr5Yj.jpg'),
(159617, 11313, 'A Casa de Moda S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/493312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pZVYs4UQIpCFRLoO8mgZXVr5Yj.jpg'),
(159618, 11313, 'A Casa de Moda S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/499349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pZVYs4UQIpCFRLoO8mgZXVr5Yj.jpg'),
(159619, 11313, 'A Casa de Moda S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/501957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2pZVYs4UQIpCFRLoO8mgZXVr5Yj.jpg'),
(159620, 11314, 'A Rainha das Vilas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462444.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pycXzKY8PdiEi6b0y3ZccCwsSzv.jpg'),
(159621, 11314, 'A Rainha das Vilas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462445.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cFRIqlda4kCaIfYk74oEVlTIujw.jpg'),
(159622, 11314, 'A Rainha das Vilas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462446.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7nDYXPpwc08JHqjag9cGjb5WxZc.jpg'),
(159623, 11314, 'A Rainha das Vilas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462447.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n8yobWzNInjZql4FgeDCWo1JKrU.jpg'),
(159624, 11314, 'A Rainha das Vilas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462448.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xahIQtg1vxXhdRRKMx59IFe9inX.jpg'),
(159625, 11315, 'Agatha Desde Sempre S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462442.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3z20ffSwTbEfEKt5gfmx0Rm3ZDR.jpg'),
(159626, 11315, 'Agatha Desde Sempre S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462443.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oLRSJcNLRaLUgVohjcMzFL9ybG7.jpg'),
(159627, 11315, 'Agatha Desde Sempre S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/464827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4TnWiIc9VFqX1HKU4HJ8vNWKHvX.jpg'),
(159628, 11315, 'Agatha Desde Sempre S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/470923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4TnWiIc9VFqX1HKU4HJ8vNWKHvX.jpg'),
(159629, 11315, 'Agatha Desde Sempre S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4TnWiIc9VFqX1HKU4HJ8vNWKHvX.jpg'),
(159630, 11315, 'Agatha Desde Sempre S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/483495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4TnWiIc9VFqX1HKU4HJ8vNWKHvX.jpg'),
(159631, 11315, 'Agatha Desde Sempre S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/491736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4TnWiIc9VFqX1HKU4HJ8vNWKHvX.jpg'),
(159632, 11315, 'Agatha Desde Sempre S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/493135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4TnWiIc9VFqX1HKU4HJ8vNWKHvX.jpg'),
(159633, 11315, 'Agatha Desde Sempre S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/493136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4TnWiIc9VFqX1HKU4HJ8vNWKHvX.jpg'),
(159634, 11316, 'Amor Atras das Grades S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j7GY7jG9qoNMFq4zEIhHvZGBNbh.jpg'),
(159635, 11316, 'Amor Atras das Grades S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j7GY7jG9qoNMFq4zEIhHvZGBNbh.jpg'),
(159636, 11316, 'Amor Atras das Grades S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j7GY7jG9qoNMFq4zEIhHvZGBNbh.jpg'),
(159637, 11316, 'Amor Atras das Grades S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j7GY7jG9qoNMFq4zEIhHvZGBNbh.jpg'),
(159638, 11316, 'Amor Atras das Grades S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j7GY7jG9qoNMFq4zEIhHvZGBNbh.jpg'),
(159639, 11316, 'Amor Atras das Grades S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j7GY7jG9qoNMFq4zEIhHvZGBNbh.jpg'),
(159640, 11316, 'Amor Atras das Grades S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j7GY7jG9qoNMFq4zEIhHvZGBNbh.jpg'),
(159641, 11316, 'Amor Atras das Grades S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j7GY7jG9qoNMFq4zEIhHvZGBNbh.jpg'),
(159642, 11317, 'Amor Atras das Grades S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j7GY7jG9qoNMFq4zEIhHvZGBNbh.jpg'),
(159643, 11317, 'Amor Atras das Grades S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j7GY7jG9qoNMFq4zEIhHvZGBNbh.jpg'),
(159644, 11317, 'Amor Atras das Grades S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j7GY7jG9qoNMFq4zEIhHvZGBNbh.jpg'),
(159645, 11317, 'Amor Atras das Grades S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j7GY7jG9qoNMFq4zEIhHvZGBNbh.jpg'),
(159646, 11317, 'Amor Atras das Grades S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j7GY7jG9qoNMFq4zEIhHvZGBNbh.jpg'),
(159647, 11317, 'Amor Atras das Grades S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j7GY7jG9qoNMFq4zEIhHvZGBNbh.jpg'),
(159648, 11317, 'Amor Atras das Grades S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/468206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j7GY7jG9qoNMFq4zEIhHvZGBNbh.jpg'),
(159649, 11318, 'Amores Mortais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462012.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c9INWOij6SSxPkzfPEjawBBNJPd.jpg'),
(159650, 11318, 'Amores Mortais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462013.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gmVSjfU4jdNA2yEsy53kQU6QmMQ.jpg'),
(159651, 11318, 'Amores Mortais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bgB1aw0QfgidFLVOMbmfxWX6uvw.jpg'),
(159652, 11318, 'Amores Mortais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bgB1aw0QfgidFLVOMbmfxWX6uvw.jpg'),
(159653, 11318, 'Amores Mortais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bgB1aw0QfgidFLVOMbmfxWX6uvw.jpg'),
(159654, 11318, 'Amores Mortais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bgB1aw0QfgidFLVOMbmfxWX6uvw.jpg'),
(159655, 11319, 'Crepusculo dos Deuses S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462420.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3V4oGABJvHEjMh49QRXRHEpJ5Xm.jpg'),
(159656, 11319, 'Crepusculo dos Deuses S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462421.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tWgl2NmRUJk2D7XN0RRHr5ZF6CQ.jpg'),
(159657, 11319, 'Crepusculo dos Deuses S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462422.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zUeqzDwgxiIlHBaKj8tEzvl9nci.jpg'),
(159658, 11319, 'Crepusculo dos Deuses S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462423.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mYL2jKwHIq1hxDMgsmKRZO5RjzQ.jpg'),
(159659, 11319, 'Crepusculo dos Deuses S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462424.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/taPAcml5aiUQLy3dzFbi675QmDx.jpg'),
(159660, 11319, 'Crepusculo dos Deuses S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462425.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/NQiVBHUJoui5MtuKp5OrdtS9e4.jpg'),
(159661, 11319, 'Crepusculo dos Deuses S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462426.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hn7fZxmCIE5pY4e8Mji59FOdXUI.jpg'),
(159662, 11319, 'Crepusculo dos Deuses S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462427.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Q04n54nElkbaaBQoPhPO9xYuaE.jpg'),
(159663, 11320, 'Guerra Culinaria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462416.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Ao3dTEPo6NfgeoHKpGwfBuXlKoJ.jpg'),
(159664, 11320, 'Guerra Culinaria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462417.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gOPinSXEN7E9Ujeu5282JXT9AhO.jpg'),
(159665, 11320, 'Guerra Culinaria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462418.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e8B1dciLDfW94O6GoOL9LN0DbR9.jpg'),
(159666, 11320, 'Guerra Culinaria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462419.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/34R6pfKOZLb0YfEYwS7IN5qreRW.jpg'),
(159667, 11320, 'Guerra Culinaria S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/464338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sFyYG8sS9c1P3lqRDxzIU1VsWc5.jpg'),
(159668, 11320, 'Guerra Culinaria S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/464339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sFyYG8sS9c1P3lqRDxzIU1VsWc5.jpg'),
(159669, 11320, 'Guerra Culinaria S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/464340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sFyYG8sS9c1P3lqRDxzIU1VsWc5.jpg'),
(159670, 11320, 'Guerra Culinaria S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/470320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sFyYG8sS9c1P3lqRDxzIU1VsWc5.jpg'),
(159671, 11320, 'Guerra Culinaria S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/470321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sFyYG8sS9c1P3lqRDxzIU1VsWc5.jpg'),
(159672, 11320, 'Guerra Culinaria S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/470322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sFyYG8sS9c1P3lqRDxzIU1VsWc5.jpg'),
(159673, 11320, 'Guerra Culinaria S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/478060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sFyYG8sS9c1P3lqRDxzIU1VsWc5.jpg'),
(159674, 11320, 'Guerra Culinaria S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/478061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sFyYG8sS9c1P3lqRDxzIU1VsWc5.jpg'),
(159675, 11321, 'Ilha da Tentacao Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0x03SC8P2AzdWUxKYjfkBHszHj.jpg'),
(159676, 11321, 'Ilha da Tentacao Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0x03SC8P2AzdWUxKYjfkBHszHj.jpg'),
(159677, 11321, 'Ilha da Tentacao Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0x03SC8P2AzdWUxKYjfkBHszHj.jpg'),
(159678, 11321, 'Ilha da Tentacao Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0x03SC8P2AzdWUxKYjfkBHszHj.jpg'),
(159679, 11321, 'Ilha da Tentacao Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/467405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0x03SC8P2AzdWUxKYjfkBHszHj.jpg'),
(159680, 11321, 'Ilha da Tentacao Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/467406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0x03SC8P2AzdWUxKYjfkBHszHj.jpg'),
(159681, 11321, 'Ilha da Tentacao Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/467407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0x03SC8P2AzdWUxKYjfkBHszHj.jpg'),
(159682, 11321, 'Ilha da Tentacao Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/474217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0x03SC8P2AzdWUxKYjfkBHszHj.jpg'),
(159683, 11321, 'Ilha da Tentacao Brasil S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/474218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q0x03SC8P2AzdWUxKYjfkBHszHj.jpg'),
(159684, 11322, 'KLASS 95 O Poder da Beleza S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462388.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lXCLRcfke22RstvMsaDtbG4mTkr.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(159685, 11322, 'KLASS 95 O Poder da Beleza S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462389.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vF8QiVQV8wu26dY7SvKgXkNJAxy.jpg'),
(159686, 11322, 'KLASS 95 O Poder da Beleza S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462390.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6kuS9rzA36zs9xQdRYnwHBoA4in.jpg'),
(159687, 11322, 'KLASS 95 O Poder da Beleza S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462391.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8hXGW3dutIoCFavVh0qbcRU320R.jpg'),
(159688, 11322, 'KLASS 95 O Poder da Beleza S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462392.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fqUcgezFQvn3tfOGWy1kW4Fdpwz.jpg'),
(159689, 11322, 'KLASS 95 O Poder da Beleza S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462393.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/elOqoWo9wbve3EfwAcxc4rYLPiu.jpg'),
(159690, 11322, 'KLASS 95 O Poder da Beleza S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462394.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tPw2TUr8JkhsdYqwdviA5cKF7pa.jpg'),
(159691, 11322, 'KLASS 95 O Poder da Beleza S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462395.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ntcBnODBPZeing4F81xosyBPtMW.jpg'),
(159692, 11322, 'KLASS 95 O Poder da Beleza S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462396.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6SdlOsEr74itrtE7FP3hEEC9aUQ.jpg'),
(159693, 11322, 'KLASS 95 O Poder da Beleza S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462397.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m5yQjMcYM9rSAAI6DS8xceWcQj3.jpg'),
(159694, 11322, 'KLASS 95 O Poder da Beleza S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/462398.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xg9zjQXybz9MLLuRGM4IPWDDtvK.jpg'),
(159695, 11322, 'KLASS 95 O Poder da Beleza S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/462399.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3yuodKtGMzw2HaF5F6pcE7hMJiT.jpg'),
(159696, 11322, 'KLASS 95 O Poder da Beleza S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/462400.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vr7KqXFh6ryuQGdEHD0qtDuMvuT.jpg'),
(159697, 11322, 'KLASS 95 O Poder da Beleza S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/462401.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jTycxSRjWeJmw2Dke8WGRYVsqAl.jpg'),
(159698, 11322, 'KLASS 95 O Poder da Beleza S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/462402.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zuxDMrzZzd3iqRtiJdmOgZomNy5.jpg'),
(159699, 11322, 'KLASS 95 O Poder da Beleza S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/462403.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iXw8eEnrCQLRdsarCLvOhb1Thr4.jpg'),
(159700, 11322, 'KLASS 95 O Poder da Beleza S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/462404.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8yHP9OVemk1j4Nne613bgXp3b79.jpg'),
(159701, 11322, 'KLASS 95 O Poder da Beleza S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/462405.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/42iBfQMo110iSqTrTExBJWT61SS.jpg'),
(159702, 11322, 'KLASS 95 O Poder da Beleza S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/462406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159703, 11322, 'KLASS 95 O Poder da Beleza S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/462407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159704, 11322, 'KLASS 95 O Poder da Beleza S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/462408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159705, 11322, 'KLASS 95 O Poder da Beleza S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/462409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159706, 11322, 'KLASS 95 O Poder da Beleza S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/462410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159707, 11322, 'KLASS 95 O Poder da Beleza S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/462411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159708, 11322, 'KLASS 95 O Poder da Beleza S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/679391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159709, 11322, 'KLASS 95 O Poder da Beleza S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/679392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159710, 11322, 'KLASS 95 O Poder da Beleza S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/679393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159711, 11322, 'KLASS 95 O Poder da Beleza S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/679394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159712, 11322, 'KLASS 95 O Poder da Beleza S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/679395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159713, 11322, 'KLASS 95 O Poder da Beleza S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/679396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159714, 11322, 'KLASS 95 O Poder da Beleza S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/679397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159715, 11322, 'KLASS 95 O Poder da Beleza S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/679398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159716, 11322, 'KLASS 95 O Poder da Beleza S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/679399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159717, 11322, 'KLASS 95 O Poder da Beleza S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/679400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159718, 11322, 'KLASS 95 O Poder da Beleza S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/679401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159719, 11322, 'KLASS 95 O Poder da Beleza S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/679402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159720, 11322, 'KLASS 95 O Poder da Beleza S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/679403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159721, 11322, 'KLASS 95 O Poder da Beleza S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/679404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159722, 11322, 'KLASS 95 O Poder da Beleza S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/679405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159723, 11322, 'KLASS 95 O Poder da Beleza S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/679406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159724, 11322, 'KLASS 95 O Poder da Beleza S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/679407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159725, 11322, 'KLASS 95 O Poder da Beleza S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/679408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159726, 11322, 'KLASS 95 O Poder da Beleza S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/679409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159727, 11322, 'KLASS 95 O Poder da Beleza S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/679410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159728, 11322, 'KLASS 95 O Poder da Beleza S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/679411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1yxVcLAZbFJpwqz0kDjm5Tch8FC.jpg'),
(159729, 11323, 'Legado de Sangue S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A4TMARB5An1hyo5dxqkxsePQLMK.jpg'),
(159730, 11323, 'Legado de Sangue S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A4TMARB5An1hyo5dxqkxsePQLMK.jpg'),
(159731, 11323, 'Legado de Sangue S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A4TMARB5An1hyo5dxqkxsePQLMK.jpg'),
(159732, 11323, 'Legado de Sangue S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A4TMARB5An1hyo5dxqkxsePQLMK.jpg'),
(159733, 11323, 'Legado de Sangue S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A4TMARB5An1hyo5dxqkxsePQLMK.jpg'),
(159734, 11323, 'Legado de Sangue S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A4TMARB5An1hyo5dxqkxsePQLMK.jpg'),
(159735, 11323, 'Legado de Sangue S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A4TMARB5An1hyo5dxqkxsePQLMK.jpg'),
(159736, 11323, 'Legado de Sangue S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A4TMARB5An1hyo5dxqkxsePQLMK.jpg'),
(159737, 11323, 'Legado de Sangue S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A4TMARB5An1hyo5dxqkxsePQLMK.jpg'),
(159738, 11323, 'Legado de Sangue S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A4TMARB5An1hyo5dxqkxsePQLMK.jpg'),
(159739, 11323, 'Legado de Sangue S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/462378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A4TMARB5An1hyo5dxqkxsePQLMK.jpg'),
(159740, 11323, 'Legado de Sangue S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/462379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A4TMARB5An1hyo5dxqkxsePQLMK.jpg'),
(159741, 11323, 'Legado de Sangue S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/462380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A4TMARB5An1hyo5dxqkxsePQLMK.jpg'),
(159742, 11323, 'Legado de Sangue S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/462381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A4TMARB5An1hyo5dxqkxsePQLMK.jpg'),
(159743, 11323, 'Legado de Sangue S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/462382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A4TMARB5An1hyo5dxqkxsePQLMK.jpg'),
(159744, 11323, 'Legado de Sangue S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/462383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A4TMARB5An1hyo5dxqkxsePQLMK.jpg'),
(159745, 11323, 'Legado de Sangue S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/462384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A4TMARB5An1hyo5dxqkxsePQLMK.jpg'),
(159746, 11323, 'Legado de Sangue S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/462385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A4TMARB5An1hyo5dxqkxsePQLMK.jpg'),
(159747, 11323, 'Legado de Sangue S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/462386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A4TMARB5An1hyo5dxqkxsePQLMK.jpg'),
(159748, 11323, 'Legado de Sangue S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/462387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A4TMARB5An1hyo5dxqkxsePQLMK.jpg'),
(159749, 11324, 'Monstros Irmaos Menendez Assassinos dos Pais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462359.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oYTTaibqd6H7q7zzY5vlHqlafwQ.jpg'),
(159750, 11324, 'Monstros Irmaos Menendez Assassinos dos Pais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462360.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gSrKEqlikwbR0yYBpUW6xJACMeG.jpg'),
(159751, 11324, 'Monstros Irmaos Menendez Assassinos dos Pais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462361.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uUGrZ30VHHTefHPtL924o23Kojt.jpg'),
(159752, 11324, 'Monstros Irmaos Menendez Assassinos dos Pais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462362.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e8m4rbCrOTNrojoxgyO3UCrVFId.jpg'),
(159753, 11324, 'Monstros Irmaos Menendez Assassinos dos Pais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462363.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a31DnA7efDosiYSuc4CiHQQJIur.jpg'),
(159754, 11324, 'Monstros Irmaos Menendez Assassinos dos Pais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462364.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yMUXiBIV1b4lOgjGyt8ZFw02v8l.jpg'),
(159755, 11324, 'Monstros Irmaos Menendez Assassinos dos Pais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462365.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g8UzJObn9jBpwzapMFlXlX2hmw4.jpg'),
(159756, 11324, 'Monstros Irmaos Menendez Assassinos dos Pais S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462366.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/drUJ4HbpLowYtib79myFBHwjtn8.jpg'),
(159757, 11324, 'Monstros Irmaos Menendez Assassinos dos Pais S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462367.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wum41oH8obN2W0uQ6YZW0ZeOK80.jpg'),
(159758, 11325, 'Monstros Irmaos Menendez Assassinos dos Pais S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/469987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xjFWzcu8LyFnuuHcVSZvVSp04XF.jpg'),
(159759, 11325, 'Monstros Irmaos Menendez Assassinos dos Pais S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/469988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xjFWzcu8LyFnuuHcVSZvVSp04XF.jpg'),
(159760, 11325, 'Monstros Irmaos Menendez Assassinos dos Pais S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/469989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xjFWzcu8LyFnuuHcVSZvVSp04XF.jpg'),
(159761, 11325, 'Monstros Irmaos Menendez Assassinos dos Pais S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/469990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xjFWzcu8LyFnuuHcVSZvVSp04XF.jpg'),
(159762, 11325, 'Monstros Irmaos Menendez Assassinos dos Pais S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/469991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xjFWzcu8LyFnuuHcVSZvVSp04XF.jpg'),
(159763, 11325, 'Monstros Irmaos Menendez Assassinos dos Pais S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/469992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xjFWzcu8LyFnuuHcVSZvVSp04XF.jpg'),
(159764, 11325, 'Monstros Irmaos Menendez Assassinos dos Pais S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/469993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xjFWzcu8LyFnuuHcVSZvVSp04XF.jpg'),
(159765, 11325, 'Monstros Irmaos Menendez Assassinos dos Pais S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/469994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xjFWzcu8LyFnuuHcVSZvVSp04XF.jpg'),
(159766, 11325, 'Monstros Irmaos Menendez Assassinos dos Pais S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/469995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xjFWzcu8LyFnuuHcVSZvVSp04XF.jpg'),
(159767, 11326, 'O Casal da Casa ao Lado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462355.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bbJI8yfKcr38kcNaCPmg7AQwmtS.jpg'),
(159768, 11326, 'O Casal da Casa ao Lado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462356.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lLX8maWZ0NNti5KcVBNjDi7i9gA.jpg'),
(159769, 11326, 'O Casal da Casa ao Lado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462357.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/woDrwGN2wVJJYXlVROnFdCNQJn1.jpg'),
(159770, 11326, 'O Casal da Casa ao Lado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462358.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xnC2GQA802YTmQy8fYzbACVjy36.jpg'),
(159771, 11326, 'O Casal da Casa ao Lado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/793869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Oh6qG4kvl1PrJ0rLeAioyhWZG2.jpg'),
(159772, 11326, 'O Casal da Casa ao Lado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/793870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Oh6qG4kvl1PrJ0rLeAioyhWZG2.jpg'),
(159773, 11327, 'O Casal da Casa ao Lado S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/887562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Oh6qG4kvl1PrJ0rLeAioyhWZG2.jpg'),
(159774, 11327, 'O Casal da Casa ao Lado S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/887563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Oh6qG4kvl1PrJ0rLeAioyhWZG2.jpg'),
(159775, 11327, 'O Casal da Casa ao Lado S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/887564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Oh6qG4kvl1PrJ0rLeAioyhWZG2.jpg'),
(159776, 11327, 'O Casal da Casa ao Lado S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/887565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Oh6qG4kvl1PrJ0rLeAioyhWZG2.jpg'),
(159777, 11327, 'O Casal da Casa ao Lado S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/887566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Oh6qG4kvl1PrJ0rLeAioyhWZG2.jpg'),
(159778, 11327, 'O Casal da Casa ao Lado S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/887740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Oh6qG4kvl1PrJ0rLeAioyhWZG2.jpg'),
(159779, 11328, 'Pinguim S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462354.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ecX4IMGRlKwyq5eZd5sjPxtUTaT.jpg'),
(159780, 11328, 'Pinguim S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/466996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/51OH9I8EnWJvFmHP2Kg2pU7ZIGK.jpg'),
(159781, 11328, 'Pinguim S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/472700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/51OH9I8EnWJvFmHP2Kg2pU7ZIGK.jpg'),
(159782, 11328, 'Pinguim S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/476015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/51OH9I8EnWJvFmHP2Kg2pU7ZIGK.jpg'),
(159783, 11328, 'Pinguim S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/488423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/51OH9I8EnWJvFmHP2Kg2pU7ZIGK.jpg'),
(159784, 11328, 'Pinguim S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/493496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/51OH9I8EnWJvFmHP2Kg2pU7ZIGK.jpg'),
(159785, 11328, 'Pinguim S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/496345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/51OH9I8EnWJvFmHP2Kg2pU7ZIGK.jpg'),
(159786, 11328, 'Pinguim S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/503028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/51OH9I8EnWJvFmHP2Kg2pU7ZIGK.jpg'),
(159787, 11329, 'Jorels Brother Shostners Show S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/463350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/498HtBtKEhvVbS9VoUQI3fxP1xG.jpg'),
(159788, 11329, 'Jorels Brother Shostners Show S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/463351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/498HtBtKEhvVbS9VoUQI3fxP1xG.jpg'),
(159789, 11329, 'Jorels Brother Shostners Show S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/463352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/498HtBtKEhvVbS9VoUQI3fxP1xG.jpg'),
(159790, 11329, 'Jorels Brother Shostners Show S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/463353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/498HtBtKEhvVbS9VoUQI3fxP1xG.jpg'),
(159791, 11330, 'Leo Batista A Voz Marcante S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/463346.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6BHv7p4IoMx4lxWMa799GTpW2Q5.jpg'),
(159792, 11330, 'Leo Batista A Voz Marcante S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/463347.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sQKId4YwaYvfDej6tbE0uqxGGog.jpg'),
(159793, 11330, 'Leo Batista A Voz Marcante S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/463348.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/asqrVQSL2q84opNijkRbxE4ei2X.jpg'),
(159794, 11330, 'Leo Batista A Voz Marcante S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/463349.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1FtaLkdgjYSs3V7EFwUMI9PD7Sk.jpg'),
(159795, 11331, 'Mutiny O Hotel da Cocaina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/463000.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kxl3QnMJUz8HKH71eJTlydLHYTy.jpg'),
(159796, 11331, 'Mutiny O Hotel da Cocaina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/463001.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wWSoR2Cx7vYV5PayR0WRX5cUKDN.jpg'),
(159797, 11331, 'Mutiny O Hotel da Cocaina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/463002.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e05H0xv6muKIh9W3CNXBwQLV5lJ.jpg'),
(159798, 11331, 'Mutiny O Hotel da Cocaina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/469977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oOddX9xEcse5SbywRDy1gtEfLAB.jpg'),
(159799, 11331, 'Mutiny O Hotel da Cocaina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/477522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oOddX9xEcse5SbywRDy1gtEfLAB.jpg'),
(159800, 11331, 'Mutiny O Hotel da Cocaina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/482681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oOddX9xEcse5SbywRDy1gtEfLAB.jpg'),
(159801, 11331, 'Mutiny O Hotel da Cocaina S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/490792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oOddX9xEcse5SbywRDy1gtEfLAB.jpg'),
(159802, 11331, 'Mutiny O Hotel da Cocaina S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/492260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oOddX9xEcse5SbywRDy1gtEfLAB.jpg'),
(159803, 11332, 'My Brilliant Friend S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462973.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tUGbW8KWekx23C8qgORoBwKSbuQ.jpg'),
(159804, 11332, 'My Brilliant Friend S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462974.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hdi3agsucOB33obbPJn4pTxzaeW.jpg'),
(159805, 11332, 'My Brilliant Friend S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462975.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hOiqU6NNztlm6S8CSDvOuZx5Frf.jpg'),
(159806, 11332, 'My Brilliant Friend S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462976.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ubfbIhZUUnT2pVT8mIBrCzzDRkq.jpg'),
(159807, 11332, 'My Brilliant Friend S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462977.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bA4HJkqtIn8wjjLPm7tVH4qO2JW.jpg'),
(159808, 11332, 'My Brilliant Friend S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462978.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jdCQ2UNM1RkcoZgRnYvPPp22oEM.jpg'),
(159809, 11332, 'My Brilliant Friend S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462979.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7mFCsJDEKRP8zo5wfHdsLIFs3Rg.jpg'),
(159810, 11332, 'My Brilliant Friend S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462980.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rN5tN0vUhNc6tMa7yalbLGHsd2e.jpg'),
(159811, 11333, 'My Brilliant Friend S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462981.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iZAU431mqxaNl4DmWe0r83Jedzv.jpg'),
(159812, 11333, 'My Brilliant Friend S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462982.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/blzpz0Jzo8wo2R3IWAY7D0m3isN.jpg'),
(159813, 11333, 'My Brilliant Friend S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462983.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7Hjgc0DXQijHYWlDVYDF0CtnVbO.jpg'),
(159814, 11333, 'My Brilliant Friend S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462984.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sYrPHcPLyQbHksYZSxZZPeKwq9L.jpg'),
(159815, 11333, 'My Brilliant Friend S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462985.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/71EzxB0PH9tcPHrzhDMyp1G5kfZ.jpg'),
(159816, 11333, 'My Brilliant Friend S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462986.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ehmkvHxqyuikWaKwpcM1LXTMh0q.jpg'),
(159817, 11333, 'My Brilliant Friend S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462987.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6aVVbUNIxpthR8uggSQJ5ZPvQno.jpg'),
(159818, 11333, 'My Brilliant Friend S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462988.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/js24sgkbgQlP6DXvrpKjPYgtztc.jpg'),
(159819, 11334, 'My Brilliant Friend S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462989.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pZmZODebSAdHVylmmkngdksl2hy.jpg'),
(159820, 11334, 'My Brilliant Friend S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462990.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2pFfP2bO49IDhvKxPaYteOhUvKY.jpg'),
(159821, 11334, 'My Brilliant Friend S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462991.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xc3Ggm5oAlW7675R07nfUlk74Aa.jpg'),
(159822, 11334, 'My Brilliant Friend S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462992.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nmEN0RYYp6cbdkXko1AZOeWG7MJ.jpg'),
(159823, 11334, 'My Brilliant Friend S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462993.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3dsnuSUE2x7Y7cTzCB7qNgnYcN4.jpg'),
(159824, 11334, 'My Brilliant Friend S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462994.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k07k7wNnmQhNNLpLV1tcqpiiif0.jpg'),
(159825, 11334, 'My Brilliant Friend S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462995.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y2gp1rsQZ3BoDUxej9WCqkFIacb.jpg'),
(159826, 11334, 'My Brilliant Friend S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462996.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hnYvivn12MdTaOgaKzs54ihh9KI.jpg'),
(159827, 11335, 'My Brilliant Friend S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462997.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ek7vrRhme7kXv12hejc0dm2u8cw.jpg'),
(159828, 11335, 'My Brilliant Friend S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462998.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fBqyk8pJk2epBv01Lhpe7JOALp2.jpg'),
(159829, 11335, 'My Brilliant Friend S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gt445Sc1zybQe7f1NqQrBV9YxiA.jpg'),
(159830, 11335, 'My Brilliant Friend S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/477516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gt445Sc1zybQe7f1NqQrBV9YxiA.jpg'),
(159831, 11335, 'My Brilliant Friend S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/477517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gt445Sc1zybQe7f1NqQrBV9YxiA.jpg'),
(159832, 11335, 'My Brilliant Friend S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/492250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gt445Sc1zybQe7f1NqQrBV9YxiA.jpg'),
(159833, 11335, 'My Brilliant Friend S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/492251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gt445Sc1zybQe7f1NqQrBV9YxiA.jpg'),
(159834, 11335, 'My Brilliant Friend S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/492252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gt445Sc1zybQe7f1NqQrBV9YxiA.jpg'),
(159835, 11335, 'My Brilliant Friend S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/505549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gt445Sc1zybQe7f1NqQrBV9YxiA.jpg'),
(159836, 11335, 'My Brilliant Friend S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/505550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gt445Sc1zybQe7f1NqQrBV9YxiA.jpg'),
(159837, 11336, 'OUT THERE Crimes of the Paranormal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eF1WJYz7FakLYnJb29IFXp2tqKz.jpg'),
(159838, 11336, 'OUT THERE Crimes of the Paranormal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eF1WJYz7FakLYnJb29IFXp2tqKz.jpg'),
(159839, 11336, 'OUT THERE Crimes of the Paranormal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eF1WJYz7FakLYnJb29IFXp2tqKz.jpg'),
(159840, 11336, 'OUT THERE Crimes of the Paranormal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eF1WJYz7FakLYnJb29IFXp2tqKz.jpg'),
(159841, 11336, 'OUT THERE Crimes of the Paranormal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eF1WJYz7FakLYnJb29IFXp2tqKz.jpg'),
(159842, 11336, 'OUT THERE Crimes of the Paranormal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eF1WJYz7FakLYnJb29IFXp2tqKz.jpg'),
(159843, 11336, 'OUT THERE Crimes of the Paranormal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eF1WJYz7FakLYnJb29IFXp2tqKz.jpg'),
(159844, 11336, 'OUT THERE Crimes of the Paranormal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eF1WJYz7FakLYnJb29IFXp2tqKz.jpg'),
(159845, 11337, 'A Vida Secreta das Esposas Mormons [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462957.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xQOed88zn7mCsAlGr0TeP4J0r2c.jpg'),
(159846, 11337, 'A Vida Secreta das Esposas Mormons [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462958.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4pqioa4maQlM7z7J5oilTvR7A0S.jpg'),
(159847, 11337, 'A Vida Secreta das Esposas Mormons [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462959.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/59w9xiXWnspxdgoGmP5neAhiiUl.jpg'),
(159848, 11337, 'A Vida Secreta das Esposas Mormons [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462960.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5pyOl8rZaehs3lauA4jVBX8OMnr.jpg'),
(159849, 11337, 'A Vida Secreta das Esposas Mormons [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462961.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/71Qn8msGHclb2UMfTXhAFIAxyfQ.jpg'),
(159850, 11337, 'A Vida Secreta das Esposas Mormons [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462962.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bhGLtbSzgLwhCYfAoCyVnQMp0IE.jpg'),
(159851, 11337, 'A Vida Secreta das Esposas Mormons [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462963.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5bKPL3ueHfbLfb5V0cMXUUULJjc.jpg'),
(159852, 11337, 'A Vida Secreta das Esposas Mormons [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462964.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wBAk7PxqtjMqThIEGKFwNM7PjW0.jpg'),
(159853, 11338, 'A Vida Secreta das Esposas Mormons [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/863563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2AczClE0HMjsIk1VcJcGUebwODA.jpg'),
(159854, 11338, 'A Vida Secreta das Esposas Mormons [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/863564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2AczClE0HMjsIk1VcJcGUebwODA.jpg'),
(159855, 11338, 'A Vida Secreta das Esposas Mormons [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/863565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2AczClE0HMjsIk1VcJcGUebwODA.jpg'),
(159856, 11338, 'A Vida Secreta das Esposas Mormons [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/863566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2AczClE0HMjsIk1VcJcGUebwODA.jpg'),
(159857, 11338, 'A Vida Secreta das Esposas Mormons [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/863567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2AczClE0HMjsIk1VcJcGUebwODA.jpg'),
(159858, 11338, 'A Vida Secreta das Esposas Mormons [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/863568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2AczClE0HMjsIk1VcJcGUebwODA.jpg'),
(159859, 11338, 'A Vida Secreta das Esposas Mormons [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/863569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2AczClE0HMjsIk1VcJcGUebwODA.jpg'),
(159860, 11338, 'A Vida Secreta das Esposas Mormons [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/863570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2AczClE0HMjsIk1VcJcGUebwODA.jpg'),
(159861, 11338, 'A Vida Secreta das Esposas Mormons [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/863571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2AczClE0HMjsIk1VcJcGUebwODA.jpg'),
(159862, 11338, 'A Vida Secreta das Esposas Mormons [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/863572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2AczClE0HMjsIk1VcJcGUebwODA.jpg'),
(159863, 11339, 'A Vida Secreta das Esposas Mormons [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/894182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2AczClE0HMjsIk1VcJcGUebwODA.jpg'),
(159864, 11340, 'A Vinganca da Branca de Neve [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159865, 11340, 'A Vinganca da Branca de Neve [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159866, 11340, 'A Vinganca da Branca de Neve [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159867, 11340, 'A Vinganca da Branca de Neve [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159868, 11340, 'A Vinganca da Branca de Neve [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159869, 11340, 'A Vinganca da Branca de Neve [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159870, 11340, 'A Vinganca da Branca de Neve [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159871, 11340, 'A Vinganca da Branca de Neve [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159872, 11340, 'A Vinganca da Branca de Neve [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159873, 11340, 'A Vinganca da Branca de Neve [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159874, 11340, 'A Vinganca da Branca de Neve [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/462913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159875, 11340, 'A Vinganca da Branca de Neve [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/462914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159876, 11340, 'A Vinganca da Branca de Neve [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/462915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159877, 11340, 'A Vinganca da Branca de Neve [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/462916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159878, 11340, 'A Vinganca da Branca de Neve [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/462917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159879, 11340, 'A Vinganca da Branca de Neve [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/462918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159880, 11340, 'A Vinganca da Branca de Neve [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/462919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159881, 11340, 'A Vinganca da Branca de Neve [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/462920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159882, 11340, 'A Vinganca da Branca de Neve [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/462921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159883, 11340, 'A Vinganca da Branca de Neve [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/462922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159884, 11340, 'A Vinganca da Branca de Neve [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/462923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159885, 11340, 'A Vinganca da Branca de Neve [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/462924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159886, 11340, 'A Vinganca da Branca de Neve [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/462925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159887, 11340, 'A Vinganca da Branca de Neve [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/462926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159888, 11340, 'A Vinganca da Branca de Neve [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/462927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159889, 11340, 'A Vinganca da Branca de Neve [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/462928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159890, 11340, 'A Vinganca da Branca de Neve [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/462929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159891, 11340, 'A Vinganca da Branca de Neve [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/462930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159892, 11340, 'A Vinganca da Branca de Neve [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/462931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159893, 11340, 'A Vinganca da Branca de Neve [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/462932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159894, 11340, 'A Vinganca da Branca de Neve [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/462933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159895, 11340, 'A Vinganca da Branca de Neve [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/462934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159896, 11340, 'A Vinganca da Branca de Neve [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/462935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159897, 11340, 'A Vinganca da Branca de Neve [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/462936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159898, 11340, 'A Vinganca da Branca de Neve [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/462937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159899, 11340, 'A Vinganca da Branca de Neve [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/462938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159900, 11340, 'A Vinganca da Branca de Neve [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/462939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159901, 11340, 'A Vinganca da Branca de Neve [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/462940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159902, 11340, 'A Vinganca da Branca de Neve [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/462941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159903, 11340, 'A Vinganca da Branca de Neve [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/462942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159904, 11340, 'A Vinganca da Branca de Neve [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/462943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159905, 11340, 'A Vinganca da Branca de Neve [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/462944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159906, 11340, 'A Vinganca da Branca de Neve [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/462945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159907, 11340, 'A Vinganca da Branca de Neve [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/462946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159908, 11340, 'A Vinganca da Branca de Neve [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/462947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159909, 11340, 'A Vinganca da Branca de Neve [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/462948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159910, 11340, 'A Vinganca da Branca de Neve [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/462949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159911, 11340, 'A Vinganca da Branca de Neve [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/462950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159912, 11340, 'A Vinganca da Branca de Neve [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/462951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159913, 11340, 'A Vinganca da Branca de Neve [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/462952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159914, 11340, 'A Vinganca da Branca de Neve [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/462953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159915, 11340, 'A Vinganca da Branca de Neve [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/462954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159916, 11340, 'A Vinganca da Branca de Neve [L] S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/462955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159917, 11340, 'A Vinganca da Branca de Neve [L] S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/462956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159918, 11340, 'A Vinganca da Branca de Neve [L] S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/468334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159919, 11340, 'A Vinganca da Branca de Neve [L] S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/468335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159920, 11340, 'A Vinganca da Branca de Neve [L] S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/468336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159921, 11340, 'A Vinganca da Branca de Neve [L] S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/468337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159922, 11340, 'A Vinganca da Branca de Neve [L] S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/468338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159923, 11340, 'A Vinganca da Branca de Neve [L] S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/468339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159924, 11340, 'A Vinganca da Branca de Neve [L] S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/470984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159925, 11340, 'A Vinganca da Branca de Neve [L] S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/470985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159926, 11340, 'A Vinganca da Branca de Neve [L] S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/470986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159927, 11340, 'A Vinganca da Branca de Neve [L] S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/475362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159928, 11340, 'A Vinganca da Branca de Neve [L] S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/475363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159929, 11340, 'A Vinganca da Branca de Neve [L] S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/479208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(159930, 11340, 'A Vinganca da Branca de Neve [L] S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/479209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159931, 11340, 'A Vinganca da Branca de Neve [L] S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/483563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159932, 11340, 'A Vinganca da Branca de Neve [L] S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/483564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159933, 11340, 'A Vinganca da Branca de Neve [L] S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/486006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159934, 11340, 'A Vinganca da Branca de Neve [L] S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/486008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159935, 11340, 'A Vinganca da Branca de Neve [L] S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/486010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159936, 11340, 'A Vinganca da Branca de Neve [L] S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/491811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159937, 11340, 'A Vinganca da Branca de Neve [L] S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/491812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159938, 11340, 'A Vinganca da Branca de Neve [L] S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/491813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159939, 11340, 'A Vinganca da Branca de Neve [L] S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/493214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159940, 11340, 'A Vinganca da Branca de Neve [L] S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/493215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159941, 11340, 'A Vinganca da Branca de Neve [L] S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/493216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159942, 11340, 'A Vinganca da Branca de Neve [L] S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/493217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159943, 11340, 'A Vinganca da Branca de Neve [L] S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/497211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159944, 11340, 'A Vinganca da Branca de Neve [L] S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/631511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159945, 11340, 'A Vinganca da Branca de Neve [L] S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/499263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159946, 11340, 'A Vinganca da Branca de Neve [L] S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/499264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159947, 11340, 'A Vinganca da Branca de Neve [L] S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/499265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159948, 11340, 'A Vinganca da Branca de Neve [L] S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/501862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159949, 11340, 'A Vinganca da Branca de Neve [L] S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/501863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159950, 11340, 'A Vinganca da Branca de Neve [L] S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/501864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159951, 11340, 'A Vinganca da Branca de Neve [L] S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/501865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159952, 11340, 'A Vinganca da Branca de Neve [L] S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/501866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159953, 11340, 'A Vinganca da Branca de Neve [L] S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/501867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159954, 11340, 'A Vinganca da Branca de Neve [L] S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/519169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159955, 11340, 'A Vinganca da Branca de Neve [L] S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/519170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159956, 11340, 'A Vinganca da Branca de Neve [L] S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/519171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159957, 11340, 'A Vinganca da Branca de Neve [L] S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/519172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159958, 11340, 'A Vinganca da Branca de Neve [L] S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/519173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159959, 11340, 'A Vinganca da Branca de Neve [L] S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/519174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159960, 11340, 'A Vinganca da Branca de Neve [L] S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/519175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159961, 11340, 'A Vinganca da Branca de Neve [L] S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/519176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159962, 11340, 'A Vinganca da Branca de Neve [L] S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/519177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159963, 11340, 'A Vinganca da Branca de Neve [L] S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/519178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159964, 11340, 'A Vinganca da Branca de Neve [L] S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/519179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rw2sfFQshJDMPCI8QzBy1EfwP1.jpg'),
(159965, 11341, 'Desvendando a America Central [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462901.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jvi1uIewClEBaNMhkh6tq2BBJYq.jpg'),
(159966, 11341, 'Desvendando a America Central [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462902.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eqe5oa9aVi0VuKXfsd7UKNAUQo8.jpg'),
(159967, 11342, 'Fragil [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wicas3qiqhZlENFUEDCYSWemoQz.jpg'),
(159968, 11342, 'Fragil [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wicas3qiqhZlENFUEDCYSWemoQz.jpg'),
(159969, 11342, 'Fragil [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wicas3qiqhZlENFUEDCYSWemoQz.jpg'),
(159970, 11342, 'Fragil [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/485359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wicas3qiqhZlENFUEDCYSWemoQz.jpg'),
(159971, 11342, 'Fragil [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/485360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wicas3qiqhZlENFUEDCYSWemoQz.jpg'),
(159972, 11342, 'Fragil [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/492805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wicas3qiqhZlENFUEDCYSWemoQz.jpg'),
(159973, 11342, 'Fragil [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/492806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wicas3qiqhZlENFUEDCYSWemoQz.jpg'),
(159974, 11342, 'Fragil [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/492807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wicas3qiqhZlENFUEDCYSWemoQz.jpg'),
(159975, 11343, 'Historia Esportiva Americana [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462896.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7KNyJ2qd2nmn30mk65gmwqmoXd7.jpg'),
(159976, 11343, 'Historia Esportiva Americana [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462897.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kfg4hXvbqclRDmARQiLRvZHVKHM.jpg'),
(159977, 11344, 'Imoveis de Luxo Sydney [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/248D1YA4UsIucTxQZ5V7iQ8R84r.jpg'),
(159978, 11344, 'Imoveis de Luxo Sydney [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/248D1YA4UsIucTxQZ5V7iQ8R84r.jpg'),
(159979, 11344, 'Imoveis de Luxo Sydney [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/248D1YA4UsIucTxQZ5V7iQ8R84r.jpg'),
(159980, 11344, 'Imoveis de Luxo Sydney [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/248D1YA4UsIucTxQZ5V7iQ8R84r.jpg'),
(159981, 11344, 'Imoveis de Luxo Sydney [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/248D1YA4UsIucTxQZ5V7iQ8R84r.jpg'),
(159982, 11344, 'Imoveis de Luxo Sydney [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/248D1YA4UsIucTxQZ5V7iQ8R84r.jpg'),
(159983, 11345, 'Imoveis de Luxo Sydney [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/248D1YA4UsIucTxQZ5V7iQ8R84r.jpg'),
(159984, 11345, 'Imoveis de Luxo Sydney [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/248D1YA4UsIucTxQZ5V7iQ8R84r.jpg'),
(159985, 11345, 'Imoveis de Luxo Sydney [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/248D1YA4UsIucTxQZ5V7iQ8R84r.jpg'),
(159986, 11345, 'Imoveis de Luxo Sydney [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/248D1YA4UsIucTxQZ5V7iQ8R84r.jpg'),
(159987, 11345, 'Imoveis de Luxo Sydney [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/248D1YA4UsIucTxQZ5V7iQ8R84r.jpg'),
(159988, 11345, 'Imoveis de Luxo Sydney [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/248D1YA4UsIucTxQZ5V7iQ8R84r.jpg'),
(159989, 11346, 'Imoveis de Luxo Sydney [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462890.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i19GicffwcLS2GDr0paRyUawnGR.jpg'),
(159990, 11346, 'Imoveis de Luxo Sydney [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462891.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pYxd2oQVbxM7gKg6VaLaUT9YUbc.jpg'),
(159991, 11346, 'Imoveis de Luxo Sydney [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462892.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/utKfPl8B9rFsJPC4oRGZXufmJxC.jpg'),
(159992, 11346, 'Imoveis de Luxo Sydney [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462893.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/50ghTTtjJJCcbw2qyWjCgkGPWA9.jpg'),
(159993, 11346, 'Imoveis de Luxo Sydney [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/248D1YA4UsIucTxQZ5V7iQ8R84r.jpg'),
(159994, 11346, 'Imoveis de Luxo Sydney [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/248D1YA4UsIucTxQZ5V7iQ8R84r.jpg'),
(159995, 11347, 'Kamen Rider Gavv [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(159996, 11347, 'Kamen Rider Gavv [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(159997, 11347, 'Kamen Rider Gavv [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(159998, 11347, 'Kamen Rider Gavv [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(159999, 11347, 'Kamen Rider Gavv [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/485239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160000, 11347, 'Kamen Rider Gavv [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/485240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160001, 11347, 'Kamen Rider Gavv [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/485241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160002, 11347, 'Kamen Rider Gavv [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/491245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160003, 11347, 'Kamen Rider Gavv [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/492734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160004, 11347, 'Kamen Rider Gavv [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/503281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160005, 11347, 'Kamen Rider Gavv [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/511879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160006, 11347, 'Kamen Rider Gavv [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/511880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160007, 11347, 'Kamen Rider Gavv [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/518018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160008, 11347, 'Kamen Rider Gavv [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/523378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160009, 11347, 'Kamen Rider Gavv [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/637154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160010, 11347, 'Kamen Rider Gavv [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/640980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160011, 11347, 'Kamen Rider Gavv [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/662242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160012, 11347, 'Kamen Rider Gavv [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/668689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160013, 11347, 'Kamen Rider Gavv [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/672047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160014, 11347, 'Kamen Rider Gavv [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/675603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160015, 11347, 'Kamen Rider Gavv [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/686203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160016, 11347, 'Kamen Rider Gavv [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/692377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160017, 11347, 'Kamen Rider Gavv [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/701636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160018, 11347, 'Kamen Rider Gavv [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/709044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160019, 11347, 'Kamen Rider Gavv [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/718035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160020, 11347, 'Kamen Rider Gavv [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/727570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160021, 11347, 'Kamen Rider Gavv [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/742379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160022, 11347, 'Kamen Rider Gavv [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/754912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160023, 11347, 'Kamen Rider Gavv [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/766663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160024, 11347, 'Kamen Rider Gavv [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/766664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160025, 11347, 'Kamen Rider Gavv [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/775724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160026, 11347, 'Kamen Rider Gavv [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/784995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160027, 11347, 'Kamen Rider Gavv [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/788513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160028, 11347, 'Kamen Rider Gavv [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/811020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160029, 11347, 'Kamen Rider Gavv [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/819866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160030, 11347, 'Kamen Rider Gavv [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/826635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160031, 11347, 'Kamen Rider Gavv [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/832155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160032, 11347, 'Kamen Rider Gavv [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/842435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160033, 11347, 'Kamen Rider Gavv [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/849403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160034, 11347, 'Kamen Rider Gavv [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/856633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160035, 11347, 'Kamen Rider Gavv [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/863520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160036, 11347, 'Kamen Rider Gavv [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/869429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160037, 11347, 'Kamen Rider Gavv [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/872011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160038, 11347, 'Kamen Rider Gavv [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/876455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160039, 11347, 'Kamen Rider Gavv [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/879571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160040, 11347, 'Kamen Rider Gavv [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/880033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160041, 11347, 'Kamen Rider Gavv [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/881148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160042, 11347, 'Kamen Rider Gavv [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/881882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160043, 11347, 'Kamen Rider Gavv [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/881883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3iHHmX7txgjptGkdqY3Q6V0r0Fk.jpg'),
(160044, 11348, 'Kidnap [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462871.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rPewvyUTaJpoCpsYrENuq0dLjwh.jpg'),
(160045, 11348, 'Kidnap [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462872.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uqPgilK1FQMXKLFtC5YduGMAmKT.jpg'),
(160046, 11348, 'Kidnap [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462873.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yBydDFgsYpFMKveCoqXBDdZC0Po.jpg'),
(160047, 11348, 'Kidnap [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/485233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ciJXZ9lfBHaNRxKyEjF5QpHPkRI.jpg'),
(160048, 11348, 'Kidnap [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/485234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ciJXZ9lfBHaNRxKyEjF5QpHPkRI.jpg'),
(160049, 11348, 'Kidnap [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/509375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ciJXZ9lfBHaNRxKyEjF5QpHPkRI.jpg'),
(160050, 11348, 'Kidnap [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/509376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ciJXZ9lfBHaNRxKyEjF5QpHPkRI.jpg'),
(160051, 11348, 'Kidnap [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/509377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ciJXZ9lfBHaNRxKyEjF5QpHPkRI.jpg'),
(160052, 11348, 'Kidnap [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/509378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ciJXZ9lfBHaNRxKyEjF5QpHPkRI.jpg'),
(160053, 11348, 'Kidnap [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/509379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ciJXZ9lfBHaNRxKyEjF5QpHPkRI.jpg'),
(160054, 11349, 'Mais Top [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462861.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7SXLbrX4id9ZaiOdbQ7qqIQ49Ed.jpg'),
(160055, 11349, 'Mais Top [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462862.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wHOOq4P8f6EhTuO37rYTHSjuLny.jpg'),
(160056, 11349, 'Mais Top [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462863.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ap1tfeuGRCi8JYDhZJnZij5Epg7.jpg'),
(160057, 11349, 'Mais Top [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462864.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n5ATP2dNwaOfO2jxLmHiGQMtVfu.jpg'),
(160058, 11349, 'Mais Top [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462865.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9NZWimxv5p2WvlLwqfLggv4kNTl.jpg'),
(160059, 11349, 'Mais Top [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462866.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y6uwi6fsHIDyDHg87nJydYwCVbA.jpg'),
(160060, 11349, 'Mais Top [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462867.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yaDNGAVGyTPoyNuXjnmnHSJQV3D.jpg'),
(160061, 11349, 'Mais Top [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462868.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8EIoqd1oWq4dOo3c4CsOWeXmC0u.jpg'),
(160062, 11349, 'Mais Top [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462869.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kwbdGgO80cKDYyd4UlHxWb01B5y.jpg'),
(160063, 11349, 'Mais Top [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462870.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/okoxFMsdvAe7V7RCyDky1RUNwms.jpg'),
(160064, 11350, 'Medico Legista Dr. Qin [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cst30i24dZKO9C7iGOBBms23x3A.jpg'),
(160065, 11350, 'Medico Legista Dr. Qin [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cst30i24dZKO9C7iGOBBms23x3A.jpg'),
(160066, 11350, 'Medico Legista Dr. Qin [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cst30i24dZKO9C7iGOBBms23x3A.jpg'),
(160067, 11350, 'Medico Legista Dr. Qin [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cst30i24dZKO9C7iGOBBms23x3A.jpg'),
(160068, 11350, 'Medico Legista Dr. Qin [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cst30i24dZKO9C7iGOBBms23x3A.jpg'),
(160069, 11350, 'Medico Legista Dr. Qin [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cst30i24dZKO9C7iGOBBms23x3A.jpg'),
(160070, 11350, 'Medico Legista Dr. Qin [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cst30i24dZKO9C7iGOBBms23x3A.jpg'),
(160071, 11350, 'Medico Legista Dr. Qin [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cst30i24dZKO9C7iGOBBms23x3A.jpg'),
(160072, 11350, 'Medico Legista Dr. Qin [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cst30i24dZKO9C7iGOBBms23x3A.jpg'),
(160073, 11350, 'Medico Legista Dr. Qin [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cst30i24dZKO9C7iGOBBms23x3A.jpg'),
(160074, 11350, 'Medico Legista Dr. Qin [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/462851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cst30i24dZKO9C7iGOBBms23x3A.jpg'),
(160075, 11350, 'Medico Legista Dr. Qin [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/462852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cst30i24dZKO9C7iGOBBms23x3A.jpg'),
(160076, 11350, 'Medico Legista Dr. Qin [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/462853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cst30i24dZKO9C7iGOBBms23x3A.jpg'),
(160077, 11350, 'Medico Legista Dr. Qin [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/462854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cst30i24dZKO9C7iGOBBms23x3A.jpg'),
(160078, 11350, 'Medico Legista Dr. Qin [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/462855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cst30i24dZKO9C7iGOBBms23x3A.jpg'),
(160079, 11350, 'Medico Legista Dr. Qin [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/462856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cst30i24dZKO9C7iGOBBms23x3A.jpg'),
(160080, 11350, 'Medico Legista Dr. Qin [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/462857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cst30i24dZKO9C7iGOBBms23x3A.jpg'),
(160081, 11350, 'Medico Legista Dr. Qin [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/462858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cst30i24dZKO9C7iGOBBms23x3A.jpg'),
(160082, 11350, 'Medico Legista Dr. Qin [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/462859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cst30i24dZKO9C7iGOBBms23x3A.jpg'),
(160083, 11350, 'Medico Legista Dr. Qin [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/462860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cst30i24dZKO9C7iGOBBms23x3A.jpg'),
(160084, 11351, 'O Professor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462836.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jGzMXDqPWkjQUbXM8Z5q3K8QzZN.jpg'),
(160085, 11351, 'O Professor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462837.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lZqiaNnRnG0TiWLtnPNzWX1Tk8y.jpg'),
(160086, 11351, 'O Professor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462838.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2x6nxrkyYeeT7Ie6jrVDP1uCFhF.jpg'),
(160087, 11351, 'O Professor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462839.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yiY3sHIYgNnuUfTy7N2AKjzSJxX.jpg'),
(160088, 11351, 'O Professor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462840.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5ZgUnrNNLya39s5Ed0dIdKMMSmi.jpg'),
(160089, 11352, 'Os 43 de Ayotzinapa Crime de Estado [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462832.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iaPopc1zyjnpOrxE7AM5qGZKj4Z.jpg'),
(160090, 11352, 'Os 43 de Ayotzinapa Crime de Estado [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462833.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kWpWnk2ofpZELMah7Kg5Z2YYf1P.jpg'),
(160091, 11352, 'Os 43 de Ayotzinapa Crime de Estado [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wC1AO8rjQcn8RrSS9svGbsIQ4DD.jpg'),
(160092, 11352, 'Os 43 de Ayotzinapa Crime de Estado [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wC1AO8rjQcn8RrSS9svGbsIQ4DD.jpg'),
(160093, 11352, 'Os 43 de Ayotzinapa Crime de Estado [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/488428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wC1AO8rjQcn8RrSS9svGbsIQ4DD.jpg'),
(160094, 11353, 'RuPauls Drag Race Global All Stars [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462825.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7Frui4pDOJlIMmiOaLxoqTQ70yO.jpg'),
(160095, 11353, 'RuPauls Drag Race Global All Stars [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462826.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/swp74q4KJEityiZzH3608Hj3Xez.jpg'),
(160096, 11353, 'RuPauls Drag Race Global All Stars [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462827.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rcolXnRfp1Wh9Vt83CxUrWHy8Di.jpg'),
(160097, 11353, 'RuPauls Drag Race Global All Stars [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462828.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Aswi5EsSNT4vyuZZlQ6WGzRt9Ss.jpg'),
(160098, 11353, 'RuPauls Drag Race Global All Stars [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462829.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lpkZZn80AWWVUGf7MUI25gyypfI.jpg'),
(160099, 11353, 'RuPauls Drag Race Global All Stars [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462830.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lUuoisNkzxTeWC9eqyLo5OjMLDz.jpg'),
(160100, 11353, 'RuPauls Drag Race Global All Stars [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462831.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bz7W2pFCl0MM3CRqJmRo3H43RqN.jpg'),
(160101, 11353, 'RuPauls Drag Race Global All Stars [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/512791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jbtW0zyr2fwo6SEOLK9jbq7ihZZ.jpg'),
(160102, 11353, 'RuPauls Drag Race Global All Stars [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/512792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jbtW0zyr2fwo6SEOLK9jbq7ihZZ.jpg'),
(160103, 11353, 'RuPauls Drag Race Global All Stars [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/512793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jbtW0zyr2fwo6SEOLK9jbq7ihZZ.jpg'),
(160104, 11353, 'RuPauls Drag Race Global All Stars [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/512794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jbtW0zyr2fwo6SEOLK9jbq7ihZZ.jpg'),
(160105, 11353, 'RuPauls Drag Race Global All Stars [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/512795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jbtW0zyr2fwo6SEOLK9jbq7ihZZ.jpg'),
(160106, 11354, 'Saudade de Voce [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462811.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uP3tBwX4NXhkd74JN50ZF1vkMID.jpg'),
(160107, 11354, 'Saudade de Voce [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462812.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/U6YWqlTCxb4J4SO9oTHTXgvxUO.jpg'),
(160108, 11354, 'Saudade de Voce [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462813.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xCdNv54f6uXcVB52qdoYXgglB7c.jpg'),
(160109, 11354, 'Saudade de Voce [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462814.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sdrzd34kHQsK11TRbYhzCCWNbNU.jpg'),
(160110, 11354, 'Saudade de Voce [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462815.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5bXg4QJmxArNgqt6FzITvMIDaiM.jpg'),
(160111, 11354, 'Saudade de Voce [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462816.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p6LOkVmFEF65Bgt79wXeohz1N7c.jpg'),
(160112, 11354, 'Saudade de Voce [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462817.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nHm96sEdREzXlwcWaZe74PvdQaR.jpg'),
(160113, 11354, 'Saudade de Voce [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462818.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rRn0ikSxGY14nYvxJd5tfaQOK3p.jpg'),
(160114, 11354, 'Saudade de Voce [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462819.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c8P4XiEodFAuZvH9NvBwJlXbs7E.jpg'),
(160115, 11354, 'Saudade de Voce [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462820.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v4AHp3sUgqOdNYZr5gqEd1pM6j2.jpg'),
(160116, 11354, 'Saudade de Voce [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/462821.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8dgbUoSmARcFrIpmZ2LCgsX5g9r.jpg'),
(160117, 11354, 'Saudade de Voce [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/462822.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8vwCRcW2gOKjI6fN3i4hUEiRkkF.jpg'),
(160118, 11354, 'Saudade de Voce [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/462823.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3TsxjqbIKrGdvf01lYcPqLmodt8.jpg'),
(160119, 11354, 'Saudade de Voce [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/462824.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7A5YbhJAGWocsZzjzyqK6LLDAMj.jpg'),
(160120, 11355, 'Sera Que Era o Amor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6lyLOMIgMbL9jDwTu08zQwfLsS4.jpg'),
(160121, 11355, 'Sera Que Era o Amor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6lyLOMIgMbL9jDwTu08zQwfLsS4.jpg'),
(160122, 11355, 'Sera Que Era o Amor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6lyLOMIgMbL9jDwTu08zQwfLsS4.jpg'),
(160123, 11355, 'Sera Que Era o Amor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6lyLOMIgMbL9jDwTu08zQwfLsS4.jpg'),
(160124, 11355, 'Sera Que Era o Amor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6lyLOMIgMbL9jDwTu08zQwfLsS4.jpg'),
(160125, 11355, 'Sera Que Era o Amor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6lyLOMIgMbL9jDwTu08zQwfLsS4.jpg'),
(160126, 11355, 'Sera Que Era o Amor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6lyLOMIgMbL9jDwTu08zQwfLsS4.jpg'),
(160127, 11355, 'Sera Que Era o Amor [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6lyLOMIgMbL9jDwTu08zQwfLsS4.jpg'),
(160128, 11355, 'Sera Que Era o Amor [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6lyLOMIgMbL9jDwTu08zQwfLsS4.jpg'),
(160129, 11355, 'Sera Que Era o Amor [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6lyLOMIgMbL9jDwTu08zQwfLsS4.jpg'),
(160130, 11356, 'The Magical Girl and the Evil Lieutenant Used to Be Archenemies [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462789.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k5ruRav6VA6fARqVKZiFW7dmQ9S.jpg'),
(160131, 11356, 'The Magical Girl and the Evil Lieutenant Used to Be Archenemies [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462790.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yVQZG3SFgTpRg6qfQEP6B48zRBF.jpg'),
(160132, 11356, 'The Magical Girl and the Evil Lieutenant Used to Be Archenemies [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462791.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cUzVQWL28ghID2SBNGTT3ZwZKVg.jpg'),
(160133, 11356, 'The Magical Girl and the Evil Lieutenant Used to Be Archenemies [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462792.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bk0WLMTSDLamqdS3iIcp0x5MysJ.jpg'),
(160134, 11356, 'The Magical Girl and the Evil Lieutenant Used to Be Archenemies [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462793.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i3E2yaRw3Tsf9xcDQEBz44HslA3.jpg'),
(160135, 11356, 'The Magical Girl and the Evil Lieutenant Used to Be Archenemies [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462794.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/al8GzDkTMMfEnF7179NxXZRDxkj.jpg'),
(160136, 11356, 'The Magical Girl and the Evil Lieutenant Used to Be Archenemies [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462795.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/puRoYiZhlneW0q6F9Hd3DYWfWt4.jpg'),
(160137, 11356, 'The Magical Girl and the Evil Lieutenant Used to Be Archenemies [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462796.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jrSdb4g35B99FtbjWDyBo0ZCChn.jpg'),
(160138, 11356, 'The Magical Girl and the Evil Lieutenant Used to Be Archenemies [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462797.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/87wZ9T8u0rs21cUQlVl66taMhbE.jpg'),
(160139, 11356, 'The Magical Girl and the Evil Lieutenant Used to Be Archenemies [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462798.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f7geq5d0571UTTUN3je3PBNOIot.jpg'),
(160140, 11356, 'The Magical Girl and the Evil Lieutenant Used to Be Archenemies [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/462799.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kvcCqrp1rca8Qcns4glAa28yzLw.jpg'),
(160141, 11356, 'The Magical Girl and the Evil Lieutenant Used to Be Archenemies [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/462800.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/siRgw38jp0aDRJqmVfUyNy9d5Bi.jpg'),
(160142, 11357, 'Vida Rural da Geracao Z [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462788.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/leOvJrkv57Awzc1Myddcoc5T5ud.jpg'),
(160143, 11357, 'Vida Rural da Geracao Z [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/487496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3Yc7jLRhkS3wCjz3yuyRHsYjmr.jpg'),
(160144, 11357, 'Vida Rural da Geracao Z [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/487497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3Yc7jLRhkS3wCjz3yuyRHsYjmr.jpg'),
(160145, 11357, 'Vida Rural da Geracao Z [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/487498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3Yc7jLRhkS3wCjz3yuyRHsYjmr.jpg'),
(160146, 11357, 'Vida Rural da Geracao Z [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/487499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3Yc7jLRhkS3wCjz3yuyRHsYjmr.jpg'),
(160147, 11357, 'Vida Rural da Geracao Z [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/497694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3Yc7jLRhkS3wCjz3yuyRHsYjmr.jpg'),
(160148, 11357, 'Vida Rural da Geracao Z [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/497695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3Yc7jLRhkS3wCjz3yuyRHsYjmr.jpg'),
(160149, 11357, 'Vida Rural da Geracao Z [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/497696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c3Yc7jLRhkS3wCjz3yuyRHsYjmr.jpg'),
(160150, 11358, 'When a Snail Falls in Love [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ix3US5jAuLvQBPW656s82AM1704.jpg'),
(160151, 11358, 'When a Snail Falls in Love [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ix3US5jAuLvQBPW656s82AM1704.jpg'),
(160152, 11358, 'When a Snail Falls in Love [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ix3US5jAuLvQBPW656s82AM1704.jpg'),
(160153, 11358, 'When a Snail Falls in Love [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ix3US5jAuLvQBPW656s82AM1704.jpg'),
(160154, 11358, 'When a Snail Falls in Love [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ix3US5jAuLvQBPW656s82AM1704.jpg'),
(160155, 11358, 'When a Snail Falls in Love [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ix3US5jAuLvQBPW656s82AM1704.jpg'),
(160156, 11358, 'When a Snail Falls in Love [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ix3US5jAuLvQBPW656s82AM1704.jpg'),
(160157, 11358, 'When a Snail Falls in Love [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ix3US5jAuLvQBPW656s82AM1704.jpg'),
(160158, 11358, 'When a Snail Falls in Love [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ix3US5jAuLvQBPW656s82AM1704.jpg'),
(160159, 11358, 'When a Snail Falls in Love [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ix3US5jAuLvQBPW656s82AM1704.jpg'),
(160160, 11358, 'When a Snail Falls in Love [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/462778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ix3US5jAuLvQBPW656s82AM1704.jpg'),
(160161, 11358, 'When a Snail Falls in Love [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/462779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ix3US5jAuLvQBPW656s82AM1704.jpg'),
(160162, 11358, 'When a Snail Falls in Love [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/462780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ix3US5jAuLvQBPW656s82AM1704.jpg'),
(160163, 11358, 'When a Snail Falls in Love [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/462781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ix3US5jAuLvQBPW656s82AM1704.jpg'),
(160164, 11358, 'When a Snail Falls in Love [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/462782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ix3US5jAuLvQBPW656s82AM1704.jpg'),
(160165, 11358, 'When a Snail Falls in Love [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/462783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ix3US5jAuLvQBPW656s82AM1704.jpg'),
(160166, 11358, 'When a Snail Falls in Love [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/462784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ix3US5jAuLvQBPW656s82AM1704.jpg'),
(160167, 11358, 'When a Snail Falls in Love [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/462785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ix3US5jAuLvQBPW656s82AM1704.jpg'),
(160168, 11358, 'When a Snail Falls in Love [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/462786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ix3US5jAuLvQBPW656s82AM1704.jpg'),
(160169, 11358, 'When a Snail Falls in Love [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/462787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ix3US5jAuLvQBPW656s82AM1704.jpg'),
(160170, 11359, 'Homicidio nos EUA Laci Peterson S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462765.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/reIJNbTeYSWd0oV10BJjAnS1PTL.jpg'),
(160171, 11359, 'Homicidio nos EUA Laci Peterson S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462766.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xLFg4x9XnaqC0ce1CZKHNkOL70D.jpg'),
(160172, 11359, 'Homicidio nos EUA Laci Peterson S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462767.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pNPBMIXKfNRPtd4PpbMD0KUDjUi.jpg'),
(160173, 11360, 'CSI Cyber S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462734.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dDf8OyQZwwYBxX7NHjJAtMX2Fd1.jpg'),
(160174, 11360, 'CSI Cyber S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462735.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ylruQg4UVGd1UXBfCXB7KnTZ99S.jpg'),
(160175, 11360, 'CSI Cyber S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462736.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qyIsfHw7ppPvxKE7FLpPWq2NPPv.jpg'),
(160176, 11360, 'CSI Cyber S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462737.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fon5FjLKfouSfudZ2acXqh6cvcO.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(160177, 11360, 'CSI Cyber S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462738.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7CbMZ8tEiO3MMybSeSJDEEiDVr4.jpg'),
(160178, 11360, 'CSI Cyber S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462739.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sxzFHhfDeAsjMpNWZ2PUkYQAfRf.jpg'),
(160179, 11360, 'CSI Cyber S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462740.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gg9WaHMtyDH1i5SB6ZUZqcNDqRc.jpg'),
(160180, 11360, 'CSI Cyber S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462741.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zIP1l1VZMxpjlkgMWByCzwoBWhX.jpg'),
(160181, 11360, 'CSI Cyber S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462742.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rsMHmc5qrKEk9NQ6RjRIud4Dhvu.jpg'),
(160182, 11360, 'CSI Cyber S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462743.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dkvxalxs2mkgT7HdCEeQNoVkhAH.jpg'),
(160183, 11360, 'CSI Cyber S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/462744.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s6BBMWO81JZiClDwKPnfrNAWRbe.jpg'),
(160184, 11360, 'CSI Cyber S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/462745.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2SSD98bFqgCmObve9S2DDYtlRb1.jpg'),
(160185, 11360, 'CSI Cyber S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/462746.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9QeUNg61QBT7CTFmmmmOQMDAUTU.jpg'),
(160186, 11361, 'CSI Cyber S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462747.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zSHqquHAit1aMp7ez03XbjmsLse.jpg'),
(160187, 11361, 'CSI Cyber S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462748.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/38y9NIjf3rmrXrBm9MqGzDjnVb3.jpg'),
(160188, 11361, 'CSI Cyber S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462749.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j6TQmMSRs43deTR2wlsEOaxLcSh.jpg'),
(160189, 11361, 'CSI Cyber S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462750.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6Xupja6XppMhAHRiDKUzofZnH1t.jpg'),
(160190, 11361, 'CSI Cyber S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462751.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9yc4rYzZEf3e4Bcwt30m2kpJccv.jpg'),
(160191, 11361, 'CSI Cyber S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462752.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/enQrs65dWEUUzdTcQTYyQR3HzwE.jpg'),
(160192, 11361, 'CSI Cyber S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462753.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sD4Mtf0GDoiWjoMUX9jW9qmmzii.jpg'),
(160193, 11361, 'CSI Cyber S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462754.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xK62T1JyVmPfVeHdDewepT5LvrI.jpg'),
(160194, 11361, 'CSI Cyber S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462755.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hrvGTNbJqQGlmudypgLeig1s5p5.jpg'),
(160195, 11361, 'CSI Cyber S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462756.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dvRkXfPavDlzTfzqL50tlzboPpB.jpg'),
(160196, 11361, 'CSI Cyber S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/462757.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5g8Ftq8EGkeWzeLpbQ0vj1q8BUZ.jpg'),
(160197, 11361, 'CSI Cyber S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/462758.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d3D0gWGVTMOLPQBxyNzTTcudAAU.jpg'),
(160198, 11361, 'CSI Cyber S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/462759.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ndb9F17X1jqJ8YkwDJ9i6pOuBE3.jpg'),
(160199, 11361, 'CSI Cyber S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/462760.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f0UVZ1bmRt2JrAWe40cJhBQg47B.jpg'),
(160200, 11361, 'CSI Cyber S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/462761.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iFvWQ9Y9AP72NjEupEgkNb0OcII.jpg'),
(160201, 11361, 'CSI Cyber S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/462762.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y7jecOgvCTGnZfD8PIcMYL637mC.jpg'),
(160202, 11361, 'CSI Cyber S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/462763.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8SYtI1jLwo1MTlGLRGfUmw8g3WL.jpg'),
(160203, 11361, 'CSI Cyber S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/462764.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tC14e9Lqw3r4AgfhfsuJnWmJFxH.jpg'),
(160204, 11362, 'The Kings Avatar [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462694.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yGVSx6oaNJNDjVt3LPB03wd9oDp.jpg'),
(160205, 11362, 'The Kings Avatar [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462695.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p3k6VvEGPAkBUzw7UQUHSG89Qmi.jpg'),
(160206, 11362, 'The Kings Avatar [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462696.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yuHvC6yQOTFGom7v3gjX0V6zGao.jpg'),
(160207, 11362, 'The Kings Avatar [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462697.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6J54vWdIQvNo52nm4lM1ojloWSn.jpg'),
(160208, 11362, 'The Kings Avatar [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462698.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e6D3CJEwpbVw7hdDCiaESy5pa8i.jpg'),
(160209, 11362, 'The Kings Avatar [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462699.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oj9zWzpOa5EXHFI8KA6ORtbFkyQ.jpg'),
(160210, 11362, 'The Kings Avatar [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462700.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tHWajRMZ53HfJBNBaytlOOLyu5R.jpg'),
(160211, 11362, 'The Kings Avatar [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462701.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pfChOUKmRV12nifYkyri9U5s9WE.jpg'),
(160212, 11362, 'The Kings Avatar [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462702.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hW1pkLGxczfpMz3308Ud9xmaOPR.jpg'),
(160213, 11362, 'The Kings Avatar [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462703.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uC7LsQhnwDaIa8edqPqxDoEp7c8.jpg'),
(160214, 11362, 'The Kings Avatar [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/462704.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vxuxO0RI2IQ5Gzoprv2anuF0SHX.jpg'),
(160215, 11362, 'The Kings Avatar [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/462705.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jbv3hNpNIo2HSjnC6c9LESPMi6T.jpg'),
(160216, 11362, 'The Kings Avatar [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/462706.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vTP66ywmFqSWIeomSkrPeL7V4im.jpg'),
(160217, 11362, 'The Kings Avatar [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/462707.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2LyfOMsjjPwiIvhJeABKLYT3e2v.jpg'),
(160218, 11362, 'The Kings Avatar [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/462708.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iMGqRXoh4Z7lw1JHh5AN9VBFyFU.jpg'),
(160219, 11362, 'The Kings Avatar [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/462709.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zxHhXPVjoJjKzg2Jh4KqL06PXnL.jpg'),
(160220, 11362, 'The Kings Avatar [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/462710.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pHIphmYJhxnBbpGHT477oSxlDxQ.jpg'),
(160221, 11362, 'The Kings Avatar [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/462711.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4nJIn3LsMTBL9vlwFIAoYmNokFl.jpg'),
(160222, 11362, 'The Kings Avatar [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/462712.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tUWnloxPeZoCxeQwLKKAUJnOl6D.jpg'),
(160223, 11362, 'The Kings Avatar [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/462713.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vSJEUSyfAExNOwDovxKfuOSVJNN.jpg'),
(160224, 11362, 'The Kings Avatar [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/462714.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w2ZQbpVg05iYW4Hh9ZLLtnOOmmG.jpg'),
(160225, 11362, 'The Kings Avatar [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/462715.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3LSoR1z6DPtk4AadbmQ0uGY2XPq.jpg'),
(160226, 11362, 'The Kings Avatar [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/462716.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hD9JPWc04jfHJsxwa9MJvq3Yx5V.jpg'),
(160227, 11362, 'The Kings Avatar [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/462717.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3y7cGHDG81mOZU4WnVeEUENJydy.jpg'),
(160228, 11362, 'The Kings Avatar [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/462718.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iQBEngcKNieeljO4gViC1pZtWPi.jpg'),
(160229, 11362, 'The Kings Avatar [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/462719.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dX29vcucWGKQqifCwexgZbAkHqo.jpg'),
(160230, 11362, 'The Kings Avatar [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/462720.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yLcLqW02XpnPey8bE65KlSMLZF9.jpg'),
(160231, 11362, 'The Kings Avatar [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/462721.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tPIECOMiHdZUBwLTGtXnMgcWskG.jpg'),
(160232, 11362, 'The Kings Avatar [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/462722.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9IIAe0R2MNE1W5UzdQic8UHzGzK.jpg'),
(160233, 11362, 'The Kings Avatar [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/462723.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/94bRZpNNqAAdbmNyOIfmbtFva4x.jpg'),
(160234, 11362, 'The Kings Avatar [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/462724.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rqNzgStcddgQWCgrBd6vuq797Lq.jpg'),
(160235, 11362, 'The Kings Avatar [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/462725.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1tw1lYCBUlZSuqhWT4YKbBjo626.jpg'),
(160236, 11362, 'The Kings Avatar [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/462726.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mfpRWEl8NoaKkVA5eWK9sMxSrNf.jpg'),
(160237, 11362, 'The Kings Avatar [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/462727.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9foXisJQ2E9hIDzx5fukTFO0EqM.jpg'),
(160238, 11362, 'The Kings Avatar [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/462728.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dNq1JJAENyEivP1mSvmb4zXVd7D.jpg'),
(160239, 11362, 'The Kings Avatar [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/462729.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j0gNxFpbX7kgfe05Dl0XRN5lE2f.jpg'),
(160240, 11362, 'The Kings Avatar [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/462730.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wmaaUSnBNShHgkSs4Zct7ujq5hd.jpg'),
(160241, 11362, 'The Kings Avatar [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/462731.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vsY6lc1f8br6JjzRHmchx0jVzfP.jpg'),
(160242, 11362, 'The Kings Avatar [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/462732.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5f8Otwek4aj1MiVy5i61SMIHWsY.jpg'),
(160243, 11362, 'The Kings Avatar [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/462733.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pP1MQ1yzm8SGmAtg40DIf9Nph7L.jpg'),
(160244, 11363, 'Timeless Guardioes da Historia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462668.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pZbbPuiTBWZjBsoSFKHG06MrAq9.jpg'),
(160245, 11363, 'Timeless Guardioes da Historia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462669.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kylgt5NFNw01SR6LmXwfdqIw1YO.jpg'),
(160246, 11363, 'Timeless Guardioes da Historia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462670.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/76MNmqBM9QcKcrUOOsoj4r8ufwe.jpg'),
(160247, 11363, 'Timeless Guardioes da Historia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462671.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sBIi9Sol1D0zxi96yijLw0az049.jpg'),
(160248, 11363, 'Timeless Guardioes da Historia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462672.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/unYmVm2878tqnqNoosJV8fjeQ5V.jpg'),
(160249, 11363, 'Timeless Guardioes da Historia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462673.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kYU4BbAVjVmmwuuXSjuGzWkTFkg.jpg'),
(160250, 11363, 'Timeless Guardioes da Historia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462674.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uhJfUvCX7vNMiUeLSvWzfsY0XIi.jpg'),
(160251, 11363, 'Timeless Guardioes da Historia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462675.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uyZZxWFZqatEi3TUhKlYKV7WggD.jpg'),
(160252, 11363, 'Timeless Guardioes da Historia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462676.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bZIMOxCwuqc8xQG8e3PQoNZ8E7Q.jpg'),
(160253, 11363, 'Timeless Guardioes da Historia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462677.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A7w23u72KXuH0pIOLvlcGfw8TjB.jpg'),
(160254, 11363, 'Timeless Guardioes da Historia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/462678.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hvNJq33ZuSSMplr4mitX14CJAzr.jpg'),
(160255, 11363, 'Timeless Guardioes da Historia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/462679.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jg7I9TiUYg1l1ESLubB5QuLiAAI.jpg'),
(160256, 11363, 'Timeless Guardioes da Historia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/462680.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1X76x0FVR9ZumbJXihMhYAJfHJq.jpg'),
(160257, 11363, 'Timeless Guardioes da Historia S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/462681.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Av6Ui5qvon0Hvf5UI8aEoxUGSz.jpg'),
(160258, 11363, 'Timeless Guardioes da Historia S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/462682.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7f0FYXpDGKNlRweDpRUDsM87TgJ.jpg'),
(160259, 11363, 'Timeless Guardioes da Historia S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/462683.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4Nc0vO8znU74z2B93FOZZEv4kS.jpg'),
(160260, 11364, 'Timeless Guardioes da Historia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/462684.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fzjh6DMZ5I82pbVc29srYTzMN9X.jpg'),
(160261, 11364, 'Timeless Guardioes da Historia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/462685.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iJGNffrx0zk1ZNgR5iB2M4JoltD.jpg'),
(160262, 11364, 'Timeless Guardioes da Historia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/462686.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9ijlTnULiQCZ0UdQmuGUaLqFSmg.jpg'),
(160263, 11364, 'Timeless Guardioes da Historia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/462687.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q0gu47d4dzrNY62QXU36zTbq8M0.jpg'),
(160264, 11364, 'Timeless Guardioes da Historia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/462688.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4KaFYzUvTUkMSfCUaLTpSc3U32y.jpg'),
(160265, 11364, 'Timeless Guardioes da Historia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/462689.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AfDMb8lRkrspK22DgykV0oVWvcn.jpg'),
(160266, 11364, 'Timeless Guardioes da Historia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/462690.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rhbfJpioTO9p0nJyIcIykElTZIY.jpg'),
(160267, 11364, 'Timeless Guardioes da Historia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/462691.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v6qlPsUqBGPfXE5ZzuAC8nASRan.jpg'),
(160268, 11364, 'Timeless Guardioes da Historia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/462692.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kbYVRGSX32ukzt4vS9VEnStRZyS.jpg'),
(160269, 11364, 'Timeless Guardioes da Historia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/462693.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wc68PFx39HoYOMjbxQJLJInpxIx.jpg'),
(160270, 11365, '20th Century Boy and Girl [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465635.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wadByTL6vuyCptZy5ikaiV2oM5W.jpg'),
(160271, 11365, '20th Century Boy and Girl [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465636.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bc9txlfGyw0FJavLxsE2Ccs7XCN.jpg'),
(160272, 11365, '20th Century Boy and Girl [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465637.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jjtmwN4FFiVM6bPfBfyL76OsQA1.jpg'),
(160273, 11365, '20th Century Boy and Girl [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465638.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u4Bdc0IGt9qBKDd3xdu3cNht8t6.jpg'),
(160274, 11365, '20th Century Boy and Girl [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465639.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mgvkuy76rvKFxNBfDp3ozwz2oYo.jpg'),
(160275, 11365, '20th Century Boy and Girl [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465640.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aS6dH2DASChB5CqAXSEKhRkpU6p.jpg'),
(160276, 11365, '20th Century Boy and Girl [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465641.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mPzzmkscXOAy6HjZVUAGQ7pdsBi.jpg'),
(160277, 11365, '20th Century Boy and Girl [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465642.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gNo8QhZtpayxHRsDdnjng5euw41.jpg'),
(160278, 11365, '20th Century Boy and Girl [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465643.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lEquiDCHn6Vkr1HnglxGZzbkcB8.jpg'),
(160279, 11365, '20th Century Boy and Girl [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465644.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sgbtiLVPLlKJJf1yFUEt3BusMg1.jpg'),
(160280, 11365, '20th Century Boy and Girl [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465645.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kR7HlMmxJeFi1DK7pxoehNlLJYV.jpg'),
(160281, 11365, '20th Century Boy and Girl [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465646.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mziBch8cH12TxfvlmR74ZqkLp38.jpg'),
(160282, 11365, '20th Century Boy and Girl [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465647.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jtCpABdcgvUTgy8SC4fIjHSivlh.jpg'),
(160283, 11365, '20th Century Boy and Girl [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/465648.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f3moQWn9qjJ94zWqOiqoiBI2PIR.jpg'),
(160284, 11365, '20th Century Boy and Girl [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/465649.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xbfxjCnDp6etJXdWOnTlq5tvMl4.jpg'),
(160285, 11365, '20th Century Boy and Girl [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/465650.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5huYI6B1bLb5NH0bhvkvlfa79FY.jpg'),
(160286, 11365, '20th Century Boy and Girl [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/465651.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a1Uz0HGRwkovfZvLSrE1YufLa1p.jpg'),
(160287, 11365, '20th Century Boy and Girl [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/465652.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5HY5u9c57ps4Leh8aFfH87AC7Np.jpg'),
(160288, 11365, '20th Century Boy and Girl [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/465653.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/so0OYhCquk5L6IAKTHBzVVzIHvZ.jpg'),
(160289, 11365, '20th Century Boy and Girl [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/465654.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qDhO1zLeApilk8xi9oo7GcZZikj.jpg'),
(160290, 11365, '20th Century Boy and Girl [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/465655.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wwkdE7cOFgwxnbotiwb4E18v008.jpg'),
(160291, 11365, '20th Century Boy and Girl [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/465656.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zAOnDamGF50hYuujv5Zm6y3O2jN.jpg'),
(160292, 11365, '20th Century Boy and Girl [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/465657.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wOjY4VSR4RbGuRbL7SH1RjNwDog.jpg'),
(160293, 11365, '20th Century Boy and Girl [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/465658.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/elMrSPs5gWcvaLNgoXhFvaVlS02.jpg'),
(160294, 11365, '20th Century Boy and Girl [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/465659.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cWsbWZVTUERdvjraNPj5wWFfAkR.jpg'),
(160295, 11365, '20th Century Boy and Girl [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/465660.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yff00LwpGBTo5gataotvAT3R2wZ.jpg'),
(160296, 11365, '20th Century Boy and Girl [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/465661.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6FFtFmav4gX45R7XRM6kNTFQM8K.jpg'),
(160297, 11365, '20th Century Boy and Girl [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/465662.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iLac8ww7rJdghJn0wi473K0TmUp.jpg'),
(160298, 11365, '20th Century Boy and Girl [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/465663.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tBDtT0TVuV97apRUEskFuuTfB22.jpg'),
(160299, 11365, '20th Century Boy and Girl [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/465664.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8PQcPXhuY875yq9cDEFReiJ3YlH.jpg'),
(160300, 11365, '20th Century Boy and Girl [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/465665.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zTUiQBUNihisJGxunQpG8BXzOpy.jpg'),
(160301, 11365, '20th Century Boy and Girl [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/465666.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b9oOkVwfEOsrftwTzsLm9bvbLnb.jpg'),
(160302, 11366, 'A Origem da Eternidade [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hMe0UjQqQtHJOvHwGX89XDe0mOM.jpg'),
(160303, 11366, 'A Origem da Eternidade [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hMe0UjQqQtHJOvHwGX89XDe0mOM.jpg'),
(160304, 11366, 'A Origem da Eternidade [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hMe0UjQqQtHJOvHwGX89XDe0mOM.jpg'),
(160305, 11366, 'A Origem da Eternidade [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hMe0UjQqQtHJOvHwGX89XDe0mOM.jpg'),
(160306, 11366, 'A Origem da Eternidade [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hMe0UjQqQtHJOvHwGX89XDe0mOM.jpg'),
(160307, 11366, 'A Origem da Eternidade [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hMe0UjQqQtHJOvHwGX89XDe0mOM.jpg'),
(160308, 11366, 'A Origem da Eternidade [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hMe0UjQqQtHJOvHwGX89XDe0mOM.jpg'),
(160309, 11366, 'A Origem da Eternidade [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hMe0UjQqQtHJOvHwGX89XDe0mOM.jpg'),
(160310, 11367, 'A Pessoa Prometida [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465587.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k27kkB6rjq4cSaCJioAyTOm52hA.jpg'),
(160311, 11367, 'A Pessoa Prometida [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465588.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bThx97zPkiiINYvJ2la6h75L8Hn.jpg'),
(160312, 11367, 'A Pessoa Prometida [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465589.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gGvBdFCTiLUQYQOg5kFuEMF6AfC.jpg'),
(160313, 11367, 'A Pessoa Prometida [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465590.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3V5kvi2LYYuVH34lN5oweeMlTXs.jpg'),
(160314, 11367, 'A Pessoa Prometida [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465591.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xpsMfPkbh4zRDKu2nyHaqQppYn3.jpg'),
(160315, 11367, 'A Pessoa Prometida [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465592.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j6Ipm5ToC2OYeTQGL7EYZRZ5cOE.jpg'),
(160316, 11367, 'A Pessoa Prometida [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465593.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4U8arXavVHdJOg0gbVrkNw3Oysx.jpg'),
(160317, 11367, 'A Pessoa Prometida [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465594.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j20MSbHyDRvrHVDt2xQJB0FeKMQ.jpg'),
(160318, 11367, 'A Pessoa Prometida [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465595.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nimMbVeXXPx942StiRhuq6K46bU.jpg'),
(160319, 11367, 'A Pessoa Prometida [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465596.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xWNUyQLXAmFkRRFbr3ff4B9e99t.jpg'),
(160320, 11367, 'A Pessoa Prometida [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465597.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qefcjLPrZz82zK29WlEG8qkdOqK.jpg'),
(160321, 11367, 'A Pessoa Prometida [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465598.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6z9tDRc4RZdnJOUKvWiHNRwJVoP.jpg'),
(160322, 11367, 'A Pessoa Prometida [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465599.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aXopprjUS905cnYOOrbK095ZsIi.jpg'),
(160323, 11367, 'A Pessoa Prometida [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/465600.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xweIld1G7lC0QfTDCruASPhgcBB.jpg'),
(160324, 11367, 'A Pessoa Prometida [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/465601.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fHgFzircdeNNuly0CMAWdjCHmAI.jpg'),
(160325, 11367, 'A Pessoa Prometida [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/465602.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lve18qospzGdQH2hUZCReBln9T.jpg'),
(160326, 11367, 'A Pessoa Prometida [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/465603.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/npRTKUT6GbRxWegi8bLvpwAsLvA.jpg'),
(160327, 11367, 'A Pessoa Prometida [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/465604.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qkoMBrAKQK3wGPcL9vSaBmmKexM.jpg'),
(160328, 11367, 'A Pessoa Prometida [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/465605.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xfQGjTmQSl4sXTo1qsKMQI1gnsG.jpg'),
(160329, 11367, 'A Pessoa Prometida [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/465606.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8zdRTUq9BdMtn4yUPIKGGl8uG2L.jpg'),
(160330, 11367, 'A Pessoa Prometida [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/465607.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uMhqRBBnZcLbyMdF0wDPJuUf4No.jpg'),
(160331, 11367, 'A Pessoa Prometida [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/465608.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r89g999jWpQGe6eBSkjZXxrVa3i.jpg'),
(160332, 11367, 'A Pessoa Prometida [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/465609.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gv9C7fDLFsCaftE1XyAlcCZz9m3.jpg'),
(160333, 11367, 'A Pessoa Prometida [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/465610.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1nQvcsWhZ2PxAQGn1b57N5R8BP8.jpg'),
(160334, 11367, 'A Pessoa Prometida [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/465611.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yuDqsgAPagufyyv6whi6us8S9w2.jpg'),
(160335, 11367, 'A Pessoa Prometida [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/465612.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vUdJiY1f6vtJqExepdjCqvuFzLi.jpg'),
(160336, 11367, 'A Pessoa Prometida [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/465613.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bbI78qcrtLnbnbtMjc2ZfSCAOE7.jpg'),
(160337, 11367, 'A Pessoa Prometida [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/465614.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/orHnImtpexzFxtNvhWwybtIBYfY.jpg'),
(160338, 11367, 'A Pessoa Prometida [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/465615.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uBjRyvA49hfQT165dlL20o712XG.jpg'),
(160339, 11367, 'A Pessoa Prometida [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/465616.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ap4WNhYJFDmMTv59kJtHRmfp34U.jpg'),
(160340, 11367, 'A Pessoa Prometida [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/465617.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zrQW07OvS18Gk2EYCRjD5SJhqLt.jpg'),
(160341, 11367, 'A Pessoa Prometida [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/465618.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xD9Vxx1DTrqdlgw4486UC5PO56m.jpg'),
(160342, 11367, 'A Pessoa Prometida [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/465619.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lE22mBgDWMe41WsoKbYmln6Iiss.jpg'),
(160343, 11367, 'A Pessoa Prometida [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/465620.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/amQo5vLYXrLLgY5Q6lw9vNsakcO.jpg'),
(160344, 11367, 'A Pessoa Prometida [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/465621.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dkaSdJYRosbREsYr5WhUiKD5njY.jpg'),
(160345, 11367, 'A Pessoa Prometida [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/465622.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gV427bvyfDk0FCSAZmcvH75NkvO.jpg'),
(160346, 11367, 'A Pessoa Prometida [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/465623.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8fu5DJTol58CpWvJxvw8ql8Pgwl.jpg'),
(160347, 11367, 'A Pessoa Prometida [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/465624.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/br3oGkc0KBGcDp1uzO4ihbhXm9l.jpg'),
(160348, 11367, 'A Pessoa Prometida [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/465625.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vdcHSmfyDMJlR5ZnOwfiGbKzIW.jpg'),
(160349, 11367, 'A Pessoa Prometida [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/465626.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4RYU4VHvR0Ms4jATxF6VkTxTSlI.jpg'),
(160350, 11368, 'Amor Com Falhas [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465555.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ZLBhznNARm4YOkpuokb6lJ3ctk.jpg'),
(160351, 11368, 'Amor Com Falhas [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465556.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJM4Mq5bDvz4dhNeYCVYbGkAlV.jpg'),
(160352, 11368, 'Amor Com Falhas [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465557.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n9FMu4pWCTJOMhd6cqWXDhBuZ8k.jpg'),
(160353, 11368, 'Amor Com Falhas [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465558.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q6toVt4LskO4klIQvyX4hNL9lN3.jpg'),
(160354, 11368, 'Amor Com Falhas [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465559.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Hj6TvRJi6T5uhUoQKjrvpU0Jph.jpg'),
(160355, 11368, 'Amor Com Falhas [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465560.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4T6wYk5y4IOrKoS7MZ6Ot4wcfrS.jpg'),
(160356, 11368, 'Amor Com Falhas [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465561.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vIlk1FA8E8sGXrDF6HY5iyY4ZoL.jpg'),
(160357, 11368, 'Amor Com Falhas [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465562.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ZJ66ZYOGjr3up9PkEFNCTEdlCS.jpg'),
(160358, 11368, 'Amor Com Falhas [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465563.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jsi2WoeTedMQUkC5qX0mcRUE4V6.jpg'),
(160359, 11368, 'Amor Com Falhas [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465564.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cPfmDPshzfzXp2FJa2LGRtfo9zY.jpg'),
(160360, 11368, 'Amor Com Falhas [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465565.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Gsguvenj9kQgqWQkcHESi51kR4.jpg'),
(160361, 11368, 'Amor Com Falhas [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465566.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a9gQQksOlPe7cVJ9rCgxQTXTSG0.jpg'),
(160362, 11368, 'Amor Com Falhas [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465567.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/S8LcAlATscXplKswxHJ6h5WO8C.jpg'),
(160363, 11368, 'Amor Com Falhas [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/465568.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/feEstqjZU7rYDUr6lIyYGXtP0eF.jpg'),
(160364, 11368, 'Amor Com Falhas [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/465569.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vq6whm0iwGk7ygBITMjNaDSDiWU.jpg'),
(160365, 11368, 'Amor Com Falhas [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/465570.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qIDD1L1UIETyzMarpoKMHzfmPzw.jpg'),
(160366, 11368, 'Amor Com Falhas [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/465571.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qnT3zPP3JdRcYFK1ZcK4atdFdYo.jpg'),
(160367, 11368, 'Amor Com Falhas [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/465572.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fbC00WVSnGx2nhgxaXubm68rjxE.jpg'),
(160368, 11368, 'Amor Com Falhas [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/465573.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lkkyTkyQSYY9FDqubQbQ6NOxw2h.jpg'),
(160369, 11368, 'Amor Com Falhas [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/465574.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b5NmUh2WbLQ3RNdZp8WDbg9WeYE.jpg'),
(160370, 11368, 'Amor Com Falhas [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/465575.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ay762tqhqMExVRcfqPtYZt3Pp6B.jpg'),
(160371, 11368, 'Amor Com Falhas [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/465576.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ywoCZfuJgiJejZAymaWqhchep9v.jpg'),
(160372, 11368, 'Amor Com Falhas [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/465577.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6dBtF9Px0hzBhWulskx3n2zTRJJ.jpg'),
(160373, 11368, 'Amor Com Falhas [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/465578.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3CmUVZwFwaw03mwtHyWPWMSPkoY.jpg'),
(160374, 11368, 'Amor Com Falhas [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/465579.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oNdYIvwxGpi9Qgcsn07Zbi20ncV.jpg'),
(160375, 11368, 'Amor Com Falhas [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/465580.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kBXX4knACSGJ9z7KaqulEylpNNY.jpg'),
(160376, 11368, 'Amor Com Falhas [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/465581.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/18kofJ3VxUBGEpVZNNTht24rBFh.jpg'),
(160377, 11368, 'Amor Com Falhas [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/465582.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/naMi7FFjYC9oHUb5ebRCZHu8YBx.jpg'),
(160378, 11368, 'Amor Com Falhas [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/465583.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hMYrfq84QAvjVPz0RcdAvtpG2KC.jpg'),
(160379, 11368, 'Amor Com Falhas [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/465584.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7hActcbxl2DGD3Ga3HKyKQH6qsT.jpg'),
(160380, 11368, 'Amor Com Falhas [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/465585.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rcbr3H74u0I1vXCM0hWbdnqEW71.jpg'),
(160381, 11368, 'Amor Com Falhas [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/465586.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3sY1sI9PH31T6ArkLbzOXaw6njR.jpg'),
(160382, 5300, 'Amor para Recomecar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465543.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zIiamKXpPfCE5o3aY3UVcChttkR.jpg'),
(160383, 5300, 'Amor para Recomecar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465544.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5yY8CEUjBOzEtkawPWiXX7gPpa7.jpg'),
(160384, 5300, 'Amor para Recomecar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465545.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rhmslbZdeiYYXXPuYrRmt5LLAFx.jpg'),
(160385, 5300, 'Amor para Recomecar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465546.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j26Gl6UVkIq8s50efsDg4ECzrfq.jpg'),
(160386, 5300, 'Amor para Recomecar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465547.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1IYEvRGmHF4LDAXIE75C8GwHiqe.jpg'),
(160387, 5300, 'Amor para Recomecar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465548.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tQIwEEwmpyte2GujSoKZuGyfP6d.jpg'),
(160388, 11369, 'Amor para Recomecar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465549.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jvkodJdfydPDexuSxSF3JQvtuLi.jpg'),
(160389, 11369, 'Amor para Recomecar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465550.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xRuMFtukQaJl78hDKdwy1uo8V5Y.jpg'),
(160390, 11369, 'Amor para Recomecar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465551.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aypjcTvbFhFJMf3xEji6BFvDFnu.jpg'),
(160391, 11369, 'Amor para Recomecar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465552.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a4MZmThyep8UPMxJC2y9pBWx98Z.jpg'),
(160392, 11369, 'Amor para Recomecar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465553.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/utav2WwTqM2qcWsJrXNazSwIGKU.jpg'),
(160393, 11369, 'Amor para Recomecar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465554.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gmwJUznIPWKtwIERC8kCt4GCVdl.jpg'),
(160394, 11370, 'Aqua Teen Esquadrao Forca Total S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465475.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gCg638C3cREyq4xazWcmtnAh8mU.jpg'),
(160395, 11370, 'Aqua Teen Esquadrao Forca Total S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465476.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2H8qM5YGOpkFdmS8Vebf49bhBa0.jpg'),
(160396, 11370, 'Aqua Teen Esquadrao Forca Total S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465477.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8I8uT7o5nLbdSEjN42lrmcKI6PX.jpg'),
(160397, 11370, 'Aqua Teen Esquadrao Forca Total S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465478.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zlMoqFJuYRZs31KK7A8vwPWgsFz.jpg'),
(160398, 11370, 'Aqua Teen Esquadrao Forca Total S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465479.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9lOfyPs5TmnA6WbNGEXJy5V9o7A.jpg'),
(160399, 11370, 'Aqua Teen Esquadrao Forca Total S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465480.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rDSYwf61KktVvdOsUZJQNJq6OO2.jpg'),
(160400, 11370, 'Aqua Teen Esquadrao Forca Total S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465481.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/NfYLCpclneGkwCTuaNwhrcQHmL.jpg'),
(160401, 11370, 'Aqua Teen Esquadrao Forca Total S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465482.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nHZC5ATw9gHhEmSICnSoV1baHj4.jpg'),
(160402, 11370, 'Aqua Teen Esquadrao Forca Total S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465483.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3b4XZ4XEcOy3mNtYG7BxZAwyM5X.jpg'),
(160403, 11370, 'Aqua Teen Esquadrao Forca Total S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465484.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/TyYBKeJL91TCZavJYD2cxle9W6.jpg'),
(160404, 11370, 'Aqua Teen Esquadrao Forca Total S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465485.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n0wty5G2YXaLLqUqaUYuWVUcrCB.jpg'),
(160405, 11370, 'Aqua Teen Esquadrao Forca Total S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465486.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2nO1C3ne8ZbU5X7eFUi4pYAL5hw.jpg'),
(160406, 11370, 'Aqua Teen Esquadrao Forca Total S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465487.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/25ysDMnayUZyIiyIb2aBGHHRMPx.jpg'),
(160407, 11370, 'Aqua Teen Esquadrao Forca Total S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/465488.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1G17UQTjHbjqntJcp9hjIjYGAwV.jpg'),
(160408, 11370, 'Aqua Teen Esquadrao Forca Total S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/465489.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n9Vyzid79GEDg5BxQpp8g0JqWN0.jpg'),
(160409, 11370, 'Aqua Teen Esquadrao Forca Total S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/465490.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pDgl4unhIaC5CGlUQBddtFl5Qlj.jpg'),
(160410, 11370, 'Aqua Teen Esquadrao Forca Total S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/465491.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/84avwt7seBljdC0LxU7Mdwv1Lun.jpg'),
(160411, 11370, 'Aqua Teen Esquadrao Forca Total S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/465492.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1Ov7vhXDOGC1hmAKpPCCTT4pRdI.jpg'),
(160412, 11371, 'Aqua Teen Esquadrao Forca Total S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465493.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fOczdzl7NUURSGHU6UJlkv8B0Xr.jpg'),
(160413, 11371, 'Aqua Teen Esquadrao Forca Total S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465494.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g0rNHf4oqGbVwdYsTu6cnS2wiha.jpg'),
(160414, 11371, 'Aqua Teen Esquadrao Forca Total S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465495.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/phbsGIvDWpQ8UkDdzSZZXGVgP3i.jpg'),
(160415, 11371, 'Aqua Teen Esquadrao Forca Total S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465496.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cZN7ICAoWvhikJMSg8YfepNom42.jpg'),
(160416, 11371, 'Aqua Teen Esquadrao Forca Total S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465497.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nNiMR3mWganGpbHlJrGUPvaT8dh.jpg'),
(160417, 11371, 'Aqua Teen Esquadrao Forca Total S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465498.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wWVKxoVDUgWnwIfPjIdD9IMT4lA.jpg'),
(160418, 11371, 'Aqua Teen Esquadrao Forca Total S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465499.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gAxEwX5MdVEFaj2PUCijxcAeyEZ.jpg'),
(160419, 11371, 'Aqua Teen Esquadrao Forca Total S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465500.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aJY66INe9aZhdfXIgyWYZtFxVCx.jpg'),
(160420, 11371, 'Aqua Teen Esquadrao Forca Total S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465501.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1dEYnrP8acLUtT1Eh51BCZiN99K.jpg'),
(160421, 11371, 'Aqua Teen Esquadrao Forca Total S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465502.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cXfDrlyqc7RdLLRjtXpAKpLfyNB.jpg'),
(160422, 11371, 'Aqua Teen Esquadrao Forca Total S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465503.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3pznGnqBKFFEnXX8isIBGgIqVyA.jpg'),
(160423, 11371, 'Aqua Teen Esquadrao Forca Total S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465504.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rHdYJDB6gcnZ4WAP25VPVgOXP0Q.jpg'),
(160424, 11371, 'Aqua Teen Esquadrao Forca Total S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465505.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vNOg0wqvgfKNK7JyMwYSMQH5aWw.jpg'),
(160425, 11371, 'Aqua Teen Esquadrao Forca Total S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/465506.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wfoYXs2yQc30TmFP43ZZCkA6o8Q.jpg'),
(160426, 11371, 'Aqua Teen Esquadrao Forca Total S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/465507.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hufeyuvTX6acppqQ0rbfeT2IxC7.jpg'),
(160427, 11371, 'Aqua Teen Esquadrao Forca Total S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/465508.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k2LnIjTj7Mkh5nMTLudl4u1hjwl.jpg'),
(160428, 11371, 'Aqua Teen Esquadrao Forca Total S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/465509.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iyCJ5eekuF3dxka65BX7efnfBUc.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(160429, 11371, 'Aqua Teen Esquadrao Forca Total S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/465510.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ibQyVO77TkynJuRukCdlGXbz9WA.jpg'),
(160430, 11371, 'Aqua Teen Esquadrao Forca Total S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/465511.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rHVkugDrJAE9fX6v7IDm0itjv5p.jpg'),
(160431, 11371, 'Aqua Teen Esquadrao Forca Total S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/465512.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ah0uuYEpNEPQCNUYhbXnZMMa1Q1.jpg'),
(160432, 11371, 'Aqua Teen Esquadrao Forca Total S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/465513.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o8qJraSwqedlArhbhkuF99Xss70.jpg'),
(160433, 11371, 'Aqua Teen Esquadrao Forca Total S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/465514.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zIWIgYO9mCokfpPgrmyOShbvGox.jpg'),
(160434, 11371, 'Aqua Teen Esquadrao Forca Total S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/465515.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sDjfX1fO5UYIxWvFlzivM2WvA6M.jpg'),
(160435, 11371, 'Aqua Teen Esquadrao Forca Total S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/465516.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pYLTEMBS4rAE3j6cYjGjP8gievR.jpg'),
(160436, 11372, 'Aqua Teen Esquadrao Forca Total S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465517.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aYphUfDza9FAQW5bnfwQjF64GiX.jpg'),
(160437, 11372, 'Aqua Teen Esquadrao Forca Total S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465518.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rUFTYF2yZuu2q9Diwzxw99gUHa1.jpg'),
(160438, 11372, 'Aqua Teen Esquadrao Forca Total S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465519.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6on14Tist0o4kQWAaFiBiAUgZJO.jpg'),
(160439, 11372, 'Aqua Teen Esquadrao Forca Total S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465520.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vN7ToB82yZUpMqeixbYDyKgDIUg.jpg'),
(160440, 11372, 'Aqua Teen Esquadrao Forca Total S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465521.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ehPfDCOtm04BTJqUc5gpSwBSxSM.jpg'),
(160441, 11372, 'Aqua Teen Esquadrao Forca Total S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465522.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tup5gOfx8YOperWUIs6J4TAmvOE.jpg'),
(160442, 11372, 'Aqua Teen Esquadrao Forca Total S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465523.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lVnXSi12hyJ3J7TiFOYdk0bXC75.jpg'),
(160443, 11372, 'Aqua Teen Esquadrao Forca Total S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465524.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rQE7OKYfptJvxqmS4Hv6Uooa1rp.jpg'),
(160444, 11372, 'Aqua Teen Esquadrao Forca Total S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465525.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vsxJtCTDi4f1DsQCd6hZAEXSf9S.jpg'),
(160445, 11372, 'Aqua Teen Esquadrao Forca Total S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465526.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6U1AEgdUfL43GeShsTrOeaVAZSC.jpg'),
(160446, 11372, 'Aqua Teen Esquadrao Forca Total S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465527.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/92ck0eTPLykAl1sVH5QIElLtjLJ.jpg'),
(160447, 11372, 'Aqua Teen Esquadrao Forca Total S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465528.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uPh7TlUv8j0F2OAPgS61MP8WgmD.jpg'),
(160448, 11372, 'Aqua Teen Esquadrao Forca Total S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465529.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f9YRCEKkGEOA4xH4ypuKsNSHMnS.jpg'),
(160449, 11373, 'Aqua Teen Esquadrao Forca Total S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465530.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2WaTJUhtXMzZVtBsfagUTMQ5rNZ.jpg'),
(160450, 11373, 'Aqua Teen Esquadrao Forca Total S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465531.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6FEJURoj8uHAm4R8GWz2o1wMX7J.jpg'),
(160451, 11373, 'Aqua Teen Esquadrao Forca Total S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465532.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eMlALzlBkYQfgIiRN7CLc3EOw3u.jpg'),
(160452, 11373, 'Aqua Teen Esquadrao Forca Total S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465533.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eMlALzlBkYQfgIiRN7CLc3EOw3u.jpg'),
(160453, 11373, 'Aqua Teen Esquadrao Forca Total S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465534.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q12x2CdoUJTdYNXkdetMS0DvdAn.jpg'),
(160454, 11373, 'Aqua Teen Esquadrao Forca Total S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465535.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zmq9G53eZ5HBgxYXn1cqXuX9XOG.jpg'),
(160455, 11373, 'Aqua Teen Esquadrao Forca Total S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465536.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/40OmzBkaPpXTNNJdvZqBIA0BG6k.jpg'),
(160456, 11373, 'Aqua Teen Esquadrao Forca Total S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465537.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uabuK5ctsCJYv0hG29QNzs5bDT3.jpg'),
(160457, 11373, 'Aqua Teen Esquadrao Forca Total S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465538.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zTmoPzzSObfGor4X87ukWuzWT6R.jpg'),
(160458, 11373, 'Aqua Teen Esquadrao Forca Total S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465539.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zw1VeOIucWpnwfTic38wTHUAGhj.jpg'),
(160459, 11373, 'Aqua Teen Esquadrao Forca Total S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465540.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ugGBar1ZC02YYsA9EjXOtWD4cHf.jpg'),
(160460, 11373, 'Aqua Teen Esquadrao Forca Total S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465541.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y79KPn10vOmfYcQTPmyBMZtCXCw.jpg'),
(160461, 11373, 'Aqua Teen Esquadrao Forca Total S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465542.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5kcj9X0yyhwtHuaJDoZdNxKyMkV.jpg'),
(160462, 11374, 'Aqua Teen Esquadrao Forca Total S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/725580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160463, 11374, 'Aqua Teen Esquadrao Forca Total S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/725581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160464, 11374, 'Aqua Teen Esquadrao Forca Total S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/725582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160465, 11374, 'Aqua Teen Esquadrao Forca Total S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/725583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160466, 11374, 'Aqua Teen Esquadrao Forca Total S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/725584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160467, 11374, 'Aqua Teen Esquadrao Forca Total S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/725585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160468, 11374, 'Aqua Teen Esquadrao Forca Total S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/725586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160469, 11374, 'Aqua Teen Esquadrao Forca Total S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/725587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160470, 11374, 'Aqua Teen Esquadrao Forca Total S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/725588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160471, 11375, 'Aqua Teen Esquadrao Forca Total S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/725589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160472, 11375, 'Aqua Teen Esquadrao Forca Total S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/725590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160473, 11375, 'Aqua Teen Esquadrao Forca Total S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/725591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160474, 11375, 'Aqua Teen Esquadrao Forca Total S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/725592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160475, 11375, 'Aqua Teen Esquadrao Forca Total S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/725593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160476, 11375, 'Aqua Teen Esquadrao Forca Total S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/725594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160477, 11375, 'Aqua Teen Esquadrao Forca Total S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/725595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160478, 11375, 'Aqua Teen Esquadrao Forca Total S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/725596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160479, 11375, 'Aqua Teen Esquadrao Forca Total S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/725597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160480, 11375, 'Aqua Teen Esquadrao Forca Total S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/725598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160481, 11375, 'Aqua Teen Esquadrao Forca Total S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/725599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160482, 11375, 'Aqua Teen Esquadrao Forca Total S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/725600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160483, 11376, 'Aqua Teen Esquadrao Forca Total S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/725601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160484, 11376, 'Aqua Teen Esquadrao Forca Total S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/725602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160485, 11376, 'Aqua Teen Esquadrao Forca Total S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/725603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160486, 11376, 'Aqua Teen Esquadrao Forca Total S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/725604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160487, 11376, 'Aqua Teen Esquadrao Forca Total S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/725605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160488, 11376, 'Aqua Teen Esquadrao Forca Total S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/725606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160489, 11376, 'Aqua Teen Esquadrao Forca Total S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/725607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160490, 11376, 'Aqua Teen Esquadrao Forca Total S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/725608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160491, 11376, 'Aqua Teen Esquadrao Forca Total S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/725609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160492, 11376, 'Aqua Teen Esquadrao Forca Total S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/725610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160493, 11377, 'Aqua Teen Esquadrao Forca Total S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/725611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160494, 11377, 'Aqua Teen Esquadrao Forca Total S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/725612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160495, 11377, 'Aqua Teen Esquadrao Forca Total S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/725613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160496, 11377, 'Aqua Teen Esquadrao Forca Total S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/725614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160497, 11377, 'Aqua Teen Esquadrao Forca Total S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/725615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160498, 11377, 'Aqua Teen Esquadrao Forca Total S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/725616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160499, 11377, 'Aqua Teen Esquadrao Forca Total S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/725617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160500, 11377, 'Aqua Teen Esquadrao Forca Total S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/725618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160501, 11377, 'Aqua Teen Esquadrao Forca Total S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/725619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160502, 11377, 'Aqua Teen Esquadrao Forca Total S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/725620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160503, 11378, 'Aqua Teen Esquadrao Forca Total S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/725621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160504, 11378, 'Aqua Teen Esquadrao Forca Total S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/725622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160505, 11378, 'Aqua Teen Esquadrao Forca Total S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/725623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160506, 11378, 'Aqua Teen Esquadrao Forca Total S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/725624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160507, 11378, 'Aqua Teen Esquadrao Forca Total S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/725625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160508, 11378, 'Aqua Teen Esquadrao Forca Total S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/725626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160509, 11378, 'Aqua Teen Esquadrao Forca Total S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/725627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160510, 11378, 'Aqua Teen Esquadrao Forca Total S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/725628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160511, 11378, 'Aqua Teen Esquadrao Forca Total S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/725629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160512, 11378, 'Aqua Teen Esquadrao Forca Total S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/725630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160513, 11379, 'Aqua Teen Esquadrao Forca Total S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/725631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160514, 11379, 'Aqua Teen Esquadrao Forca Total S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/725632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160515, 11379, 'Aqua Teen Esquadrao Forca Total S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/725633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160516, 11379, 'Aqua Teen Esquadrao Forca Total S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/725634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160517, 11379, 'Aqua Teen Esquadrao Forca Total S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/725635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160518, 11379, 'Aqua Teen Esquadrao Forca Total S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/725636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160519, 11379, 'Aqua Teen Esquadrao Forca Total S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/725637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160520, 11379, 'Aqua Teen Esquadrao Forca Total S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/725638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160521, 11379, 'Aqua Teen Esquadrao Forca Total S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/725639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160522, 11380, 'Aqua Teen Esquadrao Forca Total S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/725640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160523, 11380, 'Aqua Teen Esquadrao Forca Total S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/725641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160524, 11380, 'Aqua Teen Esquadrao Forca Total S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/725642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160525, 11380, 'Aqua Teen Esquadrao Forca Total S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/725643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160526, 11380, 'Aqua Teen Esquadrao Forca Total S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/725644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fcFVxz9IZ6PhM3tlB6877oUwTlD.jpg'),
(160527, 11381, 'Bob O Construtor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465423.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w4lkzt1hZatXqPCcvMh8gn5uDPE.jpg'),
(160528, 11381, 'Bob O Construtor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465424.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gHUjWZr8ogr6eWmWniwuZafO7zv.jpg'),
(160529, 11381, 'Bob O Construtor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465425.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5QpZcWPUZAgIh042vWZmZjFna9f.jpg'),
(160530, 11381, 'Bob O Construtor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465426.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aSNq0X3cWuklJOMrYLpdmUowuPB.jpg'),
(160531, 11381, 'Bob O Construtor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465427.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dia01TIUouEUMIoPGfK34m1xJu9.jpg'),
(160532, 11381, 'Bob O Construtor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465428.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jVmJF6ycXC94D0nJC7DMX9Hs0vJ.jpg'),
(160533, 11381, 'Bob O Construtor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465429.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pCfmRLDij2fXNde25DkO6RGAHSC.jpg'),
(160534, 11381, 'Bob O Construtor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465430.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oelJ5aMCgkw61rYoskDgry4Gpnd.jpg'),
(160535, 11381, 'Bob O Construtor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465431.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ePipfbA4tDYhQQ6RyfjnZ8pl9y.jpg'),
(160536, 11381, 'Bob O Construtor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465432.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xeMxdzdUvLy8cRkY4lzwYQnAlFf.jpg'),
(160537, 11381, 'Bob O Construtor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465433.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3sTYG6TrpwYBd84rxBnH8lIRBBv.jpg'),
(160538, 11381, 'Bob O Construtor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465434.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cNrV4qo4KBFxZcgyUmYqtvmkPuN.jpg'),
(160539, 11381, 'Bob O Construtor S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465435.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hz5SYI0oJc126lm871kUs8g9Zg3.jpg'),
(160540, 11382, 'Bob O Construtor S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465436.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vAaM3rZmsVSXlTyNy2fuFE5dDbW.jpg'),
(160541, 11382, 'Bob O Construtor S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465437.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cLod7woqxxVluIpMMNkUWt5euS6.jpg'),
(160542, 11382, 'Bob O Construtor S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465438.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7zZFXB6o7mVjH90qf1fy3cbcoih.jpg'),
(160543, 11382, 'Bob O Construtor S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465439.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eWJw04gF7XxYNAOq6SmsWyC9TE8.jpg'),
(160544, 11382, 'Bob O Construtor S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465440.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k1saWUgHTUPWYf5EVhmMwwzuTqH.jpg'),
(160545, 11382, 'Bob O Construtor S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465441.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bAZlA4zxZsF60eOw5zfE6TPbMQ7.jpg'),
(160546, 11382, 'Bob O Construtor S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465442.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/diqpJZXvBsiexYQz06N3jqwcxR8.jpg'),
(160547, 11382, 'Bob O Construtor S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465443.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dbTgFCNzZ33WmB2JMS24WuKD0H9.jpg'),
(160548, 11382, 'Bob O Construtor S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465444.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lZV7q7FvjTSoyNwHulstLFDOf6i.jpg'),
(160549, 11382, 'Bob O Construtor S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465445.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rIGu5WNVL3HhUD0ZJfhk2pR3vp2.jpg'),
(160550, 11382, 'Bob O Construtor S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465446.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xxL66xUGXZyUbl2xStBpGIIHNhW.jpg'),
(160551, 11382, 'Bob O Construtor S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465447.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vQfVxqOTWEnGSjxRnYDWS8Awrtc.jpg'),
(160552, 11382, 'Bob O Construtor S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465448.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sbcjvUf1NYCWSiXwYlwm904mJap.jpg'),
(160553, 11383, 'Bob O Construtor S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465449.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/41gcF4PtGPm5LiXSOax20SxxF6y.jpg'),
(160554, 11383, 'Bob O Construtor S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465450.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/giA3oOArsVd7bZU2zbLwsLruVCK.jpg'),
(160555, 11383, 'Bob O Construtor S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465451.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6GIrpGqNO9MmCgTZstTfYKhH8XF.jpg'),
(160556, 11383, 'Bob O Construtor S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465452.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9ZJZT8Kgn2Ds9vW5kIzEISh0ijL.jpg'),
(160557, 11383, 'Bob O Construtor S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465453.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yy4cOIXgsKEy2GmiykF71xSzPwl.jpg'),
(160558, 11383, 'Bob O Construtor S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465454.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c7Yjb5zgaEocDM5tIWCV0ADiPIV.jpg'),
(160559, 11383, 'Bob O Construtor S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465455.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sCBivUoxSBiOoQhQWawWpDikfVP.jpg'),
(160560, 11383, 'Bob O Construtor S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465456.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A2xdzN27KdtzyIyasQQyHSo7ZLJ.jpg'),
(160561, 11383, 'Bob O Construtor S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465457.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/en7FWdI7bcSYwyD3i1oBJ2m844D.jpg'),
(160562, 11383, 'Bob O Construtor S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6JdTZ7OlXeTjYirkb4pBWytRXtK.jpg'),
(160563, 11383, 'Bob O Construtor S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465459.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fwFFltb3WoA9mTUjcZXt3Yx2XBo.jpg'),
(160564, 11383, 'Bob O Construtor S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465460.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jafwJankU3eul1ZpS6LAGUjNznp.jpg'),
(160565, 11383, 'Bob O Construtor S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465461.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kUkvApdlDnNksIoaMe76h7wdGpw.jpg'),
(160566, 11384, 'Bob O Construtor S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465462.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5608FNn2yDjhK4n6fXVHcMMll0f.jpg'),
(160567, 11384, 'Bob O Construtor S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465463.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pH7Kl7iQOhYs1mEbDHBpzeBcJVo.jpg'),
(160568, 11384, 'Bob O Construtor S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465464.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fPywmKMQx2dJZ89xpS1tdtnvRoc.jpg'),
(160569, 11384, 'Bob O Construtor S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465465.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ml4wqYcKnhNd51LhEuMJz32e0GG.jpg'),
(160570, 11384, 'Bob O Construtor S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465466.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qGNzpIzCx8uQXxd3EsXFGkYbeC5.jpg'),
(160571, 11384, 'Bob O Construtor S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465467.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sXJbhjO13sBqo7KV7UDuIXe00Wm.jpg'),
(160572, 11384, 'Bob O Construtor S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465468.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6WY5usZM63WUWmhqPFJyU5rG5eC.jpg'),
(160573, 11384, 'Bob O Construtor S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465469.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/19lFwlZXZg76Ns1dZY48wP66M9C.jpg'),
(160574, 11384, 'Bob O Construtor S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465470.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9ywfPezz36tGgfi3TRGolEabfiq.jpg'),
(160575, 11384, 'Bob O Construtor S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465471.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vzugwDP3phSk1IKItfFJ2QVYzMp.jpg'),
(160576, 11384, 'Bob O Construtor S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465472.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l9zZ2lMShdr79qa7EFHZGgipLmw.jpg'),
(160577, 11384, 'Bob O Construtor S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465473.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jKAJk8RY4OGsf4mpEvejQD7K1cG.jpg'),
(160578, 11384, 'Bob O Construtor S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465474.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Aq3luizY7dahbbM52BZOPDQtSh.jpg'),
(160579, 11385, 'Capture Lover [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465413.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/skUBGBXFYE7z2lbmu4BumMXroz6.jpg'),
(160580, 11385, 'Capture Lover [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465414.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/skUBGBXFYE7z2lbmu4BumMXroz6.jpg'),
(160581, 11385, 'Capture Lover [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465415.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/skUBGBXFYE7z2lbmu4BumMXroz6.jpg'),
(160582, 11385, 'Capture Lover [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9IYmvND3kDIGP6bt2N79VPoY0uI.jpg'),
(160583, 11385, 'Capture Lover [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9IYmvND3kDIGP6bt2N79VPoY0uI.jpg'),
(160584, 11385, 'Capture Lover [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9IYmvND3kDIGP6bt2N79VPoY0uI.jpg'),
(160585, 11385, 'Capture Lover [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9IYmvND3kDIGP6bt2N79VPoY0uI.jpg'),
(160586, 11385, 'Capture Lover [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9IYmvND3kDIGP6bt2N79VPoY0uI.jpg'),
(160587, 11385, 'Capture Lover [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9IYmvND3kDIGP6bt2N79VPoY0uI.jpg'),
(160588, 11385, 'Capture Lover [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9IYmvND3kDIGP6bt2N79VPoY0uI.jpg'),
(160589, 11386, 'Casa Fantasma Hospedeiro Fantasma [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465387.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/guejDr9fKxOMPg2sZuRtcFzuxqQ.jpg'),
(160590, 11386, 'Casa Fantasma Hospedeiro Fantasma [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465388.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jgXLiVZS8kV9Fu75bXbF9hlobMs.jpg'),
(160591, 11386, 'Casa Fantasma Hospedeiro Fantasma [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465389.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tS5lTAkIImq42Ii4V2VOgPy8ds5.jpg'),
(160592, 11386, 'Casa Fantasma Hospedeiro Fantasma [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465390.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u9MFGMQQVgfeqMKsH7QHkvnfyPd.jpg'),
(160593, 11386, 'Casa Fantasma Hospedeiro Fantasma [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465391.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7aE5BLPdATaMv8vdFN3xXRCcOSn.jpg'),
(160594, 11386, 'Casa Fantasma Hospedeiro Fantasma [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465392.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t765AuWcII57zMnEqCZujWO0sGR.jpg'),
(160595, 11386, 'Casa Fantasma Hospedeiro Fantasma [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465393.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rAWuSPbP8HCg2E0U2bw2MbPnf3f.jpg'),
(160596, 11386, 'Casa Fantasma Hospedeiro Fantasma [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465394.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3QpZ3prudnFUSjQGT2eekbSNHuH.jpg'),
(160597, 11387, 'Como Morrer Sozinha [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465381.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yBkirnhQcdBpSkzfVe7r423zwUx.jpg'),
(160598, 11387, 'Como Morrer Sozinha [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465382.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yqC9vttelDytwgKXR1zZrJrUyik.jpg'),
(160599, 11387, 'Como Morrer Sozinha [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465383.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/29uhDoyQBda4Mic6C4TEVq1TWtQ.jpg'),
(160600, 11387, 'Como Morrer Sozinha [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465384.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rAqiOnKPkw4omAW57VtEdEcstwH.jpg'),
(160601, 11387, 'Como Morrer Sozinha [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465385.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pVpZy9nDKteabFO4O75Yee6kb6Y.jpg'),
(160602, 11387, 'Como Morrer Sozinha [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465386.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/31B0AFMoRZki3npzmBMDYam21XH.jpg'),
(160603, 11387, 'Como Morrer Sozinha [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/485494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9T6CEkRXUuwFMamBcCQPCzE18kT.jpg'),
(160604, 11387, 'Como Morrer Sozinha [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/485495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9T6CEkRXUuwFMamBcCQPCzE18kT.jpg'),
(160605, 11388, 'De Casa Nova S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465306.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r6A3PBtUbUPqRlCzFsCvrmXiFxE.jpg'),
(160606, 11388, 'De Casa Nova S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160607, 11388, 'De Casa Nova S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160608, 11388, 'De Casa Nova S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160609, 11388, 'De Casa Nova S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160610, 11388, 'De Casa Nova S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160611, 11388, 'De Casa Nova S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160612, 11388, 'De Casa Nova S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160613, 11388, 'De Casa Nova S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160614, 11388, 'De Casa Nova S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160615, 11388, 'De Casa Nova S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160616, 11389, 'De Casa Nova S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465317.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xeyOUd7zB0GzmAKhM0Sg3tjh54N.jpg'),
(160617, 11389, 'De Casa Nova S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465318.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eLR52vzlnlUktmB4hyn9y31f4Jn.jpg'),
(160618, 11389, 'De Casa Nova S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160619, 11389, 'De Casa Nova S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160620, 11389, 'De Casa Nova S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160621, 11389, 'De Casa Nova S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160622, 11389, 'De Casa Nova S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160623, 11389, 'De Casa Nova S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160624, 11389, 'De Casa Nova S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465325.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bLdi73inppkw7gzv2C4WgDWPlyM.jpg'),
(160625, 11389, 'De Casa Nova S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160626, 11390, 'De Casa Nova S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465327.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/clmrERx05CQpCVrCCdD9BpCHXTC.jpg'),
(160627, 11390, 'De Casa Nova S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465328.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xeZAM24pwDELb6A1uxKPFsZ5g6d.jpg'),
(160628, 11390, 'De Casa Nova S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465329.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sVuPE6oNS8DbQw34lZgAmk8Y2U5.jpg'),
(160629, 11390, 'De Casa Nova S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465330.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/abfaxD7Qc9vusljKxP0QgHcpRS5.jpg'),
(160630, 11390, 'De Casa Nova S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465331.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wVMkJBV7XsJBVzA0m69DF17tu38.jpg'),
(160631, 11390, 'De Casa Nova S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465332.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qYevQp9UVCP0GwxARbIqUeQgHyw.jpg'),
(160632, 11390, 'De Casa Nova S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465333.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b6tq1xtkjdEXk99vDe70sQbEiZw.jpg'),
(160633, 11390, 'De Casa Nova S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465334.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1TL2bfWz51YzGipeiT4AyeNwReJ.jpg'),
(160634, 11390, 'De Casa Nova S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465335.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sSsctGbIV9uAGoktQbNl7p9QQnB.jpg'),
(160635, 11390, 'De Casa Nova S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465336.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x84ZVlGwaV1MnBWzpicZtMTKJFd.jpg'),
(160636, 11390, 'De Casa Nova S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465337.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oG8BKZSaoIK17du3uoABW80bH0e.jpg'),
(160637, 11390, 'De Casa Nova S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465338.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ll50650tCHwyCrOWmhdfE9gqWR6.jpg'),
(160638, 11390, 'De Casa Nova S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465339.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1s9PVmjSkIkvjjpcKzBusoDONZ9.jpg'),
(160639, 11391, 'De Casa Nova S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465340.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AbcVtOM46MiNEDQYp3ZPvv7STs9.jpg'),
(160640, 11391, 'De Casa Nova S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465341.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mHaY0phivGJO6QOZ5ib7ZE3lqqm.jpg'),
(160641, 11391, 'De Casa Nova S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465342.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wkvkJfZIXN7tJBTOaL5R9BkGVwR.jpg'),
(160642, 11391, 'De Casa Nova S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465343.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l2LR4GhWMqacaGNTpGrrJzSdGlB.jpg'),
(160643, 11391, 'De Casa Nova S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465344.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1aSuncvyq5TANe8tcyVO8cetxZ8.jpg'),
(160644, 11391, 'De Casa Nova S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465345.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ljB3t8K5pr5KqUpDDvqOfOudOmp.jpg'),
(160645, 11391, 'De Casa Nova S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465346.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vht9bMv4LU8Zgz7TanbGRJox9TJ.jpg'),
(160646, 11391, 'De Casa Nova S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465347.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v4Km0GX4q624T7RdFghGfan6PLo.jpg'),
(160647, 11391, 'De Casa Nova S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465348.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kjk5LrtKDHNPLCgPmOE0N8JyyNk.jpg'),
(160648, 11391, 'De Casa Nova S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465349.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AfBsZKlh2eqBdHzOGydmZKSEIm9.jpg'),
(160649, 11391, 'De Casa Nova S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465350.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8oOiqTyZJ3ZWxajK2ry06fUbVxL.jpg'),
(160650, 11391, 'De Casa Nova S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465351.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4tXloRUsNFLv2LnUJN7gGVUSWgj.jpg'),
(160651, 11391, 'De Casa Nova S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465352.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2vVXYyC69iZ0xRM06uVh71CDxnr.jpg'),
(160652, 11391, 'De Casa Nova S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/465353.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s4UfF1Wlo3P11bf3ZuuntY6342C.jpg'),
(160653, 11391, 'De Casa Nova S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/465354.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p7d2j5jCF7fMn1cxpaZfQeuhl6N.jpg'),
(160654, 11392, 'De Casa Nova S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160655, 11392, 'De Casa Nova S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160656, 11392, 'De Casa Nova S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160657, 11392, 'De Casa Nova S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160658, 11392, 'De Casa Nova S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160659, 11392, 'De Casa Nova S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160660, 11392, 'De Casa Nova S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160661, 11392, 'De Casa Nova S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160662, 11392, 'De Casa Nova S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160663, 11392, 'De Casa Nova S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160664, 11392, 'De Casa Nova S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160665, 11392, 'De Casa Nova S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160666, 11392, 'De Casa Nova S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160667, 11392, 'De Casa Nova S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/465368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160668, 11392, 'De Casa Nova S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/465369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUfLrcZeBCG4TvAXUc6YYIQFYFA.jpg'),
(160669, 11393, 'De Casa Nova S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465370.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tmnxwtP6YHAAbXnJhTDXcJ4wtXq.jpg'),
(160670, 11393, 'De Casa Nova S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465371.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oaTZNdqOh1QpsRS3Fzbxmre9QbH.jpg'),
(160671, 11393, 'De Casa Nova S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465372.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lQ8AfCq824OZUuAHZCYJmAUqahK.jpg'),
(160672, 11393, 'De Casa Nova S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465373.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iK80YMTluwYSEL1RndgqU5ts1Gk.jpg'),
(160673, 11393, 'De Casa Nova S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465374.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nPyM1twV9iAPcjQRHFILmW7s956.jpg'),
(160674, 11393, 'De Casa Nova S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465375.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dC6fAah4YkfnFK6c9VKooYCD9gg.jpg'),
(160675, 11393, 'De Casa Nova S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465376.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hF3nkRcSnM03ul2WPUjtahRUKT1.jpg'),
(160676, 11393, 'De Casa Nova S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465377.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eh5zwjzeWncoEXOy6aRL3fxi60m.jpg'),
(160677, 11393, 'De Casa Nova S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465378.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9JZlNDfo1SCjoUDSzSUd2asI2lr.jpg'),
(160678, 11393, 'De Casa Nova S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465379.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hqb4ASPg3ZtYy1bLARwrt4GgX7i.jpg'),
(160679, 11393, 'De Casa Nova S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465380.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fMYtVQUjwINZ7vb6u5bDvJi3IFR.jpg'),
(160680, 11394, 'Great News S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465283.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/if07y2SzA3HIXXlnFGeC1HDhZBg.jpg'),
(160681, 11394, 'Great News S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465284.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nkQxZEzHIjGaDuCKdV44CZz3Z6N.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(160682, 11394, 'Great News S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465285.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gq2Wt1U4NECPm6hb08aaXy1jmdP.jpg'),
(160683, 11394, 'Great News S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465286.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wxkbfMZ1C5k6ykLflXBi6m5PjfH.jpg'),
(160684, 11394, 'Great News S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465287.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1lh3zSTXGioiZIyJnNqePdjFtj8.jpg'),
(160685, 11394, 'Great News S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465288.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pmgUeAT8x0OMIqH0Hb8N9EmePN0.jpg'),
(160686, 11394, 'Great News S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465289.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/10GrEV7pXxmZ570e2q8HZXZ0S4P.jpg'),
(160687, 11394, 'Great News S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465290.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gZWeCzo69fDPyhJevbo56RcANSt.jpg'),
(160688, 11394, 'Great News S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465291.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9jmr99c4DJdu1A6vIRgj2DSDzWM.jpg'),
(160689, 11394, 'Great News S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465292.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3BzgIrT2oBBRx5y4rm46E1b7dcA.jpg'),
(160690, 11395, 'Great News S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465293.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uATTJy0a7VDi20upPl9wcqDuzpe.jpg'),
(160691, 11395, 'Great News S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465294.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cJYExWpoikchF2rhVnL7Tdb6i1J.jpg'),
(160692, 11395, 'Great News S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465295.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1Eulz3ZXofIquaPMSCe5hmoIpms.jpg'),
(160693, 11395, 'Great News S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465296.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xZKOC31r6jTWlras25DvKBAvbC4.jpg'),
(160694, 11395, 'Great News S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465297.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/85QenqsJ5CBW5JiO53uA9iIyk1W.jpg'),
(160695, 11395, 'Great News S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465298.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oDDkqLtxNoUn5V7pLuWqgzdamg3.jpg'),
(160696, 11395, 'Great News S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465299.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9mHcWakOsRMgGl2AOpCclEV1RGH.jpg'),
(160697, 11395, 'Great News S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465300.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2WXpbRaFEFI2B1DE4Ssv4Hx63hC.jpg'),
(160698, 11395, 'Great News S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465301.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tHlGd8dQEHKIecIp8lhB3n7meap.jpg'),
(160699, 11395, 'Great News S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465302.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1KVrYLEFHK2a2nwnijQK8BYruTE.jpg'),
(160700, 11395, 'Great News S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465303.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iyBO1f6hjrxS2KXvdJyh2tc6FMX.jpg'),
(160701, 11395, 'Great News S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465304.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/enWCdRNeevjWXaxMSIJADI0exxj.jpg'),
(160702, 11395, 'Great News S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465305.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sPsLNRpkzo5mkfO7eju5qCqT6VY.jpg'),
(160703, 11396, 'Homens Da Montanha Franco Atirador S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUevSgU0VI6s3JFnAMBHLOorX2E.jpg'),
(160704, 11396, 'Homens Da Montanha Franco Atirador S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUevSgU0VI6s3JFnAMBHLOorX2E.jpg'),
(160705, 11396, 'Homens Da Montanha Franco Atirador S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUevSgU0VI6s3JFnAMBHLOorX2E.jpg'),
(160706, 11396, 'Homens Da Montanha Franco Atirador S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUevSgU0VI6s3JFnAMBHLOorX2E.jpg'),
(160707, 11396, 'Homens Da Montanha Franco Atirador S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUevSgU0VI6s3JFnAMBHLOorX2E.jpg'),
(160708, 11396, 'Homens Da Montanha Franco Atirador S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUevSgU0VI6s3JFnAMBHLOorX2E.jpg'),
(160709, 11396, 'Homens Da Montanha Franco Atirador S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUevSgU0VI6s3JFnAMBHLOorX2E.jpg'),
(160710, 11396, 'Homens Da Montanha Franco Atirador S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uUevSgU0VI6s3JFnAMBHLOorX2E.jpg'),
(160711, 11397, 'In Your Heart [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465267.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ejmhzEP8ioYyWtLwppI7Sv3hGfL.jpg'),
(160712, 11397, 'In Your Heart [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465268.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b0vUSbpFr23IkmOa7WNNZnj73fy.jpg'),
(160713, 11397, 'In Your Heart [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465269.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/leWhfEzearWAw3qr5k0VUA8ZWOn.jpg'),
(160714, 11397, 'In Your Heart [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465270.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ajTDZFHeXyedkkuRY4gIlinWE7b.jpg'),
(160715, 11397, 'In Your Heart [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465271.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/61h6gomOrmIH2QzRAlPcjDxu2En.jpg'),
(160716, 11397, 'In Your Heart [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465272.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fvRnz7klp1KwDXDGy1N3aQr0jvV.jpg'),
(160717, 11397, 'In Your Heart [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465273.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mI5wIUCGaLfVHVs90hooTIRLjM5.jpg'),
(160718, 11397, 'In Your Heart [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465274.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pJnqXspE9EYc3vaVZHFna4sBCuG.jpg'),
(160719, 11398, 'Jogo Mortal [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465229.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hY9ubGNwP0fxzV1pETX5p5xkjPb.jpg'),
(160720, 11398, 'Jogo Mortal [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465230.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6jOJNc73J0y69zBno1fsxGfIill.jpg'),
(160721, 11398, 'Jogo Mortal [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465231.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yXL2kLxGwt3culn5Cl0cawGmFf3.jpg'),
(160722, 11398, 'Jogo Mortal [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465232.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/DlOBcCC6KI5wlw6kKEiqtheBb1.jpg'),
(160723, 11398, 'Jogo Mortal [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465233.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nMBwoP1k4sElS7pJVsGLGJZHcls.jpg'),
(160724, 11398, 'Jogo Mortal [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465234.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f2NqxLsdqD9M6IB2VcPCq7sIAS3.jpg'),
(160725, 11398, 'Jogo Mortal [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465235.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a13waWk02p4kjEPgTQbkoNI3e2q.jpg'),
(160726, 11398, 'Jogo Mortal [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465236.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wDUEDXxcsrNSx00sTcmXbGcRA4i.jpg'),
(160727, 11398, 'Jogo Mortal [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465237.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/am58qJcz0trAfUSCW3F041h63HG.jpg'),
(160728, 11398, 'Jogo Mortal [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465238.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xffFfqDvjcRJaotB7IauMMh0sXc.jpg'),
(160729, 11398, 'Jogo Mortal [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465239.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5nO11VT4vF7HNiJpVPJfG8wQbUD.jpg'),
(160730, 11398, 'Jogo Mortal [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465240.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zrrslH1hICen9OUqEvgC1xbXAll.jpg'),
(160731, 11398, 'Jogo Mortal [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465241.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1ex3TUPk1GhZcN3Arx3hBprIZtG.jpg'),
(160732, 11398, 'Jogo Mortal [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/465242.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yReoK3xbygfk2Ou3NL7sJ7rtW9q.jpg'),
(160733, 11398, 'Jogo Mortal [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/465243.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w4BdJgY1eMmBVCtOCQFcW3yjpRv.jpg'),
(160734, 11398, 'Jogo Mortal [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/465244.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zo6gwGh9ylzZ1ml3DJpE5Qk2Cc4.jpg'),
(160735, 11398, 'Jogo Mortal [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/465245.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hNnpsRejdDQWyOlNhIYxc932rg7.jpg'),
(160736, 11398, 'Jogo Mortal [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/465246.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Yfc6ta4qybCOT3bJzCkwhDbzsC.jpg'),
(160737, 11398, 'Jogo Mortal [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/465247.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bHjkN6nIrRdFdsdwETDj1wOrAtM.jpg'),
(160738, 11398, 'Jogo Mortal [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/465248.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vfKqRm1Lxo7GoFrRAkDTy1vLcYK.jpg'),
(160739, 11398, 'Jogo Mortal [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/465249.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bNr8UNdhNpbHBy9Ma6jHoSq5ljE.jpg'),
(160740, 11398, 'Jogo Mortal [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/465250.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1YlIBHOiWCBPTZhaa26nsdM20hZ.jpg'),
(160741, 11398, 'Jogo Mortal [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/465251.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wnHy5LJ0i2aLfEu1xwcoUkmYRzQ.jpg'),
(160742, 11398, 'Jogo Mortal [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/465252.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8k1Hr7XlzXmNuLzlpQKJt2rQ6p5.jpg'),
(160743, 11398, 'Jogo Mortal [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/465253.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zMFAhWS6AyRkMyUFfRVhHpFOFRy.jpg'),
(160744, 11398, 'Jogo Mortal [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/465254.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1cKjgwo1klhG8nsQg2ebMcAUc6x.jpg'),
(160745, 11398, 'Jogo Mortal [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/465255.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2d1RQsj2ZYPBPjAEBOESW9Ws7jH.jpg'),
(160746, 11398, 'Jogo Mortal [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/465256.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e7i92DZ7noaeXWgUIg873zTbG1A.jpg'),
(160747, 11398, 'Jogo Mortal [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/465257.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rtbOvJw8XmEr7EdpteFWykgeDkH.jpg'),
(160748, 11398, 'Jogo Mortal [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/465258.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/crlDAiqQ8tgNED9ENdvzvHOzU3S.jpg'),
(160749, 11398, 'Jogo Mortal [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/465259.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3zLYyt81sDo7EEkvHW2RfU82oLt.jpg'),
(160750, 11398, 'Jogo Mortal [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/465260.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u9xSFpaRGKKubkNbmq8zZUc2Sz5.jpg'),
(160751, 11398, 'Jogo Mortal [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/465261.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oVaiCBPPY1XtzJZEEe3GbZHrjsk.jpg'),
(160752, 11398, 'Jogo Mortal [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/465262.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x7KrctJ2QmmMp3dizFJRNa3aHxa.jpg'),
(160753, 11398, 'Jogo Mortal [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/465263.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f9mNYoHAVi4SiQC5ltkdUOB9pbm.jpg'),
(160754, 11398, 'Jogo Mortal [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/465264.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hmqqIax8UG1oZw0JuUKZMpda5Mi.jpg'),
(160755, 11398, 'Jogo Mortal [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/465265.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bdyX2j2opEUIYNUaidjoCFGNcjO.jpg'),
(160756, 11398, 'Jogo Mortal [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/465266.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g6bJBPjHX8veS2ON1XYMXACpTCj.jpg'),
(160757, 11399, 'Meu Segredinho [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160758, 11399, 'Meu Segredinho [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160759, 11399, 'Meu Segredinho [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160760, 11399, 'Meu Segredinho [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160761, 11399, 'Meu Segredinho [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160762, 11399, 'Meu Segredinho [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160763, 11399, 'Meu Segredinho [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160764, 11399, 'Meu Segredinho [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160765, 11399, 'Meu Segredinho [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160766, 11399, 'Meu Segredinho [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160767, 11399, 'Meu Segredinho [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160768, 11399, 'Meu Segredinho [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160769, 11399, 'Meu Segredinho [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160770, 11399, 'Meu Segredinho [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/465209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160771, 11399, 'Meu Segredinho [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/465210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160772, 11399, 'Meu Segredinho [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/465211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160773, 11399, 'Meu Segredinho [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/465212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160774, 11399, 'Meu Segredinho [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/465213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160775, 11399, 'Meu Segredinho [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/465214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160776, 11399, 'Meu Segredinho [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/465215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160777, 11399, 'Meu Segredinho [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/465216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160778, 11399, 'Meu Segredinho [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/465217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160779, 11399, 'Meu Segredinho [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/465218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160780, 11399, 'Meu Segredinho [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/465219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160781, 11399, 'Meu Segredinho [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/465220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160782, 11399, 'Meu Segredinho [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/465221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160783, 11399, 'Meu Segredinho [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/465222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160784, 11399, 'Meu Segredinho [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/465223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160785, 11399, 'Meu Segredinho [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/465224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160786, 11399, 'Meu Segredinho [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/465225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160787, 11399, 'Meu Segredinho [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/465226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160788, 11399, 'Meu Segredinho [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/465227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160789, 11399, 'Meu Segredinho [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/465228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KhYZ8HSuDkg8I663OIJ8b5CA8.jpg'),
(160790, 11400, 'Midnight Family S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465194.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/plue9wSUaiinNQ5H5EWJmAlP1OY.jpg'),
(160791, 11400, 'Midnight Family S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465195.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mMrC6wUtObrU4e4ViV28NaBYC0z.jpg'),
(160792, 11400, 'Midnight Family S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/469998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8pqNC7kcjs9xkmVDzXdX9OjrB0X.jpg'),
(160793, 11400, 'Midnight Family S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/477532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8pqNC7kcjs9xkmVDzXdX9OjrB0X.jpg'),
(160794, 11400, 'Midnight Family S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/482686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8pqNC7kcjs9xkmVDzXdX9OjrB0X.jpg'),
(160795, 11400, 'Midnight Family S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/490806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8pqNC7kcjs9xkmVDzXdX9OjrB0X.jpg'),
(160796, 11400, 'Midnight Family S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/492276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8pqNC7kcjs9xkmVDzXdX9OjrB0X.jpg'),
(160797, 11400, 'Midnight Family S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/499857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8pqNC7kcjs9xkmVDzXdX9OjrB0X.jpg'),
(160798, 11400, 'Midnight Family S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/505570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8pqNC7kcjs9xkmVDzXdX9OjrB0X.jpg'),
(160799, 11400, 'Midnight Family S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/509358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8pqNC7kcjs9xkmVDzXdX9OjrB0X.jpg'),
(160800, 11401, 'Mr McMahon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465188.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/luDwdlIRYLEZgJPnDykT6HfwUb6.jpg'),
(160801, 11401, 'Mr McMahon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465189.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dQOVgTVcd1fF7gGBOzHttUYMAk0.jpg'),
(160802, 11401, 'Mr McMahon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465190.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kqj8A0TwACOOjRadIfJGJJI3Iaj.jpg'),
(160803, 11401, 'Mr McMahon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465191.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g0HeLSXCZJ7pHsFWDeZjGFG7l6m.jpg'),
(160804, 11401, 'Mr McMahon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465192.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uM8TtWNuUalrK59QE61qjX0A2xI.jpg'),
(160805, 11401, 'Mr McMahon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465193.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jaKpEOO2HoI2OgcDjFTAOcg2Ync.jpg'),
(160806, 11402, 'Ninguem Quer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465178.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3WXZ2kTJtuK6j27ws1DSUO3PP7l.jpg'),
(160807, 11402, 'Ninguem Quer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465179.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gGED98zXDeqzwvav8pHgly1zirY.jpg'),
(160808, 11402, 'Ninguem Quer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465180.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eaRoEsZ1O1dxjgqzVcIIdyzV9e.jpg'),
(160809, 11402, 'Ninguem Quer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465181.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3Cr08ccrv5VumPwGppDLW1oNiVc.jpg'),
(160810, 11402, 'Ninguem Quer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465182.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qDk6n76HinlSmlSagg7xMjXuWZg.jpg'),
(160811, 11402, 'Ninguem Quer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465183.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i7ziMZh6erkGYGOQqYJRB0P5aa.jpg'),
(160812, 11402, 'Ninguem Quer S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465184.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fREh6JYQpmlyp7UG2jXQMvR2ntE.jpg'),
(160813, 11402, 'Ninguem Quer S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465185.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w2GdNdPF3qhT2tMbeViDkinBc9r.jpg'),
(160814, 11402, 'Ninguem Quer S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465186.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/KtHu2YZ9aWbWq4cX4P0OokZHOm.jpg'),
(160815, 11402, 'Ninguem Quer S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465187.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5vjGq9ZPzv1W35MppxIYdpE4ZBu.jpg'),
(160816, 11403, 'Ninguem Quer S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/893738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3VUn3S19QOltMhrqFclyMV8mAs8.jpg'),
(160817, 11403, 'Ninguem Quer S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/893739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5A9E0GCMDzIOlQiai0bfvVd6Wuw.jpg'),
(160818, 11403, 'Ninguem Quer S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/893740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gjB5Q8sCC6HQufm41i3hx8UVEjj.jpg'),
(160819, 11403, 'Ninguem Quer S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/893741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9nbRdHrR6OZkDqJfntt9NyZ4hx5.jpg'),
(160820, 11403, 'Ninguem Quer S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/893742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kzjmsVrHXGs4rlz0qKkexfjOetg.jpg'),
(160821, 11403, 'Ninguem Quer S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/893743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9y1dqDTlgenO6t43pXdl2W4AUSJ.jpg'),
(160822, 11403, 'Ninguem Quer S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/893744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nCevuJcpKsSugMMw9kIV9MTQeGs.jpg'),
(160823, 11403, 'Ninguem Quer S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/893745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sRacUGCjHcJq0svhguEDk0KLaDG.jpg'),
(160824, 11403, 'Ninguem Quer S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/893746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7W9IOMGihMxbWkvJFpcRyHDyBvk.jpg'),
(160825, 11403, 'Ninguem Quer S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/893747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qFfR54alsrcCXshJyEBjC3pBuBU.jpg'),
(160826, 11404, 'Nos Eramos Reis S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465172.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bvNIJQKHtDCVAoFSaUhjhRVOlAZ.jpg'),
(160827, 11404, 'Nos Eramos Reis S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465173.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eSkMa9R3BITooFH78ztoyW7bns3.jpg'),
(160828, 11404, 'Nos Eramos Reis S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465174.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qLMlmtUr4Dfn9QqFGxcTHxYP1Cz.jpg'),
(160829, 11404, 'Nos Eramos Reis S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465175.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A2E1n8RFYCdKX5YIgWBBellPzo.jpg'),
(160830, 11404, 'Nos Eramos Reis S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465176.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rv01rTDgZ6O5TIhYgozhcroNMab.jpg'),
(160831, 11404, 'Nos Eramos Reis S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465177.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uV956qczevLDHBbMALGMOYzPZDM.jpg'),
(160832, 11405, 'O Melhor Dia da Minha Vida [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465158.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vRkzSLKlKpqCtUjuVCdRGie87sR.jpg'),
(160833, 11405, 'O Melhor Dia da Minha Vida [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465159.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vI7Bvly34SwjoH7bWVTqWI2Qx4C.jpg'),
(160834, 11405, 'O Melhor Dia da Minha Vida [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465160.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yBgJt8i6vBjKuAOe9S3DLbEaFUT.jpg'),
(160835, 11405, 'O Melhor Dia da Minha Vida [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465161.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/beZFvohdCREc0g7xAtPepdYWo5D.jpg'),
(160836, 11405, 'O Melhor Dia da Minha Vida [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465162.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gEbVWGNx11j4pvjKLQExAp0SzUz.jpg'),
(160837, 11405, 'O Melhor Dia da Minha Vida [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465163.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f4gKyXKiyN1y7UpVYji7FywGzUr.jpg'),
(160838, 11405, 'O Melhor Dia da Minha Vida [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465164.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ronOwwxv6fJU2LlGnpNWdCCuYL7.jpg'),
(160839, 11405, 'O Melhor Dia da Minha Vida [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465165.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nOi4e1ZNatlEMGTnpPNY6JNq8eZ.jpg'),
(160840, 11405, 'O Melhor Dia da Minha Vida [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465166.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1PBsvAN58MVbbxizj3fhBv1EruV.jpg'),
(160841, 11405, 'O Melhor Dia da Minha Vida [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465167.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a4fgmExDqp7njzgmgqBKniqBOy7.jpg'),
(160842, 11405, 'O Melhor Dia da Minha Vida [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465168.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4SxryRTE0STz07M5ByZNt82SU2K.jpg'),
(160843, 11405, 'O Melhor Dia da Minha Vida [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465169.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l1A7ht1TcEU2B9VFBcXNNAPkDff.jpg'),
(160844, 11405, 'O Melhor Dia da Minha Vida [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465170.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gmBCzAYcad71yXz4MPrfSAQP97j.jpg'),
(160845, 11405, 'O Melhor Dia da Minha Vida [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/465171.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6R56cFeX6hzMI0Ux1ysQipJMqYm.jpg'),
(160846, 11406, 'O Segredo Bem Guardado [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465150.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ghskhkiyj7wJIkujcmKYmXkrzhW.jpg'),
(160847, 11406, 'O Segredo Bem Guardado [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465151.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fUyNIxuAKUmQKqSBxsq8KVL8E5N.jpg'),
(160848, 11406, 'O Segredo Bem Guardado [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465152.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cg4KmA5dsjg63J6UgqmXovkj9ea.jpg'),
(160849, 11406, 'O Segredo Bem Guardado [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465153.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gNoYnIZxkzFVmW1PAfr5zbxWfNG.jpg'),
(160850, 11406, 'O Segredo Bem Guardado [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465154.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wasNoWllsx5c9btqPAqAOABM9h4.jpg'),
(160851, 11406, 'O Segredo Bem Guardado [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4K2FZ2psi4VdlOBH6OunCSJ2sfd.jpg'),
(160852, 11406, 'O Segredo Bem Guardado [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4K2FZ2psi4VdlOBH6OunCSJ2sfd.jpg'),
(160853, 11406, 'O Segredo Bem Guardado [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4K2FZ2psi4VdlOBH6OunCSJ2sfd.jpg'),
(160854, 11407, 'O Sorriso Deixou Seus Olhos [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5I0wMjc8AZiAHcv9vdvT5vkMHyw.jpg'),
(160855, 11407, 'O Sorriso Deixou Seus Olhos [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5I0wMjc8AZiAHcv9vdvT5vkMHyw.jpg'),
(160856, 11407, 'O Sorriso Deixou Seus Olhos [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5I0wMjc8AZiAHcv9vdvT5vkMHyw.jpg'),
(160857, 11407, 'O Sorriso Deixou Seus Olhos [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5I0wMjc8AZiAHcv9vdvT5vkMHyw.jpg'),
(160858, 11407, 'O Sorriso Deixou Seus Olhos [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5I0wMjc8AZiAHcv9vdvT5vkMHyw.jpg'),
(160859, 11407, 'O Sorriso Deixou Seus Olhos [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5I0wMjc8AZiAHcv9vdvT5vkMHyw.jpg'),
(160860, 11407, 'O Sorriso Deixou Seus Olhos [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5I0wMjc8AZiAHcv9vdvT5vkMHyw.jpg'),
(160861, 11407, 'O Sorriso Deixou Seus Olhos [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5I0wMjc8AZiAHcv9vdvT5vkMHyw.jpg'),
(160862, 11407, 'O Sorriso Deixou Seus Olhos [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5I0wMjc8AZiAHcv9vdvT5vkMHyw.jpg'),
(160863, 11407, 'O Sorriso Deixou Seus Olhos [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5I0wMjc8AZiAHcv9vdvT5vkMHyw.jpg'),
(160864, 11407, 'O Sorriso Deixou Seus Olhos [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5I0wMjc8AZiAHcv9vdvT5vkMHyw.jpg'),
(160865, 11407, 'O Sorriso Deixou Seus Olhos [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5I0wMjc8AZiAHcv9vdvT5vkMHyw.jpg'),
(160866, 11407, 'O Sorriso Deixou Seus Olhos [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5I0wMjc8AZiAHcv9vdvT5vkMHyw.jpg'),
(160867, 11407, 'O Sorriso Deixou Seus Olhos [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/465147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5I0wMjc8AZiAHcv9vdvT5vkMHyw.jpg'),
(160868, 11407, 'O Sorriso Deixou Seus Olhos [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/465148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5I0wMjc8AZiAHcv9vdvT5vkMHyw.jpg'),
(160869, 11407, 'O Sorriso Deixou Seus Olhos [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/465149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5I0wMjc8AZiAHcv9vdvT5vkMHyw.jpg'),
(160870, 11408, 'Paint with Love [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465122.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8l9Wl02pi478NQNuNtUEVmh6Dqu.jpg'),
(160871, 11408, 'Paint with Love [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465123.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ffKrkTBTIOhHntvyVbpYACKEy36.jpg'),
(160872, 11408, 'Paint with Love [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zGSI2DVxyTPp0gSUbpJEk7XIokJ.jpg'),
(160873, 11408, 'Paint with Love [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zGSI2DVxyTPp0gSUbpJEk7XIokJ.jpg'),
(160874, 11408, 'Paint with Love [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zGSI2DVxyTPp0gSUbpJEk7XIokJ.jpg'),
(160875, 11408, 'Paint with Love [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zGSI2DVxyTPp0gSUbpJEk7XIokJ.jpg'),
(160876, 11408, 'Paint with Love [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zGSI2DVxyTPp0gSUbpJEk7XIokJ.jpg'),
(160877, 11408, 'Paint with Love [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zGSI2DVxyTPp0gSUbpJEk7XIokJ.jpg'),
(160878, 11408, 'Paint with Love [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zGSI2DVxyTPp0gSUbpJEk7XIokJ.jpg'),
(160879, 11408, 'Paint with Love [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zGSI2DVxyTPp0gSUbpJEk7XIokJ.jpg'),
(160880, 11408, 'Paint with Love [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zGSI2DVxyTPp0gSUbpJEk7XIokJ.jpg'),
(160881, 11408, 'Paint with Love [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zGSI2DVxyTPp0gSUbpJEk7XIokJ.jpg'),
(160882, 11409, 'Paul Hollywoods Big Continental Road Trip S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmpfN9emCBRqRQl0EG5F3egaXuR.jpg'),
(160883, 11409, 'Paul Hollywoods Big Continental Road Trip S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmpfN9emCBRqRQl0EG5F3egaXuR.jpg'),
(160884, 11409, 'Paul Hollywoods Big Continental Road Trip S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zmpfN9emCBRqRQl0EG5F3egaXuR.jpg'),
(160885, 11410, 'Precise Shot [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465114.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yZKOaQFClqclz4PnRwSL45kCjJh.jpg'),
(160886, 11410, 'Precise Shot [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465115.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yZKOaQFClqclz4PnRwSL45kCjJh.jpg'),
(160887, 11410, 'Precise Shot [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465116.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yZKOaQFClqclz4PnRwSL45kCjJh.jpg'),
(160888, 11410, 'Precise Shot [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465117.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yZKOaQFClqclz4PnRwSL45kCjJh.jpg'),
(160889, 11410, 'Precise Shot [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465118.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yZKOaQFClqclz4PnRwSL45kCjJh.jpg'),
(160890, 11411, 'Querida Sa chan [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cE2OlB7qqxAalgRJWmkmewwsRcW.jpg'),
(160891, 11411, 'Querida Sa chan [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cE2OlB7qqxAalgRJWmkmewwsRcW.jpg'),
(160892, 11411, 'Querida Sa chan [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cE2OlB7qqxAalgRJWmkmewwsRcW.jpg'),
(160893, 11411, 'Querida Sa chan [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cE2OlB7qqxAalgRJWmkmewwsRcW.jpg'),
(160894, 11411, 'Querida Sa chan [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cE2OlB7qqxAalgRJWmkmewwsRcW.jpg'),
(160895, 11411, 'Querida Sa chan [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cE2OlB7qqxAalgRJWmkmewwsRcW.jpg'),
(160896, 11411, 'Querida Sa chan [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cE2OlB7qqxAalgRJWmkmewwsRcW.jpg'),
(160897, 11411, 'Querida Sa chan [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cE2OlB7qqxAalgRJWmkmewwsRcW.jpg'),
(160898, 11411, 'Querida Sa chan [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cE2OlB7qqxAalgRJWmkmewwsRcW.jpg'),
(160899, 11411, 'Querida Sa chan [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cE2OlB7qqxAalgRJWmkmewwsRcW.jpg'),
(160900, 11411, 'Querida Sa chan [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cE2OlB7qqxAalgRJWmkmewwsRcW.jpg'),
(160901, 11411, 'Querida Sa chan [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cE2OlB7qqxAalgRJWmkmewwsRcW.jpg'),
(160902, 11412, 'Seu Homem [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465091.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rs4fuIRJKzlSiEljhebfgBTqAuj.jpg'),
(160903, 11412, 'Seu Homem [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465092.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dH79JVIlzjtKCSZw9QgZy2Uw3Ui.jpg'),
(160904, 11412, 'Seu Homem [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465093.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tAiRs1m4B3XFmhTz30iJCBL4Kcr.jpg'),
(160905, 11412, 'Seu Homem [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465094.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3OO1UHEkT5GbBrmexkLl2CMoAMt.jpg'),
(160906, 11412, 'Seu Homem [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465095.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5BgY4kiRDYxoGWD21TgJAycWCIJ.jpg'),
(160907, 11412, 'Seu Homem [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465096.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bpvWrLFiH65tKvJvldL1pwnXICX.jpg'),
(160908, 11412, 'Seu Homem [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465097.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p43m093b0zXnz8nOUNS19BxiFFC.jpg'),
(160909, 11412, 'Seu Homem [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465098.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jSWWd2rnnLffEUg856TPc2SA9pt.jpg'),
(160910, 11412, 'Seu Homem [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465099.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2NsSpbCxAZEor9oozHvBfB7mGGj.jpg'),
(160911, 11412, 'Seu Homem [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465100.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s8mOiP4qB2vwGTD7jkVwJqEe8jz.jpg'),
(160912, 11412, 'Seu Homem [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465101.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5ycj25ySNeH3ETaZzFcnEETSi2z.jpg'),
(160913, 11413, 'Shting Stars [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465075.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sGNBJiL0ZJEJyJL8Q4u8IKPnnku.jpg'),
(160914, 11413, 'Shting Stars [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465076.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tpMy71dGDCOGbIpsOEadO93P1oy.jpg'),
(160915, 11413, 'Shting Stars [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465077.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pPdgkkGQaBdgXT5emWAHtRwGhlT.jpg'),
(160916, 11413, 'Shting Stars [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465078.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/goq4HL7k15E145aiVlPW05wzFqO.jpg'),
(160917, 11413, 'Shting Stars [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465079.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oi2T7wU4IjVF0HW6wnjStM0w5wi.jpg'),
(160918, 11413, 'Shting Stars [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465080.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tep7eFucf4Dz4HKY3yZivHVbhSQ.jpg'),
(160919, 11413, 'Shting Stars [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465081.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a6wFOMTfcoJkUnvGhVCka6LXJnN.jpg'),
(160920, 11413, 'Shting Stars [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465082.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qVuiA1nxl1zDELFuj7abQ0emv5I.jpg'),
(160921, 11413, 'Shting Stars [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465083.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4EUoJpiw0bRwI2M4ecI5pr3wgFW.jpg'),
(160922, 11413, 'Shting Stars [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465084.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zgHkisfwO4e82msxSdp5UUI9G10.jpg'),
(160923, 11413, 'Shting Stars [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465085.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cDVgOJop2bPt5DzhnYTlGe6xVxt.jpg'),
(160924, 11413, 'Shting Stars [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465086.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pVH8mGPaUnVNclVn6lUKYfzN9Xc.jpg'),
(160925, 11413, 'Shting Stars [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465087.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aPTdMr7bFVe6sV40Tewmi5lO5jt.jpg'),
(160926, 11413, 'Shting Stars [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/465088.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3FAqSGK2Tf1yZ4hItu30HVfOEuL.jpg'),
(160927, 11413, 'Shting Stars [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/465089.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oDdlgyg8PWBANGztKGSVrdaxcpH.jpg'),
(160928, 11413, 'Shting Stars [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/465090.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qb7eKPYcKJRtH3ETvryH8soI4ql.jpg'),
(160929, 11414, 'Sob O Mar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465023.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pLurpfXKACDPvsm76Me38DzxK61.jpg'),
(160930, 11414, 'Sob O Mar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465024.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tCCWlmWH2UJ9PsAgvMbAHYrlYuo.jpg'),
(160931, 11414, 'Sob O Mar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465025.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iAO1m4aFAq33MUO0GBRp9d3hyEN.jpg'),
(160932, 11414, 'Sob O Mar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465026.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qTUSvFrnKT8DhFcG4Yf2o7YCSi7.jpg'),
(160933, 11414, 'Sob O Mar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465027.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2bKjtalSCVZzQEJ8Vsdls2XEkRW.jpg'),
(160934, 11414, 'Sob O Mar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465028.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fj10NkmeG7iRKQIUL3p3uRmQCRh.jpg'),
(160935, 11414, 'Sob O Mar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465029.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/avPe1GnITu0lPmPIYxDqVp0dIrZ.jpg'),
(160936, 11414, 'Sob O Mar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465030.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l8eX9twCE1HkBQozMQN2Z4oDTAs.jpg'),
(160937, 11414, 'Sob O Mar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465031.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e2lnP3K9sGHwrnpZGfyyIXEm936.jpg'),
(160938, 11414, 'Sob O Mar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465032.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tiMhU1nFESSMC33or0JFi6g7lpk.jpg'),
(160939, 11414, 'Sob O Mar S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465033.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8osFnrEx1MKL48BsnbVg2AKIrJg.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(160940, 11414, 'Sob O Mar S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465034.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1U6CiCdcgTyZuGzNlSvL9qtvRjG.jpg'),
(160941, 11414, 'Sob O Mar S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465035.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l5qb2F8fFUXn2T7JDaxoaSRMFw6.jpg'),
(160942, 11414, 'Sob O Mar S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/465036.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cvTuXxZSYv4262WrhqJDv8E1SHm.jpg'),
(160943, 11414, 'Sob O Mar S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/465037.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/orPYm5elKAxveGU7HOMF7MNSbZg.jpg'),
(160944, 11414, 'Sob O Mar S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/465038.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3tqvCXXcnzN2qBMdodnmEl1QUiG.jpg'),
(160945, 11414, 'Sob O Mar S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/465039.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oRt4FO3yjVE4YYx58KSTMdh7HFG.jpg'),
(160946, 11414, 'Sob O Mar S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/465040.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3pRQUy1zj3HLlfOunagZ3RXJvuN.jpg'),
(160947, 11414, 'Sob O Mar S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/465041.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qoy9Z8qNHgKtWgEnPuH8yEYeT2I.jpg'),
(160948, 11414, 'Sob O Mar S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/465042.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u29cB7NuBShMBAzzr6U6p7Pe3y7.jpg'),
(160949, 11414, 'Sob O Mar S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/465043.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eKdAgZKUQ7AwzaNxTKOHWfjwnyJ.jpg'),
(160950, 11414, 'Sob O Mar S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/465044.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eR3sI5QkpzsAgeOB7VqDIyuMCjf.jpg'),
(160951, 11414, 'Sob O Mar S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/465045.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9904eSz74EYp6gzHfHpRB5UPaJt.jpg'),
(160952, 11414, 'Sob O Mar S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/465046.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vy82giOggJRRvYf84OxQpD4yqkB.jpg'),
(160953, 11414, 'Sob O Mar S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/465047.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wFcZpJnCgYwk3zvIfGnUnipRNj.jpg'),
(160954, 11414, 'Sob O Mar S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/465048.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1p2IOruFWTzDmtM0bzHHasaqyLz.jpg'),
(160955, 11415, 'Sob O Mar S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465049.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/41Gg9I74Bj1iNf0QWGj1u56sD7j.jpg'),
(160956, 11415, 'Sob O Mar S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465050.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z9J5xAWNmIgCH8ImwyfdCaAPYBp.jpg'),
(160957, 11415, 'Sob O Mar S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465051.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iH0Yg59Ldo916EbdwzOEFGXqnbf.jpg'),
(160958, 11415, 'Sob O Mar S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465052.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zfaAQNvNotdIP3Ja9HkiV8bORlZ.jpg'),
(160959, 11415, 'Sob O Mar S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465053.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gP6ewyREaV2SHcmjmlmZHudmltA.jpg'),
(160960, 11415, 'Sob O Mar S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465054.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nSvFWUG7RsYDke6prGl98Tp7oEN.jpg'),
(160961, 11415, 'Sob O Mar S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465055.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z2JvxTDiRll30R1HnZSSZVJJBgr.jpg'),
(160962, 11415, 'Sob O Mar S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465056.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yZyAeGi2e7CvXLJzlZLBQUAcC6G.jpg'),
(160963, 11415, 'Sob O Mar S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465057.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5wPwmjD46mOE0qDoY1WxpvpFO4u.jpg'),
(160964, 11415, 'Sob O Mar S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465058.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d1yvWEWnOgmjSWJuGy4zFbCmx1I.jpg'),
(160965, 11415, 'Sob O Mar S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465059.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lkXymJIoPVf7u86uRHmeATMTgpq.jpg'),
(160966, 11415, 'Sob O Mar S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465060.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bKxIJByVTvxuxiBluIzcn4HWWnk.jpg'),
(160967, 11415, 'Sob O Mar S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465061.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ieR1HqVjMUX8HF8cw7unEJIt8wD.jpg'),
(160968, 11416, 'Sob O Mar S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/465062.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yHPCGlhy97Tu4YtcR7KVMXw1lUa.jpg'),
(160969, 11416, 'Sob O Mar S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465063.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gAWerBFZKklZeRADHrB48kv7BUb.jpg'),
(160970, 11416, 'Sob O Mar S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465064.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iYvqWYLLIKhlO1RCaYUp1OSJqgL.jpg'),
(160971, 11416, 'Sob O Mar S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465065.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uvUeAt8cqYmDiaIn9iRHmJmuDTw.jpg'),
(160972, 11416, 'Sob O Mar S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465066.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nV8YC5yBpmbGCxOXiO4OTSr46fd.jpg'),
(160973, 11416, 'Sob O Mar S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465067.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cEBhWLn7CJpFdAVOvoJLFWoeJwM.jpg'),
(160974, 11416, 'Sob O Mar S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465068.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/52SfdZFzXfMJnqtN6pOP8WGrgrg.jpg'),
(160975, 11416, 'Sob O Mar S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465069.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cLOolCNWhWrj3Yt33PLczhoqf5X.jpg'),
(160976, 11416, 'Sob O Mar S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465070.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A21jJkq8dQqjBEMngsiQqKmrFuQ.jpg'),
(160977, 11416, 'Sob O Mar S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465071.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wFdr7kh9gn70KlbpAi037y0YwWc.jpg'),
(160978, 11416, 'Sob O Mar S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465072.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Wb6oXkbxynljVpY9rRwLTcoRAi.jpg'),
(160979, 11416, 'Sob O Mar S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465073.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/557Lx6VklpZ2lBNmuBIB6kcMEf6.jpg'),
(160980, 11416, 'Sob O Mar S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465074.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e8bcJNYU1gjkmoKAupGz6pQcsO8.jpg'),
(160981, 11417, 'Sob o Cair da Neve [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/464999.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1AE4DcVHPWMc2j9GLuKLT7pNEXH.jpg'),
(160982, 11417, 'Sob o Cair da Neve [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/465000.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h63o0jRKyDl65XI3uKZxZMaE6eF.jpg'),
(160983, 11417, 'Sob o Cair da Neve [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/465001.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/26UOPQoHgr5Rp9sbOW8CyM0WrJl.jpg'),
(160984, 11417, 'Sob o Cair da Neve [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/465002.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/26M3CgrbTWPdjlj6nrL7hMC0mFo.jpg'),
(160985, 11417, 'Sob o Cair da Neve [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/465003.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n2wgYmW73P8FxTFdOKFjjXf9Rlv.jpg'),
(160986, 11417, 'Sob o Cair da Neve [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/465004.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lmywDw5EJAOeUbXIjyalhjDBpL6.jpg'),
(160987, 11417, 'Sob o Cair da Neve [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/465005.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iFVGRWUncUU6pDJks5lTvRUUyT7.jpg'),
(160988, 11417, 'Sob o Cair da Neve [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/465006.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tNh5Jb8wMw5MA4HmhK8Yy42QvGq.jpg'),
(160989, 11417, 'Sob o Cair da Neve [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/465007.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8f2Qokg6gWP9xW028LHkM8iTOj0.jpg'),
(160990, 11417, 'Sob o Cair da Neve [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/465008.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6ahLZEh3A3Ux154KYK1O8xFrfGZ.jpg'),
(160991, 11417, 'Sob o Cair da Neve [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/465009.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a1DpjDOz8424CZTNmTD4ewdiw2G.jpg'),
(160992, 11417, 'Sob o Cair da Neve [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/465010.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/efJf1Q7XQ57rnSbC3x3ATfVgPZG.jpg'),
(160993, 11417, 'Sob o Cair da Neve [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/465011.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cLR0TV1Ofv4Xkvrn6wxmpHJetTY.jpg'),
(160994, 11417, 'Sob o Cair da Neve [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/465012.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7p4fJ5aer7ceTCLXXxazZHDTNpE.jpg'),
(160995, 11417, 'Sob o Cair da Neve [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/465013.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tUrwtaYlDECP9pfeYas12iCnCnn.jpg'),
(160996, 11417, 'Sob o Cair da Neve [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/465014.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n8US9dG9LxflPSyLZPqBSMAwn3u.jpg'),
(160997, 11417, 'Sob o Cair da Neve [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/465015.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ZIsQucHK1EVJpryJsxTrjgAlp0.jpg'),
(160998, 11417, 'Sob o Cair da Neve [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/465016.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jPyeGeZ2GlCKOqolmzRrlsXUMqJ.jpg'),
(160999, 11417, 'Sob o Cair da Neve [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/465017.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ohbuaJcVOaYIUH2cHkyciFIZPer.jpg'),
(161000, 11417, 'Sob o Cair da Neve [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/465018.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5PJPohQUwqRt7rsdzPbcQlyUTjZ.jpg'),
(161001, 11417, 'Sob o Cair da Neve [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/465019.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4f4rkxUFRsuyySgoG2DKZBkXVyW.jpg'),
(161002, 11417, 'Sob o Cair da Neve [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/465020.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yyMExNxYm0ZzhFXYJbwVawJnLue.jpg'),
(161003, 11417, 'Sob o Cair da Neve [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/465021.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kYyBmtqyIhFBgvoEBoBZQvI3UGE.jpg'),
(161004, 11417, 'Sob o Cair da Neve [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/465022.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6qNHbobY7S213Acx5k0fsaXgGGq.jpg'),
(161005, 11418, 'Sonhando Com Um Maldito Conto De Fadas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/464989.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/55KucKVNVqSGou5oC8fGaFeLOCF.jpg'),
(161006, 11418, 'Sonhando Com Um Maldito Conto De Fadas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/464990.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gZ2PvEE73anTNEtw2VF5eZkwpih.jpg'),
(161007, 11418, 'Sonhando Com Um Maldito Conto De Fadas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/464991.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uL8TIP7NT87AuE3f90uCLsLCWwQ.jpg'),
(161008, 11418, 'Sonhando Com Um Maldito Conto De Fadas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/464992.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7UN2JlpcDaTSSLArVk33BW33XfX.jpg'),
(161009, 11418, 'Sonhando Com Um Maldito Conto De Fadas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/464993.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/EloND5GqkWwSYsRaynPMN4AYYM.jpg'),
(161010, 11418, 'Sonhando Com Um Maldito Conto De Fadas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/464994.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dNRvU5oci81upfiqLRW235BYy31.jpg'),
(161011, 11418, 'Sonhando Com Um Maldito Conto De Fadas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/464995.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cDekWXAofEemvXIzEUEZoHsUhSW.jpg'),
(161012, 11418, 'Sonhando Com Um Maldito Conto De Fadas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/464996.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e4JLfFZQwgOI3gst4FxN3jLVjUm.jpg'),
(161013, 11418, 'Sonhando Com Um Maldito Conto De Fadas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/464997.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aO3if3riFtaBVDcZuMJBqf6jTLl.jpg'),
(161014, 11418, 'Sonhando Com Um Maldito Conto De Fadas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/464998.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/on2gSX3MA7FcSjILlbOVMwXgHye.jpg'),
(161015, 11419, 'The Challenge UK [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/464984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l9SjZTOxjxySaitn85nDDKEclY2.jpg'),
(161016, 11419, 'The Challenge UK [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/464985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l9SjZTOxjxySaitn85nDDKEclY2.jpg'),
(161017, 11419, 'The Challenge UK [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/464986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l9SjZTOxjxySaitn85nDDKEclY2.jpg'),
(161018, 11419, 'The Challenge UK [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/464987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l9SjZTOxjxySaitn85nDDKEclY2.jpg'),
(161019, 11419, 'The Challenge UK [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/464988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l9SjZTOxjxySaitn85nDDKEclY2.jpg'),
(161020, 11420, 'The Challenge USA [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/464973.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/omlRjysC9hjp3AeoGLWONFoGm8R.jpg'),
(161021, 11420, 'The Challenge USA [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/464974.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dObA9jz3LSpSp3MJFcGrA7R78NL.jpg'),
(161022, 11420, 'The Challenge USA [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/464975.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3IgeRdWajwg5hpsLEqpB1wrVcm5.jpg'),
(161023, 11420, 'The Challenge USA [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/464976.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iX92IB3jdncCZGZaiiw1dFaW7pO.jpg'),
(161024, 11420, 'The Challenge USA [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/464977.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ctm3Lw34r62CzQzEBDsx2rT7Csj.jpg'),
(161025, 11420, 'The Challenge USA [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/464978.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wrTjbIsTAuYB4SrJ5qakBHNYNI9.jpg'),
(161026, 11420, 'The Challenge USA [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/464979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eloBMzG3bdzRnnXfE9gRJfIXZNM.jpg'),
(161027, 11420, 'The Challenge USA [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/464980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eloBMzG3bdzRnnXfE9gRJfIXZNM.jpg'),
(161028, 11420, 'The Challenge USA [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/464981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eloBMzG3bdzRnnXfE9gRJfIXZNM.jpg'),
(161029, 11420, 'The Challenge USA [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/464982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eloBMzG3bdzRnnXfE9gRJfIXZNM.jpg'),
(161030, 11420, 'The Challenge USA [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/464983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eloBMzG3bdzRnnXfE9gRJfIXZNM.jpg'),
(161031, 11421, 'Vamos Volei de Praia Feminino [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/464937.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yZtGTaU3SwXC1A1faf5SsyQ0RRJ.jpg'),
(161032, 11421, 'Vamos Volei de Praia Feminino [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/464938.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tebsFVwBPGqSg15McVzfoZD1DXt.jpg'),
(161033, 11421, 'Vamos Volei de Praia Feminino [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/464939.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2WrhcmYENZEuPs6hjJi1XKidAs.jpg'),
(161034, 11421, 'Vamos Volei de Praia Feminino [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/464940.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zYhwBB0aMd1NY9YIUAlqFSCamfF.jpg'),
(161035, 11421, 'Vamos Volei de Praia Feminino [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/464941.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n3xOhYTIBmaoUYfm1fcSWWadZkf.jpg'),
(161036, 11421, 'Vamos Volei de Praia Feminino [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/464942.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/heQoFfBumb57QRNiKYX2c53NC0F.jpg'),
(161037, 11421, 'Vamos Volei de Praia Feminino [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/464943.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1nslapB2q7dz3vMmOgnmuQygNrS.jpg'),
(161038, 11421, 'Vamos Volei de Praia Feminino [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/464944.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uCgsichncqUe3rYlVeW9WQFpp1s.jpg'),
(161039, 11421, 'Vamos Volei de Praia Feminino [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/464945.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eEvtXI2ZtO4TSHImGjXBN9JuTyt.jpg'),
(161040, 11421, 'Vamos Volei de Praia Feminino [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/464946.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w9FLsT5cMBX598nSgw7V7ZKLwSR.jpg'),
(161041, 11421, 'Vamos Volei de Praia Feminino [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/464947.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nw0FHTRbBRI6UcYJlQ4w3e6vSEe.jpg'),
(161042, 11421, 'Vamos Volei de Praia Feminino [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/464948.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qqgl3UQgmX7P0Lx00HVcF87LRnd.jpg'),
(161043, 11421, 'Vamos Volei de Praia Feminino [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/464949.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g4Bxg84LzuYyfb5cQVOZAEEq1t3.jpg'),
(161044, 11421, 'Vamos Volei de Praia Feminino [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/464950.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/YpTPrfOu34ma20SV7L2WCiAsya.jpg'),
(161045, 11421, 'Vamos Volei de Praia Feminino [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/464951.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/91TkM6W0nWIfx4MZB2F2mcVeml0.jpg'),
(161046, 11421, 'Vamos Volei de Praia Feminino [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/464952.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6zB5lWD9pxNYdhy4nCGkwSZEcW0.jpg'),
(161047, 11421, 'Vamos Volei de Praia Feminino [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/464953.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lg3yQa3nwMXkR4EUDg2JJ7IoPxH.jpg'),
(161048, 11421, 'Vamos Volei de Praia Feminino [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/464954.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pDMGCGqEcJJtz4Jt2mttrXEd21F.jpg'),
(161049, 11421, 'Vamos Volei de Praia Feminino [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/464955.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/clcHfU4iiD6MNOlOfZOl1cEMYcg.jpg'),
(161050, 11421, 'Vamos Volei de Praia Feminino [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/464956.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/faCaiuPleLMnDt5Ns1ISdjcyrja.jpg'),
(161051, 11421, 'Vamos Volei de Praia Feminino [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/464957.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fP592Hckm90CkCDvl0ZncNmbI7d.jpg'),
(161052, 11421, 'Vamos Volei de Praia Feminino [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/464958.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5hHqJgIpHtxK2KjyHQUTedHArdd.jpg'),
(161053, 11421, 'Vamos Volei de Praia Feminino [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/464959.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wNkkFqsH3gePImKEx9tSfXYcDMp.jpg'),
(161054, 11421, 'Vamos Volei de Praia Feminino [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/464960.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pYKuLELV0nvHXmy5Sxc2SNbx9tj.jpg'),
(161055, 11421, 'Vamos Volei de Praia Feminino [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/464961.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kZMyi2gcfDOlUyFoB3wOLu2Ou9U.jpg'),
(161056, 11421, 'Vamos Volei de Praia Feminino [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/464962.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oV7T9NN5Tn88OHmtuXH8LIIhKGb.jpg'),
(161057, 11421, 'Vamos Volei de Praia Feminino [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/464963.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7nHoMkDi2MpSDwhPP9WRvyXvkbL.jpg'),
(161058, 11421, 'Vamos Volei de Praia Feminino [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/464964.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7c2y2VB6LElPBnJyA33K0c1ymVS.jpg'),
(161059, 11421, 'Vamos Volei de Praia Feminino [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/464965.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/enzJqd6YToAsJbvpfAZWcbfvJR4.jpg'),
(161060, 11421, 'Vamos Volei de Praia Feminino [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/464966.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/du1z0kKLMBs3ZY5zgF29wUGOihm.jpg'),
(161061, 11421, 'Vamos Volei de Praia Feminino [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/464967.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oSikO7jrfXS3wNREBnh3yQExUg4.jpg'),
(161062, 11421, 'Vamos Volei de Praia Feminino [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/464968.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/acJ9quYkg8zIpqbBgtoY7XHj5mn.jpg'),
(161063, 11421, 'Vamos Volei de Praia Feminino [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/464969.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j1PYglxjsWxtbVl4B6gz6JHSexe.jpg'),
(161064, 11421, 'Vamos Volei de Praia Feminino [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/464970.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3UAP8LoBDGAuHYgByLhHMEIjbmZ.jpg'),
(161065, 11421, 'Vamos Volei de Praia Feminino [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/464971.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4JgcC1W0tOd0Yg4BMXQkxIdxioQ.jpg'),
(161066, 11421, 'Vamos Volei de Praia Feminino [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/464972.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2dpHbSl1FaflVLGHzUk990OYnxy.jpg'),
(161067, 11422, 'Volta Priscila S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/464933.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nGA7Brl26QrEQ7FUywzQzssm85j.jpg'),
(161068, 11422, 'Volta Priscila S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/464934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gG9crQZ3R3Wbe6jctAu2KM0D21x.jpg'),
(161069, 11422, 'Volta Priscila S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/464935.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3v9Dl2RWKVkc8tbUTCmHD0uCfDK.jpg'),
(161070, 11422, 'Volta Priscila S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/464936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gG9crQZ3R3Wbe6jctAu2KM0D21x.jpg'),
(161071, 11423, 'Wandee Goodday [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/464921.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1pIWGJK9CXUnmUZe9816AlPjHJF.jpg'),
(161072, 11423, 'Wandee Goodday [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/464922.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8nmCjHXkcKNm6fGjs3QBYqm4wAC.jpg'),
(161073, 11423, 'Wandee Goodday [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/464923.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xdpQWjwud28zGzQlFhs82PcHX7g.jpg'),
(161074, 11423, 'Wandee Goodday [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/464924.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wa96oDvmXdRZptKj1CGxafSYuQz.jpg'),
(161075, 11423, 'Wandee Goodday [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/464925.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eXCoFGYwbndcROJpUR65Nqj8qSc.jpg'),
(161076, 11423, 'Wandee Goodday [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/464926.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rceqxFil8GGc8m0UAboRJLsUiqe.jpg'),
(161077, 11423, 'Wandee Goodday [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/464927.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sfQUIySTSVM0NiqOh4duNgQSjCV.jpg'),
(161078, 11423, 'Wandee Goodday [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/464928.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kLc9XyfLTRuTEiiMHS1plbJK3i7.jpg'),
(161079, 11423, 'Wandee Goodday [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/464929.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hnE3szurJtngVQGuTTFb2u8psES.jpg'),
(161080, 11423, 'Wandee Goodday [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/464930.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1cBg9ngywaV8us6CgKlsN26a8qo.jpg'),
(161081, 11423, 'Wandee Goodday [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/464931.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zFgnz7zERsWKxfZtVsBBl80VZhN.jpg'),
(161082, 11423, 'Wandee Goodday [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/464932.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mDmWfweb9KnlqEOsqpmUV71D99R.jpg'),
(161083, 11424, 'Wanted S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/464903.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zuzs913n9fFNehJUgAE7bQrNTcM.jpg'),
(161084, 11424, 'Wanted S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/464904.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fkFGPEbUFYEG46cVyZ30YuOVCmD.jpg'),
(161085, 11424, 'Wanted S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/464905.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/flkirNO2vZWwuaf4D3VlXNIrFKZ.jpg'),
(161086, 11424, 'Wanted S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/464906.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9unfs2o39bmS3Jmd2bKUnOdNF2S.jpg'),
(161087, 11424, 'Wanted S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/464907.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aL0IFOZZoG28up5vG3QiZ8h1I1S.jpg'),
(161088, 11424, 'Wanted S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/464908.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cJTpMWXCfi0OpxcWLXtm1Nn7H9x.jpg'),
(161089, 11425, 'Wanted S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/464909.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wzc2wjRBQK951EQp7BrxuoylBTx.jpg'),
(161090, 11425, 'Wanted S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/464910.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qzdcCO2iT1YzznxQ4cpUyWDuGJy.jpg'),
(161091, 11425, 'Wanted S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/464911.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bjIEWb2xWzoWP6jaoHJNRJyWLAn.jpg'),
(161092, 11425, 'Wanted S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/464912.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dy0cKvJ3RpxIs79rr8YDmiUq1dq.jpg'),
(161093, 11425, 'Wanted S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/464913.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iTJGSg8eSvO2dsHVQdMXEEeS7PJ.jpg'),
(161094, 11425, 'Wanted S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/464914.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wWqQBZ02BtiBS6rFcZQn5zWXK2u.jpg'),
(161095, 11426, 'Wanted S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/464915.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3wTmmwPFCsXCZ5VvvWdpAaQNpKg.jpg'),
(161096, 11426, 'Wanted S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/464916.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nxoYvLvB5hs4Gs2XpC1r4K0H06U.jpg'),
(161097, 11426, 'Wanted S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/464917.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jVccimUJzA8AJWCSTOWJzvwgGrx.jpg'),
(161098, 11426, 'Wanted S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/464918.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/PI4tHqqGkUdfO8R9dLZ6SAUAou.jpg'),
(161099, 11426, 'Wanted S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/464919.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wFqnaZBB1rU6v5lxv8ZCuq1VHzq.jpg'),
(161100, 11426, 'Wanted S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/464920.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nOudimjbKLRZa9WifLWXLdITQcg.jpg'),
(161101, 11427, 'We Are [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/464887.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gbbXM0I1J9tPfET2t4vcc3Z1rnQ.jpg'),
(161102, 11427, 'We Are [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/464888.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u4GMZMSBf488tKypgNGggdTEAvL.jpg'),
(161103, 11427, 'We Are [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/464889.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Aazvh88eOgRrvG8YeXgRRNQYO2i.jpg'),
(161104, 11427, 'We Are [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/464890.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2F5Vrsw29grCiApPuedfBjfjdk5.jpg'),
(161105, 11427, 'We Are [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/464891.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ifpnsnUteKAr0u9UNTHZcVii3qy.jpg'),
(161106, 11427, 'We Are [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/464892.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cWx0uSDbJJ2IVrmLP82eioKvHOi.jpg'),
(161107, 11427, 'We Are [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/464893.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/DfIzEhmvqZjiEIkQJLTYrL53nj.jpg'),
(161108, 11427, 'We Are [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/464894.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/65RT1RaBCcpEegEFXEx1nlkmxER.jpg'),
(161109, 11427, 'We Are [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/464895.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9oiInxNji5D49MeeK3CNoaPaw87.jpg'),
(161110, 11427, 'We Are [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/464896.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z1b1LLhYlmcJLm2kw9KR0tqYMON.jpg'),
(161111, 11427, 'We Are [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/464897.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yKr3lrsLx1HGEAUsYlKREChCAy.jpg'),
(161112, 11427, 'We Are [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/464898.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p2RDGi3jJSdhXu6G713CBpOiDU.jpg'),
(161113, 11427, 'We Are [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/464899.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hj2uRUGh0fAbchYDOormDAJIZe5.jpg'),
(161114, 11427, 'We Are [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/464900.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a3oknWU1H9fcawVyjYnnolUQrdH.jpg'),
(161115, 11427, 'We Are [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/464901.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i3sNdmuIyROg7tSk4CNjdHpgFdm.jpg'),
(161116, 11427, 'We Are [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/464902.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rvMJWfbM5snBZVnNjKgYTc73Dfn.jpg'),
(161117, 11428, 'Historia Esportiva Americana S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/468565.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7KNyJ2qd2nmn30mk65gmwqmoXd7.jpg'),
(161118, 11428, 'Historia Esportiva Americana S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/468566.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kfg4hXvbqclRDmARQiLRvZHVKHM.jpg'),
(161119, 11428, 'Historia Esportiva Americana S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/468567.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mtaOflQyGW2In9PzyffVw1IhmwI.jpg'),
(161120, 11428, 'Historia Esportiva Americana S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/492780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eazSoJwGo9tj7dT7GbAIDD32tLb.jpg'),
(161121, 11428, 'Historia Esportiva Americana S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/478027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eazSoJwGo9tj7dT7GbAIDD32tLb.jpg'),
(161122, 11428, 'Historia Esportiva Americana S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/483177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eazSoJwGo9tj7dT7GbAIDD32tLb.jpg'),
(161123, 11428, 'Historia Esportiva Americana S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/492783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eazSoJwGo9tj7dT7GbAIDD32tLb.jpg'),
(161124, 11428, 'Historia Esportiva Americana S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/492784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eazSoJwGo9tj7dT7GbAIDD32tLb.jpg'),
(161125, 11428, 'Historia Esportiva Americana S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/500123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eazSoJwGo9tj7dT7GbAIDD32tLb.jpg'),
(161126, 11428, 'Historia Esportiva Americana S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/506045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eazSoJwGo9tj7dT7GbAIDD32tLb.jpg'),
(161127, 11429, 'Voce e a Batida do Meu Coracao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/468545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMzcbrhJrwBhETKRI0vGj5aOICL.jpg'),
(161128, 11429, 'Voce e a Batida do Meu Coracao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/468546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMzcbrhJrwBhETKRI0vGj5aOICL.jpg'),
(161129, 11429, 'Voce e a Batida do Meu Coracao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/468547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMzcbrhJrwBhETKRI0vGj5aOICL.jpg'),
(161130, 11429, 'Voce e a Batida do Meu Coracao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/468548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMzcbrhJrwBhETKRI0vGj5aOICL.jpg'),
(161131, 11429, 'Voce e a Batida do Meu Coracao [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/468549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMzcbrhJrwBhETKRI0vGj5aOICL.jpg'),
(161132, 11429, 'Voce e a Batida do Meu Coracao [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/468550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMzcbrhJrwBhETKRI0vGj5aOICL.jpg'),
(161133, 11429, 'Voce e a Batida do Meu Coracao [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/468551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMzcbrhJrwBhETKRI0vGj5aOICL.jpg'),
(161134, 11429, 'Voce e a Batida do Meu Coracao [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/468552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMzcbrhJrwBhETKRI0vGj5aOICL.jpg'),
(161135, 11429, 'Voce e a Batida do Meu Coracao [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/468553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMzcbrhJrwBhETKRI0vGj5aOICL.jpg'),
(161136, 11429, 'Voce e a Batida do Meu Coracao [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/468554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMzcbrhJrwBhETKRI0vGj5aOICL.jpg'),
(161137, 11429, 'Voce e a Batida do Meu Coracao [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/468555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMzcbrhJrwBhETKRI0vGj5aOICL.jpg'),
(161138, 11429, 'Voce e a Batida do Meu Coracao [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/468556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMzcbrhJrwBhETKRI0vGj5aOICL.jpg'),
(161139, 11429, 'Voce e a Batida do Meu Coracao [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/468557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMzcbrhJrwBhETKRI0vGj5aOICL.jpg'),
(161140, 11429, 'Voce e a Batida do Meu Coracao [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/468558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMzcbrhJrwBhETKRI0vGj5aOICL.jpg'),
(161141, 11429, 'Voce e a Batida do Meu Coracao [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/468559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMzcbrhJrwBhETKRI0vGj5aOICL.jpg'),
(161142, 11429, 'Voce e a Batida do Meu Coracao [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/468560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMzcbrhJrwBhETKRI0vGj5aOICL.jpg'),
(161143, 11429, 'Voce e a Batida do Meu Coracao [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/468561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMzcbrhJrwBhETKRI0vGj5aOICL.jpg'),
(161144, 11429, 'Voce e a Batida do Meu Coracao [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/468562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMzcbrhJrwBhETKRI0vGj5aOICL.jpg'),
(161145, 11429, 'Voce e a Batida do Meu Coracao [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/468563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMzcbrhJrwBhETKRI0vGj5aOICL.jpg'),
(161146, 11429, 'Voce e a Batida do Meu Coracao [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/468564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oMzcbrhJrwBhETKRI0vGj5aOICL.jpg'),
(161147, 11430, 'Amor Fatal As Seis Esposas de Thomas Randolph S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/468530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2tJPH1c1afoZ9ARMJoWKi0TvjJ6.jpg'),
(161148, 11430, 'Amor Fatal As Seis Esposas de Thomas Randolph S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/468531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2tJPH1c1afoZ9ARMJoWKi0TvjJ6.jpg'),
(161149, 11430, 'Amor Fatal As Seis Esposas de Thomas Randolph S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/468532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2tJPH1c1afoZ9ARMJoWKi0TvjJ6.jpg'),
(161150, 11431, 'Ao Vivo do Lado de La com Tyler Henry S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/468529.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gLr5k37PoPvjBKgmqmzlHY98DPY.jpg'),
(161151, 11431, 'Ao Vivo do Lado de La com Tyler Henry S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGOhtOHVJD63JPcw7lc9ACkq6Z7.jpg'),
(161152, 11431, 'Ao Vivo do Lado de La com Tyler Henry S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGOhtOHVJD63JPcw7lc9ACkq6Z7.jpg'),
(161153, 11431, 'Ao Vivo do Lado de La com Tyler Henry S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/499177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGOhtOHVJD63JPcw7lc9ACkq6Z7.jpg'),
(161154, 11431, 'Ao Vivo do Lado de La com Tyler Henry S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/499178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGOhtOHVJD63JPcw7lc9ACkq6Z7.jpg'),
(161155, 11431, 'Ao Vivo do Lado de La com Tyler Henry S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/499179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGOhtOHVJD63JPcw7lc9ACkq6Z7.jpg'),
(161156, 11432, 'Botched Pesadelo na Bariatrica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/468527.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/am9D8MOXub3rArJVsQdxh4tpGmp.jpg'),
(161157, 11432, 'Botched Pesadelo na Bariatrica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/468528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dC40Ldl8xAP8wSI2RvZWJcRcZNz.jpg'),
(161158, 11432, 'Botched Pesadelo na Bariatrica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/474566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dC40Ldl8xAP8wSI2RvZWJcRcZNz.jpg'),
(161159, 11433, 'Operacao Fronteira Estados Unidos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/468526.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xEBVhuW7vW2btsXOIdq62Z210xt.jpg'),
(161160, 11433, 'Operacao Fronteira Estados Unidos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/476078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlCLRojglopcOtPKY1621oFH0kB.jpg'),
(161161, 11433, 'Operacao Fronteira Estados Unidos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/476079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlCLRojglopcOtPKY1621oFH0kB.jpg'),
(161162, 11433, 'Operacao Fronteira Estados Unidos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/488432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlCLRojglopcOtPKY1621oFH0kB.jpg'),
(161163, 11433, 'Operacao Fronteira Estados Unidos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/496391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlCLRojglopcOtPKY1621oFH0kB.jpg'),
(161164, 11433, 'Operacao Fronteira Estados Unidos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/496392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlCLRojglopcOtPKY1621oFH0kB.jpg'),
(161165, 11433, 'Operacao Fronteira Estados Unidos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/505417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlCLRojglopcOtPKY1621oFH0kB.jpg'),
(161166, 11433, 'Operacao Fronteira Estados Unidos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/505418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlCLRojglopcOtPKY1621oFH0kB.jpg'),
(161167, 11433, 'Operacao Fronteira Estados Unidos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/509315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlCLRojglopcOtPKY1621oFH0kB.jpg'),
(161168, 11433, 'Operacao Fronteira Estados Unidos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/514250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hlCLRojglopcOtPKY1621oFH0kB.jpg'),
(161169, 11434, 'Amor Apimentado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/471210.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1rNLQf2KeRqXD1aNKQfRBOQWJzi.jpg'),
(161170, 11434, 'Amor Apimentado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/471211.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pHZRzAYhC3zCHW4QCqmKEiPZShm.jpg'),
(161171, 11435, 'Chefs Table Macarrao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/471206.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1rNLQf2KeRqXD1aNKQfRBOQWJzi.jpg'),
(161172, 11435, 'Chefs Table Macarrao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/471207.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pHZRzAYhC3zCHW4QCqmKEiPZShm.jpg'),
(161173, 11435, 'Chefs Table Macarrao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/471208.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cgYy5Y2uqhd9YFSSCvJ9Qaq8jqw.jpg'),
(161174, 11435, 'Chefs Table Macarrao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/471209.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Ac904t8y8ppgngemMW7hqL8yNIW.jpg'),
(161175, 11436, 'Corretores de Luxo em Marbella S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/471200.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gXbaVfeVKaU6eHWCKASXcFRVFMy.jpg'),
(161176, 11436, 'Corretores de Luxo em Marbella S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/471201.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tqhpOfij1QnbTATHo3KKKb3o6sR.jpg'),
(161177, 11436, 'Corretores de Luxo em Marbella S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/471202.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9Vvj58rydTiwzJVQh0WQ2dJaS3I.jpg'),
(161178, 11436, 'Corretores de Luxo em Marbella S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/471203.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2d7FYk5xfEbugAnvyhHzuGLFXbF.jpg'),
(161179, 11436, 'Corretores de Luxo em Marbella S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/471204.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mljZFvEUKfLQgc566FdDwEMbznQ.jpg'),
(161180, 11436, 'Corretores de Luxo em Marbella S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/471205.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h4ipbKEpBCZE55XfgElvb3zjCRH.jpg'),
(161181, 11437, 'Neemias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/471199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pCICUzNpZwqU8ZHk7UGZX8WlpPj.jpg'),
(161182, 11437, 'Neemias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/477488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pCICUzNpZwqU8ZHk7UGZX8WlpPj.jpg'),
(161183, 11437, 'Neemias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/482675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pCICUzNpZwqU8ZHk7UGZX8WlpPj.jpg'),
(161184, 11437, 'Neemias S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/490785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pCICUzNpZwqU8ZHk7UGZX8WlpPj.jpg'),
(161185, 11437, 'Neemias S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/492218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pCICUzNpZwqU8ZHk7UGZX8WlpPj.jpg'),
(161186, 11437, 'Neemias S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/495687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pCICUzNpZwqU8ZHk7UGZX8WlpPj.jpg'),
(161187, 11437, 'Neemias S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/505512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pCICUzNpZwqU8ZHk7UGZX8WlpPj.jpg'),
(161188, 11438, 'O Prazer e Meu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/471195.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7p2WBKXqBmYYn6gR0UJGDbXURuI.jpg'),
(161189, 11438, 'O Prazer e Meu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/471196.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1XwW3uAlY0xSUo444dRTl8prMpY.jpg'),
(161190, 11438, 'O Prazer e Meu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/471197.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bw5NXYRjM71rCAgDb9stKxlnXLX.jpg'),
(161191, 11438, 'O Prazer e Meu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/471198.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zycTQvsvqVaw3hMq8p9T7BK9jkk.jpg'),
(161192, 11439, 'O Professor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/471190.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jGzMXDqPWkjQUbXM8Z5q3K8QzZN.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(161193, 11439, 'O Professor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/471191.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lZqiaNnRnG0TiWLtnPNzWX1Tk8y.jpg'),
(161194, 11439, 'O Professor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/471192.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2x6nxrkyYeeT7Ie6jrVDP1uCFhF.jpg'),
(161195, 11439, 'O Professor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0hEVuk1cTJ1ryT81fRIJ0xkqet.jpg'),
(161196, 11439, 'O Professor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/471194.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5ZgUnrNNLya39s5Ed0dIdKMMSmi.jpg'),
(161197, 11439, 'O Professor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0hEVuk1cTJ1ryT81fRIJ0xkqet.jpg'),
(161198, 11439, 'O Professor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/503711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0hEVuk1cTJ1ryT81fRIJ0xkqet.jpg'),
(161199, 11439, 'O Professor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/511522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0hEVuk1cTJ1ryT81fRIJ0xkqet.jpg'),
(161200, 11440, 'O Professor S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/887364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0hEVuk1cTJ1ryT81fRIJ0xkqet.jpg'),
(161201, 11440, 'O Professor S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/887560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0hEVuk1cTJ1ryT81fRIJ0xkqet.jpg'),
(161202, 11440, 'O Professor S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/887561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0hEVuk1cTJ1ryT81fRIJ0xkqet.jpg'),
(161203, 11440, 'O Professor S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/893103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0hEVuk1cTJ1ryT81fRIJ0xkqet.jpg'),
(161204, 11440, 'O Professor S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/893104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0hEVuk1cTJ1ryT81fRIJ0xkqet.jpg'),
(161205, 11440, 'O Professor S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/893105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0hEVuk1cTJ1ryT81fRIJ0xkqet.jpg'),
(161206, 11440, 'O Professor S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/893106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0hEVuk1cTJ1ryT81fRIJ0xkqet.jpg'),
(161207, 11440, 'O Professor S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/893107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0hEVuk1cTJ1ryT81fRIJ0xkqet.jpg'),
(161208, 11440, 'O Professor S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/893108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0hEVuk1cTJ1ryT81fRIJ0xkqet.jpg'),
(161209, 11440, 'O Professor S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/893109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t0hEVuk1cTJ1ryT81fRIJ0xkqet.jpg'),
(161210, 11441, 'Onde Esta a Wanda S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/471188.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9DyZZfvRhxQfNgm1tu0vsQamfsE.jpg'),
(161211, 11441, 'Onde Esta a Wanda S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/471189.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t9R5IeAS6M3yaoi7BfbuHuCIQzR.jpg'),
(161212, 11441, 'Onde Esta a Wanda S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/477241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/okVhkzrbu6GLaOMauRTn3E2S2cc.jpg'),
(161213, 11441, 'Onde Esta a Wanda S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/482418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/okVhkzrbu6GLaOMauRTn3E2S2cc.jpg'),
(161214, 11441, 'Onde Esta a Wanda S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/490540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/okVhkzrbu6GLaOMauRTn3E2S2cc.jpg'),
(161215, 11441, 'Onde Esta a Wanda S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/491976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/okVhkzrbu6GLaOMauRTn3E2S2cc.jpg'),
(161216, 11441, 'Onde Esta a Wanda S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/499836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/okVhkzrbu6GLaOMauRTn3E2S2cc.jpg'),
(161217, 11441, 'Onde Esta a Wanda S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/505426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/okVhkzrbu6GLaOMauRTn3E2S2cc.jpg'),
(161218, 11442, 'Os Misteriosos Raptos em Iowa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/471185.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jKaa5qZXMjZ896kdJPtNPBxrJVI.jpg'),
(161219, 11442, 'Os Misteriosos Raptos em Iowa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/471186.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kVCCOJ91MdAV5REfGuNFedgpBIe.jpg'),
(161220, 11442, 'Os Misteriosos Raptos em Iowa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/471187.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zcIHk7nRDCfJDMeURfid3MG9n8G.jpg'),
(161221, 11443, 'Coragem O Cao Covarde S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/471101.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5cggyNeB0tPKN5cxfiAaS9IsONr.jpg'),
(161222, 11443, 'Coragem O Cao Covarde S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/471102.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jbSPWAkq4gnvnkfJc9Qtb5LBE2F.jpg'),
(161223, 11443, 'Coragem O Cao Covarde S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/471103.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/158EWXrZZaZUed7K3pA9hjW1NB3.jpg'),
(161224, 11443, 'Coragem O Cao Covarde S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/471104.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kvhza2Qz1tUUhrZGSMNKYMDzT0D.jpg'),
(161225, 11443, 'Coragem O Cao Covarde S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/471105.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/igrnDGWWBy8Dn6Rx1FSbEEwzTfP.jpg'),
(161226, 11443, 'Coragem O Cao Covarde S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/471106.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/awehhoLbhMqq2xaGlVW00EqXMF6.jpg'),
(161227, 11443, 'Coragem O Cao Covarde S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/471107.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mjQxkZfACEbVCOG9xLzbdFL4RCi.jpg'),
(161228, 11443, 'Coragem O Cao Covarde S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/471108.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2EPmkMno1oLMGhXeeKCVuwjF4bA.jpg'),
(161229, 11443, 'Coragem O Cao Covarde S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/471109.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bih7ilF25HOM0AgsIJHMH7fmge0.jpg'),
(161230, 11443, 'Coragem O Cao Covarde S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/471110.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o5LbCa7Jk2NS5iTOP8x0ikdAKRg.jpg'),
(161231, 11443, 'Coragem O Cao Covarde S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/471111.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/674AsvAlyjSd6L4juEjhaLU7JA6.jpg'),
(161232, 11443, 'Coragem O Cao Covarde S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/471112.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o92dhxhCZiFemmurtSzIL3CTH9o.jpg'),
(161233, 11443, 'Coragem O Cao Covarde S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/471113.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/acxDuercEZnERTPq8LqDaCBTk6N.jpg'),
(161234, 11444, 'Coragem O Cao Covarde S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/471114.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iFYPhK10Ue7OhZKP1ABlPn8nidy.jpg'),
(161235, 11444, 'Coragem O Cao Covarde S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/471115.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sqeve9KNXAjlQ7r7xE47DNBieUw.jpg'),
(161236, 11444, 'Coragem O Cao Covarde S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/471116.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nhy0pnHp455AdtvegKQB0Qyij3M.jpg'),
(161237, 11444, 'Coragem O Cao Covarde S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/471117.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sQHAX2X4PWnsvgykvOltjCWKZfE.jpg'),
(161238, 11444, 'Coragem O Cao Covarde S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/471118.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4ce6dW0pvUUOIgOIickjgVJetsn.jpg'),
(161239, 11444, 'Coragem O Cao Covarde S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/471119.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Ak96xokUffTNIVTZPGdVmBuQ1v0.jpg'),
(161240, 11444, 'Coragem O Cao Covarde S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/471120.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bEj4raDwFDAtaDE2xqTQ4eIPXOj.jpg'),
(161241, 11444, 'Coragem O Cao Covarde S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/471121.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5vKlngzvFdln7Uc7qxiMDxBsTPG.jpg'),
(161242, 11444, 'Coragem O Cao Covarde S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/471122.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bh6L7u5Egc0UK4UbVMm86aKKgtf.jpg'),
(161243, 11444, 'Coragem O Cao Covarde S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/471123.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dKv2keY16xSBxDL4Y0frB7dwk6p.jpg'),
(161244, 11444, 'Coragem O Cao Covarde S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/471124.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lhJyONpK2YTx3NJyLu5B97xvkyJ.jpg'),
(161245, 11444, 'Coragem O Cao Covarde S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/471125.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/54hFSVAndHsEVsyhZOUwUB6AWj3.jpg'),
(161246, 11444, 'Coragem O Cao Covarde S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/471126.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eE5IGxK1wLj5FwFSBNn4DMKiEOI.jpg'),
(161247, 11445, 'Coragem O Cao Covarde S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/471127.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oWXtAXPfR45caTesF2cdZDPaoNi.jpg'),
(161248, 11445, 'Coragem O Cao Covarde S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/471128.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gVP2zhItzOcSORTbiVKXSdDvfeU.jpg'),
(161249, 11445, 'Coragem O Cao Covarde S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/471129.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hX5FyLcdocF7OcEtEWOdJRMRs4n.jpg'),
(161250, 11445, 'Coragem O Cao Covarde S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/471130.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vUhGnkUBgtT5TQahV3LR5fB2zng.jpg'),
(161251, 11445, 'Coragem O Cao Covarde S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/471131.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fGosT1szljOLZ3gtRkGO7oZLozq.jpg'),
(161252, 11445, 'Coragem O Cao Covarde S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/471132.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/moKKNY57WK2VH89fjSvTZkk5mqj.jpg'),
(161253, 11445, 'Coragem O Cao Covarde S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/471133.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/42eu7RWOuXfOJgmzQ5L2IPN69OU.jpg'),
(161254, 11445, 'Coragem O Cao Covarde S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/471134.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dLEoIF1SYz0HL9rbcvI8teJKjgM.jpg'),
(161255, 11445, 'Coragem O Cao Covarde S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/471135.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jHwNfvIryBKO0tYs31mnLMt05A3.jpg'),
(161256, 11445, 'Coragem O Cao Covarde S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/471136.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/16DONYLhEqZPa77kIFEQdNFJmOE.jpg'),
(161257, 11445, 'Coragem O Cao Covarde S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/471137.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/20RqqVhNrEvxfR3sM5i5WZQYiZ1.jpg'),
(161258, 11445, 'Coragem O Cao Covarde S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/471138.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4tvtWwDrMBMafy6No4ouox2QGjK.jpg'),
(161259, 11445, 'Coragem O Cao Covarde S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/471139.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/azIMVKeIoVpSARqGPgAkxsKse1P.jpg'),
(161260, 11446, 'Coragem O Cao Covarde S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/471140.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AjcTNeTXgYbroVJaSBK1sxrnNUX.jpg'),
(161261, 11446, 'Coragem O Cao Covarde S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/471141.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/izN4OqoKC7UlkWNe0rmFNkbmn0J.jpg'),
(161262, 11446, 'Coragem O Cao Covarde S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/471142.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eJrcr510VrFyhujrKJsLjBfh5Aq.jpg'),
(161263, 11446, 'Coragem O Cao Covarde S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/471143.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/munrWu77JIdlA4lWNSAFf5gdUhz.jpg'),
(161264, 11446, 'Coragem O Cao Covarde S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/471144.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5gohnXeFBfm3xGI64UajNzDbF1Q.jpg'),
(161265, 11446, 'Coragem O Cao Covarde S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/471145.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cGEqRmYj1LkFz02DNiM2baOFGDm.jpg'),
(161266, 11446, 'Coragem O Cao Covarde S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/471146.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A5LKbvkCtojhv74WNWwDE0zRfQ0.jpg'),
(161267, 11446, 'Coragem O Cao Covarde S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/471147.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wV6IwFSAl2TvQAkkFzN4EQnCuQD.jpg'),
(161268, 11446, 'Coragem O Cao Covarde S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/471148.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oX3SpWRs5swzVwxGazwC9p8JrAC.jpg'),
(161269, 11446, 'Coragem O Cao Covarde S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/471149.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w5i121DNhW6w3uebxMVVCB1xIGp.jpg'),
(161270, 11446, 'Coragem O Cao Covarde S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/471150.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/scwSKAlUfWWOSK1E44PGdxnFb2c.jpg'),
(161271, 11446, 'Coragem O Cao Covarde S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/471151.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jXIs6viORxLZDUq2PGgvfNcBsuW.jpg'),
(161272, 11446, 'Coragem O Cao Covarde S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/471152.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/BfF2Z0bJJUFjXmCRT75ZcfOfzZ.jpg'),
(161273, 11447, 'Grandes Fracassos Woodstock 99 [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/471098.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pXXaRBtYpdLNzSJBzlodDrRmXdM.jpg'),
(161274, 11447, 'Grandes Fracassos Woodstock 99 [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/471099.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ox7xtSaWorjkjUsDpFi3l2NrzIh.jpg'),
(161275, 11447, 'Grandes Fracassos Woodstock 99 [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/471100.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hN85PWTr3JlkNh0wbJVhB5CLC8S.jpg'),
(161276, 11448, 'Isekai Nonbiri Nouka [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/471086.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zhPTCrG9eRA8EBJjWDTQyIPPMrY.jpg'),
(161277, 11448, 'Isekai Nonbiri Nouka [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/471087.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lFyU2u1vCYu5sDZSElWQaXjKUzY.jpg'),
(161278, 11448, 'Isekai Nonbiri Nouka [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/471088.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vVt8s9nLurAaQWlhNfr7wawVQ4A.jpg'),
(161279, 11448, 'Isekai Nonbiri Nouka [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/471089.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dGmdQ3MduShw70ePdNxCI3g8CBh.jpg'),
(161280, 11448, 'Isekai Nonbiri Nouka [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/471090.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yfE334oRuQxO3WSpA4f2EUcsCNm.jpg'),
(161281, 11448, 'Isekai Nonbiri Nouka [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/471091.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lw41KNuRBgkNXL8kjTNRtNMteX3.jpg'),
(161282, 11448, 'Isekai Nonbiri Nouka [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/471092.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pjzjoyM4rDhm0VkoHW0EMSvuMfA.jpg'),
(161283, 11448, 'Isekai Nonbiri Nouka [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/471093.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xp15tsvymsGj4VzzC71t58dprp0.jpg'),
(161284, 11448, 'Isekai Nonbiri Nouka [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/471094.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Ckr0no7L4aNssmotTusLl5etQ5.jpg'),
(161285, 11448, 'Isekai Nonbiri Nouka [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/471095.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5sk9O75FrqixHg4k0GLxns6U9pg.jpg'),
(161286, 11448, 'Isekai Nonbiri Nouka [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/471096.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4zevHWcfGyJ6QYSlkBae4LIMcwL.jpg'),
(161287, 11448, 'Isekai Nonbiri Nouka [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/471097.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fPW7lfLKqlQHTGPIYNQ7698mV7J.jpg'),
(161288, 11449, 'Parasyte The Maxim [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/471062.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b8xmC8J3MUb4knwo8F9u6orP6Wy.jpg'),
(161289, 11449, 'Parasyte The Maxim [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/471063.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6xPU5vPmvkrkTqmdpF4JGsDApYp.jpg'),
(161290, 11449, 'Parasyte The Maxim [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/471064.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6iBbBJiZfv1RD5dvg6Y8I5BgkDu.jpg'),
(161291, 11449, 'Parasyte The Maxim [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/471065.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f0m3suL9QmKU8N8ugnIGHFzVOEf.jpg'),
(161292, 11449, 'Parasyte The Maxim [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/471066.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/meTyTu5BqCFa9ZxZpWWlAwu5rmh.jpg'),
(161293, 11449, 'Parasyte The Maxim [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/471067.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hL6wciEKcvF5ZjDJRmp2UeYn5v4.jpg'),
(161294, 11449, 'Parasyte The Maxim [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/471068.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4aYMLNDLjx0Y2Lnl7L5Mgg1iIYE.jpg'),
(161295, 11449, 'Parasyte The Maxim [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/471069.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4radWJoiPcvwLTd0gvqJ5nWmm5M.jpg'),
(161296, 11449, 'Parasyte The Maxim [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/471070.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9r9KkPbObx3ApDd7Vb3bc19LWTJ.jpg'),
(161297, 11449, 'Parasyte The Maxim [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/471071.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f7IM0QOTEMcvsUbr8PWJPZThwCn.jpg'),
(161298, 11449, 'Parasyte The Maxim [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/471072.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/haf8wk2S8M0aSiBvzzUb7b9ZlB6.jpg'),
(161299, 11449, 'Parasyte The Maxim [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/471073.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k9jjVH1OwmmFWZZgaytWNADQQi1.jpg'),
(161300, 11449, 'Parasyte The Maxim [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/471074.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/21Xgq86JRqj7t9KPWQKlJxn3IOt.jpg'),
(161301, 11449, 'Parasyte The Maxim [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/471075.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2TlbPtUSgaR8u43zG8is1Wojo6z.jpg'),
(161302, 11449, 'Parasyte The Maxim [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/471076.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nyGwhBr81IuNq77KcqW1KNNbJmf.jpg'),
(161303, 11449, 'Parasyte The Maxim [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/471077.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u8UcVFB7GnwgkQ5d4qRvdaCK8cb.jpg'),
(161304, 11449, 'Parasyte The Maxim [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/471078.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bafEV5CCI4cT4Y52p9iIN3LZgsJ.jpg'),
(161305, 11449, 'Parasyte The Maxim [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/471079.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xsmBLZvLpFeLF2tP3pufNPDytqQ.jpg'),
(161306, 11449, 'Parasyte The Maxim [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/471080.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yhiBQ7HmjFo3frXpSynRNF8t9rB.jpg'),
(161307, 11449, 'Parasyte The Maxim [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/471081.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aVgLHGQEJ4WNWvRR1MRnN1v1ltV.jpg'),
(161308, 11449, 'Parasyte The Maxim [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/471082.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rJqJgECcU0iVhIIOcIz1CvNuSqK.jpg'),
(161309, 11449, 'Parasyte The Maxim [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/471083.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jy0phUX4i6ptjFxwlrVPsChNiWC.jpg'),
(161310, 11449, 'Parasyte The Maxim [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/471084.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9h0kZusfGap0q1uMuf7072wolHR.jpg'),
(161311, 11449, 'Parasyte The Maxim [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/471085.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p0UrUCI26FQIZKWo5KTUBuhUHaG.jpg'),
(161312, 11450, 'That Time I Got Reincarnated as a Slime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/471153.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kn2O2A6yxvPNjyxJ2gJmW6l8qzs.jpg'),
(161313, 11450, 'That Time I Got Reincarnated as a Slime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/471154.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bl7NSSaMhVQFAUdVMyyzylfZ5Be.jpg'),
(161314, 11450, 'That Time I Got Reincarnated as a Slime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/471155.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uB7iLDVu1DXXk8u4IOr3O4eWAY1.jpg'),
(161315, 11450, 'That Time I Got Reincarnated as a Slime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/471156.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4kAo0igLqN4ql5IjOXFM1x2qE40.jpg'),
(161316, 11450, 'That Time I Got Reincarnated as a Slime S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/471157.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jZiQCe4EvUZMYUqdztgzmqgNYUH.jpg'),
(161317, 11450, 'That Time I Got Reincarnated as a Slime S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/471158.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/umRZpXoBQ6L1KbSm9g74ZSofJ9J.jpg'),
(161318, 11450, 'That Time I Got Reincarnated as a Slime S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/471159.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eCFR8aqyILnl6sUS3QgFNFkMH6r.jpg'),
(161319, 11450, 'That Time I Got Reincarnated as a Slime S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/471160.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2rLu3nl83nHbvqE435xAlyV40yw.jpg'),
(161320, 11450, 'That Time I Got Reincarnated as a Slime S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/471161.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c3XhKRZlM7HLkhHpmzi2z2aeiZD.jpg'),
(161321, 11450, 'That Time I Got Reincarnated as a Slime S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/471162.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hMerUrDesUpiZyynGMsQjE5BgDq.jpg'),
(161322, 11450, 'That Time I Got Reincarnated as a Slime S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/471163.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8qmpYCQouyHFFC0iR77I6KBoF2u.jpg'),
(161323, 11450, 'That Time I Got Reincarnated as a Slime S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/471164.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4sekRZzE4nat8VytAhTUVGEEpYK.jpg'),
(161324, 11450, 'That Time I Got Reincarnated as a Slime S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/471165.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9PcZM0qOxB5AnE6IPSGJFW9JG3V.jpg'),
(161325, 11450, 'That Time I Got Reincarnated as a Slime S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/471166.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/46oZhigxWtncWcTRtu60TWuXZiv.jpg'),
(161326, 11450, 'That Time I Got Reincarnated as a Slime S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/471167.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iFStfGwmHg8XtloFhPlIBB3XMFn.jpg'),
(161327, 11450, 'That Time I Got Reincarnated as a Slime S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/471168.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j7IZf3gTyvS8j5K1AWv8J9EpytK.jpg'),
(161328, 11450, 'That Time I Got Reincarnated as a Slime S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/471169.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/isClSj96Vwlv1FgYpRYoNXWbejg.jpg'),
(161329, 11450, 'That Time I Got Reincarnated as a Slime S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/471170.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7RVXfIQ1erRpRdWpaYOr5VbEuYz.jpg'),
(161330, 11450, 'That Time I Got Reincarnated as a Slime S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/471171.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ag2XMpv9gi3EFbjsUvHMKBRT7H8.jpg'),
(161331, 11450, 'That Time I Got Reincarnated as a Slime S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/471172.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eddUGXrqpY99Y5RWpgNsy8TVorz.jpg'),
(161332, 11450, 'That Time I Got Reincarnated as a Slime S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/471173.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/waETiQ7NF5Dpcy7G853myOt9piH.jpg'),
(161333, 11450, 'That Time I Got Reincarnated as a Slime S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/471174.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p5o1dVBXSiy3Sn6krkuHNAxVVjS.jpg'),
(161334, 11450, 'That Time I Got Reincarnated as a Slime S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/471175.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/53AyHp2PohkqITF2HMy49rMVpmP.jpg'),
(161335, 11450, 'That Time I Got Reincarnated as a Slime S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/471176.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1dfhbX75RXgO0hAR08PpUR2Z3nL.jpg'),
(161336, 11450, 'That Time I Got Reincarnated as a Slime S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/471177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9YcNx1dnNkZ3PZzrMqc52WjCEcw.jpg'),
(161337, 11450, 'That Time I Got Reincarnated as a Slime S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/471178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9YcNx1dnNkZ3PZzrMqc52WjCEcw.jpg'),
(161338, 11450, 'That Time I Got Reincarnated as a Slime S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/471179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9YcNx1dnNkZ3PZzrMqc52WjCEcw.jpg'),
(161339, 11450, 'That Time I Got Reincarnated as a Slime S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/471180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9YcNx1dnNkZ3PZzrMqc52WjCEcw.jpg'),
(161340, 11450, 'That Time I Got Reincarnated as a Slime S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/471181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9YcNx1dnNkZ3PZzrMqc52WjCEcw.jpg'),
(161341, 11451, 'That Time I Got Reincarnated as a Slime S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502558.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bs6Flt7I9N8tuHnjEaSf36283T8.jpg'),
(161342, 11451, 'That Time I Got Reincarnated as a Slime S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502559.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j7NCloTQ6Ct4XO2JdB9VcBmtIkZ.jpg'),
(161343, 11451, 'That Time I Got Reincarnated as a Slime S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502560.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tDu3AlVFeqQYaW4cNe5VpdRHn7f.jpg'),
(161344, 11451, 'That Time I Got Reincarnated as a Slime S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502561.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rDgVd7RALIs5AddXvPxhCX3epc8.jpg'),
(161345, 11451, 'That Time I Got Reincarnated as a Slime S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502562.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gxIH2VyiJii33RI01YKuyWlC5OS.jpg'),
(161346, 11451, 'That Time I Got Reincarnated as a Slime S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502563.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t0pVgAn54d8hEM8jlXKR6mo78d8.jpg'),
(161347, 11451, 'That Time I Got Reincarnated as a Slime S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502564.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9USrLwMcUYAsEf23FsUhkA9MXuu.jpg'),
(161348, 11451, 'That Time I Got Reincarnated as a Slime S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502565.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oevQGAJLWW1pSCnrWIzz1WQu3hw.jpg'),
(161349, 11451, 'That Time I Got Reincarnated as a Slime S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502566.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oSSUuI7fI1GtHX9eBhIdNprsgsV.jpg'),
(161350, 11451, 'That Time I Got Reincarnated as a Slime S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502567.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/llymxkqLyxv7G7SJUB8Kp3HQsw6.jpg'),
(161351, 11451, 'That Time I Got Reincarnated as a Slime S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502568.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mJJZ9fQ2kCZtEooOYaDteLBbVg6.jpg'),
(161352, 11451, 'That Time I Got Reincarnated as a Slime S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/502569.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oJNmEBZbQbYJ23CKs4ez6F4X1NU.jpg'),
(161353, 11451, 'That Time I Got Reincarnated as a Slime S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/502570.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jBI5jxywljEpn2rRJ4Za638l94U.jpg'),
(161354, 11451, 'That Time I Got Reincarnated as a Slime S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/502571.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2Bhta8n31W6N5BYyWZGioHwcf2r.jpg'),
(161355, 11451, 'That Time I Got Reincarnated as a Slime S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/502572.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rV0yfsBqoCbRZf93h1MbfEImGqW.jpg'),
(161356, 11451, 'That Time I Got Reincarnated as a Slime S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/502573.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9jmfp8IiwWRMt9UiJKJOuw2rWrb.jpg'),
(161357, 11451, 'That Time I Got Reincarnated as a Slime S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/502574.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Q9Y5d5V8xSJ9hyhWEOkSviNPS8.jpg'),
(161358, 11451, 'That Time I Got Reincarnated as a Slime S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/502575.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/36fEVDsd90B2nmMOvjxgmMrooG8.jpg'),
(161359, 11451, 'That Time I Got Reincarnated as a Slime S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/502576.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/myX4iY2MSXFqzQwDdZ9NY5WnEWu.jpg'),
(161360, 11451, 'That Time I Got Reincarnated as a Slime S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/502577.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/grvpiSfzWRVsjKm7T9g0eGjZDeJ.jpg'),
(161361, 11451, 'That Time I Got Reincarnated as a Slime S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/502578.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uOfZ4vpjzLmrxwQLD0xNtc752lQ.jpg'),
(161362, 11451, 'That Time I Got Reincarnated as a Slime S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/502579.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8qorHFrntCGKcb5VEMKTek9tAbW.jpg'),
(161363, 11451, 'That Time I Got Reincarnated as a Slime S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/502580.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xagCdFgh27KPDG6myv3uG3BrZpD.jpg'),
(161364, 11451, 'That Time I Got Reincarnated as a Slime S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/502581.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zZmkBDXs1qgTgL9ajzcRTnEZM6p.jpg'),
(161365, 11452, 'That Time I Got Reincarnated as a Slime S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502582.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qGdvJCuZLL3XTlaVcokjmjOYwVT.jpg'),
(161366, 11452, 'That Time I Got Reincarnated as a Slime S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502583.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gnkxMRfTMvM4MINia242eUwC2BC.jpg'),
(161367, 11452, 'That Time I Got Reincarnated as a Slime S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502584.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oX5lgWyfgFytnF4CMd54iiSZk4z.jpg'),
(161368, 11452, 'That Time I Got Reincarnated as a Slime S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502585.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jxataJe0pYR1TsO6XdmALL9ANxw.jpg'),
(161369, 11452, 'That Time I Got Reincarnated as a Slime S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502586.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kzmSrgouF94DQPtUDh4Kz5TKWD8.jpg'),
(161370, 11452, 'That Time I Got Reincarnated as a Slime S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502587.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b8A5oHCMXL1jjuO2M03JscJdzuS.jpg'),
(161371, 11452, 'That Time I Got Reincarnated as a Slime S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502588.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6mNV55ohN64U7aJwEmJjjp4hGKi.jpg'),
(161372, 11452, 'That Time I Got Reincarnated as a Slime S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502589.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c3Jj3Xb99fSvJJpvddxZnq3dy0c.jpg'),
(161373, 11452, 'That Time I Got Reincarnated as a Slime S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502590.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bGT0jO2TjNWLg3OiDkGdaSJP6g9.jpg'),
(161374, 11452, 'That Time I Got Reincarnated as a Slime S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502591.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9jYxy649Hdhsq8h5TvuLHiAAv7B.jpg'),
(161375, 11452, 'That Time I Got Reincarnated as a Slime S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502592.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wwHzXThhY1lXcMWSRbVStjdpLEw.jpg'),
(161376, 11452, 'That Time I Got Reincarnated as a Slime S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/502593.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hPGZS4IGBxTQVZJmhgUwIIFXslH.jpg'),
(161377, 11452, 'That Time I Got Reincarnated as a Slime S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/502594.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3zBjNDMUpcRVjgFjZocBEGqAT9F.jpg'),
(161378, 11452, 'That Time I Got Reincarnated as a Slime S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/502595.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r2etwUKAEWtBwpS1IxawnFGUXDL.jpg'),
(161379, 11452, 'That Time I Got Reincarnated as a Slime S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/502596.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3sNFkBcw2Voe9B7vNj2EZw9f5KM.jpg'),
(161380, 11452, 'That Time I Got Reincarnated as a Slime S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/502597.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pimVG6E4gDUEpttY4OZCXDLZmbb.jpg'),
(161381, 11452, 'That Time I Got Reincarnated as a Slime S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/502598.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7xUiEXbNU4yWw4r8XWmBrrC6wsB.jpg'),
(161382, 11452, 'That Time I Got Reincarnated as a Slime S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/502599.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/er7j1Py01CRLM8ZOtzv5yBVREjX.jpg'),
(161383, 11452, 'That Time I Got Reincarnated as a Slime S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/502600.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sDHYySPS447hY31ukvDRAar0ODo.jpg'),
(161384, 11452, 'That Time I Got Reincarnated as a Slime S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/502601.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ibk5z7Byfgqi1J9Fv2iZ0iMqizh.jpg'),
(161385, 11453, 'A Pracinha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161386, 11453, 'A Pracinha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/625878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161387, 11453, 'A Pracinha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/475554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161388, 11453, 'A Pracinha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/475555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161389, 11453, 'A Pracinha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/475556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161390, 11453, 'A Pracinha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/475557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161391, 11453, 'A Pracinha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/475558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161392, 11453, 'A Pracinha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/475559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161393, 11453, 'A Pracinha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/475560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161394, 11453, 'A Pracinha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/475561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161395, 11454, 'A Pracinha S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/666381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161396, 11454, 'A Pracinha S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/670029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161397, 11454, 'A Pracinha S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/795121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161398, 11454, 'A Pracinha S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/795122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161399, 11454, 'A Pracinha S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/795123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161400, 11454, 'A Pracinha S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/795124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161401, 11454, 'A Pracinha S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/795125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161402, 11454, 'A Pracinha S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/795126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161403, 11454, 'A Pracinha S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/795127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161404, 11454, 'A Pracinha S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/795128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161405, 11455, 'A Pracinha S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/888250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161406, 11455, 'A Pracinha S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/888251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161407, 11455, 'A Pracinha S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/888252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161408, 11455, 'A Pracinha S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/888253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161409, 11455, 'A Pracinha S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/888254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161410, 11455, 'A Pracinha S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/888255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161411, 11455, 'A Pracinha S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/888256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161412, 11455, 'A Pracinha S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/888257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161413, 11455, 'A Pracinha S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/888258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161414, 11455, 'A Pracinha S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/888259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ePJYT2x2AOWZQfdX3vy3s0Okdbi.jpg'),
(161415, 11456, 'Ash vs Evil Dead S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475522.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jjn4rqMeqKJpf1PVEGsZeSHLYMZ.jpg'),
(161416, 11456, 'Ash vs Evil Dead S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/475523.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oHtGZvJvnMKEncTFesvkUpn5dFO.jpg'),
(161417, 11456, 'Ash vs Evil Dead S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/475524.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kbR1K3A3nl6Km0bb9bSP46cZh4h.jpg'),
(161418, 11456, 'Ash vs Evil Dead S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/475525.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5FeaOcMobRryl8cWba4tB0x1sRj.jpg'),
(161419, 11456, 'Ash vs Evil Dead S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/475526.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/quEuKLrnIATUAhwD2Fd4rPBc9Dc.jpg'),
(161420, 11456, 'Ash vs Evil Dead S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/475527.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qmvZYpNcBb6xHofAf3wUNrCpq9e.jpg'),
(161421, 11456, 'Ash vs Evil Dead S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/475528.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wwxL9nL7Whvns08L9JHfQADLNMH.jpg'),
(161422, 11456, 'Ash vs Evil Dead S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/475529.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tgXx94YHx2jNx9ncTvjekPIAa2L.jpg'),
(161423, 11456, 'Ash vs Evil Dead S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/475530.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ka06pRSe84krCyBQGJsdbbEotA0.jpg'),
(161424, 11456, 'Ash vs Evil Dead S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/475531.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bKrPWl7u8T7X8ZMzuLSYTO2b5Kn.jpg'),
(161425, 11457, 'Ash vs Evil Dead S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475532.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vREjbRFJf5qx3bUKb9uewi377nm.jpg'),
(161426, 11457, 'Ash vs Evil Dead S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/475533.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2xnQLwOESCutqyPcQ19Bcl3uW0i.jpg'),
(161427, 11457, 'Ash vs Evil Dead S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/475534.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mR0sHllcXWrCaMCj1rpjZG2VuCL.jpg'),
(161428, 11457, 'Ash vs Evil Dead S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/475535.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4pvZQhr2xtOVNKdWjCh2kUQTkDZ.jpg'),
(161429, 11457, 'Ash vs Evil Dead S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/475536.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/63QLZmCi6lZvfQt2aHVxEmd5cY1.jpg'),
(161430, 11457, 'Ash vs Evil Dead S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/475537.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7yt9EEqzJJNv6iowgiQr9KRA1Ya.jpg'),
(161431, 11457, 'Ash vs Evil Dead S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/475538.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2HZpiFAK1yznmVkINm6oOtZiyU4.jpg'),
(161432, 11457, 'Ash vs Evil Dead S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/475539.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9BIO2tsdrV5JJBOOpzncxvyXDvm.jpg'),
(161433, 11457, 'Ash vs Evil Dead S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/475540.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uPgVizNFm4VJoo9fl2cHot5Who2.jpg'),
(161434, 11457, 'Ash vs Evil Dead S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/475541.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vzFox17tszap1dvxYAujZmqGjk.jpg'),
(161435, 11458, 'Ash vs Evil Dead S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475542.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oNV1srvQs4MO9CSwJkYcVgVDhNo.jpg'),
(161436, 11458, 'Ash vs Evil Dead S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/475543.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zZtRskxwOeNF50C84o0eQHb6o16.jpg'),
(161437, 11458, 'Ash vs Evil Dead S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/475544.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wrGvPDO1VHWhVyk3o72awYYE0PN.jpg'),
(161438, 11458, 'Ash vs Evil Dead S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/475545.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j0o40WDJHGU8oHHHApooqMAHezA.jpg'),
(161439, 11458, 'Ash vs Evil Dead S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/475546.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7x9Ahrf2jbSzj0QYglzgw65VzBZ.jpg'),
(161440, 11458, 'Ash vs Evil Dead S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/475547.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/asjkTLAxZCop9mMycTC6CItTXKF.jpg'),
(161441, 11458, 'Ash vs Evil Dead S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/475548.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tYgWWBMLF8pHOkAMi5cLD8DfURG.jpg'),
(161442, 11458, 'Ash vs Evil Dead S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/475549.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pRkPDhK7FZ6ebYsPzaO71KDAyfi.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(161443, 11458, 'Ash vs Evil Dead S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/475550.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/620EJmWoYYU3FsKLykkwJvzHK2s.jpg'),
(161444, 11458, 'Ash vs Evil Dead S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/475551.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mkyZYgWiMWtoWCPrdeSuhkqC19G.jpg'),
(161445, 11459, 'O Incrivel Circo Digital S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475519.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xonR1txXqYwyXhHnjZjEv0Yxpcs.jpg'),
(161446, 11459, 'O Incrivel Circo Digital S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/475520.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kRSwu3leMIra0rQVfA7wJtjADtB.jpg'),
(161447, 11459, 'O Incrivel Circo Digital S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/475521.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1K5ZTet6GnJiDke7tOEcEDTzN6j.jpg'),
(161448, 11459, 'O Incrivel Circo Digital S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/525221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/DP3elz7gDEkZbYnDyZk60CX7AA.jpg'),
(161449, 11459, 'O Incrivel Circo Digital S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/896468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/DP3elz7gDEkZbYnDyZk60CX7AA.jpg'),
(161450, 11459, 'O Incrivel Circo Digital S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/896469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/DP3elz7gDEkZbYnDyZk60CX7AA.jpg'),
(161451, 11459, 'O Incrivel Circo Digital S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/896470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/DP3elz7gDEkZbYnDyZk60CX7AA.jpg'),
(161452, 11460, 'Seis irmaos Esquizofrenicos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475518.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nVELQJxgaN2ulFc6viOxUFFUijV.jpg'),
(161453, 11460, 'Seis irmaos Esquizofrenicos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/488107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vkpp2YD2uA4HBERVt0bRFuDJex0.jpg'),
(161454, 11460, 'Seis irmaos Esquizofrenicos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/488108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vkpp2YD2uA4HBERVt0bRFuDJex0.jpg'),
(161455, 11460, 'Seis irmaos Esquizofrenicos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/497907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vkpp2YD2uA4HBERVt0bRFuDJex0.jpg'),
(161456, 11461, 'A Franquia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475517.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iKIV8PaB2DBffASETh9swVbmMPz.jpg'),
(161457, 11461, 'A Franquia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WVXrvTgieRu3VlSodzKVmQPzkw.jpg'),
(161458, 11461, 'A Franquia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WVXrvTgieRu3VlSodzKVmQPzkw.jpg'),
(161459, 11461, 'A Franquia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/493965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WVXrvTgieRu3VlSodzKVmQPzkw.jpg'),
(161460, 11461, 'A Franquia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/497217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WVXrvTgieRu3VlSodzKVmQPzkw.jpg'),
(161461, 11461, 'A Franquia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/503392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WVXrvTgieRu3VlSodzKVmQPzkw.jpg'),
(161462, 11461, 'A Franquia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WVXrvTgieRu3VlSodzKVmQPzkw.jpg'),
(161463, 11461, 'A Franquia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/512626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/WVXrvTgieRu3VlSodzKVmQPzkw.jpg'),
(161464, 11462, 'Gintama [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475649.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wrSrCPl18BezBwFmNsTzC13ZQd9.jpg'),
(161465, 11462, 'Gintama [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/475650.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gUsJQDsG9P1jDeIvvSPsEzWLvZi.jpg'),
(161466, 11462, 'Gintama [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/475651.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d8jHNlW05xgHLHCZYzOGUPqIc8j.jpg'),
(161467, 11462, 'Gintama [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/475652.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jWD6SKPy80axhnKOGvS7dlWg4D.jpg'),
(161468, 11462, 'Gintama [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/475653.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6IQLouAoF75YoZM7iWCaEu7Yjxc.jpg'),
(161469, 11462, 'Gintama [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/475654.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jWU8f3P8VYi2WAjIRFkN2kP1ZwL.jpg'),
(161470, 11462, 'Gintama [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/475655.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pwLUJJMTX5CuBd1kehZcvS0376H.jpg'),
(161471, 11462, 'Gintama [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/475656.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gwMHoArQl9t5q6ezr6b1ze9lS5M.jpg'),
(161472, 11462, 'Gintama [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/475657.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1gJCQApDkIYeIUrvrBYL3SPyu8d.jpg'),
(161473, 11462, 'Gintama [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/475658.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6HUhzYEWzOdbAYjAuX1JvCHw6bw.jpg'),
(161474, 11462, 'Gintama [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/475659.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z2miowxPrFA2ykHOJbDR6mA6ipp.jpg'),
(161475, 11462, 'Gintama [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/475660.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A6X70gomZXNIoDgSdckaKu2hoy3.jpg'),
(161476, 11462, 'Gintama [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/475661.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sATPmJghKtCAYx7JiiC8ExWxQwM.jpg'),
(161477, 11462, 'Gintama [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/475662.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lQXAR1seRlBv6Agy59y88FogS89.jpg'),
(161478, 11462, 'Gintama [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/475663.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sgNWBwSpFaD4DsXUOFo4nGvvc2U.jpg'),
(161479, 11462, 'Gintama [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/475664.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6HVvxYX6vZhwTzSjmDdSa7KSewz.jpg'),
(161480, 11462, 'Gintama [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/475665.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jEHNwgkyR4aczulEZqflZcOuCMu.jpg'),
(161481, 11462, 'Gintama [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/475666.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6LYxS2MrulB4lqHraNRkXrTJiJB.jpg'),
(161482, 11462, 'Gintama [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/475667.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gJadkGLEp3U3PaLeUHrvKuSXCbO.jpg'),
(161483, 11462, 'Gintama [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/475668.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iZ3BO90VvJxPSLmO2NSMYxVkT1D.jpg'),
(161484, 11462, 'Gintama [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/475669.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dWij7yaVSpfJb626DbhRlkDEVvm.jpg'),
(161485, 11462, 'Gintama [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/475670.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kv3vg5YfncNvjis97pKIP1sEVU2.jpg'),
(161486, 11462, 'Gintama [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/475671.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2S2YMCpuUlcix21ww3uAa3Pliyu.jpg'),
(161487, 11462, 'Gintama [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/475672.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5dNTIpt7BVCfIaKi6TrdUHurOUK.jpg'),
(161488, 11462, 'Gintama [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/475673.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/juXdZEcjtYWQnH9Tu5YoUPcumqg.jpg'),
(161489, 11462, 'Gintama [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/475674.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rsZKoeqZqN9IRXLmrjL1rGaR9qJ.jpg'),
(161490, 11462, 'Gintama [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/475675.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tCMHLyp1cRA827NGwweAWdRfzxI.jpg'),
(161491, 11462, 'Gintama [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/475676.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qrq2woCheflopB9UdaJAk1dhBn6.jpg'),
(161492, 11462, 'Gintama [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/475677.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iyhXp9BBtlp7sSJNt67c33lELGq.jpg'),
(161493, 11462, 'Gintama [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/475678.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9wTYJJnvdSVjVjdF1LWyDd25YyP.jpg'),
(161494, 11462, 'Gintama [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/475679.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sMGyqYMbHMb4Wj9XjtSvL7j9Q42.jpg'),
(161495, 11462, 'Gintama [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/475680.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8bN8xvkmkX5NB8i3YXQb2nM0S7V.jpg'),
(161496, 11462, 'Gintama [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/475681.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ky6Wb8O2L4gWzrl98y2tBLBdJAs.jpg'),
(161497, 11462, 'Gintama [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/475682.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mG6wTE7KcyRRIQITSqdPcVvOtb9.jpg'),
(161498, 11462, 'Gintama [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/475683.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ayuEn3hARU4V4484UpEFVfSEftw.jpg'),
(161499, 11462, 'Gintama [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/475684.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yOnsdyAZFUwUr58giRDNoJpSRj1.jpg'),
(161500, 11462, 'Gintama [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/475685.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/exRcPbJrqfKUV7D74ZZdbsNcVez.jpg'),
(161501, 11462, 'Gintama [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/475686.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/utL30qXypohSvPQj4F3U3VRTJpp.jpg'),
(161502, 11462, 'Gintama [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/475687.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qXYG5zEmTzDEGIpQEq5fdD2SpH1.jpg'),
(161503, 11462, 'Gintama [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/475688.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qup3TOWaoHzjUx0SYhrXrvZAbov.jpg'),
(161504, 11462, 'Gintama [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/475689.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x1DpyRR0kgC3OYeozVQMR5Zhj1B.jpg'),
(161505, 11462, 'Gintama [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/475690.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wydiCUPCzTjXU1ZvXeRBlqUWesN.jpg'),
(161506, 11462, 'Gintama [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/475691.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6LNx7oLHVxnuaW2Rx4GK4SA9FjU.jpg'),
(161507, 11462, 'Gintama [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/475692.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oI55q5qYcal27XYfCvjh9h0NL8C.jpg'),
(161508, 11462, 'Gintama [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/475693.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ffH6z0Iz5aYHM3hydKUIBYpeabT.jpg'),
(161509, 11462, 'Gintama [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/475694.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tRBEuNHhPkHuTLP4iVxWaGSZzBt.jpg'),
(161510, 11462, 'Gintama [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/475695.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nuYLQWHXVeBlAz3NKMmi3dit8IA.jpg'),
(161511, 11462, 'Gintama [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/475696.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fVd9QVzXgdQUsTijbRViVlJkIdy.jpg'),
(161512, 11463, 'Gintama [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475697.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2AT2lTbI3u5ZJjpx7pcf48nMlpb.jpg'),
(161513, 11463, 'Gintama [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/475698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161514, 11463, 'Gintama [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/475699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161515, 11463, 'Gintama [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/475700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161516, 11463, 'Gintama [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/475701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161517, 11463, 'Gintama [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/475702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161518, 11463, 'Gintama [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/475703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161519, 11463, 'Gintama [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/475704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161520, 11463, 'Gintama [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/475705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161521, 11463, 'Gintama [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/475706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161522, 11463, 'Gintama [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/475707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161523, 11463, 'Gintama [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/475708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161524, 11463, 'Gintama [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/475709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161525, 11463, 'Gintama [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/475710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161526, 11463, 'Gintama [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/475711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161527, 11463, 'Gintama [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/475712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161528, 11463, 'Gintama [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/475713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161529, 11463, 'Gintama [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/475714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161530, 11463, 'Gintama [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/475715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161531, 11463, 'Gintama [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/475716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161532, 11463, 'Gintama [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/475717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161533, 11463, 'Gintama [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/475718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161534, 11463, 'Gintama [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/475719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161535, 11463, 'Gintama [L] S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/475720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161536, 11463, 'Gintama [L] S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/475721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161537, 11463, 'Gintama [L] S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/475722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161538, 11463, 'Gintama [L] S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/475723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161539, 11463, 'Gintama [L] S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/475724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161540, 11463, 'Gintama [L] S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/475725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161541, 11463, 'Gintama [L] S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/475726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161542, 11463, 'Gintama [L] S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/475727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161543, 11463, 'Gintama [L] S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/475728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161544, 11463, 'Gintama [L] S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/475729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161545, 11463, 'Gintama [L] S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/475730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161546, 11463, 'Gintama [L] S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/475731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161547, 11463, 'Gintama [L] S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/475732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161548, 11463, 'Gintama [L] S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/475733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161549, 11463, 'Gintama [L] S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/475734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161550, 11463, 'Gintama [L] S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/475735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161551, 11463, 'Gintama [L] S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/475736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161552, 11463, 'Gintama [L] S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/475737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161553, 11463, 'Gintama [L] S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/475738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161554, 11463, 'Gintama [L] S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/475739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161555, 11463, 'Gintama [L] S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/475740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161556, 11463, 'Gintama [L] S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/475741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161557, 11463, 'Gintama [L] S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/475742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161558, 11463, 'Gintama [L] S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/475743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161559, 11463, 'Gintama [L] S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/475744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161560, 11463, 'Gintama [L] S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/475745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161561, 11463, 'Gintama [L] S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/475746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161562, 11464, 'Gintama [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161563, 11464, 'Gintama [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/475748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161564, 11464, 'Gintama [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/475749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161565, 11464, 'Gintama [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/475750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161566, 11464, 'Gintama [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/475751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161567, 11464, 'Gintama [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/475752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161568, 11464, 'Gintama [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/475753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161569, 11464, 'Gintama [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/475754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161570, 11464, 'Gintama [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/475755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161571, 11464, 'Gintama [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/475756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161572, 11464, 'Gintama [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/475757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161573, 11464, 'Gintama [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/475758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161574, 11464, 'Gintama [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/475759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161575, 11464, 'Gintama [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/475760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161576, 11464, 'Gintama [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/475761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161577, 11464, 'Gintama [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/475762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161578, 11464, 'Gintama [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/475763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161579, 11464, 'Gintama [L] S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/475764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161580, 11464, 'Gintama [L] S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/475765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161581, 11464, 'Gintama [L] S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/475766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161582, 11464, 'Gintama [L] S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/475767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161583, 11464, 'Gintama [L] S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/475768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161584, 11464, 'Gintama [L] S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/475769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161585, 11464, 'Gintama [L] S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/475770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161586, 11464, 'Gintama [L] S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/475771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161587, 11464, 'Gintama [L] S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/475772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161588, 11464, 'Gintama [L] S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/475773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161589, 11464, 'Gintama [L] S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/475774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161590, 11464, 'Gintama [L] S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/475775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161591, 11464, 'Gintama [L] S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/475776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161592, 11464, 'Gintama [L] S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/475777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161593, 11464, 'Gintama [L] S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/475778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161594, 11464, 'Gintama [L] S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/475779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161595, 11464, 'Gintama [L] S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/475780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161596, 11464, 'Gintama [L] S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/475781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161597, 11464, 'Gintama [L] S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/475782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161598, 11464, 'Gintama [L] S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/475783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161599, 11464, 'Gintama [L] S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/475784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161600, 11464, 'Gintama [L] S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/475785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161601, 11464, 'Gintama [L] S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/475786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161602, 11464, 'Gintama [L] S03 E41', 'http://sinalprivado.info:80/series/1533784/1533784/475787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161603, 11464, 'Gintama [L] S03 E42', 'http://sinalprivado.info:80/series/1533784/1533784/475788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161604, 11464, 'Gintama [L] S03 E43', 'http://sinalprivado.info:80/series/1533784/1533784/475789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161605, 11464, 'Gintama [L] S03 E44', 'http://sinalprivado.info:80/series/1533784/1533784/475790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161606, 11464, 'Gintama [L] S03 E45', 'http://sinalprivado.info:80/series/1533784/1533784/475791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161607, 11464, 'Gintama [L] S03 E46', 'http://sinalprivado.info:80/series/1533784/1533784/475792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161608, 11464, 'Gintama [L] S03 E47', 'http://sinalprivado.info:80/series/1533784/1533784/475793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161609, 11464, 'Gintama [L] S03 E48', 'http://sinalprivado.info:80/series/1533784/1533784/475794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161610, 11464, 'Gintama [L] S03 E49', 'http://sinalprivado.info:80/series/1533784/1533784/475795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161611, 11464, 'Gintama [L] S03 E50', 'http://sinalprivado.info:80/series/1533784/1533784/475796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161612, 11464, 'Gintama [L] S03 E51', 'http://sinalprivado.info:80/series/1533784/1533784/475797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161613, 11465, 'Gintama [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161614, 11465, 'Gintama [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/475799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161615, 11465, 'Gintama [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/475800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161616, 11465, 'Gintama [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/475801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161617, 11465, 'Gintama [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/475802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161618, 11465, 'Gintama [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/475803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161619, 11465, 'Gintama [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/475804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161620, 11465, 'Gintama [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/475805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161621, 11465, 'Gintama [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/475806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161622, 11465, 'Gintama [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/475807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161623, 11465, 'Gintama [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/475808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161624, 11465, 'Gintama [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/475809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161625, 11465, 'Gintama [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/475810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161626, 11465, 'Gintama [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/475811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161627, 11465, 'Gintama [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/475812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161628, 11465, 'Gintama [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/475813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161629, 11465, 'Gintama [L] S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/475814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161630, 11465, 'Gintama [L] S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/475815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161631, 11465, 'Gintama [L] S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/475816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161632, 11465, 'Gintama [L] S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/475817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161633, 11465, 'Gintama [L] S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/475818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161634, 11465, 'Gintama [L] S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/475819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161635, 11465, 'Gintama [L] S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/475820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161636, 11465, 'Gintama [L] S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/475821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161637, 11465, 'Gintama [L] S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/475822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161638, 11465, 'Gintama [L] S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/475823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161639, 11465, 'Gintama [L] S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/475824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161640, 11465, 'Gintama [L] S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/475825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161641, 11465, 'Gintama [L] S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/475826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161642, 11465, 'Gintama [L] S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/475827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161643, 11465, 'Gintama [L] S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/475828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161644, 11465, 'Gintama [L] S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/475829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161645, 11465, 'Gintama [L] S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/475830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161646, 11465, 'Gintama [L] S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/475831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161647, 11465, 'Gintama [L] S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/475832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161648, 11465, 'Gintama [L] S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/475833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161649, 11465, 'Gintama [L] S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/475834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161650, 11465, 'Gintama [L] S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/475835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161651, 11465, 'Gintama [L] S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/475836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161652, 11465, 'Gintama [L] S04 E40', 'http://sinalprivado.info:80/series/1533784/1533784/475837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161653, 11465, 'Gintama [L] S04 E41', 'http://sinalprivado.info:80/series/1533784/1533784/475838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161654, 11465, 'Gintama [L] S04 E42', 'http://sinalprivado.info:80/series/1533784/1533784/475839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161655, 11465, 'Gintama [L] S04 E43', 'http://sinalprivado.info:80/series/1533784/1533784/475840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161656, 11465, 'Gintama [L] S04 E44', 'http://sinalprivado.info:80/series/1533784/1533784/475841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161657, 11465, 'Gintama [L] S04 E45', 'http://sinalprivado.info:80/series/1533784/1533784/475842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161658, 11465, 'Gintama [L] S04 E46', 'http://sinalprivado.info:80/series/1533784/1533784/475843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161659, 11465, 'Gintama [L] S04 E47', 'http://sinalprivado.info:80/series/1533784/1533784/475844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161660, 11465, 'Gintama [L] S04 E48', 'http://sinalprivado.info:80/series/1533784/1533784/475845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161661, 11465, 'Gintama [L] S04 E49', 'http://sinalprivado.info:80/series/1533784/1533784/475846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161662, 11465, 'Gintama [L] S04 E50', 'http://sinalprivado.info:80/series/1533784/1533784/475847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161663, 11466, 'Gintama [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161664, 11466, 'Gintama [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/475849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161665, 11466, 'Gintama [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/475850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161666, 11466, 'Gintama [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/475851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161667, 11466, 'Gintama [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/475852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161668, 11466, 'Gintama [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/475853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161669, 11466, 'Gintama [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/475854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161670, 11466, 'Gintama [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/475855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161671, 11466, 'Gintama [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/475856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161672, 11466, 'Gintama [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/475857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161673, 11466, 'Gintama [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/475858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161674, 11466, 'Gintama [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/475859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161675, 11466, 'Gintama [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/475860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161676, 11466, 'Gintama [L] S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/475861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161677, 11466, 'Gintama [L] S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/475862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161678, 11466, 'Gintama [L] S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/475863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161679, 11466, 'Gintama [L] S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/475864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161680, 11466, 'Gintama [L] S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/475865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161681, 11466, 'Gintama [L] S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/475866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161682, 11466, 'Gintama [L] S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/475867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161683, 11466, 'Gintama [L] S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/475868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161684, 11466, 'Gintama [L] S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/475869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161685, 11466, 'Gintama [L] S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/475870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161686, 11466, 'Gintama [L] S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/475871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161687, 11466, 'Gintama [L] S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/475872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161688, 11466, 'Gintama [L] S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/475873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161689, 11466, 'Gintama [L] S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/475874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161690, 11466, 'Gintama [L] S05 E28', 'http://sinalprivado.info:80/series/1533784/1533784/475875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161691, 11466, 'Gintama [L] S05 E29', 'http://sinalprivado.info:80/series/1533784/1533784/475876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161692, 11466, 'Gintama [L] S05 E30', 'http://sinalprivado.info:80/series/1533784/1533784/475877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161693, 11466, 'Gintama [L] S05 E31', 'http://sinalprivado.info:80/series/1533784/1533784/475878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161694, 11466, 'Gintama [L] S05 E32', 'http://sinalprivado.info:80/series/1533784/1533784/475879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161695, 11466, 'Gintama [L] S05 E33', 'http://sinalprivado.info:80/series/1533784/1533784/475880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161696, 11466, 'Gintama [L] S05 E34', 'http://sinalprivado.info:80/series/1533784/1533784/475881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161697, 11466, 'Gintama [L] S05 E35', 'http://sinalprivado.info:80/series/1533784/1533784/475882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161698, 11466, 'Gintama [L] S05 E36', 'http://sinalprivado.info:80/series/1533784/1533784/475883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161699, 11466, 'Gintama [L] S05 E37', 'http://sinalprivado.info:80/series/1533784/1533784/475884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161700, 11466, 'Gintama [L] S05 E38', 'http://sinalprivado.info:80/series/1533784/1533784/475885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161701, 11466, 'Gintama [L] S05 E39', 'http://sinalprivado.info:80/series/1533784/1533784/475886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161702, 11466, 'Gintama [L] S05 E40', 'http://sinalprivado.info:80/series/1533784/1533784/475887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161703, 11466, 'Gintama [L] S05 E41', 'http://sinalprivado.info:80/series/1533784/1533784/475888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161704, 11466, 'Gintama [L] S05 E42', 'http://sinalprivado.info:80/series/1533784/1533784/475889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161705, 11466, 'Gintama [L] S05 E43', 'http://sinalprivado.info:80/series/1533784/1533784/475890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161706, 11466, 'Gintama [L] S05 E44', 'http://sinalprivado.info:80/series/1533784/1533784/475891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161707, 11466, 'Gintama [L] S05 E45', 'http://sinalprivado.info:80/series/1533784/1533784/475892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161708, 11466, 'Gintama [L] S05 E46', 'http://sinalprivado.info:80/series/1533784/1533784/475893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(161709, 11466, 'Gintama [L] S05 E47', 'http://sinalprivado.info:80/series/1533784/1533784/475894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161710, 11466, 'Gintama [L] S05 E48', 'http://sinalprivado.info:80/series/1533784/1533784/475895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161711, 11466, 'Gintama [L] S05 E49', 'http://sinalprivado.info:80/series/1533784/1533784/475896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161712, 11466, 'Gintama [L] S05 E50', 'http://sinalprivado.info:80/series/1533784/1533784/475897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161713, 11466, 'Gintama [L] S05 E51', 'http://sinalprivado.info:80/series/1533784/1533784/475898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161714, 11467, 'Gintama [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161715, 11467, 'Gintama [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/475900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161716, 11467, 'Gintama [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/475901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161717, 11467, 'Gintama [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/475902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161718, 11467, 'Gintama [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/475903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161719, 11467, 'Gintama [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/475904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161720, 11467, 'Gintama [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/475905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161721, 11467, 'Gintama [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/475906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161722, 11467, 'Gintama [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/475907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161723, 11467, 'Gintama [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/475908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161724, 11467, 'Gintama [L] S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/475909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161725, 11467, 'Gintama [L] S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/475910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161726, 11467, 'Gintama [L] S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/475911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161727, 11468, 'Gintama [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161728, 11468, 'Gintama [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/475913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161729, 11468, 'Gintama [L] S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/475914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161730, 11468, 'Gintama [L] S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/475915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161731, 11468, 'Gintama [L] S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/475916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161732, 11468, 'Gintama [L] S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/475917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161733, 11468, 'Gintama [L] S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/475918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161734, 11468, 'Gintama [L] S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/475919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161735, 11468, 'Gintama [L] S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/475920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161736, 11468, 'Gintama [L] S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/475921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161737, 11468, 'Gintama [L] S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/475922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161738, 11468, 'Gintama [L] S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/475923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161739, 11468, 'Gintama [L] S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/475924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161740, 11468, 'Gintama [L] S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/475925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161741, 11468, 'Gintama [L] S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/475926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161742, 11468, 'Gintama [L] S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/475927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161743, 11468, 'Gintama [L] S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/475928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161744, 11468, 'Gintama [L] S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/475929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161745, 11468, 'Gintama [L] S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/475930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161746, 11468, 'Gintama [L] S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/475931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161747, 11468, 'Gintama [L] S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/475932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161748, 11468, 'Gintama [L] S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/475933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161749, 11468, 'Gintama [L] S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/475934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161750, 11468, 'Gintama [L] S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/475935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161751, 11468, 'Gintama [L] S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/475936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161752, 11468, 'Gintama [L] S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/475937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161753, 11468, 'Gintama [L] S07 E27', 'http://sinalprivado.info:80/series/1533784/1533784/475938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161754, 11468, 'Gintama [L] S07 E28', 'http://sinalprivado.info:80/series/1533784/1533784/475939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161755, 11468, 'Gintama [L] S07 E29', 'http://sinalprivado.info:80/series/1533784/1533784/475940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161756, 11468, 'Gintama [L] S07 E30', 'http://sinalprivado.info:80/series/1533784/1533784/475941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161757, 11468, 'Gintama [L] S07 E31', 'http://sinalprivado.info:80/series/1533784/1533784/475942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161758, 11468, 'Gintama [L] S07 E32', 'http://sinalprivado.info:80/series/1533784/1533784/475943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161759, 11468, 'Gintama [L] S07 E33', 'http://sinalprivado.info:80/series/1533784/1533784/475944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161760, 11468, 'Gintama [L] S07 E34', 'http://sinalprivado.info:80/series/1533784/1533784/475945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161761, 11468, 'Gintama [L] S07 E35', 'http://sinalprivado.info:80/series/1533784/1533784/475946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161762, 11468, 'Gintama [L] S07 E36', 'http://sinalprivado.info:80/series/1533784/1533784/475947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161763, 11468, 'Gintama [L] S07 E37', 'http://sinalprivado.info:80/series/1533784/1533784/475948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161764, 11468, 'Gintama [L] S07 E38', 'http://sinalprivado.info:80/series/1533784/1533784/475949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161765, 11468, 'Gintama [L] S07 E39', 'http://sinalprivado.info:80/series/1533784/1533784/475950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161766, 11468, 'Gintama [L] S07 E40', 'http://sinalprivado.info:80/series/1533784/1533784/475951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161767, 11468, 'Gintama [L] S07 E41', 'http://sinalprivado.info:80/series/1533784/1533784/475952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161768, 11468, 'Gintama [L] S07 E42', 'http://sinalprivado.info:80/series/1533784/1533784/475953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161769, 11468, 'Gintama [L] S07 E43', 'http://sinalprivado.info:80/series/1533784/1533784/475954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161770, 11468, 'Gintama [L] S07 E44', 'http://sinalprivado.info:80/series/1533784/1533784/475955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161771, 11468, 'Gintama [L] S07 E45', 'http://sinalprivado.info:80/series/1533784/1533784/475956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161772, 11468, 'Gintama [L] S07 E46', 'http://sinalprivado.info:80/series/1533784/1533784/475957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161773, 11468, 'Gintama [L] S07 E47', 'http://sinalprivado.info:80/series/1533784/1533784/475958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161774, 11468, 'Gintama [L] S07 E48', 'http://sinalprivado.info:80/series/1533784/1533784/475959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161775, 11468, 'Gintama [L] S07 E49', 'http://sinalprivado.info:80/series/1533784/1533784/475960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161776, 11468, 'Gintama [L] S07 E50', 'http://sinalprivado.info:80/series/1533784/1533784/475961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161777, 11469, 'Gintama [L] S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161778, 11469, 'Gintama [L] S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/475963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161779, 11469, 'Gintama [L] S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/475964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161780, 11469, 'Gintama [L] S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/475965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161781, 11469, 'Gintama [L] S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/475966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161782, 11469, 'Gintama [L] S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/475967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161783, 11469, 'Gintama [L] S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/475968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161784, 11469, 'Gintama [L] S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/475969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161785, 11469, 'Gintama [L] S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/475970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161786, 11469, 'Gintama [L] S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/475971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161787, 11469, 'Gintama [L] S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/475972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161788, 11469, 'Gintama [L] S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/475973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161789, 11469, 'Gintama [L] S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/475974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161790, 11469, 'Gintama [L] S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/475975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161791, 11469, 'Gintama [L] S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/475976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161792, 11469, 'Gintama [L] S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/475977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161793, 11469, 'Gintama [L] S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/475978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161794, 11469, 'Gintama [L] S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/475979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161795, 11469, 'Gintama [L] S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/475980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161796, 11469, 'Gintama [L] S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/475981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161797, 11469, 'Gintama [L] S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/475982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161798, 11469, 'Gintama [L] S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/475983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161799, 11469, 'Gintama [L] S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/475984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161800, 11469, 'Gintama [L] S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/475985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161801, 11469, 'Gintama [L] S08 E25', 'http://sinalprivado.info:80/series/1533784/1533784/475986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161802, 11469, 'Gintama [L] S08 E26', 'http://sinalprivado.info:80/series/1533784/1533784/475987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161803, 11469, 'Gintama [L] S08 E27', 'http://sinalprivado.info:80/series/1533784/1533784/475988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161804, 11469, 'Gintama [L] S08 E28', 'http://sinalprivado.info:80/series/1533784/1533784/475989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161805, 11469, 'Gintama [L] S08 E29', 'http://sinalprivado.info:80/series/1533784/1533784/475990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161806, 11469, 'Gintama [L] S08 E30', 'http://sinalprivado.info:80/series/1533784/1533784/475991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161807, 11469, 'Gintama [L] S08 E31', 'http://sinalprivado.info:80/series/1533784/1533784/475992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161808, 11469, 'Gintama [L] S08 E32', 'http://sinalprivado.info:80/series/1533784/1533784/475993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161809, 11469, 'Gintama [L] S08 E33', 'http://sinalprivado.info:80/series/1533784/1533784/475994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161810, 11469, 'Gintama [L] S08 E34', 'http://sinalprivado.info:80/series/1533784/1533784/475995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161811, 11469, 'Gintama [L] S08 E35', 'http://sinalprivado.info:80/series/1533784/1533784/475996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161812, 11469, 'Gintama [L] S08 E36', 'http://sinalprivado.info:80/series/1533784/1533784/475997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161813, 11469, 'Gintama [L] S08 E37', 'http://sinalprivado.info:80/series/1533784/1533784/475998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161814, 11469, 'Gintama [L] S08 E38', 'http://sinalprivado.info:80/series/1533784/1533784/475999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161815, 11469, 'Gintama [L] S08 E39', 'http://sinalprivado.info:80/series/1533784/1533784/476000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161816, 11469, 'Gintama [L] S08 E40', 'http://sinalprivado.info:80/series/1533784/1533784/476001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161817, 11469, 'Gintama [L] S08 E41', 'http://sinalprivado.info:80/series/1533784/1533784/476002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161818, 11469, 'Gintama [L] S08 E42', 'http://sinalprivado.info:80/series/1533784/1533784/476003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161819, 11469, 'Gintama [L] S08 E43', 'http://sinalprivado.info:80/series/1533784/1533784/476004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161820, 11469, 'Gintama [L] S08 E44', 'http://sinalprivado.info:80/series/1533784/1533784/476005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161821, 11469, 'Gintama [L] S08 E45', 'http://sinalprivado.info:80/series/1533784/1533784/476006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161822, 11469, 'Gintama [L] S08 E46', 'http://sinalprivado.info:80/series/1533784/1533784/476007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161823, 11469, 'Gintama [L] S08 E47', 'http://sinalprivado.info:80/series/1533784/1533784/476008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161824, 11469, 'Gintama [L] S08 E48', 'http://sinalprivado.info:80/series/1533784/1533784/476009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161825, 11469, 'Gintama [L] S08 E49', 'http://sinalprivado.info:80/series/1533784/1533784/476010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cWD3BD0aQFypLGVOvd23hWdg5bP.jpg'),
(161826, 11470, 'Parasyte The Maxim S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475625.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b8xmC8J3MUb4knwo8F9u6orP6Wy.jpg'),
(161827, 11470, 'Parasyte The Maxim S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/475626.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6xPU5vPmvkrkTqmdpF4JGsDApYp.jpg'),
(161828, 11470, 'Parasyte The Maxim S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/475627.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6iBbBJiZfv1RD5dvg6Y8I5BgkDu.jpg'),
(161829, 11470, 'Parasyte The Maxim S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/475628.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f0m3suL9QmKU8N8ugnIGHFzVOEf.jpg'),
(161830, 11470, 'Parasyte The Maxim S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/475629.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/meTyTu5BqCFa9ZxZpWWlAwu5rmh.jpg'),
(161831, 11470, 'Parasyte The Maxim S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/475630.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hL6wciEKcvF5ZjDJRmp2UeYn5v4.jpg'),
(161832, 11470, 'Parasyte The Maxim S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/475631.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4aYMLNDLjx0Y2Lnl7L5Mgg1iIYE.jpg'),
(161833, 11470, 'Parasyte The Maxim S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/475632.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4radWJoiPcvwLTd0gvqJ5nWmm5M.jpg'),
(161834, 11470, 'Parasyte The Maxim S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/475633.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9r9KkPbObx3ApDd7Vb3bc19LWTJ.jpg'),
(161835, 11470, 'Parasyte The Maxim S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/475634.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f7IM0QOTEMcvsUbr8PWJPZThwCn.jpg'),
(161836, 11470, 'Parasyte The Maxim S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/475635.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/haf8wk2S8M0aSiBvzzUb7b9ZlB6.jpg'),
(161837, 11470, 'Parasyte The Maxim S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/475636.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k9jjVH1OwmmFWZZgaytWNADQQi1.jpg'),
(161838, 11470, 'Parasyte The Maxim S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/475637.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/21Xgq86JRqj7t9KPWQKlJxn3IOt.jpg'),
(161839, 11470, 'Parasyte The Maxim S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/475638.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2TlbPtUSgaR8u43zG8is1Wojo6z.jpg'),
(161840, 11470, 'Parasyte The Maxim S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/475639.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nyGwhBr81IuNq77KcqW1KNNbJmf.jpg'),
(161841, 11470, 'Parasyte The Maxim S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/475640.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u8UcVFB7GnwgkQ5d4qRvdaCK8cb.jpg'),
(161842, 11470, 'Parasyte The Maxim S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/475641.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bafEV5CCI4cT4Y52p9iIN3LZgsJ.jpg'),
(161843, 11470, 'Parasyte The Maxim S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/475642.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xsmBLZvLpFeLF2tP3pufNPDytqQ.jpg'),
(161844, 11470, 'Parasyte The Maxim S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/475643.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yhiBQ7HmjFo3frXpSynRNF8t9rB.jpg'),
(161845, 11470, 'Parasyte The Maxim S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/475644.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aVgLHGQEJ4WNWvRR1MRnN1v1ltV.jpg'),
(161846, 11470, 'Parasyte The Maxim S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/475645.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rJqJgECcU0iVhIIOcIz1CvNuSqK.jpg'),
(161847, 11470, 'Parasyte The Maxim S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/475646.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jy0phUX4i6ptjFxwlrVPsChNiWC.jpg'),
(161848, 11470, 'Parasyte The Maxim S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/475647.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9h0kZusfGap0q1uMuf7072wolHR.jpg'),
(161849, 11470, 'Parasyte The Maxim S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/475648.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p0UrUCI26FQIZKWo5KTUBuhUHaG.jpg'),
(161850, 11471, 'Tomb Raider A Lenda de Lara Croft S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475617.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bO42warcrw9cMeT9QVbEMzVGFnr.jpg'),
(161851, 11471, 'Tomb Raider A Lenda de Lara Croft S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/475618.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ryg8JoATKyaAbZS1u6aFEElsgvY.jpg'),
(161852, 11471, 'Tomb Raider A Lenda de Lara Croft S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/475619.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bqyu4gJoixTLcpZjj9hbacgZFKm.jpg'),
(161853, 11471, 'Tomb Raider A Lenda de Lara Croft S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/475620.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aQ0edij0Qxp3zDD13hYK1E7bls0.jpg'),
(161854, 11471, 'Tomb Raider A Lenda de Lara Croft S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/475621.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yok1hh7eP6XdPQFRGC9PLzkVUQ1.jpg'),
(161855, 11471, 'Tomb Raider A Lenda de Lara Croft S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/475622.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iIiItMtk7umBq8ix9QsHuxPEcri.jpg'),
(161856, 11471, 'Tomb Raider A Lenda de Lara Croft S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/475623.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qeSB8QbvB7t9ZLHHuj2s7as0Flx.jpg'),
(161857, 11471, 'Tomb Raider A Lenda de Lara Croft S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/475624.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l1Xl20J052YtGrjO2YFahDN5iDy.jpg'),
(161858, 11472, 'Tomb Raider A Lenda de Lara Croft S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/895824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIvbfZFLJGwNvJKJcnYIppSbWdI.jpg'),
(161859, 11472, 'Tomb Raider A Lenda de Lara Croft S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/895825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIvbfZFLJGwNvJKJcnYIppSbWdI.jpg'),
(161860, 11472, 'Tomb Raider A Lenda de Lara Croft S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/895826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIvbfZFLJGwNvJKJcnYIppSbWdI.jpg'),
(161861, 11472, 'Tomb Raider A Lenda de Lara Croft S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/895827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIvbfZFLJGwNvJKJcnYIppSbWdI.jpg'),
(161862, 11472, 'Tomb Raider A Lenda de Lara Croft S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/895828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIvbfZFLJGwNvJKJcnYIppSbWdI.jpg'),
(161863, 11472, 'Tomb Raider A Lenda de Lara Croft S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/895829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIvbfZFLJGwNvJKJcnYIppSbWdI.jpg'),
(161864, 11472, 'Tomb Raider A Lenda de Lara Croft S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/895830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIvbfZFLJGwNvJKJcnYIppSbWdI.jpg'),
(161865, 11472, 'Tomb Raider A Lenda de Lara Croft S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/895831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mIvbfZFLJGwNvJKJcnYIppSbWdI.jpg'),
(161866, 11473, 'A Familia Addams (1964) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475595.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/14NByLYYUpBCDqBtvN23U9a7mOf.jpg'),
(161867, 11473, 'A Familia Addams (1964) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/475596.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/94IGHpnorAGpBWfx8dXXGgSBVRd.jpg'),
(161868, 11473, 'A Familia Addams (1964) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/475597.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4ZS4MOiR8PQoG73pHgp8AH3CuAu.jpg'),
(161869, 11473, 'A Familia Addams (1964) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/475598.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iBaPtPL6j28AB3nMcBghlwPW9vb.jpg'),
(161870, 11473, 'A Familia Addams (1964) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/475599.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6173j1ViTwVeQFLlD3YL1WevRLT.jpg'),
(161871, 11473, 'A Familia Addams (1964) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/475600.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zUIzRWUIKifgbzeKCKd5vD2CVV.jpg'),
(161872, 11473, 'A Familia Addams (1964) S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/475601.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fWXdbIT0wOqXynQQrq5GQNQ5nVV.jpg'),
(161873, 11473, 'A Familia Addams (1964) S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/475602.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l3M64Z3iJ2tenPrl3rjo7EoDF6m.jpg'),
(161874, 11473, 'A Familia Addams (1964) S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/475603.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2nlCWQ7eJNWdLYaJOcy2GfP61zD.jpg'),
(161875, 11473, 'A Familia Addams (1964) S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/475604.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jNp7TvGQfyiKDKzg8vm2VqBycgV.jpg'),
(161876, 11473, 'A Familia Addams (1964) S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/475605.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lustPtyczrCduwUayWjP5GwoJUo.jpg'),
(161877, 11473, 'A Familia Addams (1964) S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/475606.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nnInX7OvSDnfy2oNA8RycXLgiV6.jpg'),
(161878, 11473, 'A Familia Addams (1964) S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/475607.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wNPMS5jJaeUhuR6P8VMV686XbYU.jpg'),
(161879, 11473, 'A Familia Addams (1964) S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/475608.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lSGrnoL2DxXnjG3GRYcIwSVhETC.jpg'),
(161880, 11473, 'A Familia Addams (1964) S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/475609.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lYnfepq336nPicf2UnSbVuwTmfw.jpg'),
(161881, 11473, 'A Familia Addams (1964) S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/475610.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/22XOM6yzhLSXWiRhlYiJkWwD5kU.jpg'),
(161882, 11473, 'A Familia Addams (1964) S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/475611.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sFtuUBEETYs3xqxCxFdw0jkDBmM.jpg'),
(161883, 11473, 'A Familia Addams (1964) S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/475612.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Amarta9bM6hK1FohDBBikrlrT4U.jpg'),
(161884, 11473, 'A Familia Addams (1964) S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/475613.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bTKpIkF3RuFi8GVwWE6YVOzcpjg.jpg'),
(161885, 11473, 'A Familia Addams (1964) S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/475614.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yZnG1SEYbk43qCqAai6b0PSzJhe.jpg'),
(161886, 11473, 'A Familia Addams (1964) S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/475615.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4NfUbKWOv2Xyhzz7NFC5AVWgxYD.jpg'),
(161887, 11473, 'A Familia Addams (1964) S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/475616.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5kHJPGZf8bXaws8j06VvkS84OIT.jpg'),
(161888, 11474, 'Amor Traicoeiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475589.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ez1tfoXG4NlSk8tropHdfsV1zjf.jpg'),
(161889, 11474, 'Amor Traicoeiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/475590.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4zr6sEKlr2kXVbv5JaGV6Oj9D41.jpg'),
(161890, 11474, 'Amor Traicoeiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/475591.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tbnFNIRMsNrfp9XNG2fOD0TxQS4.jpg'),
(161891, 11474, 'Amor Traicoeiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/475592.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uL0kcmGDTzLyDp2S6pIDfoKe1ZC.jpg'),
(161892, 11474, 'Amor Traicoeiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/475593.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vZWsVaPz4Ljb37RlInResOJJevZ.jpg'),
(161893, 11474, 'Amor Traicoeiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/475594.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qBEB3HBqqdzqSynP4c0MaNJzYmz.jpg'),
(161894, 11475, 'Disclaimer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475587.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qMRKjdWi3CD6ZJkBz0l3GprwBCK.jpg'),
(161895, 11475, 'Disclaimer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/475588.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yMxiuzXq8R9j7jBikbVtVEDtLxg.jpg'),
(161896, 11475, 'Disclaimer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6TdW4T2EsnhXrPQccB8szK93UhF.jpg'),
(161897, 11475, 'Disclaimer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6TdW4T2EsnhXrPQccB8szK93UhF.jpg'),
(161898, 11475, 'Disclaimer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/626825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6TdW4T2EsnhXrPQccB8szK93UhF.jpg'),
(161899, 11475, 'Disclaimer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/626826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6TdW4T2EsnhXrPQccB8szK93UhF.jpg'),
(161900, 11475, 'Disclaimer S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/499167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6TdW4T2EsnhXrPQccB8szK93UhF.jpg'),
(161901, 11476, 'Murai in Love S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475581.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/FXghbAWMP3fgkszvODVzQ8nsh8.jpg'),
(161902, 11476, 'Murai in Love S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/475582.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oNyQMOQNS9hu9YdRDcLwXUY99zV.jpg'),
(161903, 11476, 'Murai in Love S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/475583.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/25PLw7ZZdDmaRnSm1ldKtVkN8YR.jpg'),
(161904, 11476, 'Murai in Love S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/475584.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bY4WJI2o4oC40CuqBoEoGAyheuz.jpg'),
(161905, 11476, 'Murai in Love S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/475585.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2vTM2GxaoMa2LRl0WxEKE04jU5n.jpg'),
(161906, 11476, 'Murai in Love S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/475586.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ewb2mBVeGjrEXzP6pKBNbtXuFXZ.jpg'),
(161907, 11476, 'Murai in Love S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oaYHnhk09qc20zj7IzYhuwfbgSI.jpg'),
(161908, 11476, 'Murai in Love S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/490800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oaYHnhk09qc20zj7IzYhuwfbgSI.jpg'),
(161909, 11476, 'Murai in Love S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/492269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oaYHnhk09qc20zj7IzYhuwfbgSI.jpg'),
(161910, 11476, 'Murai in Love S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/499849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oaYHnhk09qc20zj7IzYhuwfbgSI.jpg'),
(161911, 11476, 'Murai in Love S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/505561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oaYHnhk09qc20zj7IzYhuwfbgSI.jpg'),
(161912, 11476, 'Murai in Love S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/509348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oaYHnhk09qc20zj7IzYhuwfbgSI.jpg'),
(161913, 11477, 'NBA 5 em Quadra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475571.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qGdl4AczVh6MDwUTHZ2cuWSBYmE.jpg'),
(161914, 11477, 'NBA 5 em Quadra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/475572.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rUSGv79ciPCYkz1911K1z8Oepgn.jpg'),
(161915, 11477, 'NBA 5 em Quadra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/475573.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/edMifag1tohPXrV5PkEHbZoyuFB.jpg'),
(161916, 11477, 'NBA 5 em Quadra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/475574.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cjhYMnjDnaVdWTiWbcMNjwN5kcc.jpg'),
(161917, 11477, 'NBA 5 em Quadra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/475575.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uTtu2VPINNPQzWO6D8mrBEgmvuA.jpg'),
(161918, 11477, 'NBA 5 em Quadra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/475576.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hhgpqz8B2q7pViTSovHiq7t8DOv.jpg'),
(161919, 11477, 'NBA 5 em Quadra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/475577.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vTZ4EWF3QrfZjitN1aDj1yDLfoA.jpg'),
(161920, 11477, 'NBA 5 em Quadra S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/475578.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pB7dLbQRKdqXUBKtWpUqu9r1uez.jpg'),
(161921, 11477, 'NBA 5 em Quadra S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/475579.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dLm5KGXMyCxrZC2yIvNXyzvCS5Y.jpg'),
(161922, 11477, 'NBA 5 em Quadra S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/475580.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6L01pPN35MwCJ9mNbWTbNztE5ZC.jpg'),
(161923, 11478, 'NBA 5 em Quadra S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/889062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/95kxEQlknZXGQGyKnogRHn75rCR.jpg'),
(161924, 11478, 'NBA 5 em Quadra S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/889063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/95kxEQlknZXGQGyKnogRHn75rCR.jpg'),
(161925, 11478, 'NBA 5 em Quadra S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/889064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/95kxEQlknZXGQGyKnogRHn75rCR.jpg'),
(161926, 11478, 'NBA 5 em Quadra S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/889065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/95kxEQlknZXGQGyKnogRHn75rCR.jpg'),
(161927, 11478, 'NBA 5 em Quadra S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/889066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/95kxEQlknZXGQGyKnogRHn75rCR.jpg'),
(161928, 11478, 'NBA 5 em Quadra S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/889067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/95kxEQlknZXGQGyKnogRHn75rCR.jpg'),
(161929, 11478, 'NBA 5 em Quadra S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/889068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/95kxEQlknZXGQGyKnogRHn75rCR.jpg'),
(161930, 11478, 'NBA 5 em Quadra S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/889069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/95kxEQlknZXGQGyKnogRHn75rCR.jpg'),
(161931, 11479, 'O Segredo do Rio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/475563.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2JaoJUaqDFKvEWAif28YbFMejWU.jpg'),
(161932, 11479, 'O Segredo do Rio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/475564.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vS1wOl0jeo0bczZSlaIeCNg1owX.jpg'),
(161933, 11479, 'O Segredo do Rio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/475565.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k7rB2xfASQZVAW9bOnBWXn7ek9.jpg'),
(161934, 11479, 'O Segredo do Rio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/475566.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dyzUEWQmRQx8NvjyVvw8oc9ZXGS.jpg'),
(161935, 11479, 'O Segredo do Rio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/475567.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5mFEqEl0zL2LuYAeUjFayR8TqSy.jpg'),
(161936, 11479, 'O Segredo do Rio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/475568.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pYiVyVlmHJJWV5uJQehPKII8gAB.jpg'),
(161937, 11479, 'O Segredo do Rio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/475569.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oCROJjWkIzWBBxe0aKsCWIeCQo4.jpg'),
(161938, 11479, 'O Segredo do Rio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/475570.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6dyF5UtnE12RcYzcxSTTJXzEzQc.jpg'),
(161939, 11480, 'O Tatuador de Auschwitz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479486.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/egYgRLLGTf3zRxB72HAofnfh2EC.jpg'),
(161940, 11480, 'O Tatuador de Auschwitz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479487.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rCgRoiz3iKOlEsFgI4vSVndO4et.jpg'),
(161941, 11480, 'O Tatuador de Auschwitz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479488.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AmUKxjr18Q4q8IIm7YMVKlfBffh.jpg'),
(161942, 11480, 'O Tatuador de Auschwitz S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479489.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uqXXXv50pnYTWebCP29Ea2YK0ri.jpg'),
(161943, 11480, 'O Tatuador de Auschwitz S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479490.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eFrJgSoujEdj5vXkgjgffvefip7.jpg'),
(161944, 11480, 'O Tatuador de Auschwitz S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479491.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h9Q8pua9LrZkrW2LIhNF6jt3mZH.jpg'),
(161945, 11481, 'TV Colosso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161946, 11481, 'TV Colosso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161947, 11481, 'TV Colosso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161948, 11481, 'TV Colosso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161949, 11481, 'TV Colosso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161950, 11481, 'TV Colosso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/488074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161951, 11481, 'TV Colosso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/488075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161952, 11481, 'TV Colosso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/488076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161953, 11481, 'TV Colosso S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/488077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161954, 11481, 'TV Colosso S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/488078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161955, 11481, 'TV Colosso S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/490006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161956, 11481, 'TV Colosso S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/490007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161957, 11481, 'TV Colosso S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/490008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161958, 11481, 'TV Colosso S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/490009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161959, 11481, 'TV Colosso S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/490010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161960, 11481, 'TV Colosso S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/494900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161961, 11481, 'TV Colosso S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/494901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161962, 11481, 'TV Colosso S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/494902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161963, 11481, 'TV Colosso S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/494903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161964, 11481, 'TV Colosso S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/494904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161965, 11481, 'TV Colosso S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/494905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161966, 11481, 'TV Colosso S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/498854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161967, 11481, 'TV Colosso S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/498855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161968, 11481, 'TV Colosso S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/498856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161969, 11481, 'TV Colosso S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/504663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161970, 11481, 'TV Colosso S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/504664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(161971, 11481, 'TV Colosso S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/504665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161972, 11481, 'TV Colosso S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/504666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161973, 11481, 'TV Colosso S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/504667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161974, 11481, 'TV Colosso S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/507543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161975, 11481, 'TV Colosso S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/511138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161976, 11481, 'TV Colosso S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/511139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161977, 11481, 'TV Colosso S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/511140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161978, 11481, 'TV Colosso S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/511141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161979, 11481, 'TV Colosso S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/511142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161980, 11481, 'TV Colosso S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/513968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161981, 11481, 'TV Colosso S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/513969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161982, 11481, 'TV Colosso S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/513970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161983, 11481, 'TV Colosso S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/513971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161984, 11481, 'TV Colosso S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/513972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vzVbjj3CdMwtbYI5zBaRpmspqZ4.jpg'),
(161985, 11482, 'Amores que Enganam S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8IiPHI9dHvDCxKgD1CKyNxqCOX6.jpg'),
(161986, 11482, 'Amores que Enganam S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/485908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8IiPHI9dHvDCxKgD1CKyNxqCOX6.jpg'),
(161987, 11482, 'Amores que Enganam S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/493097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8IiPHI9dHvDCxKgD1CKyNxqCOX6.jpg'),
(161988, 11482, 'Amores que Enganam S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/497113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8IiPHI9dHvDCxKgD1CKyNxqCOX6.jpg'),
(161989, 11482, 'Amores que Enganam S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/503369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8IiPHI9dHvDCxKgD1CKyNxqCOX6.jpg'),
(161990, 11482, 'Amores que Enganam S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8IiPHI9dHvDCxKgD1CKyNxqCOX6.jpg'),
(161991, 11482, 'Amores que Enganam S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8IiPHI9dHvDCxKgD1CKyNxqCOX6.jpg'),
(161992, 11482, 'Amores que Enganam S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8IiPHI9dHvDCxKgD1CKyNxqCOX6.jpg'),
(161993, 11482, 'Amores que Enganam S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8IiPHI9dHvDCxKgD1CKyNxqCOX6.jpg'),
(161994, 11482, 'Amores que Enganam S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8IiPHI9dHvDCxKgD1CKyNxqCOX6.jpg'),
(161995, 11483, 'Citadel Diana S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479474.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fQZz58bKGWr7gh37G6gIljcvwyb.jpg'),
(161996, 11483, 'Citadel Diana S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479475.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9gFXm9OKSERnpnvQQa55xYPMooX.jpg'),
(161997, 11483, 'Citadel Diana S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479476.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vXjQuftUlWfbDpqDhuAnxkoeE6I.jpg'),
(161998, 11483, 'Citadel Diana S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479477.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pqdcBZV6FYqTZd9J3es83rILLbi.jpg'),
(161999, 11483, 'Citadel Diana S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479478.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jwh16a10blfYTkXjgTPYcHDjYyN.jpg'),
(162000, 11483, 'Citadel Diana S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479479.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/51N91s7MQ4ZImtCTeJJMEsw1H3P.jpg'),
(162001, 11484, 'Os Invenciveis CarrosMonstros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479448.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3p00ngPoSwfFRNqxRiBZXcqUldP.jpg'),
(162002, 11484, 'Os Invenciveis CarrosMonstros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479449.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nCYzImNXnyo7YFw4XqRhfXqAQGw.jpg'),
(162003, 11484, 'Os Invenciveis CarrosMonstros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479450.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hzfxkZj9r9Zujc1okol4liSAvqI.jpg'),
(162004, 11484, 'Os Invenciveis CarrosMonstros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479451.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wxryns6smQ0tE3dXLpu1qmtzu9r.jpg'),
(162005, 11484, 'Os Invenciveis CarrosMonstros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479452.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ti6jfczfB4WStvKth8bG0ZFNTuI.jpg'),
(162006, 11484, 'Os Invenciveis CarrosMonstros S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479453.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ssdpSCnWjziDqbydQfYAUN3Y9gS.jpg'),
(162007, 11484, 'Os Invenciveis CarrosMonstros S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/479454.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jaxxK3w3P0i3AydJjDf64SQ0wsL.jpg'),
(162008, 11484, 'Os Invenciveis CarrosMonstros S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/479455.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rzcOT7SAPXuaDnDfatsyPWOQfxx.jpg'),
(162009, 11484, 'Os Invenciveis CarrosMonstros S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/479456.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2Cnd2o3BCPLInUE8ufDWrRNCvcZ.jpg'),
(162010, 11484, 'Os Invenciveis CarrosMonstros S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/479457.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qzXLeVHjzLL4k8zg3oWBAQsjeL8.jpg'),
(162011, 11484, 'Os Invenciveis CarrosMonstros S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/479458.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n1caBFcdWJ9SfvR5wNxsqwoHNZ4.jpg'),
(162012, 11484, 'Os Invenciveis CarrosMonstros S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/479459.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fuURMO3oZmoyxpVJJhO9SdmAJFT.jpg'),
(162013, 11484, 'Os Invenciveis CarrosMonstros S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/479460.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ixxOU0Zmjr6iO3yLFAdfOB86zxz.jpg'),
(162014, 11484, 'Os Invenciveis CarrosMonstros S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/479461.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qzJSMcFCvIavIGWkEaXuw4ef4xg.jpg'),
(162015, 11484, 'Os Invenciveis CarrosMonstros S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/479462.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aMfCfztiKQy7qCs55hWThfwTuhZ.jpg'),
(162016, 11484, 'Os Invenciveis CarrosMonstros S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/479463.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aYGBmx4kkRGCQpSi2Gnc6NSlhUW.jpg'),
(162017, 11484, 'Os Invenciveis CarrosMonstros S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/479464.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9okNhZSLupOYE4YYdsBk4meORqR.jpg'),
(162018, 11484, 'Os Invenciveis CarrosMonstros S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/479465.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v4NVL2M6IBzVJ6gcuIQ8xEbg25J.jpg'),
(162019, 11484, 'Os Invenciveis CarrosMonstros S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/479466.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ilGJR4vM6aHfXLe6HE8NBy0xYX0.jpg'),
(162020, 11484, 'Os Invenciveis CarrosMonstros S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/479467.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/os546lYmDNENBTbHwNDTA5PwC31.jpg'),
(162021, 11484, 'Os Invenciveis CarrosMonstros S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/479468.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ds2JjaTTmS8EeJhZuYBwLkb60zE.jpg'),
(162022, 11484, 'Os Invenciveis CarrosMonstros S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/479469.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ajT8TC9R0c91Dq1qSpikRBH37rx.jpg'),
(162023, 11484, 'Os Invenciveis CarrosMonstros S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/479470.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6X0JDw37VMX41ox1VIGwHsrgkNY.jpg'),
(162024, 11484, 'Os Invenciveis CarrosMonstros S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/479471.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kXc4RYrOKTEHmGhZ3LSHjsMRx9f.jpg'),
(162025, 11484, 'Os Invenciveis CarrosMonstros S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/479472.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/R5KRcC3vxTLywaL75Rmq04Xc4V.jpg'),
(162026, 11484, 'Os Invenciveis CarrosMonstros S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/479473.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kmo9l418FMdWcTfW0afQJK1Owdt.jpg'),
(162027, 11485, 'Felicity S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/483793.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bYE7aY4gyTyjLyqsKieGVpm6lK.jpg'),
(162028, 11485, 'Felicity S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/483794.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dGpgDrJJvAvVl6SE7P7nIMwVCBC.jpg'),
(162029, 11485, 'Felicity S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/483795.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bYJevhigx09HvVCtqX5nG2MEZCh.jpg'),
(162030, 11485, 'Felicity S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/483796.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/owd5RuXtU3fTySFvyH5fbNXsSij.jpg'),
(162031, 11485, 'Felicity S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/483797.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dnE55ezwF1bJFp446z2bz1TqEsp.jpg'),
(162032, 11485, 'Felicity S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/483798.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aZsJkrkSajQsNx81VwLqGJ8s9Xa.jpg'),
(162033, 11485, 'Felicity S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/483799.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8LktrFpEsfwqeUocWXt3mVpiaS4.jpg'),
(162034, 11485, 'Felicity S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/483800.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ezcQlqiqQtj29BOXiDEX1XkCP22.jpg'),
(162035, 11485, 'Felicity S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/483801.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2zjQULHWqx0GF0ziCQwxymhNKBi.jpg'),
(162036, 11485, 'Felicity S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/483802.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6pgJWhbzSovsTh9qLkvGYGquXOx.jpg'),
(162037, 11485, 'Felicity S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/483803.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9VqLDOKtkvtjHYARfZQwePwfadU.jpg'),
(162038, 11485, 'Felicity S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/483804.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3vIxQ538Pxi6M4OOlVIlyIagrVp.jpg'),
(162039, 11485, 'Felicity S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/483805.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vCIDJjIauJyS0BRAqeFylkC5Qdk.jpg'),
(162040, 11485, 'Felicity S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/483806.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l3WjkF1Pq1DE1FbHrDEYyXeDTRo.jpg'),
(162041, 11485, 'Felicity S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/483807.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i1ePXAyeftBj1PSggXpD2M1kc4l.jpg'),
(162042, 11485, 'Felicity S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/483808.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/btCwfFqopP6RSJ2Uc7w4s3W7Txk.jpg'),
(162043, 11485, 'Felicity S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/483809.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s1iyxVTYLk4QPMJghnFS0kQZA9g.jpg'),
(162044, 11485, 'Felicity S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/483810.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mvfQTFggA09E1wzwR2Z7u1N9IT7.jpg'),
(162045, 11485, 'Felicity S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/483811.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/edNhzL7ksLzSpyXnGkUYR4Wkn6k.jpg'),
(162046, 11485, 'Felicity S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/483812.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/naAVMjEANw4PuNaVJVjWqQUeMaj.jpg'),
(162047, 11485, 'Felicity S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/483813.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ttwSz1vk8xsTNOee5mXiHel0QOo.jpg'),
(162048, 11485, 'Felicity S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/483814.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1ml5Jr3sBF9KP9TiAfc2gzfv102.jpg'),
(162049, 11486, 'Felicity S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/483815.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tIFLghNrzyiIs4xJljhjPwgXgel.jpg'),
(162050, 11486, 'Felicity S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/483816.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wgGrJvjALtnCsoqVyykSOgZO5cu.jpg'),
(162051, 11486, 'Felicity S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/483817.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dDMDLztJTbfvm4smydj3dOLDF9M.jpg'),
(162052, 11486, 'Felicity S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/483818.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v7c726qgATMl1psAnOPSpjgffD5.jpg'),
(162053, 11486, 'Felicity S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/483819.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hEXP8gOvoXG2LI4WoH78oaCQe45.jpg'),
(162054, 11486, 'Felicity S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/483820.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5PDgqFs1RT0YNlckT9eFREqaqUF.jpg'),
(162055, 11486, 'Felicity S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/483821.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cQxlHl01hfLnlGH6VQp5Cw4idRr.jpg'),
(162056, 11486, 'Felicity S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/483822.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cNWAv1tCgMEMOA1BhWO8lSqZish.jpg'),
(162057, 11486, 'Felicity S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/483823.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vBYZL1kwCSDM1y256XnSCAnSEzj.jpg'),
(162058, 11486, 'Felicity S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/483824.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wT0lauxmUEhRhbjZfbstENWXBEY.jpg'),
(162059, 11486, 'Felicity S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/483825.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u90YUI9vGjC60NFp9EV8oXylMU0.jpg'),
(162060, 11486, 'Felicity S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/483826.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xFZj8uex27uGdf42kIgxJDAuidT.jpg'),
(162061, 11486, 'Felicity S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/483827.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a2LPB2E05lKjYFrBYDSuF35If7v.jpg'),
(162062, 11486, 'Felicity S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/483828.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nYXVXV0zgfrRs8S7J173wRmHAvx.jpg'),
(162063, 11486, 'Felicity S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/483829.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jTDugTlGE3Zh6KmkbH4Jvgaa65U.jpg'),
(162064, 11486, 'Felicity S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/483830.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hlXktV5OFLvIjbuVHPdWyyDcQOZ.jpg'),
(162065, 11486, 'Felicity S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/483831.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/csqjTe6X4u5EFTkEw00eW4fTrxX.jpg'),
(162066, 11486, 'Felicity S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/483832.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f1dvtp5v7wkWR01jJuPicHa9kjC.jpg'),
(162067, 11486, 'Felicity S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/483833.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lN8PoAlC2dEcm8ANE3rhtnpzcx.jpg'),
(162068, 11486, 'Felicity S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/483834.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Agq2pCKAA31w7VjOqHEZLdX5yFW.jpg'),
(162069, 11486, 'Felicity S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/483835.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k0FFy1XnljaHR9KhW9AzqgTnqOj.jpg'),
(162070, 11486, 'Felicity S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/483836.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yMvXRukjCzICBW098s1JWRULBbx.jpg'),
(162071, 11486, 'Felicity S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/483837.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rTmO5Hrszwq7Tc1zDnT247ZXRj1.jpg'),
(162072, 11487, 'Felicity S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/483838.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fUSrpVZh9kVWKPJFZUiggki9lNu.jpg'),
(162073, 11487, 'Felicity S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/483839.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tw70mSGD9QrN7ORGXm13jWsBAsu.jpg'),
(162074, 11487, 'Felicity S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/483840.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gHMvSWWF9OePYozPH6RYu24Lu9D.jpg'),
(162075, 11487, 'Felicity S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/483841.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pPzYvpjJcrsUktpiK5BhlnZVhXU.jpg'),
(162076, 11487, 'Felicity S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/483842.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f65WEdWA70rhp3pogRXIX61QyBG.jpg'),
(162077, 11487, 'Felicity S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/483843.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bUEW8ksi33PNjL4k0yuIXXsUFU.jpg'),
(162078, 11487, 'Felicity S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/483844.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fk0eho74pCmjnvU92h8XggmG0dY.jpg'),
(162079, 11487, 'Felicity S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/483845.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jkyTkrbItOILsQeaHNBqWgikY8J.jpg'),
(162080, 11487, 'Felicity S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/483846.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bchDoZbawgMbmRybLgNlvkEgbw6.jpg'),
(162081, 11487, 'Felicity S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/483847.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7umL9dkTIkvXWIBBCmzTle6S6HN.jpg'),
(162082, 11487, 'Felicity S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/483848.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wVLB0dzKRC4NnBPhSH8bKHeVX9X.jpg'),
(162083, 11487, 'Felicity S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/483849.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vFqdVxsIFCc9U8qWS6koZBxElY0.jpg'),
(162084, 11487, 'Felicity S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/483850.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/smrQJCmw2v2ine4NBUtAxXQockr.jpg'),
(162085, 11487, 'Felicity S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/483851.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hC8WXjwXhHeR5mdTzjV9Zp6GIG7.jpg'),
(162086, 11487, 'Felicity S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/483852.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9ixLTVuVFeVIzHmDFu0lmxHdIXR.jpg'),
(162087, 11487, 'Felicity S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/483853.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z7zTxQ6v5sFTyMq7HYBYavQRpS7.jpg'),
(162088, 11487, 'Felicity S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/483854.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/51IwBAUCPvuBoqE58zwiBa3zIrV.jpg'),
(162089, 11488, 'Felicity S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/739568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dbP9h32XdRtyK1sg8O6Z2kHXlnP.jpg'),
(162090, 11488, 'Felicity S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/739569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tWAXZvR0TUTGotzDavRvXbkW1uu.jpg'),
(162091, 11488, 'Felicity S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/739570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a1jOpAK6MWGCEo4LJaBSG6CtnEu.jpg'),
(162092, 11488, 'Felicity S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/739571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/43BeUb9hitFSt8AwwqXZ2tY9ORa.jpg'),
(162093, 11488, 'Felicity S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/739572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cH8DnWeni0zWcA3biyGoiTNqAie.jpg'),
(162094, 11488, 'Felicity S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/739573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/h5PMZSofQoYTJ8DctldDwlgp9Nt.jpg'),
(162095, 11488, 'Felicity S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/739574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gQhWsIzh2z9q69ep06KT6cGhvax.jpg'),
(162096, 11488, 'Felicity S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/739575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t7ZBgn3Kj17fVpup6yW3A9Mvvvj.jpg'),
(162097, 11488, 'Felicity S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/739576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zgApt7I8utyQvK3pbBQAyVPhP5i.jpg'),
(162098, 11488, 'Felicity S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/739577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cUQKJBWjBO4JBjx8jMEvx8L8zXN.jpg'),
(162099, 11488, 'Felicity S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/739578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uuw4kXFiQrLEbdYrZzLiY15Luu5.jpg'),
(162100, 11488, 'Felicity S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/739579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/utYA7F3HDHr3Qa5amgTjeRJzrDf.jpg'),
(162101, 11488, 'Felicity S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/739580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/il5cLSZoiCjVFdbd8R3OmDBvF5d.jpg'),
(162102, 11488, 'Felicity S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/739581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVboVATs6fSWoBP21V255Br5nXh.jpg'),
(162103, 11488, 'Felicity S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/739582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fE14RXDd24dLxJ5Oq7S6nz3zCxF.jpg'),
(162104, 11488, 'Felicity S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/739583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x6sMzdoqSlMmVnP4zeEFC40vKoy.jpg'),
(162105, 11488, 'Felicity S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/739584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nk2Zmk5VuQAxG1mRADB5rq1O77v.jpg'),
(162106, 11488, 'Felicity S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/739585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w3CjUnoI70CruVXI0PWlEBYPH4M.jpg'),
(162107, 11488, 'Felicity S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/739586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cGB80QaM1Jc16dwVHkER4jSTlkC.jpg'),
(162108, 11488, 'Felicity S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/739587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cActw5QDTVeVATdUJUa1mcZd6M5.jpg'),
(162109, 11488, 'Felicity S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/739588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/84Ufs71iOacF5KU35QR9QkTHwrW.jpg'),
(162110, 11488, 'Felicity S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/739589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7fRZQ7BREFrxQeOWrB8uNMg8kC9.jpg'),
(162111, 11489, 'Sr Rainha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/483773.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xZ7dWDnAqyy1ywtnzj34ZngRmj8.jpg'),
(162112, 11489, 'Sr Rainha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/483774.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cixThg9b00MvJKolqsfpXe6GDW3.jpg'),
(162113, 11489, 'Sr Rainha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/483775.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xLRpdsHmxeqjncLKKlOAKX5ou28.jpg'),
(162114, 11489, 'Sr Rainha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/483776.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/IggbLkj4NAvZdTwCXsucar4qWP.jpg'),
(162115, 11489, 'Sr Rainha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/483777.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oWBoalZHPAeQSF7c71SagS8FrFe.jpg'),
(162116, 11489, 'Sr Rainha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/483778.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3BNtGoo7qqGjPozB37t477YdbY0.jpg'),
(162117, 11489, 'Sr Rainha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/483779.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8PleE05KfZuktbBu4skQ6xaNrwz.jpg'),
(162118, 11489, 'Sr Rainha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/483780.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gTSNA0OWyH5zoGdctLsdwecjJdr.jpg'),
(162119, 11489, 'Sr Rainha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/483781.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bIp94QTTbNae2OOfCaIvvwLHXpI.jpg'),
(162120, 11489, 'Sr Rainha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/483782.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mL9rVaSkTsFmcEdeqIxsFks8BoI.jpg'),
(162121, 11489, 'Sr Rainha S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/483783.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5sCAsnE6uEHQbGeUtRoJNH1H2fw.jpg'),
(162122, 11489, 'Sr Rainha S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/483784.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ncJvbDwqQF2xOzgazOzokz7y9iE.jpg'),
(162123, 11489, 'Sr Rainha S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/483785.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gtrMuS1iFIYrLCdzbkywRoZsCQE.jpg'),
(162124, 11489, 'Sr Rainha S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/483786.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yCxXmcoAvaWqX0urkdIoJjpUuQf.jpg'),
(162125, 11489, 'Sr Rainha S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/483787.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yFqqMW4tVKiPtPULQlQHfMoFVE1.jpg'),
(162126, 11489, 'Sr Rainha S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/483788.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vdsfKGPJEW2rlaOnjqnS0VG95wZ.jpg'),
(162127, 11489, 'Sr Rainha S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/483789.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aG6llPzH3lLu1j4heNDVCymHTOW.jpg'),
(162128, 11489, 'Sr Rainha S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/483790.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ggnnN6V2JK4ULR25Kwiq7b4wIhG.jpg'),
(162129, 11489, 'Sr Rainha S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/483791.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Flu5ahNWRTlwAAcSI7tsxEc8PM.jpg'),
(162130, 11489, 'Sr Rainha S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/483792.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zGZeIKSI3AxOknuIVEI9uwS0CbR.jpg'),
(162131, 11490, 'Ultimate Homem Aranha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/483669.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/30kJO5kG6lRNtx8fCGaZwUlIOqM.jpg'),
(162132, 11490, 'Ultimate Homem Aranha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/483670.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7E2vyhVzXUWdLfiIa1SvWXBkPBi.jpg'),
(162133, 11490, 'Ultimate Homem Aranha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/483671.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wzP0GrCpQlefB5P2h6PAVP2MQTk.jpg'),
(162134, 11490, 'Ultimate Homem Aranha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/483672.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cOcuO2461RiRBdvDO8Sw9BEEiw0.jpg'),
(162135, 11490, 'Ultimate Homem Aranha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/483673.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bBgL56jmvpKK3XvafD1AkyE39nD.jpg'),
(162136, 11490, 'Ultimate Homem Aranha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/483674.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8ifgi1T3DURetTA0YMyVA4WMoTE.jpg'),
(162137, 11490, 'Ultimate Homem Aranha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/483675.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wrFmbxivEueTAMEcCMAEFtKpeS4.jpg'),
(162138, 11490, 'Ultimate Homem Aranha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/483676.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mD4LoaJqkReNJQFRZg0faK2RclS.jpg'),
(162139, 11490, 'Ultimate Homem Aranha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/483677.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1dPcCpLNq4jrFg6yao2qIGAFXhG.jpg'),
(162140, 11490, 'Ultimate Homem Aranha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/483678.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fqqNiqPyPeoDcjeNQegIha9YjDN.jpg'),
(162141, 11490, 'Ultimate Homem Aranha S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/483679.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iR96pqBaAfT8ppp0bpgLToTCe8Z.jpg'),
(162142, 11490, 'Ultimate Homem Aranha S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/483680.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bzmQ7L9KzWREf2pnB9NfxBzF8O6.jpg'),
(162143, 11490, 'Ultimate Homem Aranha S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/483681.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aRozoH4BgSAuJNbyi2GDCID9kY6.jpg'),
(162144, 11490, 'Ultimate Homem Aranha S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/483682.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cozvVOZsO9DsIPMx0v1jJzvgiVK.jpg'),
(162145, 11490, 'Ultimate Homem Aranha S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/483683.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/udCU4v11mJvg8L0UxUmmANn3zf1.jpg'),
(162146, 11490, 'Ultimate Homem Aranha S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/483684.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2xhrg9WFjyWEqfyJOoruKngp3CD.jpg'),
(162147, 11490, 'Ultimate Homem Aranha S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/483685.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zcHwQaHvlHdzF78GLi8FFD6dnzt.jpg'),
(162148, 11490, 'Ultimate Homem Aranha S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/483686.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1hXjfpabsmgz5i62PIYZDiof45z.jpg'),
(162149, 11490, 'Ultimate Homem Aranha S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/483687.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rVPvSWZJNQtSsEwFeCBuIFjNyhq.jpg'),
(162150, 11490, 'Ultimate Homem Aranha S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/483688.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b6rY7UAfsTPwIops2WqofC2AW5L.jpg'),
(162151, 11490, 'Ultimate Homem Aranha S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/483689.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yc3kGlBcxgQAsFa7qa6Xl0nvSM5.jpg'),
(162152, 11490, 'Ultimate Homem Aranha S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/483690.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/IiUHgWod7wCL0tNMTtJZMf9K3w.jpg'),
(162153, 11490, 'Ultimate Homem Aranha S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/483691.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1yBb9ecOjjspvXR7Uo8Ds0uWyKI.jpg'),
(162154, 11490, 'Ultimate Homem Aranha S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/483692.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vv8xDBRBuILk5rp0JaCUdgdXQFf.jpg'),
(162155, 11490, 'Ultimate Homem Aranha S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/483693.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zOmd8m5uwRqvEFXAvZVXCFsKYt8.jpg'),
(162156, 11490, 'Ultimate Homem Aranha S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/483694.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lbOO9MLHGO7O1iSE6ZEFYoGXFH8.jpg'),
(162157, 11491, 'Ultimate Homem Aranha S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/483695.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hUy6xNF3PPsOkuHJyDN8mvgA5rO.jpg'),
(162158, 11491, 'Ultimate Homem Aranha S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/483696.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2kK8krEKTjeV2Sm1zH5lBLLGR9C.jpg'),
(162159, 11491, 'Ultimate Homem Aranha S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/483697.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mctPovR20pbEiTbxiJBy0IhtgRu.jpg'),
(162160, 11491, 'Ultimate Homem Aranha S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/483698.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yuISM1cqwUCmiOJKUk4ruTYSisZ.jpg'),
(162161, 11491, 'Ultimate Homem Aranha S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/483699.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cEjjwsxxtSGYHT34PkqdR5NFhN4.jpg'),
(162162, 11491, 'Ultimate Homem Aranha S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/483700.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mFdN3QbTW9RB3dmxvperDb3NMps.jpg'),
(162163, 11491, 'Ultimate Homem Aranha S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/483701.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/meZSq73Z9FTqbVd80HJNEXFBy04.jpg'),
(162164, 11491, 'Ultimate Homem Aranha S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/483702.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4joY50YrInyII6vnm7sszPvod37.jpg'),
(162165, 11491, 'Ultimate Homem Aranha S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/483703.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5rJ32FE9wivjmTBgod4keJ3kgB4.jpg'),
(162166, 11491, 'Ultimate Homem Aranha S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/483704.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jIq6J0v7GEqZn2G2h8XxXJkvKAP.jpg'),
(162167, 11491, 'Ultimate Homem Aranha S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/483705.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3AKVMDd4RZqLqqMjvc6tAtKNZf.jpg'),
(162168, 11491, 'Ultimate Homem Aranha S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/483706.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lcn3V4dvIrhTtT5ebT72MqDb6u.jpg'),
(162169, 11491, 'Ultimate Homem Aranha S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/483707.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lYiDVSMkKBXSaXvACuciatV2sXq.jpg'),
(162170, 11491, 'Ultimate Homem Aranha S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/483708.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xTvYEe6Uy3f07P4Ig3L6YWjVWi0.jpg'),
(162171, 11491, 'Ultimate Homem Aranha S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/483709.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2ATwPlN1Uu1wRxhofUzS4LL1Qt0.jpg'),
(162172, 11491, 'Ultimate Homem Aranha S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/483710.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oLpaMydw2zQGGHA8bZA3LxMFVqi.jpg'),
(162173, 11491, 'Ultimate Homem Aranha S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/483711.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pCrE4HwoK93kdnudFKpiLWBa0Is.jpg'),
(162174, 11491, 'Ultimate Homem Aranha S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/483712.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dEUB4Dv43bZ96WYKtVdu2A1ZLZz.jpg'),
(162175, 11491, 'Ultimate Homem Aranha S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/483713.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1xyh9XKz1t0YYuDywSOeC4hoBDL.jpg'),
(162176, 11491, 'Ultimate Homem Aranha S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/483714.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mz5U2DGXmfmqoer9mikIsx8SGlp.jpg'),
(162177, 11491, 'Ultimate Homem Aranha S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/483715.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yEr3otUJyI8Qt7vwTi9GIJHjHEx.jpg'),
(162178, 11491, 'Ultimate Homem Aranha S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/483716.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fuyVMlX7cgg3lNEJTn93NqHYkW6.jpg'),
(162179, 11491, 'Ultimate Homem Aranha S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/483717.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zJHjvDe1W1D7sQEVmv3HlLDaMVC.jpg'),
(162180, 11491, 'Ultimate Homem Aranha S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/483718.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/stI7RPC4D9XzWiQUtfObhF8g4Ju.jpg'),
(162181, 11491, 'Ultimate Homem Aranha S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/483719.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/heshGR14SiVy3nQBa6UjD601VVU.jpg'),
(162182, 11491, 'Ultimate Homem Aranha S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/483720.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lKaUMuP82DXO29XoTpU5M7xjqrC.jpg'),
(162183, 11492, 'Ultimate Homem Aranha S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/483721.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/21qgOdgTlptegbc8EfijSNscdYT.jpg'),
(162184, 11492, 'Ultimate Homem Aranha S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/483722.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3GViJW1ymrwg4QJhsQfxZ03IIjk.jpg'),
(162185, 11492, 'Ultimate Homem Aranha S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/483723.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jU3CsjAxNuqgMVkwcULHEzLG3xp.jpg'),
(162186, 11492, 'Ultimate Homem Aranha S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/483724.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fkQMXJGjsxwuTQ3RmpZqbdEKPce.jpg'),
(162187, 11492, 'Ultimate Homem Aranha S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/483725.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hWVqeK2Xf4RpsySHpcEydB0MCcr.jpg'),
(162188, 11492, 'Ultimate Homem Aranha S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/483726.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t7hwVblWUAknvkdI2UsvMFEENDb.jpg'),
(162189, 11492, 'Ultimate Homem Aranha S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/483727.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mdIfqcGlGbJxkNkDGzvLECpojfJ.jpg'),
(162190, 11492, 'Ultimate Homem Aranha S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/483728.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lsUxB2xC17gdKFKl8K1IRxhdPtE.jpg'),
(162191, 11492, 'Ultimate Homem Aranha S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/483729.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/foTXlOTRXWZZg5fbYhrwzOehO3M.jpg'),
(162192, 11492, 'Ultimate Homem Aranha S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/483730.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jAMRRnWa8btLZKX9bTn7WUIsbZI.jpg'),
(162193, 11492, 'Ultimate Homem Aranha S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/483731.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1dyuzRKUZlyLAj6ZArBhUe9RrDS.jpg'),
(162194, 11492, 'Ultimate Homem Aranha S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/483732.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/axxiBhmu2cX9xLG2k9LyFZqREoI.jpg'),
(162195, 11492, 'Ultimate Homem Aranha S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/483733.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8o2B8gEibOeHOpHJ3UiSz7n64u5.jpg'),
(162196, 11492, 'Ultimate Homem Aranha S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/483734.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/shd5JiuT55nLJd1A8G7HIurreqx.jpg'),
(162197, 11492, 'Ultimate Homem Aranha S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/483735.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3sommNSZysCgYuZkmnVk1okYZA5.jpg'),
(162198, 11492, 'Ultimate Homem Aranha S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/483736.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mFxfHEPtRxZeSD2ViCIxilV4slU.jpg'),
(162199, 11492, 'Ultimate Homem Aranha S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/483737.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rKEPnJZKPQYcPOGFodAK5ThwNOz.jpg'),
(162200, 11492, 'Ultimate Homem Aranha S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/483738.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tNAYmMUx89GnvzuLWuWZJJ54fby.jpg'),
(162201, 11492, 'Ultimate Homem Aranha S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/483739.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nGP6XnQxuQ8oE6Vpc2GrS9m6poX.jpg'),
(162202, 11492, 'Ultimate Homem Aranha S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/483740.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nnmN42yGtG9O9jegsiJ82RJfVm8.jpg'),
(162203, 11492, 'Ultimate Homem Aranha S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/483741.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/86HUPBpdByLJ0k533Pl4QIHQULu.jpg'),
(162204, 11492, 'Ultimate Homem Aranha S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/483742.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dOwG1Rr3qsuFVXW1HyGDynu2c4g.jpg'),
(162205, 11492, 'Ultimate Homem Aranha S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/483743.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b8cLTzcMg4jECd1c9RWxtKt7Fuh.jpg'),
(162206, 11492, 'Ultimate Homem Aranha S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/483744.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4iJBLMgWjDI0MpMJfbK0AlXOWxK.jpg'),
(162207, 11492, 'Ultimate Homem Aranha S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/483745.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oQU809tF63VUr4kb6Yj9oaxajTR.jpg'),
(162208, 11492, 'Ultimate Homem Aranha S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/483746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aoZxQsP5qbWYM5ziXDK5bNpuhyi.jpg'),
(162209, 11493, 'Ultimate Homem Aranha S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/483747.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dNjtaMsZ2W48649tlXisMfcwJGU.jpg'),
(162210, 11493, 'Ultimate Homem Aranha S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/483748.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tzzlH7usdyY2fKKpDxrRyCaKllt.jpg'),
(162211, 11493, 'Ultimate Homem Aranha S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/483749.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y2zRxszZ8VXlSDtV6LIiVXXZbp1.jpg'),
(162212, 11493, 'Ultimate Homem Aranha S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/483750.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/25oavHBBiKRuSzgw6yTaO06IHbF.jpg'),
(162213, 11493, 'Ultimate Homem Aranha S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/483751.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kit6akgu6UhMZxxWChQZr3SLaN9.jpg'),
(162214, 11493, 'Ultimate Homem Aranha S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/483752.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wqNoWYFBZA7z8stoY1QHRpjnmdX.jpg'),
(162215, 11493, 'Ultimate Homem Aranha S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/483753.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rBSgRy2guBe7Ot7om28JNkfxYFt.jpg'),
(162216, 11493, 'Ultimate Homem Aranha S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/483754.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/afliOT6pEH7UPefGZkuBDz09h9x.jpg'),
(162217, 11493, 'Ultimate Homem Aranha S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/483755.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qG1VFIATzR2xRRLkql6WeaLdtrX.jpg'),
(162218, 11493, 'Ultimate Homem Aranha S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/483756.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h0VAj1VcOtdvXHCQa96srFAZYWT.jpg'),
(162219, 11493, 'Ultimate Homem Aranha S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/483757.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4gfhYDqtvWpaoWmMrJQb3bcMr5T.jpg'),
(162220, 11493, 'Ultimate Homem Aranha S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/483758.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qChfHYk2VJZtYFbEMGZdoiyx7lB.jpg'),
(162221, 11493, 'Ultimate Homem Aranha S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/483759.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x8eF5gvrJczCS2cyudz6CX23ze8.jpg'),
(162222, 11493, 'Ultimate Homem Aranha S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/483760.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7lWxVEGvY71pG6GASo3CRq0Eraj.jpg'),
(162223, 11493, 'Ultimate Homem Aranha S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/483761.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yRYBdHaFCc4YecvVuG9JOX39sat.jpg'),
(162224, 11493, 'Ultimate Homem Aranha S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/483762.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5A865SdWTyCMXHWCtT7JMkt8YhY.jpg'),
(162225, 11493, 'Ultimate Homem Aranha S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/483763.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eXpJQvjEJuVd5xkqk8HueG8sWuw.jpg'),
(162226, 11493, 'Ultimate Homem Aranha S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/483764.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mG9DS8dCTXFVK06HwNXQS7FudIe.jpg'),
(162227, 11493, 'Ultimate Homem Aranha S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/483765.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVaBaZTiUpyZcQ7cSN8HneGdXN.jpg'),
(162228, 11493, 'Ultimate Homem Aranha S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/483766.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hwTeXyGdA7t9nr0bEGg7dtfJ5eg.jpg'),
(162229, 11493, 'Ultimate Homem Aranha S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/483767.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qwDJvy7Gw6t7ZyYzl6kX7p0zmXL.jpg'),
(162230, 11493, 'Ultimate Homem Aranha S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/483768.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rWC5LNtBVhg1lE7GkW9C3ivfJu1.jpg'),
(162231, 11493, 'Ultimate Homem Aranha S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/483769.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iOV1p7DBZ2wdbFvK2iRcdTDSV2p.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(162232, 11493, 'Ultimate Homem Aranha S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/483770.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/14VisMv1796qYBW2IY3tB7wdqEs.jpg'),
(162233, 11493, 'Ultimate Homem Aranha S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/483771.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/id94nsnzwOYXG35pu9H9ib9tDgd.jpg'),
(162234, 11493, 'Ultimate Homem Aranha S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/483772.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ph8BSYQ6Ul2By7DHn439s1v6xPY.jpg'),
(162235, 11494, 'Go Go Loser Ranger S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/483657.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7FArKOV46JCPM8n0dEhw0rCpBZv.jpg'),
(162236, 11494, 'Go Go Loser Ranger S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/483658.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kzqSckBeNnXEe7jIuSNz3QJkfhz.jpg'),
(162237, 11494, 'Go Go Loser Ranger S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/483659.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dgRtIa6A3bNYQGVMNq8ghhg8qAy.jpg'),
(162238, 11494, 'Go Go Loser Ranger S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/483660.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tkMQ26fktWEbMH7vSTAlx0XICKO.jpg'),
(162239, 11494, 'Go Go Loser Ranger S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/483661.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Tv5EDgO1rWhusTpGse9A7V5B8b.jpg'),
(162240, 11494, 'Go Go Loser Ranger S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/483662.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n2IXRTYmY37obhMCxLotFHV2ci8.jpg'),
(162241, 11494, 'Go Go Loser Ranger S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/483663.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qLZMnkv4S4QRSPK0O9adVSrXUzr.jpg'),
(162242, 11494, 'Go Go Loser Ranger S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/483664.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sNr4ffnufET3VoYWCe2Hz112gry.jpg'),
(162243, 11494, 'Go Go Loser Ranger S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/483665.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tYoBGkk7g2Q2OOgfKBuzl1rvC7r.jpg'),
(162244, 11494, 'Go Go Loser Ranger S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/483666.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wCPtM7AuhvQzf725yHnPsCvmlv4.jpg'),
(162245, 11494, 'Go Go Loser Ranger S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/483667.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kDT2F5dTEVntYV7JsV6vrm2jvYZ.jpg'),
(162246, 11494, 'Go Go Loser Ranger S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/483668.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rBWP8KjJ7UVpitc2vR1HNho5ISD.jpg'),
(162247, 11495, 'A Disputa dos Confeiteiros Halloween S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162248, 11495, 'A Disputa dos Confeiteiros Halloween S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162249, 11495, 'A Disputa dos Confeiteiros Halloween S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162250, 11495, 'A Disputa dos Confeiteiros Halloween S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162251, 11496, 'A Disputa dos Confeiteiros Halloween S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162252, 11496, 'A Disputa dos Confeiteiros Halloween S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162253, 11496, 'A Disputa dos Confeiteiros Halloween S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162254, 11496, 'A Disputa dos Confeiteiros Halloween S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162255, 11496, 'A Disputa dos Confeiteiros Halloween S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162256, 11497, 'A Disputa dos Confeiteiros Halloween S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162257, 11497, 'A Disputa dos Confeiteiros Halloween S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162258, 11497, 'A Disputa dos Confeiteiros Halloween S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162259, 11497, 'A Disputa dos Confeiteiros Halloween S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162260, 11497, 'A Disputa dos Confeiteiros Halloween S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162261, 11497, 'A Disputa dos Confeiteiros Halloween S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162262, 11498, 'A Disputa dos Confeiteiros Halloween S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162263, 11498, 'A Disputa dos Confeiteiros Halloween S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162264, 11498, 'A Disputa dos Confeiteiros Halloween S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162265, 11498, 'A Disputa dos Confeiteiros Halloween S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162266, 11498, 'A Disputa dos Confeiteiros Halloween S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162267, 11498, 'A Disputa dos Confeiteiros Halloween S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162268, 11499, 'A Disputa dos Confeiteiros Halloween S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479723.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lxHoC7Kkt9Yf14LERBSfFAtiHhC.jpg'),
(162269, 11499, 'A Disputa dos Confeiteiros Halloween S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162270, 11499, 'A Disputa dos Confeiteiros Halloween S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162271, 11499, 'A Disputa dos Confeiteiros Halloween S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162272, 11499, 'A Disputa dos Confeiteiros Halloween S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162273, 11499, 'A Disputa dos Confeiteiros Halloween S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162274, 11500, 'A Disputa dos Confeiteiros Halloween S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479729.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iksnFmZsZsuc3HDDnQwQmud9tnF.jpg'),
(162275, 11500, 'A Disputa dos Confeiteiros Halloween S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479730.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8JWplHFtUdMFSBpmIrgSNOrKbXs.jpg'),
(162276, 11500, 'A Disputa dos Confeiteiros Halloween S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479731.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n7vvqT1rfEIOwNb9ALZJILvEomz.jpg'),
(162277, 11500, 'A Disputa dos Confeiteiros Halloween S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479732.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iwLY41102nzMWUpb2LLVv2XLyQ9.jpg'),
(162278, 11500, 'A Disputa dos Confeiteiros Halloween S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479733.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tuFa5ubxRT2QXoreh5miXEgwaav.jpg'),
(162279, 11501, 'A Disputa dos Confeiteiros Halloween S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162280, 11501, 'A Disputa dos Confeiteiros Halloween S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162281, 11501, 'A Disputa dos Confeiteiros Halloween S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162282, 11501, 'A Disputa dos Confeiteiros Halloween S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162283, 11501, 'A Disputa dos Confeiteiros Halloween S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162284, 11501, 'A Disputa dos Confeiteiros Halloween S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162285, 11501, 'A Disputa dos Confeiteiros Halloween S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/479740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162286, 11502, 'A Disputa dos Confeiteiros Halloween S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479741.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4cPI7ITHpFruZVvUzJMmVMxqWxl.jpg'),
(162287, 11502, 'A Disputa dos Confeiteiros Halloween S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479742.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3kzO7QRF3ZGtpAp8FXUOOglY7MC.jpg'),
(162288, 11502, 'A Disputa dos Confeiteiros Halloween S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/494008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162289, 11502, 'A Disputa dos Confeiteiros Halloween S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/497260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162290, 11502, 'A Disputa dos Confeiteiros Halloween S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/503436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162291, 11502, 'A Disputa dos Confeiteiros Halloween S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162292, 11502, 'A Disputa dos Confeiteiros Halloween S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/510356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1QXS7jYaEcOTWETXOAtiup8r1Zx.jpg'),
(162293, 11503, 'Armadilha do Amor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479666.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A40Ze1MqZnCeGf6bNABzJ01fwmj.jpg'),
(162294, 11503, 'Armadilha do Amor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479667.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7dtHgQpOQb0aokyXjpR0iuBAEIx.jpg'),
(162295, 11503, 'Armadilha do Amor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479668.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bZ4zXggYAZVS2o9wLmIm1RW5wuw.jpg'),
(162296, 11503, 'Armadilha do Amor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479669.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5sZ1ExiHKdlr6EFsFtdndPdRvET.jpg'),
(162297, 11503, 'Armadilha do Amor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479670.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tmMXUGV6BmBFTA6VM8YWaFp19g4.jpg'),
(162298, 11503, 'Armadilha do Amor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479671.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ieKT3xr8juHGHTnWrjG1OLIR2ol.jpg'),
(162299, 11503, 'Armadilha do Amor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/479672.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pUxV4AckwaOqj8W1ap3YnFLNIi1.jpg'),
(162300, 11503, 'Armadilha do Amor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/479673.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9lxTWp9Y3EaDaLtLHYEEQ9rhzqc.jpg'),
(162301, 11503, 'Armadilha do Amor S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/479674.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5OT44RERmSDshksU2csjNzA6yYX.jpg'),
(162302, 11503, 'Armadilha do Amor S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/479675.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fHHz49YFLwn5vAp3TGfsuZO7VFK.jpg'),
(162303, 11503, 'Armadilha do Amor S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/479676.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6uNfBZPqiyp6gomgLoowRtMrKsI.jpg'),
(162304, 11503, 'Armadilha do Amor S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/479677.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fMNmH152oPAKaZLfXwfj65h0gfJ.jpg'),
(162305, 11503, 'Armadilha do Amor S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/479678.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y8l1YRKmOVdtk4IKKytHBC6cnod.jpg'),
(162306, 11503, 'Armadilha do Amor S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/479679.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dQvmkAILGy5i270JojP1eZpQi4r.jpg'),
(162307, 11503, 'Armadilha do Amor S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/479680.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qxUlueHeA4mbZSpKsdRaZHzwbKv.jpg'),
(162308, 11503, 'Armadilha do Amor S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/479681.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mkE8J7WGekMXGQs2V8c88v0mbs.jpg'),
(162309, 11503, 'Armadilha do Amor S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/479682.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tL7GaphSL3Dqa4ikrJGuimaRiga.jpg'),
(162310, 11503, 'Armadilha do Amor S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/479683.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tsBFPCWAZMqkmk5Ll4jIx1CEY1c.jpg'),
(162311, 11503, 'Armadilha do Amor S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/479684.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6Z1MfBLSJVIr35uVZuWMc4GrOyk.jpg'),
(162312, 11503, 'Armadilha do Amor S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/479685.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ywkxUPxN2vx88bkQUHuswZEdqSn.jpg'),
(162313, 11503, 'Armadilha do Amor S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/479686.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jrjUghpygRcNnGE9i8fRjtNbexO.jpg'),
(162314, 11503, 'Armadilha do Amor S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/479687.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w5ehsSA6l6a4OUm4SCMpek1o1K4.jpg'),
(162315, 11503, 'Armadilha do Amor S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/479688.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6tfJJibkGrDpWRl4r8psHeS3GBB.jpg'),
(162316, 11503, 'Armadilha do Amor S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/479689.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mU8mKEUqPnJwsHFib5w7mUf1uEO.jpg'),
(162317, 11503, 'Armadilha do Amor S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/479690.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dIUe4sNjVHWBG26XXxuJAZ5ksWI.jpg'),
(162318, 11503, 'Armadilha do Amor S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/479691.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uToD0drcEiillryURq9iWb7GwAN.jpg'),
(162319, 11503, 'Armadilha do Amor S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/479692.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c71gidRzsGO8YK0SCmCUMVMFBdR.jpg'),
(162320, 11503, 'Armadilha do Amor S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/479693.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zBFmP6J7YD5JcARhd2KEsx6cThi.jpg'),
(162321, 11503, 'Armadilha do Amor S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/479694.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yi0mvV5cVKYHp4VBmk14L3SJEe2.jpg'),
(162322, 11503, 'Armadilha do Amor S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/479695.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vrp8sGa2aZJqIQeg3QdZPNpb3n.jpg'),
(162323, 11503, 'Armadilha do Amor S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/479696.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t7sJhoQRYy757kPeZYo98CaZXIC.jpg'),
(162324, 11503, 'Armadilha do Amor S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/479697.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vVXPiWpmRh6k5UkysoG4D4pNXYR.jpg'),
(162325, 11503, 'Armadilha do Amor S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/479698.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5csIaRUWdSTfmNahjcwdmi3qPog.jpg'),
(162326, 11503, 'Armadilha do Amor S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/479699.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oS5v3c7UVwwYkA1zWUNnBWlImlY.jpg'),
(162327, 11503, 'Armadilha do Amor S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/479700.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dmW9cKZrw2PNlC2K2ls6CLtCRob.jpg'),
(162328, 11503, 'Armadilha do Amor S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/479701.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pHW8UM1LAI4bgcaf1KLW2dAUer4.jpg'),
(162329, 11503, 'Armadilha do Amor S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/485901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3mmQtKizYKbQCIWq1K76HV1Iort.jpg'),
(162330, 11503, 'Armadilha do Amor S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/485902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3mmQtKizYKbQCIWq1K76HV1Iort.jpg'),
(162331, 11503, 'Armadilha do Amor S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/485903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3mmQtKizYKbQCIWq1K76HV1Iort.jpg'),
(162332, 11503, 'Armadilha do Amor S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/485904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3mmQtKizYKbQCIWq1K76HV1Iort.jpg'),
(162333, 11503, 'Armadilha do Amor S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/485905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3mmQtKizYKbQCIWq1K76HV1Iort.jpg'),
(162334, 11503, 'Armadilha do Amor S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/485906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3mmQtKizYKbQCIWq1K76HV1Iort.jpg'),
(162335, 11503, 'Armadilha do Amor S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/491699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3mmQtKizYKbQCIWq1K76HV1Iort.jpg'),
(162336, 11503, 'Armadilha do Amor S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/491700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3mmQtKizYKbQCIWq1K76HV1Iort.jpg'),
(162337, 11503, 'Armadilha do Amor S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/491701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3mmQtKizYKbQCIWq1K76HV1Iort.jpg'),
(162338, 11504, 'Beyblade X S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479640.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oBnjkhoyfrWruTVfW55qIMtmqpF.jpg'),
(162339, 11504, 'Beyblade X S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479641.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4V7PdAZprFojH9btYEfvBw60iPf.jpg'),
(162340, 11504, 'Beyblade X S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479642.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vl6kSgXP6lU1vq6ouQxmd7uGIQb.jpg'),
(162341, 11504, 'Beyblade X S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479643.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yXTip0t1CSNJ94dyIKITmgkfqBh.jpg'),
(162342, 11504, 'Beyblade X S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479644.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eJAAK73ANjboO5mePx4lA4EttRC.jpg'),
(162343, 11504, 'Beyblade X S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479645.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wAe5Y3LF4mMuJf3R4QFQl8jreQj.jpg'),
(162344, 11504, 'Beyblade X S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/479646.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4TRQMNBeiCeCM8pPcFmr4aMLEkW.jpg'),
(162345, 11504, 'Beyblade X S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/479647.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/anNP7rRfNgZphT9hkXp0n2KD8S5.jpg'),
(162346, 11504, 'Beyblade X S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/479648.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3PrboRtqhxyGHxzqiX1ik7kORq0.jpg'),
(162347, 11504, 'Beyblade X S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/479649.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4qbrb27dnjtbdjNkOb90W6JgYjU.jpg'),
(162348, 11504, 'Beyblade X S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/479650.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4lGnkOxOoLGT2PTbL350l8ffmqe.jpg'),
(162349, 11504, 'Beyblade X S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/479651.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tjQPH6eu6LaF1QrlUHERpWoXuNJ.jpg'),
(162350, 11504, 'Beyblade X S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/479652.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lAELl54FtC7QxgccheGSS2ksKWd.jpg'),
(162351, 11504, 'Beyblade X S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/479653.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lwbqMIKrlkwivqr90vUIWPSjUkr.jpg'),
(162352, 11504, 'Beyblade X S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/479654.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/95IdikWuhdnaQJwglmylDfzGtn7.jpg'),
(162353, 11504, 'Beyblade X S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/479655.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kfIARVYK51DTx1UcMVSLUJRwS4M.jpg'),
(162354, 11504, 'Beyblade X S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/479656.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4HkckN35TQJ6LIbUCn15rtQmUUh.jpg'),
(162355, 11504, 'Beyblade X S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/479657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66wkm14IWdrY5LaKZDAbkD2T9Jt.jpg'),
(162356, 11504, 'Beyblade X S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/479658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/66wkm14IWdrY5LaKZDAbkD2T9Jt.jpg'),
(162357, 11504, 'Beyblade X S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/479659.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aEjzSrJ4HQjRMfSh8YSUBxNRkZy.jpg'),
(162358, 11504, 'Beyblade X S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/479660.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1qI32WaP4saBLR84Y1efju4fOyc.jpg'),
(162359, 11504, 'Beyblade X S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/479661.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qBdwxVSbHjmiyDQhFbImTAq0GaS.jpg'),
(162360, 11504, 'Beyblade X S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/479662.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j8YbVr0Llmi3X1EXrjEOKA34EJd.jpg'),
(162361, 11504, 'Beyblade X S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/479663.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6vHDBsbF4Eit1MPWWvs3AN4zAor.jpg'),
(162362, 11504, 'Beyblade X S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/479664.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tBiMUwtSRpys6Y2rW4XxK0BV4mp.jpg'),
(162363, 11504, 'Beyblade X S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/479665.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/roVn4aTl9FdsUGlCGl8L54YV6V2.jpg'),
(162364, 11505, 'Chefs Table S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479610.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4nE322DkEAEaCxDbl6klwCJ5HPp.jpg'),
(162365, 11505, 'Chefs Table S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479611.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uEnJbKgMiYWrek6KyPeCcfIOgdS.jpg'),
(162366, 11505, 'Chefs Table S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479612.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xLirzQ7bo1jerltTSU3MaPnVbY3.jpg'),
(162367, 11505, 'Chefs Table S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479613.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8YQq7jc5wYqr3gkGkyUPJJdNVVK.jpg'),
(162368, 11505, 'Chefs Table S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479614.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xIyy7ntDLwjFQoeGwjBVoTysOlz.jpg'),
(162369, 11505, 'Chefs Table S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479615.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/emK3lvyNb48ktlXHoe7Ew5tlt2Y.jpg'),
(162370, 11506, 'Chefs Table S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479616.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fnEsnNxbSBEPzvX4GIGWelKxiEv.jpg'),
(162371, 11506, 'Chefs Table S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479617.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fnkIBiPRx8TgiKTh4IHATXr2Co9.jpg'),
(162372, 11506, 'Chefs Table S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479618.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8UNdCziVuc3NiSqelpz5T7Uyr7Y.jpg'),
(162373, 11506, 'Chefs Table S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479619.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6AqmSr7Zsw23Yr9B3o0aFySE8iN.jpg'),
(162374, 11506, 'Chefs Table S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479620.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ygrpH3O3rr0XZhaUL5WvDW9RBfQ.jpg'),
(162375, 11506, 'Chefs Table S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479621.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nF8JN8AJqkSyR1R4ca4NDJusbV6.jpg'),
(162376, 11507, 'Chefs Table S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479622.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j3zwSQfFazkO1JnFAAU26t3FQEO.jpg'),
(162377, 11507, 'Chefs Table S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479623.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mh8KIYRRmUuFB4lFmUr8EfN5XzS.jpg'),
(162378, 11507, 'Chefs Table S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479624.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8f2ysvChv5pknNb7mv8pQW65gl2.jpg'),
(162379, 11507, 'Chefs Table S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479625.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8Zf1sGylWahc0kL5FwxR85waGw7.jpg'),
(162380, 11507, 'Chefs Table S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479626.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kNiqmj7HUhimhaYNxk4cKgicJxi.jpg'),
(162381, 11507, 'Chefs Table S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479627.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uXljVcdyfJNg7ehdeqf1PpcYzoU.jpg'),
(162382, 11508, 'Chefs Table S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479628.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hKr4abM2C8WqtRfmf2fCZmrXIe2.jpg'),
(162383, 11508, 'Chefs Table S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479629.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rpfgN0NA9CVM4akyOK6p6qTWqGy.jpg'),
(162384, 11508, 'Chefs Table S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479630.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/izc50IuZGv5vDg2UUW17uLc62vr.jpg'),
(162385, 11508, 'Chefs Table S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479631.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oj4gXXxAhk88fyt3Oqd346be5Sw.jpg'),
(162386, 11509, 'Chefs Table S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479632.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uqLhnDY0x7uI7KbDoLtGc3dwyYP.jpg'),
(162387, 11509, 'Chefs Table S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479633.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8E0c8b2fNDfipnEdyVSW1m1vVyA.jpg'),
(162388, 11509, 'Chefs Table S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479634.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6zrFfm1j1DrgjXYgUjXCRfyjvAG.jpg'),
(162389, 11509, 'Chefs Table S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479635.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h0lkDgO0IWC4ktD5H2yYrgNsLuP.jpg'),
(162390, 11510, 'Chefs Table S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479636.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1saW6bVAN26HJM7ErmPhGbrzd1q.jpg'),
(162391, 11510, 'Chefs Table S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479637.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4IsCj6m1XwYiHmkRjDMjnVYRFUl.jpg'),
(162392, 11510, 'Chefs Table S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479638.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kaPGrU3JTChIzEEsitHYFE5TTBe.jpg'),
(162393, 11510, 'Chefs Table S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479639.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n91gPYcAu85PeO6kdXRS2gYqgKx.jpg'),
(162394, 11511, 'DAN DA DAN S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479607.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bmVsa3oLgAd26YNJOPjJ4QgWY08.jpg'),
(162395, 11511, 'DAN DA DAN S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479608.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aIgNMI3bAR1yauVFlozRzsRdmxj.jpg'),
(162396, 11511, 'DAN DA DAN S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479609.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mM7WAhNZyXO0axLZ0FGhNIwY5Xv.jpg'),
(162397, 11511, 'DAN DA DAN S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/492879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtQug1eOyeU2VXIpNoDF1lTlcH4.jpg'),
(162398, 11511, 'DAN DA DAN S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/492880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtQug1eOyeU2VXIpNoDF1lTlcH4.jpg'),
(162399, 11511, 'DAN DA DAN S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/499173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtQug1eOyeU2VXIpNoDF1lTlcH4.jpg'),
(162400, 11511, 'DAN DA DAN S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/506255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtQug1eOyeU2VXIpNoDF1lTlcH4.jpg'),
(162401, 11511, 'DAN DA DAN S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/509123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtQug1eOyeU2VXIpNoDF1lTlcH4.jpg'),
(162402, 11511, 'DAN DA DAN S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/515688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtQug1eOyeU2VXIpNoDF1lTlcH4.jpg'),
(162403, 11511, 'DAN DA DAN S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/518717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtQug1eOyeU2VXIpNoDF1lTlcH4.jpg'),
(162404, 11511, 'DAN DA DAN S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/523538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtQug1eOyeU2VXIpNoDF1lTlcH4.jpg'),
(162405, 11511, 'DAN DA DAN S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/639304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtQug1eOyeU2VXIpNoDF1lTlcH4.jpg'),
(162406, 11512, 'DAN DA DAN S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/856458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtQug1eOyeU2VXIpNoDF1lTlcH4.jpg'),
(162407, 11512, 'DAN DA DAN S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/865758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtQug1eOyeU2VXIpNoDF1lTlcH4.jpg'),
(162408, 11512, 'DAN DA DAN S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/870882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtQug1eOyeU2VXIpNoDF1lTlcH4.jpg'),
(162409, 11512, 'DAN DA DAN S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/878382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtQug1eOyeU2VXIpNoDF1lTlcH4.jpg'),
(162410, 11512, 'DAN DA DAN S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/879428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtQug1eOyeU2VXIpNoDF1lTlcH4.jpg'),
(162411, 11512, 'DAN DA DAN S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/879893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtQug1eOyeU2VXIpNoDF1lTlcH4.jpg'),
(162412, 11512, 'DAN DA DAN S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/880595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtQug1eOyeU2VXIpNoDF1lTlcH4.jpg'),
(162413, 11512, 'DAN DA DAN S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/881237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtQug1eOyeU2VXIpNoDF1lTlcH4.jpg'),
(162414, 11512, 'DAN DA DAN S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/881346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtQug1eOyeU2VXIpNoDF1lTlcH4.jpg'),
(162415, 11512, 'DAN DA DAN S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/883032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtQug1eOyeU2VXIpNoDF1lTlcH4.jpg'),
(162416, 11512, 'DAN DA DAN S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/883827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtQug1eOyeU2VXIpNoDF1lTlcH4.jpg'),
(162417, 11512, 'DAN DA DAN S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/885332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vtQug1eOyeU2VXIpNoDF1lTlcH4.jpg'),
(162418, 11513, 'Destino Paranormal Top 10 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479599.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/chjaKr3h74snKW91LFWiZWbzWVk.jpg'),
(162419, 11513, 'Destino Paranormal Top 10 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479600.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fle5hAiqvxxrWx9lBv3dZuFHhbg.jpg'),
(162420, 11513, 'Destino Paranormal Top 10 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479601.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1PCg5svEM8kpW58LeEpNxfoFgy.jpg'),
(162421, 11513, 'Destino Paranormal Top 10 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479602.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ewlLDkgUzRDumyLDnXpJh79UNIW.jpg'),
(162422, 11513, 'Destino Paranormal Top 10 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479603.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eYGg658MtFUQCpQAZfp5RcPnPkA.jpg'),
(162423, 11513, 'Destino Paranormal Top 10 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479604.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yLpv3sednOQhc2nOvYUxCBmxPq9.jpg'),
(162424, 11513, 'Destino Paranormal Top 10 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/479605.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7hm4qyAPRe3AxpEmp8b3HntMKmC.jpg'),
(162425, 11513, 'Destino Paranormal Top 10 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/479606.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zY1ziQaU5CdWBrY8e2w6fv0i2Qr.jpg'),
(162426, 11514, 'Deu a Louca no Tempo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2he15LYjVLnFyMsC5GlRYklr53.jpg'),
(162427, 11514, 'Deu a Louca no Tempo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2he15LYjVLnFyMsC5GlRYklr53.jpg'),
(162428, 11514, 'Deu a Louca no Tempo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2he15LYjVLnFyMsC5GlRYklr53.jpg'),
(162429, 11514, 'Deu a Louca no Tempo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2he15LYjVLnFyMsC5GlRYklr53.jpg'),
(162430, 11514, 'Deu a Louca no Tempo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q2he15LYjVLnFyMsC5GlRYklr53.jpg'),
(162431, 11515, 'Divina Christina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mqhofjtAPccsNajxFR4CeRNx8TP.jpg'),
(162432, 11515, 'Divina Christina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mqhofjtAPccsNajxFR4CeRNx8TP.jpg'),
(162433, 11515, 'Divina Christina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mqhofjtAPccsNajxFR4CeRNx8TP.jpg'),
(162434, 11515, 'Divina Christina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mqhofjtAPccsNajxFR4CeRNx8TP.jpg'),
(162435, 11516, 'FLCL S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479566.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5RGOThoZphTkL1l4BMismezLbl5.jpg'),
(162436, 11516, 'FLCL S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479567.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fNl5RMhBJ4GwPxFXhYLcs4Uw38N.jpg'),
(162437, 11516, 'FLCL S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479568.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rGOJnEWqTEXFlBPjY8ORG7pUKxz.jpg'),
(162438, 11516, 'FLCL S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479569.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bwWtZtWcLj6Jq0aT0IREtplcWiG.jpg'),
(162439, 11516, 'FLCL S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479570.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zipcQSvhlWAV1GJMnClw2evSFwc.jpg'),
(162440, 11516, 'FLCL S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479571.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lOd6LN1t59K7kZp9FzcLFJzn3QW.jpg'),
(162441, 11517, 'FLCL S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479572.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3v8S5iN0U9i59ccjqwYyMl4BGE1.jpg'),
(162442, 11517, 'FLCL S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479573.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/brkoSAbQeiXxFFaxXV5h0MSgyLB.jpg'),
(162443, 11517, 'FLCL S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479574.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pNyyHPtl606vGLVeMUXP7tV2d12.jpg'),
(162444, 11517, 'FLCL S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479575.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9Om4EzlvTS2Iz1n8rBd7VnjVWXy.jpg'),
(162445, 11517, 'FLCL S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479576.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aHzFVAPcNzRibYaQkQz7mFaFPdD.jpg'),
(162446, 11517, 'FLCL S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479577.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lehLy6mZXEusFeW61LDiyKIw7gq.jpg'),
(162447, 11518, 'FLCL S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479578.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xLPInWwrCr4jMY39nnv5DJAhrjD.jpg'),
(162448, 11518, 'FLCL S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479579.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zHAC9lECvZyxnsFPuLDGPmz5EHj.jpg'),
(162449, 11518, 'FLCL S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479580.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q4jpT12sLZ2KiZ6tjRoO6rlCDFy.jpg'),
(162450, 11518, 'FLCL S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479581.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wEjSxIf1XAIpK0PFxDHirtRMKdv.jpg'),
(162451, 11518, 'FLCL S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479582.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lGDLjtlaVzczfJCWGLWnuLLhQYA.jpg'),
(162452, 11518, 'FLCL S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479583.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gpZBNUuJPmwL5EuMfQtFP0DlpeU.jpg'),
(162453, 11519, 'FLCL S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479584.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9ofjUkBdpyOT7yCypJVnKTPbFE9.jpg'),
(162454, 11519, 'FLCL S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479585.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vRW1DPvLczBPGTRCp9mSGdAqGJz.jpg'),
(162455, 11519, 'FLCL S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479586.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qYxc9IQKY9oAOZl8qVqRf60CH8u.jpg'),
(162456, 11520, 'FLCL S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479587.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9D2dyxQL492DtSOm6OWh8Bhvxzy.jpg'),
(162457, 11520, 'FLCL S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479588.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uuXkB3w0YGbctCqx2NRScwNOjLV.jpg'),
(162458, 11520, 'FLCL S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479589.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cZcm18p1soO9C38qGidfGvAqsJF.jpg'),
(162459, 11521, 'Mobile Suit Gundam Requiem for Vengeance S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479560.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aYNwvuxg2UIELLb5F94Rba1qHKU.jpg'),
(162460, 11521, 'Mobile Suit Gundam Requiem for Vengeance S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479561.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ktH7XOE4lhkzwMgLMEsre7KGAqn.jpg'),
(162461, 11521, 'Mobile Suit Gundam Requiem for Vengeance S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479562.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3CVsAj6aMILIhum04X95jrlHVl9.jpg'),
(162462, 11521, 'Mobile Suit Gundam Requiem for Vengeance S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479563.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w8oQFHCZT7me3SuFuZCOAEkT9FP.jpg'),
(162463, 11521, 'Mobile Suit Gundam Requiem for Vengeance S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479564.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5BygVsVf8TiuY9fuIfk6sCD6vT6.jpg'),
(162464, 11521, 'Mobile Suit Gundam Requiem for Vengeance S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479565.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eqi4PM3Svznz7WJpYo2WjO1BsVT.jpg'),
(162465, 11522, 'O Rei da Pesca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479550.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xWMqsTAhgIE1ARi2AAlUdgjbXaG.jpg'),
(162466, 11522, 'O Rei da Pesca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479551.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vsbxnBL9Nw9sO7tMQMMg1C0OZnJ.jpg'),
(162467, 11522, 'O Rei da Pesca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479552.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q6h9OYimfZFgf415DZ6TMbJBYjT.jpg'),
(162468, 11522, 'O Rei da Pesca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479553.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jTzbyteVThMCJc9qo9urGhJZvL1.jpg'),
(162469, 11522, 'O Rei da Pesca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479554.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pPiXUAabCEMdaeJEwt2sCTt4LDk.jpg'),
(162470, 11522, 'O Rei da Pesca S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479555.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jXKKCAdAqo9NsAzhCQnpIQlso71.jpg'),
(162471, 11522, 'O Rei da Pesca S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/479556.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sFwzAkJKV8fuqNh9HvEGWQC5hIx.jpg'),
(162472, 11522, 'O Rei da Pesca S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/479557.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3k1ZtDVuemUakQmh5S5eEwEzWhw.jpg'),
(162473, 11522, 'O Rei da Pesca S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/479558.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nQubhf9EBxRfxHvhyDOnKdHppU8.jpg'),
(162474, 11522, 'O Rei da Pesca S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/479559.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9yBuS8hEhwTxnABU8lflbM9fn40.jpg'),
(162475, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479524.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uLSaNPZIUf78wC2WIuI4kLfrgnv.jpg'),
(162476, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479525.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uILd7T0UPTjmdPIWVym411wAZSh.jpg'),
(162477, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479526.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uDHJJn3myEpEkUMDI0WR06mUUmO.jpg'),
(162478, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479527.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lrnFeE0wxR4W7qHBHLYRwMMDMp6.jpg'),
(162479, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479528.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/BSOdCzMEKvnEmeB9bOogVnkUnp.jpg'),
(162480, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479529.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xqbuiTj3fwMrK6nDXA1kcx6XjnN.jpg'),
(162481, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/479530.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jGcHvE2owr3zK2D2m0bNpJFFG30.jpg'),
(162482, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/479531.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/urXbyJjg8gtVmDgwJCcIAym5m9L.jpg'),
(162483, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/479532.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AeLxZ2ACMZBPLGqgQDt19193ZiK.jpg'),
(162484, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/479533.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l45dGcgB5Xo8AZrFRjoz5p8FxZ0.jpg'),
(162485, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/479534.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nd7OUVNItefqklspcM4s5iFL3zK.jpg'),
(162486, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/479535.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l9YfTb0nk9gn7FrsdyKaO5w2v4.jpg'),
(162487, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/479536.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4y2LQM5EifqlrhPUXLH2tkRIiJd.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(162488, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/479537.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nPEp1zDKwKNN4au0v8GQYA4mcsr.jpg'),
(162489, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/479538.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k9pkX2u9L85iRSjoeQmv2GBpmK2.jpg'),
(162490, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/479539.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mUbvxGpAosh9PmUbwoluY5RAtQ1.jpg'),
(162491, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/479540.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/21bhTtfijXFqd4k9xmmeROVUUjR.jpg'),
(162492, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/479541.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6mdF9lOrGE6NajPBOmlIooydjqI.jpg'),
(162493, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/479542.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uvYnJaUOi0SlRYxI0VLCP0rlMzm.jpg'),
(162494, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/479543.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tkvPZZAxIMgI8OuiWVStO5PBs9d.jpg'),
(162495, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/479544.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9iyyMh8lN2CpIPNmu3MmPw1qPg3.jpg'),
(162496, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/479545.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mueNV6Fz1dxpyYsmh7TJcWga2Mf.jpg'),
(162497, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/479546.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d01M7a8MayuIdgAbxRXSus4R8gm.jpg'),
(162498, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/479547.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i8JJAodjlhHTa5ikDkSNustVkSV.jpg'),
(162499, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/479548.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l0s4FcLUC7zLRIObzOv4GolGjtU.jpg'),
(162500, 11523, 'Pac Man e as Aventuras Fantasmagoricas S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/479549.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1QpPXJs0SZBchFmmy34QIq1VlJz.jpg'),
(162501, 11524, 'Patrulha Salvadora S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162502, 11524, 'Patrulha Salvadora S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162503, 11524, 'Patrulha Salvadora S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162504, 11524, 'Patrulha Salvadora S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162505, 11524, 'Patrulha Salvadora S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162506, 11524, 'Patrulha Salvadora S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162507, 11524, 'Patrulha Salvadora S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/479517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162508, 11524, 'Patrulha Salvadora S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/479518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162509, 11524, 'Patrulha Salvadora S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/479519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162510, 11524, 'Patrulha Salvadora S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/479520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162511, 11524, 'Patrulha Salvadora S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/479521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162512, 11524, 'Patrulha Salvadora S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/479522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162513, 11524, 'Patrulha Salvadora S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/479523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162514, 11525, 'Patrulha Salvadora S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/855729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162515, 11525, 'Patrulha Salvadora S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/855730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162516, 11525, 'Patrulha Salvadora S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/855731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162517, 11525, 'Patrulha Salvadora S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/855732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162518, 11525, 'Patrulha Salvadora S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/855733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162519, 11525, 'Patrulha Salvadora S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/855734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162520, 11525, 'Patrulha Salvadora S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/855735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162521, 11525, 'Patrulha Salvadora S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/855736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162522, 11525, 'Patrulha Salvadora S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/855737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162523, 11525, 'Patrulha Salvadora S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/855738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162524, 11525, 'Patrulha Salvadora S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/855739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162525, 11525, 'Patrulha Salvadora S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/855740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162526, 11525, 'Patrulha Salvadora S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/855741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162527, 11526, 'Patrulha Salvadora S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/855742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162528, 11526, 'Patrulha Salvadora S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/855743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162529, 11526, 'Patrulha Salvadora S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/855744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162530, 11526, 'Patrulha Salvadora S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/855745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162531, 11526, 'Patrulha Salvadora S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/855746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162532, 11526, 'Patrulha Salvadora S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/855747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162533, 11526, 'Patrulha Salvadora S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/855748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162534, 11526, 'Patrulha Salvadora S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/855749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162535, 11526, 'Patrulha Salvadora S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/855750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162536, 11526, 'Patrulha Salvadora S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/855751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162537, 11526, 'Patrulha Salvadora S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/855752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162538, 11526, 'Patrulha Salvadora S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/855753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162539, 11526, 'Patrulha Salvadora S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/855754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162540, 11527, 'Patrulha Salvadora S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/855755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162541, 11527, 'Patrulha Salvadora S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/855756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162542, 11527, 'Patrulha Salvadora S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/855757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162543, 11527, 'Patrulha Salvadora S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/855758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162544, 11527, 'Patrulha Salvadora S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/855759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162545, 11527, 'Patrulha Salvadora S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/855760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162546, 11527, 'Patrulha Salvadora S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/855761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162547, 11527, 'Patrulha Salvadora S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/855762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162548, 11527, 'Patrulha Salvadora S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/855763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162549, 11527, 'Patrulha Salvadora S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/855764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162550, 11527, 'Patrulha Salvadora S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/855765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162551, 11527, 'Patrulha Salvadora S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/855766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162552, 11527, 'Patrulha Salvadora S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/855767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/klVJGXsIiHqLrMaPKWbcy2XPGMo.jpg'),
(162553, 11528, 'Poeira em Alto Mar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v3NVeMsYbphKJD5acxR1MwOHvsl.jpg'),
(162554, 11528, 'Poeira em Alto Mar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v3NVeMsYbphKJD5acxR1MwOHvsl.jpg'),
(162555, 11528, 'Poeira em Alto Mar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v3NVeMsYbphKJD5acxR1MwOHvsl.jpg'),
(162556, 11528, 'Poeira em Alto Mar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v3NVeMsYbphKJD5acxR1MwOHvsl.jpg'),
(162557, 11528, 'Poeira em Alto Mar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v3NVeMsYbphKJD5acxR1MwOHvsl.jpg'),
(162558, 11529, 'A Ex mulher S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479502.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4V9GB1a0i2NdQxIawCe4Clyqg1L.jpg'),
(162559, 11529, 'A Ex mulher S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479503.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dWu3cBDZZRMD62MFc0qv1h6WjLC.jpg'),
(162560, 11529, 'A Ex mulher S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479504.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sphDMLwFYjpWHN7qfnxB0INWCof.jpg'),
(162561, 11529, 'A Ex mulher S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479505.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Bn9o6nFYMSfXpEiKl5JE4yLYlG.jpg'),
(162562, 11530, 'A Ex mulher S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/895835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vp5Vs17MUizJ7bQNMRsUcvDVquC.jpg'),
(162563, 11530, 'A Ex mulher S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/895836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vp5Vs17MUizJ7bQNMRsUcvDVquC.jpg'),
(162564, 11530, 'A Ex mulher S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/895837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vp5Vs17MUizJ7bQNMRsUcvDVquC.jpg'),
(162565, 11530, 'A Ex mulher S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/895838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vp5Vs17MUizJ7bQNMRsUcvDVquC.jpg'),
(162566, 1856, 'The Office S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479494.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mXKNGQ6PzAG8uoEL2jwQ2UWR3St.jpg'),
(162567, 1856, 'The Office S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/479495.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gj2NDIXzrP0Z6ECtwb3IHn6h6B6.jpg'),
(162568, 1856, 'The Office S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/479496.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6rn6hWYHxEtviRAm2Usc05IvJSE.jpg'),
(162569, 1856, 'The Office S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/479497.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jdYtGBRlz5pGKeyqp1JQEdMGYrC.jpg'),
(162570, 1856, 'The Office S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/479498.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1coOPJunjGCbPfL0THAdyoByQB1.jpg'),
(162571, 1856, 'The Office S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/479499.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gLwSbFGHER6G99PxkesWQpF8ULs.jpg'),
(162572, 1856, 'The Office S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/479500.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4eDV2HPKGtQeVabVQkHmfB9JvSQ.jpg'),
(162573, 1856, 'The Office S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/479501.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wJZy3opTsnnMgtK9YS8DbEDPKWr.jpg'),
(162574, 11531, 'To Nessa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/479493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ekr6786E9KxFm1LNTwNQl0PzKh.jpg'),
(162575, 11531, 'To Nessa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/487978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ekr6786E9KxFm1LNTwNQl0PzKh.jpg'),
(162576, 11531, 'To Nessa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/503688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ekr6786E9KxFm1LNTwNQl0PzKh.jpg'),
(162577, 11531, 'To Nessa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/503689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5ekr6786E9KxFm1LNTwNQl0PzKh.jpg'),
(162578, 11532, 'Astronauta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486729.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ho4ANrURS5LjzJte3u8FUs0Yp9j.jpg'),
(162579, 11532, 'Astronauta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/493950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vxpGmqRuyk4y179ltiJWvVqbbhh.jpg'),
(162580, 11532, 'Astronauta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/497095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vxpGmqRuyk4y179ltiJWvVqbbhh.jpg'),
(162581, 11532, 'Astronauta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vxpGmqRuyk4y179ltiJWvVqbbhh.jpg'),
(162582, 11532, 'Astronauta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vxpGmqRuyk4y179ltiJWvVqbbhh.jpg'),
(162583, 11532, 'Astronauta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vxpGmqRuyk4y179ltiJWvVqbbhh.jpg'),
(162584, 11533, 'Carniceiros S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486724.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/um4w7kC1PCCCWBlJHch8inQwmwH.jpg'),
(162585, 11533, 'Carniceiros S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486725.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qeE2cTtLRn3bpj1fzxpOU2Ek3kH.jpg'),
(162586, 11533, 'Carniceiros S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486726.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/adPlJh6MnntFH1lFm4Vdo8CvS3R.jpg'),
(162587, 11533, 'Carniceiros S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486727.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/58liil8pgBKyG9FFY78WHUyJAWv.jpg'),
(162588, 11533, 'Carniceiros S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486728.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jhnsJF5ocJJAerwDWnq7MXhzm5e.jpg'),
(162589, 11534, 'Fallen Luz e Sombra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486716.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uV55HB4flm5dmZVtP8OnFkSNfcL.jpg'),
(162590, 11534, 'Fallen Luz e Sombra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486717.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/43XUnlLzVc9NFL2hqt1RX1KYiQM.jpg'),
(162591, 11534, 'Fallen Luz e Sombra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486718.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yJZmbhB5aRdn4OuY01TwTBsmQuV.jpg'),
(162592, 11534, 'Fallen Luz e Sombra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486719.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5eTY9SORtoZ68KO5R9Od3nP6KLE.jpg'),
(162593, 11534, 'Fallen Luz e Sombra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486720.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jbSjgqZ0tNQoreaPUpsUo8HYx9K.jpg'),
(162594, 11534, 'Fallen Luz e Sombra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486721.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hQWA3G6yve16Ife4gNqAlhJIBTX.jpg'),
(162595, 11534, 'Fallen Luz e Sombra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486722.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pbsXbZbCVoRu64wuMJW1TplHvpH.jpg'),
(162596, 11534, 'Fallen Luz e Sombra S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486723.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lhj2WFXZbBtogQImeTGZ4aB4iss.jpg'),
(162597, 11535, 'Terra dos Meninos Pelados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Ct368IXaFa7TPTJab6y6LsVfud.jpg'),
(162598, 11535, 'Terra dos Meninos Pelados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Ct368IXaFa7TPTJab6y6LsVfud.jpg'),
(162599, 11535, 'Terra dos Meninos Pelados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Ct368IXaFa7TPTJab6y6LsVfud.jpg'),
(162600, 11535, 'Terra dos Meninos Pelados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Ct368IXaFa7TPTJab6y6LsVfud.jpg'),
(162601, 11536, 'Os Medicos da Face S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486710.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/77EccgFjbpgyG78qBqIjh1T51R9.jpg'),
(162602, 11536, 'Os Medicos da Face S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486711.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7cQInsDOburJ6fjrecCJWwJpmDe.jpg'),
(162603, 11536, 'Os Medicos da Face S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/491929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zt4oFvqHdPvqvDzS0pGDHJReRc3.jpg'),
(162604, 11536, 'Os Medicos da Face S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/496349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zt4oFvqHdPvqvDzS0pGDHJReRc3.jpg'),
(162605, 11536, 'Os Medicos da Face S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/505397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zt4oFvqHdPvqvDzS0pGDHJReRc3.jpg'),
(162606, 11536, 'Os Medicos da Face S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/505398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zt4oFvqHdPvqvDzS0pGDHJReRc3.jpg'),
(162607, 11536, 'Os Medicos da Face S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/511379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zt4oFvqHdPvqvDzS0pGDHJReRc3.jpg'),
(162608, 11536, 'Os Medicos da Face S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/514213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zt4oFvqHdPvqvDzS0pGDHJReRc3.jpg'),
(162609, 11537, 'Restaurando Casas de Fazenda Negocio Arriscado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A3seNnRbMzATxwdBc9StEk2LQbA.jpg'),
(162610, 11537, 'Restaurando Casas de Fazenda Negocio Arriscado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A3seNnRbMzATxwdBc9StEk2LQbA.jpg'),
(162611, 11537, 'Restaurando Casas de Fazenda Negocio Arriscado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A3seNnRbMzATxwdBc9StEk2LQbA.jpg'),
(162612, 11537, 'Restaurando Casas de Fazenda Negocio Arriscado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A3seNnRbMzATxwdBc9StEk2LQbA.jpg'),
(162613, 11538, 'A Cadela Sabichona [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wm0zAzPD6xMjf7YUpAMqyyDsvKe.jpg'),
(162614, 11538, 'A Cadela Sabichona [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wm0zAzPD6xMjf7YUpAMqyyDsvKe.jpg'),
(162615, 11538, 'A Cadela Sabichona [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wm0zAzPD6xMjf7YUpAMqyyDsvKe.jpg'),
(162616, 11538, 'A Cadela Sabichona [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wm0zAzPD6xMjf7YUpAMqyyDsvKe.jpg'),
(162617, 11538, 'A Cadela Sabichona [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wm0zAzPD6xMjf7YUpAMqyyDsvKe.jpg'),
(162618, 11538, 'A Cadela Sabichona [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wm0zAzPD6xMjf7YUpAMqyyDsvKe.jpg'),
(162619, 11538, 'A Cadela Sabichona [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wm0zAzPD6xMjf7YUpAMqyyDsvKe.jpg'),
(162620, 11538, 'A Cadela Sabichona [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wm0zAzPD6xMjf7YUpAMqyyDsvKe.jpg'),
(162621, 11538, 'A Cadela Sabichona [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/508607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wm0zAzPD6xMjf7YUpAMqyyDsvKe.jpg'),
(162622, 11538, 'A Cadela Sabichona [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/508608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wm0zAzPD6xMjf7YUpAMqyyDsvKe.jpg'),
(162623, 11538, 'A Cadela Sabichona [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/508609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wm0zAzPD6xMjf7YUpAMqyyDsvKe.jpg'),
(162624, 11538, 'A Cadela Sabichona [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/508610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wm0zAzPD6xMjf7YUpAMqyyDsvKe.jpg'),
(162625, 11539, 'A Confidente [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486697.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c1rM8jaoLnz86ZDHooQvnK3D1gI.jpg'),
(162626, 11539, 'A Confidente [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502312.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nXAboyDy3RDyUaoahY89vcgrzoc.jpg'),
(162627, 11539, 'A Confidente [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502313.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7vHtngi8ZCww4gb6VaaeP5Tmelr.jpg'),
(162628, 11539, 'A Confidente [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502314.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q7l1uFsi214i5wIQUvdJyBbP7Hd.jpg'),
(162629, 11540, 'A Maquina [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486691.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wBqo5ZIx9TVU7y6TbFcRUNQCQVe.jpg'),
(162630, 11540, 'A Maquina [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486692.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qGpBLXMkhUxALmDyg55fTsremHB.jpg'),
(162631, 11540, 'A Maquina [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486693.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7878KaRRYUTG9iA1pMobwo7QZv9.jpg'),
(162632, 11540, 'A Maquina [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486694.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9YSjSKHuST09kOuAWEFrhQ9svx2.jpg'),
(162633, 11540, 'A Maquina [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486695.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cg9JKweuTm08dxLaTFromFu29N2.jpg'),
(162634, 11540, 'A Maquina [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486696.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bBD8hmN34lH3EXR1DuKEOPr0XJL.jpg'),
(162635, 11541, 'Bake Me Please [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486685.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tTjp5y2wpK3ESRnNdCssQdghV2D.jpg'),
(162636, 11541, 'Bake Me Please [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486686.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lKLhndumnHAeFAgHia36K1zqvJ6.jpg'),
(162637, 11541, 'Bake Me Please [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486687.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rf1lS5kEShU1oFjxQp9jQZuhFVE.jpg'),
(162638, 11541, 'Bake Me Please [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486688.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3keInSJQy03gC5fao427uV4Q7zG.jpg'),
(162639, 11541, 'Bake Me Please [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486689.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/529qsG4oHpq2Kdm8m9KX6w3TtWa.jpg'),
(162640, 11541, 'Bake Me Please [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486690.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zI2vwru01VuCtrdjHAzYg0qr5AS.jpg'),
(162641, 11542, 'Comedy Revenge [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486679.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7JURgfUhjJIVfqn8KlOPnq7gWZk.jpg'),
(162642, 11542, 'Comedy Revenge [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486680.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cSMi0HoPvEEr1lqqmRCJ4Vyeh1K.jpg'),
(162643, 11542, 'Comedy Revenge [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486681.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3jAoZiJkhSbtlT67TcomiJTTv2I.jpg'),
(162644, 11542, 'Comedy Revenge [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486682.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rk3cH6N7LFEKsDK1OarjWFaiiCl.jpg'),
(162645, 11542, 'Comedy Revenge [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486683.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fmdqtdWLZtZrbc1Vr01Ytd8gZLq.jpg'),
(162646, 11542, 'Comedy Revenge [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486684.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5gqAqD5ujRNqUQuNhe8SW6od8KK.jpg'),
(162647, 11543, 'Confeitaria do Terror [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486677.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oT8uexRoO6TqL0GC8iVFUQK0ziR.jpg'),
(162648, 11543, 'Confeitaria do Terror [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486678.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/haMYsTqZWY3VkcprlxZaQ9bR4J1.jpg'),
(162649, 9609, 'Doctor John [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162650, 9609, 'Doctor John [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162651, 9609, 'Doctor John [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162652, 9609, 'Doctor John [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162653, 9609, 'Doctor John [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162654, 9609, 'Doctor John [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162655, 9609, 'Doctor John [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162656, 9609, 'Doctor John [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162657, 9609, 'Doctor John [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/486653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162658, 9609, 'Doctor John [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/486654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162659, 9609, 'Doctor John [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/486655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162660, 9609, 'Doctor John [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/486656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162661, 9609, 'Doctor John [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/486657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162662, 9609, 'Doctor John [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/486658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162663, 9609, 'Doctor John [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/486659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162664, 9609, 'Doctor John [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/486660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162665, 9609, 'Doctor John [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/486661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162666, 9609, 'Doctor John [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/486662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162667, 9609, 'Doctor John [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/486663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162668, 9609, 'Doctor John [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/486664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162669, 9609, 'Doctor John [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/486665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162670, 9609, 'Doctor John [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/486666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162671, 9609, 'Doctor John [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/486667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162672, 9609, 'Doctor John [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/486668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162673, 9609, 'Doctor John [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/486669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162674, 9609, 'Doctor John [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/486670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162675, 9609, 'Doctor John [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/486671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162676, 9609, 'Doctor John [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/486672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162677, 9609, 'Doctor John [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/486673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162678, 9609, 'Doctor John [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/486674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162679, 9609, 'Doctor John [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/486675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162680, 9609, 'Doctor John [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/486676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wMKgkgWt4jzZfPlCSsi0ESbyRiE.jpg'),
(162681, 11544, 'Doctor Odyssey [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486642.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hlqCbQRgLy3mkLxYf8t7Nmf6fxB.jpg'),
(162682, 11544, 'Doctor Odyssey [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486643.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A8e9zrRzdpSc6MG01FBNJHQuLGX.jpg'),
(162683, 11544, 'Doctor Odyssey [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486644.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kui9mgxi0RQ6xVfXA9Yo80Lxv5g.jpg'),
(162684, 11544, 'Doctor Odyssey [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(162685, 11544, 'Doctor Odyssey [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(162686, 11544, 'Doctor Odyssey [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(162687, 11544, 'Doctor Odyssey [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(162688, 11544, 'Doctor Odyssey [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/514544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(162689, 11544, 'Doctor Odyssey [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/776821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(162690, 11544, 'Doctor Odyssey [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/776822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(162691, 11544, 'Doctor Odyssey [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/776823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(162692, 11544, 'Doctor Odyssey [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/776824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(162693, 11544, 'Doctor Odyssey [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/776825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(162694, 11544, 'Doctor Odyssey [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/776826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(162695, 11544, 'Doctor Odyssey [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/786327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(162696, 11544, 'Doctor Odyssey [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/796663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(162697, 11544, 'Doctor Odyssey [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/805106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(162698, 11544, 'Doctor Odyssey [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/808453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(162699, 11545, 'Dragon Ball DAIMA [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486640.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r3SDXWQxc5PqZ5yvcwerJq2DgEe.jpg'),
(162700, 11545, 'Dragon Ball DAIMA [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486641.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h6ZzSPzRbGqFhvPJwrDrL6E3zr0.jpg'),
(162701, 11545, 'Dragon Ball DAIMA [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pc9jW4KdhGfJ7go74VTOq3qWxk5.jpg'),
(162702, 11545, 'Dragon Ball DAIMA [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pc9jW4KdhGfJ7go74VTOq3qWxk5.jpg'),
(162703, 11545, 'Dragon Ball DAIMA [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pc9jW4KdhGfJ7go74VTOq3qWxk5.jpg'),
(162704, 11545, 'Dragon Ball DAIMA [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pc9jW4KdhGfJ7go74VTOq3qWxk5.jpg'),
(162705, 11545, 'Dragon Ball DAIMA [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pc9jW4KdhGfJ7go74VTOq3qWxk5.jpg'),
(162706, 11545, 'Dragon Ball DAIMA [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/514528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pc9jW4KdhGfJ7go74VTOq3qWxk5.jpg'),
(162707, 11545, 'Dragon Ball DAIMA [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/518656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pc9jW4KdhGfJ7go74VTOq3qWxk5.jpg'),
(162708, 11545, 'Dragon Ball DAIMA [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/521319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pc9jW4KdhGfJ7go74VTOq3qWxk5.jpg'),
(162709, 11545, 'Dragon Ball DAIMA [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/639292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pc9jW4KdhGfJ7go74VTOq3qWxk5.jpg'),
(162710, 11545, 'Dragon Ball DAIMA [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/656672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pc9jW4KdhGfJ7go74VTOq3qWxk5.jpg'),
(162711, 11545, 'Dragon Ball DAIMA [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/660464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pc9jW4KdhGfJ7go74VTOq3qWxk5.jpg'),
(162712, 11545, 'Dragon Ball DAIMA [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/665063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pc9jW4KdhGfJ7go74VTOq3qWxk5.jpg'),
(162713, 11545, 'Dragon Ball DAIMA [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/675825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pc9jW4KdhGfJ7go74VTOq3qWxk5.jpg'),
(162714, 11545, 'Dragon Ball DAIMA [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/683738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pc9jW4KdhGfJ7go74VTOq3qWxk5.jpg'),
(162715, 11545, 'Dragon Ball DAIMA [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/686777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pc9jW4KdhGfJ7go74VTOq3qWxk5.jpg'),
(162716, 11545, 'Dragon Ball DAIMA [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/698214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pc9jW4KdhGfJ7go74VTOq3qWxk5.jpg'),
(162717, 11545, 'Dragon Ball DAIMA [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/706379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pc9jW4KdhGfJ7go74VTOq3qWxk5.jpg'),
(162718, 11545, 'Dragon Ball DAIMA [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/712823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pc9jW4KdhGfJ7go74VTOq3qWxk5.jpg'),
(162719, 11546, 'Familia de Ferro [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162720, 11546, 'Familia de Ferro [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162721, 11546, 'Familia de Ferro [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486638.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/saZ9cUjxEEiLJMWoi9To3JFtJwc.jpg'),
(162722, 11546, 'Familia de Ferro [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486639.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/co1pIQgIpgWgbl27mveKCttJXW1.jpg'),
(162723, 11546, 'Familia de Ferro [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162724, 11546, 'Familia de Ferro [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162725, 11546, 'Familia de Ferro [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162726, 11546, 'Familia de Ferro [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/508506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162727, 11546, 'Familia de Ferro [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/508507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162728, 11546, 'Familia de Ferro [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/508508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162729, 11546, 'Familia de Ferro [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/508509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162730, 11546, 'Familia de Ferro [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/664701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162731, 11546, 'Familia de Ferro [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/664702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162732, 11546, 'Familia de Ferro [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/664703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162733, 11546, 'Familia de Ferro [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/664704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162734, 11546, 'Familia de Ferro [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/664705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162735, 11546, 'Familia de Ferro [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/664706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162736, 11546, 'Familia de Ferro [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/664707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162737, 11546, 'Familia de Ferro [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/664708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162738, 11546, 'Familia de Ferro [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/664709.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162739, 11546, 'Familia de Ferro [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/664710.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162740, 11546, 'Familia de Ferro [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/664711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162741, 11546, 'Familia de Ferro [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/664712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162742, 11546, 'Familia de Ferro [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/664713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162743, 11546, 'Familia de Ferro [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/664714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(162744, 11546, 'Familia de Ferro [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/664715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162745, 11546, 'Familia de Ferro [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/664716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162746, 11546, 'Familia de Ferro [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/664717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162747, 11546, 'Familia de Ferro [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/664718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162748, 11546, 'Familia de Ferro [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/664719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162749, 11546, 'Familia de Ferro [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/664720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162750, 11546, 'Familia de Ferro [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/664721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162751, 11546, 'Familia de Ferro [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/698181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162752, 11546, 'Familia de Ferro [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/698182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162753, 11546, 'Familia de Ferro [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/698183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162754, 11546, 'Familia de Ferro [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/698184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/m868OmP1qXF6BGGockyTm3aIwhQ.jpg'),
(162755, 11547, 'Familia por Escolha [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486634.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1O8XLMswBgYGZAMBjq4iDogtwb7.jpg'),
(162756, 11547, 'Familia por Escolha [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486635.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c1VETKWQpwLjfZGsdP8oARuXuYg.jpg'),
(162757, 11547, 'Familia por Escolha [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/513356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVyhURoPK3PJdYIQSLdfEhhIfSE.jpg'),
(162758, 11547, 'Familia por Escolha [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/513357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVyhURoPK3PJdYIQSLdfEhhIfSE.jpg'),
(162759, 11547, 'Familia por Escolha [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/513358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVyhURoPK3PJdYIQSLdfEhhIfSE.jpg'),
(162760, 11547, 'Familia por Escolha [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/513359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVyhURoPK3PJdYIQSLdfEhhIfSE.jpg'),
(162761, 11547, 'Familia por Escolha [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/513360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVyhURoPK3PJdYIQSLdfEhhIfSE.jpg'),
(162762, 11547, 'Familia por Escolha [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/513361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVyhURoPK3PJdYIQSLdfEhhIfSE.jpg'),
(162763, 11547, 'Familia por Escolha [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/513362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVyhURoPK3PJdYIQSLdfEhhIfSE.jpg'),
(162764, 11547, 'Familia por Escolha [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/513363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVyhURoPK3PJdYIQSLdfEhhIfSE.jpg'),
(162765, 11547, 'Familia por Escolha [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/513364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVyhURoPK3PJdYIQSLdfEhhIfSE.jpg'),
(162766, 11547, 'Familia por Escolha [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/513365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVyhURoPK3PJdYIQSLdfEhhIfSE.jpg'),
(162767, 11547, 'Familia por Escolha [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/513366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVyhURoPK3PJdYIQSLdfEhhIfSE.jpg'),
(162768, 11547, 'Familia por Escolha [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/513367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVyhURoPK3PJdYIQSLdfEhhIfSE.jpg'),
(162769, 11547, 'Familia por Escolha [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/515660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVyhURoPK3PJdYIQSLdfEhhIfSE.jpg'),
(162770, 11547, 'Familia por Escolha [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/515661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wVyhURoPK3PJdYIQSLdfEhhIfSE.jpg'),
(162771, 11548, 'Grotesquerie [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486628.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mtIkvn4rnxwqKV95LiacSOKMDVu.jpg'),
(162772, 11548, 'Grotesquerie [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486629.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xXaSWhG5lWudjITIQ2uZQg5HY1R.jpg'),
(162773, 11548, 'Grotesquerie [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486630.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uTk28VwTCFP7H0RQjdPXHmM1g8b.jpg'),
(162774, 11548, 'Grotesquerie [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486631.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KGgH5hxA9dX8RUf5BtDiNQdxS.jpg'),
(162775, 11548, 'Grotesquerie [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486632.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dPA9WcDwxlZZvqntpza6MeJ30f9.jpg'),
(162776, 11548, 'Grotesquerie [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486633.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dDMguU43euo7xGZllaoUEFJAYsg.jpg'),
(162777, 11548, 'Grotesquerie [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/513350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ZjPu0cf7N57J97jmCcRLvwveUu.jpg'),
(162778, 11548, 'Grotesquerie [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/513351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ZjPu0cf7N57J97jmCcRLvwveUu.jpg'),
(162779, 11548, 'Grotesquerie [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/513352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ZjPu0cf7N57J97jmCcRLvwveUu.jpg'),
(162780, 11548, 'Grotesquerie [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/513353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ZjPu0cf7N57J97jmCcRLvwveUu.jpg'),
(162781, 11549, 'Hospital Marginal [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486617.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m2sBUOvpWd9tfYNa89yQ7OaOonP.jpg'),
(162782, 11549, 'Hospital Marginal [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486618.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eFUacJsh070185z3CfOmxJK18Y9.jpg'),
(162783, 11549, 'Hospital Marginal [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486619.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zIgTL9wdquhEdMlUVX2vrRFgdVo.jpg'),
(162784, 11549, 'Hospital Marginal [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486620.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/24Ht8ip90emAdNVZyCyzVNDOYaX.jpg'),
(162785, 11549, 'Hospital Marginal [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486621.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sNoloAEfNFNqnel76u7luRYqJSd.jpg'),
(162786, 11549, 'Hospital Marginal [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486622.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vommPHK7pPIsQ7G3sMhuTwfPaMp.jpg'),
(162787, 11549, 'Hospital Marginal [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486623.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pGSq5CKDiiKyFZbnrBaayssARQn.jpg'),
(162788, 11549, 'Hospital Marginal [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486624.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bfJtTitcGl3F0f55W69nU3fS5kC.jpg'),
(162789, 11549, 'Hospital Marginal [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/486625.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yZkpm6wEZXI9GZk3eTuxDgx1Mu0.jpg'),
(162790, 11549, 'Hospital Marginal [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/486626.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kBW4XtIZHQ9xXDVDTNy3uznYCIJ.jpg'),
(162791, 11549, 'Hospital Marginal [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/486627.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d6iOLsADrHlvuLrQKxiEMucTAQB.jpg'),
(162792, 11550, 'Jardim de Meteoros [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486568.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/76nW01rNrcy5furpD5lvPhxZYBM.jpg'),
(162793, 11550, 'Jardim de Meteoros [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486569.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/osqzPzf30R6rin8XqVGCCSRxKbt.jpg'),
(162794, 11550, 'Jardim de Meteoros [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486570.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9dhZrfziNh8ncbV44uOna1Bi0mN.jpg'),
(162795, 11550, 'Jardim de Meteoros [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486571.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cXw42tXq8mCmDWadtxslcg7Wp2N.jpg'),
(162796, 11550, 'Jardim de Meteoros [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486572.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/scl7H9wcuzJf1OwA7VBGwGOdOzC.jpg'),
(162797, 11550, 'Jardim de Meteoros [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486573.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xUNe63wVfuK9ux13k6pHUdjDLAq.jpg'),
(162798, 11550, 'Jardim de Meteoros [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486574.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bUW46ICEonujYsXgxJs1T3axuAG.jpg'),
(162799, 11550, 'Jardim de Meteoros [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486575.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r7Eb21cxKOY7tgj8kKOshZ087hr.jpg'),
(162800, 11550, 'Jardim de Meteoros [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/486576.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bzFdA5EP5KobgjXQYzelU8oFpAK.jpg'),
(162801, 11550, 'Jardim de Meteoros [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/486577.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ggkSos4IIt4PZ6VyezyfP5IojmW.jpg'),
(162802, 11550, 'Jardim de Meteoros [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/486578.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q72NkeihWqmMrekmDpG7mt2PGnS.jpg'),
(162803, 11550, 'Jardim de Meteoros [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/486579.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gGue1I74qVEOL8ORqoK8vo3XpuM.jpg'),
(162804, 11550, 'Jardim de Meteoros [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/486580.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1o88PoPKBq8Z8QLQXlCbNR4sU8M.jpg'),
(162805, 11550, 'Jardim de Meteoros [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/486581.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6IfTDD49GS8SLsJODy0Oel0yXI1.jpg'),
(162806, 11550, 'Jardim de Meteoros [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/486582.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fRAKu4tk55J5sJKNxlWb3vanLun.jpg'),
(162807, 11550, 'Jardim de Meteoros [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/486583.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oSksNc7jH7V0dntbIvK7UICyt13.jpg'),
(162808, 11550, 'Jardim de Meteoros [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/486584.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lZpRM6D532LAyoQ0ESP3yOtH28Z.jpg'),
(162809, 11550, 'Jardim de Meteoros [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/486585.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Aa6O7tLcawAbA96lrkIDIqwQ29A.jpg'),
(162810, 11550, 'Jardim de Meteoros [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/486586.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fRG93eiAqT8W46bWBkegM1PqMoX.jpg'),
(162811, 11550, 'Jardim de Meteoros [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/486587.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4AInv82Q0E8vM0eTL5ioOwBjz1Z.jpg'),
(162812, 11550, 'Jardim de Meteoros [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/486588.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cyB5HDFFuXGhKw6PzoEmONpM4yA.jpg'),
(162813, 11550, 'Jardim de Meteoros [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/486589.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rO8cch5pcb8fYL7DAxXWDHpf8xp.jpg'),
(162814, 11550, 'Jardim de Meteoros [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/486590.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fSK55bMvMaq2k8XkDwxOjxXzFuB.jpg'),
(162815, 11550, 'Jardim de Meteoros [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/486591.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ckLcvfPt1P2bylyz1TzHgqe2Q7D.jpg'),
(162816, 11550, 'Jardim de Meteoros [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/486592.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4N7yvoqg77iOPaOXclZ25WmDvHC.jpg'),
(162817, 11550, 'Jardim de Meteoros [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/486593.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ySbHhSeuC91nUo0AX5cPNpGmXFV.jpg'),
(162818, 11550, 'Jardim de Meteoros [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/486594.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bqeCBMjpTOCkZhkeCMWkUPAvbhD.jpg'),
(162819, 11550, 'Jardim de Meteoros [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/486595.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j3piOMtyN6yUttF14B8abvQONhc.jpg'),
(162820, 11550, 'Jardim de Meteoros [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/486596.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6K4xhqFM9lrNOIq2k0wM6yB42BG.jpg'),
(162821, 11550, 'Jardim de Meteoros [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/486597.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/izjJlvRwa2eYvnUq9MUkym5Xn7p.jpg'),
(162822, 11550, 'Jardim de Meteoros [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/486598.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lvWN8JNOAqzi09BqQAl216gP4Kn.jpg'),
(162823, 11550, 'Jardim de Meteoros [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/486599.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jd9RWZBTkWBprRfowJGyi5evr8D.jpg'),
(162824, 11550, 'Jardim de Meteoros [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/486600.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xXG5ykq0mPHKOWHuFheiv1fGTUo.jpg'),
(162825, 11550, 'Jardim de Meteoros [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/486601.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wjYABeuTycKUaty3LkwADZwztGH.jpg'),
(162826, 11550, 'Jardim de Meteoros [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/486602.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y0xTIxG8C9xmslf1jDlCq31GGYn.jpg'),
(162827, 11550, 'Jardim de Meteoros [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/486603.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7SfSsKCpN80qtctY7upbNxkSCRG.jpg'),
(162828, 11550, 'Jardim de Meteoros [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/486604.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bR1PMKHYjKOmUTimnMEdQ1VP551.jpg'),
(162829, 11550, 'Jardim de Meteoros [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/486605.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iZLN77LnVtgFj6yUhxfiICMQRkN.jpg'),
(162830, 11550, 'Jardim de Meteoros [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/486606.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cU2nEkwEuSYhdQu9UgIpygZK3Hn.jpg'),
(162831, 11550, 'Jardim de Meteoros [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/486607.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5pJQIIEr34naZqp9tW7qEVfj47z.jpg'),
(162832, 11550, 'Jardim de Meteoros [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/486608.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6jzRggDKIPsxbl7okKya5eG8CRn.jpg'),
(162833, 11550, 'Jardim de Meteoros [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/486609.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ogpWCH8UICCLylJNjtoTnr0J31p.jpg'),
(162834, 11550, 'Jardim de Meteoros [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/486610.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n8DGuj6xqc1ZlDOlyfdlf1KG0q5.jpg'),
(162835, 11550, 'Jardim de Meteoros [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/486611.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/915n9CbckpCvUfaeE2f7BCrkKvK.jpg'),
(162836, 11550, 'Jardim de Meteoros [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/486612.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/geEohFCMi4aIhEBsYt8oKH1Jp8S.jpg'),
(162837, 11550, 'Jardim de Meteoros [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/486613.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hi1vzcbAnhkS5Zt18Puh0ioEkh1.jpg'),
(162838, 11550, 'Jardim de Meteoros [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/486614.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hc6w4KhJIqE9vuXaFZAL79v3yLA.jpg'),
(162839, 11550, 'Jardim de Meteoros [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/486615.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pinDoi9vRFJvh3VXVN3fYwGKLKF.jpg'),
(162840, 11550, 'Jardim de Meteoros [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/486616.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mBwXcE0BRvtFEIG4QnDGJcYVyYQ.jpg'),
(162841, 11551, 'Kinokoinu Mushroom Pup [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486565.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7OSKgDK6nAF8NeUV1mLdhj3jDf4.jpg'),
(162842, 11551, 'Kinokoinu Mushroom Pup [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486566.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/evAy4kZyBauq8JhjX4sAkmDM4s5.jpg'),
(162843, 11551, 'Kinokoinu Mushroom Pup [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486567.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ojd2iVWPQJkmIjjZC4yUHCyemOn.jpg'),
(162844, 11551, 'Kinokoinu Mushroom Pup [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/513340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2kjIui4ejGFtVMOtSAmjFwcsiKm.jpg'),
(162845, 11551, 'Kinokoinu Mushroom Pup [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/513341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2kjIui4ejGFtVMOtSAmjFwcsiKm.jpg'),
(162846, 11551, 'Kinokoinu Mushroom Pup [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/513342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2kjIui4ejGFtVMOtSAmjFwcsiKm.jpg'),
(162847, 11551, 'Kinokoinu Mushroom Pup [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/513343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2kjIui4ejGFtVMOtSAmjFwcsiKm.jpg'),
(162848, 11551, 'Kinokoinu Mushroom Pup [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/639122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2kjIui4ejGFtVMOtSAmjFwcsiKm.jpg'),
(162849, 11551, 'Kinokoinu Mushroom Pup [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/639123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2kjIui4ejGFtVMOtSAmjFwcsiKm.jpg'),
(162850, 11551, 'Kinokoinu Mushroom Pup [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/639124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2kjIui4ejGFtVMOtSAmjFwcsiKm.jpg'),
(162851, 11551, 'Kinokoinu Mushroom Pup [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/639125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2kjIui4ejGFtVMOtSAmjFwcsiKm.jpg'),
(162852, 11552, 'Light of My Lion [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486564.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bvpEjwFiOaYmQcKUhyQcwDNoLSM.jpg'),
(162853, 11552, 'Light of My Lion [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/513333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/X4YqOo8K57flH1VAX0tF6muRTZ.jpg'),
(162854, 11552, 'Light of My Lion [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/513334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/X4YqOo8K57flH1VAX0tF6muRTZ.jpg'),
(162855, 11552, 'Light of My Lion [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/513335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/X4YqOo8K57flH1VAX0tF6muRTZ.jpg'),
(162856, 11552, 'Light of My Lion [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/513336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/X4YqOo8K57flH1VAX0tF6muRTZ.jpg'),
(162857, 11552, 'Light of My Lion [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/515444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/X4YqOo8K57flH1VAX0tF6muRTZ.jpg'),
(162858, 11552, 'Light of My Lion [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/517961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/X4YqOo8K57flH1VAX0tF6muRTZ.jpg'),
(162859, 11552, 'Light of My Lion [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/517962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/X4YqOo8K57flH1VAX0tF6muRTZ.jpg'),
(162860, 11552, 'Light of My Lion [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/637131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/X4YqOo8K57flH1VAX0tF6muRTZ.jpg'),
(162861, 11552, 'Light of My Lion [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/639113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/X4YqOo8K57flH1VAX0tF6muRTZ.jpg'),
(162862, 11552, 'Light of My Lion [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/656660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/X4YqOo8K57flH1VAX0tF6muRTZ.jpg'),
(162863, 11553, 'Meu Casamento Feliz [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486554.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fxVTK5OmxZF3SFCMIqZa9WrF75R.jpg'),
(162864, 11553, 'Meu Casamento Feliz [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486555.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2svSxcqpbpknFX6DCn9QkoV1K8c.jpg'),
(162865, 11553, 'Meu Casamento Feliz [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486556.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2D1AP9qFNjxeoVAdgmopMkxZ7Wu.jpg'),
(162866, 11553, 'Meu Casamento Feliz [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486557.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2mmSnvpubVqDRE1XfJ25FZvTplf.jpg'),
(162867, 11553, 'Meu Casamento Feliz [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486558.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iyXf7Ny4atWvv3zeF2cNQpBMAeY.jpg'),
(162868, 11553, 'Meu Casamento Feliz [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162869, 11553, 'Meu Casamento Feliz [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162870, 11553, 'Meu Casamento Feliz [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162871, 11553, 'Meu Casamento Feliz [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/486562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162872, 11553, 'Meu Casamento Feliz [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/486563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162873, 11553, 'Meu Casamento Feliz [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/511537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162874, 11553, 'Meu Casamento Feliz [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/511538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162875, 11553, 'Meu Casamento Feliz [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/511539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162876, 11553, 'Meu Casamento Feliz [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/511540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162877, 11553, 'Meu Casamento Feliz [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/511541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162878, 11553, 'Meu Casamento Feliz [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/511542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162879, 11553, 'Meu Casamento Feliz [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/511543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162880, 11553, 'Meu Casamento Feliz [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/511544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162881, 11553, 'Meu Casamento Feliz [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/511545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162882, 11553, 'Meu Casamento Feliz [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/511546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162883, 11553, 'Meu Casamento Feliz [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/511547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162884, 11553, 'Meu Casamento Feliz [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/511548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162885, 11553, 'Meu Casamento Feliz [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/511549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162886, 11553, 'Meu Casamento Feliz [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/511550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162887, 11553, 'Meu Casamento Feliz [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/511551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162888, 11553, 'Meu Casamento Feliz [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/511552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162889, 11553, 'Meu Casamento Feliz [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/511553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162890, 11553, 'Meu Casamento Feliz [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/511554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162891, 11553, 'Meu Casamento Feliz [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/511555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162892, 11553, 'Meu Casamento Feliz [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/511556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162893, 11553, 'Meu Casamento Feliz [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/511557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162894, 11553, 'Meu Casamento Feliz [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/511558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162895, 11553, 'Meu Casamento Feliz [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/511559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162896, 11553, 'Meu Casamento Feliz [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/511560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162897, 11553, 'Meu Casamento Feliz [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/511561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162898, 11553, 'Meu Casamento Feliz [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/514318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162899, 11553, 'Meu Casamento Feliz [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/514319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162900, 11553, 'Meu Casamento Feliz [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/514320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162901, 11553, 'Meu Casamento Feliz [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/514321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162902, 11553, 'Meu Casamento Feliz [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/514322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162903, 11553, 'Meu Casamento Feliz [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/520189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162904, 11553, 'Meu Casamento Feliz [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/520190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162905, 11553, 'Meu Casamento Feliz [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/520191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162906, 11553, 'Meu Casamento Feliz [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/520192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162907, 11553, 'Meu Casamento Feliz [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/520193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162908, 11553, 'Meu Casamento Feliz [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/638410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162909, 11553, 'Meu Casamento Feliz [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/638411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162910, 11553, 'Meu Casamento Feliz [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/638412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162911, 11553, 'Meu Casamento Feliz [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/638413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162912, 11553, 'Meu Casamento Feliz [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/638414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162913, 11553, 'Meu Casamento Feliz [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/638415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162914, 11553, 'Meu Casamento Feliz [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/638416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162915, 11553, 'Meu Casamento Feliz [L] S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/662156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162916, 11553, 'Meu Casamento Feliz [L] S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/662157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162917, 11553, 'Meu Casamento Feliz [L] S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/662158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162918, 11553, 'Meu Casamento Feliz [L] S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/662159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162919, 11553, 'Meu Casamento Feliz [L] S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/662160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162920, 11553, 'Meu Casamento Feliz [L] S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/662161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162921, 11553, 'Meu Casamento Feliz [L] S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/662162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162922, 11553, 'Meu Casamento Feliz [L] S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/662163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162923, 11553, 'Meu Casamento Feliz [L] S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/662164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162924, 11553, 'Meu Casamento Feliz [L] S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/662165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162925, 11553, 'Meu Casamento Feliz [L] S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/662166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162926, 11553, 'Meu Casamento Feliz [L] S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/671887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162927, 11553, 'Meu Casamento Feliz [L] S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/671888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162928, 11553, 'Meu Casamento Feliz [L] S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/671889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162929, 11553, 'Meu Casamento Feliz [L] S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/671890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162930, 11553, 'Meu Casamento Feliz [L] S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/671891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162931, 11553, 'Meu Casamento Feliz [L] S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/671892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162932, 11553, 'Meu Casamento Feliz [L] S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/671893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162933, 11553, 'Meu Casamento Feliz [L] S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/671894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162934, 11553, 'Meu Casamento Feliz [L] S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/679181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162935, 11553, 'Meu Casamento Feliz [L] S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/679182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162936, 11553, 'Meu Casamento Feliz [L] S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/679183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162937, 11553, 'Meu Casamento Feliz [L] S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/679184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162938, 11553, 'Meu Casamento Feliz [L] S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/679185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162939, 11553, 'Meu Casamento Feliz [L] S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/679186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162940, 11553, 'Meu Casamento Feliz [L] S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/679187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162941, 11553, 'Meu Casamento Feliz [L] S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/689844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162942, 11553, 'Meu Casamento Feliz [L] S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/689845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162943, 11553, 'Meu Casamento Feliz [L] S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/689846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162944, 11553, 'Meu Casamento Feliz [L] S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/689847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162945, 11553, 'Meu Casamento Feliz [L] S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/689848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162946, 11553, 'Meu Casamento Feliz [L] S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/689849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162947, 11553, 'Meu Casamento Feliz [L] S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/689850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162948, 11553, 'Meu Casamento Feliz [L] S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/689851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162949, 11553, 'Meu Casamento Feliz [L] S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/705102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162950, 11553, 'Meu Casamento Feliz [L] S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/705103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162951, 11553, 'Meu Casamento Feliz [L] S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/705104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162952, 11553, 'Meu Casamento Feliz [L] S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/705105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162953, 11553, 'Meu Casamento Feliz [L] S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/705106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162954, 11553, 'Meu Casamento Feliz [L] S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/705107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162955, 11553, 'Meu Casamento Feliz [L] S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/705108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162956, 11553, 'Meu Casamento Feliz [L] S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/705109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162957, 11553, 'Meu Casamento Feliz [L] S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/705110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162958, 11553, 'Meu Casamento Feliz [L] S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/723169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162959, 11553, 'Meu Casamento Feliz [L] S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/723170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162960, 11553, 'Meu Casamento Feliz [L] S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/723171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162961, 11553, 'Meu Casamento Feliz [L] S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/723172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162962, 11553, 'Meu Casamento Feliz [L] S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/723173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162963, 11553, 'Meu Casamento Feliz [L] S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/723174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162964, 11553, 'Meu Casamento Feliz [L] S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/723175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162965, 11553, 'Meu Casamento Feliz [L] S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/723176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162966, 11553, 'Meu Casamento Feliz [L] S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/723177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162967, 11553, 'Meu Casamento Feliz [L] S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/723178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162968, 11553, 'Meu Casamento Feliz [L] S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/723179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162969, 11553, 'Meu Casamento Feliz [L] S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/723180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162970, 11553, 'Meu Casamento Feliz [L] S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/723181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162971, 11553, 'Meu Casamento Feliz [L] S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/723182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162972, 11553, 'Meu Casamento Feliz [L] S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/751671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162973, 11553, 'Meu Casamento Feliz [L] S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/751672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162974, 11553, 'Meu Casamento Feliz [L] S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/751673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162975, 11553, 'Meu Casamento Feliz [L] S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/751674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162976, 11553, 'Meu Casamento Feliz [L] S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/751675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162977, 11553, 'Meu Casamento Feliz [L] S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/751676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162978, 11553, 'Meu Casamento Feliz [L] S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/751677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162979, 11553, 'Meu Casamento Feliz [L] S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/751678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162980, 11553, 'Meu Casamento Feliz [L] S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/751679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162981, 11553, 'Meu Casamento Feliz [L] S01 E119', 'http://sinalprivado.info:80/series/1533784/1533784/751680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162982, 11553, 'Meu Casamento Feliz [L] S01 E120', 'http://sinalprivado.info:80/series/1533784/1533784/774678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162983, 11553, 'Meu Casamento Feliz [L] S01 E121', 'http://sinalprivado.info:80/series/1533784/1533784/774679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162984, 11553, 'Meu Casamento Feliz [L] S01 E122', 'http://sinalprivado.info:80/series/1533784/1533784/774680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162985, 11553, 'Meu Casamento Feliz [L] S01 E123', 'http://sinalprivado.info:80/series/1533784/1533784/774681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162986, 11553, 'Meu Casamento Feliz [L] S01 E124', 'http://sinalprivado.info:80/series/1533784/1533784/774682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162987, 11553, 'Meu Casamento Feliz [L] S01 E125', 'http://sinalprivado.info:80/series/1533784/1533784/774683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWbIqQm9639XjkPzQXxo9sNIapy.jpg'),
(162988, 11554, 'Negative Positive Angler [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486551.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hjYpOZDBcDY7g9Eg3LgCavuVfVm.jpg'),
(162989, 11554, 'Negative Positive Angler [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486552.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sb4wAftU5bnOd0jt89MANauKFm2.jpg'),
(162990, 11554, 'Negative Positive Angler [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486553.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1p4f57FrAowXNicxp5MKQeK3JY2.jpg'),
(162991, 11554, 'Negative Positive Angler [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/513325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/50YOJIJvCnTrohnMi1flWZIiGNt.jpg'),
(162992, 11554, 'Negative Positive Angler [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/513326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/50YOJIJvCnTrohnMi1flWZIiGNt.jpg'),
(162993, 11554, 'Negative Positive Angler [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/513327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/50YOJIJvCnTrohnMi1flWZIiGNt.jpg'),
(162994, 11554, 'Negative Positive Angler [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/513328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/50YOJIJvCnTrohnMi1flWZIiGNt.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(162995, 11554, 'Negative Positive Angler [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/513329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/50YOJIJvCnTrohnMi1flWZIiGNt.jpg'),
(162996, 11554, 'Negative Positive Angler [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/515420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/50YOJIJvCnTrohnMi1flWZIiGNt.jpg'),
(162997, 11554, 'Negative Positive Angler [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/517814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/50YOJIJvCnTrohnMi1flWZIiGNt.jpg'),
(162998, 11554, 'Negative Positive Angler [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/523311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/50YOJIJvCnTrohnMi1flWZIiGNt.jpg'),
(162999, 11554, 'Negative Positive Angler [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/639103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/50YOJIJvCnTrohnMi1flWZIiGNt.jpg'),
(163000, 11555, 'O Castelo de Takeshi Japao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486543.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dtMndgru6qTAIrQVWoFtI7F7xR8.jpg'),
(163001, 11555, 'O Castelo de Takeshi Japao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486544.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6Ut4nHHtr1JYyy1aXkI9e1ishgL.jpg'),
(163002, 11555, 'O Castelo de Takeshi Japao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486545.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oubirAcoGgVufPhZfsa1RUjpc1z.jpg'),
(163003, 11555, 'O Castelo de Takeshi Japao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486546.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w6HTiPr10qG1sZ7AZ4H6Z8T2vel.jpg'),
(163004, 11555, 'O Castelo de Takeshi Japao [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486547.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/taevvYHVhoCPBOGhnjwQoS6KNhK.jpg'),
(163005, 11555, 'O Castelo de Takeshi Japao [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486548.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cQlPMIxH2yP8nU1gaRJLpRcyNSq.jpg'),
(163006, 11555, 'O Castelo de Takeshi Japao [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486549.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tDxe7XRySadx2tF4NQQdX3EzM41.jpg'),
(163007, 11555, 'O Castelo de Takeshi Japao [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486550.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8D3BGgNvUiuOZ3dStmREPLLnE5X.jpg'),
(163008, 11556, 'Only Boo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486531.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a59GLDZPbQcd327G2fEhHnxqR3I.jpg'),
(163009, 11556, 'Only Boo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486532.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u8kaE33DOgAqTj04IKXsuPgNsn0.jpg'),
(163010, 11556, 'Only Boo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486533.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j3HgA5MPqj6C7EOR8RH5tQ4sjMM.jpg'),
(163011, 11556, 'Only Boo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486534.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rzXvLh6cnfjskLYnm7FNWeUlIzq.jpg'),
(163012, 11556, 'Only Boo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486535.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pnaHtr6sjLIKeXsUxdMWpT3rap5.jpg'),
(163013, 11556, 'Only Boo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486536.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5TgHWdknw6StpNUgr7muJMPikcq.jpg'),
(163014, 11556, 'Only Boo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486537.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wEIOxYxvCb5UFsu4D22gK2BL3lO.jpg'),
(163015, 11556, 'Only Boo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486538.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xn5tRiEnPelNlRd0h4seaMdwllq.jpg'),
(163016, 11556, 'Only Boo [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/486539.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ni2RoTOSj6IQIdkL9FTeebL9GY6.jpg'),
(163017, 11556, 'Only Boo [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/486540.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7B99SflvdHtc2GrXAxGohjyKlQU.jpg'),
(163018, 11556, 'Only Boo [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/486541.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qHzMh7bHMLhUsAkbF6SOjIdbVwb.jpg'),
(163019, 11556, 'Only Boo [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/486542.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1SEjlXmvoq09rzaD5OM1J6d0xlP.jpg'),
(163020, 11557, 'Orange Marmalade [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486519.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/64eiLFqydlGXYF0A4IQKMddUhlb.jpg'),
(163021, 11557, 'Orange Marmalade [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486520.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yWHgZc5zlMnDyWQzSMcqMYg16Fu.jpg'),
(163022, 11557, 'Orange Marmalade [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486521.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kUJWCnhpi4XyERJZPGmelDDtKLY.jpg'),
(163023, 11557, 'Orange Marmalade [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486522.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sSXyA9z55fUn1LSfCDKeuEVXFQv.jpg'),
(163024, 11557, 'Orange Marmalade [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486523.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uWTA5f5OeJ6HqE6HxFnafnRtagH.jpg'),
(163025, 11557, 'Orange Marmalade [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486524.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d1f5lk1i4CDGpD6J5VDMUlyZumR.jpg'),
(163026, 11557, 'Orange Marmalade [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486525.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tWo7yyCus0yTZcw6uKYFUVRqeLt.jpg'),
(163027, 11557, 'Orange Marmalade [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486526.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/loXT3Yq661lsMXK6xkOOBc8N181.jpg'),
(163028, 11557, 'Orange Marmalade [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/486527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdzZQ3hLUdLfDz6Y5fYyaMzZI9N.jpg'),
(163029, 11557, 'Orange Marmalade [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/486528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdzZQ3hLUdLfDz6Y5fYyaMzZI9N.jpg'),
(163030, 11557, 'Orange Marmalade [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/486529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdzZQ3hLUdLfDz6Y5fYyaMzZI9N.jpg'),
(163031, 11557, 'Orange Marmalade [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/486530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kdzZQ3hLUdLfDz6Y5fYyaMzZI9N.jpg'),
(163032, 11558, 'Os Desajustados de Seul [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486505.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rxJIi4jnH8PumGbDfyGl11cPvYC.jpg'),
(163033, 11558, 'Os Desajustados de Seul [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486506.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Agh5ryrMYXqbwFZXvy6WkHNWaQ7.jpg'),
(163034, 11558, 'Os Desajustados de Seul [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486507.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3peQpCP3WiJazrBqNVNwOkqeyuo.jpg'),
(163035, 11558, 'Os Desajustados de Seul [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486508.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dwTqvT0xpStjQYaAGG5dOHoMcXA.jpg'),
(163036, 11558, 'Os Desajustados de Seul [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486509.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/65oszAnl0x2WGA8wqRJWhVZU06v.jpg'),
(163037, 11558, 'Os Desajustados de Seul [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486510.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ijYxO64PcwDOiaDZIpfZh86CecJ.jpg'),
(163038, 11558, 'Os Desajustados de Seul [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486511.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/85qhCqAuNCtaV7B6Ojtu6tSPKqJ.jpg'),
(163039, 11558, 'Os Desajustados de Seul [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486512.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xGRAq5yz2wLAfVD20xCnrSdn6xh.jpg'),
(163040, 11558, 'Os Desajustados de Seul [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/486513.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mCE7QKxFkj2xnBpmpHqlwWXluky.jpg'),
(163041, 11558, 'Os Desajustados de Seul [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/486514.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7UPxrhaJCDgIusBC4sK6MzeXV2p.jpg'),
(163042, 11558, 'Os Desajustados de Seul [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/486515.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mXiJwMhdDcNM5NVE12UEaqKm8f7.jpg'),
(163043, 11558, 'Os Desajustados de Seul [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/486516.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wQmc2hkktFiasU6EvpmwXV1ejsR.jpg'),
(163044, 11558, 'Os Desajustados de Seul [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/486517.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1PSkAMwrRkNcTpj53217q99ddOf.jpg'),
(163045, 11558, 'Os Desajustados de Seul [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/486518.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4Ib12YzR74UEVSJqDkFUttiewGa.jpg'),
(163046, 11558, 'Os Desajustados de Seul [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/513310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ak9Jot1xhAyzMMuUxxEMMHxYirL.jpg'),
(163047, 11558, 'Os Desajustados de Seul [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/513311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ak9Jot1xhAyzMMuUxxEMMHxYirL.jpg'),
(163048, 11558, 'Os Desajustados de Seul [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/513312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ak9Jot1xhAyzMMuUxxEMMHxYirL.jpg'),
(163049, 11558, 'Os Desajustados de Seul [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/513313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ak9Jot1xhAyzMMuUxxEMMHxYirL.jpg'),
(163050, 11558, 'Os Desajustados de Seul [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/513314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ak9Jot1xhAyzMMuUxxEMMHxYirL.jpg'),
(163051, 11558, 'Os Desajustados de Seul [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/513315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Ak9Jot1xhAyzMMuUxxEMMHxYirL.jpg'),
(163052, 11559, 'Paris Has Fallen [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486500.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t4mOhF9S9GuvBlipTKhTHxfA4Ci.jpg'),
(163053, 11559, 'Paris Has Fallen [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486501.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fNOq9GXYDjoM2VyxjN8EKw6kq7q.jpg'),
(163054, 11559, 'Paris Has Fallen [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486502.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q1fOJ4CiZHxjIoxXjNgYzhsP5l4.jpg'),
(163055, 11559, 'Paris Has Fallen [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486503.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yevxg1SPNO5r8iUY0oF5GtZUA0H.jpg'),
(163056, 11559, 'Paris Has Fallen [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486504.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jmaEyE8UkHuwi1mZT4wgxp7lDE4.jpg'),
(163057, 11559, 'Paris Has Fallen [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/513293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ei1jnjJ154XN1E4q9JKEpuEImup.jpg'),
(163058, 11559, 'Paris Has Fallen [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/513294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ei1jnjJ154XN1E4q9JKEpuEImup.jpg'),
(163059, 11559, 'Paris Has Fallen [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/513295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ei1jnjJ154XN1E4q9JKEpuEImup.jpg'),
(163060, 11560, 'Romance Excentrico [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j76kcbugBcDLk7FvbVAK0sL0JPo.jpg'),
(163061, 11560, 'Romance Excentrico [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j76kcbugBcDLk7FvbVAK0sL0JPo.jpg'),
(163062, 11560, 'Romance Excentrico [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/512798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j76kcbugBcDLk7FvbVAK0sL0JPo.jpg'),
(163063, 11560, 'Romance Excentrico [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/512799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j76kcbugBcDLk7FvbVAK0sL0JPo.jpg'),
(163064, 11560, 'Romance Excentrico [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/512800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j76kcbugBcDLk7FvbVAK0sL0JPo.jpg'),
(163065, 11560, 'Romance Excentrico [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/512801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j76kcbugBcDLk7FvbVAK0sL0JPo.jpg'),
(163066, 11560, 'Romance Excentrico [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/512802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j76kcbugBcDLk7FvbVAK0sL0JPo.jpg'),
(163067, 11560, 'Romance Excentrico [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/512803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j76kcbugBcDLk7FvbVAK0sL0JPo.jpg'),
(163068, 11560, 'Romance Excentrico [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/512804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j76kcbugBcDLk7FvbVAK0sL0JPo.jpg'),
(163069, 11560, 'Romance Excentrico [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/512805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j76kcbugBcDLk7FvbVAK0sL0JPo.jpg'),
(163070, 11560, 'Romance Excentrico [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/512806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j76kcbugBcDLk7FvbVAK0sL0JPo.jpg'),
(163071, 11560, 'Romance Excentrico [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/512807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j76kcbugBcDLk7FvbVAK0sL0JPo.jpg'),
(163072, 11561, 'Sol do Mestre [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486481.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mcseASwsM5Pp4H9rYwlf5zTet1J.jpg'),
(163073, 11561, 'Sol do Mestre [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486482.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2uhwoqBmAEKgxjBbn14bjMMzByz.jpg'),
(163074, 11561, 'Sol do Mestre [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486483.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nX2miPneAuimu7UXhISRsqY5uIv.jpg'),
(163075, 11561, 'Sol do Mestre [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486484.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uL1x5NrX6RBjvTpTOM2RKJOJkPJ.jpg'),
(163076, 11561, 'Sol do Mestre [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486485.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fNJF5D7HS0ZMlDST4R3hkCXfpDj.jpg'),
(163077, 11561, 'Sol do Mestre [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486486.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7ZBrWWFEl7jn8MZXLwTMsqYEU4Y.jpg'),
(163078, 11561, 'Sol do Mestre [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486487.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xV4dOciIJObAXdftFlCmMMR1NB9.jpg'),
(163079, 11561, 'Sol do Mestre [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486488.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/59YBMdf8aHPkv0IMDtpjbfHXfkz.jpg'),
(163080, 11561, 'Sol do Mestre [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/486489.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5c1zBBueJsY4W2gz4UlFRnXkMyA.jpg'),
(163081, 11561, 'Sol do Mestre [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/486490.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Rc25xVwRHuS7fzlk2J7Lpfb1g6.jpg'),
(163082, 11561, 'Sol do Mestre [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/486491.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mkeSzZvHRpllJ79LgmUufrIGVhO.jpg'),
(163083, 11561, 'Sol do Mestre [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/486492.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1rYETCyc0quLomGvlMMWvRDIc3v.jpg'),
(163084, 11561, 'Sol do Mestre [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/486493.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eN3Vya08VL0oZgEvcXMbCfv4xR2.jpg'),
(163085, 11561, 'Sol do Mestre [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/486494.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jdzoHj3q5LCkSpVqAPI4BNiy6OA.jpg'),
(163086, 11561, 'Sol do Mestre [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/486495.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rTDffxY1aWe5kJ986aY0L4DtEj1.jpg'),
(163087, 11561, 'Sol do Mestre [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/486496.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8IgUYj4e85UVxDyFQG4APdIw0rr.jpg'),
(163088, 11561, 'Sol do Mestre [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/486497.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/anUCOQtarOqAAUl0X2svHrUE9Jw.jpg'),
(163089, 11562, 'Teacup [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486479.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tEJKmk58K9SHK2iwlCJ3SLhGsgX.jpg'),
(163090, 11562, 'Teacup [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486480.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1DAXKEVRUb2DfuUYAF3kV32a4NM.jpg'),
(163091, 11562, 'Teacup [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/512737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/emeFo6OW5tE0BISzx0HEdVqOOgG.jpg'),
(163092, 11562, 'Teacup [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/512738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/emeFo6OW5tE0BISzx0HEdVqOOgG.jpg'),
(163093, 11562, 'Teacup [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/512739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/emeFo6OW5tE0BISzx0HEdVqOOgG.jpg'),
(163094, 11562, 'Teacup [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/512740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/emeFo6OW5tE0BISzx0HEdVqOOgG.jpg'),
(163095, 11562, 'Teacup [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/512741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/emeFo6OW5tE0BISzx0HEdVqOOgG.jpg'),
(163096, 11562, 'Teacup [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/512742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/emeFo6OW5tE0BISzx0HEdVqOOgG.jpg'),
(163097, 11563, 'The Boy That Never Was [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486475.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hvrPhj0Y5NYQr2fyK4cYgaROJlI.jpg'),
(163098, 11563, 'The Boy That Never Was [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486476.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fpxJOYsttMsy4Thkl6qZwpbfTW5.jpg'),
(163099, 11563, 'The Boy That Never Was [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486477.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ia7vzCnn7EIuM0pf1LiDOU5B3vt.jpg'),
(163100, 11563, 'The Boy That Never Was [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486478.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7cKH5nLZXaNBVAibfWpisFdt7JL.jpg'),
(163101, 11564, 'The Titan Games [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486466.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/97uR2bXpgfR2jEzAr8sS9tjal37.jpg'),
(163102, 11564, 'The Titan Games [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486467.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gwAaKfYBfVhDrS1STzC7oluws40.jpg'),
(163103, 11564, 'The Titan Games [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486468.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3UqqZwMGMKBf247XpuCSaenZUfC.jpg'),
(163104, 11564, 'The Titan Games [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486469.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zq5dSfXs1VxnF6k89mmmZJos4S5.jpg'),
(163105, 11564, 'The Titan Games [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486470.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/umw2bZ6BGGYDs2ueIeqXEqLN3yF.jpg'),
(163106, 11564, 'The Titan Games [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486471.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aKxOL391Ljb9OmwZ4ASNhqEOwST.jpg'),
(163107, 11564, 'The Titan Games [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486472.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g5Q23WJT9f5VlapMJFQQvU61SHF.jpg'),
(163108, 11564, 'The Titan Games [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486473.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wnrtOki2t3EcU0jJKgxwHWeHDpJ.jpg'),
(163109, 11564, 'The Titan Games [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/486474.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mfvbTb0pajyYE9Nl0BHug9ZdVAX.jpg'),
(163110, 11565, 'Through the Darkness [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486454.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/etKXrUTggBZaoUwOWXRR8atPwzr.jpg'),
(163111, 11565, 'Through the Darkness [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486455.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cvqLZ7O5Hg6djrzI4hCT2Y2kEqq.jpg'),
(163112, 11565, 'Through the Darkness [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486456.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/voZG331wCUJNALbOBiy4nQx4pVk.jpg'),
(163113, 11565, 'Through the Darkness [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486457.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2ctJgFVtaYCb5N6p2wz4I3F8WHe.jpg'),
(163114, 11565, 'Through the Darkness [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486458.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1UEnW6EEKiVBMhFMUpTsxo9GMB0.jpg'),
(163115, 11565, 'Through the Darkness [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486459.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kXHEw1dASWRjfJpH8jfmwiaAJWD.jpg'),
(163116, 11565, 'Through the Darkness [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486460.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gmF3UkHkNw4Uu9l9xEW3CrcSGlO.jpg'),
(163117, 11565, 'Through the Darkness [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486461.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9k2CCdKdMgLewSFeYrNGy8wCso4.jpg'),
(163118, 11565, 'Through the Darkness [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/486462.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sutx7Fn2Pg1N6rsACcxJNeKBFSg.jpg'),
(163119, 11565, 'Through the Darkness [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/486463.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dH3XAQxTjbn0yKQRlxJFnMeuJtB.jpg'),
(163120, 11565, 'Through the Darkness [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/486464.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b2PgNm8vcfZCcKBscE4gYOf7r5n.jpg'),
(163121, 11565, 'Through the Darkness [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/486465.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j8Mmcj17k6C4RONbolJ0dwx6FCu.jpg'),
(163122, 11566, 'Uzumaki [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486450.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hcaHxeAVPqc8IJvIpBGVImkvEyH.jpg'),
(163123, 11566, 'Uzumaki [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486451.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j4q1Oxyslpap1aldbk8vYgPvuEM.jpg'),
(163124, 11566, 'Uzumaki [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486452.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5UwM7OhQgFcWJtAe0p0CKeWwQ8a.jpg'),
(163125, 11566, 'Uzumaki [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486453.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/me5QUo9p1iP3fa6d0hMR8XTqUJ9.jpg'),
(163126, 11567, 'Voltando por Voce [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486444.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x9FO4n0fUefP1oaQWtUNtOvwqfF.jpg'),
(163127, 11567, 'Voltando por Voce [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486445.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/danK7SPwVIsJP39JPMRy3acNMVR.jpg'),
(163128, 11567, 'Voltando por Voce [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486446.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a36ykaUoDA75TIHR4COcm5dbecC.jpg'),
(163129, 11567, 'Voltando por Voce [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486447.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a9zE5fexN4pIk93I8EMVXmAf2EA.jpg'),
(163130, 11567, 'Voltando por Voce [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486448.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kzD8K696XPxxPSwCYwSp9YMISJE.jpg'),
(163131, 11567, 'Voltando por Voce [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486449.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h3y0b5wkhtCDmPrA7pkwwc9g1SB.jpg'),
(163132, 11567, 'Voltando por Voce [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/510967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPvtN63xZwAxTkLx7feUooA8HYe.jpg'),
(163133, 11567, 'Voltando por Voce [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/510968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oPvtN63xZwAxTkLx7feUooA8HYe.jpg'),
(163134, 11568, 'Casas na Arvore S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163135, 11568, 'Casas na Arvore S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163136, 11568, 'Casas na Arvore S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163137, 11568, 'Casas na Arvore S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163138, 11568, 'Casas na Arvore S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163139, 11568, 'Casas na Arvore S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163140, 11568, 'Casas na Arvore S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163141, 11568, 'Casas na Arvore S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163142, 11569, 'Casas na Arvore S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486359.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qaFu3S5dttcWHt3glht5oTaF6PR.jpg'),
(163143, 11569, 'Casas na Arvore S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486360.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f9x0StOpCuemoeYnlP2XbpQGNHb.jpg'),
(163144, 11569, 'Casas na Arvore S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486361.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wiyIfONvTW9zahiEm5d9lOCsPCt.jpg'),
(163145, 11569, 'Casas na Arvore S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486362.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5TdMruRr3lu232EpxetSsbcfJnV.jpg'),
(163146, 11569, 'Casas na Arvore S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486363.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/89TJvNSaraJTxwOraY7wo8svjSd.jpg'),
(163147, 11569, 'Casas na Arvore S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486364.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1pmkieSozsrEdgYZtYFJSZy0HdT.jpg'),
(163148, 11569, 'Casas na Arvore S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163149, 11569, 'Casas na Arvore S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163150, 11569, 'Casas na Arvore S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/486367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163151, 11569, 'Casas na Arvore S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/486368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163152, 11570, 'Casas na Arvore S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486369.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h5wqfZB0mQBrntEGbLX63Kxc4eI.jpg'),
(163153, 11570, 'Casas na Arvore S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486370.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9fhGb0bl5R1CrRgp2FxNiwEUxpP.jpg'),
(163154, 11570, 'Casas na Arvore S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486371.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iCdpZb6I43M0Hp9DIM5O5tOIJxx.jpg'),
(163155, 11570, 'Casas na Arvore S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163156, 11570, 'Casas na Arvore S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163157, 11570, 'Casas na Arvore S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486374.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rCHQjZL4l9W8xB1EQ1rErXaTXnQ.jpg'),
(163158, 11570, 'Casas na Arvore S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163159, 11571, 'Casas na Arvore S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163160, 11571, 'Casas na Arvore S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163161, 11571, 'Casas na Arvore S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163162, 11571, 'Casas na Arvore S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163163, 11571, 'Casas na Arvore S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163164, 11571, 'Casas na Arvore S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163165, 11571, 'Casas na Arvore S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163166, 11571, 'Casas na Arvore S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163167, 11571, 'Casas na Arvore S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/486384.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fmsm9VcC85GHSCvSTNR1TV92gIy.jpg'),
(163168, 11571, 'Casas na Arvore S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/486385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163169, 11572, 'Casas na Arvore S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486386.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y2SCpjxT4y11LUQcVKxNpPGh50b.jpg'),
(163170, 11572, 'Casas na Arvore S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486387.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/UqIJW7lH0qS4mCYcE6gF4fARuT.jpg'),
(163171, 11572, 'Casas na Arvore S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486388.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bfzmhs3sAXaRcCQ4uxB0WL0Ka5Y.jpg'),
(163172, 11572, 'Casas na Arvore S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486389.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cTkICHIuNxg4DgoR5AhqszyCa9a.jpg'),
(163173, 11572, 'Casas na Arvore S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486390.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yqiW8vocqjIV6rJP39i1taZ127F.jpg'),
(163174, 11573, 'Casas na Arvore S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163175, 11573, 'Casas na Arvore S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486392.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uH8qgMY3OI4S9poVE3Vsq0hymZr.jpg'),
(163176, 11573, 'Casas na Arvore S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486393.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kRMPnvRbh1brqL2Doof1SJB3S06.jpg'),
(163177, 11573, 'Casas na Arvore S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163178, 11573, 'Casas na Arvore S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163179, 11573, 'Casas na Arvore S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163180, 11573, 'Casas na Arvore S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163181, 11573, 'Casas na Arvore S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163182, 11573, 'Casas na Arvore S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/486399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163183, 11574, 'Casas na Arvore S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163184, 11574, 'Casas na Arvore S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163185, 11574, 'Casas na Arvore S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163186, 11574, 'Casas na Arvore S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163187, 11574, 'Casas na Arvore S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163188, 11574, 'Casas na Arvore S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163189, 11574, 'Casas na Arvore S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163190, 11574, 'Casas na Arvore S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163191, 11574, 'Casas na Arvore S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/486408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163192, 11574, 'Casas na Arvore S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/486409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163193, 11575, 'Casas na Arvore S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163194, 11575, 'Casas na Arvore S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163195, 11575, 'Casas na Arvore S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163196, 11575, 'Casas na Arvore S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163197, 11576, 'Casas na Arvore S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163198, 11576, 'Casas na Arvore S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163199, 11576, 'Casas na Arvore S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163200, 11576, 'Casas na Arvore S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163201, 11576, 'Casas na Arvore S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163202, 11576, 'Casas na Arvore S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163203, 11576, 'Casas na Arvore S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163204, 11576, 'Casas na Arvore S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163205, 11576, 'Casas na Arvore S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/486422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163206, 11576, 'Casas na Arvore S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/486423.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e6RqULaJ4njgiMPF8E6m5kuvQy7.jpg'),
(163207, 11577, 'Casas na Arvore S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163208, 11577, 'Casas na Arvore S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163209, 11577, 'Casas na Arvore S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163210, 11577, 'Casas na Arvore S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163211, 11577, 'Casas na Arvore S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163212, 11577, 'Casas na Arvore S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163213, 11577, 'Casas na Arvore S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163214, 11577, 'Casas na Arvore S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163215, 11577, 'Casas na Arvore S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/486432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163216, 11578, 'Casas na Arvore S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/486433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163217, 11578, 'Casas na Arvore S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/486434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163218, 11578, 'Casas na Arvore S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/486435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163219, 11578, 'Casas na Arvore S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/486436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163220, 11578, 'Casas na Arvore S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/486437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163221, 11578, 'Casas na Arvore S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/486438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163222, 11578, 'Casas na Arvore S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/486439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163223, 11578, 'Casas na Arvore S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/486440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163224, 11578, 'Casas na Arvore S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/486441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163225, 11578, 'Casas na Arvore S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/486442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163226, 11578, 'Casas na Arvore S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/486443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pkqJxkQTtsh7yIVke2LL4Ei63Lk.jpg'),
(163227, 11579, 'Aile Lacos de Paixao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/489331.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4SYQksSkeKSWzVQ7UYasN4j4fsd.jpg'),
(163228, 11579, 'Aile Lacos de Paixao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/489332.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vDapRNiK5zGnBh4efLgrQohAxbx.jpg'),
(163229, 11579, 'Aile Lacos de Paixao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/489333.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vN5ywDyrEWu9jyR54tDGbDYKWTX.jpg'),
(163230, 11579, 'Aile Lacos de Paixao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/489334.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lkPF8V2Vo4nPlW5IxqABREQa0qf.jpg'),
(163231, 11579, 'Aile Lacos de Paixao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/489335.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sU0i2AxSxuvQKStut2fqXEw3773.jpg'),
(163232, 11579, 'Aile Lacos de Paixao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/489336.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f0UarZ6dVQt8Qer1sQHHO9Kb4zB.jpg'),
(163233, 11579, 'Aile Lacos de Paixao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/489337.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/onLhPZ5E6ISOMic2V3AGmh9o3UC.jpg'),
(163234, 11579, 'Aile Lacos de Paixao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/489338.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7CbVz0qRoVXrdEVOXwslYnnW6lI.jpg'),
(163235, 11579, 'Aile Lacos de Paixao S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/489339.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yF0T5dOhYhLWB8E7LhrWHFhm4Yx.jpg'),
(163236, 11579, 'Aile Lacos de Paixao S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/493961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163237, 11579, 'Aile Lacos de Paixao S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/510181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163238, 11579, 'Aile Lacos de Paixao S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/510182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163239, 11579, 'Aile Lacos de Paixao S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/510183.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163240, 11579, 'Aile Lacos de Paixao S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/510184.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163241, 11579, 'Aile Lacos de Paixao S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/510185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163242, 11579, 'Aile Lacos de Paixao S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/510186.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163243, 11579, 'Aile Lacos de Paixao S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/510187.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163244, 11579, 'Aile Lacos de Paixao S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/510188.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163245, 11579, 'Aile Lacos de Paixao S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/510189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163246, 11579, 'Aile Lacos de Paixao S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/510190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163247, 11579, 'Aile Lacos de Paixao S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/510191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163248, 11579, 'Aile Lacos de Paixao S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/510192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163249, 11579, 'Aile Lacos de Paixao S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/510193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163250, 11579, 'Aile Lacos de Paixao S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/510194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163251, 11579, 'Aile Lacos de Paixao S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/510195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(163252, 11579, 'Aile Lacos de Paixao S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/510196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163253, 11579, 'Aile Lacos de Paixao S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/510197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163254, 11579, 'Aile Lacos de Paixao S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/510198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163255, 11579, 'Aile Lacos de Paixao S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/510199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163256, 11579, 'Aile Lacos de Paixao S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/510200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163257, 11579, 'Aile Lacos de Paixao S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/510201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163258, 11579, 'Aile Lacos de Paixao S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/510202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163259, 11579, 'Aile Lacos de Paixao S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/510203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163260, 11579, 'Aile Lacos de Paixao S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/510204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163261, 11579, 'Aile Lacos de Paixao S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/510205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163262, 11579, 'Aile Lacos de Paixao S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/510206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163263, 11579, 'Aile Lacos de Paixao S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/510208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163264, 11579, 'Aile Lacos de Paixao S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/510209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163265, 11579, 'Aile Lacos de Paixao S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/510210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163266, 11580, 'Aile Lacos de Paixao S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/642114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163267, 11580, 'Aile Lacos de Paixao S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/642115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163268, 11580, 'Aile Lacos de Paixao S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/642116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163269, 11580, 'Aile Lacos de Paixao S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/642117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163270, 11580, 'Aile Lacos de Paixao S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/642118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163271, 11580, 'Aile Lacos de Paixao S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/642119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163272, 11580, 'Aile Lacos de Paixao S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/642120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163273, 11580, 'Aile Lacos de Paixao S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/642121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163274, 11580, 'Aile Lacos de Paixao S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/642122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163275, 11580, 'Aile Lacos de Paixao S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/642123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163276, 11580, 'Aile Lacos de Paixao S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/642124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163277, 11580, 'Aile Lacos de Paixao S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/642125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163278, 11580, 'Aile Lacos de Paixao S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/642126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163279, 11580, 'Aile Lacos de Paixao S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/642127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163280, 11580, 'Aile Lacos de Paixao S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/642128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163281, 11580, 'Aile Lacos de Paixao S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/642129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163282, 11580, 'Aile Lacos de Paixao S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/642130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163283, 11580, 'Aile Lacos de Paixao S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/642131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163284, 11580, 'Aile Lacos de Paixao S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/642132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163285, 11580, 'Aile Lacos de Paixao S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/642133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163286, 11580, 'Aile Lacos de Paixao S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/642134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163287, 11580, 'Aile Lacos de Paixao S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/642135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163288, 11580, 'Aile Lacos de Paixao S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/642136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163289, 11580, 'Aile Lacos de Paixao S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/642137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163290, 11580, 'Aile Lacos de Paixao S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/642138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163291, 11580, 'Aile Lacos de Paixao S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/642139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163292, 11580, 'Aile Lacos de Paixao S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/642140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163293, 11580, 'Aile Lacos de Paixao S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/642141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163294, 11580, 'Aile Lacos de Paixao S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/642142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163295, 11580, 'Aile Lacos de Paixao S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/642143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163296, 11580, 'Aile Lacos de Paixao S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/642144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163297, 11580, 'Aile Lacos de Paixao S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/642145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163298, 11580, 'Aile Lacos de Paixao S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/642146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163299, 11580, 'Aile Lacos de Paixao S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/642147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163300, 11580, 'Aile Lacos de Paixao S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/642148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163301, 11580, 'Aile Lacos de Paixao S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/642149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163302, 11580, 'Aile Lacos de Paixao S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/642150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163303, 11580, 'Aile Lacos de Paixao S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/642151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163304, 11580, 'Aile Lacos de Paixao S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/642152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163305, 11580, 'Aile Lacos de Paixao S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/642153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163306, 11580, 'Aile Lacos de Paixao S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/642154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163307, 11580, 'Aile Lacos de Paixao S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/642155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163308, 11580, 'Aile Lacos de Paixao S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/642156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163309, 11580, 'Aile Lacos de Paixao S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/642157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163310, 11580, 'Aile Lacos de Paixao S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/642158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163311, 11580, 'Aile Lacos de Paixao S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/642159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163312, 11580, 'Aile Lacos de Paixao S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/642160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163313, 11580, 'Aile Lacos de Paixao S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/642161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163314, 11580, 'Aile Lacos de Paixao S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/642162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163315, 11580, 'Aile Lacos de Paixao S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/642163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163316, 11580, 'Aile Lacos de Paixao S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/642164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163317, 11580, 'Aile Lacos de Paixao S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/642165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163318, 11580, 'Aile Lacos de Paixao S02 E53', 'http://sinalprivado.info:80/series/1533784/1533784/642166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163319, 11580, 'Aile Lacos de Paixao S02 E54', 'http://sinalprivado.info:80/series/1533784/1533784/642167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163320, 11580, 'Aile Lacos de Paixao S02 E55', 'http://sinalprivado.info:80/series/1533784/1533784/642168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vXrmNsArQGFPLgDSZCPcDUvX6kp.jpg'),
(163321, 11581, 'Aqui Quem Fala e o Zodiaco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/489328.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fuzdGFJaD684AZqGEEu7ASka9Wd.jpg'),
(163322, 11581, 'Aqui Quem Fala e o Zodiaco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/489329.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rBroBgoWrKNRPGTVMkJX4xRiJtL.jpg'),
(163323, 11581, 'Aqui Quem Fala e o Zodiaco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/489330.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3gWi7WX0ZcbLB64tnAlOlcIPeQI.jpg'),
(163324, 11582, 'Beauty in Black S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/489320.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gKUUmjd0bZyxV9BAIdvFhrz1lY5.jpg'),
(163325, 11582, 'Beauty in Black S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/489321.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4syKOE2xASycSauPa8t9qsISVeR.jpg'),
(163326, 11582, 'Beauty in Black S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/489322.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jqZYDxOAfHXkclsO12KdSvPtahz.jpg'),
(163327, 11582, 'Beauty in Black S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/489323.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wFqaQzbOuVJVA25GKM28DX5tTDM.jpg'),
(163328, 11582, 'Beauty in Black S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/489324.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uhWj5RRPuoZySwOQGZG3g4i6fGe.jpg'),
(163329, 11582, 'Beauty in Black S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/489325.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lOzYIeXZTOOjTvtnYv1P3hhaCDw.jpg'),
(163330, 11582, 'Beauty in Black S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/489326.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gkAojWvXFRAPGXl2WEt36wxOLtC.jpg'),
(163331, 11582, 'Beauty in Black S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/489327.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tLoZBCmqvXqgdOGF4DvSVfWYizb.jpg'),
(163332, 11582, 'Beauty in Black S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/719129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i98Jl46WBpK7ymttNOakowtNuFF.jpg'),
(163333, 11582, 'Beauty in Black S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/719130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i98Jl46WBpK7ymttNOakowtNuFF.jpg'),
(163334, 11582, 'Beauty in Black S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/719131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i98Jl46WBpK7ymttNOakowtNuFF.jpg'),
(163335, 11582, 'Beauty in Black S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/719132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i98Jl46WBpK7ymttNOakowtNuFF.jpg'),
(163336, 11582, 'Beauty in Black S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/719133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i98Jl46WBpK7ymttNOakowtNuFF.jpg'),
(163337, 11582, 'Beauty in Black S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/719134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i98Jl46WBpK7ymttNOakowtNuFF.jpg'),
(163338, 11582, 'Beauty in Black S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/719135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i98Jl46WBpK7ymttNOakowtNuFF.jpg'),
(163339, 11582, 'Beauty in Black S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/719136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i98Jl46WBpK7ymttNOakowtNuFF.jpg'),
(163340, 11583, 'Beauty in Black S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/885173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i98Jl46WBpK7ymttNOakowtNuFF.jpg'),
(163341, 11583, 'Beauty in Black S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/885174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i98Jl46WBpK7ymttNOakowtNuFF.jpg'),
(163342, 11583, 'Beauty in Black S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/885175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i98Jl46WBpK7ymttNOakowtNuFF.jpg'),
(163343, 11583, 'Beauty in Black S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/885176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i98Jl46WBpK7ymttNOakowtNuFF.jpg'),
(163344, 11583, 'Beauty in Black S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/885177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i98Jl46WBpK7ymttNOakowtNuFF.jpg'),
(163345, 11583, 'Beauty in Black S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/885178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i98Jl46WBpK7ymttNOakowtNuFF.jpg'),
(163346, 11583, 'Beauty in Black S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/885179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i98Jl46WBpK7ymttNOakowtNuFF.jpg'),
(163347, 11583, 'Beauty in Black S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/885180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i98Jl46WBpK7ymttNOakowtNuFF.jpg'),
(163348, 11584, 'Chitaozinho e Xororo Uma Historia de Sucesso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/489315.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/90qGafPwlPJm7cSDJbdnS2MFFzc.jpg'),
(163349, 11584, 'Chitaozinho e Xororo Uma Historia de Sucesso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/489316.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u9RrLYS5sUVtGvOXBMWiSlZiBRo.jpg'),
(163350, 11584, 'Chitaozinho e Xororo Uma Historia de Sucesso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/489317.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sI7i47rJJaUXVwq98biDBLeLP4i.jpg'),
(163351, 11584, 'Chitaozinho e Xororo Uma Historia de Sucesso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/489318.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fKTylPXifMlK5WP16uQADmBXVvX.jpg'),
(163352, 11584, 'Chitaozinho e Xororo Uma Historia de Sucesso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/489319.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t1oJwRV7Tfna6tBc7PfMdwcJzNI.jpg'),
(163353, 11585, 'Ed Stafford Vida de Cigano S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/489313.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uNLbwOlR4ii1TRe3gSOnwVBVMXL.jpg'),
(163354, 11585, 'Ed Stafford Vida de Cigano S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/489314.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gUHmgrxvJoJG4PXv1tMT2Cr7Pbu.jpg'),
(163355, 11586, 'Eu e Mickey S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/489247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163356, 11586, 'Eu e Mickey S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/489248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163357, 11586, 'Eu e Mickey S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/489249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163358, 11586, 'Eu e Mickey S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/489250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163359, 11586, 'Eu e Mickey S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/489251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163360, 11586, 'Eu e Mickey S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/489252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163361, 11586, 'Eu e Mickey S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/489253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163362, 11586, 'Eu e Mickey S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/489254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163363, 11586, 'Eu e Mickey S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/489255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163364, 11586, 'Eu e Mickey S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/489256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163365, 11586, 'Eu e Mickey S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/489257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163366, 11586, 'Eu e Mickey S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/489258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163367, 11586, 'Eu e Mickey S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/489259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163368, 11586, 'Eu e Mickey S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/489260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163369, 11586, 'Eu e Mickey S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/489261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163370, 11586, 'Eu e Mickey S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/489262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163371, 11586, 'Eu e Mickey S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/489263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163372, 11586, 'Eu e Mickey S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/489264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163373, 11586, 'Eu e Mickey S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/489265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163374, 11586, 'Eu e Mickey S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/489266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163375, 11586, 'Eu e Mickey S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/489267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163376, 11586, 'Eu e Mickey S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/489268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163377, 11586, 'Eu e Mickey S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/489269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163378, 11586, 'Eu e Mickey S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/489270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163379, 11586, 'Eu e Mickey S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/489271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163380, 11586, 'Eu e Mickey S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/489272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163381, 11586, 'Eu e Mickey S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/489273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163382, 11586, 'Eu e Mickey S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/489274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163383, 11586, 'Eu e Mickey S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/489275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163384, 11586, 'Eu e Mickey S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/489276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163385, 11586, 'Eu e Mickey S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/489277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163386, 11586, 'Eu e Mickey S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/489278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163387, 11586, 'Eu e Mickey S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/489279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163388, 11586, 'Eu e Mickey S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/489280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163389, 11586, 'Eu e Mickey S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/489281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163390, 11586, 'Eu e Mickey S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/489282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163391, 11586, 'Eu e Mickey S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/489283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163392, 11586, 'Eu e Mickey S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/489284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163393, 11586, 'Eu e Mickey S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/489285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163394, 11586, 'Eu e Mickey S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/489286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163395, 11587, 'Eu e Mickey S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/489287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163396, 11587, 'Eu e Mickey S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/489288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163397, 11587, 'Eu e Mickey S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/489289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163398, 11587, 'Eu e Mickey S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/489290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163399, 11587, 'Eu e Mickey S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/489291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163400, 11587, 'Eu e Mickey S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/489292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163401, 11587, 'Eu e Mickey S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/489293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163402, 11587, 'Eu e Mickey S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/489294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163403, 11587, 'Eu e Mickey S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/489295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163404, 11587, 'Eu e Mickey S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/489296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163405, 11587, 'Eu e Mickey S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/489297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163406, 11587, 'Eu e Mickey S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/489298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163407, 11587, 'Eu e Mickey S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/489299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163408, 11587, 'Eu e Mickey S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/489300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163409, 11587, 'Eu e Mickey S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/489301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163410, 11587, 'Eu e Mickey S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/489302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163411, 11587, 'Eu e Mickey S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/489303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163412, 11587, 'Eu e Mickey S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/489304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163413, 11587, 'Eu e Mickey S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/489305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163414, 11587, 'Eu e Mickey S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/489306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163415, 11587, 'Eu e Mickey S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/489307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163416, 11587, 'Eu e Mickey S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/489308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163417, 11587, 'Eu e Mickey S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/489309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163418, 11587, 'Eu e Mickey S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/489310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163419, 11587, 'Eu e Mickey S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/489311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163420, 11587, 'Eu e Mickey S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/489312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163421, 11587, 'Eu e Mickey S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/506223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163422, 11587, 'Eu e Mickey S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/506224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163423, 11587, 'Eu e Mickey S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/506225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163424, 11587, 'Eu e Mickey S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/506226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163425, 11587, 'Eu e Mickey S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/506227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163426, 11587, 'Eu e Mickey S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/506228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163427, 11587, 'Eu e Mickey S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/506229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163428, 11587, 'Eu e Mickey S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/506230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163429, 11587, 'Eu e Mickey S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/506231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163430, 11587, 'Eu e Mickey S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/506232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163431, 11587, 'Eu e Mickey S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/506233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163432, 11587, 'Eu e Mickey S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/506234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zcJmZG4RV1eiRuCb5RpUAAvJksf.jpg'),
(163433, 11588, 'Like a Dragon Yakuza S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/489244.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9JWwqv9vlBAYRnSZdeh6SoOz3HU.jpg'),
(163434, 11588, 'Like a Dragon Yakuza S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/489245.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/26DHlLKvl3tQl7zrmlX3iVmfjPF.jpg'),
(163435, 11588, 'Like a Dragon Yakuza S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/489246.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jg9ygZzdh5dGWGmkMjubREO5PGo.jpg'),
(163436, 11588, 'Like a Dragon Yakuza S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/492564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69cNeUKYUFSQ4f4uqR1NssUQzlm.jpg'),
(163437, 11588, 'Like a Dragon Yakuza S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/492565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69cNeUKYUFSQ4f4uqR1NssUQzlm.jpg'),
(163438, 11588, 'Like a Dragon Yakuza S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/492566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/69cNeUKYUFSQ4f4uqR1NssUQzlm.jpg'),
(163439, 11589, 'NCIS Sydney S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/489243.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wAa07lZ9HKAswaEtTuRXvX4RPaQ.jpg'),
(163440, 11589, 'NCIS Sydney S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/492220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(163441, 11589, 'NCIS Sydney S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/499839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(163442, 11589, 'NCIS Sydney S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/505516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(163443, 11589, 'NCIS Sydney S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/509336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(163444, 11589, 'NCIS Sydney S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/515426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(163445, 11589, 'NCIS Sydney S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/523318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(163446, 11589, 'NCIS Sydney S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/523319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(163447, 11590, 'NCIS Sydney S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/774513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(163448, 11590, 'NCIS Sydney S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/784561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(163449, 11590, 'NCIS Sydney S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/793881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(163450, 11590, 'NCIS Sydney S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/805868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(163451, 11590, 'NCIS Sydney S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/805869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(163452, 11590, 'NCIS Sydney S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/809198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(163453, 11590, 'NCIS Sydney S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/880050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(163454, 11590, 'NCIS Sydney S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/880051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(163455, 11590, 'NCIS Sydney S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/880052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(163456, 11590, 'NCIS Sydney S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/880053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8wZng0c3GJEYcpW0DtVCzg7xlPO.jpg'),
(163457, 11591, 'Territory S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/489170.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x7pGZsdc5raEGZNfWNLKKfawQF3.jpg'),
(163458, 11591, 'Territory S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/489171.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n7YSjl8ZqVVBjwtSDrAV23lwUUU.jpg'),
(163459, 11591, 'Territory S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/489172.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z7fdnd45Pla7a2BJFUYZYmxZJFu.jpg'),
(163460, 11591, 'Territory S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/489173.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nnJ2d8CMaO1rqnKWWsYhxuMdrA8.jpg'),
(163461, 11591, 'Territory S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/489174.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uhZ7NBZPtriQqaE4jlMuJN2DUpz.jpg'),
(163462, 11591, 'Territory S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/489175.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t08GqgNmbJhaeZfFhYlJlPzihsJ.jpg'),
(163463, 11592, 'The Real Murders on Elm Street S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/489169.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ncONqdQpIPYHC9yYB9RavLNoNuP.jpg'),
(163464, 11592, 'The Real Murders on Elm Street S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/497773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fQChxafTVQeWQtfwW7M0GT85Mqc.jpg'),
(163465, 11592, 'The Real Murders on Elm Street S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/499612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fQChxafTVQeWQtfwW7M0GT85Mqc.jpg'),
(163466, 11592, 'The Real Murders on Elm Street S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/504580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fQChxafTVQeWQtfwW7M0GT85Mqc.jpg'),
(163467, 11592, 'The Real Murders on Elm Street S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/509178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fQChxafTVQeWQtfwW7M0GT85Mqc.jpg'),
(163468, 11592, 'The Real Murders on Elm Street S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/514884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fQChxafTVQeWQtfwW7M0GT85Mqc.jpg'),
(163469, 11593, 'The Real Murders on Elm Street S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/891004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fQChxafTVQeWQtfwW7M0GT85Mqc.jpg'),
(163470, 11593, 'The Real Murders on Elm Street S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/891992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fQChxafTVQeWQtfwW7M0GT85Mqc.jpg'),
(163471, 11593, 'The Real Murders on Elm Street S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/892412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fQChxafTVQeWQtfwW7M0GT85Mqc.jpg'),
(163472, 11593, 'The Real Murders on Elm Street S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/893340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fQChxafTVQeWQtfwW7M0GT85Mqc.jpg'),
(163473, 11593, 'The Real Murders on Elm Street S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/893560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fQChxafTVQeWQtfwW7M0GT85Mqc.jpg'),
(163474, 11593, 'The Real Murders on Elm Street S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/894197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fQChxafTVQeWQtfwW7M0GT85Mqc.jpg'),
(163475, 11594, 'Tributo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/489163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n8j2QvciBnz3rMKYQMXBfpkdb8l.jpg'),
(163476, 11594, 'Tributo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/489164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n8j2QvciBnz3rMKYQMXBfpkdb8l.jpg'),
(163477, 11594, 'Tributo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/489165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n8j2QvciBnz3rMKYQMXBfpkdb8l.jpg'),
(163478, 11594, 'Tributo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/489166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n8j2QvciBnz3rMKYQMXBfpkdb8l.jpg'),
(163479, 11594, 'Tributo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/489167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n8j2QvciBnz3rMKYQMXBfpkdb8l.jpg'),
(163480, 11594, 'Tributo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/489168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n8j2QvciBnz3rMKYQMXBfpkdb8l.jpg'),
(163481, 11594, 'Tributo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/493446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n8j2QvciBnz3rMKYQMXBfpkdb8l.jpg'),
(163482, 11594, 'Tributo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/667206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n8j2QvciBnz3rMKYQMXBfpkdb8l.jpg'),
(163483, 11594, 'Tributo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/667207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n8j2QvciBnz3rMKYQMXBfpkdb8l.jpg'),
(163484, 11595, 'Turma da Monica Origens S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/489155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWAp4fWpmCPbn95vTsDkuIQJHMC.jpg'),
(163485, 11595, 'Turma da Monica Origens S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/489156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWAp4fWpmCPbn95vTsDkuIQJHMC.jpg'),
(163486, 11595, 'Turma da Monica Origens S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/489157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWAp4fWpmCPbn95vTsDkuIQJHMC.jpg'),
(163487, 11595, 'Turma da Monica Origens S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/489158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWAp4fWpmCPbn95vTsDkuIQJHMC.jpg'),
(163488, 11595, 'Turma da Monica Origens S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/489159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWAp4fWpmCPbn95vTsDkuIQJHMC.jpg'),
(163489, 11595, 'Turma da Monica Origens S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/489160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWAp4fWpmCPbn95vTsDkuIQJHMC.jpg'),
(163490, 11595, 'Turma da Monica Origens S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/489161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWAp4fWpmCPbn95vTsDkuIQJHMC.jpg'),
(163491, 11595, 'Turma da Monica Origens S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/489162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gWAp4fWpmCPbn95vTsDkuIQJHMC.jpg'),
(163492, 11596, 'A Ultima Noite em Tremor S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/494305.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iENolDv2BAxhoZUliSLma3zWfg2.jpg'),
(163493, 11596, 'A Ultima Noite em Tremor S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/494306.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yXkc7M1Tf5t8gXcApskKBWcgg7i.jpg'),
(163494, 11596, 'A Ultima Noite em Tremor S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/494307.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jo4vu5SlKqoanSNmV0PoYnGzcFJ.jpg'),
(163495, 11596, 'A Ultima Noite em Tremor S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/494308.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m8MMKhGfXPQz6I0hdDd2FjXXiOH.jpg'),
(163496, 11596, 'A Ultima Noite em Tremor S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/494309.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/15AzePTpVGVgEmQmzgUzkwxt7aD.jpg'),
(163497, 11596, 'A Ultima Noite em Tremor S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/494310.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i2Ap9gpMpxS2RKAss2SKUQ4wFuJ.jpg'),
(163498, 11596, 'A Ultima Noite em Tremor S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/494311.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/scFVCNfIQ6L8A1EczO481oa3l3F.jpg'),
(163499, 11596, 'A Ultima Noite em Tremor S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/494312.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dmDp47pyI9YfyMoucKkMDcIGNp4.jpg'),
(163500, 11597, 'Ate Que o Design nos Separe S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/494303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fe3LZKJjElh6Iho1atz6TKWHVRo.jpg'),
(163501, 11597, 'Ate Que o Design nos Separe S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/497092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fe3LZKJjElh6Iho1atz6TKWHVRo.jpg'),
(163502, 11597, 'Ate Que o Design nos Separe S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/503777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fe3LZKJjElh6Iho1atz6TKWHVRo.jpg'),
(163503, 11597, 'Ate Que o Design nos Separe S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/503778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fe3LZKJjElh6Iho1atz6TKWHVRo.jpg'),
(163504, 11597, 'Ate Que o Design nos Separe S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/512543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fe3LZKJjElh6Iho1atz6TKWHVRo.jpg'),
(163505, 11597, 'Ate Que o Design nos Separe S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/839394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fe3LZKJjElh6Iho1atz6TKWHVRo.jpg'),
(163506, 11597, 'Ate Que o Design nos Separe S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/839395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fe3LZKJjElh6Iho1atz6TKWHVRo.jpg'),
(163507, 11597, 'Ate Que o Design nos Separe S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/839396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fe3LZKJjElh6Iho1atz6TKWHVRo.jpg'),
(163508, 11597, 'Ate Que o Design nos Separe S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/839397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fe3LZKJjElh6Iho1atz6TKWHVRo.jpg'),
(163509, 11598, 'Escandalo na Realeza S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/494300.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/DnOxCqQlWFIUvzUHwlzhHYMRPL.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(163510, 11598, 'Escandalo na Realeza S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/494301.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kfMng03BOfXEFg7EiFjyTqPnfDB.jpg'),
(163511, 11598, 'Escandalo na Realeza S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/494302.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4O9aNnczFZsIaD9F2UAFIvrw7yr.jpg'),
(163512, 11599, 'Minha Casa Frankenstein S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/494294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xnXZOthx5p9j2gTRiiNFL0Hn0nN.jpg'),
(163513, 11599, 'Minha Casa Frankenstein S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/494295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xnXZOthx5p9j2gTRiiNFL0Hn0nN.jpg'),
(163514, 11599, 'Minha Casa Frankenstein S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/494296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xnXZOthx5p9j2gTRiiNFL0Hn0nN.jpg'),
(163515, 11599, 'Minha Casa Frankenstein S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/494297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xnXZOthx5p9j2gTRiiNFL0Hn0nN.jpg'),
(163516, 11599, 'Minha Casa Frankenstein S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/496634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xnXZOthx5p9j2gTRiiNFL0Hn0nN.jpg'),
(163517, 11599, 'Minha Casa Frankenstein S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/496635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xnXZOthx5p9j2gTRiiNFL0Hn0nN.jpg'),
(163518, 11600, 'Passado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/491924.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t8cPbTKHRpIfNJ8VBZ5DZnHTnUX.jpg'),
(163519, 11600, 'Passado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/491925.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3VkVu8VkLGpcOQ54UkR2TWcuTfz.jpg'),
(163520, 11600, 'Passado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/491926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6rdAUVJDApKKihkrqIt6Vtkz938.jpg'),
(163521, 11600, 'Passado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/498917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6rdAUVJDApKKihkrqIt6Vtkz938.jpg'),
(163522, 11600, 'Passado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/505392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6rdAUVJDApKKihkrqIt6Vtkz938.jpg'),
(163523, 11600, 'Passado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/513287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6rdAUVJDApKKihkrqIt6Vtkz938.jpg'),
(163524, 11600, 'Passado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/515408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6rdAUVJDApKKihkrqIt6Vtkz938.jpg'),
(163525, 11600, 'Passado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/517588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6rdAUVJDApKKihkrqIt6Vtkz938.jpg'),
(163526, 11600, 'Passado S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/522411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6rdAUVJDApKKihkrqIt6Vtkz938.jpg'),
(163527, 11600, 'Passado S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/639074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6rdAUVJDApKKihkrqIt6Vtkz938.jpg'),
(163528, 11601, 'Sin City Tow S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/494292.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zZTDXFj8nmutPoKUBUwTjzup7SW.jpg'),
(163529, 11601, 'Sin City Tow S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/496291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xp9oZE9SMKsVeWoa26SGqsF5lIN.jpg'),
(163530, 11601, 'Sin City Tow S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/503692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xp9oZE9SMKsVeWoa26SGqsF5lIN.jpg'),
(163531, 11601, 'Sin City Tow S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/503693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xp9oZE9SMKsVeWoa26SGqsF5lIN.jpg'),
(163532, 11601, 'Sin City Tow S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/511153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xp9oZE9SMKsVeWoa26SGqsF5lIN.jpg'),
(163533, 11601, 'Sin City Tow S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/513978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xp9oZE9SMKsVeWoa26SGqsF5lIN.jpg'),
(163534, 11601, 'Sin City Tow S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/516990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xp9oZE9SMKsVeWoa26SGqsF5lIN.jpg'),
(163535, 11601, 'Sin City Tow S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xp9oZE9SMKsVeWoa26SGqsF5lIN.jpg'),
(163536, 11601, 'Sin City Tow S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/637899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xp9oZE9SMKsVeWoa26SGqsF5lIN.jpg'),
(163537, 11601, 'Sin City Tow S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/688317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xp9oZE9SMKsVeWoa26SGqsF5lIN.jpg'),
(163538, 11602, 'Abducao em Manhattan S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/493404.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w1hm1JWkbRKYyf8a1mKuuoutAil.jpg'),
(163539, 11602, 'Abducao em Manhattan S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/493405.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ftaYC06gPyr1jhHmH8opZmwKXY4.jpg'),
(163540, 11602, 'Abducao em Manhattan S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/493406.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1nUaaqQJUIkQ2ixi8YlKTCSF2Ay.jpg'),
(163541, 11603, 'Assassino Zen S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/493396.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/unyUVc5c9n13HD205u350KexKuG.jpg'),
(163542, 11603, 'Assassino Zen S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/493397.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xIRDlmzKpqEbFqQI2FFh70liiMG.jpg'),
(163543, 11603, 'Assassino Zen S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/493398.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hdRi91Y2MBcvJ2tny8VE2gPTaCe.jpg'),
(163544, 11603, 'Assassino Zen S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/493399.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4IlhjADvBvVx2Ws2YSZkkan8Nlv.jpg'),
(163545, 11603, 'Assassino Zen S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/493400.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/347W6BQ98irMsnZVwlXamkYHmdG.jpg'),
(163546, 11603, 'Assassino Zen S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/493401.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9HI3UZzP69xOI0LCyHbi6ym9F3k.jpg'),
(163547, 11603, 'Assassino Zen S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/493402.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rqChNJSjyPKy9Ewrxd70n23UMUa.jpg'),
(163548, 11603, 'Assassino Zen S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/493403.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sm65GjKz3JAgyh5fzMasKK4B4ME.jpg'),
(163549, 11604, 'Carros Unicos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/493394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/os4Hbj4yz4RBfXbwba0v1flCuvW.jpg'),
(163550, 11604, 'Carros Unicos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/493395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/os4Hbj4yz4RBfXbwba0v1flCuvW.jpg'),
(163551, 11604, 'Carros Unicos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/495882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/os4Hbj4yz4RBfXbwba0v1flCuvW.jpg'),
(163552, 11604, 'Carros Unicos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/503293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/os4Hbj4yz4RBfXbwba0v1flCuvW.jpg'),
(163553, 11604, 'Carros Unicos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/503294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/os4Hbj4yz4RBfXbwba0v1flCuvW.jpg'),
(163554, 11604, 'Carros Unicos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/507929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/os4Hbj4yz4RBfXbwba0v1flCuvW.jpg'),
(163555, 11604, 'Carros Unicos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/512478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/os4Hbj4yz4RBfXbwba0v1flCuvW.jpg'),
(163556, 11604, 'Carros Unicos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/514557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/os4Hbj4yz4RBfXbwba0v1flCuvW.jpg'),
(163557, 11604, 'Carros Unicos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/518732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/os4Hbj4yz4RBfXbwba0v1flCuvW.jpg'),
(163558, 11604, 'Carros Unicos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/521335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/os4Hbj4yz4RBfXbwba0v1flCuvW.jpg'),
(163559, 11604, 'Carros Unicos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/638588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/os4Hbj4yz4RBfXbwba0v1flCuvW.jpg'),
(163560, 11604, 'Carros Unicos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/656691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/os4Hbj4yz4RBfXbwba0v1flCuvW.jpg'),
(163561, 11605, 'Coragem Irmao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/493388.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wCZ9f8CG3nNJv1fObPtJavFjNbk.jpg'),
(163562, 11605, 'Coragem Irmao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/493389.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dbOnXKWIgg3BinREi56LzwnECyA.jpg'),
(163563, 11605, 'Coragem Irmao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/493390.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8WtFPklI7XnbqwusipGdNVzH4i7.jpg'),
(163564, 11605, 'Coragem Irmao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/493391.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jTXI6hOebvPXlgIZQOr3uaLqSeu.jpg'),
(163565, 11605, 'Coragem Irmao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/493392.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ibArl8OPhHBLAeAIYPtjtX9GLLI.jpg'),
(163566, 11605, 'Coragem Irmao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/493393.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ypw3mVTvQodiemyYRohjsoJl9Ve.jpg'),
(163567, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/493387.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yk5aKbasSlti1jZKbpa7G9Gu49H.jpg'),
(163568, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/499560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163569, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163570, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/509403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163571, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/515516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163572, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/639242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163573, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/640992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163574, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/695917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163575, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/701723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163576, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/714695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163577, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/718169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163578, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/724595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163579, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/731254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163580, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/742421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163581, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/776267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163582, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/780617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163583, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/794430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163584, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/795692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163585, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/801095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163586, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/813407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163587, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/822078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163588, 11606, 'Georgie e Mandy Seu Primeiro Casamento S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/822079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163589, 11607, 'Georgie e Mandy Seu Primeiro Casamento S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/890690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163590, 11607, 'Georgie e Mandy Seu Primeiro Casamento S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/892004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163591, 11607, 'Georgie e Mandy Seu Primeiro Casamento S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/892657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163592, 11607, 'Georgie e Mandy Seu Primeiro Casamento S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/893597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163593, 11607, 'Georgie e Mandy Seu Primeiro Casamento S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/893598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163594, 11607, 'Georgie e Mandy Seu Primeiro Casamento S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/894221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163595, 11607, 'Georgie e Mandy Seu Primeiro Casamento S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/897450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163596, 11607, 'Georgie e Mandy Seu Primeiro Casamento S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/897451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/vGYJfuPkhyuV1fDLFwkNcZx2qcY.jpg'),
(163597, 11608, 'Historias Assustadoras do Mickey S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/493382.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xIM1aaGttqcF1eeEVIK61oepMFp.jpg'),
(163598, 11608, 'Historias Assustadoras do Mickey S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/493383.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s9d4tMv7XZdiIiC0ka51SH9H39N.jpg'),
(163599, 11608, 'Historias Assustadoras do Mickey S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/493384.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1n2WtFEgHt8NpKhAp83nQ9bGp23.jpg'),
(163600, 11608, 'Historias Assustadoras do Mickey S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/493385.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8g1Yx5zzJzu6a6XHLOlSxVHyYju.jpg'),
(163601, 11608, 'Historias Assustadoras do Mickey S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/493386.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g02W4H6kNXvrTkYLqdEq6W3q7Ri.jpg'),
(163602, 11609, 'Maniaco do Parque A Historia Nao Contada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/493378.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/hapXmfskIEVcwiskaqRDBT5YGey.jpg'),
(163603, 11609, 'Maniaco do Parque A Historia Nao Contada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/493379.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/hapXmfskIEVcwiskaqRDBT5YGey.jpg'),
(163604, 11609, 'Maniaco do Parque A Historia Nao Contada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/493380.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/hapXmfskIEVcwiskaqRDBT5YGey.jpg'),
(163605, 11609, 'Maniaco do Parque A Historia Nao Contada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/493381.mp4', 'https://image.tmdb.org/t/p/w600_and_h900_bestv2/hapXmfskIEVcwiskaqRDBT5YGey.jpg'),
(163606, 11610, 'Nao Volte para Casa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/493372.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vGpKsaWBTtbrnFDFpCy6Zv3o21.jpg'),
(163607, 11610, 'Nao Volte para Casa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/493373.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6bbgbZD6QRklVWFDjV4wXb9k1bB.jpg'),
(163608, 11610, 'Nao Volte para Casa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/493374.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j0mKTUF3Fm3VuFGUoXpHTG9DDkF.jpg'),
(163609, 11610, 'Nao Volte para Casa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/493375.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yeB512foe8gyc77UKWeNrpMhY8Q.jpg'),
(163610, 11610, 'Nao Volte para Casa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/493376.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ufOWJB6WWvqDVQktezEj1SpojrN.jpg'),
(163611, 11610, 'Nao Volte para Casa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/493377.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1YhfkbEiIJFVvHP6myMMBbI0he5.jpg'),
(163612, 11611, 'O Caso Robinho S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/493368.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yPEy6JbOk5GmP88UoVctZP9MbBr.jpg'),
(163613, 11611, 'O Caso Robinho S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/493369.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1NSA0puoZUUg2R57I4X7lKQpk9R.jpg'),
(163614, 11611, 'O Caso Robinho S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/493370.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s7OC7az0ruAAP8W2fSziav0qI7i.jpg'),
(163615, 11611, 'O Caso Robinho S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/493371.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x59up3lOJ6v5hO0eGutwyT1gBbl.jpg'),
(163616, 11612, 'Os Quatro da Candelaria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/493364.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kXUIhz1plPCZ2qkdyFwzIyFSOln.jpg'),
(163617, 11612, 'Os Quatro da Candelaria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/493365.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6OoskWDGPok6Fz2lYzE2GfJMsKv.jpg'),
(163618, 11612, 'Os Quatro da Candelaria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/493366.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6sLNBrtpxYg2wROcW5AqiRHKlIu.jpg'),
(163619, 11612, 'Os Quatro da Candelaria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/493367.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q1VIkJH6DbgKtE9c8zhXytHwmrg.jpg'),
(163620, 11613, 'Super Dragon Ball Heroes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/493319.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r1xV5iCbTP3tAQjjYxzw6bfHPEz.jpg'),
(163621, 11613, 'Super Dragon Ball Heroes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/493320.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qLR6BqXKUwwA37eIdo64SAnCC2d.jpg'),
(163622, 11613, 'Super Dragon Ball Heroes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/493321.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cOpqf1Q5CADU55PNsnnpktnIYqD.jpg'),
(163623, 11613, 'Super Dragon Ball Heroes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/493322.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/easQKWiQKbWQ2iFVFe24XVebZd4.jpg'),
(163624, 11613, 'Super Dragon Ball Heroes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/493323.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/agGAyZ2JsnD1v3z4MqRL08LEFCn.jpg'),
(163625, 11613, 'Super Dragon Ball Heroes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/493324.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qVHiLKcalFDTxFB7KbBJKyFtmaM.jpg'),
(163626, 11614, 'Super Dragon Ball Heroes S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/493325.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rcim7TVn4OQuUW0m4VBQuuRUq5x.jpg'),
(163627, 11614, 'Super Dragon Ball Heroes S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/493326.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bLNKDpRkM3nUuIqgw1D6WsH6Tot.jpg'),
(163628, 11614, 'Super Dragon Ball Heroes S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/493327.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k0GSyirJeHYyHek1UVGKHEd1dBh.jpg'),
(163629, 11614, 'Super Dragon Ball Heroes S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/493328.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4U79kRWLlNwiuB3wNUDzqDPFNpL.jpg'),
(163630, 11614, 'Super Dragon Ball Heroes S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/493329.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Daw4V6toeztHqwLJ33YBQL55BU.jpg'),
(163631, 11614, 'Super Dragon Ball Heroes S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/493330.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ynTn0HTmhnYPgIk3MelX1wShxFU.jpg'),
(163632, 11614, 'Super Dragon Ball Heroes S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/493331.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vctWyVjMLLiPz1ihR8hIlsXXjgi.jpg'),
(163633, 11614, 'Super Dragon Ball Heroes S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/493332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163634, 11614, 'Super Dragon Ball Heroes S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/493333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163635, 11614, 'Super Dragon Ball Heroes S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/493334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163636, 11614, 'Super Dragon Ball Heroes S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/493335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163637, 11614, 'Super Dragon Ball Heroes S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/493336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163638, 11614, 'Super Dragon Ball Heroes S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/493337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163639, 11615, 'Super Dragon Ball Heroes S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/493338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163640, 11616, 'Super Dragon Ball Heroes S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/493339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163641, 11616, 'Super Dragon Ball Heroes S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/493340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163642, 11616, 'Super Dragon Ball Heroes S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/493341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163643, 11616, 'Super Dragon Ball Heroes S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/493342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163644, 11616, 'Super Dragon Ball Heroes S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/493343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163645, 11616, 'Super Dragon Ball Heroes S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/493344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163646, 11616, 'Super Dragon Ball Heroes S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/493345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163647, 11616, 'Super Dragon Ball Heroes S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/493346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163648, 11616, 'Super Dragon Ball Heroes S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/493347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163649, 11616, 'Super Dragon Ball Heroes S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/493348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163650, 11616, 'Super Dragon Ball Heroes S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/493349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163651, 11616, 'Super Dragon Ball Heroes S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/493350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163652, 11617, 'Super Dragon Ball Heroes S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/493351.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163653, 11617, 'Super Dragon Ball Heroes S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/493352.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163654, 11617, 'Super Dragon Ball Heroes S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/493353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163655, 11617, 'Super Dragon Ball Heroes S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/493354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163656, 11617, 'Super Dragon Ball Heroes S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/493355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163657, 11617, 'Super Dragon Ball Heroes S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/493356.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163658, 11617, 'Super Dragon Ball Heroes S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/493357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163659, 11617, 'Super Dragon Ball Heroes S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/493358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163660, 11618, 'Super Dragon Ball Heroes S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/493359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163661, 11618, 'Super Dragon Ball Heroes S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/493360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163662, 11618, 'Super Dragon Ball Heroes S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/493361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163663, 11618, 'Super Dragon Ball Heroes S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/493362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163664, 11618, 'Super Dragon Ball Heroes S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/493363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mieaZy4iPjnhOlE6sw7dBK3hCbt.jpg'),
(163665, 11619, 'Viva o Cinema Uma Historia da Mostra de Sao Paulo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/493315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A97hE5bcUUm01WcfLj7cU3JOcdN.jpg'),
(163666, 11619, 'Viva o Cinema Uma Historia da Mostra de Sao Paulo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/493316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A97hE5bcUUm01WcfLj7cU3JOcdN.jpg'),
(163667, 11619, 'Viva o Cinema Uma Historia da Mostra de Sao Paulo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/493317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A97hE5bcUUm01WcfLj7cU3JOcdN.jpg'),
(163668, 11619, 'Viva o Cinema Uma Historia da Mostra de Sao Paulo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/493318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/A97hE5bcUUm01WcfLj7cU3JOcdN.jpg'),
(163669, 11620, 'Voce Faria o Mesmo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/493313.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p3GgwaGELnuXLZC0uSQaRNr2RBr.jpg'),
(163670, 11620, 'Voce Faria o Mesmo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/493314.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wRNoTb7yiIbtm7uX4WxxzN8NFel.jpg'),
(163671, 11620, 'Voce Faria o Mesmo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/499609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s2RPQ1rBmpoNQxFcPml4wZFhwif.jpg'),
(163672, 11620, 'Voce Faria o Mesmo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/503915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s2RPQ1rBmpoNQxFcPml4wZFhwif.jpg'),
(163673, 11620, 'Voce Faria o Mesmo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/509173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s2RPQ1rBmpoNQxFcPml4wZFhwif.jpg'),
(163674, 11620, 'Voce Faria o Mesmo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/514878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s2RPQ1rBmpoNQxFcPml4wZFhwif.jpg'),
(163675, 11620, 'Voce Faria o Mesmo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/521769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s2RPQ1rBmpoNQxFcPml4wZFhwif.jpg'),
(163676, 11620, 'Voce Faria o Mesmo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/521770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/s2RPQ1rBmpoNQxFcPml4wZFhwif.jpg'),
(163677, 11621, 'Como Agua para Chocolate S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/497676.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hMBXF1V9vIMyA3HSWbBvdh3uwPD.jpg'),
(163678, 11621, 'Como Agua para Chocolate S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/503289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FuwDeqVoNOiR8XmtnpCB9Non85.jpg'),
(163679, 11621, 'Como Agua para Chocolate S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/512470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FuwDeqVoNOiR8XmtnpCB9Non85.jpg'),
(163680, 11621, 'Como Agua para Chocolate S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/512471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FuwDeqVoNOiR8XmtnpCB9Non85.jpg'),
(163681, 11621, 'Como Agua para Chocolate S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/514549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FuwDeqVoNOiR8XmtnpCB9Non85.jpg'),
(163682, 11621, 'Como Agua para Chocolate S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/518723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8FuwDeqVoNOiR8XmtnpCB9Non85.jpg'),
(163683, 11622, 'Influencia Mortal Assassinatos Nas Redes Sociais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/497671.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ehrPtV76eyijbqmfdJKH3ZXmAcT.jpg'),
(163684, 11622, 'Influencia Mortal Assassinatos Nas Redes Sociais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/497672.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gFizP2KvZJGhRv8PHFxBlyh8lHG.jpg'),
(163685, 11622, 'Influencia Mortal Assassinatos Nas Redes Sociais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/497673.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sWSxaAumg9v5k3uUznFNw0JAAkC.jpg'),
(163686, 11622, 'Influencia Mortal Assassinatos Nas Redes Sociais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/497674.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bPpqkS4f7p67M0UsspgDyZdF5uK.jpg'),
(163687, 11622, 'Influencia Mortal Assassinatos Nas Redes Sociais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/497675.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/loUopg5VPv2jkiwAXsc85Oq9dOT.jpg'),
(163688, 11622, 'Influencia Mortal Assassinatos Nas Redes Sociais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/503287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qbVM1KuFFRUCytZoxgh4Yantvgv.jpg'),
(163689, 11623, 'Joias Sobre Rodas O Sonho S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/497653.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l5IU2y9mYPD72Tuc6OiMG0D47TQ.jpg'),
(163690, 11623, 'Joias Sobre Rodas O Sonho S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/497654.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8q8qDclw5oVoWT019anuIRGcmuo.jpg'),
(163691, 11623, 'Joias Sobre Rodas O Sonho S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/497655.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iyhMoQHcMKafjX0cFa8mvuLaRSZ.jpg'),
(163692, 11623, 'Joias Sobre Rodas O Sonho S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/497656.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9x70rwTMMU8snwGPwpuS2CqQmbS.jpg'),
(163693, 11623, 'Joias Sobre Rodas O Sonho S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/497657.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kCsbTH4nCfCOXf0KyZqGDaLuQbA.jpg'),
(163694, 11623, 'Joias Sobre Rodas O Sonho S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/497658.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xKF1klAawSZUOjWwQTFvPwsimV5.jpg'),
(163695, 11623, 'Joias Sobre Rodas O Sonho S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/497659.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8Rk8NPZrpLgyOij7ImX6CDAbDEI.jpg'),
(163696, 11623, 'Joias Sobre Rodas O Sonho S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/497660.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kAePJANnGBQOVH58opLpSOtchfo.jpg'),
(163697, 11624, 'Joias Sobre Rodas O Sonho S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/497661.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gzTCwne9gOR6zHJjOKSDRSZi3qT.jpg'),
(163698, 11624, 'Joias Sobre Rodas O Sonho S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/497662.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jO0CrEps8gcdzvW44VvA9rH7lul.jpg'),
(163699, 11624, 'Joias Sobre Rodas O Sonho S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/497663.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yfrrMz3MbbWCDw7d8Rg6XLaO1Rs.jpg'),
(163700, 11624, 'Joias Sobre Rodas O Sonho S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/497664.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yePYIhfJqWVT05vCbUCHzUxM2aw.jpg'),
(163701, 11624, 'Joias Sobre Rodas O Sonho S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/497665.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n7D2KhJEzhIgbWqYpKQ8uj1V1js.jpg'),
(163702, 11624, 'Joias Sobre Rodas O Sonho S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/497666.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ePbYn4OZ2H4bQudgoyGSJdxQYk6.jpg'),
(163703, 11624, 'Joias Sobre Rodas O Sonho S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/497667.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6XJk2FSIQyktUxWRf6K41w3uwPx.jpg'),
(163704, 11624, 'Joias Sobre Rodas O Sonho S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/497668.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u1kiVFFoInyW0f6ToPRw6O7BxX2.jpg'),
(163705, 11624, 'Joias Sobre Rodas O Sonho S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/497669.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8Mi1rg0S7K9xDKYyZuJjCMZ2SCt.jpg'),
(163706, 11624, 'Joias Sobre Rodas O Sonho S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/497670.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pmzyAgd3OaXFo9lvyC8kUP8Z46A.jpg'),
(163707, 11625, 'Mexicanicos Celebridades S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/497639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5lnh5XhLeOP6FJmXqQOqpCJZrNU.jpg'),
(163708, 11625, 'Mexicanicos Celebridades S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/497640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5lnh5XhLeOP6FJmXqQOqpCJZrNU.jpg'),
(163709, 11625, 'Mexicanicos Celebridades S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/497641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5lnh5XhLeOP6FJmXqQOqpCJZrNU.jpg'),
(163710, 11625, 'Mexicanicos Celebridades S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/497642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5lnh5XhLeOP6FJmXqQOqpCJZrNU.jpg'),
(163711, 11625, 'Mexicanicos Celebridades S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/497643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5lnh5XhLeOP6FJmXqQOqpCJZrNU.jpg'),
(163712, 11625, 'Mexicanicos Celebridades S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/497644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5lnh5XhLeOP6FJmXqQOqpCJZrNU.jpg'),
(163713, 11625, 'Mexicanicos Celebridades S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/497645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5lnh5XhLeOP6FJmXqQOqpCJZrNU.jpg'),
(163714, 11625, 'Mexicanicos Celebridades S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/497646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5lnh5XhLeOP6FJmXqQOqpCJZrNU.jpg'),
(163715, 11626, 'Mexicanicos Celebridades S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/497647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5lnh5XhLeOP6FJmXqQOqpCJZrNU.jpg'),
(163716, 11626, 'Mexicanicos Celebridades S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/497648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5lnh5XhLeOP6FJmXqQOqpCJZrNU.jpg'),
(163717, 11627, 'Misterios da Barbie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/497631.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/an6IzfKS4EQiu9FQXMTvyb3xeas.jpg'),
(163718, 11627, 'Misterios da Barbie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/497632.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3oLt97zLR3jcohWIsF4UJpUUrGh.jpg'),
(163719, 11627, 'Misterios da Barbie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/497633.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jjwmi31IB6zNnE1a2W3cmOfYUQ1.jpg'),
(163720, 11627, 'Misterios da Barbie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/497634.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3B90XXQwxuhnYvVbCMpgbsrCMvv.jpg'),
(163721, 11627, 'Misterios da Barbie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/497635.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o5Pi6pwEqlRJb8UYD4BGg3UwOy.jpg'),
(163722, 11627, 'Misterios da Barbie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/497636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zKfE4AevCL8RjfcrhfJZat5vWTb.jpg'),
(163723, 11627, 'Misterios da Barbie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/497637.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6zfLRCcX3CJKgNMaRCMJYpuoEGl.jpg'),
(163724, 11627, 'Misterios da Barbie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/497638.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8jXgg2qcBTqIVoxn66Gt2FmwkFD.jpg'),
(163725, 11628, 'Show Do Milhao S24 E01', 'http://sinalprivado.info:80/series/1533784/1533784/497623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163726, 11628, 'Show Do Milhao S24 E02', 'http://sinalprivado.info:80/series/1533784/1533784/497624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163727, 11628, 'Show Do Milhao S24 E03', 'http://sinalprivado.info:80/series/1533784/1533784/497625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163728, 11628, 'Show Do Milhao S24 E04', 'http://sinalprivado.info:80/series/1533784/1533784/497626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163729, 11628, 'Show Do Milhao S24 E05', 'http://sinalprivado.info:80/series/1533784/1533784/497627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163730, 11628, 'Show Do Milhao S24 E06', 'http://sinalprivado.info:80/series/1533784/1533784/497628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163731, 11628, 'Show Do Milhao S24 E07', 'http://sinalprivado.info:80/series/1533784/1533784/497629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163732, 11628, 'Show Do Milhao S24 E08', 'http://sinalprivado.info:80/series/1533784/1533784/497630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163733, 11628, 'Show Do Milhao S24 E09', 'http://sinalprivado.info:80/series/1533784/1533784/504756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163734, 11628, 'Show Do Milhao S24 E10', 'http://sinalprivado.info:80/series/1533784/1533784/504757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163735, 11628, 'Show Do Milhao S24 E11', 'http://sinalprivado.info:80/series/1533784/1533784/509255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163736, 11628, 'Show Do Milhao S24 E12', 'http://sinalprivado.info:80/series/1533784/1533784/514960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163737, 11628, 'Show Do Milhao S24 E13', 'http://sinalprivado.info:80/series/1533784/1533784/517017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163738, 11628, 'Show Do Milhao S24 E14', 'http://sinalprivado.info:80/series/1533784/1533784/657448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163739, 11629, 'Show Do Milhao S25 E01', 'http://sinalprivado.info:80/series/1533784/1533784/811349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163740, 11629, 'Show Do Milhao S25 E02', 'http://sinalprivado.info:80/series/1533784/1533784/811350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163741, 11629, 'Show Do Milhao S25 E03', 'http://sinalprivado.info:80/series/1533784/1533784/820353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163742, 11629, 'Show Do Milhao S25 E04', 'http://sinalprivado.info:80/series/1533784/1533784/835206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163743, 11629, 'Show Do Milhao S25 E05', 'http://sinalprivado.info:80/series/1533784/1533784/835207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163744, 11629, 'Show Do Milhao S25 E06', 'http://sinalprivado.info:80/series/1533784/1533784/845110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163745, 11629, 'Show Do Milhao S25 E07', 'http://sinalprivado.info:80/series/1533784/1533784/850053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163746, 11629, 'Show Do Milhao S25 E08', 'http://sinalprivado.info:80/series/1533784/1533784/856792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163747, 11629, 'Show Do Milhao S25 E09', 'http://sinalprivado.info:80/series/1533784/1533784/863833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163748, 11629, 'Show Do Milhao S25 E10', 'http://sinalprivado.info:80/series/1533784/1533784/869657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163749, 11629, 'Show Do Milhao S25 E11', 'http://sinalprivado.info:80/series/1533784/1533784/873429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163750, 11629, 'Show Do Milhao S25 E12', 'http://sinalprivado.info:80/series/1533784/1533784/878835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163751, 11629, 'Show Do Milhao S25 E13', 'http://sinalprivado.info:80/series/1533784/1533784/879945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163752, 11629, 'Show Do Milhao S25 E14', 'http://sinalprivado.info:80/series/1533784/1533784/880343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163753, 11629, 'Show Do Milhao S25 E15', 'http://sinalprivado.info:80/series/1533784/1533784/881159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163754, 11629, 'Show Do Milhao S25 E16', 'http://sinalprivado.info:80/series/1533784/1533784/881277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163755, 11629, 'Show Do Milhao S25 E17', 'http://sinalprivado.info:80/series/1533784/1533784/896653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163756, 11629, 'Show Do Milhao S25 E18', 'http://sinalprivado.info:80/series/1533784/1533784/896654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163757, 11629, 'Show Do Milhao S25 E19', 'http://sinalprivado.info:80/series/1533784/1533784/897405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1OzdQR2UEd5eUz414nZU2q5TKQI.jpg'),
(163758, 11630, 'Trabalho Sujo S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/494867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pM844LEiiw6uS7tOdXk3eyzUFUO.jpg'),
(163759, 11630, 'Trabalho Sujo S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/494868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pM844LEiiw6uS7tOdXk3eyzUFUO.jpg'),
(163760, 11630, 'Trabalho Sujo S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/494869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pM844LEiiw6uS7tOdXk3eyzUFUO.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(163761, 11630, 'Trabalho Sujo S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/494870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pM844LEiiw6uS7tOdXk3eyzUFUO.jpg'),
(163762, 11631, 'Trabalho Sujo S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/494871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pM844LEiiw6uS7tOdXk3eyzUFUO.jpg'),
(163763, 11631, 'Trabalho Sujo S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/494872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pM844LEiiw6uS7tOdXk3eyzUFUO.jpg'),
(163764, 11631, 'Trabalho Sujo S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/494873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pM844LEiiw6uS7tOdXk3eyzUFUO.jpg'),
(163765, 11631, 'Trabalho Sujo S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/494874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pM844LEiiw6uS7tOdXk3eyzUFUO.jpg'),
(163766, 11631, 'Trabalho Sujo S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/494875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pM844LEiiw6uS7tOdXk3eyzUFUO.jpg'),
(163767, 11631, 'Trabalho Sujo S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/494876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pM844LEiiw6uS7tOdXk3eyzUFUO.jpg'),
(163768, 11632, 'Trabalho Sujo S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/494877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pM844LEiiw6uS7tOdXk3eyzUFUO.jpg'),
(163769, 11632, 'Trabalho Sujo S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/494878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pM844LEiiw6uS7tOdXk3eyzUFUO.jpg'),
(163770, 11632, 'Trabalho Sujo S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/494879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pM844LEiiw6uS7tOdXk3eyzUFUO.jpg'),
(163771, 11632, 'Trabalho Sujo S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/494880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pM844LEiiw6uS7tOdXk3eyzUFUO.jpg'),
(163772, 11632, 'Trabalho Sujo S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/494881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pM844LEiiw6uS7tOdXk3eyzUFUO.jpg'),
(163773, 11632, 'Trabalho Sujo S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/494882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pM844LEiiw6uS7tOdXk3eyzUFUO.jpg'),
(163774, 11632, 'Trabalho Sujo S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/494883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pM844LEiiw6uS7tOdXk3eyzUFUO.jpg'),
(163775, 11632, 'Trabalho Sujo S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/494884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pM844LEiiw6uS7tOdXk3eyzUFUO.jpg'),
(163776, 11633, 'Mexicanicos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/497544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163777, 11633, 'Mexicanicos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/497545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163778, 11633, 'Mexicanicos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/497546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163779, 11633, 'Mexicanicos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/497547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163780, 11633, 'Mexicanicos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/497548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163781, 11633, 'Mexicanicos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/497549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163782, 11633, 'Mexicanicos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/497550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163783, 11633, 'Mexicanicos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/497551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163784, 11634, 'Mexicanicos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/497552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163785, 11634, 'Mexicanicos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/497553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163786, 11634, 'Mexicanicos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/497554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163787, 11634, 'Mexicanicos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/497555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163788, 11634, 'Mexicanicos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/497556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163789, 11634, 'Mexicanicos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/497557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163790, 11635, 'Mexicanicos S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/497558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163791, 11635, 'Mexicanicos S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/497559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163792, 11635, 'Mexicanicos S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/497560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163793, 11635, 'Mexicanicos S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/497561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163794, 11635, 'Mexicanicos S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/497562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163795, 11635, 'Mexicanicos S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/497563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163796, 11636, 'Mexicanicos S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/497564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163797, 11636, 'Mexicanicos S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/497565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163798, 11636, 'Mexicanicos S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/497566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163799, 11636, 'Mexicanicos S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/497567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163800, 11636, 'Mexicanicos S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/497568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163801, 11636, 'Mexicanicos S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/497569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163802, 11636, 'Mexicanicos S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/497570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163803, 11636, 'Mexicanicos S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/497571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163804, 11636, 'Mexicanicos S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/497572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163805, 11636, 'Mexicanicos S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/497573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163806, 11636, 'Mexicanicos S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/497574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163807, 11636, 'Mexicanicos S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/497575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163808, 11636, 'Mexicanicos S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/497576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163809, 11636, 'Mexicanicos S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/497577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163810, 11636, 'Mexicanicos S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/497578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163811, 11637, 'Mexicanicos S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/497579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163812, 11637, 'Mexicanicos S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/497580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163813, 11637, 'Mexicanicos S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/497581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163814, 11637, 'Mexicanicos S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/497582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163815, 11637, 'Mexicanicos S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/497583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163816, 11637, 'Mexicanicos S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/497584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163817, 11637, 'Mexicanicos S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/497585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163818, 11637, 'Mexicanicos S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/497586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163819, 11637, 'Mexicanicos S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/497587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163820, 11638, 'Mexicanicos S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/497588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163821, 11638, 'Mexicanicos S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/497589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163822, 11638, 'Mexicanicos S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/497590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163823, 11638, 'Mexicanicos S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/497591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163824, 11638, 'Mexicanicos S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/497592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163825, 11638, 'Mexicanicos S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/497593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163826, 11638, 'Mexicanicos S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/497594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163827, 11638, 'Mexicanicos S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/497595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163828, 11638, 'Mexicanicos S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/497596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163829, 11638, 'Mexicanicos S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/497597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163830, 11638, 'Mexicanicos S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/497598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163831, 11638, 'Mexicanicos S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/497599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163832, 11638, 'Mexicanicos S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/497600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163833, 11639, 'Mexicanicos S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/497601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163834, 11639, 'Mexicanicos S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/497602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163835, 11639, 'Mexicanicos S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/497603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163836, 11639, 'Mexicanicos S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/497604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163837, 11639, 'Mexicanicos S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/497605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163838, 11639, 'Mexicanicos S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/497606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163839, 11639, 'Mexicanicos S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/497607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163840, 11639, 'Mexicanicos S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/497608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163841, 11639, 'Mexicanicos S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/497609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163842, 11639, 'Mexicanicos S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/497610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163843, 11639, 'Mexicanicos S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/497611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163844, 11640, 'Mexicanicos S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/497612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163845, 11640, 'Mexicanicos S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/497613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163846, 11640, 'Mexicanicos S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/497614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163847, 11640, 'Mexicanicos S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/497615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163848, 11640, 'Mexicanicos S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/497616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163849, 11640, 'Mexicanicos S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/497617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163850, 11640, 'Mexicanicos S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/497618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163851, 11640, 'Mexicanicos S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/497619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163852, 11640, 'Mexicanicos S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/497620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163853, 11641, 'Mexicanicos S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/497621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163854, 11641, 'Mexicanicos S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/497622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iPx3d7vNpyvU3HIuyb95AR3I7w4.jpg'),
(163855, 11642, 'One Piece Log Fish Man Island Saga [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/497543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cHZ3bDzqrhmmpYi85BAVJ0ZIeLd.jpg'),
(163856, 11642, 'One Piece Log Fish Man Island Saga [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/511436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cHZ3bDzqrhmmpYi85BAVJ0ZIeLd.jpg'),
(163857, 11642, 'One Piece Log Fish Man Island Saga [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/511437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cHZ3bDzqrhmmpYi85BAVJ0ZIeLd.jpg'),
(163858, 11642, 'One Piece Log Fish Man Island Saga [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/511438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cHZ3bDzqrhmmpYi85BAVJ0ZIeLd.jpg'),
(163859, 11642, 'One Piece Log Fish Man Island Saga [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/514255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cHZ3bDzqrhmmpYi85BAVJ0ZIeLd.jpg'),
(163860, 11642, 'One Piece Log Fish Man Island Saga [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/517693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cHZ3bDzqrhmmpYi85BAVJ0ZIeLd.jpg'),
(163861, 11642, 'One Piece Log Fish Man Island Saga [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/525159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cHZ3bDzqrhmmpYi85BAVJ0ZIeLd.jpg'),
(163862, 11642, 'One Piece Log Fish Man Island Saga [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/638359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cHZ3bDzqrhmmpYi85BAVJ0ZIeLd.jpg'),
(163863, 11642, 'One Piece Log Fish Man Island Saga [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/658825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cHZ3bDzqrhmmpYi85BAVJ0ZIeLd.jpg'),
(163864, 11642, 'One Piece Log Fish Man Island Saga [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/658826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cHZ3bDzqrhmmpYi85BAVJ0ZIeLd.jpg'),
(163865, 11642, 'One Piece Log Fish Man Island Saga [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/660210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cHZ3bDzqrhmmpYi85BAVJ0ZIeLd.jpg'),
(163866, 11642, 'One Piece Log Fish Man Island Saga [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/669239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cHZ3bDzqrhmmpYi85BAVJ0ZIeLd.jpg'),
(163867, 11642, 'One Piece Log Fish Man Island Saga [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/674923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cHZ3bDzqrhmmpYi85BAVJ0ZIeLd.jpg'),
(163868, 11642, 'One Piece Log Fish Man Island Saga [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/689264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cHZ3bDzqrhmmpYi85BAVJ0ZIeLd.jpg'),
(163869, 11642, 'One Piece Log Fish Man Island Saga [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/699595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cHZ3bDzqrhmmpYi85BAVJ0ZIeLd.jpg'),
(163870, 11642, 'One Piece Log Fish Man Island Saga [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/704416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cHZ3bDzqrhmmpYi85BAVJ0ZIeLd.jpg'),
(163871, 11642, 'One Piece Log Fish Man Island Saga [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/716074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cHZ3bDzqrhmmpYi85BAVJ0ZIeLd.jpg'),
(163872, 11642, 'One Piece Log Fish Man Island Saga [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/728591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cHZ3bDzqrhmmpYi85BAVJ0ZIeLd.jpg'),
(163873, 11642, 'One Piece Log Fish Man Island Saga [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/738012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cHZ3bDzqrhmmpYi85BAVJ0ZIeLd.jpg'),
(163874, 11642, 'One Piece Log Fish Man Island Saga [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/751049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cHZ3bDzqrhmmpYi85BAVJ0ZIeLd.jpg'),
(163875, 11643, 'Pesca Mortal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/495956.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8so8MXR9hS3Op4evOpQNdF6rPU3.jpg'),
(163876, 11643, 'Pesca Mortal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/495957.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4tYmG2Hhgq6aZ6FqwbgOuWOyNEE.jpg'),
(163877, 11643, 'Pesca Mortal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/495958.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8wiI0C4L6CPz4oO3SnX22pmdcnU.jpg'),
(163878, 11643, 'Pesca Mortal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/495959.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b9NgjLTkTuKxnT5f9oYTMTcxvGL.jpg'),
(163879, 11643, 'Pesca Mortal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/495960.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/93RiNfSu8sEVFyeZ7eCaKYsTICZ.jpg'),
(163880, 11643, 'Pesca Mortal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/495961.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yFCRPxznTSDAKD1SL2fslCc8bsP.jpg'),
(163881, 11643, 'Pesca Mortal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/495962.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kA6ZoAmZJG4KBUXgpvmTZNg4Jqr.jpg'),
(163882, 11643, 'Pesca Mortal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/495963.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9uCEG4CLzogedFnNrDL0pAQjvYM.jpg'),
(163883, 11643, 'Pesca Mortal S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/495964.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xkZNk1XDSfx1EHnjlO1ukxIoUzF.jpg'),
(163884, 11644, 'Pesca Mortal S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/495965.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aj0jXD90uvqTZdM5MN7cjNNkK8U.jpg'),
(163885, 11644, 'Pesca Mortal S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/495966.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mbAKWQleynjASJt8DCgsOo77F4t.jpg'),
(163886, 11644, 'Pesca Mortal S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/495967.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q7JIDBzGiBQIRWZpxz03ya2QWwh.jpg'),
(163887, 11644, 'Pesca Mortal S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/495968.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yLO83983SHBCljWicWVI3a0Xb5A.jpg'),
(163888, 11644, 'Pesca Mortal S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/495969.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kLSM1PYnH4bPgZkmApXW644Q2oN.jpg'),
(163889, 11644, 'Pesca Mortal S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/495970.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wftrfSwdzp5HYkxKu1MxcDKBL30.jpg'),
(163890, 11644, 'Pesca Mortal S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/495971.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nZI2rfyZlp8y5L85UcvgQZf9wFa.jpg'),
(163891, 11644, 'Pesca Mortal S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/495972.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1FwyvFuI5N2KlygcTnS45FIeABE.jpg'),
(163892, 11644, 'Pesca Mortal S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/495973.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/psV0Vu3eMX9LZVJThLTgPdJWNrs.jpg'),
(163893, 11644, 'Pesca Mortal S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/495974.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xqeWtTqWW9mn3KPvDe5XddTkIYD.jpg'),
(163894, 11644, 'Pesca Mortal S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/635175.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yhIjRmqsq6aIAKVOvx3lvpWiGPz.jpg'),
(163895, 11645, 'Pesca Mortal S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/495976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(163896, 11645, 'Pesca Mortal S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/495977.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q1FHf74yK83F3M6rTCjGOCs50BF.jpg'),
(163897, 11645, 'Pesca Mortal S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/495978.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h1Byd89zEPDuQ2kWm9yMrWaHBNO.jpg'),
(163898, 11645, 'Pesca Mortal S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/495979.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vQTvUBZFT9jtH21enhbtkXa1xB5.jpg'),
(163899, 11645, 'Pesca Mortal S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/495980.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cQ6Fz13l1kIMPCwjDWg9QVzkzN2.jpg'),
(163900, 11645, 'Pesca Mortal S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/495981.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a0CWvOZYXD6RGymuJUj7QtDb1LS.jpg'),
(163901, 11645, 'Pesca Mortal S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/495982.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/VKNzMX5XHbk3yKw0hUMebRr0z9.jpg'),
(163902, 11645, 'Pesca Mortal S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/495983.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ym52rcthnndC2rK37234jcMjzIN.jpg'),
(163903, 11645, 'Pesca Mortal S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/495984.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jylCtUL9FBgaBkUjGp6pAnjakn8.jpg'),
(163904, 11645, 'Pesca Mortal S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/495985.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hQUFRsLuotdbNHOGoHRHZo5Ldam.jpg'),
(163905, 11645, 'Pesca Mortal S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/495986.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cU7VAWH31kr35vLVgS10Nt6W8JE.jpg'),
(163906, 11645, 'Pesca Mortal S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/495987.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ljZPA4iUHMPf6AoFTj56zveBU1j.jpg'),
(163907, 11646, 'Pesca Mortal S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/495988.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vNnutc5F0tPPNJinssgL3WfLv36.jpg'),
(163908, 11646, 'Pesca Mortal S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/495989.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qGUCVy2wY6dp8Q8wgNFHwyAJJ8s.jpg'),
(163909, 11646, 'Pesca Mortal S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/495990.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9y2C5XtsOIqY18xNz1NtL7fYDp7.jpg'),
(163910, 11646, 'Pesca Mortal S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/495991.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rznDeLc43VlTzjvFvluNCf8eAId.jpg'),
(163911, 11646, 'Pesca Mortal S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/495992.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2QYinvGoIH3Szdr2u3gYRy7lrXI.jpg'),
(163912, 11646, 'Pesca Mortal S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/495993.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4cBtdx3ViOPWWcetCu8NvHSa2kl.jpg'),
(163913, 11646, 'Pesca Mortal S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/495994.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z52hwBOAQ4rjDP9r3cuWMGlyzrh.jpg'),
(163914, 11646, 'Pesca Mortal S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/495995.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yq2u6vJpIw0FCtjTC5SWdy9FRDD.jpg'),
(163915, 11646, 'Pesca Mortal S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/495996.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/VtOtlHqFYehpbmGLIrs0XThD3z.jpg'),
(163916, 11646, 'Pesca Mortal S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/495997.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rWFgTpSxB80DfVXlGABrR7HgOW7.jpg'),
(163917, 11646, 'Pesca Mortal S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/495998.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6HjcGS1ILXUaT1D53gKY6TrU7DV.jpg'),
(163918, 11646, 'Pesca Mortal S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/495999.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t1q4Fv8ePtewRYHcxtcXjdwTYwt.jpg'),
(163919, 11646, 'Pesca Mortal S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/496000.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nZz8aAkTqTIN9AnDafTTwf7TXou.jpg'),
(163920, 11646, 'Pesca Mortal S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/496001.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Ar2oHz0qGH7zOMq4mbDwijl3emX.jpg'),
(163921, 11646, 'Pesca Mortal S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/496002.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3mpIcMQKIjA5STbcnBwPpYOyxG1.jpg'),
(163922, 11646, 'Pesca Mortal S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/496003.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jr8mZ4BZPDpkGhni7Zh6ZbpDCV.jpg'),
(163923, 11647, 'Pesca Mortal S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/496004.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kcoZLfCgeeYexPKggATelMI9IZJ.jpg'),
(163924, 11647, 'Pesca Mortal S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/496005.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oGIFwOieSS0ZE7BnruvZFjLBHv1.jpg'),
(163925, 11647, 'Pesca Mortal S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/496006.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/54QzraYbk6i29LLOEz3VaihI0Sr.jpg'),
(163926, 11647, 'Pesca Mortal S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/496007.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AuetrYwSoRaKimgUp0uDDw2UJJ9.jpg'),
(163927, 11647, 'Pesca Mortal S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/496008.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wiQRO55qifNuE8Rl80UX8zuTKD0.jpg'),
(163928, 11647, 'Pesca Mortal S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/496009.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1qbFrHtf63r2BwKcRtCZ3Xoai7y.jpg'),
(163929, 11647, 'Pesca Mortal S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/496010.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b9ZP9bOT9BQIHmJK7sUlHeYelsa.jpg'),
(163930, 11647, 'Pesca Mortal S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/496011.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gBkpG8fGKlpu7SzWK08gEpN1jkt.jpg'),
(163931, 11647, 'Pesca Mortal S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/496012.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tyeb2LignenNfOwQ5pJkrsQvgt1.jpg'),
(163932, 11647, 'Pesca Mortal S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/496013.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pY3IvjhfRhsbuctOP4VfpaeJCte.jpg'),
(163933, 11647, 'Pesca Mortal S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/496014.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lxcl2yF1j3NOQxwQOSguvLJ5epi.jpg'),
(163934, 11647, 'Pesca Mortal S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/496015.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zCZmjmq25maHbopvyiX17jIBtZh.jpg'),
(163935, 11647, 'Pesca Mortal S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/496016.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qjnkHwSPO1JIny2BwGAeBQ9pVdU.jpg'),
(163936, 11647, 'Pesca Mortal S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/496017.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4KsbXKJj7K1yUDfKYw6pjV3HIYe.jpg'),
(163937, 11647, 'Pesca Mortal S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/496018.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aTL2iC6qGIghNbdmZdYSCpHwTf2.jpg'),
(163938, 11647, 'Pesca Mortal S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/496019.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6FkSbudRVEAkAxy5CycROxuHo5o.jpg'),
(163939, 11648, 'Pesca Mortal S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/496020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(163940, 11648, 'Pesca Mortal S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/496021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(163941, 11648, 'Pesca Mortal S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/496022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(163942, 11648, 'Pesca Mortal S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/496023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(163943, 11648, 'Pesca Mortal S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/496024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(163944, 11648, 'Pesca Mortal S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/496025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(163945, 11648, 'Pesca Mortal S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/496026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(163946, 11648, 'Pesca Mortal S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/496027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(163947, 11648, 'Pesca Mortal S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/496028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(163948, 11648, 'Pesca Mortal S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/496029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(163949, 11648, 'Pesca Mortal S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/496030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(163950, 11648, 'Pesca Mortal S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/496031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(163951, 11648, 'Pesca Mortal S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/496032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(163952, 11648, 'Pesca Mortal S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/496033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(163953, 11648, 'Pesca Mortal S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/496034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(163954, 11648, 'Pesca Mortal S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/496035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(163955, 11648, 'Pesca Mortal S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/496036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(163956, 11648, 'Pesca Mortal S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/496037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(163957, 11649, 'Pesca Mortal S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/496038.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tdKcvnfsqIWwQnzrNiHrk9M4jwB.jpg'),
(163958, 11649, 'Pesca Mortal S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/496039.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pfnKqaoeKUlUwHrtFXpe2QXELcN.jpg'),
(163959, 11649, 'Pesca Mortal S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/496040.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2gHqOyDQ2VBIR26GmYiHb95lmz9.jpg'),
(163960, 11649, 'Pesca Mortal S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/496041.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p4aElLzVi4Yy5vnilDDGNRR6rDR.jpg'),
(163961, 11649, 'Pesca Mortal S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/496042.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ugGAXDaW9i1N03CQF9WDcsJMYjE.jpg'),
(163962, 11649, 'Pesca Mortal S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/496043.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y8a6hqqbtQFlY7h5dU5DTw2n64m.jpg'),
(163963, 11649, 'Pesca Mortal S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/496044.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kXotprHtlaNCAh8gxQwTLALuFl9.jpg'),
(163964, 11649, 'Pesca Mortal S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/496045.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1kTimMCO9xtsuy0MLUIplWzB5hW.jpg'),
(163965, 11649, 'Pesca Mortal S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/496046.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/93ne8xBhNQd3QmQBFJlr2E8aZKM.jpg'),
(163966, 11649, 'Pesca Mortal S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/496047.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fugJEdUKArRBArWyquI7OmpuVzs.jpg'),
(163967, 11649, 'Pesca Mortal S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/496048.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aB6YQOuIAm9XqUGmSYGnRf2hdJS.jpg'),
(163968, 11649, 'Pesca Mortal S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/496049.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7UKrHbGuO1SpjnPit8hvrGIlZh7.jpg'),
(163969, 11649, 'Pesca Mortal S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/496050.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/GgexlPxn94WTt00lCFH3J1cvkB.jpg'),
(163970, 11649, 'Pesca Mortal S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/496051.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/CQ9ldVnrhJZ6l9nzr2rbaSu64j.jpg'),
(163971, 11649, 'Pesca Mortal S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/496052.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qHIwb9GY93GHy28QrSCTNiVdkM5.jpg'),
(163972, 11649, 'Pesca Mortal S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/496053.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9acdsKc7MQ28gcRroF5OHJYlnAn.jpg'),
(163973, 11649, 'Pesca Mortal S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/496054.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/drNoFc69KpQ1YzfLPO0R323FisN.jpg'),
(163974, 11649, 'Pesca Mortal S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/496055.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tG1LNLtEimteslXLgGAoazqBQYk.jpg'),
(163975, 11650, 'Pesca Mortal S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/496056.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1VLHwzLclT5h3mU7WBf6HAyo7dF.jpg'),
(163976, 11650, 'Pesca Mortal S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/496057.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8izAcpJj7kao2azdgk1HU64GdbA.jpg'),
(163977, 11650, 'Pesca Mortal S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/496058.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7DhL0aXSMOh2c0gUehFUuIikecj.jpg'),
(163978, 11650, 'Pesca Mortal S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/496059.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vRurBGRs1gbRF5cyjPGuJWQ2MT5.jpg'),
(163979, 11650, 'Pesca Mortal S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/496060.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m8xMxDPrP1NysaqeKSqNgtFX9YS.jpg'),
(163980, 11650, 'Pesca Mortal S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/496061.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iPuEgVPrCaCPglSutGN4PkRZC9s.jpg'),
(163981, 11650, 'Pesca Mortal S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/496062.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bYAnnEjMzEj5YhzPHhvxPOajDVK.jpg'),
(163982, 11650, 'Pesca Mortal S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/496063.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t4FetgV5emwD8POJxkM39xYbDyz.jpg'),
(163983, 11650, 'Pesca Mortal S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/496064.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qV98lCvqZIV99EVOlyPnA6aUWoF.jpg'),
(163984, 11650, 'Pesca Mortal S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/496065.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3CWIYd1W0Bc4pZHu6XelwamET9i.jpg'),
(163985, 11650, 'Pesca Mortal S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/496066.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tTWoAcu69bwKZYQeCGXJjTLzWCX.jpg'),
(163986, 11650, 'Pesca Mortal S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/496067.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rRXKt3jG8NiU6KDkUhrjIbQOUnU.jpg'),
(163987, 11650, 'Pesca Mortal S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/496068.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eKiGMDHGkxad8Go3tOb0e9H2X05.jpg'),
(163988, 11650, 'Pesca Mortal S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/496069.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aLVwOIvONW76ho0rxR58hTvGjVg.jpg'),
(163989, 11650, 'Pesca Mortal S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/496070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(163990, 11650, 'Pesca Mortal S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/496071.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4W7mstqVzfDBWXrKNkbD2QKlNi4.jpg'),
(163991, 11650, 'Pesca Mortal S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/496072.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mwFf6mI9ZtIs3o21jzFeLpYYmFG.jpg'),
(163992, 11650, 'Pesca Mortal S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/496073.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/TGPrOZOpyhrJAKz9gbj8K2QT0x.jpg'),
(163993, 11650, 'Pesca Mortal S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/496074.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oZ9tWiqtBegkdbFqw6wIFyQ2slc.jpg'),
(163994, 11651, 'Pesca Mortal S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/496075.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iPMcY4BkDQBj7FDi54JeXrdpgzD.jpg'),
(163995, 11651, 'Pesca Mortal S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/496076.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nM4PZzGkiLDv6O5YelDF7qw8rlE.jpg'),
(163996, 11651, 'Pesca Mortal S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/496077.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4dPx9U1AIlhCa0lpSAkSdQrDmZ0.jpg'),
(163997, 11651, 'Pesca Mortal S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/496078.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p9HEAP92XXT5Yb9tF0DDELseXa3.jpg'),
(163998, 11651, 'Pesca Mortal S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/496079.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fRxeXcAfYLeGwcNshyP2siQChFO.jpg'),
(163999, 11651, 'Pesca Mortal S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/496080.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k6WxnDGEkXapwQVtmDeh9le0Hb7.jpg'),
(164000, 11651, 'Pesca Mortal S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/496081.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2wXMKZ4Lmm3MWSWNPlJ7ceVreut.jpg'),
(164001, 11651, 'Pesca Mortal S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/496082.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lkoMosttB93mZtcBa2APmH1af7o.jpg'),
(164002, 11651, 'Pesca Mortal S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/496083.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sYfit3WemGb3a948Ea00yyRa9LD.jpg'),
(164003, 11651, 'Pesca Mortal S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/496084.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1HB4LISJ82zOcQdKhWMT1zYpBxu.jpg'),
(164004, 11651, 'Pesca Mortal S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/496085.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eE4tpmxud8Dzyrxz0qWsGfP30tH.jpg'),
(164005, 11651, 'Pesca Mortal S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/496086.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kJ3v3EqgocQ2aFOiCV0FMOKYp6R.jpg'),
(164006, 11651, 'Pesca Mortal S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/496087.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iR3CQ9ggi8GOxu3UW5wzVLuO9N8.jpg'),
(164007, 11651, 'Pesca Mortal S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/496088.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3Yr2VtZHeKpLtFCEk5PbGMCoUFB.jpg'),
(164008, 11651, 'Pesca Mortal S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/496089.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qAQQVXVQzB2p4KaIMf1BHw3jbxz.jpg'),
(164009, 11651, 'Pesca Mortal S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/496090.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/glaGOMpZ9jk3N00Haaeo2a4yq3v.jpg'),
(164010, 11651, 'Pesca Mortal S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/496091.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3NVy1zh9LvZBjC2CpBCrmyf3uXF.jpg'),
(164011, 11651, 'Pesca Mortal S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/496092.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/caEUJDgcNgkYJnE8pCk2MqGnnOe.jpg'),
(164012, 11651, 'Pesca Mortal S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/496093.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dfUek5mV51jaDuzKMnZIXSmLHDS.jpg'),
(164013, 11651, 'Pesca Mortal S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/496094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164014, 11652, 'Pesca Mortal S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/496095.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9tduj3OpCj47ZY7NPyigwHUbjuQ.jpg'),
(164015, 11652, 'Pesca Mortal S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/496096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164016, 11652, 'Pesca Mortal S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/496097.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5ibf6C5mIfiOgrClovRpy9Lw8Gz.jpg'),
(164017, 11652, 'Pesca Mortal S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/496098.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mhMGw87vsrgxyUwT4AuSWT0DSTN.jpg'),
(164018, 11652, 'Pesca Mortal S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/496099.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yrhwt1IPVoN7MNmRyWA8kYdutJ0.jpg'),
(164019, 11652, 'Pesca Mortal S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/496100.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hg6AjAXbzV61i1xAFu5ZpNPd7SB.jpg'),
(164020, 11652, 'Pesca Mortal S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/496101.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ynI7DVlAxGs8vFL5Rf3GtGTTIOb.jpg'),
(164021, 11652, 'Pesca Mortal S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/496102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164022, 11652, 'Pesca Mortal S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/496103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164023, 11652, 'Pesca Mortal S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/496104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(164024, 11652, 'Pesca Mortal S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/496105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164025, 11652, 'Pesca Mortal S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/496106.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jxhnXjuQPvc8DEMKZiF80TjCFFf.jpg'),
(164026, 11652, 'Pesca Mortal S15 E13', 'http://sinalprivado.info:80/series/1533784/1533784/496107.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qR8x4ZEha4mTUis0FfoQx8w1uu9.jpg'),
(164027, 11652, 'Pesca Mortal S15 E14', 'http://sinalprivado.info:80/series/1533784/1533784/496108.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oQWEBkFSuZ5Tz7spPaJk4F954CG.jpg'),
(164028, 11652, 'Pesca Mortal S15 E15', 'http://sinalprivado.info:80/series/1533784/1533784/496109.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6urUEzRWMIaK0jew7Z3HYJmaSmv.jpg'),
(164029, 11652, 'Pesca Mortal S15 E16', 'http://sinalprivado.info:80/series/1533784/1533784/496110.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2hbYK3wDIlG27DHHAjeDQYXxQsd.jpg'),
(164030, 11652, 'Pesca Mortal S15 E17', 'http://sinalprivado.info:80/series/1533784/1533784/496111.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kcWzvSiyjEqQQYaslAXFvaHQUUr.jpg'),
(164031, 11652, 'Pesca Mortal S15 E18', 'http://sinalprivado.info:80/series/1533784/1533784/496112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164032, 11652, 'Pesca Mortal S15 E19', 'http://sinalprivado.info:80/series/1533784/1533784/496113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164033, 11652, 'Pesca Mortal S15 E20', 'http://sinalprivado.info:80/series/1533784/1533784/496114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164034, 11652, 'Pesca Mortal S15 E21', 'http://sinalprivado.info:80/series/1533784/1533784/496115.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fYf9QkAkF1vXN65GDcGI0DpxnTW.jpg'),
(164035, 11652, 'Pesca Mortal S15 E22', 'http://sinalprivado.info:80/series/1533784/1533784/496116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164036, 11653, 'Pesca Mortal S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/496117.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c9IiPkxizMPrZQrhOYbzJdcH161.jpg'),
(164037, 11653, 'Pesca Mortal S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/496118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164038, 11653, 'Pesca Mortal S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/496119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164039, 11653, 'Pesca Mortal S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/496120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164040, 11653, 'Pesca Mortal S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/496121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164041, 11653, 'Pesca Mortal S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/496122.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xmQDTwJYWqe9Ailo3AaRYqoqJ12.jpg'),
(164042, 11653, 'Pesca Mortal S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/496123.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sKq2jS6glPWLQVloi9R4Uf8GD7T.jpg'),
(164043, 11653, 'Pesca Mortal S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/496124.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6aeIn5r6Insl7G7FV6oyXUyYOSt.jpg'),
(164044, 11653, 'Pesca Mortal S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/496125.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n67VXOET2xDvilgqbvos50iJRdC.jpg'),
(164045, 11653, 'Pesca Mortal S16 E10', 'http://sinalprivado.info:80/series/1533784/1533784/496126.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mAojr1kXKhjdVplFvxVcbs2FiRO.jpg'),
(164046, 11653, 'Pesca Mortal S16 E11', 'http://sinalprivado.info:80/series/1533784/1533784/496127.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yKvRDi6zJqJH03WUwRmGfVe6hiP.jpg'),
(164047, 11653, 'Pesca Mortal S16 E12', 'http://sinalprivado.info:80/series/1533784/1533784/496128.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bC7AThqfPHmkEGrweZNin37Oh43.jpg'),
(164048, 11653, 'Pesca Mortal S16 E13', 'http://sinalprivado.info:80/series/1533784/1533784/496129.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hoDmrynctpcEMM8p5dwpM0GnXxG.jpg'),
(164049, 11653, 'Pesca Mortal S16 E14', 'http://sinalprivado.info:80/series/1533784/1533784/496130.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/amFiUjmFqz5VHObX91NsWqVbuq8.jpg'),
(164050, 11653, 'Pesca Mortal S16 E15', 'http://sinalprivado.info:80/series/1533784/1533784/496131.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q17M7XovCsfUuZNwFw7VRjZAdIt.jpg'),
(164051, 11653, 'Pesca Mortal S16 E16', 'http://sinalprivado.info:80/series/1533784/1533784/496132.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gHcxMzcFeWpMrsT3IeJdHBIVklG.jpg'),
(164052, 11653, 'Pesca Mortal S16 E17', 'http://sinalprivado.info:80/series/1533784/1533784/496133.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pyTtSvQOTSPFazNYsoe1ksN56rT.jpg'),
(164053, 11653, 'Pesca Mortal S16 E18', 'http://sinalprivado.info:80/series/1533784/1533784/496134.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7ZecWR6naR028vl6MZJeoeabQgV.jpg'),
(164054, 11653, 'Pesca Mortal S16 E19', 'http://sinalprivado.info:80/series/1533784/1533784/496135.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yjAsXYoahFt7jxx2Koo231ZVvSn.jpg'),
(164055, 11653, 'Pesca Mortal S16 E20', 'http://sinalprivado.info:80/series/1533784/1533784/496136.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sUUfYgMh4h9j1FPwvNxooE6hunG.jpg'),
(164056, 11653, 'Pesca Mortal S16 E21', 'http://sinalprivado.info:80/series/1533784/1533784/496137.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b3PQ0FeIiHdPfyTGJN4YwhmWeYw.jpg'),
(164057, 11653, 'Pesca Mortal S16 E22', 'http://sinalprivado.info:80/series/1533784/1533784/496138.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sDpN6QSsLkYW4VcmH9eXFNF1WwY.jpg'),
(164058, 11653, 'Pesca Mortal S16 E23', 'http://sinalprivado.info:80/series/1533784/1533784/496139.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1ESpfmVir9FWKHjfuqUTiB2lt4i.jpg'),
(164059, 11654, 'Pesca Mortal S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/496140.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hNbRZDnad6xMlm6zO7jbudoONeJ.jpg'),
(164060, 11654, 'Pesca Mortal S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/496141.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4wJ1c9sHd7FH4LE7wv97RgmetB2.jpg'),
(164061, 11654, 'Pesca Mortal S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/496142.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cMzBWiRF5DyV05dZ3KWQmGu8MgC.jpg'),
(164062, 11654, 'Pesca Mortal S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/496143.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c3ibKxensSSzQC0cKQSyuJ7ewQD.jpg'),
(164063, 11654, 'Pesca Mortal S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/496144.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lLuoXUMs04hdj2WIixTGTdwbgTg.jpg'),
(164064, 11654, 'Pesca Mortal S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/496145.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t17MG4hM8iSCWUEnJ1CbGh05j5t.jpg'),
(164065, 11654, 'Pesca Mortal S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/496146.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gdS11NuyudrgvRSEjVLW2FrVWW.jpg'),
(164066, 11654, 'Pesca Mortal S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/496147.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u4Q58sYIqsKObph0M4DPycPxxCV.jpg'),
(164067, 11654, 'Pesca Mortal S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/496148.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gQQkudsKs1Nu7ZYmECQEqM7FN2A.jpg'),
(164068, 11654, 'Pesca Mortal S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/496149.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f3oazjBVKbLW11rHiVVBI9F3frE.jpg'),
(164069, 11654, 'Pesca Mortal S17 E11', 'http://sinalprivado.info:80/series/1533784/1533784/496150.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vG9THib3o1hjIdTtQQifif2GQ58.jpg'),
(164070, 11654, 'Pesca Mortal S17 E12', 'http://sinalprivado.info:80/series/1533784/1533784/496151.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g0dQuIREDi3FuSDQMV0gN4PxbqG.jpg'),
(164071, 11654, 'Pesca Mortal S17 E13', 'http://sinalprivado.info:80/series/1533784/1533784/496152.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3KcIM0pvZjod55fQVSHTT3xTmST.jpg'),
(164072, 11654, 'Pesca Mortal S17 E14', 'http://sinalprivado.info:80/series/1533784/1533784/496153.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a0jVReW2Ulhg6EMBPrDXw1EdrOm.jpg'),
(164073, 11654, 'Pesca Mortal S17 E15', 'http://sinalprivado.info:80/series/1533784/1533784/496154.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t8NlkHLfFMp2YDw9hBAFMsPkUWx.jpg'),
(164074, 11654, 'Pesca Mortal S17 E16', 'http://sinalprivado.info:80/series/1533784/1533784/496155.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5ZCeLDJVqphY622q7olMLUxYr37.jpg'),
(164075, 11654, 'Pesca Mortal S17 E17', 'http://sinalprivado.info:80/series/1533784/1533784/496156.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5WQfYRTMGcA2YfoxNtDBLHZvYLL.jpg'),
(164076, 11654, 'Pesca Mortal S17 E18', 'http://sinalprivado.info:80/series/1533784/1533784/496157.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pt2ugequ9Vsb2R80da6Soz3kykg.jpg'),
(164077, 11654, 'Pesca Mortal S17 E19', 'http://sinalprivado.info:80/series/1533784/1533784/496158.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/crhKaNbgWmLa9oPH0dsDxjn2K2N.jpg'),
(164078, 11654, 'Pesca Mortal S17 E20', 'http://sinalprivado.info:80/series/1533784/1533784/496159.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nmINEwZiWdrFZb0jFeUuMuy3FI6.jpg'),
(164079, 11654, 'Pesca Mortal S17 E21', 'http://sinalprivado.info:80/series/1533784/1533784/496160.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e1azRXxHNQxpeJa6FPbcLHWESZu.jpg'),
(164080, 11654, 'Pesca Mortal S17 E22', 'http://sinalprivado.info:80/series/1533784/1533784/496161.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ljnmfP1vRUOWB416vMxeRu9rlou.jpg'),
(164081, 11655, 'Pesca Mortal S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/505357.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164082, 11655, 'Pesca Mortal S18 E02', 'http://sinalprivado.info:80/series/1533784/1533784/505358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164083, 11655, 'Pesca Mortal S18 E03', 'http://sinalprivado.info:80/series/1533784/1533784/505359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164084, 11655, 'Pesca Mortal S18 E04', 'http://sinalprivado.info:80/series/1533784/1533784/505360.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164085, 11655, 'Pesca Mortal S18 E05', 'http://sinalprivado.info:80/series/1533784/1533784/505361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164086, 11655, 'Pesca Mortal S18 E06', 'http://sinalprivado.info:80/series/1533784/1533784/505362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164087, 11655, 'Pesca Mortal S18 E07', 'http://sinalprivado.info:80/series/1533784/1533784/505363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164088, 11655, 'Pesca Mortal S18 E08', 'http://sinalprivado.info:80/series/1533784/1533784/505364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164089, 11655, 'Pesca Mortal S18 E09', 'http://sinalprivado.info:80/series/1533784/1533784/505365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164090, 11655, 'Pesca Mortal S18 E10', 'http://sinalprivado.info:80/series/1533784/1533784/505366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164091, 11655, 'Pesca Mortal S18 E11', 'http://sinalprivado.info:80/series/1533784/1533784/505367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164092, 11655, 'Pesca Mortal S18 E12', 'http://sinalprivado.info:80/series/1533784/1533784/505368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164093, 11655, 'Pesca Mortal S18 E13', 'http://sinalprivado.info:80/series/1533784/1533784/505369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164094, 11655, 'Pesca Mortal S18 E14', 'http://sinalprivado.info:80/series/1533784/1533784/505370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164095, 11655, 'Pesca Mortal S18 E15', 'http://sinalprivado.info:80/series/1533784/1533784/505371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164096, 11655, 'Pesca Mortal S18 E16', 'http://sinalprivado.info:80/series/1533784/1533784/505372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164097, 11655, 'Pesca Mortal S18 E17', 'http://sinalprivado.info:80/series/1533784/1533784/505373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164098, 11655, 'Pesca Mortal S18 E18', 'http://sinalprivado.info:80/series/1533784/1533784/505374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164099, 11655, 'Pesca Mortal S18 E19', 'http://sinalprivado.info:80/series/1533784/1533784/505375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164100, 11655, 'Pesca Mortal S18 E20', 'http://sinalprivado.info:80/series/1533784/1533784/505376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164101, 11655, 'Pesca Mortal S18 E21', 'http://sinalprivado.info:80/series/1533784/1533784/505377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164102, 11655, 'Pesca Mortal S18 E22', 'http://sinalprivado.info:80/series/1533784/1533784/505378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164103, 11655, 'Pesca Mortal S18 E23', 'http://sinalprivado.info:80/series/1533784/1533784/505379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164104, 11656, 'Pesca Mortal S19 E01', 'http://sinalprivado.info:80/series/1533784/1533784/686643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164105, 11656, 'Pesca Mortal S19 E02', 'http://sinalprivado.info:80/series/1533784/1533784/686644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164106, 11656, 'Pesca Mortal S19 E03', 'http://sinalprivado.info:80/series/1533784/1533784/686645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164107, 11656, 'Pesca Mortal S19 E04', 'http://sinalprivado.info:80/series/1533784/1533784/686646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164108, 11656, 'Pesca Mortal S19 E05', 'http://sinalprivado.info:80/series/1533784/1533784/686647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164109, 11656, 'Pesca Mortal S19 E06', 'http://sinalprivado.info:80/series/1533784/1533784/686648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164110, 11656, 'Pesca Mortal S19 E07', 'http://sinalprivado.info:80/series/1533784/1533784/686649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164111, 11656, 'Pesca Mortal S19 E08', 'http://sinalprivado.info:80/series/1533784/1533784/686650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164112, 11656, 'Pesca Mortal S19 E09', 'http://sinalprivado.info:80/series/1533784/1533784/686651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164113, 11656, 'Pesca Mortal S19 E10', 'http://sinalprivado.info:80/series/1533784/1533784/686652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164114, 11656, 'Pesca Mortal S19 E11', 'http://sinalprivado.info:80/series/1533784/1533784/686653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164115, 11656, 'Pesca Mortal S19 E12', 'http://sinalprivado.info:80/series/1533784/1533784/686654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164116, 11656, 'Pesca Mortal S19 E13', 'http://sinalprivado.info:80/series/1533784/1533784/686655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164117, 11656, 'Pesca Mortal S19 E14', 'http://sinalprivado.info:80/series/1533784/1533784/686656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164118, 11656, 'Pesca Mortal S19 E15', 'http://sinalprivado.info:80/series/1533784/1533784/686657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164119, 11656, 'Pesca Mortal S19 E16', 'http://sinalprivado.info:80/series/1533784/1533784/686658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164120, 11656, 'Pesca Mortal S19 E17', 'http://sinalprivado.info:80/series/1533784/1533784/686659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164121, 11656, 'Pesca Mortal S19 E18', 'http://sinalprivado.info:80/series/1533784/1533784/686660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164122, 11656, 'Pesca Mortal S19 E19', 'http://sinalprivado.info:80/series/1533784/1533784/686661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164123, 11656, 'Pesca Mortal S19 E20', 'http://sinalprivado.info:80/series/1533784/1533784/686662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164124, 11656, 'Pesca Mortal S19 E21', 'http://sinalprivado.info:80/series/1533784/1533784/686663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164125, 11656, 'Pesca Mortal S19 E22', 'http://sinalprivado.info:80/series/1533784/1533784/686664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164126, 11657, 'Pesca Mortal S20 E01', 'http://sinalprivado.info:80/series/1533784/1533784/496162.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/af66Dc5vdzFs5Bg83KstG5SZKEy.jpg'),
(164127, 11657, 'Pesca Mortal S20 E02', 'http://sinalprivado.info:80/series/1533784/1533784/496163.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/usZb6kpmX9YYQ17OYWq4w0BZeBV.jpg'),
(164128, 11657, 'Pesca Mortal S20 E03', 'http://sinalprivado.info:80/series/1533784/1533784/496164.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p8N3gN615ydg1aVNla3xlJAoVaT.jpg'),
(164129, 11657, 'Pesca Mortal S20 E04', 'http://sinalprivado.info:80/series/1533784/1533784/496165.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/svNQNmdezwhI21l0vc3wgHHXVRb.jpg'),
(164130, 11657, 'Pesca Mortal S20 E05', 'http://sinalprivado.info:80/series/1533784/1533784/496166.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hUfGU0koEYmw655PQxoxwOKCPo1.jpg'),
(164131, 11657, 'Pesca Mortal S20 E06', 'http://sinalprivado.info:80/series/1533784/1533784/496167.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jXElBK6DEMEnYOJuH5TVf60mzO1.jpg'),
(164132, 11657, 'Pesca Mortal S20 E07', 'http://sinalprivado.info:80/series/1533784/1533784/505386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164133, 11657, 'Pesca Mortal S20 E08', 'http://sinalprivado.info:80/series/1533784/1533784/505387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164134, 11657, 'Pesca Mortal S20 E09', 'http://sinalprivado.info:80/series/1533784/1533784/513281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164135, 11657, 'Pesca Mortal S20 E10', 'http://sinalprivado.info:80/series/1533784/1533784/515401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164136, 11657, 'Pesca Mortal S20 E11', 'http://sinalprivado.info:80/series/1533784/1533784/522401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164137, 11657, 'Pesca Mortal S20 E12', 'http://sinalprivado.info:80/series/1533784/1533784/522402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164138, 11657, 'Pesca Mortal S20 E13', 'http://sinalprivado.info:80/series/1533784/1533784/638263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164139, 11657, 'Pesca Mortal S20 E14', 'http://sinalprivado.info:80/series/1533784/1533784/643905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164140, 11657, 'Pesca Mortal S20 E15', 'http://sinalprivado.info:80/series/1533784/1533784/657951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164141, 11657, 'Pesca Mortal S20 E16', 'http://sinalprivado.info:80/series/1533784/1533784/661768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164142, 11657, 'Pesca Mortal S20 E17', 'http://sinalprivado.info:80/series/1533784/1533784/667772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164143, 11657, 'Pesca Mortal S20 E18', 'http://sinalprivado.info:80/series/1533784/1533784/677477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164144, 11657, 'Pesca Mortal S20 E19', 'http://sinalprivado.info:80/series/1533784/1533784/685358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/c0VnIYgnQcNj9HnRZEC1IlvR8EZ.jpg'),
(164145, 11658, 'Destino Final Palm Glade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/494314.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fKQEgck9A5Om7FYDBS3C1Tyuq6W.jpg'),
(164146, 11658, 'Destino Final Palm Glade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/494315.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j3GNlE8qLOCJlf4HOja3aZwvJxb.jpg'),
(164147, 11658, 'Destino Final Palm Glade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/494316.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2V8Ru9485495BUPWn2ZKrIzWxt5.jpg'),
(164148, 11658, 'Destino Final Palm Glade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/494317.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2C2XuOi92FEGDFvNYCy6uhpSMkI.jpg'),
(164149, 11658, 'Destino Final Palm Glade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/494318.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rP9qLKxew5DLJWkhAoBUaxbGdbN.jpg'),
(164150, 11658, 'Destino Final Palm Glade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/494319.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xU9HwCP53Yi1XH7YmLHO0jsy75w.jpg'),
(164151, 11658, 'Destino Final Palm Glade S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/494320.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cCHXoHmanqblpVa9RNQp396If3M.jpg'),
(164152, 11658, 'Destino Final Palm Glade S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/494321.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fB0jushduaXZfdSKIbKD39etCxK.jpg'),
(164153, 11658, 'Destino Final Palm Glade S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/494322.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iZI9hSQNQczdioTXVmlRQs16UAX.jpg'),
(164154, 11658, 'Destino Final Palm Glade S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/494323.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oDJPbBFNMELiKSD8AhirQPgOVGE.jpg'),
(164155, 11658, 'Destino Final Palm Glade S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/494324.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pT4j1HtOpA1yjJkyzIny9b8oTaX.jpg'),
(164156, 11658, 'Destino Final Palm Glade S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/494325.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fMlgN2G5Zlk7g7E5Ook4GkZ4d2T.jpg'),
(164157, 11658, 'Destino Final Palm Glade S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/494326.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r8KfIQhzo8OEMZ0DlEPcPbzAteK.jpg'),
(164158, 11659, 'Destino Final Palm Glade S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/494327.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5TaIzDAzvCn2c06DUo7AG3EnLXk.jpg'),
(164159, 11659, 'Destino Final Palm Glade S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/494328.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hNIz3d5TJHQsms27CAjbE36uBUp.jpg'),
(164160, 11659, 'Destino Final Palm Glade S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/494329.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iBJ3gNDsf6sodEWiSJvaRhGHxGj.jpg'),
(164161, 11659, 'Destino Final Palm Glade S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/494330.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eeJsetV8y30kjG9tR62OkO0xJLj.jpg'),
(164162, 11659, 'Destino Final Palm Glade S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/494331.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5L5ssWA7VvuPBJMX3zXWPYlawB1.jpg'),
(164163, 11659, 'Destino Final Palm Glade S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/494332.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gsToSiHr4K3dLenTxaTxBN6tvZr.jpg'),
(164164, 11659, 'Destino Final Palm Glade S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/494333.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/scGj1YeX0A4CrCOwXksLtQ8Ri4o.jpg'),
(164165, 11659, 'Destino Final Palm Glade S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/494334.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ygsfJAA3gR4Np2oI1dau8fWAFRp.jpg'),
(164166, 11659, 'Destino Final Palm Glade S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/494335.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jcae3M1WPz5aA9ywN7oMbqFyYOk.jpg'),
(164167, 11659, 'Destino Final Palm Glade S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/494336.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cT6Kdo1NIxEkfO0975mCz3oT4nX.jpg'),
(164168, 11659, 'Destino Final Palm Glade S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/494337.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/49uX8VbarpKeyQaXcK12TR1HJxq.jpg'),
(164169, 11659, 'Destino Final Palm Glade S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/494338.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/MFIYRqglLyyq6VSB7QXlMZLY45.jpg'),
(164170, 11659, 'Destino Final Palm Glade S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/494339.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jN6ZS7NBMTqjchaTvEQewq3lfRG.jpg'),
(164171, 11660, 'Destino Final Palm Glade S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/494340.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rdSALW16QNk7lDtUS6Chus3d0tX.jpg'),
(164172, 11660, 'Destino Final Palm Glade S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/494341.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vWeTJSvbeCfaP0PYDyCu05sbwDP.jpg'),
(164173, 11660, 'Destino Final Palm Glade S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/494342.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rdP09xbstN4MQbbq5prUrTBmWu6.jpg'),
(164174, 11660, 'Destino Final Palm Glade S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/494343.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g0j0E1ev04XE5XtjOwvvxO30slI.jpg'),
(164175, 11660, 'Destino Final Palm Glade S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/494344.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4NAxZrMl90LAyHJzOWdvIhgetoe.jpg'),
(164176, 11660, 'Destino Final Palm Glade S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/494345.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9OpVT6bHkqtMb0ncAURT8etGjsJ.jpg'),
(164177, 11660, 'Destino Final Palm Glade S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/494346.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5wh6nGlNpBoHeyY5dmOBxswchYy.jpg'),
(164178, 11660, 'Destino Final Palm Glade S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/494347.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pUmuGbpkrqcQOVHEPAUv1u1zEN7.jpg'),
(164179, 11660, 'Destino Final Palm Glade S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/494348.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lJnahuggkdvAyTRCXRKp9Qvs6WN.jpg'),
(164180, 11660, 'Destino Final Palm Glade S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/494349.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5ZWkUYDtw7kHXQwpSO5QKTkwTRV.jpg'),
(164181, 11661, 'Destino Final Palm Glade S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/494350.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kZazvw4o0TElRXruoboTEQDyY7v.jpg'),
(164182, 11661, 'Destino Final Palm Glade S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/494351.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/udIYQj9QhcUAjlv0J3bRW1DcCKa.jpg'),
(164183, 11661, 'Destino Final Palm Glade S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/494352.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iwid1HK1BLs6p9n2LBjbX4tUitR.jpg'),
(164184, 11661, 'Destino Final Palm Glade S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/494353.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zsEo7ilNLKK2aumb41o9gJqnwZt.jpg'),
(164185, 11661, 'Destino Final Palm Glade S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/494354.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eQ59Ad3RCxiS8cxDWcyVNRBvREF.jpg'),
(164186, 11661, 'Destino Final Palm Glade S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/494355.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iq9Jr0gB0Bqqp9jBA9pxONijbxk.jpg'),
(164187, 11661, 'Destino Final Palm Glade S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/494356.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a7ntMzNptMd53Lc28J2IXjGFuzB.jpg'),
(164188, 11661, 'Destino Final Palm Glade S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/494357.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uRcRtMVwK1Dvg0AZLwFOVrtRMHn.jpg'),
(164189, 11661, 'Destino Final Palm Glade S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/494358.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nfwho3zffDElcTZDMMczr30Ji6H.jpg'),
(164190, 11661, 'Destino Final Palm Glade S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/494359.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ycTFxTEs1jyq2ievnRvrhlyvXnV.jpg'),
(164191, 11661, 'Destino Final Palm Glade S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/494360.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zju8c5Nl0V3ct6JamYJIaYJEaA0.jpg'),
(164192, 11661, 'Destino Final Palm Glade S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/494361.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wQZVnuaD0AEUIQhfVaBOARUWq9Z.jpg'),
(164193, 11661, 'Destino Final Palm Glade S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/494362.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d6OsE7WEtqoWc5IkppippMqJbvi.jpg'),
(164194, 11662, 'Os Simpsons S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500604.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3j10k0OIY2yRhguiyEEDdNnTRw9.jpg'),
(164195, 11662, 'Os Simpsons S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500605.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vaXc0rNWRhwcpUZc0ejK9E9fwsM.jpg'),
(164196, 11662, 'Os Simpsons S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500606.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tPxc5e1hk6eUP1apMbKVb6GohXX.jpg'),
(164197, 11662, 'Os Simpsons S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500607.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tEgv8vl308F3uM3jYmfRZXZlhSL.jpg'),
(164198, 11662, 'Os Simpsons S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500608.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zKi8d86pry4Qj2SiUrsGQdQZbYm.jpg'),
(164199, 11662, 'Os Simpsons S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/500609.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zmu0zpREHn6RRxbvS3oxmIPeiDd.jpg'),
(164200, 11662, 'Os Simpsons S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/500610.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l0Q73yGXKYook8gsBFITff3pSth.jpg'),
(164201, 11662, 'Os Simpsons S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/500611.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4xhe3umFrTMHpxuAXUKi2zNFNJg.jpg'),
(164202, 11662, 'Os Simpsons S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/500612.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8YgLazRliTXKZlwZN7Qnr9Z86gW.jpg'),
(164203, 11662, 'Os Simpsons S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/500613.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g3cCmeaIiCmSx7i5p0Mo0rWOqhH.jpg'),
(164204, 11662, 'Os Simpsons S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/500614.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fGWXSAweEAbzTxoR62gsc14e1gt.jpg'),
(164205, 11662, 'Os Simpsons S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/500615.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hbnL7T4HMYeogFMagx5Qc6wGaSB.jpg'),
(164206, 11662, 'Os Simpsons S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/500616.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vs6Rr5NqODPZnSm18SeoBI7d9Xc.jpg'),
(164207, 11663, 'Os Simpsons S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500617.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uu4Xyfc2ceDF1fUOZuYOUOBFp1e.jpg'),
(164208, 11663, 'Os Simpsons S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500618.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6cs49lUDM3wImex0w2gnAlw3dq3.jpg'),
(164209, 11663, 'Os Simpsons S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500619.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fn3vVIu3jQoygMdcZBomUQJg8pF.jpg'),
(164210, 11663, 'Os Simpsons S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500620.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ku11Kcqz7rzAsqbkhx15BbKZZtB.jpg'),
(164211, 11663, 'Os Simpsons S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500621.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cAioTdV38QEms5UtiQyZdxyHI9D.jpg'),
(164212, 11663, 'Os Simpsons S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/500622.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/22aHMEPWfRqOLbzASI8fyuoBBEL.jpg'),
(164213, 11663, 'Os Simpsons S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/500623.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k0ahzHBXD46LCKLI1xogy9m95AG.jpg'),
(164214, 11663, 'Os Simpsons S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/500624.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uONSQsPJwiq18mQukHSAGXiAaLN.jpg'),
(164215, 11663, 'Os Simpsons S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/500625.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gR6NU8rl4ElEkLi69feiD4IJKIy.jpg'),
(164216, 11663, 'Os Simpsons S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/500626.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iktR0XuBPJHEHqmRjwo4HKqdkPw.jpg'),
(164217, 11663, 'Os Simpsons S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/500627.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AdbRkunWr3yRbQD66DGJaIwmBmN.jpg'),
(164218, 11663, 'Os Simpsons S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/500628.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/osutS8IJtjo9qOfeNGK0kEep0V.jpg'),
(164219, 11663, 'Os Simpsons S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/500629.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kbMszxJqQWDQKVWK0RKy2N9REiJ.jpg'),
(164220, 11663, 'Os Simpsons S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/500630.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gbGO7vBVkoZ41iWmFMPE0Hkgb0V.jpg'),
(164221, 11663, 'Os Simpsons S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/500631.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zGmGslqh8BRkJ7VEH0h6p2AUPee.jpg'),
(164222, 11663, 'Os Simpsons S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/500632.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1KPtp6dSfbsgRyZDY11tMNmUCYk.jpg'),
(164223, 11663, 'Os Simpsons S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/500633.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r4Ep38sEljrbhZ50xoI5kWd3BiK.jpg'),
(164224, 11663, 'Os Simpsons S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/500634.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uF2l60fu1pgUxxsDFOsSdQ660AN.jpg'),
(164225, 11663, 'Os Simpsons S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/500635.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c4qViYIMe2s3awGr5E19U92CC8Y.jpg'),
(164226, 11663, 'Os Simpsons S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/500636.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zs22jpXWYbQJDavcZ5IoSLu1TFC.jpg'),
(164227, 11663, 'Os Simpsons S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/500637.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yK3anNbQqsQfIh9Yjq23ISMpkIT.jpg'),
(164228, 11663, 'Os Simpsons S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/500638.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hs2ZFWVFvRwe7Kq3jEbP3p22jPV.jpg'),
(164229, 11664, 'Os Simpsons S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500639.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jQ6CWtYt9S6z4K9CNQtlmMiVC66.jpg'),
(164230, 11664, 'Os Simpsons S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500640.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yhx9y1YUcIWiZzQLQxrF36Bc7xi.jpg'),
(164231, 11664, 'Os Simpsons S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500641.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fhIV6InRE921DsX7VhcOC5VwipN.jpg'),
(164232, 11664, 'Os Simpsons S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500642.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pTu7QSnxLSO5xIynGWXZB4J2B68.jpg'),
(164233, 11664, 'Os Simpsons S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500643.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/76ZFVwrqjKA5OYoRzQ8f3svHKdc.jpg'),
(164234, 11664, 'Os Simpsons S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/500644.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n0knCzPo8XBLPZVmbEP7Diy8gS3.jpg'),
(164235, 11664, 'Os Simpsons S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/500645.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qRZ4zwUUW3WrbMPE3spKn55QMsh.jpg'),
(164236, 11664, 'Os Simpsons S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/500646.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kreYHDwrimjnAvuuQkovc7Fafei.jpg'),
(164237, 11664, 'Os Simpsons S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/500647.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yHmCDDJBewNfjOa5Ms2Mv1SySvf.jpg'),
(164238, 11664, 'Os Simpsons S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/500648.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gXnzw75dydHdeIH4W57T3vzSGup.jpg'),
(164239, 11664, 'Os Simpsons S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/500649.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/muJ6QcKL4Mt0hDyUnd0WisR3J9t.jpg'),
(164240, 11664, 'Os Simpsons S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/500650.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e6pljYsk6yvkOpQfVtDNqHUY31J.jpg'),
(164241, 11664, 'Os Simpsons S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/500651.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kFw2WgIxo9JbHMXCAxLyhgvCGFH.jpg'),
(164242, 11664, 'Os Simpsons S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/500652.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5WFTPQgtC2Wja5niRg9yevyh3qu.jpg'),
(164243, 11664, 'Os Simpsons S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/500653.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jmjNcQoD5QTNuhR9GlWxDbKYezy.jpg'),
(164244, 11664, 'Os Simpsons S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/500654.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bZ40XQsFYTQhTQpx3AK03YA9NBG.jpg'),
(164245, 11664, 'Os Simpsons S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/500655.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bBKkizYfKmJcp2bTl0XiBFJwxwN.jpg'),
(164246, 11664, 'Os Simpsons S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/500656.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t40Miysb61S1pwVWR7akHPTA98T.jpg'),
(164247, 11664, 'Os Simpsons S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/500657.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oEKUfOH2geBxiHEZgyiXoA5OumK.jpg'),
(164248, 11664, 'Os Simpsons S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/500658.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bTLzblLoOl77WMYcTtTv5b5oWnF.jpg'),
(164249, 11664, 'Os Simpsons S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/500659.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yiTXk1s1IxqRBHw6ycfyRHLrnfH.jpg'),
(164250, 11664, 'Os Simpsons S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/500660.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/onnsBE4nrzVjXapcBVskgnNPWYn.jpg'),
(164251, 11664, 'Os Simpsons S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/500661.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ytqkO5TT7DXojM70iFVYFaaKWMV.jpg'),
(164252, 11664, 'Os Simpsons S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/500662.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aJEKhpC8op2xihc3bbeDN8RwHkS.jpg'),
(164253, 11665, 'Os Simpsons S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500663.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6EoVQhrq6UOk3UBzeBGwJJz08Kh.jpg'),
(164254, 11665, 'Os Simpsons S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500664.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pDjGyQT5FbjvQWRNLQRBS76ooKt.jpg'),
(164255, 11665, 'Os Simpsons S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500665.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wilxhMIPn9VhmRFTjyM2Mjqo44L.jpg'),
(164256, 11665, 'Os Simpsons S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500666.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i9LwMK7AP5O1M6wdJ8lkfdvh5T.jpg'),
(164257, 11665, 'Os Simpsons S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500667.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lEojftT4NydQtBbDBEzNifIt2LQ.jpg'),
(164258, 11665, 'Os Simpsons S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/500668.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nIdGe37LMkHHu7An5u869eq0jJG.jpg'),
(164259, 11665, 'Os Simpsons S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/500669.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aRZbAcKvkCpCn1oxvliwrS6IDMd.jpg'),
(164260, 11665, 'Os Simpsons S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/500670.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jlCmgPGiGc7ZjzjI4Q8FGxDOqaL.jpg'),
(164261, 11665, 'Os Simpsons S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/500671.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w15pg6uJc7ouZE7UlMtKSItLJeR.jpg'),
(164262, 11665, 'Os Simpsons S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/500672.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hKBTWStS7DHRUxtniHTIPq6Jw9W.jpg'),
(164263, 11665, 'Os Simpsons S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/500673.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qljHnXrfSUvkKQnkx7mzKxcyNAt.jpg'),
(164264, 11665, 'Os Simpsons S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/500674.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/acwoGrLEdaUEw4T0O9u2xYuPLz.jpg'),
(164265, 11665, 'Os Simpsons S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/500675.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/feDzbYBzcmy0Z5Q9IEjPmMIRv3O.jpg'),
(164266, 11665, 'Os Simpsons S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/500676.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wxbuu42dsewGw3VYmyepgluJIhT.jpg'),
(164267, 11665, 'Os Simpsons S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/500677.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xJ6sqPvze56B2iSsz2Hbm0QTVaA.jpg'),
(164268, 11665, 'Os Simpsons S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/500678.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zUuDpJCgzudFFyVtgRgAy9r5Wmt.jpg'),
(164269, 11665, 'Os Simpsons S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/500679.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xaECGLjFTGZF7PJpAMLE6yfOEpr.jpg'),
(164270, 11665, 'Os Simpsons S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/500680.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r5UGabzVmub1ZYxg1SPSY8xnBUH.jpg'),
(164271, 11665, 'Os Simpsons S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/500681.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xP5TnHNcLyVVqAXutDsTmzrUETP.jpg'),
(164272, 11665, 'Os Simpsons S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/500682.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xNb05Ls23IWWkSXtwRyI1QXesP1.jpg'),
(164273, 11665, 'Os Simpsons S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/500683.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wxVjnBlZHWAg8KETRGEKWKg0Orf.jpg'),
(164274, 11665, 'Os Simpsons S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/500684.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nPGlBGrnCSo9pP77dNelraribUr.jpg'),
(164275, 11666, 'Os Simpsons S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500685.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9IV7ORotDcT8m6n7bBEMg0ZeBvZ.jpg'),
(164276, 11666, 'Os Simpsons S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500686.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7jzTrfSakoBjBUWrQ85jA9K4H00.jpg'),
(164277, 11666, 'Os Simpsons S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500687.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9k3Dj5UBho5pFwX4DhAHo1rF0Ic.jpg'),
(164278, 11666, 'Os Simpsons S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500688.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xekqIZuJRqP1xGfQoNhmsNlwJB4.jpg'),
(164279, 11666, 'Os Simpsons S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500689.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7G1KjBt1yvhUzwHFZNsKET3exea.jpg'),
(164280, 11666, 'Os Simpsons S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/500690.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/onltAK4OWpPVw0vEEFbVjpNW1Xu.jpg'),
(164281, 11666, 'Os Simpsons S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/500691.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eKFCtqz9SgmTlsvLk71NhMrYlzR.jpg'),
(164282, 11666, 'Os Simpsons S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/500692.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tGir1Jf3JsYlXcfdm29SzoqdV5h.jpg'),
(164283, 11666, 'Os Simpsons S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/500693.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gaFL3cAedTpS77KTvU9iq0m9YkI.jpg'),
(164284, 11666, 'Os Simpsons S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/500694.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ll44I7PnnU55SiG5R2QPAQQRAUa.jpg'),
(164285, 11666, 'Os Simpsons S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/500695.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pRgmMCZzu7gwDbdrNJDF8OaNmuN.jpg'),
(164286, 11666, 'Os Simpsons S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/500696.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4CBra5bUOrTKV8rcdz0LXX3W8pZ.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(164287, 11666, 'Os Simpsons S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/500697.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/onaCUyUhtQthJfjFJXLb8qeLD7Y.jpg'),
(164288, 11666, 'Os Simpsons S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/500698.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tJnSyhaq87qeZZeYKj8RhnqcSNe.jpg'),
(164289, 11666, 'Os Simpsons S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/500699.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kxwK6540qpra3kmnVfldNKOFbRI.jpg'),
(164290, 11666, 'Os Simpsons S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/500700.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qKBkMYL2nLxyYN4P9tGbPpJE1Rq.jpg'),
(164291, 11666, 'Os Simpsons S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/500701.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jvZhuAzHEPvdVVMScGuAymhAdPS.jpg'),
(164292, 11666, 'Os Simpsons S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/500702.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oqlwa6cxsdeAvk9Cta2hjYSOEzh.jpg'),
(164293, 11666, 'Os Simpsons S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/500703.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ba4sh9jxbEet4LKAHj4pPi06srx.jpg'),
(164294, 11666, 'Os Simpsons S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/500704.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yCRZfaIbiFBsTu1v06fGTgcchJL.jpg'),
(164295, 11666, 'Os Simpsons S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/500705.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ubyg8hnpwt2tCSDVMwMeFOSqs1.jpg'),
(164296, 11666, 'Os Simpsons S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/500706.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gSIdAQC1IqvyF8g79SH43hit3v7.jpg'),
(164297, 11667, 'Os Simpsons S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500707.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iSNNSrsde7kHLoZQTufeGzNg9A2.jpg'),
(164298, 11667, 'Os Simpsons S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500708.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c1nMJaXXrj0LhqZ5htcNfStmFUL.jpg'),
(164299, 11667, 'Os Simpsons S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500709.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pyvCKDJzwgUmEUMkfx5CQMIbC63.jpg'),
(164300, 11667, 'Os Simpsons S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500710.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p3ilqhwjmdiL5Cr09zSO4iud2Yb.jpg'),
(164301, 11667, 'Os Simpsons S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500711.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8KoFSWkImPUXp0TTIqCw6Lz3UgP.jpg'),
(164302, 11667, 'Os Simpsons S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/500712.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x7nae0xArRHmVaufd8dzNGuAIHl.jpg'),
(164303, 11667, 'Os Simpsons S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/500713.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kH5tvvlPI3e4GgdU3BByBomxQpo.jpg'),
(164304, 11667, 'Os Simpsons S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/500714.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/opPPFSmHQUCYLVACgMl392w5DsG.jpg'),
(164305, 11667, 'Os Simpsons S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/500715.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dX2kCLp0rdDWiJCmKG3p5AthAJK.jpg'),
(164306, 11667, 'Os Simpsons S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/500716.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gnvZwWSA0YwQS9dWmbqJWUugNf4.jpg'),
(164307, 11667, 'Os Simpsons S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/500717.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wXXdJ3OBexmtOjQq17a1JNxYEzI.jpg'),
(164308, 11667, 'Os Simpsons S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/500718.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/anSzEzeNwYEDgQ0zX7AoB6zaNE4.jpg'),
(164309, 11667, 'Os Simpsons S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/500719.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/buKiAgMyQYLk4rPIgmJgeFiVHlz.jpg'),
(164310, 11667, 'Os Simpsons S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/500720.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pMYNYVdPvhkIvLT7d7ntIxZV7s.jpg'),
(164311, 11667, 'Os Simpsons S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/500721.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/afXOok8CgDaBKsvSbeWDehIxGdY.jpg'),
(164312, 11667, 'Os Simpsons S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/500722.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sbBpslqmNSojux13Vqpe3TfIsbS.jpg'),
(164313, 11667, 'Os Simpsons S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/500723.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ndXn2XJGzEPwoG8JP19tbbaTdtC.jpg'),
(164314, 11667, 'Os Simpsons S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/500724.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mFRzrwM1LOcvKPmkva1ZaAeGHzT.jpg'),
(164315, 11667, 'Os Simpsons S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/500725.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/alttjLtNqrNDm7rfOPLvJ0oqru7.jpg'),
(164316, 11667, 'Os Simpsons S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/500726.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iO0DhZAsARtgp9C0GqiJyTJwzMZ.jpg'),
(164317, 11667, 'Os Simpsons S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/500727.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zvbLXQfK3mp1wRtk4AURRaP7Xqs.jpg'),
(164318, 11667, 'Os Simpsons S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/500728.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cC5K4fZTzylj14GOUgqUkv3rCXo.jpg'),
(164319, 11667, 'Os Simpsons S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/500729.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5cTr6y8edvEK0xv1TudqHeBgBDB.jpg'),
(164320, 11667, 'Os Simpsons S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/500730.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fkmX6NgeDnoUj5Tbzr8kfEOVyUd.jpg'),
(164321, 11667, 'Os Simpsons S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/500731.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bgpIb655Et20R6yeKdceWoFs8jS.jpg'),
(164322, 11668, 'Os Simpsons S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500732.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uWhWWxHSEhTz0t2NwdeOOEzxDhJ.jpg'),
(164323, 11668, 'Os Simpsons S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500733.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uEtSO6K5qtR8TA8YbLk62j2Pnms.jpg'),
(164324, 11668, 'Os Simpsons S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500734.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a7UFQtlCUUa6Tziw296x9avOPFn.jpg'),
(164325, 11668, 'Os Simpsons S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500735.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w1VIj9HpmBLGsrwmY34JJskx9aX.jpg'),
(164326, 11668, 'Os Simpsons S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500736.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r9KDk1OhGGxlBg5TGJsgjVvttra.jpg'),
(164327, 11668, 'Os Simpsons S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/500737.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o6v9bqo6XQqv3pQPhmcUH8byDAn.jpg'),
(164328, 11668, 'Os Simpsons S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/500738.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/34Nklgs7aep7KlepPK38oEEdAnA.jpg'),
(164329, 11668, 'Os Simpsons S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/500739.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ye2SHNWbxcQ8e0rwfEZv2PgrG9O.jpg'),
(164330, 11668, 'Os Simpsons S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/500740.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3tpGzrQ0UhKXLLoJ6Gkcs42BEGn.jpg'),
(164331, 11668, 'Os Simpsons S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/500741.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7pWLL2sgcD5pz9qBpIpqHi5IKBY.jpg'),
(164332, 11668, 'Os Simpsons S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/500742.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tuCBzfbNxRV1eBs0fAEI45Fnysu.jpg'),
(164333, 11668, 'Os Simpsons S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/500743.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ieNQwVTouhbPjcTiQoZGnnQHSa3.jpg'),
(164334, 11668, 'Os Simpsons S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/500744.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/updqD7jNQMdCridf9bC5m1P98VZ.jpg'),
(164335, 11668, 'Os Simpsons S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/500745.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sHrAKxycReLmpelDiVs4G6DibKV.jpg'),
(164336, 11668, 'Os Simpsons S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/500746.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iuW4hezvjnUCuDdcbpHOaBXeuNP.jpg'),
(164337, 11668, 'Os Simpsons S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/500747.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pnWiNsKdBZZ5iO3iXslCvTIqhmz.jpg'),
(164338, 11668, 'Os Simpsons S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/500748.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oN3BBW0S0jnkaHBHBAVjMKz2snS.jpg'),
(164339, 11668, 'Os Simpsons S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/500749.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c7k6F2iemlzrhQ0hts00T6zPT43.jpg'),
(164340, 11668, 'Os Simpsons S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/500750.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5MkRIP5CK5HMzZypvc2P4ByaQpB.jpg'),
(164341, 11668, 'Os Simpsons S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/500751.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fgcxXdHfNmz8OSZ5GShDQdVp0SV.jpg'),
(164342, 11668, 'Os Simpsons S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/500752.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yqDVsSSsPMBwet6uHohiPCp95J2.jpg'),
(164343, 11668, 'Os Simpsons S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/500753.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yLkYhwbM0n4igokYy6H3X2EESvm.jpg'),
(164344, 11668, 'Os Simpsons S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/500754.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v74SN1qRQ4HVhpluoV7ACPUYhKM.jpg'),
(164345, 11668, 'Os Simpsons S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/500755.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qylq5ZKK3XFjs3Wz3Zr3tmN72GC.jpg'),
(164346, 11668, 'Os Simpsons S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/500756.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tPaaWGAQZW6YWvRJ3IMQPwt2fSB.jpg'),
(164347, 11669, 'Os Simpsons S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500757.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mL04FwIjuP8X7uBLtUi01zhoxyY.jpg'),
(164348, 11669, 'Os Simpsons S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500758.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5yDjmB7NrXMtYFcak0QEYFp9qVv.jpg'),
(164349, 11669, 'Os Simpsons S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500759.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oa1oFFg6yU5mpHRJQqbFJDHn3Iq.jpg'),
(164350, 11669, 'Os Simpsons S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500760.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/skMTpzC4EmKwF0F8vmX3fC42Y1e.jpg'),
(164351, 11669, 'Os Simpsons S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500761.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bAG3fyaeWdClLcx0GQfGgQGgZDx.jpg'),
(164352, 11669, 'Os Simpsons S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/500762.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wcccUPyHAAivlQ4Wt1CTtiblLIC.jpg'),
(164353, 11669, 'Os Simpsons S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/500763.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AgDDQrPyOgo66QubZQCMVoYuLDs.jpg'),
(164354, 11669, 'Os Simpsons S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/500764.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v87zvuX2zDWPZWciHggsTnDD7E4.jpg'),
(164355, 11669, 'Os Simpsons S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/500765.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/odYr06dBSr6X3V11dL7p2RVKw0I.jpg'),
(164356, 11669, 'Os Simpsons S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/500766.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dRxYLu23hwmtojefqvUZU7EsmFs.jpg'),
(164357, 11669, 'Os Simpsons S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/500767.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7dPqry0xkQ8pxSgjIA3i6qwORQ.jpg'),
(164358, 11669, 'Os Simpsons S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/500768.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ykfdIBg4ldQwwLJQHtocM5pHya6.jpg'),
(164359, 11669, 'Os Simpsons S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/500769.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5vreDUmZ3XwZ9bVvM3Fdvl4j91t.jpg'),
(164360, 11669, 'Os Simpsons S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/500770.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kBz3EqFih9LBAdly1b7XpoLwUQj.jpg'),
(164361, 11669, 'Os Simpsons S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/500771.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mP8WN7aAqJfpOuSYSzBOC0WT59s.jpg'),
(164362, 11669, 'Os Simpsons S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/500772.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cVtj8JCHpHMYZA9dYS51qqykdMO.jpg'),
(164363, 11669, 'Os Simpsons S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/500773.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yPIxXcACCdxoDamGb6GLWQPIHwT.jpg'),
(164364, 11669, 'Os Simpsons S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/500774.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/RxlAo0xzWLbuvYeF4B7Sn4WjxJ.jpg'),
(164365, 11669, 'Os Simpsons S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/500775.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b4owvTFjubmWDKoDBmR9yp3IIgz.jpg'),
(164366, 11669, 'Os Simpsons S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/500776.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/flA3uN8dlPmi5SCKPjyaDXdrf2X.jpg'),
(164367, 11669, 'Os Simpsons S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/500777.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/55Njc97Jg38Ik8nDItk0MQkRXf4.jpg'),
(164368, 11669, 'Os Simpsons S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/500778.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nMCWgeBsbSn2pz5j0P47hUGKr85.jpg'),
(164369, 11669, 'Os Simpsons S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/500779.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6iS2L9QpaszsXvqdseHoxWI332Z.jpg'),
(164370, 11669, 'Os Simpsons S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/500780.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4CkktOGgpjwg5B1gYS4EFmSrPGS.jpg'),
(164371, 11669, 'Os Simpsons S08 E25', 'http://sinalprivado.info:80/series/1533784/1533784/500781.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/blHMT36Y9SQXmCWHJrU1gCps5i5.jpg'),
(164372, 11670, 'Os Simpsons S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500782.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2MBShJiJbR2SAakfL6wdhn1vhWk.jpg'),
(164373, 11670, 'Os Simpsons S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500783.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7u1EAzK2x92P9qPyWntmXMbUBzw.jpg'),
(164374, 11670, 'Os Simpsons S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500784.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9yWqeSSIA0jeZhQv84fwC8kEGy7.jpg'),
(164375, 11670, 'Os Simpsons S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500785.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tHwFPX4nFbB54tFNsKkcSChmF5E.jpg'),
(164376, 11670, 'Os Simpsons S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500786.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9HP2HQ03HIqw6XOcqbFDokZtmo7.jpg'),
(164377, 11670, 'Os Simpsons S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/500787.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d0YCBcmfwXdpDpwcALJiTEbfZQs.jpg'),
(164378, 11670, 'Os Simpsons S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/500788.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dgHd8p3UeLRO9j6ZEczV2sORvDQ.jpg'),
(164379, 11670, 'Os Simpsons S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/500789.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7tFVM21s4lmgQultuHNW9hHk9cE.jpg'),
(164380, 11670, 'Os Simpsons S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/500790.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/opQZb5PztKSAtbBL36dQ6Bw7i5u.jpg'),
(164381, 11670, 'Os Simpsons S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/500791.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pkCfsDqeEJTf82TF0X5QeIV4FtL.jpg'),
(164382, 11670, 'Os Simpsons S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/500792.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6JfR7bcsycX3e8wNHe4sc1H10VY.jpg'),
(164383, 11670, 'Os Simpsons S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/500793.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wuBmfre0yoO94voQmy9u9UXWJna.jpg'),
(164384, 11670, 'Os Simpsons S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/500794.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6ba836HtQrNtJtWYmkOaiMn4uh6.jpg'),
(164385, 11670, 'Os Simpsons S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/500795.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wU2veVuixvSX9zswxPgVjt5rFbS.jpg'),
(164386, 11670, 'Os Simpsons S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/500796.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yUTPaVR1HsPcNdNroPOCmDMsvha.jpg'),
(164387, 11670, 'Os Simpsons S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/500797.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m7Kas9BIR3CRl9KqCPHjdi9qXIR.jpg'),
(164388, 11670, 'Os Simpsons S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/500798.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5auNDVI25QeEiIX7F1JXGVTCA5U.jpg'),
(164389, 11670, 'Os Simpsons S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/500799.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3kU5f1gZ8vEebiWeCrSLRNwz1A2.jpg'),
(164390, 11670, 'Os Simpsons S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/500800.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ugsvr8BIVwMu608c4uliM64Ho23.jpg'),
(164391, 11670, 'Os Simpsons S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/500801.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9muA2Gqn8lQLLLZe2Mo05329C0P.jpg'),
(164392, 11670, 'Os Simpsons S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/500802.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kLnxZoMV9MqOJ3g1Lfkk2YvtCFO.jpg'),
(164393, 11670, 'Os Simpsons S09 E22', 'http://sinalprivado.info:80/series/1533784/1533784/500803.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jUQXxdsYRsU3VOYUoHrx9qVMfZb.jpg'),
(164394, 11670, 'Os Simpsons S09 E23', 'http://sinalprivado.info:80/series/1533784/1533784/500804.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/15GSxZMvDZiF4W7M5V1pdU0r1hz.jpg'),
(164395, 11670, 'Os Simpsons S09 E24', 'http://sinalprivado.info:80/series/1533784/1533784/500805.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yKUgkZNLU3gKYYNpHuwmsqKEJcF.jpg'),
(164396, 11670, 'Os Simpsons S09 E25', 'http://sinalprivado.info:80/series/1533784/1533784/500806.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/anwDWp1G4BTJ1XS7KzPcEar2Dij.jpg'),
(164397, 11671, 'Os Simpsons S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500807.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5BX92Gq0mYyXYjC0zADInMmVgBI.jpg'),
(164398, 11671, 'Os Simpsons S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500808.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/edvDcVLoszXlBFHTL3RuOiO5mqL.jpg'),
(164399, 11671, 'Os Simpsons S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500809.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ttST6vuFm9rwIjHYJSs8C9aMocg.jpg'),
(164400, 11671, 'Os Simpsons S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500810.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dwicl3ahKPqKdyXvvpJav3fgPb7.jpg'),
(164401, 11671, 'Os Simpsons S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500811.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hPGIv42kRJVT5VyerB1GKrRllPw.jpg'),
(164402, 11671, 'Os Simpsons S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/500812.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/phnfWakOvuULtPb9ebY2F4N8LKK.jpg'),
(164403, 11671, 'Os Simpsons S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/500813.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cbWaF8owl8wD5yyo5K7gOSESdQ7.jpg'),
(164404, 11671, 'Os Simpsons S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/500814.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zoNBTexGBURmZlw2ruzvy5qqmM6.jpg'),
(164405, 11671, 'Os Simpsons S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/500815.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8suiIlNl3DJ64zQfBfU9OnuhUOn.jpg'),
(164406, 11671, 'Os Simpsons S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/500816.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/M3F2x4JJuOfBapvqcgy448lNgr.jpg'),
(164407, 11671, 'Os Simpsons S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/500817.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ruM6TsJuR77iqMktO4a4o01dLKe.jpg'),
(164408, 11671, 'Os Simpsons S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/500818.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h70ZgNWe0VPdK0MkdYagpuXGtYP.jpg'),
(164409, 11671, 'Os Simpsons S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/500819.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hXysSwnlvgbKk6W1mmyr3tY0NPC.jpg'),
(164410, 11671, 'Os Simpsons S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/500820.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8mRrWC78fzzI9faI1lFlIvYvmP4.jpg'),
(164411, 11671, 'Os Simpsons S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/500821.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7bE3BmgQi105cicYgJwb0qQeC3T.jpg'),
(164412, 11671, 'Os Simpsons S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/500822.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8f1SPiOpJ3zFLRMN5ftSgoRmTt2.jpg'),
(164413, 11671, 'Os Simpsons S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/500823.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4FqLumseC0jODcnuBWTzwTHnqum.jpg'),
(164414, 11671, 'Os Simpsons S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/500824.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bbRCNCZDS7roqzlx8kD95ouyjaO.jpg'),
(164415, 11671, 'Os Simpsons S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/500825.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cOR05yNHBtc55RjDR2e6Zjoq6Ba.jpg'),
(164416, 11671, 'Os Simpsons S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/500826.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vHryWyGO7IJ0jgzPbtPnSrg8EM6.jpg'),
(164417, 11671, 'Os Simpsons S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/500827.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3Dot0HpOw1nwG6jToauOa2TzCNU.jpg'),
(164418, 11671, 'Os Simpsons S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/500828.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dpzT6y1hbyEHTp7xJD9RiTFWEo5.jpg'),
(164419, 11671, 'Os Simpsons S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/500829.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iMb8agwFq0gLqjZYuWllkpGlH9V.jpg'),
(164420, 11672, 'Os Simpsons S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500830.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hvKW8cHFcsVgfeYV3aEOBbGcoy1.jpg'),
(164421, 11672, 'Os Simpsons S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500831.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tAQGR5iivfi20SAGaSG9o2yaiov.jpg'),
(164422, 11672, 'Os Simpsons S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500832.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cvzUZz5xTMsKXZDI9ANNG3xmwyM.jpg'),
(164423, 11672, 'Os Simpsons S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500833.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k4azXLZCuz4SqfqHO5yZ5S0MAS.jpg'),
(164424, 11672, 'Os Simpsons S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500834.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y0W2UfJaHwl9ouMfUFvUkqIh0g4.jpg'),
(164425, 11672, 'Os Simpsons S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/500835.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y9pQb9CsD7HTpm9LVZXGAprV7Rb.jpg'),
(164426, 11672, 'Os Simpsons S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/500836.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nWgnITT1ok5tPVTqBkjj4U4fouY.jpg'),
(164427, 11672, 'Os Simpsons S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/500837.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cr4eSWmbag0XBteqdDLNs5n50Uw.jpg'),
(164428, 11672, 'Os Simpsons S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/500838.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zSUtveL8zZZRK1GOyD7fiXsFCm0.jpg'),
(164429, 11672, 'Os Simpsons S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/500839.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hgvHujp0qecHzF0PzL8KfqQtva9.jpg'),
(164430, 11672, 'Os Simpsons S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/500840.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tyz0nQrGSP84qxfF4i85txqR9sU.jpg'),
(164431, 11672, 'Os Simpsons S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/500841.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gPDy5074E7oIRRgrJTNGQhBnyvY.jpg'),
(164432, 11672, 'Os Simpsons S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/500842.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lokGUjObk99SE9pU3mkRMe0P6Xi.jpg'),
(164433, 11672, 'Os Simpsons S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/500843.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vfXgzd9BydzFQqzz182tRZX5ugA.jpg'),
(164434, 11672, 'Os Simpsons S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/500844.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wsJzx71TGN58gPYGc4vDivqY6IP.jpg'),
(164435, 11672, 'Os Simpsons S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/500845.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5EHDsfkDZs7XFglFCoy6JG5JdWm.jpg'),
(164436, 11672, 'Os Simpsons S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/500846.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4XUiaQZiGkQqa03WRt6WUOgvTrY.jpg'),
(164437, 11672, 'Os Simpsons S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/500847.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kAm7ar3blpaHNnGyTKY6JNFlWwa.jpg'),
(164438, 11672, 'Os Simpsons S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/500848.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9nUs5q49wUNgt2plBLTgy35Ystl.jpg'),
(164439, 11672, 'Os Simpsons S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/500849.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/difS8F5CskQWrllLExJp0ABJO2m.jpg'),
(164440, 11672, 'Os Simpsons S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/500850.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tynAJOBn9Wde2kCnOOczhZxKvJ3.jpg'),
(164441, 11672, 'Os Simpsons S11 E22', 'http://sinalprivado.info:80/series/1533784/1533784/500851.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qDhpIx4K1hIu9N7REXVEAOsLMiA.jpg'),
(164442, 11673, 'Os Simpsons S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500852.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w5WbT0dzggTabsPM9fTqzxvJIQA.jpg'),
(164443, 11673, 'Os Simpsons S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500853.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7KqfXGaCAvTVRne3nMxDdGSQqKS.jpg'),
(164444, 11673, 'Os Simpsons S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500854.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eVB8FoLCUQOJXPl9uIrSwILUH3.jpg'),
(164445, 11673, 'Os Simpsons S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500855.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fHmxaDYvXCmsZqs6WulMamdu9Wi.jpg'),
(164446, 11673, 'Os Simpsons S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500856.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lAOtgJtTADRrr5gxNdh4kEuepD5.jpg'),
(164447, 11673, 'Os Simpsons S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/500857.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gjBbpzQ3b3E7fHb5gkMCHsOImFQ.jpg'),
(164448, 11673, 'Os Simpsons S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/500858.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7BGkc4yGkjdTxo4L3d4JvqotGcQ.jpg'),
(164449, 11673, 'Os Simpsons S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/500859.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2vWqXNMikshPX9dVqKAT3qupqup.jpg'),
(164450, 11673, 'Os Simpsons S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/500860.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hTNbbl8uipbVoDIZ8OgtCkZnYAL.jpg'),
(164451, 11673, 'Os Simpsons S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/500861.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s5lvq1sIdICOqX0kKzdAWUQNdCT.jpg'),
(164452, 11673, 'Os Simpsons S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/500862.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u7nlutZgBVe7QbSsNrYbGa30a8x.jpg'),
(164453, 11673, 'Os Simpsons S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/500863.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zPO8DEthCIGNpWErs3bvRuT4emQ.jpg'),
(164454, 11673, 'Os Simpsons S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/500864.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p2zf41UdmgoPBXS0xSrIMldqOFq.jpg'),
(164455, 11673, 'Os Simpsons S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/500865.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9MTd6DWjQccIztGqN3IXd3wZ4v0.jpg'),
(164456, 11673, 'Os Simpsons S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/500866.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qWzLc6ln1aGwtPGu6NcUpQwYkx0.jpg'),
(164457, 11673, 'Os Simpsons S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/500867.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9jlTs2EYzfgGG86kzO82jLnk9Qu.jpg'),
(164458, 11673, 'Os Simpsons S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/500868.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2muVedvhUd87ZFWmEfnS9Y8WT1d.jpg'),
(164459, 11673, 'Os Simpsons S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/500869.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kpim0dcnloaTJW5iAIdFVV9RyV3.jpg'),
(164460, 11673, 'Os Simpsons S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/500870.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2Bay9dWHz1uW3gE2hwZsjeQQ6bl.jpg'),
(164461, 11673, 'Os Simpsons S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/500871.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kYNauorldGvl55Vx0x6E7mbP9Gy.jpg'),
(164462, 11673, 'Os Simpsons S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/500872.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lNcBNNaPp3Uk14iIJuQkpIjNfJM.jpg'),
(164463, 11674, 'Os Simpsons S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500873.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9RELyTRHODqvYEWPjaZ35YO3zVp.jpg'),
(164464, 11674, 'Os Simpsons S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500874.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gTOio7rvoZtAfPbmF0S2HnfOVub.jpg'),
(164465, 11674, 'Os Simpsons S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500875.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uAju5IF72gKgsmmd0FvsoYzzIxa.jpg'),
(164466, 11674, 'Os Simpsons S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500876.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nhZzEoHTAyJUkBLZoLTOkARHF8z.jpg'),
(164467, 11674, 'Os Simpsons S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500877.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oqI3sB56a2Z9sgLXvk3kxtKxrye.jpg'),
(164468, 11674, 'Os Simpsons S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/500878.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nr3QGsDpNEHITa2b9XOwFZcx5QF.jpg'),
(164469, 11674, 'Os Simpsons S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/500879.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d6YuVVW0BqEt9rR7ZGVwLnyZ93F.jpg'),
(164470, 11674, 'Os Simpsons S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/500880.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kYBUoSJ5zOcgmOHNvEkCxNM8Eei.jpg'),
(164471, 11674, 'Os Simpsons S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/500881.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iRy0OWf2WyxYVtemoaNe9DPSSla.jpg'),
(164472, 11674, 'Os Simpsons S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/500882.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sny5VXFNrNVE1swa2MDytLwZYgS.jpg'),
(164473, 11674, 'Os Simpsons S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/500883.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aEiieS2hS6qNvdmfYRFRdcrXZ7D.jpg'),
(164474, 11674, 'Os Simpsons S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/500884.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xA6i2Gx2wlkFYccRnTpCnNc5tka.jpg'),
(164475, 11674, 'Os Simpsons S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/500885.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cxZnUA9raTyglWqdpkCoJC2llFl.jpg'),
(164476, 11674, 'Os Simpsons S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/500886.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2x6sjBVQt20O1P5mlFaT6CAdsdd.jpg'),
(164477, 11674, 'Os Simpsons S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/500887.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aB04kLazmoy2CjrAmQepixyLq7A.jpg'),
(164478, 11674, 'Os Simpsons S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/500888.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nA4VvJwUJp7bGhgReDdS68gJiF0.jpg'),
(164479, 11674, 'Os Simpsons S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/500889.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y5DMDld2LxJHO4EdjKfNEmgCMa6.jpg'),
(164480, 11674, 'Os Simpsons S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/500890.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kUHsZy4mBXd69c8OWRlQHkOzwUp.jpg'),
(164481, 11674, 'Os Simpsons S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/500891.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cvG0Drn7BuiSh8v94AFtjyUGA03.jpg'),
(164482, 11674, 'Os Simpsons S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/500892.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6MoQqK6r4ymm6tgpuK2NV66iP8c.jpg'),
(164483, 11674, 'Os Simpsons S13 E21', 'http://sinalprivado.info:80/series/1533784/1533784/500893.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/94EtinpO9xXnm9HtXJOl0NBuWYq.jpg'),
(164484, 11674, 'Os Simpsons S13 E22', 'http://sinalprivado.info:80/series/1533784/1533784/500894.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hhT1JuC7IyWbQ63yB7NC0Xp8Q4x.jpg'),
(164485, 11675, 'Os Simpsons S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500895.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ArsvOlY05ProKjN7zTMHiNiwp8V.jpg'),
(164486, 11675, 'Os Simpsons S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500896.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9mzLfkkdpAZ73qhZ37k3rPMXlvj.jpg'),
(164487, 11675, 'Os Simpsons S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500897.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hK6aWzcsrY3mxZQlQYSIbIMVNm0.jpg'),
(164488, 11675, 'Os Simpsons S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500898.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/feWQ09GUZaqwUSaZLz04dm7xpAK.jpg'),
(164489, 11675, 'Os Simpsons S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500899.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hN6Q0sUPqMUzyU46KAEzLK6XjdW.jpg'),
(164490, 11675, 'Os Simpsons S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/500900.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dvRi5ZtuqeKDTJwXDkrC8WfxAMe.jpg'),
(164491, 11675, 'Os Simpsons S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/500901.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2m5L9GbIMs9X1jwtVknz8Bw9Y3N.jpg'),
(164492, 11675, 'Os Simpsons S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/500902.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lXdYBAqsxF48gzkYTTEV3sNNUTI.jpg'),
(164493, 11675, 'Os Simpsons S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/500903.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Srx9XgPLyEHF9DsiA9k7yESPrD.jpg'),
(164494, 11675, 'Os Simpsons S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/500904.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/GVzrQGyCFiVFbPHmZlb1NORj1e.jpg'),
(164495, 11675, 'Os Simpsons S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/500905.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vWlogYRs9NlsHCql32u7crCM9Qr.jpg'),
(164496, 11675, 'Os Simpsons S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/500906.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/44R9C9akN65t8iratEije8gJGXM.jpg'),
(164497, 11675, 'Os Simpsons S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/500907.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1M8e7SDsNKI1ftvtRU6kDZvPuKX.jpg'),
(164498, 11675, 'Os Simpsons S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/500908.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9UAr1WUuCOruhpepTgvXkiP9pOp.jpg'),
(164499, 11675, 'Os Simpsons S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/500909.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gczcEcxLa0AUN42U6xiMoVEOv5k.jpg'),
(164500, 11675, 'Os Simpsons S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/500910.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uYJ8obN9GU9pmta0isFsVhgyijD.jpg'),
(164501, 11675, 'Os Simpsons S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/500911.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zo0ix7RLaork0wmljY9cUnIlghb.jpg'),
(164502, 11675, 'Os Simpsons S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/500912.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rrU7rGDtXvqwUrNVI2PJPU6y5S9.jpg'),
(164503, 11675, 'Os Simpsons S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/500913.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/inWPh8gUdJI7KC1GcGc1iVAZyAd.jpg'),
(164504, 11675, 'Os Simpsons S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/500914.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qg6BttQ014x2Seo3hBgk6d7xPsW.jpg'),
(164505, 11675, 'Os Simpsons S14 E21', 'http://sinalprivado.info:80/series/1533784/1533784/500915.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k0o5VrILrPmfErDR3uCI2gtt6FU.jpg'),
(164506, 11675, 'Os Simpsons S14 E22', 'http://sinalprivado.info:80/series/1533784/1533784/500916.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z9tjEGn63OEED1NfEcF7rM31CmG.jpg'),
(164507, 11676, 'Os Simpsons S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500917.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4XAfPywguzhK2voqI9Nu6K5hIRH.jpg'),
(164508, 11676, 'Os Simpsons S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500918.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wMvRgotlIzS00SpcV8LDIHshZWo.jpg'),
(164509, 11676, 'Os Simpsons S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500919.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k0MzQQhaCcZdaQEBruV1q6qMQ3R.jpg'),
(164510, 11676, 'Os Simpsons S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500920.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eFH1s3PIXzAA6PjhCRzDQcDle9L.jpg'),
(164511, 11676, 'Os Simpsons S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500921.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tdhHmTAC1X8Zgg1e1vkkUzMqVvO.jpg'),
(164512, 11676, 'Os Simpsons S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/500922.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/paZk6iXuLoTQyyuDde060FApMr8.jpg'),
(164513, 11676, 'Os Simpsons S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/500923.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zsev9AumNO83wqwsvboLenkySgW.jpg'),
(164514, 11676, 'Os Simpsons S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/500924.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b6wgDg2Lahp0Ocbwt9CDkXViOmr.jpg'),
(164515, 11676, 'Os Simpsons S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/500925.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ukpWslAdtlTVieWlUwD7MAEfP4U.jpg'),
(164516, 11676, 'Os Simpsons S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/500926.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fAnXdsFXGqNvRzKdUoF4LKvVZ9D.jpg'),
(164517, 11676, 'Os Simpsons S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/500927.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sgTpPJ0CLZylSsSo3YS6S7zH5qT.jpg'),
(164518, 11676, 'Os Simpsons S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/500928.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ssolsNav5tWa9LVgFxmmqvKqtjm.jpg'),
(164519, 11676, 'Os Simpsons S15 E13', 'http://sinalprivado.info:80/series/1533784/1533784/500929.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4mGzB8pWMQsiFYT77ttQw9QqIYG.jpg'),
(164520, 11676, 'Os Simpsons S15 E14', 'http://sinalprivado.info:80/series/1533784/1533784/500930.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wZFFiu2BOxZlgXZ0afRJqIADQH1.jpg'),
(164521, 11676, 'Os Simpsons S15 E15', 'http://sinalprivado.info:80/series/1533784/1533784/500931.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jFqY5X4IaDDRUbgO73ecKZqvkPC.jpg'),
(164522, 11676, 'Os Simpsons S15 E16', 'http://sinalprivado.info:80/series/1533784/1533784/500932.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q4RHV5uklz7d4N2UIVFLrSGyPNQ.jpg'),
(164523, 11676, 'Os Simpsons S15 E17', 'http://sinalprivado.info:80/series/1533784/1533784/500933.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/22xA31qk5t8gfmcDBwlMIdmF6gc.jpg'),
(164524, 11676, 'Os Simpsons S15 E18', 'http://sinalprivado.info:80/series/1533784/1533784/500934.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mCtBy7jBTV6XNV64DzuNapVff6k.jpg'),
(164525, 11676, 'Os Simpsons S15 E19', 'http://sinalprivado.info:80/series/1533784/1533784/500935.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7aBSk8K1xRadsOpOHnW9tGfJOn9.jpg'),
(164526, 11676, 'Os Simpsons S15 E20', 'http://sinalprivado.info:80/series/1533784/1533784/500936.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6jMk2Dx6r0C85flNd3XHDUZNhEq.jpg'),
(164527, 11676, 'Os Simpsons S15 E21', 'http://sinalprivado.info:80/series/1533784/1533784/500937.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c1s5tfOH3g798h2x7GG6WZIbVKe.jpg'),
(164528, 11676, 'Os Simpsons S15 E22', 'http://sinalprivado.info:80/series/1533784/1533784/500938.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rgZZAmytBbUukeIagf31ApFL54L.jpg'),
(164529, 11677, 'Os Simpsons S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500939.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cIegZWMyMbDf4fcbROoAdSkmcT8.jpg'),
(164530, 11677, 'Os Simpsons S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500940.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8fFlKw3mxl4mF3ap1iedj3XWzlH.jpg'),
(164531, 11677, 'Os Simpsons S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500941.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wsNhIiOAMyYhgNmvCIUEzjiJp8i.jpg'),
(164532, 11677, 'Os Simpsons S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500942.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jiRZyb61VUP07nnO2uCtnDOmpTs.jpg'),
(164533, 11677, 'Os Simpsons S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500943.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5NY4eS3d9mrdCsSBJbnBdNKVtgV.jpg'),
(164534, 11677, 'Os Simpsons S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/500944.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z8uRU1kH7KLOM47eYze3bwISkx0.jpg'),
(164535, 11677, 'Os Simpsons S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/500945.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tUXNLSRnOcxfptajPtCamRC1VFl.jpg'),
(164536, 11677, 'Os Simpsons S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/500946.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8aSBINdm8z1bpTQMx8JOgoAwu0q.jpg'),
(164537, 11677, 'Os Simpsons S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/500947.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gYvPjxtFCBMzppX5irw8v31LaEw.jpg'),
(164538, 11677, 'Os Simpsons S16 E10', 'http://sinalprivado.info:80/series/1533784/1533784/500948.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/igE6goCd1ykP51JDlvYavU8BMIV.jpg'),
(164539, 11677, 'Os Simpsons S16 E11', 'http://sinalprivado.info:80/series/1533784/1533784/500949.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3N8RpLbSVOF4JjSwrGufJaYNMKg.jpg'),
(164540, 11677, 'Os Simpsons S16 E12', 'http://sinalprivado.info:80/series/1533784/1533784/500950.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l0xDmW68m3CFXKSNTTYolV0WJBT.jpg'),
(164541, 11677, 'Os Simpsons S16 E13', 'http://sinalprivado.info:80/series/1533784/1533784/500951.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uF54I0u41KzDB1kmGAx1UXw3AgZ.jpg'),
(164542, 11677, 'Os Simpsons S16 E14', 'http://sinalprivado.info:80/series/1533784/1533784/500952.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o7aDeG8e8MITPROJhn8BiwizM0b.jpg'),
(164543, 11677, 'Os Simpsons S16 E15', 'http://sinalprivado.info:80/series/1533784/1533784/500953.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aYbcQeoQMza4rnIPLc0PDgO5zEV.jpg'),
(164544, 11677, 'Os Simpsons S16 E16', 'http://sinalprivado.info:80/series/1533784/1533784/500954.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7RsBjxtma5AOTURUC4VZUlXNeNl.jpg'),
(164545, 11677, 'Os Simpsons S16 E17', 'http://sinalprivado.info:80/series/1533784/1533784/500955.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t8q9MeaCBqiwLwZInJ2NSSWCJmy.jpg'),
(164546, 11677, 'Os Simpsons S16 E18', 'http://sinalprivado.info:80/series/1533784/1533784/500956.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1qrxpKAx32TllukNAHYYzbqyY1r.jpg'),
(164547, 11677, 'Os Simpsons S16 E19', 'http://sinalprivado.info:80/series/1533784/1533784/500957.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xgBLFmj9KyNgpxpppFWi3HObVZe.jpg'),
(164548, 11677, 'Os Simpsons S16 E20', 'http://sinalprivado.info:80/series/1533784/1533784/500958.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xQI4BZGS4rNnaVPZRvEq8l9GaG4.jpg'),
(164549, 11677, 'Os Simpsons S16 E21', 'http://sinalprivado.info:80/series/1533784/1533784/500959.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5qjNMa6kPHDICnJ9Oi22OcEURYs.jpg'),
(164550, 11678, 'Os Simpsons S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500960.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kedm7EwLbTKZ0I5wKSHZSD89RTR.jpg'),
(164551, 11678, 'Os Simpsons S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500961.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dMC3zxLlSWR87fGM6yb5kVPkMT6.jpg'),
(164552, 11678, 'Os Simpsons S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500962.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/80Q3ijOhlcjzG0W0eoNkhzHeRDa.jpg'),
(164553, 11678, 'Os Simpsons S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500963.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vZL4eWVPhaURaEBODGEsbv7fKeF.jpg'),
(164554, 11678, 'Os Simpsons S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500964.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iLbBgY5koarb3VHqrZbe1za3nJ6.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(164555, 11678, 'Os Simpsons S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/500965.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8g1Vfcrv2wuyst4ef3C8v8oxCag.jpg'),
(164556, 11678, 'Os Simpsons S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/500966.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2GrHzmunnuMayvwyqrHeEQrzZDs.jpg'),
(164557, 11678, 'Os Simpsons S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/500967.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lRz1JHvhbIAMTHqUMG2fAhr811h.jpg'),
(164558, 11678, 'Os Simpsons S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/500968.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iF0UuEda3RJRCZSHZZ3VUlbSSWQ.jpg'),
(164559, 11678, 'Os Simpsons S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/500969.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rZZheajhwKNhCOsHRtifDkKHUiE.jpg'),
(164560, 11678, 'Os Simpsons S17 E11', 'http://sinalprivado.info:80/series/1533784/1533784/500970.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yOdtJQaE9UbeEPidyZrersykcLX.jpg'),
(164561, 11678, 'Os Simpsons S17 E12', 'http://sinalprivado.info:80/series/1533784/1533784/500971.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mwXjxTCrtsbmz62ufCZhf04CVln.jpg'),
(164562, 11678, 'Os Simpsons S17 E13', 'http://sinalprivado.info:80/series/1533784/1533784/500972.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gGKJgbWER6Lks0jUPMyXiAsqbXS.jpg'),
(164563, 11678, 'Os Simpsons S17 E14', 'http://sinalprivado.info:80/series/1533784/1533784/500973.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/98bOEGo7GOOwH2089UsqzeAYzUG.jpg'),
(164564, 11678, 'Os Simpsons S17 E15', 'http://sinalprivado.info:80/series/1533784/1533784/500974.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nTKSlYrYJWtsT5dDDjFb5mfIN3u.jpg'),
(164565, 11678, 'Os Simpsons S17 E16', 'http://sinalprivado.info:80/series/1533784/1533784/500975.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yNXtCQs6dJxZBK5Be2PtW4Ai5wQ.jpg'),
(164566, 11678, 'Os Simpsons S17 E17', 'http://sinalprivado.info:80/series/1533784/1533784/500976.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gsqN6uCLpMg1dPaNmtTkdps3mEU.jpg'),
(164567, 11678, 'Os Simpsons S17 E18', 'http://sinalprivado.info:80/series/1533784/1533784/500977.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3ZWuLVGnCtr91n6hdCAzX32OIJ8.jpg'),
(164568, 11678, 'Os Simpsons S17 E19', 'http://sinalprivado.info:80/series/1533784/1533784/500978.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cwjkltn5dpf1UA7RFWiD94ZdTY3.jpg'),
(164569, 11678, 'Os Simpsons S17 E20', 'http://sinalprivado.info:80/series/1533784/1533784/500979.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ujX2FgDOoa3yxD5GWnUy5ehLayV.jpg'),
(164570, 11678, 'Os Simpsons S17 E21', 'http://sinalprivado.info:80/series/1533784/1533784/500980.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iwocCGG1PRC9ggI3IKXpaPrPwwO.jpg'),
(164571, 11678, 'Os Simpsons S17 E22', 'http://sinalprivado.info:80/series/1533784/1533784/500981.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oACQnRA313UG0PBJUzAatMaT1sD.jpg'),
(164572, 11679, 'Os Simpsons S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500982.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lJd1hKcvGcqNfuvO5pbus1LfaoZ.jpg'),
(164573, 11679, 'Os Simpsons S18 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500983.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8GFYz4h9JnJ1qGII0mEsfd8wpCv.jpg'),
(164574, 11679, 'Os Simpsons S18 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500984.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aXGGIJGQbK2kKiWfO6lRwaYMIJH.jpg'),
(164575, 11679, 'Os Simpsons S18 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500985.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yRWtv3xDq395srLCrAS5ChBc9Zp.jpg'),
(164576, 11679, 'Os Simpsons S18 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500986.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8EsXrv8h9qTEHmRE6Zob8Og0tXb.jpg'),
(164577, 11679, 'Os Simpsons S18 E06', 'http://sinalprivado.info:80/series/1533784/1533784/500987.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/73dyhyzHf1i33wcnM1NMlL9baEg.jpg'),
(164578, 11679, 'Os Simpsons S18 E07', 'http://sinalprivado.info:80/series/1533784/1533784/500988.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rc2QeZfGT8CtcfcHMB7nFlSVndY.jpg'),
(164579, 11679, 'Os Simpsons S18 E08', 'http://sinalprivado.info:80/series/1533784/1533784/500989.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c1qfexpSNZuWIsRhnutqzno5Mi.jpg'),
(164580, 11679, 'Os Simpsons S18 E09', 'http://sinalprivado.info:80/series/1533784/1533784/500990.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5olaRLBeOXhOhpTgJMBIBac1EYh.jpg'),
(164581, 11679, 'Os Simpsons S18 E10', 'http://sinalprivado.info:80/series/1533784/1533784/500991.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zEPT1FICsXyfVcFUWmNoYtqDoTI.jpg'),
(164582, 11679, 'Os Simpsons S18 E11', 'http://sinalprivado.info:80/series/1533784/1533784/500992.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wZQLESu8TPcELrU4z2uXtG3oHto.jpg'),
(164583, 11679, 'Os Simpsons S18 E12', 'http://sinalprivado.info:80/series/1533784/1533784/500993.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cUcqamEtAiG2y9frBsLWbNeQArQ.jpg'),
(164584, 11679, 'Os Simpsons S18 E13', 'http://sinalprivado.info:80/series/1533784/1533784/500994.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lew32JuTkA2AZH8s6pxviXNZcDm.jpg'),
(164585, 11679, 'Os Simpsons S18 E14', 'http://sinalprivado.info:80/series/1533784/1533784/500995.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iAoPmkjnzysLpQaVSTv8EIXS0He.jpg'),
(164586, 11679, 'Os Simpsons S18 E15', 'http://sinalprivado.info:80/series/1533784/1533784/500996.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rqYALxTgle3qkY3Jj7EbGjWIK7t.jpg'),
(164587, 11679, 'Os Simpsons S18 E16', 'http://sinalprivado.info:80/series/1533784/1533784/500997.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lGqPeQ05hdFUJqix4R7nhZYyIms.jpg'),
(164588, 11679, 'Os Simpsons S18 E17', 'http://sinalprivado.info:80/series/1533784/1533784/500998.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xIcKs69Q68vhQVvjtQMcagbRwdX.jpg'),
(164589, 11679, 'Os Simpsons S18 E18', 'http://sinalprivado.info:80/series/1533784/1533784/500999.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3AqZZR5qHjGGy9i10QKGOT5r9FL.jpg'),
(164590, 11679, 'Os Simpsons S18 E19', 'http://sinalprivado.info:80/series/1533784/1533784/501000.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/376CPYYLQY9iwkNj93q6ncIAIgT.jpg'),
(164591, 11679, 'Os Simpsons S18 E20', 'http://sinalprivado.info:80/series/1533784/1533784/501001.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bRN6TUZPMsE7XPLhLztp0JYk3oD.jpg'),
(164592, 11679, 'Os Simpsons S18 E21', 'http://sinalprivado.info:80/series/1533784/1533784/501002.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ffw8afx9H3Yx3NNqZWaWoYHamd.jpg'),
(164593, 11679, 'Os Simpsons S18 E22', 'http://sinalprivado.info:80/series/1533784/1533784/501003.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6mOPBxPwsZX6RfvZGMZTVwmef5b.jpg'),
(164594, 11680, 'Os Simpsons S19 E01', 'http://sinalprivado.info:80/series/1533784/1533784/501004.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5oQxSoTYWwNw04ahbUTdZ4SXaeU.jpg'),
(164595, 11680, 'Os Simpsons S19 E02', 'http://sinalprivado.info:80/series/1533784/1533784/501005.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zx8VbFsiOEi7aQUygrhQ7qtFB7c.jpg'),
(164596, 11680, 'Os Simpsons S19 E03', 'http://sinalprivado.info:80/series/1533784/1533784/501006.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rheJmcaJ4a9v90RcUCjsbA6TdLU.jpg'),
(164597, 11680, 'Os Simpsons S19 E04', 'http://sinalprivado.info:80/series/1533784/1533784/501007.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6LnTRtR277psLzXMYlLM6r6sx0A.jpg'),
(164598, 11680, 'Os Simpsons S19 E05', 'http://sinalprivado.info:80/series/1533784/1533784/501008.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yjmaAEE5wBMbAfPCOHbI2YRLmqF.jpg'),
(164599, 11680, 'Os Simpsons S19 E06', 'http://sinalprivado.info:80/series/1533784/1533784/501009.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sLNoOytzAZMWXsTJHP2i3ArBniZ.jpg'),
(164600, 11680, 'Os Simpsons S19 E07', 'http://sinalprivado.info:80/series/1533784/1533784/501010.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nHYdxGJ8qTz1hWJJzsM5y0F6ZN1.jpg'),
(164601, 11680, 'Os Simpsons S19 E08', 'http://sinalprivado.info:80/series/1533784/1533784/501011.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1BvcFYhw87ohAaB6zEapy7FmmOW.jpg'),
(164602, 11680, 'Os Simpsons S19 E09', 'http://sinalprivado.info:80/series/1533784/1533784/501012.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zxp6Q9XhwvUsC1agsGoYhc9cS0f.jpg'),
(164603, 11680, 'Os Simpsons S19 E10', 'http://sinalprivado.info:80/series/1533784/1533784/501013.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zzkpPlsOfXEHpPdnScx9mi5trhc.jpg'),
(164604, 11680, 'Os Simpsons S19 E11', 'http://sinalprivado.info:80/series/1533784/1533784/501014.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m1glfE7eopXhKkH6JErqe5hYrHw.jpg'),
(164605, 11680, 'Os Simpsons S19 E12', 'http://sinalprivado.info:80/series/1533784/1533784/501015.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vTZWIBxKSdeN8hhMXUBNww5ig6y.jpg'),
(164606, 11680, 'Os Simpsons S19 E13', 'http://sinalprivado.info:80/series/1533784/1533784/501016.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rEE5dVmM4Vm8mYHUzFlLsJb614A.jpg'),
(164607, 11680, 'Os Simpsons S19 E14', 'http://sinalprivado.info:80/series/1533784/1533784/501017.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/csWU5O4BdrYrmpUwF6eCyJ7vdos.jpg'),
(164608, 11680, 'Os Simpsons S19 E15', 'http://sinalprivado.info:80/series/1533784/1533784/501018.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f19shJZCPt9Jj2btRvkyHnynVv5.jpg'),
(164609, 11680, 'Os Simpsons S19 E16', 'http://sinalprivado.info:80/series/1533784/1533784/501019.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/65A4geEMC49w39X0X2RdmgLyqv7.jpg'),
(164610, 11680, 'Os Simpsons S19 E17', 'http://sinalprivado.info:80/series/1533784/1533784/501020.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bTgJeUdGiyN3DWkW70lnUw5eCCU.jpg'),
(164611, 11680, 'Os Simpsons S19 E18', 'http://sinalprivado.info:80/series/1533784/1533784/501021.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3IheqIfvIuKCqCQNv3590gqyitp.jpg'),
(164612, 11680, 'Os Simpsons S19 E19', 'http://sinalprivado.info:80/series/1533784/1533784/501022.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eXofhDmHECifbbWMJ5iSWcQkQeb.jpg'),
(164613, 11680, 'Os Simpsons S19 E20', 'http://sinalprivado.info:80/series/1533784/1533784/501023.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ed9cMTcp4GyMZcW3LtFQefOayx7.jpg'),
(164614, 11681, 'Os Simpsons S20 E01', 'http://sinalprivado.info:80/series/1533784/1533784/501024.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4lRi3m1BOR1dXVptOJPrKNB6tWK.jpg'),
(164615, 11681, 'Os Simpsons S20 E02', 'http://sinalprivado.info:80/series/1533784/1533784/501025.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5guIsxIQnXAnnWKzwF920ai2JCf.jpg'),
(164616, 11681, 'Os Simpsons S20 E03', 'http://sinalprivado.info:80/series/1533784/1533784/501026.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1wCUtTLxlwTlmAvycQvzFH6jZC0.jpg'),
(164617, 11681, 'Os Simpsons S20 E04', 'http://sinalprivado.info:80/series/1533784/1533784/501027.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2yfllJUHZm6trvJogkr6xu8jsZk.jpg'),
(164618, 11681, 'Os Simpsons S20 E05', 'http://sinalprivado.info:80/series/1533784/1533784/501028.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iqi8MRTdvHXpHdqK9YDHTz4SwOV.jpg'),
(164619, 11681, 'Os Simpsons S20 E06', 'http://sinalprivado.info:80/series/1533784/1533784/501029.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dMyOsl8RSZlr16P27ZzSGN1md9l.jpg'),
(164620, 11681, 'Os Simpsons S20 E07', 'http://sinalprivado.info:80/series/1533784/1533784/501030.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7fh4F6gWqtmRZULvlxjnBT8sj9j.jpg'),
(164621, 11681, 'Os Simpsons S20 E08', 'http://sinalprivado.info:80/series/1533784/1533784/501031.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/13eOFSKOfvaXbOG65X2x078ILUO.jpg'),
(164622, 11681, 'Os Simpsons S20 E09', 'http://sinalprivado.info:80/series/1533784/1533784/501032.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vBazf9YZhX5ZwHFSpgm281FFMM3.jpg'),
(164623, 11681, 'Os Simpsons S20 E10', 'http://sinalprivado.info:80/series/1533784/1533784/501033.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4Mq6sLtjhv5EnKDDolL9FcrAey3.jpg'),
(164624, 11681, 'Os Simpsons S20 E11', 'http://sinalprivado.info:80/series/1533784/1533784/501034.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5VQoZ8lsjUJl2LwSKbUCTcrOrhK.jpg'),
(164625, 11681, 'Os Simpsons S20 E12', 'http://sinalprivado.info:80/series/1533784/1533784/501035.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nmkvQipKMTldIgv1fzn6CwaUXYo.jpg'),
(164626, 11681, 'Os Simpsons S20 E13', 'http://sinalprivado.info:80/series/1533784/1533784/501036.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ukZdqmEUrdW5XDmJACuLc0Mh9Xn.jpg'),
(164627, 11681, 'Os Simpsons S20 E14', 'http://sinalprivado.info:80/series/1533784/1533784/501037.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kadwGHCXl2dQVdMY0ku6I68bxOh.jpg'),
(164628, 11681, 'Os Simpsons S20 E15', 'http://sinalprivado.info:80/series/1533784/1533784/501038.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/agQL5r3UaZPMhOMkN3r0Yh36R8q.jpg'),
(164629, 11681, 'Os Simpsons S20 E16', 'http://sinalprivado.info:80/series/1533784/1533784/501039.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8yrR5e08s7VUTZ65nQpmxGnE5mA.jpg'),
(164630, 11681, 'Os Simpsons S20 E17', 'http://sinalprivado.info:80/series/1533784/1533784/501040.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/genb9cm461EBc1DRlRO621XNI8W.jpg'),
(164631, 11681, 'Os Simpsons S20 E18', 'http://sinalprivado.info:80/series/1533784/1533784/501041.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2qRsGo560tOw929npYahBrmgTjZ.jpg'),
(164632, 11681, 'Os Simpsons S20 E19', 'http://sinalprivado.info:80/series/1533784/1533784/501042.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2oobHBPgNCN4Wv0IMLAGILxiCcJ.jpg'),
(164633, 11681, 'Os Simpsons S20 E20', 'http://sinalprivado.info:80/series/1533784/1533784/501043.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yYU6TsE4UxCNQmwGbneax8dar4e.jpg'),
(164634, 11681, 'Os Simpsons S20 E21', 'http://sinalprivado.info:80/series/1533784/1533784/501044.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9tIpS6VDwe3ylmgIGKGvbxzQxhw.jpg'),
(164635, 11682, 'Os Simpsons S21 E01', 'http://sinalprivado.info:80/series/1533784/1533784/501045.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ifPqgNjMy7FeDY36DLjg1oscmx7.jpg'),
(164636, 11682, 'Os Simpsons S21 E02', 'http://sinalprivado.info:80/series/1533784/1533784/501046.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4Fyc7VUjqgU5n7qyHabU7OcGhT9.jpg'),
(164637, 11682, 'Os Simpsons S21 E03', 'http://sinalprivado.info:80/series/1533784/1533784/501047.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3uniTuBpor7RWKhjAkXAbpKDnOg.jpg'),
(164638, 11682, 'Os Simpsons S21 E04', 'http://sinalprivado.info:80/series/1533784/1533784/501048.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qk6gwqRQrvxtoAM1VGacGagO6EI.jpg'),
(164639, 11682, 'Os Simpsons S21 E05', 'http://sinalprivado.info:80/series/1533784/1533784/501049.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uROUHczERyD58y2GbfbcdsCdZOk.jpg'),
(164640, 11682, 'Os Simpsons S21 E06', 'http://sinalprivado.info:80/series/1533784/1533784/501050.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4ZqZoASE7tGA5i9w6JFvR8ntdCo.jpg'),
(164641, 11682, 'Os Simpsons S21 E07', 'http://sinalprivado.info:80/series/1533784/1533784/501051.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rEcHFaE8k9csQbBLnVkGuhVQmmu.jpg'),
(164642, 11682, 'Os Simpsons S21 E08', 'http://sinalprivado.info:80/series/1533784/1533784/501052.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xpWYkRneq0pDb7km5hRg1sgIG58.jpg'),
(164643, 11682, 'Os Simpsons S21 E09', 'http://sinalprivado.info:80/series/1533784/1533784/501053.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ccPTeG8nGQAj05R5Uj9UVWkVun1.jpg'),
(164644, 11682, 'Os Simpsons S21 E10', 'http://sinalprivado.info:80/series/1533784/1533784/501054.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/av1H80GWfvjxbhrjyjT7saQG6YC.jpg'),
(164645, 11682, 'Os Simpsons S21 E11', 'http://sinalprivado.info:80/series/1533784/1533784/501055.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zbswPlx0nV4MjGH4gnKUfPnWJCh.jpg'),
(164646, 11682, 'Os Simpsons S21 E12', 'http://sinalprivado.info:80/series/1533784/1533784/501056.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Lce9SGRtasZV0MpTBC7YsM5A7e.jpg'),
(164647, 11682, 'Os Simpsons S21 E13', 'http://sinalprivado.info:80/series/1533784/1533784/501057.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aMVBfxLBaxMh6cOktNLwNtlY12h.jpg'),
(164648, 11682, 'Os Simpsons S21 E14', 'http://sinalprivado.info:80/series/1533784/1533784/501058.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7eEINBkUYQzbtc5Bkk1rvL62RS9.jpg'),
(164649, 11682, 'Os Simpsons S21 E15', 'http://sinalprivado.info:80/series/1533784/1533784/501059.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tRirzP2j8gmt1Ma9W1dPMqPPPbP.jpg'),
(164650, 11682, 'Os Simpsons S21 E16', 'http://sinalprivado.info:80/series/1533784/1533784/501060.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eFVYErxlHnIc392LZm7IwAMWtYb.jpg'),
(164651, 11682, 'Os Simpsons S21 E17', 'http://sinalprivado.info:80/series/1533784/1533784/501061.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qbmYn40siC8Sr69F63DhwxqIkFU.jpg'),
(164652, 11682, 'Os Simpsons S21 E18', 'http://sinalprivado.info:80/series/1533784/1533784/501062.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eQ4ksgP6mowSC3X04bxIgE6Je8K.jpg'),
(164653, 11682, 'Os Simpsons S21 E19', 'http://sinalprivado.info:80/series/1533784/1533784/501063.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AnbQyfvkzTMLfv2Kq5amsnHxlCz.jpg'),
(164654, 11682, 'Os Simpsons S21 E20', 'http://sinalprivado.info:80/series/1533784/1533784/501064.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fRTwu2GDHjOz59dB61VcpzQK2AJ.jpg'),
(164655, 11682, 'Os Simpsons S21 E21', 'http://sinalprivado.info:80/series/1533784/1533784/501065.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7sQKp438DHeIkzSi2byFJCzr9Un.jpg'),
(164656, 11682, 'Os Simpsons S21 E22', 'http://sinalprivado.info:80/series/1533784/1533784/501066.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yk2c7FtzUVPsnOgMFrMvZXI0ZOK.jpg'),
(164657, 11682, 'Os Simpsons S21 E23', 'http://sinalprivado.info:80/series/1533784/1533784/501067.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kGLKL5YwnRuBiZ32y9DEQJtqDa7.jpg'),
(164658, 11683, 'Os Simpsons S22 E01', 'http://sinalprivado.info:80/series/1533784/1533784/501068.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aTEIrH2jyvBSj61gmiCsFkyu7LX.jpg'),
(164659, 11683, 'Os Simpsons S22 E02', 'http://sinalprivado.info:80/series/1533784/1533784/501069.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7vz6iLiYBlIbZY3wmZpNYRvjWNN.jpg'),
(164660, 11683, 'Os Simpsons S22 E03', 'http://sinalprivado.info:80/series/1533784/1533784/501070.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xEjIdwjrjab6s0eKMK0h9eEaw6A.jpg'),
(164661, 11683, 'Os Simpsons S22 E04', 'http://sinalprivado.info:80/series/1533784/1533784/501071.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/caH9EJmY94Zl51W5g2cbpenF1FM.jpg'),
(164662, 11683, 'Os Simpsons S22 E05', 'http://sinalprivado.info:80/series/1533784/1533784/501072.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eyxaG3GzLJswkIlormLe6d4MJWS.jpg'),
(164663, 11683, 'Os Simpsons S22 E06', 'http://sinalprivado.info:80/series/1533784/1533784/501073.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5XFcefnsOYdpLgrWw48oxfujUfc.jpg'),
(164664, 11683, 'Os Simpsons S22 E07', 'http://sinalprivado.info:80/series/1533784/1533784/501074.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yeS7FgesJurRgTma4u1OfsVu8j2.jpg'),
(164665, 11683, 'Os Simpsons S22 E08', 'http://sinalprivado.info:80/series/1533784/1533784/501075.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aT5vxpEO7BDkENuWSKqx50DUMmN.jpg'),
(164666, 11683, 'Os Simpsons S22 E09', 'http://sinalprivado.info:80/series/1533784/1533784/501076.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8gMp1iUXc6xmqMyKidCJbE0zFsy.jpg'),
(164667, 11683, 'Os Simpsons S22 E10', 'http://sinalprivado.info:80/series/1533784/1533784/501077.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ArQjkDKZa10246bPU0cDzgqjnTK.jpg'),
(164668, 11683, 'Os Simpsons S22 E11', 'http://sinalprivado.info:80/series/1533784/1533784/501078.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uMoTyCpUOHfKMRVtP14v3cDB3vd.jpg'),
(164669, 11683, 'Os Simpsons S22 E12', 'http://sinalprivado.info:80/series/1533784/1533784/501079.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uFIdfpJdS4FA8e0JPcNhx862nOS.jpg'),
(164670, 11683, 'Os Simpsons S22 E13', 'http://sinalprivado.info:80/series/1533784/1533784/501080.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k08pCuXnSytnwoKZukFT5pu0wmM.jpg'),
(164671, 11683, 'Os Simpsons S22 E14', 'http://sinalprivado.info:80/series/1533784/1533784/501081.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eJ8s1AF2RmxGvXisMVWtRbSN6Au.jpg'),
(164672, 11683, 'Os Simpsons S22 E15', 'http://sinalprivado.info:80/series/1533784/1533784/501082.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ba4GeFG18GMPWwgPTF3wcPwkOHq.jpg'),
(164673, 11683, 'Os Simpsons S22 E16', 'http://sinalprivado.info:80/series/1533784/1533784/501083.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/77bYQWKA1PVkRN6d2xHZvWQn1rH.jpg'),
(164674, 11683, 'Os Simpsons S22 E17', 'http://sinalprivado.info:80/series/1533784/1533784/501084.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lPnwhFRPrWfg43hj3HGj8UIZqoM.jpg'),
(164675, 11683, 'Os Simpsons S22 E18', 'http://sinalprivado.info:80/series/1533784/1533784/501085.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u3oT7S1UTIYexqS0LRGYCDRFWkW.jpg'),
(164676, 11683, 'Os Simpsons S22 E19', 'http://sinalprivado.info:80/series/1533784/1533784/501086.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s3XpcfFeCvLJfSNdd44mU17S7KA.jpg'),
(164677, 11683, 'Os Simpsons S22 E20', 'http://sinalprivado.info:80/series/1533784/1533784/501087.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3hPPETv3MCdEjXuMczhoaoV1ktn.jpg'),
(164678, 11683, 'Os Simpsons S22 E21', 'http://sinalprivado.info:80/series/1533784/1533784/501088.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5k6x7ygxMQqa4WqtUvzECZTPuwC.jpg'),
(164679, 11683, 'Os Simpsons S22 E22', 'http://sinalprivado.info:80/series/1533784/1533784/501089.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lZIbHU5tmLEInKLauIGeJAh1rKM.jpg'),
(164680, 11684, 'Os Simpsons S23 E01', 'http://sinalprivado.info:80/series/1533784/1533784/501090.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gzjLJLYeSWuvVRpZf1RtA2RnBnf.jpg'),
(164681, 11684, 'Os Simpsons S23 E02', 'http://sinalprivado.info:80/series/1533784/1533784/501091.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cHIQaXLpRpjaUr7xg86bUWp9zaE.jpg'),
(164682, 11684, 'Os Simpsons S23 E03', 'http://sinalprivado.info:80/series/1533784/1533784/501092.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8Y7FJqpymZAi8jfVwdlhDvJjpTk.jpg'),
(164683, 11684, 'Os Simpsons S23 E04', 'http://sinalprivado.info:80/series/1533784/1533784/501093.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dlc7zOvJuxFmt2VcnCnxL4VfpKN.jpg'),
(164684, 11684, 'Os Simpsons S23 E05', 'http://sinalprivado.info:80/series/1533784/1533784/501094.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xsz6TUAHelQKaP93r8c3B3rpO5X.jpg'),
(164685, 11684, 'Os Simpsons S23 E06', 'http://sinalprivado.info:80/series/1533784/1533784/501095.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1oXqbbz2Mk01ZS8fB3OO4kazQik.jpg'),
(164686, 11684, 'Os Simpsons S23 E07', 'http://sinalprivado.info:80/series/1533784/1533784/501096.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oxAUaLWP4BQK8H7b5RA9DOvcWiq.jpg'),
(164687, 11684, 'Os Simpsons S23 E08', 'http://sinalprivado.info:80/series/1533784/1533784/501097.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iiuqlFyensnhkzSIvDAjt8NQXeM.jpg'),
(164688, 11684, 'Os Simpsons S23 E09', 'http://sinalprivado.info:80/series/1533784/1533784/501098.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6dQlJfFmoJ9u3XIIbCT2dOFcacX.jpg'),
(164689, 11684, 'Os Simpsons S23 E10', 'http://sinalprivado.info:80/series/1533784/1533784/501099.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dsX3El0mm5CALYsJj53OuRHIwTm.jpg'),
(164690, 11684, 'Os Simpsons S23 E11', 'http://sinalprivado.info:80/series/1533784/1533784/501100.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tVVjCCz45Ck9zx1trHMdYIh3Fvn.jpg'),
(164691, 11684, 'Os Simpsons S23 E12', 'http://sinalprivado.info:80/series/1533784/1533784/501101.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nj3WtdgxJAukuPX8TBAal7xvi5y.jpg'),
(164692, 11684, 'Os Simpsons S23 E13', 'http://sinalprivado.info:80/series/1533784/1533784/501102.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lKXhW0ewMjvtb0Zpf0bs68iIwEa.jpg'),
(164693, 11684, 'Os Simpsons S23 E14', 'http://sinalprivado.info:80/series/1533784/1533784/501103.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AwCeEuQrWaqtB7HTHmOph5gt2UF.jpg'),
(164694, 11684, 'Os Simpsons S23 E15', 'http://sinalprivado.info:80/series/1533784/1533784/501104.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p1yCAhDuzlgT3yCCPPteMXUgcvh.jpg'),
(164695, 11684, 'Os Simpsons S23 E16', 'http://sinalprivado.info:80/series/1533784/1533784/501105.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qxfXo1WBYx5ejkAI894gssAsS9G.jpg'),
(164696, 11684, 'Os Simpsons S23 E17', 'http://sinalprivado.info:80/series/1533784/1533784/501106.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rIv4N3ywbmlMfOot0NxZugk1rE3.jpg'),
(164697, 11684, 'Os Simpsons S23 E18', 'http://sinalprivado.info:80/series/1533784/1533784/501107.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gcesdsPilLaOvCck6WXHE0EEmMI.jpg'),
(164698, 11684, 'Os Simpsons S23 E19', 'http://sinalprivado.info:80/series/1533784/1533784/501108.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u16uUWkPkkac1m1BgxbvM7j0YSX.jpg'),
(164699, 11684, 'Os Simpsons S23 E20', 'http://sinalprivado.info:80/series/1533784/1533784/501109.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uQkb2LC09oFwKSyYLV2WqkALrra.jpg'),
(164700, 11684, 'Os Simpsons S23 E21', 'http://sinalprivado.info:80/series/1533784/1533784/501110.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bVqtGKHKl7PXl6ywv2xvETJyK4f.jpg'),
(164701, 11684, 'Os Simpsons S23 E22', 'http://sinalprivado.info:80/series/1533784/1533784/501111.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/izWuz1FjxDcu6pbbWWwDaHMIxPF.jpg'),
(164702, 11685, 'Os Simpsons S24 E01', 'http://sinalprivado.info:80/series/1533784/1533784/501112.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zIHjgQu1aYNmpbOoYvV4wmurzDz.jpg'),
(164703, 11685, 'Os Simpsons S24 E02', 'http://sinalprivado.info:80/series/1533784/1533784/501113.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oct5oACjidT42l6yOHPEzLMWTXD.jpg'),
(164704, 11685, 'Os Simpsons S24 E03', 'http://sinalprivado.info:80/series/1533784/1533784/501114.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s03hQbTp34SEYTqhzYqQtvcGcUm.jpg'),
(164705, 11685, 'Os Simpsons S24 E04', 'http://sinalprivado.info:80/series/1533784/1533784/501115.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6vrsnIQs6O204aIIAyrtEin39PF.jpg'),
(164706, 11685, 'Os Simpsons S24 E05', 'http://sinalprivado.info:80/series/1533784/1533784/501116.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8irLdkTgeV40ZU5aJZFZGCWbjBO.jpg'),
(164707, 11685, 'Os Simpsons S24 E06', 'http://sinalprivado.info:80/series/1533784/1533784/501117.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p7GuYHmT3rTZSUxjTRuhsEHJeCE.jpg'),
(164708, 11685, 'Os Simpsons S24 E07', 'http://sinalprivado.info:80/series/1533784/1533784/501118.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7pBMWndGdwPEeZg0vlMHuVCT21P.jpg'),
(164709, 11685, 'Os Simpsons S24 E08', 'http://sinalprivado.info:80/series/1533784/1533784/501119.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uymKguewVkSMmE9LAQYbOuJJ81k.jpg'),
(164710, 11685, 'Os Simpsons S24 E09', 'http://sinalprivado.info:80/series/1533784/1533784/501120.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3PzkKdQlmQjpTdzYsD3Mo3jWQse.jpg'),
(164711, 11685, 'Os Simpsons S24 E10', 'http://sinalprivado.info:80/series/1533784/1533784/501121.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5EmwcHFpVsEJSOJnyHWPj8mP59T.jpg'),
(164712, 11685, 'Os Simpsons S24 E11', 'http://sinalprivado.info:80/series/1533784/1533784/501122.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oQsiewvh6F3DOJQ7SMRxwf2nBDs.jpg'),
(164713, 11685, 'Os Simpsons S24 E12', 'http://sinalprivado.info:80/series/1533784/1533784/501123.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m6EBP16XG2o8aUekuBKl90TJOVQ.jpg'),
(164714, 11685, 'Os Simpsons S24 E13', 'http://sinalprivado.info:80/series/1533784/1533784/501124.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lB8PZLDPAy09csZ4CEWe3Rq3xQt.jpg'),
(164715, 11685, 'Os Simpsons S24 E14', 'http://sinalprivado.info:80/series/1533784/1533784/501125.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1C3XmbNfxwvCFijUuvGJ78yt7no.jpg'),
(164716, 11685, 'Os Simpsons S24 E15', 'http://sinalprivado.info:80/series/1533784/1533784/501126.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wvj9O5YcVB7hvz6P6DTwG11DISn.jpg'),
(164717, 11685, 'Os Simpsons S24 E16', 'http://sinalprivado.info:80/series/1533784/1533784/501127.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zfivy63XVvEiyWlZVAkImjlEcHH.jpg'),
(164718, 11685, 'Os Simpsons S24 E17', 'http://sinalprivado.info:80/series/1533784/1533784/501128.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yyuCltHSzFOrHoVBR2hkqQroCXq.jpg'),
(164719, 11685, 'Os Simpsons S24 E18', 'http://sinalprivado.info:80/series/1533784/1533784/501129.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bk4ubGlGZfYbvsg03cViRBowlgU.jpg'),
(164720, 11685, 'Os Simpsons S24 E19', 'http://sinalprivado.info:80/series/1533784/1533784/501130.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sce4beSgSUc7k9whyWuPrIIEd1s.jpg'),
(164721, 11685, 'Os Simpsons S24 E20', 'http://sinalprivado.info:80/series/1533784/1533784/501131.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/31c2slQCDwI0hLWWSXIvK6qRjWr.jpg'),
(164722, 11685, 'Os Simpsons S24 E21', 'http://sinalprivado.info:80/series/1533784/1533784/501132.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9KtTScpJAdHjRlz7WBpvvAwnWCK.jpg'),
(164723, 11686, 'Os Simpsons S25 E01', 'http://sinalprivado.info:80/series/1533784/1533784/501133.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yTOpnZsyKuyUIDMIzvc3ypt7Ofb.jpg'),
(164724, 11686, 'Os Simpsons S25 E02', 'http://sinalprivado.info:80/series/1533784/1533784/501134.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mAMjn0q6FIfG9UgceqiWccSBAhG.jpg'),
(164725, 11686, 'Os Simpsons S25 E03', 'http://sinalprivado.info:80/series/1533784/1533784/501135.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hgTUXniGadCJXarBv8Ae4GVXhuk.jpg'),
(164726, 11686, 'Os Simpsons S25 E04', 'http://sinalprivado.info:80/series/1533784/1533784/501136.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o8hW2Q0Yh8BBL5DGafeuRDvnc4D.jpg'),
(164727, 11686, 'Os Simpsons S25 E05', 'http://sinalprivado.info:80/series/1533784/1533784/501137.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A9UZTo6Gb8J6t7dflbk9cEyXQ4H.jpg'),
(164728, 11686, 'Os Simpsons S25 E06', 'http://sinalprivado.info:80/series/1533784/1533784/501138.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cqsobDXwPf9PrPKSQ6g8qeCJckd.jpg'),
(164729, 11686, 'Os Simpsons S25 E07', 'http://sinalprivado.info:80/series/1533784/1533784/501139.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/weWxhI3yON1Kju7BsOgR1OwkfQ.jpg'),
(164730, 11686, 'Os Simpsons S25 E08', 'http://sinalprivado.info:80/series/1533784/1533784/501140.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8OggxuXO1zr38042NLPCQ60mTl3.jpg'),
(164731, 11686, 'Os Simpsons S25 E09', 'http://sinalprivado.info:80/series/1533784/1533784/501141.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nA4FpyJitzXHDPtQ9pTtKIjmGhJ.jpg'),
(164732, 11686, 'Os Simpsons S25 E10', 'http://sinalprivado.info:80/series/1533784/1533784/501142.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3mIy8JL9mTdpMBm6MxI6pYswAF7.jpg'),
(164733, 11686, 'Os Simpsons S25 E11', 'http://sinalprivado.info:80/series/1533784/1533784/501143.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m6qjYcsDJcelPSnUQs4YIfARGqt.jpg'),
(164734, 11686, 'Os Simpsons S25 E12', 'http://sinalprivado.info:80/series/1533784/1533784/501144.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yvqwncC6yzlKdyO5oIoUgIYdjbc.jpg'),
(164735, 11686, 'Os Simpsons S25 E13', 'http://sinalprivado.info:80/series/1533784/1533784/501145.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xjPufOOc0AjXNei7tUQxXq0OhIa.jpg'),
(164736, 11686, 'Os Simpsons S25 E14', 'http://sinalprivado.info:80/series/1533784/1533784/501146.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6eRTZ1BauHgynrvvGZ3zzhi3NKs.jpg'),
(164737, 11686, 'Os Simpsons S25 E15', 'http://sinalprivado.info:80/series/1533784/1533784/501147.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vcag4jIguXp54btonMAFhzjkWLA.jpg'),
(164738, 11686, 'Os Simpsons S25 E16', 'http://sinalprivado.info:80/series/1533784/1533784/501148.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c3h2qWeK83UUnDKTcl0WdrDuuzb.jpg'),
(164739, 11686, 'Os Simpsons S25 E17', 'http://sinalprivado.info:80/series/1533784/1533784/501149.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rTtxZa6ji0ELqKUiFGQ8vCxF3wz.jpg'),
(164740, 11686, 'Os Simpsons S25 E18', 'http://sinalprivado.info:80/series/1533784/1533784/501150.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3zsn6aUFAHMLHxKlM8psWKL7am4.jpg'),
(164741, 11686, 'Os Simpsons S25 E19', 'http://sinalprivado.info:80/series/1533784/1533784/501151.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/WKGYRhDdNDr2A0OHQ5Wk7xLiTp.jpg'),
(164742, 11686, 'Os Simpsons S25 E20', 'http://sinalprivado.info:80/series/1533784/1533784/501152.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4soeEDdTMCcxui9syKvpNfxOVB8.jpg'),
(164743, 11686, 'Os Simpsons S25 E21', 'http://sinalprivado.info:80/series/1533784/1533784/501153.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rlH8tg1qaYwsze6WmtjS72obIzN.jpg'),
(164744, 11686, 'Os Simpsons S25 E22', 'http://sinalprivado.info:80/series/1533784/1533784/501154.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6NaLO2oegEFgRxdn1m81iHdox8r.jpg'),
(164745, 11687, 'Os Simpsons S26 E01', 'http://sinalprivado.info:80/series/1533784/1533784/501155.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hWL4vzZKGnCd9Vd8SPM4mmMs9gA.jpg'),
(164746, 11687, 'Os Simpsons S26 E02', 'http://sinalprivado.info:80/series/1533784/1533784/501156.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cIVjbpWZ0N93Rg9VRUpiLQ78azC.jpg'),
(164747, 11687, 'Os Simpsons S26 E03', 'http://sinalprivado.info:80/series/1533784/1533784/501157.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9CoRTG5LfwulbeBimBCHanW5Si1.jpg'),
(164748, 11687, 'Os Simpsons S26 E04', 'http://sinalprivado.info:80/series/1533784/1533784/501158.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lkIPgYy4xFKp9oVfivpGr2NgiXP.jpg'),
(164749, 11687, 'Os Simpsons S26 E05', 'http://sinalprivado.info:80/series/1533784/1533784/501159.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wa6KTUFdj7K8tGL85j3VqvBt0vj.jpg'),
(164750, 11687, 'Os Simpsons S26 E06', 'http://sinalprivado.info:80/series/1533784/1533784/501160.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nFFi4rPMD0Gqyo5GQzzQqVbyOnF.jpg'),
(164751, 11687, 'Os Simpsons S26 E07', 'http://sinalprivado.info:80/series/1533784/1533784/501161.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/42uQpr4nmvxyi5Hvk3RABXWxekO.jpg'),
(164752, 11687, 'Os Simpsons S26 E08', 'http://sinalprivado.info:80/series/1533784/1533784/501162.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5k8NptlSBObwBnYTzuqCuiwkAc9.jpg'),
(164753, 11687, 'Os Simpsons S26 E09', 'http://sinalprivado.info:80/series/1533784/1533784/501163.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bQNcB0o3ha2m4KK2FXKFgxP4nHi.jpg'),
(164754, 11687, 'Os Simpsons S26 E10', 'http://sinalprivado.info:80/series/1533784/1533784/501164.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gfXvnNDrCQIj6wlSwAbUGC9KZPX.jpg'),
(164755, 11687, 'Os Simpsons S26 E11', 'http://sinalprivado.info:80/series/1533784/1533784/501165.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/foBHq18TAcDDdrjEIirF2biVIFV.jpg'),
(164756, 11687, 'Os Simpsons S26 E12', 'http://sinalprivado.info:80/series/1533784/1533784/501166.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/esUqin6FhqYW7nqfZnnKFdMJBRb.jpg'),
(164757, 11687, 'Os Simpsons S26 E13', 'http://sinalprivado.info:80/series/1533784/1533784/501167.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m08LwQrFlaEvt41hMTGGHNMXC6w.jpg'),
(164758, 11687, 'Os Simpsons S26 E14', 'http://sinalprivado.info:80/series/1533784/1533784/501168.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fIN7amC3JUOBcBfOuf1ATGGayu1.jpg'),
(164759, 11687, 'Os Simpsons S26 E15', 'http://sinalprivado.info:80/series/1533784/1533784/501169.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9zxbza21FUBLzh5haAjbINGy9c.jpg'),
(164760, 11687, 'Os Simpsons S26 E16', 'http://sinalprivado.info:80/series/1533784/1533784/501170.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6a3r14YQN2UPFhNjBfWvFOAEQm8.jpg'),
(164761, 11687, 'Os Simpsons S26 E17', 'http://sinalprivado.info:80/series/1533784/1533784/501171.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yppaOpYLygGbkF6D90ySAekEjkK.jpg'),
(164762, 11687, 'Os Simpsons S26 E18', 'http://sinalprivado.info:80/series/1533784/1533784/501172.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k3hTiogy5qY9JobKRvkn0AjvYbJ.jpg'),
(164763, 11687, 'Os Simpsons S26 E19', 'http://sinalprivado.info:80/series/1533784/1533784/501173.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u8HR5RTLJGGMHDm9CnwLrrXrpmP.jpg'),
(164764, 11687, 'Os Simpsons S26 E20', 'http://sinalprivado.info:80/series/1533784/1533784/501174.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4DhQKT65qSgNPdWKr3uY4tmaOnf.jpg'),
(164765, 11687, 'Os Simpsons S26 E21', 'http://sinalprivado.info:80/series/1533784/1533784/501175.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lxVMzlQTv4EiQss2OFr8wkFPyKl.jpg'),
(164766, 11687, 'Os Simpsons S26 E22', 'http://sinalprivado.info:80/series/1533784/1533784/501176.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9m8ihZwvJ5xidLVCYoxAYiz1sqk.jpg'),
(164767, 11688, 'Os Simpsons S27 E01', 'http://sinalprivado.info:80/series/1533784/1533784/501177.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tKkUDD9PrQiCEu3bSgR4Ne0zizS.jpg'),
(164768, 11688, 'Os Simpsons S27 E02', 'http://sinalprivado.info:80/series/1533784/1533784/501178.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f98ygllbOZVNvlJztxj03l1LLio.jpg'),
(164769, 11688, 'Os Simpsons S27 E03', 'http://sinalprivado.info:80/series/1533784/1533784/501179.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r8Oc5jLbdMxdRqAXARsYUHv4csv.jpg'),
(164770, 11688, 'Os Simpsons S27 E04', 'http://sinalprivado.info:80/series/1533784/1533784/501180.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wG4EOudYo7dXpNI0kOk50sp6DWC.jpg'),
(164771, 11688, 'Os Simpsons S27 E05', 'http://sinalprivado.info:80/series/1533784/1533784/501181.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hOJJOQl7RM5xQxvT02YF5CsfeJP.jpg'),
(164772, 11688, 'Os Simpsons S27 E06', 'http://sinalprivado.info:80/series/1533784/1533784/501182.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/44ncYEXehsyVyYwWtDMFxkmJjKd.jpg'),
(164773, 11688, 'Os Simpsons S27 E07', 'http://sinalprivado.info:80/series/1533784/1533784/501183.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/623bfaDfhzq01EmwOEtb5ahhF7g.jpg'),
(164774, 11688, 'Os Simpsons S27 E08', 'http://sinalprivado.info:80/series/1533784/1533784/501184.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lkQ1TG0KaBN96ngvF2FUVfZjMfS.jpg'),
(164775, 11688, 'Os Simpsons S27 E09', 'http://sinalprivado.info:80/series/1533784/1533784/501185.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cHR8I80240a5X2NRjGtdGDkOudy.jpg'),
(164776, 11688, 'Os Simpsons S27 E10', 'http://sinalprivado.info:80/series/1533784/1533784/501186.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yxOJlHbLg9eQaokUWgNyNsGLLBm.jpg'),
(164777, 11688, 'Os Simpsons S27 E11', 'http://sinalprivado.info:80/series/1533784/1533784/501187.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ulPIX0XfJkQxn9CdgD2ZWdVl6Sx.jpg'),
(164778, 11688, 'Os Simpsons S27 E12', 'http://sinalprivado.info:80/series/1533784/1533784/501188.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3WaiBS9u9UtmuXSWQnqstCW9uk0.jpg'),
(164779, 11688, 'Os Simpsons S27 E13', 'http://sinalprivado.info:80/series/1533784/1533784/501189.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/88VMXSNPJ4QNF4C19pa4NxRP9CM.jpg'),
(164780, 11688, 'Os Simpsons S27 E14', 'http://sinalprivado.info:80/series/1533784/1533784/501190.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/86raN4xnKwwwxj6JhteAUTIn8Hu.jpg'),
(164781, 11688, 'Os Simpsons S27 E15', 'http://sinalprivado.info:80/series/1533784/1533784/501191.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bd27bcmPslLs5vq0FTCUlAZIaF8.jpg'),
(164782, 11688, 'Os Simpsons S27 E16', 'http://sinalprivado.info:80/series/1533784/1533784/501192.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kRhJtTPldwT4Ym91aUJzZrSsoKJ.jpg'),
(164783, 11688, 'Os Simpsons S27 E17', 'http://sinalprivado.info:80/series/1533784/1533784/501193.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lTunh28JdpUnMWlYXGeJpvbmQ0k.jpg'),
(164784, 11688, 'Os Simpsons S27 E18', 'http://sinalprivado.info:80/series/1533784/1533784/501194.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xSA0vZTw3MkOjw0LpULGPAFBozk.jpg'),
(164785, 11688, 'Os Simpsons S27 E19', 'http://sinalprivado.info:80/series/1533784/1533784/501195.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gePbDGSbeSrcUC7fqPLhGUUjlBE.jpg'),
(164786, 11688, 'Os Simpsons S27 E20', 'http://sinalprivado.info:80/series/1533784/1533784/501196.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1E8nRNLK7zWu41gterVEmjt3mxF.jpg'),
(164787, 11688, 'Os Simpsons S27 E21', 'http://sinalprivado.info:80/series/1533784/1533784/501197.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kgq2lViSCYTp5Q8K4bOQbE0m2h1.jpg'),
(164788, 11688, 'Os Simpsons S27 E22', 'http://sinalprivado.info:80/series/1533784/1533784/501198.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/waVlWZCnDPWgotG3nfcLCKdmkKl.jpg'),
(164789, 11689, 'Os Simpsons S28 E01', 'http://sinalprivado.info:80/series/1533784/1533784/501199.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cR0WmMABkL23PKUqgXWhX91J7Ke.jpg'),
(164790, 11689, 'Os Simpsons S28 E02', 'http://sinalprivado.info:80/series/1533784/1533784/501200.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wLKxdc9HolSlGfrZMG4aEjIfxzT.jpg'),
(164791, 11689, 'Os Simpsons S28 E03', 'http://sinalprivado.info:80/series/1533784/1533784/501201.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sKRtYmWYEnnW0m4u7zoucr7FWT3.jpg'),
(164792, 11689, 'Os Simpsons S28 E04', 'http://sinalprivado.info:80/series/1533784/1533784/501202.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pIbIETUZQxUYsGcrsYMpMx5FBYE.jpg'),
(164793, 11689, 'Os Simpsons S28 E05', 'http://sinalprivado.info:80/series/1533784/1533784/501203.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mJ6XRjFYYyfZT3kKwhhX6HuPLkX.jpg'),
(164794, 11689, 'Os Simpsons S28 E06', 'http://sinalprivado.info:80/series/1533784/1533784/501204.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AfyPrqfY1s59VuWGPyrSSh03uAo.jpg'),
(164795, 11689, 'Os Simpsons S28 E07', 'http://sinalprivado.info:80/series/1533784/1533784/501205.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u3edOuKQWidSuBb5XXoDMj2Kwu8.jpg'),
(164796, 11689, 'Os Simpsons S28 E08', 'http://sinalprivado.info:80/series/1533784/1533784/501206.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kBCQjUNk86UE6riUHUR0acd5z51.jpg'),
(164797, 11689, 'Os Simpsons S28 E09', 'http://sinalprivado.info:80/series/1533784/1533784/501207.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8rBc3fz00pVFqOe3zaIhDNOKEqo.jpg'),
(164798, 11689, 'Os Simpsons S28 E10', 'http://sinalprivado.info:80/series/1533784/1533784/501208.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gi81CdmVUGW1UQeFSb7B1NH6zBM.jpg'),
(164799, 11689, 'Os Simpsons S28 E11', 'http://sinalprivado.info:80/series/1533784/1533784/501209.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/80FmvYOhIclvBivP9XkQtAW1mlV.jpg'),
(164800, 11689, 'Os Simpsons S28 E12', 'http://sinalprivado.info:80/series/1533784/1533784/501210.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uUR3suAE675NA1TDGchSwl6QFjA.jpg'),
(164801, 11689, 'Os Simpsons S28 E13', 'http://sinalprivado.info:80/series/1533784/1533784/501211.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dizM4xdsmjcXfaQHAbf7NOMlOHE.jpg'),
(164802, 11689, 'Os Simpsons S28 E14', 'http://sinalprivado.info:80/series/1533784/1533784/501212.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iP8t9inr8wqmJgLjZmknUN7Yip6.jpg'),
(164803, 11689, 'Os Simpsons S28 E15', 'http://sinalprivado.info:80/series/1533784/1533784/501213.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nXOCLlVc51AkWz68EC1vrcOYUF3.jpg'),
(164804, 11689, 'Os Simpsons S28 E16', 'http://sinalprivado.info:80/series/1533784/1533784/501214.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5CI6co1tuuHGhwoAEDIbY3wxt6Q.jpg'),
(164805, 11689, 'Os Simpsons S28 E17', 'http://sinalprivado.info:80/series/1533784/1533784/501215.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cq72jPh7sNKF0SjdtyXeNlOnfaW.jpg'),
(164806, 11689, 'Os Simpsons S28 E18', 'http://sinalprivado.info:80/series/1533784/1533784/501216.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cbi3qmpgeOxNqRRXbJ6wSep7KJJ.jpg'),
(164807, 11689, 'Os Simpsons S28 E19', 'http://sinalprivado.info:80/series/1533784/1533784/501217.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xJUg4AM16pJ9M12OyqsuDFjtIYd.jpg'),
(164808, 11689, 'Os Simpsons S28 E20', 'http://sinalprivado.info:80/series/1533784/1533784/501218.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iBpcge7MDQHVzuExcrranOrDF9K.jpg'),
(164809, 11689, 'Os Simpsons S28 E21', 'http://sinalprivado.info:80/series/1533784/1533784/501219.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fciyOgSwwks9mJSYdNGFfNo8UPU.jpg'),
(164810, 11689, 'Os Simpsons S28 E22', 'http://sinalprivado.info:80/series/1533784/1533784/501220.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/duWAOwsbkqn04kbEtxW5D684D4j.jpg'),
(164811, 11690, 'Os Simpsons S29 E01', 'http://sinalprivado.info:80/series/1533784/1533784/501221.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/csK3VayctCvMdHYWbP09ewJoaTn.jpg'),
(164812, 11690, 'Os Simpsons S29 E02', 'http://sinalprivado.info:80/series/1533784/1533784/501222.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lX0bZl41mmk9Nl2BoqRYeuUd1xO.jpg'),
(164813, 11690, 'Os Simpsons S29 E03', 'http://sinalprivado.info:80/series/1533784/1533784/501223.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/papSI0pHVV4h2lKUIdpw7cNDoPZ.jpg'),
(164814, 11690, 'Os Simpsons S29 E04', 'http://sinalprivado.info:80/series/1533784/1533784/501224.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uPkAbZgpfLjgC2sX6zUrC1oXbfG.jpg'),
(164815, 11690, 'Os Simpsons S29 E05', 'http://sinalprivado.info:80/series/1533784/1533784/501225.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lDCyaJopKH2HqBYAj83ZWhwa1Bu.jpg'),
(164816, 11690, 'Os Simpsons S29 E06', 'http://sinalprivado.info:80/series/1533784/1533784/501226.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jarP9LgPeyzrX9VYqYG9BgpwOXw.jpg'),
(164817, 11690, 'Os Simpsons S29 E07', 'http://sinalprivado.info:80/series/1533784/1533784/501227.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xokeqqBWmtkZFNH0GXxHOVrkQ4c.jpg'),
(164818, 11690, 'Os Simpsons S29 E08', 'http://sinalprivado.info:80/series/1533784/1533784/501228.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5RweFPSkWH9j62LXWwxPSKdPAIE.jpg'),
(164819, 11690, 'Os Simpsons S29 E09', 'http://sinalprivado.info:80/series/1533784/1533784/501229.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/auoDQnBbgVbcSqFY57439SNcnbX.jpg'),
(164820, 11690, 'Os Simpsons S29 E10', 'http://sinalprivado.info:80/series/1533784/1533784/501230.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zgCNktdN5no3AtQUK6xiOtQu2x0.jpg'),
(164821, 11690, 'Os Simpsons S29 E11', 'http://sinalprivado.info:80/series/1533784/1533784/501231.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jcDVdXfLK57taEaWjeMKGny1ihQ.jpg'),
(164822, 11690, 'Os Simpsons S29 E12', 'http://sinalprivado.info:80/series/1533784/1533784/501232.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t1R1Uj9Grkk0uiIhpyQdRCxKN42.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(164823, 11690, 'Os Simpsons S29 E13', 'http://sinalprivado.info:80/series/1533784/1533784/501233.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4AYrp5yrCi4v091wSu7rgcMSCB7.jpg'),
(164824, 11690, 'Os Simpsons S29 E14', 'http://sinalprivado.info:80/series/1533784/1533784/501234.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9njnp3OVM4vkoTJokVsiR9PVVhm.jpg'),
(164825, 11690, 'Os Simpsons S29 E15', 'http://sinalprivado.info:80/series/1533784/1533784/501235.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qEa4laSNeDybr5AcwUoTFBfGiEh.jpg'),
(164826, 11690, 'Os Simpsons S29 E16', 'http://sinalprivado.info:80/series/1533784/1533784/501236.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5DFeYabkwwGlhLZB2V2mpDAADOn.jpg'),
(164827, 11690, 'Os Simpsons S29 E17', 'http://sinalprivado.info:80/series/1533784/1533784/501237.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2SVgo3u0XGKnl8wWyBUSvAgYocR.jpg'),
(164828, 11690, 'Os Simpsons S29 E18', 'http://sinalprivado.info:80/series/1533784/1533784/501238.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1BfpwVk4zHjR8dho1awKzq37peJ.jpg'),
(164829, 11690, 'Os Simpsons S29 E19', 'http://sinalprivado.info:80/series/1533784/1533784/501239.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lhLOI59Iyb0P3tFZzMKO9vgJMEM.jpg'),
(164830, 11690, 'Os Simpsons S29 E20', 'http://sinalprivado.info:80/series/1533784/1533784/501240.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/diuLjXgMbZYnSHSAalOV8iJYlmx.jpg'),
(164831, 11690, 'Os Simpsons S29 E21', 'http://sinalprivado.info:80/series/1533784/1533784/501241.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2bCGg8OPsg09SRSkWnfOBk6TMXG.jpg'),
(164832, 11691, 'Os Simpsons S30 E01', 'http://sinalprivado.info:80/series/1533784/1533784/501242.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k2TgeCBuVwbmKlUAUpVWQWFZHZi.jpg'),
(164833, 11691, 'Os Simpsons S30 E02', 'http://sinalprivado.info:80/series/1533784/1533784/501243.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ptSpOzlJjIjxB5dYWLIAOQbKhRs.jpg'),
(164834, 11691, 'Os Simpsons S30 E03', 'http://sinalprivado.info:80/series/1533784/1533784/501244.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2vyF5BPLxpgobQEhhmtqtd05cUM.jpg'),
(164835, 11691, 'Os Simpsons S30 E04', 'http://sinalprivado.info:80/series/1533784/1533784/501245.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w5eZjHkmtwH5MIVvqPJdhcIcPhI.jpg'),
(164836, 11691, 'Os Simpsons S30 E05', 'http://sinalprivado.info:80/series/1533784/1533784/501246.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/neWBHLIc5f7rjC3kzRnU6qkKtwm.jpg'),
(164837, 11691, 'Os Simpsons S30 E06', 'http://sinalprivado.info:80/series/1533784/1533784/501247.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cV48w9UdTWnu8f25sgIWR4DZHuP.jpg'),
(164838, 11691, 'Os Simpsons S30 E07', 'http://sinalprivado.info:80/series/1533784/1533784/501248.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cs3eIgwcS4y5i1TPkr3iKDpCpsK.jpg'),
(164839, 11691, 'Os Simpsons S30 E08', 'http://sinalprivado.info:80/series/1533784/1533784/501249.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vKKVUt42eV0IdvQWNBGh5z95eTJ.jpg'),
(164840, 11691, 'Os Simpsons S30 E09', 'http://sinalprivado.info:80/series/1533784/1533784/501250.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7wSmQvOGoPr9vdsLtOjNKwAwS6X.jpg'),
(164841, 11691, 'Os Simpsons S30 E10', 'http://sinalprivado.info:80/series/1533784/1533784/501251.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/97fbw6FwJq0LazFbozPyt1iw8Yj.jpg'),
(164842, 11691, 'Os Simpsons S30 E11', 'http://sinalprivado.info:80/series/1533784/1533784/501252.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8XJNuVuQx9qCEeo84lntqRbEiSJ.jpg'),
(164843, 11691, 'Os Simpsons S30 E12', 'http://sinalprivado.info:80/series/1533784/1533784/501253.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7qBQ2r1ca0f8FzR1MRCrx9Q9wKU.jpg'),
(164844, 11691, 'Os Simpsons S30 E13', 'http://sinalprivado.info:80/series/1533784/1533784/501254.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sD2lPwmb2oCcAHWldLzA6WqwAjb.jpg'),
(164845, 11691, 'Os Simpsons S30 E14', 'http://sinalprivado.info:80/series/1533784/1533784/501255.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yDDOFAE3wNlLBWnGnYoQPHkdbFn.jpg'),
(164846, 11691, 'Os Simpsons S30 E15', 'http://sinalprivado.info:80/series/1533784/1533784/501256.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iAdPnKvGlnEl20kd176tPyK2yiL.jpg'),
(164847, 11691, 'Os Simpsons S30 E16', 'http://sinalprivado.info:80/series/1533784/1533784/501257.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kQHlrY7UWw2wRhuLNhfoICpNHdY.jpg'),
(164848, 11691, 'Os Simpsons S30 E17', 'http://sinalprivado.info:80/series/1533784/1533784/501258.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zwcAAzFpwluxKVoCnJsJVrWy5W1.jpg'),
(164849, 11691, 'Os Simpsons S30 E18', 'http://sinalprivado.info:80/series/1533784/1533784/501259.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nRgIQnpf3UhgLthPeaT8bGTXrVF.jpg'),
(164850, 11691, 'Os Simpsons S30 E19', 'http://sinalprivado.info:80/series/1533784/1533784/501260.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yRiaUW9NTkHYJ5vpbfh5i4lhiTi.jpg'),
(164851, 11691, 'Os Simpsons S30 E20', 'http://sinalprivado.info:80/series/1533784/1533784/501261.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c8n0HOtLNSXxozCn6rOuEkwXHPz.jpg'),
(164852, 11691, 'Os Simpsons S30 E21', 'http://sinalprivado.info:80/series/1533784/1533784/501262.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qDzMMbIPypCDIrz1WrtqPyrLInh.jpg'),
(164853, 11691, 'Os Simpsons S30 E22', 'http://sinalprivado.info:80/series/1533784/1533784/501263.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u8mWExRiHXBippM1nzc8ExZljPX.jpg'),
(164854, 11691, 'Os Simpsons S30 E23', 'http://sinalprivado.info:80/series/1533784/1533784/501264.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vVRxO1waRD0YREWfd8rcrudcJ8o.jpg'),
(164855, 11692, 'Os Simpsons S31 E01', 'http://sinalprivado.info:80/series/1533784/1533784/501265.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7s2DJjjidGABGUWyWBHDBONdDIM.jpg'),
(164856, 11692, 'Os Simpsons S31 E02', 'http://sinalprivado.info:80/series/1533784/1533784/501266.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vsiOLe4PV1bKindMRSALwwjBVA7.jpg'),
(164857, 11692, 'Os Simpsons S31 E03', 'http://sinalprivado.info:80/series/1533784/1533784/501267.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iczczHw7GtN0FeyBtqf8U7eD5i6.jpg'),
(164858, 11692, 'Os Simpsons S31 E04', 'http://sinalprivado.info:80/series/1533784/1533784/501268.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/82NvRY8ZWbL50S4fBrrNqTkpcIb.jpg'),
(164859, 11692, 'Os Simpsons S31 E05', 'http://sinalprivado.info:80/series/1533784/1533784/501269.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fXbPjM5MNMa1iKW3aCXY4styDUW.jpg'),
(164860, 11692, 'Os Simpsons S31 E06', 'http://sinalprivado.info:80/series/1533784/1533784/501270.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cpG2J2LfgSvsb2mNlRc554jyw4X.jpg'),
(164861, 11692, 'Os Simpsons S31 E07', 'http://sinalprivado.info:80/series/1533784/1533784/501271.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/udzfi4Kya2Acq4UU1VOulM4evrN.jpg'),
(164862, 11692, 'Os Simpsons S31 E08', 'http://sinalprivado.info:80/series/1533784/1533784/501272.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yZSstjgrLWQP9x2qYbDLl0IGQt5.jpg'),
(164863, 11692, 'Os Simpsons S31 E09', 'http://sinalprivado.info:80/series/1533784/1533784/501273.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hOeWZkSs4QIBT0t1sQnqbLEP1HQ.jpg'),
(164864, 11692, 'Os Simpsons S31 E10', 'http://sinalprivado.info:80/series/1533784/1533784/501274.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dNic75xWyM5RMAuNlI7dX2lLNz.jpg'),
(164865, 11692, 'Os Simpsons S31 E11', 'http://sinalprivado.info:80/series/1533784/1533784/501275.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nl2YnVGgBzTroQnvTpFCBeTrUIy.jpg'),
(164866, 11692, 'Os Simpsons S31 E12', 'http://sinalprivado.info:80/series/1533784/1533784/501276.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b03kcXExgBBykmzVBwridE7CHc4.jpg'),
(164867, 11692, 'Os Simpsons S31 E13', 'http://sinalprivado.info:80/series/1533784/1533784/501277.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9kLmwa4BTU6qcHrXsuJUkWxjP3c.jpg'),
(164868, 11692, 'Os Simpsons S31 E14', 'http://sinalprivado.info:80/series/1533784/1533784/501278.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gt1HDmy6z52Zke08QUsEDt5qbru.jpg'),
(164869, 11692, 'Os Simpsons S31 E15', 'http://sinalprivado.info:80/series/1533784/1533784/501279.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3gBV072ottZ4LHSyKGx84Jkcmr9.jpg'),
(164870, 11692, 'Os Simpsons S31 E16', 'http://sinalprivado.info:80/series/1533784/1533784/501280.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gTBAKbl5yzU74Af9sZ2ijGECMFV.jpg'),
(164871, 11692, 'Os Simpsons S31 E17', 'http://sinalprivado.info:80/series/1533784/1533784/501281.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i5Jp4sIgU8XaX92RFYQWd04H7hK.jpg'),
(164872, 11692, 'Os Simpsons S31 E18', 'http://sinalprivado.info:80/series/1533784/1533784/501282.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/46J1x7wLGfTV97zNs2579AlfdGV.jpg'),
(164873, 11692, 'Os Simpsons S31 E19', 'http://sinalprivado.info:80/series/1533784/1533784/501283.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pGlh7HaCUvpsCOPLqRuKHTqz90y.jpg'),
(164874, 11692, 'Os Simpsons S31 E20', 'http://sinalprivado.info:80/series/1533784/1533784/501284.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dsw5onllfk8Oz5CRyXZBx78zuFe.jpg'),
(164875, 11692, 'Os Simpsons S31 E21', 'http://sinalprivado.info:80/series/1533784/1533784/501285.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dXlQvuVhWfOqQJYHI8G6IjxVahQ.jpg'),
(164876, 11692, 'Os Simpsons S31 E22', 'http://sinalprivado.info:80/series/1533784/1533784/501286.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/os8xKlW51wXFitXznAGvau5U9Lu.jpg'),
(164877, 11693, 'Os Simpsons S32 E01', 'http://sinalprivado.info:80/series/1533784/1533784/501287.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ke3E3ChGS54iuooiiEHd5pjmEIi.jpg'),
(164878, 11693, 'Os Simpsons S32 E02', 'http://sinalprivado.info:80/series/1533784/1533784/501288.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i3ESoxKyri7dVopnBdF91OdRbv0.jpg'),
(164879, 11693, 'Os Simpsons S32 E03', 'http://sinalprivado.info:80/series/1533784/1533784/501289.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d1EEKs9U2CbsPzMF0Q61400ApkZ.jpg'),
(164880, 11693, 'Os Simpsons S32 E04', 'http://sinalprivado.info:80/series/1533784/1533784/501290.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iKJoBSkH7IEp6pp1EvVFLd3sUOu.jpg'),
(164881, 11693, 'Os Simpsons S32 E05', 'http://sinalprivado.info:80/series/1533784/1533784/501291.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5TQXBGH7UVTOifDlefTKRc6A8VS.jpg'),
(164882, 11693, 'Os Simpsons S32 E06', 'http://sinalprivado.info:80/series/1533784/1533784/501292.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/12uPYyVUgJQ326TDcmyatzvQqpB.jpg'),
(164883, 11693, 'Os Simpsons S32 E07', 'http://sinalprivado.info:80/series/1533784/1533784/501293.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/egIB2qEof6EgW9C177ItbTOLdaJ.jpg'),
(164884, 11693, 'Os Simpsons S32 E08', 'http://sinalprivado.info:80/series/1533784/1533784/501294.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sZGWfUjenYSZRAX3cYkzYrjNlc4.jpg'),
(164885, 11693, 'Os Simpsons S32 E09', 'http://sinalprivado.info:80/series/1533784/1533784/501295.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l33tCkHCecUmrfrlP4E3unOW8Bs.jpg'),
(164886, 11693, 'Os Simpsons S32 E10', 'http://sinalprivado.info:80/series/1533784/1533784/501296.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5EdlHoXMtkQw2gTngLn3lTmsvZO.jpg'),
(164887, 11693, 'Os Simpsons S32 E11', 'http://sinalprivado.info:80/series/1533784/1533784/501297.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1I3oZqedn8JahWXwrfnkZcVmqQ5.jpg'),
(164888, 11693, 'Os Simpsons S32 E12', 'http://sinalprivado.info:80/series/1533784/1533784/501298.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lals0XbdD1PuQkxsxGv7tsc508p.jpg'),
(164889, 11693, 'Os Simpsons S32 E13', 'http://sinalprivado.info:80/series/1533784/1533784/501299.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dNodmnSgvi8QbqzwPC80b67hjPL.jpg'),
(164890, 11693, 'Os Simpsons S32 E14', 'http://sinalprivado.info:80/series/1533784/1533784/501300.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/orkEy4oQrca0oyGkHcGpZrvh5TV.jpg'),
(164891, 11693, 'Os Simpsons S32 E15', 'http://sinalprivado.info:80/series/1533784/1533784/501301.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s67j9cnGWsxY31SZVPPTlPqSXvY.jpg'),
(164892, 11693, 'Os Simpsons S32 E16', 'http://sinalprivado.info:80/series/1533784/1533784/501302.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7fGohzfWvuPrcI20PYt5I7vGgRK.jpg'),
(164893, 11693, 'Os Simpsons S32 E17', 'http://sinalprivado.info:80/series/1533784/1533784/501303.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/teKMNagpPV7I2BZPxv0t8inFeK.jpg'),
(164894, 11693, 'Os Simpsons S32 E18', 'http://sinalprivado.info:80/series/1533784/1533784/501304.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mlVeooD3eTUnKmn918ifeJMyqsn.jpg'),
(164895, 11693, 'Os Simpsons S32 E19', 'http://sinalprivado.info:80/series/1533784/1533784/501305.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yibhsAPT9wxz09wdJhtuisBgN17.jpg'),
(164896, 11693, 'Os Simpsons S32 E20', 'http://sinalprivado.info:80/series/1533784/1533784/501306.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t1j6VyJYwg26yVoVMtwa1B1DYvr.jpg'),
(164897, 11693, 'Os Simpsons S32 E21', 'http://sinalprivado.info:80/series/1533784/1533784/501307.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w4MvFkaZp85Wj3UQeLS6RqM2tRU.jpg'),
(164898, 11693, 'Os Simpsons S32 E22', 'http://sinalprivado.info:80/series/1533784/1533784/501308.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a9ymN3dyP5diL7UUe4edKQvx8hU.jpg'),
(164899, 11694, 'Os Simpsons S33 E01', 'http://sinalprivado.info:80/series/1533784/1533784/501309.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aaPARRYZcexqA3GQSn8VUhJlCuO.jpg'),
(164900, 11694, 'Os Simpsons S33 E02', 'http://sinalprivado.info:80/series/1533784/1533784/501310.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6YlXkcpSaCQ3w1IxuPZZyONwISO.jpg'),
(164901, 11694, 'Os Simpsons S33 E03', 'http://sinalprivado.info:80/series/1533784/1533784/501311.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pt7Jq9dz7QzrarQz02M7rcB22oP.jpg'),
(164902, 11694, 'Os Simpsons S33 E04', 'http://sinalprivado.info:80/series/1533784/1533784/501312.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/odkofLCngGIBYiJGfJCvMuPSzsa.jpg'),
(164903, 11694, 'Os Simpsons S33 E05', 'http://sinalprivado.info:80/series/1533784/1533784/501313.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3HkIYMYGlaHvYdp8B5PFg6wn596.jpg'),
(164904, 11694, 'Os Simpsons S33 E06', 'http://sinalprivado.info:80/series/1533784/1533784/501314.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8vUh5H3tmR55BQPUCBzxGiF5dUI.jpg'),
(164905, 11694, 'Os Simpsons S33 E07', 'http://sinalprivado.info:80/series/1533784/1533784/501315.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pdjxAE7yRBVXxLpPR5IDeIWA3VF.jpg'),
(164906, 11694, 'Os Simpsons S33 E08', 'http://sinalprivado.info:80/series/1533784/1533784/501316.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ayt3UNn17Jh5G0zNzUSEUbUmaHA.jpg'),
(164907, 11694, 'Os Simpsons S33 E09', 'http://sinalprivado.info:80/series/1533784/1533784/501317.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nL0O8CNpIUGaOr9GzuCum1O37f4.jpg'),
(164908, 11694, 'Os Simpsons S33 E10', 'http://sinalprivado.info:80/series/1533784/1533784/501318.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xqokEUFP6BTvaOxdUGGsoYIimij.jpg'),
(164909, 11694, 'Os Simpsons S33 E11', 'http://sinalprivado.info:80/series/1533784/1533784/501319.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e5HLNkCPPNykd6uXQyUwprFVwka.jpg'),
(164910, 11694, 'Os Simpsons S33 E12', 'http://sinalprivado.info:80/series/1533784/1533784/501320.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zTo7RfEbMQjFpKhBVo9enMASSNU.jpg'),
(164911, 11694, 'Os Simpsons S33 E13', 'http://sinalprivado.info:80/series/1533784/1533784/501321.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/koQkiwlcFC6vG1sKNpZFJil6t9l.jpg'),
(164912, 11694, 'Os Simpsons S33 E14', 'http://sinalprivado.info:80/series/1533784/1533784/501322.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/liJG4tOxi8IE4LkAX7orEX4uJWo.jpg'),
(164913, 11694, 'Os Simpsons S33 E15', 'http://sinalprivado.info:80/series/1533784/1533784/501323.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rCkbx1v6AurjmecWiiGUZ9rexpT.jpg'),
(164914, 11694, 'Os Simpsons S33 E16', 'http://sinalprivado.info:80/series/1533784/1533784/501324.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dhXqYR7YlTFoGLAblmDbmmfrR0K.jpg'),
(164915, 11694, 'Os Simpsons S33 E17', 'http://sinalprivado.info:80/series/1533784/1533784/501325.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yY04plv9o4He9KIRxwUqFM0usyy.jpg'),
(164916, 11694, 'Os Simpsons S33 E18', 'http://sinalprivado.info:80/series/1533784/1533784/501326.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/71nlmNPPwvGVQtnq6xr67RPrXbV.jpg'),
(164917, 11694, 'Os Simpsons S33 E19', 'http://sinalprivado.info:80/series/1533784/1533784/501327.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1jy1UVVKADFB2bvChmzvIbwgrTi.jpg'),
(164918, 11694, 'Os Simpsons S33 E20', 'http://sinalprivado.info:80/series/1533784/1533784/501328.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rXzkC5EovKHSKK9ymFJ0wKM80ay.jpg'),
(164919, 11694, 'Os Simpsons S33 E21', 'http://sinalprivado.info:80/series/1533784/1533784/501329.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hyu51H0b1vkbJHYTK864XrQ6nbu.jpg'),
(164920, 11694, 'Os Simpsons S33 E22', 'http://sinalprivado.info:80/series/1533784/1533784/501330.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iHrSLtQTsYMqGrlqXtYaxyhSU6D.jpg'),
(164921, 11695, 'Os Simpsons S34 E01', 'http://sinalprivado.info:80/series/1533784/1533784/501331.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ho0CyvftpNB2zxxgKzsZfLkKUh7.jpg'),
(164922, 11695, 'Os Simpsons S34 E02', 'http://sinalprivado.info:80/series/1533784/1533784/501332.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xSefS0e26WTfXwAVOq70W3b5AK3.jpg'),
(164923, 11695, 'Os Simpsons S34 E03', 'http://sinalprivado.info:80/series/1533784/1533784/501333.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eyu5hs3kEnwglKxUOxYCSHRV0Vi.jpg'),
(164924, 11695, 'Os Simpsons S34 E04', 'http://sinalprivado.info:80/series/1533784/1533784/501334.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8boZAWhTUxQ8jawZwUMvR6oh7QS.jpg'),
(164925, 11695, 'Os Simpsons S34 E05', 'http://sinalprivado.info:80/series/1533784/1533784/501335.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3ZNiiIWuCNzNfOfjZkbnbJupUsP.jpg'),
(164926, 11695, 'Os Simpsons S34 E06', 'http://sinalprivado.info:80/series/1533784/1533784/501336.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5BCwsrrBNIbA61hsQaDEhVGkCyV.jpg'),
(164927, 11695, 'Os Simpsons S34 E07', 'http://sinalprivado.info:80/series/1533784/1533784/501337.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yH9ugg3ZCCh0Zv2VJpfpboH93Y0.jpg'),
(164928, 11695, 'Os Simpsons S34 E08', 'http://sinalprivado.info:80/series/1533784/1533784/501338.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/52DcIvipvFfJ4UpnrHghHpZv3IZ.jpg'),
(164929, 11695, 'Os Simpsons S34 E09', 'http://sinalprivado.info:80/series/1533784/1533784/501339.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xLfHfDEosYkfcXRyqQV1EsNnjk.jpg'),
(164930, 11695, 'Os Simpsons S34 E10', 'http://sinalprivado.info:80/series/1533784/1533784/501340.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lSsiv8QQip9DSbN88EWDv0ApuZW.jpg'),
(164931, 11695, 'Os Simpsons S34 E11', 'http://sinalprivado.info:80/series/1533784/1533784/501341.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aTHHNOqLiq8QoPQAGoL8EOKz6Vt.jpg'),
(164932, 11695, 'Os Simpsons S34 E12', 'http://sinalprivado.info:80/series/1533784/1533784/501342.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/66x2k0kEvz0oDBxtertU66U3dJn.jpg'),
(164933, 11695, 'Os Simpsons S34 E13', 'http://sinalprivado.info:80/series/1533784/1533784/501343.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zU0BElWYJWGZDzj9B12b5M9lVlU.jpg'),
(164934, 11695, 'Os Simpsons S34 E14', 'http://sinalprivado.info:80/series/1533784/1533784/501344.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vpaGCLFUtf5DHL6x7aLHFoFxbXT.jpg'),
(164935, 11695, 'Os Simpsons S34 E15', 'http://sinalprivado.info:80/series/1533784/1533784/501345.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Al5oTBtijp1CZvI0d28oJc2Nkvq.jpg'),
(164936, 11695, 'Os Simpsons S34 E16', 'http://sinalprivado.info:80/series/1533784/1533784/501346.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sXKKzSscajPS2C2OJ94RrIwSuLs.jpg'),
(164937, 11695, 'Os Simpsons S34 E17', 'http://sinalprivado.info:80/series/1533784/1533784/501347.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nYEbYY7ZapgABLjh4pFtTX7OeIs.jpg'),
(164938, 11695, 'Os Simpsons S34 E18', 'http://sinalprivado.info:80/series/1533784/1533784/501348.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ixrNMX8k8nDz0Xvd6btANrb3loS.jpg'),
(164939, 11695, 'Os Simpsons S34 E19', 'http://sinalprivado.info:80/series/1533784/1533784/501349.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hZ3N04hDb18V2wGIS0k0Uz26HX2.jpg'),
(164940, 11695, 'Os Simpsons S34 E20', 'http://sinalprivado.info:80/series/1533784/1533784/501350.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1p10iQDylvSoSHYM1UW8SY1hGJG.jpg'),
(164941, 11695, 'Os Simpsons S34 E21', 'http://sinalprivado.info:80/series/1533784/1533784/501351.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wBaBKeeMmWsxw9mMKh1ec1YwT2u.jpg'),
(164942, 11695, 'Os Simpsons S34 E22', 'http://sinalprivado.info:80/series/1533784/1533784/501352.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/70yYWvEo2lVEkQu7yRhpsLrHRI3.jpg'),
(164943, 11696, 'Os Simpsons S35 E01', 'http://sinalprivado.info:80/series/1533784/1533784/501353.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3h5vxJqazJLCPQZH4Z8TOuCUpRC.jpg'),
(164944, 11696, 'Os Simpsons S35 E02', 'http://sinalprivado.info:80/series/1533784/1533784/501354.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ayfdkVnD1VUPq9aVjEPBQd4cUW6.jpg'),
(164945, 11696, 'Os Simpsons S35 E03', 'http://sinalprivado.info:80/series/1533784/1533784/501355.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/164WAjcFhReT5xp5pLFUkZjolDU.jpg'),
(164946, 11696, 'Os Simpsons S35 E04', 'http://sinalprivado.info:80/series/1533784/1533784/501356.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hD87XVYM80Ge6F0j1tIRk4Akg4b.jpg'),
(164947, 11696, 'Os Simpsons S35 E05', 'http://sinalprivado.info:80/series/1533784/1533784/501357.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/223RAYPMWtXHSTFMtujdl9UBjzW.jpg'),
(164948, 11696, 'Os Simpsons S35 E06', 'http://sinalprivado.info:80/series/1533784/1533784/501358.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zWH62bFjvNLDO7XUVzEp0soAt8d.jpg'),
(164949, 11696, 'Os Simpsons S35 E07', 'http://sinalprivado.info:80/series/1533784/1533784/501359.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r5T5bIU4WFzAAQYAjnmEmAIdTlY.jpg'),
(164950, 11696, 'Os Simpsons S35 E08', 'http://sinalprivado.info:80/series/1533784/1533784/501360.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wUrJIPl9p4F90LMoInSzIWXXhZG.jpg'),
(164951, 11696, 'Os Simpsons S35 E09', 'http://sinalprivado.info:80/series/1533784/1533784/501361.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cTy8XUHtauX9KGq3Y9OJItjI7Yx.jpg'),
(164952, 11696, 'Os Simpsons S35 E10', 'http://sinalprivado.info:80/series/1533784/1533784/501362.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/idkzKpcf0A3YakVrdNRHutjUVX5.jpg'),
(164953, 11696, 'Os Simpsons S35 E11', 'http://sinalprivado.info:80/series/1533784/1533784/501363.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sEytloGFMuecXQgoT7d2G5lXHrh.jpg'),
(164954, 11696, 'Os Simpsons S35 E12', 'http://sinalprivado.info:80/series/1533784/1533784/501364.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1Ri7zmWEjRSyRbVrvumqrGQjQO2.jpg'),
(164955, 11696, 'Os Simpsons S35 E13', 'http://sinalprivado.info:80/series/1533784/1533784/501365.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rWwzaSeNUmCOGO3stvXkzQp67sY.jpg'),
(164956, 11696, 'Os Simpsons S35 E14', 'http://sinalprivado.info:80/series/1533784/1533784/501366.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/34mUZgzijYYfAh3IP0jFSIgHVFO.jpg'),
(164957, 11696, 'Os Simpsons S35 E15', 'http://sinalprivado.info:80/series/1533784/1533784/501367.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/laaQgbaGVnJ9SJdTpVVAOiFy7ry.jpg'),
(164958, 11696, 'Os Simpsons S35 E16', 'http://sinalprivado.info:80/series/1533784/1533784/501368.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sspLwqIbKUo5IgeWeuSuzLEaxk5.jpg'),
(164959, 11696, 'Os Simpsons S35 E17', 'http://sinalprivado.info:80/series/1533784/1533784/501369.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yuk7qzLWifdyCxx8xQdtGZGKH7t.jpg'),
(164960, 11696, 'Os Simpsons S35 E18', 'http://sinalprivado.info:80/series/1533784/1533784/501370.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yJ25Jz4HUBZHryrjUTBXVr3X4nt.jpg'),
(164961, 11697, 'Os Simpsons S36 E01', 'http://sinalprivado.info:80/series/1533784/1533784/501371.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2IonOeHU9DSdlNpcYjTHcdbtdQN.jpg'),
(164962, 11697, 'Os Simpsons S36 E02', 'http://sinalprivado.info:80/series/1533784/1533784/523180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164963, 11697, 'Os Simpsons S36 E03', 'http://sinalprivado.info:80/series/1533784/1533784/636880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164964, 11697, 'Os Simpsons S36 E04', 'http://sinalprivado.info:80/series/1533784/1533784/812325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164965, 11697, 'Os Simpsons S36 E05', 'http://sinalprivado.info:80/series/1533784/1533784/640752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164966, 11697, 'Os Simpsons S36 E06', 'http://sinalprivado.info:80/series/1533784/1533784/640753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164967, 11697, 'Os Simpsons S36 E07', 'http://sinalprivado.info:80/series/1533784/1533784/658815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164968, 11697, 'Os Simpsons S36 E08', 'http://sinalprivado.info:80/series/1533784/1533784/686142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164969, 11697, 'Os Simpsons S36 E09', 'http://sinalprivado.info:80/series/1533784/1533784/686143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164970, 11697, 'Os Simpsons S36 E10', 'http://sinalprivado.info:80/series/1533784/1533784/686144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164971, 11697, 'Os Simpsons S36 E11', 'http://sinalprivado.info:80/series/1533784/1533784/686145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164972, 11697, 'Os Simpsons S36 E12', 'http://sinalprivado.info:80/series/1533784/1533784/689230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164973, 11697, 'Os Simpsons S36 E13', 'http://sinalprivado.info:80/series/1533784/1533784/812334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164974, 11697, 'Os Simpsons S36 E14', 'http://sinalprivado.info:80/series/1533784/1533784/824550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164975, 11697, 'Os Simpsons S36 E15', 'http://sinalprivado.info:80/series/1533784/1533784/836490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164976, 11697, 'Os Simpsons S36 E16', 'http://sinalprivado.info:80/series/1533784/1533784/836491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164977, 11697, 'Os Simpsons S36 E17', 'http://sinalprivado.info:80/series/1533784/1533784/854136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164978, 11697, 'Os Simpsons S36 E18', 'http://sinalprivado.info:80/series/1533784/1533784/854137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164979, 11697, 'Os Simpsons S36 E19', 'http://sinalprivado.info:80/series/1533784/1533784/854138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164980, 11697, 'Os Simpsons S36 E20', 'http://sinalprivado.info:80/series/1533784/1533784/854139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164981, 11697, 'Os Simpsons S36 E21', 'http://sinalprivado.info:80/series/1533784/1533784/854140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164982, 11697, 'Os Simpsons S36 E22', 'http://sinalprivado.info:80/series/1533784/1533784/636881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164983, 11698, 'Os Simpsons S37 E01', 'http://sinalprivado.info:80/series/1533784/1533784/891851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164984, 11698, 'Os Simpsons S37 E02', 'http://sinalprivado.info:80/series/1533784/1533784/891852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164985, 11698, 'Os Simpsons S37 E03', 'http://sinalprivado.info:80/series/1533784/1533784/894206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/29DgU8r0acAM719FVYQ25Iqwdqk.jpg'),
(164986, 11699, 'Citadel Honey Bunny S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500598.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2EEB1MQcldphUBHbU2pLLskg3kA.jpg'),
(164987, 11699, 'Citadel Honey Bunny S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500599.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iMzbY86smsItCv1rXOdbyVxeZgA.jpg'),
(164988, 11699, 'Citadel Honey Bunny S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500600.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pTs0xuvuzRyTsUxekmaJceCQmRO.jpg'),
(164989, 11699, 'Citadel Honey Bunny S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500601.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/78hlB5TY4qeNNbjoGL2FrODqEC6.jpg'),
(164990, 11699, 'Citadel Honey Bunny S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500602.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xYcfwll9ivtOXZyhc9nehHRHPiW.jpg'),
(164991, 11699, 'Citadel Honey Bunny S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/500603.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rmWQEA0xOp9Rd6shDHMeueTkXn5.jpg'),
(164992, 11700, 'Febre do Ouro O Desafio de Parker S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500578.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7CvnNpQcnTe3T77LFiDuyp4IZvD.jpg'),
(164993, 11700, 'Febre do Ouro O Desafio de Parker S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500579.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pHV5SB9R5AXhDZJEIFF2DibiKDa.jpg'),
(164994, 11700, 'Febre do Ouro O Desafio de Parker S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500580.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5uqgEeV7DQ5H1UdQfwMyTLQ4J5g.jpg'),
(164995, 11700, 'Febre do Ouro O Desafio de Parker S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500581.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/knmqXkmmAXvNMSkl3iuLs1yn3A1.jpg'),
(164996, 11701, 'Febre do Ouro O Desafio de Parker S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500582.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9tOcXTZ9gs9SpPokZN22TjCQ3TY.jpg'),
(164997, 11701, 'Febre do Ouro O Desafio de Parker S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500583.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fwwKvnf2Dm4dytN6cSRSI6sellj.jpg'),
(164998, 11701, 'Febre do Ouro O Desafio de Parker S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500584.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gMj3WjIJRb3HQm4KpbigyYiPZQl.jpg'),
(164999, 11701, 'Febre do Ouro O Desafio de Parker S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500585.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b8OvRge3KMWvKSfWEhpWfVwac1P.jpg'),
(165000, 11701, 'Febre do Ouro O Desafio de Parker S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500586.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b83UYBaCVphilNhHkCaUNoZeUCV.jpg'),
(165001, 11701, 'Febre do Ouro O Desafio de Parker S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/500587.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3dUSXMdIaXrUhTD3Lgq1xRkc684.jpg'),
(165002, 11702, 'Febre do Ouro O Desafio de Parker S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/500588.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mCcPtyJbGnY0uwZWMAfC1QsKdgc.jpg'),
(165003, 11702, 'Febre do Ouro O Desafio de Parker S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/500589.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6aY621PZ2NdKUTuxGrapX2kuSQT.jpg'),
(165004, 11702, 'Febre do Ouro O Desafio de Parker S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/500590.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5X81QBBam6fVcfMYBxy3sbUtGQW.jpg'),
(165005, 11702, 'Febre do Ouro O Desafio de Parker S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/500591.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ctYvIMHXVOKcTij0OyyqP58viVo.jpg'),
(165006, 11702, 'Febre do Ouro O Desafio de Parker S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/500592.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l3ShzZt8ubnIDTNrCl5odfNbVH6.jpg'),
(165007, 11702, 'Febre do Ouro O Desafio de Parker S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/500593.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vVBMceZnTrgKdPyx5PnZb5uTfTc.jpg'),
(165008, 11702, 'Febre do Ouro O Desafio de Parker S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/500594.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aug8OTpGj36P4CBJT5NwaOj6XWu.jpg'),
(165009, 11702, 'Febre do Ouro O Desafio de Parker S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/500595.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9yY8biTI01p5mvL6fFmWAX7wjPc.jpg'),
(165010, 11702, 'Febre do Ouro O Desafio de Parker S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/500596.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2PTp72TsZ9B2DEMzsceO8OcOT5k.jpg'),
(165011, 11702, 'Febre do Ouro O Desafio de Parker S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/500597.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4zsUWFHSrQHOjdPbswhuXiZMLIH.jpg'),
(165012, 11703, 'Febre do Ouro O Desafio de Parker S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165013, 11703, 'Febre do Ouro O Desafio de Parker S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165014, 11703, 'Febre do Ouro O Desafio de Parker S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165015, 11703, 'Febre do Ouro O Desafio de Parker S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165016, 11703, 'Febre do Ouro O Desafio de Parker S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165017, 11703, 'Febre do Ouro O Desafio de Parker S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/506084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165018, 11703, 'Febre do Ouro O Desafio de Parker S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/506085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165019, 11703, 'Febre do Ouro O Desafio de Parker S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/506086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165020, 11704, 'Febre do Ouro O Desafio de Parker S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165021, 11704, 'Febre do Ouro O Desafio de Parker S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165022, 11704, 'Febre do Ouro O Desafio de Parker S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165023, 11704, 'Febre do Ouro O Desafio de Parker S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165024, 11704, 'Febre do Ouro O Desafio de Parker S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165025, 11704, 'Febre do Ouro O Desafio de Parker S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/506092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165026, 11704, 'Febre do Ouro O Desafio de Parker S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/506093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165027, 11704, 'Febre do Ouro O Desafio de Parker S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/506094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165028, 11704, 'Febre do Ouro O Desafio de Parker S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/506095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165029, 11704, 'Febre do Ouro O Desafio de Parker S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/506096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165030, 9732, 'Febre do Ouro O Desafio de Parker S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165031, 9732, 'Febre do Ouro O Desafio de Parker S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165032, 9732, 'Febre do Ouro O Desafio de Parker S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165033, 9732, 'Febre do Ouro O Desafio de Parker S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165034, 9732, 'Febre do Ouro O Desafio de Parker S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165035, 9732, 'Febre do Ouro O Desafio de Parker S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/506102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165036, 9732, 'Febre do Ouro O Desafio de Parker S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/506103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165037, 9732, 'Febre do Ouro O Desafio de Parker S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/506104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165038, 9732, 'Febre do Ouro O Desafio de Parker S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/506105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165039, 9732, 'Febre do Ouro O Desafio de Parker S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/506106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165040, 9732, 'Febre do Ouro O Desafio de Parker S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/506107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165041, 9732, 'Febre do Ouro O Desafio de Parker S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/506108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165042, 11705, 'Febre do Ouro O Desafio de Parker S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/672172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165043, 11705, 'Febre do Ouro O Desafio de Parker S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/672173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165044, 11705, 'Febre do Ouro O Desafio de Parker S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/672174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165045, 11705, 'Febre do Ouro O Desafio de Parker S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/672175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165046, 11705, 'Febre do Ouro O Desafio de Parker S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/672176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165047, 11705, 'Febre do Ouro O Desafio de Parker S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/672177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165048, 11705, 'Febre do Ouro O Desafio de Parker S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/672178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165049, 11705, 'Febre do Ouro O Desafio de Parker S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/672179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165050, 11705, 'Febre do Ouro O Desafio de Parker S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/672180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165051, 11705, 'Febre do Ouro O Desafio de Parker S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/672181.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nGi3QTQqZ1wDzlMlykIRCXyvPC2.jpg'),
(165052, 11706, 'Luva de Pedreiro O Rei da Jogada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/499604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/epcOQyZ0I9Fddy7qPRejN8ph2WZ.jpg'),
(165053, 11706, 'Luva de Pedreiro O Rei da Jogada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/499605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/epcOQyZ0I9Fddy7qPRejN8ph2WZ.jpg'),
(165054, 11706, 'Luva de Pedreiro O Rei da Jogada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/499606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/epcOQyZ0I9Fddy7qPRejN8ph2WZ.jpg'),
(165055, 11707, 'Banco Central sob Ataque S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/498287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w9ZuACmkXZUUNGQO2rr07fzEXHX.jpg'),
(165056, 11707, 'Banco Central sob Ataque S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/498288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w9ZuACmkXZUUNGQO2rr07fzEXHX.jpg'),
(165057, 11707, 'Banco Central sob Ataque S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/498289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w9ZuACmkXZUUNGQO2rr07fzEXHX.jpg'),
(165058, 11707, 'Banco Central sob Ataque S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/498290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w9ZuACmkXZUUNGQO2rr07fzEXHX.jpg'),
(165059, 11707, 'Banco Central sob Ataque S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/498291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w9ZuACmkXZUUNGQO2rr07fzEXHX.jpg'),
(165060, 11708, 'Cromanon A Noite do Incendio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/498245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6B5MR1x8QaqV7TU0VyvlxpyK7dS.jpg'),
(165061, 11708, 'Cromanon A Noite do Incendio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/498246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6B5MR1x8QaqV7TU0VyvlxpyK7dS.jpg'),
(165062, 11708, 'Cromanon A Noite do Incendio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/498247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6B5MR1x8QaqV7TU0VyvlxpyK7dS.jpg'),
(165063, 11708, 'Cromanon A Noite do Incendio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/498248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6B5MR1x8QaqV7TU0VyvlxpyK7dS.jpg'),
(165064, 11708, 'Cromanon A Noite do Incendio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/498249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6B5MR1x8QaqV7TU0VyvlxpyK7dS.jpg'),
(165065, 11708, 'Cromanon A Noite do Incendio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/498250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6B5MR1x8QaqV7TU0VyvlxpyK7dS.jpg'),
(165066, 11708, 'Cromanon A Noite do Incendio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/498251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6B5MR1x8QaqV7TU0VyvlxpyK7dS.jpg'),
(165067, 11708, 'Cromanon A Noite do Incendio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/498252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6B5MR1x8QaqV7TU0VyvlxpyK7dS.jpg'),
(165068, 11709, 'Investigacao Alienigena S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/498239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lOVFYT4IQppV0FUQyxMhkDImXau.jpg'),
(165069, 11709, 'Investigacao Alienigena S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/498240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lOVFYT4IQppV0FUQyxMhkDImXau.jpg'),
(165070, 11709, 'Investigacao Alienigena S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/498241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lOVFYT4IQppV0FUQyxMhkDImXau.jpg'),
(165071, 11709, 'Investigacao Alienigena S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/498242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lOVFYT4IQppV0FUQyxMhkDImXau.jpg'),
(165072, 11709, 'Investigacao Alienigena S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/498243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lOVFYT4IQppV0FUQyxMhkDImXau.jpg'),
(165073, 11709, 'Investigacao Alienigena S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/498244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lOVFYT4IQppV0FUQyxMhkDImXau.jpg'),
(165074, 11710, 'Mr. Plankton S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/498229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6laAGCSuPnYbCnsAjhFiAqlDr1Z.jpg'),
(165075, 11710, 'Mr. Plankton S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/498230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6laAGCSuPnYbCnsAjhFiAqlDr1Z.jpg'),
(165076, 11710, 'Mr. Plankton S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/498231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6laAGCSuPnYbCnsAjhFiAqlDr1Z.jpg'),
(165077, 11710, 'Mr. Plankton S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/498232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6laAGCSuPnYbCnsAjhFiAqlDr1Z.jpg'),
(165078, 11710, 'Mr. Plankton S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/498233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6laAGCSuPnYbCnsAjhFiAqlDr1Z.jpg'),
(165079, 11710, 'Mr. Plankton S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/498234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6laAGCSuPnYbCnsAjhFiAqlDr1Z.jpg'),
(165080, 11710, 'Mr. Plankton S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/498235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6laAGCSuPnYbCnsAjhFiAqlDr1Z.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(165081, 11710, 'Mr. Plankton S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/498236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6laAGCSuPnYbCnsAjhFiAqlDr1Z.jpg'),
(165082, 11710, 'Mr. Plankton S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/498237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6laAGCSuPnYbCnsAjhFiAqlDr1Z.jpg'),
(165083, 11710, 'Mr. Plankton S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/498238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6laAGCSuPnYbCnsAjhFiAqlDr1Z.jpg'),
(165084, 11711, 'O Ringue S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/498224.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gsRPCFIyMZDX8J9trc6GdhfArqT.jpg'),
(165085, 11711, 'O Ringue S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/498225.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ql5FXWevByptCyzxAEpQHV87WJ.jpg'),
(165086, 11711, 'O Ringue S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/498226.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oqwXvmfgWV0lADWwfBlyGKepwjY.jpg'),
(165087, 11711, 'O Ringue S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/498227.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3f3DujIo6Z52t4vb2U7JZAgnMPz.jpg'),
(165088, 11711, 'O Ringue S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/498228.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e43Wo6eyHMAYi4TL9NWWuMrSFDj.jpg'),
(165089, 11712, 'Preamar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/498211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fgdR2XpU2lCA6PuAiHXy2njoDVT.jpg'),
(165090, 11712, 'Preamar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/498212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fgdR2XpU2lCA6PuAiHXy2njoDVT.jpg'),
(165091, 11712, 'Preamar S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/498213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fgdR2XpU2lCA6PuAiHXy2njoDVT.jpg'),
(165092, 11712, 'Preamar S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/498214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fgdR2XpU2lCA6PuAiHXy2njoDVT.jpg'),
(165093, 11712, 'Preamar S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/498215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fgdR2XpU2lCA6PuAiHXy2njoDVT.jpg'),
(165094, 11712, 'Preamar S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/498216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fgdR2XpU2lCA6PuAiHXy2njoDVT.jpg'),
(165095, 11712, 'Preamar S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/498217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fgdR2XpU2lCA6PuAiHXy2njoDVT.jpg'),
(165096, 11712, 'Preamar S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/498218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fgdR2XpU2lCA6PuAiHXy2njoDVT.jpg'),
(165097, 11712, 'Preamar S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/498219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fgdR2XpU2lCA6PuAiHXy2njoDVT.jpg'),
(165098, 11712, 'Preamar S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/498220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fgdR2XpU2lCA6PuAiHXy2njoDVT.jpg'),
(165099, 11712, 'Preamar S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/498221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fgdR2XpU2lCA6PuAiHXy2njoDVT.jpg'),
(165100, 11712, 'Preamar S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/498222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fgdR2XpU2lCA6PuAiHXy2njoDVT.jpg'),
(165101, 11712, 'Preamar S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/498223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fgdR2XpU2lCA6PuAiHXy2njoDVT.jpg'),
(165102, 11713, 'Cada Minuto Conta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/498201.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AfQuXNZ4PNP3SkIGlUJvoJ6NRm0.jpg'),
(165103, 11713, 'Cada Minuto Conta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/498202.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yivM8HcluhObW5GEjEsWcU4QQhn.jpg'),
(165104, 11713, 'Cada Minuto Conta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/498203.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/CVWKBW7upDa5FhkxqelNRHOkEU.jpg'),
(165105, 11713, 'Cada Minuto Conta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/498204.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dPQRZYLs2yrEGo0PGDApPTnpxh0.jpg'),
(165106, 11713, 'Cada Minuto Conta S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/498205.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3JGmTmVd4EdRMgn1y94YCVqMmkv.jpg'),
(165107, 11713, 'Cada Minuto Conta S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/498206.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l37keu0ICHQN4j1dcUnDNSy8OwG.jpg'),
(165108, 11713, 'Cada Minuto Conta S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/498207.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/47hU9WnlH19sjI3h4IS1Q4AxOLK.jpg'),
(165109, 11713, 'Cada Minuto Conta S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/498208.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vSkZadOGpPLWZAjwRS69fTFeWN4.jpg'),
(165110, 11713, 'Cada Minuto Conta S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/498209.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k3gtfjc7zYlHlGgV3EsaJtGZqqy.jpg'),
(165111, 11713, 'Cada Minuto Conta S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/498210.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qv1YXjkQ0sL2w8GtkQ5yM2VUm10.jpg'),
(165112, 11714, 'Luis Enrique Voce Nao Sabe P.... Nenhuma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/498198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1do6S7aOqXFFTLFC5a9cnLwnBHz.jpg'),
(165113, 11714, 'Luis Enrique Voce Nao Sabe P.... Nenhuma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/498199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1do6S7aOqXFFTLFC5a9cnLwnBHz.jpg'),
(165114, 11714, 'Luis Enrique Voce Nao Sabe P.... Nenhuma S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/498200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1do6S7aOqXFFTLFC5a9cnLwnBHz.jpg'),
(165115, 11715, 'Nada para Ver Aqui S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/498190.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/inKolINCBYMhI4jRs8cLbajngIN.jpg'),
(165116, 11715, 'Nada para Ver Aqui S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/498191.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iKZKr3sD67WnI5qlPwzIcw5BREL.jpg'),
(165117, 11715, 'Nada para Ver Aqui S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/498192.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tTn3A1CZZg8rch5M8zsMk4sicMu.jpg'),
(165118, 11715, 'Nada para Ver Aqui S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/498193.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kurecAYjWYTLBdQDkUHWmxqbYJI.jpg'),
(165119, 11715, 'Nada para Ver Aqui S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/498194.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/disUu4hBofAv1KLxIPRwM4zdu05.jpg'),
(165120, 11715, 'Nada para Ver Aqui S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/498195.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bTmsZyFYFlmF8Vblodkh1elPpml.jpg'),
(165121, 11715, 'Nada para Ver Aqui S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/498196.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8VVaKB8DkQNfRT25vY61GDuzN8k.jpg'),
(165122, 11715, 'Nada para Ver Aqui S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/498197.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iegmdF8YozOSM8bTti7jAlTjadF.jpg'),
(165123, 11716, 'Nada para Ver Aqui S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/509324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uMDNV5IhDzt1dZJyD5kl0xilVJA.jpg'),
(165124, 11716, 'Nada para Ver Aqui S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/509325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uMDNV5IhDzt1dZJyD5kl0xilVJA.jpg'),
(165125, 11716, 'Nada para Ver Aqui S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/509326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uMDNV5IhDzt1dZJyD5kl0xilVJA.jpg'),
(165126, 11716, 'Nada para Ver Aqui S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/509327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uMDNV5IhDzt1dZJyD5kl0xilVJA.jpg'),
(165127, 11716, 'Nada para Ver Aqui S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/509328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uMDNV5IhDzt1dZJyD5kl0xilVJA.jpg'),
(165128, 11716, 'Nada para Ver Aqui S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/509329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uMDNV5IhDzt1dZJyD5kl0xilVJA.jpg'),
(165129, 11716, 'Nada para Ver Aqui S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/509330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uMDNV5IhDzt1dZJyD5kl0xilVJA.jpg'),
(165130, 11716, 'Nada para Ver Aqui S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/509331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uMDNV5IhDzt1dZJyD5kl0xilVJA.jpg'),
(165131, 11717, 'Duvida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/498188.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3BF1Kx3SlSHcjSnucVx2RrBvF3a.jpg'),
(165132, 11717, 'Duvida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/498189.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lHYIg1G4O3NydD1W3QoHCe5ZFgX.jpg'),
(165133, 11717, 'Duvida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/503773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Y1eKKOvV9FRFbVpRo3oj6VrvFM.jpg'),
(165134, 11717, 'Duvida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/503774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Y1eKKOvV9FRFbVpRo3oj6VrvFM.jpg'),
(165135, 11717, 'Duvida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/512465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Y1eKKOvV9FRFbVpRo3oj6VrvFM.jpg'),
(165136, 11717, 'Duvida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/514516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Y1eKKOvV9FRFbVpRo3oj6VrvFM.jpg'),
(165137, 11717, 'Duvida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/514517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Y1eKKOvV9FRFbVpRo3oj6VrvFM.jpg'),
(165138, 11717, 'Duvida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/518642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Y1eKKOvV9FRFbVpRo3oj6VrvFM.jpg'),
(165139, 11717, 'Duvida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/518643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Y1eKKOvV9FRFbVpRo3oj6VrvFM.jpg'),
(165140, 11717, 'Duvida S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/521304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Y1eKKOvV9FRFbVpRo3oj6VrvFM.jpg'),
(165141, 11718, 'Rubble e Sua Turma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/498162.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gwKo0n4bsrijCg9kz2bl9LkdFbG.jpg'),
(165142, 11718, 'Rubble e Sua Turma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/498163.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lH4IWLRBXnrkMy7T4A4qX3cqZve.jpg'),
(165143, 11718, 'Rubble e Sua Turma S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/498164.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/erJyPvq4xDkp1fXsUdydeympiDk.jpg'),
(165144, 11718, 'Rubble e Sua Turma S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/498165.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uQDx7qBO81Z5igFj8TBQW4yhZL6.jpg'),
(165145, 11718, 'Rubble e Sua Turma S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/498166.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bJf7Szwm9uESwWoYSIK5RjHswAr.jpg'),
(165146, 11718, 'Rubble e Sua Turma S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/498167.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aY7mI7DfGTmZ1BKUUwoatMMtyFe.jpg'),
(165147, 11718, 'Rubble e Sua Turma S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/498168.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/R6I7afSvKH1kTt4XTmkN7OvBMP.jpg'),
(165148, 11718, 'Rubble e Sua Turma S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/498169.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gQxatsc6Knzhz6mihetoNup5uqW.jpg'),
(165149, 11718, 'Rubble e Sua Turma S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/498170.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jsjdjsLZBEX9TRIv4B9g1TlJwA2.jpg'),
(165150, 11718, 'Rubble e Sua Turma S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/498171.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gEi99k2defoS1FjA9p4vrMoQPIx.jpg'),
(165151, 11718, 'Rubble e Sua Turma S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/498172.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vix8KfMg8pOh4Vjz7tss73uYvEl.jpg'),
(165152, 11718, 'Rubble e Sua Turma S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/498173.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2BkVI4RBdfYCo57h3Akm6YNZyNk.jpg'),
(165153, 11718, 'Rubble e Sua Turma S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/498174.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sJmfR06klDzSE9cJV1z3s8P1xUI.jpg'),
(165154, 11718, 'Rubble e Sua Turma S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/498175.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uY4D4fz1gXOaA4m0MWcifBl7AXA.jpg'),
(165155, 11718, 'Rubble e Sua Turma S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/498176.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z29fMGpBB1SgIg812JHdgBSIqgV.jpg'),
(165156, 11718, 'Rubble e Sua Turma S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/498177.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/SMoD3hRlfEQzaCvs1iOAujOe3g.jpg'),
(165157, 11718, 'Rubble e Sua Turma S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/498178.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y8VTU3Iiks7csZ2qajVbB3hXD07.jpg'),
(165158, 11718, 'Rubble e Sua Turma S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/498179.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hCTyfaIri5O3u02CjcXWwO2wNy9.jpg'),
(165159, 11718, 'Rubble e Sua Turma S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/498180.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2GOIshLmVSz0BkpD5FbXrvIijEA.jpg'),
(165160, 11718, 'Rubble e Sua Turma S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/498181.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eSEqL5IlPQ0RSjCxuTblvFVw0zP.jpg'),
(165161, 11718, 'Rubble e Sua Turma S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/498182.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/85xnzViDzqAjvus8R61EUaoKwX6.jpg'),
(165162, 11718, 'Rubble e Sua Turma S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/498183.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1KE0qAgz4ARJ21QX5GpJIOmenkZ.jpg'),
(165163, 11718, 'Rubble e Sua Turma S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/498184.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aDm3mTDkE7uxMdkeSyooJALTzM3.jpg'),
(165164, 11718, 'Rubble e Sua Turma S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/498185.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zA2fPuuIK9VdGwETZHhGDIS0PKv.jpg'),
(165165, 11718, 'Rubble e Sua Turma S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/498186.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jjeJLUeVPNG2lytlmepfL5Jdbzl.jpg'),
(165166, 11718, 'Rubble e Sua Turma S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/498187.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zCnsA2NSFER1CYKCHUge13b6vna.jpg'),
(165167, 11719, 'Rubble e Sua Turma S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/667514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5MA1tqT0yI57IlPBy0KRN6G2mhN.jpg'),
(165168, 11719, 'Rubble e Sua Turma S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/667515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5MA1tqT0yI57IlPBy0KRN6G2mhN.jpg'),
(165169, 11719, 'Rubble e Sua Turma S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/667516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5MA1tqT0yI57IlPBy0KRN6G2mhN.jpg'),
(165170, 11719, 'Rubble e Sua Turma S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/667517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5MA1tqT0yI57IlPBy0KRN6G2mhN.jpg'),
(165171, 11719, 'Rubble e Sua Turma S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/667518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5MA1tqT0yI57IlPBy0KRN6G2mhN.jpg'),
(165172, 11719, 'Rubble e Sua Turma S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/667519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5MA1tqT0yI57IlPBy0KRN6G2mhN.jpg'),
(165173, 11719, 'Rubble e Sua Turma S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/667520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5MA1tqT0yI57IlPBy0KRN6G2mhN.jpg'),
(165174, 11719, 'Rubble e Sua Turma S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/667521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5MA1tqT0yI57IlPBy0KRN6G2mhN.jpg'),
(165175, 11719, 'Rubble e Sua Turma S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/667522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5MA1tqT0yI57IlPBy0KRN6G2mhN.jpg'),
(165176, 11719, 'Rubble e Sua Turma S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/667523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5MA1tqT0yI57IlPBy0KRN6G2mhN.jpg'),
(165177, 11719, 'Rubble e Sua Turma S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/667524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5MA1tqT0yI57IlPBy0KRN6G2mhN.jpg'),
(165178, 11719, 'Rubble e Sua Turma S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/667525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5MA1tqT0yI57IlPBy0KRN6G2mhN.jpg'),
(165179, 11719, 'Rubble e Sua Turma S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/667526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5MA1tqT0yI57IlPBy0KRN6G2mhN.jpg'),
(165180, 11720, 'Brasil Visto de Cima a Noite S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/498152.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mQMCjgMyj1xRgA3ulYYrExznJGk.jpg'),
(165181, 11720, 'Brasil Visto de Cima a Noite S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/498153.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6vw8XLTCnPft2f3E2ij84BFh2e4.jpg'),
(165182, 11720, 'Brasil Visto de Cima a Noite S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/498154.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mCmPdiC6ctkimRsxXjcmBwogoSs.jpg'),
(165183, 11720, 'Brasil Visto de Cima a Noite S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/498155.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wao76A2YP3H1G9E10U18jxS0Qs9.jpg'),
(165184, 11720, 'Brasil Visto de Cima a Noite S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/498156.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wXz9HJXgcdQW2fjukrhOsLfaJz5.jpg'),
(165185, 11720, 'Brasil Visto de Cima a Noite S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/498157.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t00rvIfKxJaO1uz0t52KfmlKTqU.jpg'),
(165186, 11720, 'Brasil Visto de Cima a Noite S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/498158.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6vAUeKRoFz7hc8nOXDlLdXAmPSG.jpg'),
(165187, 11720, 'Brasil Visto de Cima a Noite S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/498159.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zEmfKwXdpbOINkEGBSzuCo9cJor.jpg'),
(165188, 11720, 'Brasil Visto de Cima a Noite S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/498160.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uhL9CQAs0r2xxyIQTQRw2a3YGTl.jpg'),
(165189, 11720, 'Brasil Visto de Cima a Noite S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/498161.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n7Fz9EVPPCGiZPLONawqc9xLBBq.jpg'),
(165190, 11720, 'Brasil Visto de Cima a Noite S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/770216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kgV8XP2bEiEJFfF1wpNsVzp2HrX.jpg'),
(165191, 11720, 'Brasil Visto de Cima a Noite S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/770217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kgV8XP2bEiEJFfF1wpNsVzp2HrX.jpg'),
(165192, 11720, 'Brasil Visto de Cima a Noite S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/770218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kgV8XP2bEiEJFfF1wpNsVzp2HrX.jpg'),
(165193, 11720, 'Brasil Visto de Cima a Noite S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/770219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kgV8XP2bEiEJFfF1wpNsVzp2HrX.jpg'),
(165194, 11720, 'Brasil Visto de Cima a Noite S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/770220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kgV8XP2bEiEJFfF1wpNsVzp2HrX.jpg'),
(165195, 11720, 'Brasil Visto de Cima a Noite S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/770221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kgV8XP2bEiEJFfF1wpNsVzp2HrX.jpg'),
(165196, 11720, 'Brasil Visto de Cima a Noite S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/770222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kgV8XP2bEiEJFfF1wpNsVzp2HrX.jpg'),
(165197, 11720, 'Brasil Visto de Cima a Noite S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/770223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kgV8XP2bEiEJFfF1wpNsVzp2HrX.jpg'),
(165198, 11720, 'Brasil Visto de Cima a Noite S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/770224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kgV8XP2bEiEJFfF1wpNsVzp2HrX.jpg'),
(165199, 11720, 'Brasil Visto de Cima a Noite S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/770225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kgV8XP2bEiEJFfF1wpNsVzp2HrX.jpg'),
(165200, 11720, 'Brasil Visto de Cima a Noite S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/770226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kgV8XP2bEiEJFfF1wpNsVzp2HrX.jpg'),
(165201, 11720, 'Brasil Visto de Cima a Noite S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/770227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kgV8XP2bEiEJFfF1wpNsVzp2HrX.jpg'),
(165202, 11720, 'Brasil Visto de Cima a Noite S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/770228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kgV8XP2bEiEJFfF1wpNsVzp2HrX.jpg'),
(165203, 11720, 'Brasil Visto de Cima a Noite S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/770229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kgV8XP2bEiEJFfF1wpNsVzp2HrX.jpg'),
(165204, 11720, 'Brasil Visto de Cima a Noite S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/770230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kgV8XP2bEiEJFfF1wpNsVzp2HrX.jpg'),
(165205, 11720, 'Brasil Visto de Cima a Noite S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/770231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kgV8XP2bEiEJFfF1wpNsVzp2HrX.jpg'),
(165206, 11721, 'O Rei do Inverno S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/505496.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iSnAg64f5gkt4avoLmLJuA2MI2i.jpg'),
(165207, 11721, 'O Rei do Inverno S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/505497.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kLlaJfArrd5h6vpRQFJRDJF9kWv.jpg'),
(165208, 11721, 'O Rei do Inverno S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/505498.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9McSgMTJbcSXjyOpIhRW7vmseL0.jpg'),
(165209, 11721, 'O Rei do Inverno S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/505499.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qiJQNJrQSwiOdEaa0Aj6IC4vGEJ.jpg'),
(165210, 11721, 'O Rei do Inverno S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/505500.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mRs0nxz6eJC5A9vwDryuehBlXgR.jpg'),
(165211, 11721, 'O Rei do Inverno S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/505501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQm8mkzFv97sEmr6A63Az8ggs0M.jpg'),
(165212, 11721, 'O Rei do Inverno S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/505502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQm8mkzFv97sEmr6A63Az8ggs0M.jpg'),
(165213, 11721, 'O Rei do Inverno S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/505503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQm8mkzFv97sEmr6A63Az8ggs0M.jpg'),
(165214, 11721, 'O Rei do Inverno S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/505504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQm8mkzFv97sEmr6A63Az8ggs0M.jpg'),
(165215, 11721, 'O Rei do Inverno S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/505505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQm8mkzFv97sEmr6A63Az8ggs0M.jpg'),
(165216, 11722, 'Trabalho Honesto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502862.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9Hmgk7FdAJQ51JzuInPNfkTyMfM.jpg'),
(165217, 11722, 'Trabalho Honesto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502863.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1qheSDWmRkfLrxaW8r9JTQpXToW.jpg'),
(165218, 11722, 'Trabalho Honesto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/507512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4fncJSnUqbkMurayrXHNmOw2YTC.jpg'),
(165219, 11722, 'Trabalho Honesto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/507513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4fncJSnUqbkMurayrXHNmOw2YTC.jpg'),
(165220, 11722, 'Trabalho Honesto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/511020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4fncJSnUqbkMurayrXHNmOw2YTC.jpg'),
(165221, 11722, 'Trabalho Honesto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/511021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4fncJSnUqbkMurayrXHNmOw2YTC.jpg'),
(165222, 11722, 'Trabalho Honesto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/513901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4fncJSnUqbkMurayrXHNmOw2YTC.jpg'),
(165223, 11722, 'Trabalho Honesto S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/513902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4fncJSnUqbkMurayrXHNmOw2YTC.jpg'),
(165224, 11722, 'Trabalho Honesto S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/516959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4fncJSnUqbkMurayrXHNmOw2YTC.jpg'),
(165225, 11722, 'Trabalho Honesto S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/516960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4fncJSnUqbkMurayrXHNmOw2YTC.jpg'),
(165226, 11722, 'Trabalho Honesto S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4fncJSnUqbkMurayrXHNmOw2YTC.jpg'),
(165227, 11722, 'Trabalho Honesto S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4fncJSnUqbkMurayrXHNmOw2YTC.jpg'),
(165228, 11723, 'Angelica 50 e Uns S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502857.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cmfc6uEZEhbas8xbZ4miLCRlEI1.jpg'),
(165229, 11723, 'Angelica 50 e Uns S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502858.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bi9jiSAikh5XTLMAq46R7f5hujn.jpg'),
(165230, 11723, 'Angelica 50 e Uns S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502859.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cq9pUyYFMJFvEUnsQlWDU3olCZd.jpg'),
(165231, 11723, 'Angelica 50 e Uns S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502860.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eP2mbau5O6h2mILAXbSoNN1aiUS.jpg'),
(165232, 11723, 'Angelica 50 e Uns S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502861.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z2QouW0JkL9Ejl57CaswSmGtJ7v.jpg'),
(165233, 11724, 'Nightsleeper S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502856.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jpHS648BqBDBEdZmj0IufrwaOf1.jpg'),
(165234, 11724, 'Nightsleeper S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/507715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/twMzmcKkJpftjhYyrPXETddN08R.jpg'),
(165235, 11724, 'Nightsleeper S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/515411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/twMzmcKkJpftjhYyrPXETddN08R.jpg'),
(165236, 11724, 'Nightsleeper S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/517803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/twMzmcKkJpftjhYyrPXETddN08R.jpg'),
(165237, 11724, 'Nightsleeper S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/517804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/twMzmcKkJpftjhYyrPXETddN08R.jpg'),
(165238, 11724, 'Nightsleeper S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/525231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/twMzmcKkJpftjhYyrPXETddN08R.jpg'),
(165239, 11725, 'Catfish Brasil S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165240, 11725, 'Catfish Brasil S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165241, 11725, 'Catfish Brasil S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165242, 11725, 'Catfish Brasil S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165243, 11725, 'Catfish Brasil S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165244, 11725, 'Catfish Brasil S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165245, 11725, 'Catfish Brasil S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165246, 11725, 'Catfish Brasil S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165247, 11726, 'Catfish Brasil S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165248, 11726, 'Catfish Brasil S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165249, 11726, 'Catfish Brasil S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165250, 11726, 'Catfish Brasil S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165251, 11727, 'Catfish Brasil S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165252, 11727, 'Catfish Brasil S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165253, 11727, 'Catfish Brasil S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165254, 11727, 'Catfish Brasil S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165255, 11727, 'Catfish Brasil S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165256, 11727, 'Catfish Brasil S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165257, 11727, 'Catfish Brasil S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165258, 11727, 'Catfish Brasil S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165259, 11727, 'Catfish Brasil S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165260, 11727, 'Catfish Brasil S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qw19tyRWXg1mvWVkFscCOc8QSAo.jpg'),
(165261, 11728, 'Dragon Ball Z Kai S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502736.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gPglPQFQ2TbHoSXJSWqza2bUSyc.jpg'),
(165262, 11728, 'Dragon Ball Z Kai S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502737.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cJ9hG81PkfDVfPYbNic0lHbnQRE.jpg'),
(165263, 11728, 'Dragon Ball Z Kai S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502738.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cuhuDDqPOIpcqryZUZg9krmuTbB.jpg'),
(165264, 11728, 'Dragon Ball Z Kai S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502739.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1rsdqjA4eDWWzGqXvWDmRtfIZ0J.jpg'),
(165265, 11728, 'Dragon Ball Z Kai S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502740.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5TRO0OnBFehy3iPSc9jXSmTtUHL.jpg'),
(165266, 11728, 'Dragon Ball Z Kai S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502741.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wUhtBUQutlGUnd9rKevRSQJKkH0.jpg'),
(165267, 11728, 'Dragon Ball Z Kai S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502742.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uqEbjjA9VSLqSwgmNd1LFZCUoXm.jpg'),
(165268, 11728, 'Dragon Ball Z Kai S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502743.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2ut792wk9BsODyLhiljotvrprsT.jpg'),
(165269, 11728, 'Dragon Ball Z Kai S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502744.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j8uh5ROYY6SOlBRpgOV0MrHFV6v.jpg'),
(165270, 11728, 'Dragon Ball Z Kai S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502745.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jij9Iqp7tC9MeJrIi6PxYpPVQva.jpg'),
(165271, 11728, 'Dragon Ball Z Kai S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502746.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hgxz7FwBiQBc0UpeZ1ifRKP5mQ6.jpg'),
(165272, 11728, 'Dragon Ball Z Kai S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/502747.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wRab3kRw8ZYgnV07wMPLcPHNSK3.jpg'),
(165273, 11728, 'Dragon Ball Z Kai S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/502748.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/prSCbjWBYGks0QN5De3457adkzv.jpg'),
(165274, 11728, 'Dragon Ball Z Kai S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/502749.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lqDqym1QwTqu4GkmeFtS6nb9nZN.jpg'),
(165275, 11728, 'Dragon Ball Z Kai S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/502750.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fgHUwOKg7qrnmkPwzaSNWoTM5J2.jpg'),
(165276, 11728, 'Dragon Ball Z Kai S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/502751.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1byTopw8xGBb3u1eE847ogwf7Y2.jpg'),
(165277, 11728, 'Dragon Ball Z Kai S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/502752.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wWe79ufTx9h4WFdG39lpJEHRwCD.jpg'),
(165278, 11728, 'Dragon Ball Z Kai S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/502753.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/weOgU2Vh1OW6l1B1WCA0vPTXnqp.jpg'),
(165279, 11729, 'Dragon Ball Z Kai S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502754.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1b32PsqErZTI77N6IyE7EUPzTTX.jpg'),
(165280, 11729, 'Dragon Ball Z Kai S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502755.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rLw71n8UtSlW7cIR63VJsc9hwgH.jpg'),
(165281, 11729, 'Dragon Ball Z Kai S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502756.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/grZiiaX29bem6PAk29582LOCgt.jpg'),
(165282, 11729, 'Dragon Ball Z Kai S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502757.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uIHPsLCnGgE05VvWEsjU9Y5Ql2i.jpg'),
(165283, 11729, 'Dragon Ball Z Kai S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502758.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ds95ffi8yFY60tLI6tRa4XtuCEI.jpg'),
(165284, 11729, 'Dragon Ball Z Kai S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502759.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b0EVGIbesfXSpXXu0PbiJ6g7Z5c.jpg'),
(165285, 11729, 'Dragon Ball Z Kai S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502760.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wE7dUShaK5AAWw8qkAAcQyclrLN.jpg'),
(165286, 11729, 'Dragon Ball Z Kai S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502761.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aBHfAMHnBdOrLOAeWYLBaohO4iP.jpg'),
(165287, 11729, 'Dragon Ball Z Kai S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502762.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pGqXtLpc1CB6Ww2u4XbsWr2sP5l.jpg'),
(165288, 11729, 'Dragon Ball Z Kai S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502763.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/GK8KK3IQtvpP8cq1AOiJ2wOxmY.jpg'),
(165289, 11729, 'Dragon Ball Z Kai S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502764.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3Jzl8M7W76bzBRKV1Ax9L12a08a.jpg'),
(165290, 11729, 'Dragon Ball Z Kai S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/502765.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6dypR3vanHiPJ2ocbSn5hjhXv37.jpg'),
(165291, 11729, 'Dragon Ball Z Kai S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/502766.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lRha5F5Fhesu5UA9ziqeKFzBugk.jpg'),
(165292, 11729, 'Dragon Ball Z Kai S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/502767.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q2ZJCRa143tVA5UZ3XwJblyKs3x.jpg'),
(165293, 11729, 'Dragon Ball Z Kai S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/502768.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xf16h1Aa1YVcv4901jAR6z2SgAZ.jpg'),
(165294, 11729, 'Dragon Ball Z Kai S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/502769.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iq2ptTWoE2kVcJnUOg8sPIOPZQY.jpg'),
(165295, 11729, 'Dragon Ball Z Kai S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/502770.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kGUqOxA6GTB7Z1K5rcbHds96bpI.jpg'),
(165296, 11729, 'Dragon Ball Z Kai S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/502771.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jmXAiNFOud5pJ6TQEQxs8gdQXnd.jpg'),
(165297, 11729, 'Dragon Ball Z Kai S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/502772.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mZXYdrCabzqWyzbvRZTR0WISkPa.jpg'),
(165298, 11729, 'Dragon Ball Z Kai S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/502773.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gLDEVT6SUXi7Z5WqUK9AlfRSvd8.jpg'),
(165299, 11729, 'Dragon Ball Z Kai S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/502774.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9gVNNdngASXtffPVKCZyX2rR1OV.jpg'),
(165300, 11729, 'Dragon Ball Z Kai S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/502775.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3KkyecgCd8JdEbwmAwcSyT887fn.jpg'),
(165301, 11729, 'Dragon Ball Z Kai S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/502776.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qs5bEHpL2w74KHvQR16tCJq8pW1.jpg'),
(165302, 11729, 'Dragon Ball Z Kai S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/502777.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6EH0pZ4T6jkc19112RQ6azCa4t7.jpg'),
(165303, 11729, 'Dragon Ball Z Kai S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/502778.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zLyHpNv4aqpTmFQaFwfjKfKlR3R.jpg'),
(165304, 11729, 'Dragon Ball Z Kai S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/502779.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mK35E3o0FaKzQ6sFpI2NHpOYtZ0.jpg'),
(165305, 11729, 'Dragon Ball Z Kai S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/502780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165306, 11729, 'Dragon Ball Z Kai S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/502781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165307, 11729, 'Dragon Ball Z Kai S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/502782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165308, 11729, 'Dragon Ball Z Kai S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/502783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165309, 11729, 'Dragon Ball Z Kai S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/502784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165310, 11729, 'Dragon Ball Z Kai S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/502785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165311, 11729, 'Dragon Ball Z Kai S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/502786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165312, 11729, 'Dragon Ball Z Kai S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/502787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165313, 11729, 'Dragon Ball Z Kai S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/502788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165314, 11729, 'Dragon Ball Z Kai S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/502789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165315, 11729, 'Dragon Ball Z Kai S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/502790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165316, 11729, 'Dragon Ball Z Kai S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/502791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165317, 11730, 'Dragon Ball Z Kai S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502792.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vngzm5R3NYaDWHMBI6djKnyq7hK.jpg'),
(165318, 11730, 'Dragon Ball Z Kai S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502793.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qQ7tMnzsNx8WrULhgiqv6YYaynJ.jpg'),
(165319, 11730, 'Dragon Ball Z Kai S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502794.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c5CtmLi1bgNpNN48iBkm8nKDsyW.jpg'),
(165320, 11730, 'Dragon Ball Z Kai S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502795.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wtiCs4qkRFsCXcGFDrAqdbOX7we.jpg'),
(165321, 11730, 'Dragon Ball Z Kai S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502796.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/paTZtKVt4jifXQ9BuskXidxuyPW.jpg'),
(165322, 11730, 'Dragon Ball Z Kai S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502797.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uuw8OiHiWkRaY8KkFWMEqXHDZDz.jpg'),
(165323, 11730, 'Dragon Ball Z Kai S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502798.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ytHz5WumctIYjojzJjAhTtHF3mb.jpg'),
(165324, 11730, 'Dragon Ball Z Kai S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502799.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uSnwmdk371qxdo5wyswSlNj2AXt.jpg'),
(165325, 11730, 'Dragon Ball Z Kai S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502800.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/66BnCm41RawiWhbT6XVL8JUb74B.jpg'),
(165326, 11730, 'Dragon Ball Z Kai S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502801.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4NtfB6gVEvep3YdQY3yLUiIZw77.jpg'),
(165327, 11730, 'Dragon Ball Z Kai S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502802.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/srWvTdyrWBaeXN4ul22lAXT9yYl.jpg'),
(165328, 11730, 'Dragon Ball Z Kai S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/502803.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rwrEHylwldBOrK96fTqywQqzhtE.jpg'),
(165329, 11730, 'Dragon Ball Z Kai S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/502804.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hnQdBRhpAPhY1i301iZII13DyYp.jpg'),
(165330, 11730, 'Dragon Ball Z Kai S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/502805.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fLrSCmwZECu5Np6DfmRzrqTq24Q.jpg'),
(165331, 11730, 'Dragon Ball Z Kai S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/502806.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ktVfl8rp4Z9HJTUhvH6Ax8QFapN.jpg'),
(165332, 11730, 'Dragon Ball Z Kai S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/502807.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zeP9T0UgjoJERm2KiHsAQJlUqrr.jpg'),
(165333, 11730, 'Dragon Ball Z Kai S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/502808.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6JccHPHyDLrYNleeIhgggebhRDI.jpg'),
(165334, 11730, 'Dragon Ball Z Kai S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/502809.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kp4ypjCOeh5hvxoHt20gYkxN8E4.jpg'),
(165335, 11730, 'Dragon Ball Z Kai S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/502810.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zJQzGdnT5kiiS4GpFAzi53sIYgV.jpg'),
(165336, 11730, 'Dragon Ball Z Kai S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/502811.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/R2bBYdULeLGp4oeT0xlkuSDZXC.jpg'),
(165337, 11730, 'Dragon Ball Z Kai S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/502812.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rzu0ReNtXfHRLGit5LUvhmIEZbl.jpg'),
(165338, 11730, 'Dragon Ball Z Kai S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/502813.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vxxh2ETXEUyE0CjEhPQkl3Fy0sb.jpg'),
(165339, 11730, 'Dragon Ball Z Kai S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/502814.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/UgVRAxaHOMDwv6BCLbe1Neft0S.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(165340, 11730, 'Dragon Ball Z Kai S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/502815.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ksQQF79hwavmtIG8wbS4cdwpxFf.jpg'),
(165341, 11730, 'Dragon Ball Z Kai S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/502816.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wSlsgqDl9A14KMiPFxYVigHbS5a.jpg'),
(165342, 11730, 'Dragon Ball Z Kai S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/502817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165343, 11730, 'Dragon Ball Z Kai S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/502818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165344, 11730, 'Dragon Ball Z Kai S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/502819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165345, 11730, 'Dragon Ball Z Kai S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/502820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165346, 11730, 'Dragon Ball Z Kai S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/502821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165347, 11730, 'Dragon Ball Z Kai S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/502822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165348, 11730, 'Dragon Ball Z Kai S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/502823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165349, 11730, 'Dragon Ball Z Kai S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/502824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165350, 11730, 'Dragon Ball Z Kai S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/502825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165351, 11730, 'Dragon Ball Z Kai S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/502826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165352, 11730, 'Dragon Ball Z Kai S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/502827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165353, 11730, 'Dragon Ball Z Kai S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/502828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165354, 11730, 'Dragon Ball Z Kai S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/502829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165355, 11730, 'Dragon Ball Z Kai S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/502830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165356, 11730, 'Dragon Ball Z Kai S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/502831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165357, 11730, 'Dragon Ball Z Kai S03 E41', 'http://sinalprivado.info:80/series/1533784/1533784/502832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165358, 11730, 'Dragon Ball Z Kai S03 E42', 'http://sinalprivado.info:80/series/1533784/1533784/502833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qxL2QgXCxe8QbiCMYvCVSCRJ731.jpg'),
(165359, 11731, 'O Tempo Entre Costuras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502719.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iSOqgCDIR1RQh0dD2Lyt6xSHXvv.jpg'),
(165360, 11731, 'O Tempo Entre Costuras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502720.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5sA0v9TBStGdbW0WOxn0g577N0Y.jpg'),
(165361, 11731, 'O Tempo Entre Costuras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502721.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qkZv3y34RYXF11F5cu06CjWLdCI.jpg'),
(165362, 11731, 'O Tempo Entre Costuras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502722.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8LElwyDzO02BgQe9H2Lx0pGWkD7.jpg'),
(165363, 11731, 'O Tempo Entre Costuras S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502723.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yzD9dtcstfjY0aIyUi1HxhGywK6.jpg'),
(165364, 11731, 'O Tempo Entre Costuras S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502724.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/swV2GiW80gFnEC7G7CKZZEHHDUX.jpg'),
(165365, 11731, 'O Tempo Entre Costuras S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502725.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eM0Uzfpfaq4cL4PqgHC3uoOFygR.jpg'),
(165366, 11731, 'O Tempo Entre Costuras S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502726.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jgiDJwi5lQ5Hjt6byE7TZQ1feqI.jpg'),
(165367, 11731, 'O Tempo Entre Costuras S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502727.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ukecf8iiIdRP8e8UCxFi2Uqc638.jpg'),
(165368, 11731, 'O Tempo Entre Costuras S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cOtzEpmktbphnJ9bwvwxkVUgQSS.jpg'),
(165369, 11731, 'O Tempo Entre Costuras S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502729.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wEj09Ym7Fv3I8q1aEvg7L4kJxAV.jpg'),
(165370, 11731, 'O Tempo Entre Costuras S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/502730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cOtzEpmktbphnJ9bwvwxkVUgQSS.jpg'),
(165371, 11731, 'O Tempo Entre Costuras S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/502731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cOtzEpmktbphnJ9bwvwxkVUgQSS.jpg'),
(165372, 11731, 'O Tempo Entre Costuras S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/502732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cOtzEpmktbphnJ9bwvwxkVUgQSS.jpg'),
(165373, 11731, 'O Tempo Entre Costuras S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/502733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cOtzEpmktbphnJ9bwvwxkVUgQSS.jpg'),
(165374, 11731, 'O Tempo Entre Costuras S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/502734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cOtzEpmktbphnJ9bwvwxkVUgQSS.jpg'),
(165375, 11731, 'O Tempo Entre Costuras S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/502735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cOtzEpmktbphnJ9bwvwxkVUgQSS.jpg'),
(165376, 11732, 'The Faraway Paladin S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502707.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7vh4p4VMVlUJKUsat2KAAJWwFxo.jpg'),
(165377, 11732, 'The Faraway Paladin S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502708.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zqdLlhtrw92Rfwtn7dkpYtDSiXn.jpg'),
(165378, 11732, 'The Faraway Paladin S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502709.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hCoWsUlaNV0RBmEOSGYztqbLug3.jpg'),
(165379, 11732, 'The Faraway Paladin S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502710.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qxQzdKpPtcNeIbdCVQk9zhpjSgK.jpg'),
(165380, 11732, 'The Faraway Paladin S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502711.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zcRqFGiR9iHFQdkEbXH2v1OjVkb.jpg'),
(165381, 11732, 'The Faraway Paladin S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502712.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5BxZ5AkMQs6J0u9P30WLgXgpmHo.jpg'),
(165382, 11732, 'The Faraway Paladin S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502713.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/87MVgHP5tDZrIs7VBqkDODHqcJQ.jpg'),
(165383, 11732, 'The Faraway Paladin S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502714.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zSIdWIvbEfEDZyRP7dv6nWomSTk.jpg'),
(165384, 11732, 'The Faraway Paladin S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502715.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9cgFiJEoehRQuXPexqvIvVvqQSK.jpg'),
(165385, 11732, 'The Faraway Paladin S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502716.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sGPxGofJotnctprlbUvcCnijKeR.jpg'),
(165386, 11732, 'The Faraway Paladin S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502717.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jqPT3hvCSna8wmU60CbvH30O4TP.jpg'),
(165387, 11732, 'The Faraway Paladin S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/502718.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ltXBm1fB3WgDsUAw68INFJMiaAR.jpg'),
(165388, 11733, 'Affair [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502521.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/PBbS7fgbq83pWhL9pYbWdjSwqV.jpg'),
(165389, 11733, 'Affair [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502522.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fNDaaEbTCPMa16jrdBXtLcqL7e5.jpg'),
(165390, 11733, 'Affair [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502523.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7NsbZdQoMfzJVjTg7Ll3urg5IUu.jpg'),
(165391, 11733, 'Affair [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502524.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3FtJKTxbFaqi5KUqFWA0YkZkKqQ.jpg'),
(165392, 11733, 'Affair [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502525.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gveovdxeYRxkfisJ4hlvDJaKAZr.jpg'),
(165393, 11733, 'Affair [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502526.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tw11IPlFgs71wW4O2MAJWHFbFTl.jpg'),
(165394, 11733, 'Affair [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502527.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rCfyIaYZANKEURXRmL6bcTeLbr9.jpg'),
(165395, 11733, 'Affair [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502528.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uu1LuPY86av0nL8RLLM3D4b7UyR.jpg'),
(165396, 11734, 'Blue Canvas of Youthful Days [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/he51AgTDq3cUomzh4qvtBSORst2.jpg'),
(165397, 11734, 'Blue Canvas of Youthful Days [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/he51AgTDq3cUomzh4qvtBSORst2.jpg'),
(165398, 11734, 'Blue Canvas of Youthful Days [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/he51AgTDq3cUomzh4qvtBSORst2.jpg'),
(165399, 11734, 'Blue Canvas of Youthful Days [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/he51AgTDq3cUomzh4qvtBSORst2.jpg'),
(165400, 11734, 'Blue Canvas of Youthful Days [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/he51AgTDq3cUomzh4qvtBSORst2.jpg'),
(165401, 11734, 'Blue Canvas of Youthful Days [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/he51AgTDq3cUomzh4qvtBSORst2.jpg'),
(165402, 11734, 'Blue Canvas of Youthful Days [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/he51AgTDq3cUomzh4qvtBSORst2.jpg'),
(165403, 11734, 'Blue Canvas of Youthful Days [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/508542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/he51AgTDq3cUomzh4qvtBSORst2.jpg'),
(165404, 11734, 'Blue Canvas of Youthful Days [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/515697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/he51AgTDq3cUomzh4qvtBSORst2.jpg'),
(165405, 11734, 'Blue Canvas of Youthful Days [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/515698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/he51AgTDq3cUomzh4qvtBSORst2.jpg'),
(165406, 11734, 'Blue Canvas of Youthful Days [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/518885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/he51AgTDq3cUomzh4qvtBSORst2.jpg'),
(165407, 11734, 'Blue Canvas of Youthful Days [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/518886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/he51AgTDq3cUomzh4qvtBSORst2.jpg'),
(165408, 11735, 'Duvida [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/628221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Y1eKKOvV9FRFbVpRo3oj6VrvFM.jpg'),
(165409, 11735, 'Duvida [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502507.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3BF1Kx3SlSHcjSnucVx2RrBvF3a.jpg'),
(165410, 11735, 'Duvida [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502508.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lHYIg1G4O3NydD1W3QoHCe5ZFgX.jpg'),
(165411, 11735, 'Duvida [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502509.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gK6jsSBM4xyXCswMqFM7h1EFXNd.jpg'),
(165412, 11735, 'Duvida [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502510.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cT75DTgxThhpyhDbvqZ80XPzpYX.jpg'),
(165413, 11735, 'Duvida [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502511.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hiwf1rgi55bELYqaREwdHIQTdJV.jpg'),
(165414, 11735, 'Duvida [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502512.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oxyt6lNx5lwOf3WcaHKVF4uqR1x.jpg'),
(165415, 11735, 'Duvida [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502513.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uqJKBV0kKldOQpZ2tjvKnjrsuTR.jpg'),
(165416, 11735, 'Duvida [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502514.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hU95Z8sNk0iIZJptBgKyZ6kH6BW.jpg'),
(165417, 11735, 'Duvida [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/628230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Y1eKKOvV9FRFbVpRo3oj6VrvFM.jpg'),
(165418, 11735, 'Duvida [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/508520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Y1eKKOvV9FRFbVpRo3oj6VrvFM.jpg'),
(165419, 11736, 'Estudos Sociais Crescendo na Era Digital [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502501.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4dUptivPfw2BSLHDwd6cdy6GIbd.jpg'),
(165420, 11736, 'Estudos Sociais Crescendo na Era Digital [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502502.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gkNdCWfStcOxkdAJcvzUiwzHQua.jpg'),
(165421, 11736, 'Estudos Sociais Crescendo na Era Digital [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502503.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cK4QfugeM3nuHF8s2GS2p24YbIS.jpg'),
(165422, 11736, 'Estudos Sociais Crescendo na Era Digital [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502504.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zIS9g6O8r3iOaRmytEQCd6nX4cB.jpg'),
(165423, 11736, 'Estudos Sociais Crescendo na Era Digital [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502505.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AqZlNuCLKPaKJpLEdQwvlUDJbyd.jpg'),
(165424, 10634, 'Girls Band Cry [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502488.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tl09m8rTN4a1cMzRd7KKuQSSjbf.jpg'),
(165425, 10634, 'Girls Band Cry [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502489.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t7MD0CpXY0fkchtPkIhkqJ6HCHN.jpg'),
(165426, 10634, 'Girls Band Cry [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502490.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7J4ayKC5HdAwjYVTX6lMxjMxxy0.jpg'),
(165427, 10634, 'Girls Band Cry [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502491.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7I8FEYhBocNfCv2PG1KIz95LqUv.jpg'),
(165428, 10634, 'Girls Band Cry [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502492.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ouAw1kVBUTyS746ngyaNL38cxsl.jpg'),
(165429, 10634, 'Girls Band Cry [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502493.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xSotVQztQE6ExxvlgpAjlAzPv3N.jpg'),
(165430, 10634, 'Girls Band Cry [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502494.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kW8d62bz5Mqoo8i6FbVbXlK9PZI.jpg'),
(165431, 10634, 'Girls Band Cry [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502495.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tMmH3uhot3jGgusMRUkUSftsGvY.jpg'),
(165432, 10634, 'Girls Band Cry [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502496.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/97mCCTpeymXEX2q6yDHUmh8qzMq.jpg'),
(165433, 10634, 'Girls Band Cry [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502497.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/50GOFjQSuWVfzGGtbraatSdH66s.jpg'),
(165434, 10634, 'Girls Band Cry [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502498.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nJkV3XS1rK9Cu7n0uD0RGp1sqYD.jpg'),
(165435, 10634, 'Girls Band Cry [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/502499.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x44HVN5ReERJnM5EVvhDkTZLf86.jpg'),
(165436, 10634, 'Girls Band Cry [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/502500.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w9xFcCgpYdMf3W1kq3mMDc5hZZF.jpg'),
(165437, 11737, 'Hysteria [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502480.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aQ8lC1AyRSl0KTDjdc2mJTt652a.jpg'),
(165438, 11737, 'Hysteria [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502481.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4tzaamViJzPl29zC0Zeqsid0Atp.jpg'),
(165439, 11737, 'Hysteria [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502482.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sMOOX7LiSyMiiJ4OcQ30eL1Y78J.jpg'),
(165440, 11737, 'Hysteria [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502483.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uYTknw8tt82n72UP34bCZzGnHkP.jpg'),
(165441, 11737, 'Hysteria [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502484.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vsnPewEY0dGhHRKCv1PIaL0PGoh.jpg'),
(165442, 11737, 'Hysteria [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502485.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vx9jHAVp8rKgtmRH4bAIzAqaII8.jpg'),
(165443, 11737, 'Hysteria [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502486.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5S1XxS2cFawNpMYupBlGUUDfpws.jpg'),
(165444, 11737, 'Hysteria [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502487.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ntGUchSvr3NnElJrB8vgZTiR7Ok.jpg'),
(165445, 11738, 'Linda Mentira [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502458.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kXyJf75QeWz7aCaP7TQiQJfoVfb.jpg'),
(165446, 11738, 'Linda Mentira [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502459.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xT5mIOK3ZXbPyaoQXd487ceZQw9.jpg'),
(165447, 11738, 'Linda Mentira [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502460.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/se1w1zXy9OQwueBBT1mDt5YaUjm.jpg'),
(165448, 11738, 'Linda Mentira [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502461.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yOHhIdg64NTt2r2tUOQpjiVCyVT.jpg'),
(165449, 11738, 'Linda Mentira [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502462.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xLmi9S4WAagwnt57SHRLJ3KcAzk.jpg'),
(165450, 11738, 'Linda Mentira [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502463.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/14kX2MUG027vTltEKnYeBOJXMHy.jpg'),
(165451, 11738, 'Linda Mentira [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502464.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2y7ZVdslwU2jkmED8cehLrh1BiT.jpg'),
(165452, 11738, 'Linda Mentira [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502465.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/86qokQTnHyCYWqVsQqYaI517ItG.jpg'),
(165453, 11738, 'Linda Mentira [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502466.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q6NyYezU51y9s6w7egFrsqYQbvm.jpg'),
(165454, 11738, 'Linda Mentira [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502467.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ohmkXrqhe2Te4zFtYd0q1KFE6Dt.jpg'),
(165455, 11738, 'Linda Mentira [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502468.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uKD5c1laeWrCsVOxKVOuvCSgvmN.jpg'),
(165456, 11738, 'Linda Mentira [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/502469.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/daG0hCBa4FVYN2yQc1eyHVFsAY.jpg'),
(165457, 11738, 'Linda Mentira [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/502470.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ybYwrOFFX2XoTEEf88LxlsOh8sz.jpg'),
(165458, 11738, 'Linda Mentira [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/502471.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rxVsELrqzuDZyP5vLKTSSCfVmmj.jpg'),
(165459, 11738, 'Linda Mentira [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/502472.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6UhMQ9qet2YpqNIc53RWwIkWOv9.jpg'),
(165460, 11738, 'Linda Mentira [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/502473.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qjLr5xfNg5iHE224FgmFbWuA6Wn.jpg'),
(165461, 11738, 'Linda Mentira [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/502474.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tZZFjLBOctSVa151AZR5oOGCyo2.jpg'),
(165462, 11738, 'Linda Mentira [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/502475.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zOMfUHJiM2uoDJLFyib8dIL2bVO.jpg'),
(165463, 11738, 'Linda Mentira [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/502476.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/atdoB6BIjOwd56T9MPsMg6wud8Q.jpg'),
(165464, 11738, 'Linda Mentira [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/502477.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oaIrovolYMKs3fXZyyi5aVT5ADv.jpg'),
(165465, 11738, 'Linda Mentira [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/502478.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8Nv6MN6rFrhrLInou7JGqghnTQ1.jpg'),
(165466, 11738, 'Linda Mentira [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/502479.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cZQOKyJTBzX5eEzcLw4kAcJR3ev.jpg'),
(165467, 11739, 'Love Senior [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502448.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gCRXkpvCXlhlw5Bvqtmt8DETnD8.jpg'),
(165468, 11739, 'Love Senior [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502449.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jKURBITNviUNkNvqoLBKkxMic7C.jpg'),
(165469, 11739, 'Love Senior [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502450.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jQ2vhFzFDimrhp7k3Mf8RCmgstA.jpg'),
(165470, 11739, 'Love Senior [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502451.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/egFWDBgG643pTuOi7JtQNUmrbPf.jpg'),
(165471, 11739, 'Love Senior [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502452.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lJHLmEsSl6lG7Q2CLeBqzpycQiT.jpg'),
(165472, 11739, 'Love Senior [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502453.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cNLIsFY9KVuOv5cNHitU34Yvx57.jpg'),
(165473, 11739, 'Love Senior [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502454.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x3AOeBBo2j3Sgdg48u4K5AzjAZs.jpg'),
(165474, 11739, 'Love Senior [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502455.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gqmLYfez68xZKUsSCTtNlKEEyVo.jpg'),
(165475, 11739, 'Love Senior [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502456.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gmo41ewdLzNo7bdaOZuOObSpxtI.jpg'),
(165476, 11739, 'Love Senior [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cXqrbHhW8MfZJ6l1VpFn8XA6b78.jpg'),
(165477, 11740, 'Love Sick [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502442.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u0Xx6FVoIxJO6HAzEQwd6WDyMZI.jpg'),
(165478, 11740, 'Love Sick [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502443.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ySPQvjjG0cIMmbQ4nfCANFWE0UD.jpg'),
(165479, 11740, 'Love Sick [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502444.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aWou9WBy8eehZnMX6kzyg9x8pOv.jpg'),
(165480, 11740, 'Love Sick [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502445.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p7AYyx6ckdlLfuVgbEzMdsSUDht.jpg'),
(165481, 11740, 'Love Sick [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502446.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iuMEWjyGpAVlu1Y9eOT6iPS5IxA.jpg'),
(165482, 11740, 'Love Sick [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502447.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6Upuap9xYzHw17lIKF2ixUK9D7M.jpg'),
(165483, 11741, 'Mate Me Ame Me [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502419.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cNnS8krUD62irUoljE8qBi13PMh.jpg'),
(165484, 11741, 'Mate Me Ame Me [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502420.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oNuNEsYieTfkQrldRaYAfN9hUHL.jpg'),
(165485, 11741, 'Mate Me Ame Me [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502421.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rh71Q37XfpRRgptCc5WrjeYYzO3.jpg'),
(165486, 11741, 'Mate Me Ame Me [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502422.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7nDrIj1MVjUg74qz4UFyU1fhmgy.jpg'),
(165487, 11741, 'Mate Me Ame Me [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502423.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y6M0mjFEtqBZrMmNDDoYLxMedx2.jpg'),
(165488, 11741, 'Mate Me Ame Me [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502424.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cbzpkagZxu0OxGp4cInt3lFY2N7.jpg'),
(165489, 11741, 'Mate Me Ame Me [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502425.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5UWfoiBBCurIB4hRDJrbhybrUR8.jpg'),
(165490, 11741, 'Mate Me Ame Me [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/632962.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/csA4kpdwzfvphNMrlYQNRqpmIf0.jpg'),
(165491, 11741, 'Mate Me Ame Me [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502427.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/74PgBqCDFwrBcUMJ2cBkDw4z75U.jpg'),
(165492, 11741, 'Mate Me Ame Me [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502428.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vu3DwRFO0yGvr67tegOMYNoPSBl.jpg'),
(165493, 11741, 'Mate Me Ame Me [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502429.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1LqjTk5Fs4yquFqp7YZrJOSIdZD.jpg'),
(165494, 11741, 'Mate Me Ame Me [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/502430.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q09fsv8k9ZiadzjGOj8k1YjGOW.jpg'),
(165495, 11741, 'Mate Me Ame Me [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/502431.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gIYBfbLwWHPn4zawsZiQ6ZTOqK0.jpg'),
(165496, 11741, 'Mate Me Ame Me [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/502432.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z5yeSXq3TElCIpgdHJvRgx13Qdr.jpg'),
(165497, 11741, 'Mate Me Ame Me [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/502433.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eCqedX7L30tjR3C3OcziAA4ta0o.jpg'),
(165498, 11741, 'Mate Me Ame Me [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/502434.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7mzD5bcxFcHJk5K7rhJ0iCLQPMh.jpg'),
(165499, 11741, 'Mate Me Ame Me [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/502435.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pj0RpmZQa5UP6tETzo9YFcW51ch.jpg'),
(165500, 11741, 'Mate Me Ame Me [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/502436.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aIr9143oSrfN110X5L4LI5al751.jpg'),
(165501, 11741, 'Mate Me Ame Me [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/502437.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iolb8DVyfIvDvAB7DWtkZJ6peyr.jpg'),
(165502, 11741, 'Mate Me Ame Me [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/502438.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tbHItNttqudDK4i8b06m1xDJMTw.jpg'),
(165503, 11741, 'Mate Me Ame Me [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/502439.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x8kHlF9GHOfARz8iGrWpKxJLsXD.jpg'),
(165504, 11741, 'Mate Me Ame Me [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/502440.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9YfmfIRoQSl1GRNkME8YA69Z8RI.jpg'),
(165505, 11741, 'Mate Me Ame Me [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/632977.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qFVMoCLswwquDUSNdZilxkDAiHe.jpg'),
(165506, 11741, 'Mate Me Ame Me [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/511601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Ra74ZCKOMmGeBn6oDDl7WOAvwW.jpg'),
(165507, 11741, 'Mate Me Ame Me [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/511602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Ra74ZCKOMmGeBn6oDDl7WOAvwW.jpg'),
(165508, 11741, 'Mate Me Ame Me [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/511603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Ra74ZCKOMmGeBn6oDDl7WOAvwW.jpg'),
(165509, 11741, 'Mate Me Ame Me [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/511604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Ra74ZCKOMmGeBn6oDDl7WOAvwW.jpg'),
(165510, 11741, 'Mate Me Ame Me [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/511605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Ra74ZCKOMmGeBn6oDDl7WOAvwW.jpg'),
(165511, 11741, 'Mate Me Ame Me [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/511606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Ra74ZCKOMmGeBn6oDDl7WOAvwW.jpg'),
(165512, 11741, 'Mate Me Ame Me [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/511607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Ra74ZCKOMmGeBn6oDDl7WOAvwW.jpg'),
(165513, 11741, 'Mate Me Ame Me [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/511608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Ra74ZCKOMmGeBn6oDDl7WOAvwW.jpg'),
(165514, 11741, 'Mate Me Ame Me [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/511609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7Ra74ZCKOMmGeBn6oDDl7WOAvwW.jpg'),
(165515, 11742, 'Meu Duble [L] S00 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHp4smGKQ5pNuLhsOSOLq17QRU.jpg'),
(165516, 11742, 'Meu Duble [L] S00 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHp4smGKQ5pNuLhsOSOLq17QRU.jpg'),
(165517, 11742, 'Meu Duble [L] S00 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHp4smGKQ5pNuLhsOSOLq17QRU.jpg'),
(165518, 11742, 'Meu Duble [L] S00 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHp4smGKQ5pNuLhsOSOLq17QRU.jpg'),
(165519, 11742, 'Meu Duble [L] S00 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHp4smGKQ5pNuLhsOSOLq17QRU.jpg'),
(165520, 11742, 'Meu Duble [L] S00 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHp4smGKQ5pNuLhsOSOLq17QRU.jpg'),
(165521, 11742, 'Meu Duble [L] S00 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHp4smGKQ5pNuLhsOSOLq17QRU.jpg'),
(165522, 11742, 'Meu Duble [L] S00 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHp4smGKQ5pNuLhsOSOLq17QRU.jpg'),
(165523, 11742, 'Meu Duble [L] S00 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHp4smGKQ5pNuLhsOSOLq17QRU.jpg'),
(165524, 11742, 'Meu Duble [L] S00 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHp4smGKQ5pNuLhsOSOLq17QRU.jpg'),
(165525, 11742, 'Meu Duble [L] S00 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHp4smGKQ5pNuLhsOSOLq17QRU.jpg'),
(165526, 11743, 'Meu Duble [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502404.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p2G2Q5vIrYTZog3Y0TXTgQjHc2h.jpg'),
(165527, 11743, 'Meu Duble [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502405.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5EASnETv8tjO6bmhutgqwr5Z7i6.jpg'),
(165528, 11743, 'Meu Duble [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502406.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kHVuhB5ptCmZyScIFI6ouvHUac3.jpg'),
(165529, 11743, 'Meu Duble [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502407.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8XyYcmMCwZae9NVIg7ZvFpeC8Xf.jpg'),
(165530, 11743, 'Meu Duble [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502408.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6H3zpB6MegBNK0z9rvA9vso5JJM.jpg'),
(165531, 11743, 'Meu Duble [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502409.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6HWloFB5dLlVLQKLFq9TjMIfbIa.jpg'),
(165532, 11743, 'Meu Duble [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502410.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3LOXJxBWq7N0NpNpyDnMhmyLqiF.jpg'),
(165533, 11743, 'Meu Duble [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502411.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c64ROCgLdXUJ9HBjLfsIaqUSwzh.jpg'),
(165534, 11743, 'Meu Duble [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502412.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1gQKo2PfjdmKKhSMPxFCq5ne2yb.jpg'),
(165535, 11743, 'Meu Duble [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502413.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9UOjmIqL6DqlyrLwc0lQh6mCaga.jpg'),
(165536, 11743, 'Meu Duble [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502414.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rKQ17UOU05y9a6SAjG44vBPT1OW.jpg'),
(165537, 11743, 'Meu Duble [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/502415.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/906ExgNPU1AD2bBG5XyiNUmI4Bb.jpg'),
(165538, 11743, 'Meu Duble [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/502416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHp4smGKQ5pNuLhsOSOLq17QRU.jpg'),
(165539, 11743, 'Meu Duble [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/502417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHp4smGKQ5pNuLhsOSOLq17QRU.jpg'),
(165540, 11743, 'Meu Duble [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/502418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UHp4smGKQ5pNuLhsOSOLq17QRU.jpg'),
(165541, 11744, 'Murder in a Small Town [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502388.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6ewAJMBxsrZyYRmvYlYhAbtLxoi.jpg'),
(165542, 11744, 'Murder in a Small Town [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502389.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/52dHm3leNCRL9r4HsxPMQxcuqje.jpg'),
(165543, 11744, 'Murder in a Small Town [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502390.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pTcnk62shesqDMzS5mhgJ4Kf1ef.jpg'),
(165544, 11744, 'Murder in a Small Town [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502391.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fuSJ2Sirfi6AHRy48x1C66oEz0U.jpg'),
(165545, 11744, 'Murder in a Small Town [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502392.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lzionk9JB6Sln6S4nH3yaAqJXFF.jpg'),
(165546, 11744, 'Murder in a Small Town [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/887522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8rdmK4vSIhNDQAtbamEFL2kLhG.jpg'),
(165547, 11744, 'Murder in a Small Town [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/887523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8rdmK4vSIhNDQAtbamEFL2kLhG.jpg'),
(165548, 11744, 'Murder in a Small Town [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/887524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8rdmK4vSIhNDQAtbamEFL2kLhG.jpg'),
(165549, 11745, 'Murder in a Small Town [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/887264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8rdmK4vSIhNDQAtbamEFL2kLhG.jpg'),
(165550, 11745, 'Murder in a Small Town [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/887702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8rdmK4vSIhNDQAtbamEFL2kLhG.jpg'),
(165551, 11745, 'Murder in a Small Town [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/888096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8rdmK4vSIhNDQAtbamEFL2kLhG.jpg'),
(165552, 11745, 'Murder in a Small Town [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/892169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8rdmK4vSIhNDQAtbamEFL2kLhG.jpg'),
(165553, 11745, 'Murder in a Small Town [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/889990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8rdmK4vSIhNDQAtbamEFL2kLhG.jpg'),
(165554, 11745, 'Murder in a Small Town [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/892170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8rdmK4vSIhNDQAtbamEFL2kLhG.jpg'),
(165555, 11745, 'Murder in a Small Town [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/893035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8rdmK4vSIhNDQAtbamEFL2kLhG.jpg'),
(165556, 11745, 'Murder in a Small Town [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/893297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8rdmK4vSIhNDQAtbamEFL2kLhG.jpg'),
(165557, 11745, 'Murder in a Small Town [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/894808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8rdmK4vSIhNDQAtbamEFL2kLhG.jpg'),
(165558, 11745, 'Murder in a Small Town [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/894809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r8rdmK4vSIhNDQAtbamEFL2kLhG.jpg'),
(165559, 11746, 'NCIS Origins [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502386.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sBN4q2WB6pGQqACV2EEomc99S2c.jpg'),
(165560, 11746, 'NCIS Origins [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502387.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5S5laeKux8px3LLxcfgko8fhlmI.jpg'),
(165561, 11746, 'NCIS Origins [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/511525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ft0mhNUC6ck8jnDJfSlltaGXMvf.jpg'),
(165562, 11746, 'NCIS Origins [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/511526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ft0mhNUC6ck8jnDJfSlltaGXMvf.jpg'),
(165563, 11746, 'NCIS Origins [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/517819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ft0mhNUC6ck8jnDJfSlltaGXMvf.jpg'),
(165564, 11746, 'NCIS Origins [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/517820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ft0mhNUC6ck8jnDJfSlltaGXMvf.jpg'),
(165565, 11746, 'NCIS Origins [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/520148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ft0mhNUC6ck8jnDJfSlltaGXMvf.jpg'),
(165566, 11746, 'NCIS Origins [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/636980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ft0mhNUC6ck8jnDJfSlltaGXMvf.jpg'),
(165567, 11746, 'NCIS Origins [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/656641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ft0mhNUC6ck8jnDJfSlltaGXMvf.jpg'),
(165568, 11746, 'NCIS Origins [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/656642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ft0mhNUC6ck8jnDJfSlltaGXMvf.jpg'),
(165569, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502354.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mhzumGxgRWN7IocxUxV8jDBgFHf.jpg'),
(165570, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502355.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ySchHRTC7Fuu800tZ35wjuvafPG.jpg'),
(165571, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502356.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fPDUPoIBKxHEUSq2AdJ10JS1Gd.jpg'),
(165572, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502357.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j9M89qBP8yDXkzGmPqX9kO6nQhA.jpg'),
(165573, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502358.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yiHLZaEBUfehqjwHcEBezvyNFW8.jpg'),
(165574, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502359.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wxIXHDmm3ZDfyYTsqsHaOXNqy2a.jpg'),
(165575, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502360.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s2haQrIem43g9MbLGLdCvnlg11j.jpg'),
(165576, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502361.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iaHY7II9CTyq4qP0BzZCaSVTtei.jpg'),
(165577, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502362.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1VmCa0637rCubxx8hiwDd7qfHPc.jpg'),
(165578, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502363.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/slYZCH36BMhhWk53ANiujBhl33b.jpg'),
(165579, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502364.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x3rTkqju5rTQB6UqzHojD4LCRSF.jpg'),
(165580, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/502365.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uxvIL21Sh3AI6b2M5Jv2zTlDE4E.jpg'),
(165581, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/502366.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r4ec5zH88HfNo11pXQ4YwNxgZwe.jpg'),
(165582, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/502367.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yG8qXKWGHfXG8Fg6Q2sRbrXOTnP.jpg'),
(165583, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/502368.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5ufChuTAQqRMAhuGBPpJKmVn6mp.jpg'),
(165584, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/502369.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7RjRkOrHM11dZOJHE4A2DI4iV7X.jpg'),
(165585, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/502370.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lSdvTazzTCRXr6cNsCnuVcrTJGy.jpg'),
(165586, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/502371.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Ail5NkJHMtfjDwNTa9Z7mM5OarS.jpg'),
(165587, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/502372.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ieXFCWfWhzsKHRJjLp3h043CAQY.jpg'),
(165588, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/502373.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v2edOL9qh9i9mrYpzBThUaUrqHM.jpg'),
(165589, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/502374.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w66ULDgO9GdoOeYKrOlC7ZkfbuU.jpg'),
(165590, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/502375.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j6zD7srn7Q8p8i5uAD8U15N563M.jpg'),
(165591, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/502376.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sz6GlcfatZTVfjquwMomttrkSD5.jpg'),
(165592, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/502377.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gAGpq4M3X0ejskgiRg7rZaLauib.jpg'),
(165593, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/502378.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sll4TCzOWhRSu3IpGfxGxEzR5yT.jpg'),
(165594, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/502379.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3ji5DY5Ud6b6TUUbBBnKeeq6AcR.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(165595, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/502380.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ccHD2HuTGNZQEoemA8sr73Z9aRt.jpg'),
(165596, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/502381.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2fU0dDSXamZcndNe8sd7FayoVhH.jpg'),
(165597, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/502382.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vbBwTKhMbZkJ443qDZXyAcVdvzQ.jpg'),
(165598, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/502383.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zGDGkO4WlUJdPwilORUQJJu0mJ.jpg'),
(165599, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/502384.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/80epiJJiP37w9sbDUKcI2kg5Rj7.jpg'),
(165600, 11747, 'O Rei das Lagrimas Lee Bang Won [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/502385.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rfu66lyJIy93EsT914No1c9nDvX.jpg'),
(165601, 11748, 'Pit Babe [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502341.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ufLvtCP17UAKzxlBXkkHNquF1M1.jpg'),
(165602, 11748, 'Pit Babe [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502342.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fShzqOkAR08ph9cQSKoMS68sVdI.jpg'),
(165603, 11748, 'Pit Babe [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502343.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2HjCrUxrfyRVpIXgYrCc03OlocN.jpg'),
(165604, 11748, 'Pit Babe [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502344.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eLM8RkUFsj7Ik7WqQQTF1QKrhR3.jpg'),
(165605, 11748, 'Pit Babe [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502345.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4CNQbTRIIBQlbCZhGJOixHsGHGW.jpg'),
(165606, 11748, 'Pit Babe [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502346.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pwmZA1JtNQS388PAPsBt9EpBdXi.jpg'),
(165607, 11748, 'Pit Babe [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502347.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mKXAt2Ym87wT3D48KgOqzkGk16D.jpg'),
(165608, 11748, 'Pit Babe [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502348.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Aw0UGxM51L0nJx26DTKQ3MJHFEB.jpg'),
(165609, 11748, 'Pit Babe [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502349.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bbE7CTGXWx6jou6zUrrcPyIodR6.jpg'),
(165610, 11748, 'Pit Babe [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502350.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4dQqegvBZoGprbvQJVfDFvULBic.jpg'),
(165611, 11748, 'Pit Babe [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502351.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5bhD2P0QiMxjQELf7Yg84VHml2O.jpg'),
(165612, 11748, 'Pit Babe [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/502352.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/exRYDdOYtIJGkoyimjGYPqPHNuY.jpg'),
(165613, 11748, 'Pit Babe [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/502353.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y07ye9beoVSl82YCzhXsZxr9y0K.jpg'),
(165614, 11749, 'Seja Seu Cavaleiro [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165615, 11749, 'Seja Seu Cavaleiro [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165616, 11749, 'Seja Seu Cavaleiro [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165617, 11749, 'Seja Seu Cavaleiro [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165618, 11749, 'Seja Seu Cavaleiro [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165619, 11749, 'Seja Seu Cavaleiro [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165620, 11749, 'Seja Seu Cavaleiro [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/511192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165621, 11749, 'Seja Seu Cavaleiro [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/511193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165622, 11749, 'Seja Seu Cavaleiro [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/511194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165623, 11749, 'Seja Seu Cavaleiro [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/511195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165624, 11749, 'Seja Seu Cavaleiro [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/511196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165625, 11749, 'Seja Seu Cavaleiro [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/511197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165626, 11749, 'Seja Seu Cavaleiro [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/511198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165627, 11749, 'Seja Seu Cavaleiro [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/511199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165628, 11749, 'Seja Seu Cavaleiro [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/511200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165629, 11749, 'Seja Seu Cavaleiro [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/511201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165630, 11749, 'Seja Seu Cavaleiro [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/511202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165631, 11749, 'Seja Seu Cavaleiro [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/511203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165632, 11749, 'Seja Seu Cavaleiro [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/511204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165633, 11749, 'Seja Seu Cavaleiro [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/511205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165634, 11749, 'Seja Seu Cavaleiro [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/511206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165635, 11749, 'Seja Seu Cavaleiro [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/511207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165636, 11749, 'Seja Seu Cavaleiro [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/511208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165637, 11749, 'Seja Seu Cavaleiro [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/511209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165638, 11749, 'Seja Seu Cavaleiro [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/511210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165639, 11749, 'Seja Seu Cavaleiro [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/511211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165640, 11749, 'Seja Seu Cavaleiro [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/511212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165641, 11749, 'Seja Seu Cavaleiro [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/511213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165642, 11749, 'Seja Seu Cavaleiro [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/511214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxjI00OcRVqvNCPgE9MYVE1QvuQ.jpg'),
(165643, 11750, 'So Acontece na Florida [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502332.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dTcvWiUHKxOZ9EQnmIllAXy9C97.jpg'),
(165644, 11750, 'So Acontece na Florida [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502333.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uVVhP4fQPPgD1J0zUsrm9V3hI1r.jpg'),
(165645, 11750, 'So Acontece na Florida [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502334.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/se0r4qnDf6QvOPh7vG5XHqzThxD.jpg'),
(165646, 11750, 'So Acontece na Florida [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/511146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zSw9DKCLh4KHhgwcggViWfGneZD.jpg'),
(165647, 11750, 'So Acontece na Florida [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/511147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zSw9DKCLh4KHhgwcggViWfGneZD.jpg'),
(165648, 11750, 'So Acontece na Florida [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/511148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zSw9DKCLh4KHhgwcggViWfGneZD.jpg'),
(165649, 11751, 'So Acontece na Florida [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/893514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zSw9DKCLh4KHhgwcggViWfGneZD.jpg'),
(165650, 11751, 'So Acontece na Florida [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/894799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zSw9DKCLh4KHhgwcggViWfGneZD.jpg'),
(165651, 11751, 'So Acontece na Florida [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/895785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zSw9DKCLh4KHhgwcggViWfGneZD.jpg'),
(165652, 11751, 'So Acontece na Florida [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/896890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zSw9DKCLh4KHhgwcggViWfGneZD.jpg'),
(165653, 11751, 'So Acontece na Florida [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/897361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zSw9DKCLh4KHhgwcggViWfGneZD.jpg'),
(165654, 11752, 'Sweetpea [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502329.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jgnvUK6f9FJ76517VoUMDuk9Mc7.jpg'),
(165655, 11752, 'Sweetpea [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502330.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cOKss9nV0wsFV2kMr8fTsKM7Ftu.jpg'),
(165656, 11752, 'Sweetpea [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502331.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dkpMWTlXtm5Inx45HCfdJ0Ewc9r.jpg'),
(165657, 11753, 'Um Arremesso Overtime Elite [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502317.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8PRacf3NJLBemLXej6luamS2MrX.jpg'),
(165658, 11753, 'Um Arremesso Overtime Elite [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502318.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9I4oCeHs2YQioqYdycQ1PTMX2VY.jpg'),
(165659, 11753, 'Um Arremesso Overtime Elite [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502319.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h2NYTqwTieM9OCLDNy6FWBb3Y2v.jpg'),
(165660, 11753, 'Um Arremesso Overtime Elite [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502320.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eApxSm7IEt2fV0oSJnGUedOIcjc.jpg'),
(165661, 11753, 'Um Arremesso Overtime Elite [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502321.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/etNCAG1NE9H7AXNYNj1jaE9IBPc.jpg'),
(165662, 11753, 'Um Arremesso Overtime Elite [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502322.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yxwAsm0wqx0AnIQOOZKgAWuuKbA.jpg'),
(165663, 11754, 'Um Arremesso Overtime Elite [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7MYRaasZEkTSPszjcSR16KEzF7O.jpg'),
(165664, 11754, 'Um Arremesso Overtime Elite [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7MYRaasZEkTSPszjcSR16KEzF7O.jpg'),
(165665, 11754, 'Um Arremesso Overtime Elite [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7MYRaasZEkTSPszjcSR16KEzF7O.jpg'),
(165666, 11754, 'Um Arremesso Overtime Elite [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7MYRaasZEkTSPszjcSR16KEzF7O.jpg'),
(165667, 11754, 'Um Arremesso Overtime Elite [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7MYRaasZEkTSPszjcSR16KEzF7O.jpg'),
(165668, 11754, 'Um Arremesso Overtime Elite [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7MYRaasZEkTSPszjcSR16KEzF7O.jpg'),
(165669, 11755, 'Wingman [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502315.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iiWyUotncl3wgbc1Pic3YicFjZM.jpg'),
(165670, 11755, 'Wingman [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502316.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y2Rp53PCizubAp6bapJxKsx8YIq.jpg'),
(165671, 11755, 'Wingman [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/512732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bbiFE2zLW6H390Jf6lzend7Ffb1.jpg'),
(165672, 11755, 'Wingman [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/512733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bbiFE2zLW6H390Jf6lzend7Ffb1.jpg'),
(165673, 11755, 'Wingman [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/512734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bbiFE2zLW6H390Jf6lzend7Ffb1.jpg'),
(165674, 11755, 'Wingman [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/516737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bbiFE2zLW6H390Jf6lzend7Ffb1.jpg'),
(165675, 11755, 'Wingman [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bbiFE2zLW6H390Jf6lzend7Ffb1.jpg'),
(165676, 11755, 'Wingman [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bbiFE2zLW6H390Jf6lzend7Ffb1.jpg'),
(165677, 11755, 'Wingman [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/639761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bbiFE2zLW6H390Jf6lzend7Ffb1.jpg'),
(165678, 11755, 'Wingman [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/639762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bbiFE2zLW6H390Jf6lzend7Ffb1.jpg'),
(165679, 11756, 'Uma Pitada de Magia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502259.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jm9IlucUs4N2xpTj3rCGrtuY9jv.jpg'),
(165680, 11756, 'Uma Pitada de Magia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502260.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cBZFZpURyv98vaGhgXsHQdrepOh.jpg'),
(165681, 11756, 'Uma Pitada de Magia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502261.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8jc7iCSlFUXjQjVL4zMOVf4pnGI.jpg'),
(165682, 11756, 'Uma Pitada de Magia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502262.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kRo5PKO3X37OAq2Ha2nv12MgwFz.jpg'),
(165683, 11756, 'Uma Pitada de Magia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502263.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4qw4fbwU5q6ojWtYpPuQyMzbpj6.jpg'),
(165684, 11756, 'Uma Pitada de Magia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502264.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1h8OWsMOXHJa86OKmXkqvJiVjaV.jpg'),
(165685, 11756, 'Uma Pitada de Magia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502265.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/37VNuZH1uT2IF0GaeKz5Pyb9iyw.jpg'),
(165686, 11756, 'Uma Pitada de Magia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502266.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6jjoAQNiitiK8xibN2rTVBbjPLU.jpg'),
(165687, 11756, 'Uma Pitada de Magia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502267.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dbAFtQjhVOZsNd0xFHYfLMwYhy4.jpg'),
(165688, 11756, 'Uma Pitada de Magia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502268.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/is0BFbjKB39dEHuq5Rh3IbYIS8C.jpg'),
(165689, 11756, 'Uma Pitada de Magia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502269.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fjGOj7tIUK52O7O5Q8COwdQgYhC.jpg'),
(165690, 11756, 'Uma Pitada de Magia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/502270.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ghLK0og5mS6sjOo80IaLWw2hdTl.jpg'),
(165691, 11756, 'Uma Pitada de Magia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/502271.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a5M1Kx40AZZq0AJxscakCFDilT5.jpg'),
(165692, 11757, 'Uma Pitada de Magia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502272.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8LuaOxsBeAM8LYqFPSIuXOk8kkd.jpg'),
(165693, 11757, 'Uma Pitada de Magia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502273.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yRTydJ0eQmF5IlD1sRH1G0pC8wp.jpg'),
(165694, 11757, 'Uma Pitada de Magia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502274.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8x2KYAMTA01mJgwbwckAAcLLiHp.jpg'),
(165695, 11757, 'Uma Pitada de Magia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502275.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gaeeCJwKHBsdbrtl5GXBUcJEvIS.jpg'),
(165696, 11757, 'Uma Pitada de Magia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502276.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eBeukJ1EjF6HNV7iy0pfKEYoQcF.jpg'),
(165697, 11757, 'Uma Pitada de Magia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502277.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rmoGzgaXL6DjeRPLrPMK7WAHOzC.jpg'),
(165698, 11757, 'Uma Pitada de Magia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502278.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xGY8Cwhhvg4V6qOtJhQ4b9I1I3Q.jpg'),
(165699, 11757, 'Uma Pitada de Magia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502279.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bMDNL0fzyXofhTSOjGnSd5ihcjm.jpg'),
(165700, 11757, 'Uma Pitada de Magia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502280.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xXab322OgNNZv7xs1k9H9D9QJal.jpg'),
(165701, 11757, 'Uma Pitada de Magia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502281.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d6gyWE7WrqQLrtxRQgxsSoOZvMz.jpg'),
(165702, 11757, 'Uma Pitada de Magia S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502282.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jmQKFsSUS1Xxe7DurbOJQBoJBMH.jpg'),
(165703, 11757, 'Uma Pitada de Magia S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/502283.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bRKpEJLjlngt0BukdEoXPRtGdbW.jpg'),
(165704, 11757, 'Uma Pitada de Magia S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/502284.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fcVwT3lPuILETcdcXaX6HwGXNON.jpg'),
(165705, 11757, 'Uma Pitada de Magia S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/502285.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oRNkucXLHeQberqp0NfTTr1TyE3.jpg'),
(165706, 11757, 'Uma Pitada de Magia S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/502286.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oouwlBSNtSt6mvR53GS33jrewJc.jpg'),
(165707, 11757, 'Uma Pitada de Magia S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/502287.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q4RGnunOZDZ3D0kx1VfPQj6kakt.jpg'),
(165708, 11757, 'Uma Pitada de Magia S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/502288.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8vMckuZNrkmlzrUbjdZiBt9AQxe.jpg'),
(165709, 11757, 'Uma Pitada de Magia S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/502289.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zQYbpEIrpjLDXIZModiZyZPPVUI.jpg'),
(165710, 11757, 'Uma Pitada de Magia S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/502290.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5h8JUEH5HmVWD98WPy5xu3vmhKk.jpg'),
(165711, 11757, 'Uma Pitada de Magia S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/502291.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/woxVx87UCEzBf1W1ZrVBMtlF62c.jpg'),
(165712, 11757, 'Uma Pitada de Magia S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/502292.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kBKA2ZM32i8As5eTS1MQpPwC932.jpg'),
(165713, 11757, 'Uma Pitada de Magia S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/502293.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nhbmWdYDegZblpHCSZVFrvYD33m.jpg'),
(165714, 11757, 'Uma Pitada de Magia S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/502294.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gfvo09VisdbiFwvwSrptyfEj5tG.jpg'),
(165715, 11757, 'Uma Pitada de Magia S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/502295.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bcw07BeyVtvra8TAh3lGuBreVDU.jpg'),
(165716, 11757, 'Uma Pitada de Magia S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/502296.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vy5aEBFusdDH3IYPWmkJPn2Q2az.jpg'),
(165717, 11757, 'Uma Pitada de Magia S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/502297.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u2OLFsH101JPjfqTI5woYC0JSQ2.jpg'),
(165718, 11758, 'Uma Pitada de Magia S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502298.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mk5lMUwWbOPraWZQjDckPknXVVq.jpg'),
(165719, 11758, 'Uma Pitada de Magia S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502299.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tmH9Qr1VUBq4uJhi4kgPIPwYeBD.jpg'),
(165720, 11758, 'Uma Pitada de Magia S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502300.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9DUr0lGHpN1uiAIMRLjH5nm3zvV.jpg'),
(165721, 11758, 'Uma Pitada de Magia S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502301.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6z103129PkpeUP9M3mDDmpNF630.jpg'),
(165722, 11758, 'Uma Pitada de Magia S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502302.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/juz0u82wr8CH0pcfgKUodpPl4Y7.jpg'),
(165723, 11758, 'Uma Pitada de Magia S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502303.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eJTCmAACM1RbIVM7vrykdaZWiUQ.jpg'),
(165724, 11758, 'Uma Pitada de Magia S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502304.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/234V5c4oZ2RZrkeHHEsZCD9JOZU.jpg'),
(165725, 11758, 'Uma Pitada de Magia S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502305.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7vx1mj6Qime7aQol5QqLE63on2Q.jpg'),
(165726, 11758, 'Uma Pitada de Magia S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502306.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sFcjVQLl2zjrzO3kSXfWPaO3Q9g.jpg'),
(165727, 11758, 'Uma Pitada de Magia S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502307.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ssHdZDTKnIxnSHj2saT9PJ3rx4M.jpg'),
(165728, 11758, 'Uma Pitada de Magia S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502308.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/etH9AzlWXZIb80XZXW6VVXXpdFL.jpg'),
(165729, 11758, 'Uma Pitada de Magia S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/502309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z1Y1R1ooMiJ2mmZCtOgOQYU6tqr.jpg'),
(165730, 11758, 'Uma Pitada de Magia S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/502310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z1Y1R1ooMiJ2mmZCtOgOQYU6tqr.jpg'),
(165731, 11759, 'Pinha e Pony S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502245.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tUyPe5NZ3M948CaDYMn6RSG5UaA.jpg'),
(165732, 11759, 'Pinha e Pony S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502246.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AkqAswx7gamwY9Ianm9LiC0nXR2.jpg'),
(165733, 11759, 'Pinha e Pony S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502247.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/UGyDhxq9FrPUWraOq8lX7UqKAg.jpg'),
(165734, 11759, 'Pinha e Pony S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502248.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tXVe9ewVXSPmk2sW7EWxph6DGB7.jpg'),
(165735, 11759, 'Pinha e Pony S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502249.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t1yrSMs0z6Ag5N7jJSF0xSTRAiI.jpg'),
(165736, 11759, 'Pinha e Pony S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502250.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i1HHOoT6Xr8f9iwOcqQeOKkGrxH.jpg'),
(165737, 11760, 'Pinha e Pony S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502251.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5RGyFcO6dmYevaLXIp7Cj5AEPlb.jpg'),
(165738, 11760, 'Pinha e Pony S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502252.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oY3t5rWwyHKe8aDLHW0Fr2Qra1d.jpg'),
(165739, 11760, 'Pinha e Pony S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502253.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yqQManiPaGgXs1cKpK9hPe3E2N5.jpg'),
(165740, 11760, 'Pinha e Pony S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502254.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uBZWVt77GbggL61sAWPwFqisqXp.jpg'),
(165741, 11760, 'Pinha e Pony S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502255.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yn7KJQlHAYuXeWrOuKquU2Tcmwb.jpg'),
(165742, 11760, 'Pinha e Pony S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502256.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/htzkmxO7MGYA1aIoohZ9dhJ9RbH.jpg'),
(165743, 11760, 'Pinha e Pony S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502257.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vUc4wlaXAos8VDyAv4Uuan7czUT.jpg'),
(165744, 11760, 'Pinha e Pony S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502258.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aqGVo9To0IDL2dMDX63UFy3VzTn.jpg'),
(165745, 11761, 'As Maes dos Pinguins S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502239.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nA3R1zVBzhRLpyhiDDJmb59jaS0.jpg'),
(165746, 11761, 'As Maes dos Pinguins S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502240.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fr8ik1nY1tI3bFyTmZBTXfVqQ3v.jpg'),
(165747, 11761, 'As Maes dos Pinguins S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502241.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/txH9eRnrOaXf4vi17OOSyzLUm7e.jpg'),
(165748, 11761, 'As Maes dos Pinguins S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502242.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rZznQASWd2m1Jt18t2M9vl0nrNT.jpg'),
(165749, 11761, 'As Maes dos Pinguins S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502243.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bv1Q7n9bjTFrUmZCkD3KKpLCtS6.jpg'),
(165750, 11761, 'As Maes dos Pinguins S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502244.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cupGXOJNELdyHZ03WZ7epnLQSjd.jpg'),
(165751, 11762, 'O Retorno de Simone Biles S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502235.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l1S12g1Vdu1pXuKUCOkEzWE7Vlj.jpg'),
(165752, 11762, 'O Retorno de Simone Biles S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502236.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oY05XzBaTeujUwnxs5c3yL3zRfb.jpg'),
(165753, 11762, 'O Retorno de Simone Biles S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502237.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1RW4TIiHZv60BiAL27stJRa6qVH.jpg'),
(165754, 11762, 'O Retorno de Simone Biles S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502238.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ccRVle4BBI8cP4AlWpgYZuX1nuu.jpg'),
(165755, 11763, 'A Sonhadora S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/503794.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ups5BsT9bQpbrwzVgGxX9LUcsOH.jpg'),
(165756, 11763, 'A Sonhadora S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/503795.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/idsIg5S0gpEkUFNc86oFfil5oeQ.jpg'),
(165757, 11763, 'A Sonhadora S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/503796.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/duR1mo8OTkZ7pj5SjICcdORCeV2.jpg'),
(165758, 11763, 'A Sonhadora S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/503797.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z8RC0kgU7UVHd6w2j8paUI3Mwkk.jpg'),
(165759, 11763, 'A Sonhadora S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/503798.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j2wabqhYh0DEDCyTblmJHRFp9dE.jpg'),
(165760, 11763, 'A Sonhadora S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/503799.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aGA4DVLaUFK1CqUz78QK9LPHiR7.jpg'),
(165761, 11763, 'A Sonhadora S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/503800.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uEzNnz2vMl71RmZjLKiSoFyPUMT.jpg'),
(165762, 11763, 'A Sonhadora S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/503801.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8MFdo3x9Sy0pdEa1fLRTNDVm1jN.jpg'),
(165763, 11763, 'A Sonhadora S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/503802.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3FLEDn85a0ywCXNZ4Z2VRjzUdFN.jpg'),
(165764, 11763, 'A Sonhadora S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/503803.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aC3Y61enUU5fhWGxyiJFuQsNBl6.jpg'),
(165765, 11763, 'A Sonhadora S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/503804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165766, 11763, 'A Sonhadora S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/503805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165767, 11763, 'A Sonhadora S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/503806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165768, 11763, 'A Sonhadora S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/503807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165769, 11763, 'A Sonhadora S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/503808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165770, 11763, 'A Sonhadora S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/503809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165771, 11763, 'A Sonhadora S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/503810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165772, 11763, 'A Sonhadora S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/503811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165773, 11763, 'A Sonhadora S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/503812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165774, 11763, 'A Sonhadora S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/503813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165775, 11763, 'A Sonhadora S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/503814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165776, 11763, 'A Sonhadora S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/503815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165777, 11763, 'A Sonhadora S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/503816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165778, 11763, 'A Sonhadora S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/503817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165779, 11763, 'A Sonhadora S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/503818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165780, 11763, 'A Sonhadora S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/503819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165781, 11763, 'A Sonhadora S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/503820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165782, 11763, 'A Sonhadora S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/503821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165783, 11763, 'A Sonhadora S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/503822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165784, 11763, 'A Sonhadora S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/503823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165785, 11763, 'A Sonhadora S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/503824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165786, 11763, 'A Sonhadora S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/503825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165787, 11763, 'A Sonhadora S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/503826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165788, 11763, 'A Sonhadora S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/503827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165789, 11763, 'A Sonhadora S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/503828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165790, 11763, 'A Sonhadora S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/503829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165791, 11763, 'A Sonhadora S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/503830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165792, 11763, 'A Sonhadora S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/503831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165793, 11763, 'A Sonhadora S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/503832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165794, 11763, 'A Sonhadora S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/503833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165795, 11763, 'A Sonhadora S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/503834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165796, 11763, 'A Sonhadora S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/503835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165797, 11763, 'A Sonhadora S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/503836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165798, 11763, 'A Sonhadora S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/503837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165799, 11763, 'A Sonhadora S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/503838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165800, 11763, 'A Sonhadora S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/503839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165801, 11763, 'A Sonhadora S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/503840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165802, 11763, 'A Sonhadora S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/503841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165803, 11763, 'A Sonhadora S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/503842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165804, 11763, 'A Sonhadora S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/503843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165805, 11763, 'A Sonhadora S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/503844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165806, 11763, 'A Sonhadora S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/503845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165807, 11763, 'A Sonhadora S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/503846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165808, 11763, 'A Sonhadora S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/503847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165809, 11763, 'A Sonhadora S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/503848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165810, 11763, 'A Sonhadora S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/503849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165811, 11763, 'A Sonhadora S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/503850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165812, 11763, 'A Sonhadora S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/503851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165813, 11763, 'A Sonhadora S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/503852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165814, 11763, 'A Sonhadora S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/503853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165815, 11763, 'A Sonhadora S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/503854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165816, 11763, 'A Sonhadora S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/503855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165817, 11763, 'A Sonhadora S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/503856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165818, 11763, 'A Sonhadora S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/503857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165819, 11763, 'A Sonhadora S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/503858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165820, 11763, 'A Sonhadora S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/503859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165821, 11763, 'A Sonhadora S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/503860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165822, 11763, 'A Sonhadora S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/503861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165823, 11763, 'A Sonhadora S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/503862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165824, 11763, 'A Sonhadora S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/503863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165825, 11763, 'A Sonhadora S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/503864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165826, 11763, 'A Sonhadora S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/503865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165827, 11763, 'A Sonhadora S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/503866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165828, 11763, 'A Sonhadora S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/503867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165829, 11763, 'A Sonhadora S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/503868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165830, 11763, 'A Sonhadora S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/510286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165831, 11763, 'A Sonhadora S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/510287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165832, 11763, 'A Sonhadora S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/510288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165833, 11763, 'A Sonhadora S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/510289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165834, 11763, 'A Sonhadora S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/510290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165835, 11763, 'A Sonhadora S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/510291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165836, 11763, 'A Sonhadora S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/510292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165837, 11763, 'A Sonhadora S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/510293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165838, 11763, 'A Sonhadora S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/510294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165839, 11763, 'A Sonhadora S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/510295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165840, 11763, 'A Sonhadora S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/510296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165841, 11763, 'A Sonhadora S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/510297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165842, 11763, 'A Sonhadora S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/510298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165843, 11763, 'A Sonhadora S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/510299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165844, 11763, 'A Sonhadora S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/510300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165845, 11763, 'A Sonhadora S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/510301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165846, 11763, 'A Sonhadora S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/510302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165847, 11763, 'A Sonhadora S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/510303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165848, 11763, 'A Sonhadora S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/510304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165849, 11763, 'A Sonhadora S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/510305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165850, 11763, 'A Sonhadora S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/510306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165851, 11763, 'A Sonhadora S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/510307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165852, 11763, 'A Sonhadora S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/510308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165853, 11763, 'A Sonhadora S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/510309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(165854, 11763, 'A Sonhadora S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/510310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165855, 11763, 'A Sonhadora S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/520553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165856, 11763, 'A Sonhadora S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/520554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165857, 11763, 'A Sonhadora S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/520555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165858, 11763, 'A Sonhadora S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/520556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165859, 11763, 'A Sonhadora S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/520557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165860, 11763, 'A Sonhadora S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/520558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165861, 11763, 'A Sonhadora S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/520559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165862, 11763, 'A Sonhadora S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/520560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165863, 11763, 'A Sonhadora S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/520561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165864, 11763, 'A Sonhadora S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/520562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165865, 11763, 'A Sonhadora S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/520563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165866, 11763, 'A Sonhadora S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/520564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165867, 11763, 'A Sonhadora S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/520565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165868, 11763, 'A Sonhadora S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/520566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165869, 11763, 'A Sonhadora S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/520567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165870, 11763, 'A Sonhadora S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/520568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165871, 11763, 'A Sonhadora S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/520569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165872, 11763, 'A Sonhadora S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/520570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165873, 11763, 'A Sonhadora S01 E119', 'http://sinalprivado.info:80/series/1533784/1533784/520571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165874, 11763, 'A Sonhadora S01 E120', 'http://sinalprivado.info:80/series/1533784/1533784/520572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165875, 11763, 'A Sonhadora S01 E121', 'http://sinalprivado.info:80/series/1533784/1533784/520573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165876, 11763, 'A Sonhadora S01 E122', 'http://sinalprivado.info:80/series/1533784/1533784/520574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165877, 11763, 'A Sonhadora S01 E123', 'http://sinalprivado.info:80/series/1533784/1533784/520575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165878, 11763, 'A Sonhadora S01 E124', 'http://sinalprivado.info:80/series/1533784/1533784/520576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165879, 11763, 'A Sonhadora S01 E125', 'http://sinalprivado.info:80/series/1533784/1533784/520577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165880, 11763, 'A Sonhadora S01 E126', 'http://sinalprivado.info:80/series/1533784/1533784/520578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165881, 11763, 'A Sonhadora S01 E127', 'http://sinalprivado.info:80/series/1533784/1533784/520579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165882, 11763, 'A Sonhadora S01 E128', 'http://sinalprivado.info:80/series/1533784/1533784/520580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165883, 11763, 'A Sonhadora S01 E129', 'http://sinalprivado.info:80/series/1533784/1533784/520581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165884, 11763, 'A Sonhadora S01 E130', 'http://sinalprivado.info:80/series/1533784/1533784/520582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165885, 11763, 'A Sonhadora S01 E131', 'http://sinalprivado.info:80/series/1533784/1533784/520583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165886, 11763, 'A Sonhadora S01 E132', 'http://sinalprivado.info:80/series/1533784/1533784/520584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165887, 11763, 'A Sonhadora S01 E133', 'http://sinalprivado.info:80/series/1533784/1533784/520585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165888, 11763, 'A Sonhadora S01 E134', 'http://sinalprivado.info:80/series/1533784/1533784/520586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165889, 11763, 'A Sonhadora S01 E135', 'http://sinalprivado.info:80/series/1533784/1533784/520587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165890, 11763, 'A Sonhadora S01 E136', 'http://sinalprivado.info:80/series/1533784/1533784/520588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165891, 11763, 'A Sonhadora S01 E137', 'http://sinalprivado.info:80/series/1533784/1533784/520589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165892, 11763, 'A Sonhadora S01 E138', 'http://sinalprivado.info:80/series/1533784/1533784/520590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165893, 11763, 'A Sonhadora S01 E139', 'http://sinalprivado.info:80/series/1533784/1533784/520591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165894, 11763, 'A Sonhadora S01 E140', 'http://sinalprivado.info:80/series/1533784/1533784/520592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165895, 11763, 'A Sonhadora S01 E141', 'http://sinalprivado.info:80/series/1533784/1533784/520593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165896, 11763, 'A Sonhadora S01 E142', 'http://sinalprivado.info:80/series/1533784/1533784/520594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165897, 11763, 'A Sonhadora S01 E143', 'http://sinalprivado.info:80/series/1533784/1533784/520595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165898, 11763, 'A Sonhadora S01 E144', 'http://sinalprivado.info:80/series/1533784/1533784/520596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165899, 11763, 'A Sonhadora S01 E145', 'http://sinalprivado.info:80/series/1533784/1533784/520597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165900, 11763, 'A Sonhadora S01 E146', 'http://sinalprivado.info:80/series/1533784/1533784/520598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165901, 11763, 'A Sonhadora S01 E147', 'http://sinalprivado.info:80/series/1533784/1533784/520599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165902, 11763, 'A Sonhadora S01 E148', 'http://sinalprivado.info:80/series/1533784/1533784/520600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165903, 11763, 'A Sonhadora S01 E149', 'http://sinalprivado.info:80/series/1533784/1533784/520601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165904, 11763, 'A Sonhadora S01 E150', 'http://sinalprivado.info:80/series/1533784/1533784/520602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165905, 11763, 'A Sonhadora S01 E151', 'http://sinalprivado.info:80/series/1533784/1533784/520603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165906, 11763, 'A Sonhadora S01 E152', 'http://sinalprivado.info:80/series/1533784/1533784/520604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165907, 11763, 'A Sonhadora S01 E153', 'http://sinalprivado.info:80/series/1533784/1533784/520605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165908, 11763, 'A Sonhadora S01 E154', 'http://sinalprivado.info:80/series/1533784/1533784/520606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165909, 11763, 'A Sonhadora S01 E155', 'http://sinalprivado.info:80/series/1533784/1533784/520607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165910, 11763, 'A Sonhadora S01 E156', 'http://sinalprivado.info:80/series/1533784/1533784/520608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165911, 11763, 'A Sonhadora S01 E157', 'http://sinalprivado.info:80/series/1533784/1533784/520609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165912, 11763, 'A Sonhadora S01 E158', 'http://sinalprivado.info:80/series/1533784/1533784/520610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165913, 11763, 'A Sonhadora S01 E159', 'http://sinalprivado.info:80/series/1533784/1533784/520611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165914, 11763, 'A Sonhadora S01 E160', 'http://sinalprivado.info:80/series/1533784/1533784/520612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165915, 11763, 'A Sonhadora S01 E161', 'http://sinalprivado.info:80/series/1533784/1533784/520613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/55FB9BaPbPokzOGZH1tQ8EQ0Mh9.jpg'),
(165916, 11764, 'Depois do Adeus S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1Gw1TBFzGnlfOmykaN1wSbWSGQy.jpg'),
(165917, 11764, 'Depois do Adeus S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1Gw1TBFzGnlfOmykaN1wSbWSGQy.jpg'),
(165918, 11764, 'Depois do Adeus S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1Gw1TBFzGnlfOmykaN1wSbWSGQy.jpg'),
(165919, 11764, 'Depois do Adeus S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1Gw1TBFzGnlfOmykaN1wSbWSGQy.jpg'),
(165920, 11764, 'Depois do Adeus S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1Gw1TBFzGnlfOmykaN1wSbWSGQy.jpg'),
(165921, 11764, 'Depois do Adeus S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1Gw1TBFzGnlfOmykaN1wSbWSGQy.jpg'),
(165922, 11764, 'Depois do Adeus S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1Gw1TBFzGnlfOmykaN1wSbWSGQy.jpg'),
(165923, 11764, 'Depois do Adeus S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1Gw1TBFzGnlfOmykaN1wSbWSGQy.jpg'),
(165924, 11765, 'Detetive Alex Cross S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oArnlWvky2KtWoGC0ChaDboEvcH.jpg'),
(165925, 11765, 'Detetive Alex Cross S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oArnlWvky2KtWoGC0ChaDboEvcH.jpg'),
(165926, 11765, 'Detetive Alex Cross S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oArnlWvky2KtWoGC0ChaDboEvcH.jpg'),
(165927, 11765, 'Detetive Alex Cross S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oArnlWvky2KtWoGC0ChaDboEvcH.jpg'),
(165928, 11765, 'Detetive Alex Cross S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oArnlWvky2KtWoGC0ChaDboEvcH.jpg'),
(165929, 11765, 'Detetive Alex Cross S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oArnlWvky2KtWoGC0ChaDboEvcH.jpg'),
(165930, 11765, 'Detetive Alex Cross S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oArnlWvky2KtWoGC0ChaDboEvcH.jpg'),
(165931, 11765, 'Detetive Alex Cross S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oArnlWvky2KtWoGC0ChaDboEvcH.jpg'),
(165932, 11766, 'Grotesquerie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502213.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mtIkvn4rnxwqKV95LiacSOKMDVu.jpg'),
(165933, 11766, 'Grotesquerie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502214.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xXaSWhG5lWudjITIQ2uZQg5HY1R.jpg'),
(165934, 11766, 'Grotesquerie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502215.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uTk28VwTCFP7H0RQjdPXHmM1g8b.jpg'),
(165935, 11766, 'Grotesquerie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502216.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s0KGgH5hxA9dX8RUf5BtDiNQdxS.jpg'),
(165936, 11766, 'Grotesquerie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502217.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dPA9WcDwxlZZvqntpza6MeJ30f9.jpg'),
(165937, 11766, 'Grotesquerie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502218.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dDMguU43euo7xGZllaoUEFJAYsg.jpg'),
(165938, 11766, 'Grotesquerie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/518029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ZjPu0cf7N57J97jmCcRLvwveUu.jpg'),
(165939, 11766, 'Grotesquerie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/518030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ZjPu0cf7N57J97jmCcRLvwveUu.jpg'),
(165940, 11766, 'Grotesquerie S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/518031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ZjPu0cf7N57J97jmCcRLvwveUu.jpg'),
(165941, 11766, 'Grotesquerie S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/518032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1ZjPu0cf7N57J97jmCcRLvwveUu.jpg'),
(165942, 11767, 'Os Padrinhos Magicos Um Novo Desejo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502203.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jghxaHaKI4aAk8oJH7zT7OqfS4a.jpg'),
(165943, 11767, 'Os Padrinhos Magicos Um Novo Desejo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502204.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ksbKClciEAHufXsa4eUh6o7DuHV.jpg'),
(165944, 11767, 'Os Padrinhos Magicos Um Novo Desejo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502205.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p4tW12mz2AVUVwPTSWteLZAZH8s.jpg'),
(165945, 11767, 'Os Padrinhos Magicos Um Novo Desejo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502206.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zABw0jaxCaWv8vSJw2MK9BRRVgI.jpg'),
(165946, 11767, 'Os Padrinhos Magicos Um Novo Desejo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502207.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qSIhohwtKKmA6HAuCQWuKaKEFBr.jpg'),
(165947, 11767, 'Os Padrinhos Magicos Um Novo Desejo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502208.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wIDXdtRHD9uRUgWeKltGoNFgGqk.jpg'),
(165948, 11767, 'Os Padrinhos Magicos Um Novo Desejo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502209.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jz8huh8aDTm8Dl7lTwG9sQ2WhCI.jpg'),
(165949, 11767, 'Os Padrinhos Magicos Um Novo Desejo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502210.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mDyRmR4XtvhGKuCMkta1Kzn3hKC.jpg'),
(165950, 11767, 'Os Padrinhos Magicos Um Novo Desejo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502211.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/maSEnPMHno6WJCTREOEcAHbGk2c.jpg'),
(165951, 11767, 'Os Padrinhos Magicos Um Novo Desejo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502212.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aUPm85x4wnutERyO6GOTms69LvG.jpg'),
(165952, 11768, 'Harry Potter Bruxos da Confeitaria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502202.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Uyuau9E8cBiYa9k1fAZrbWIBGE.jpg'),
(165953, 11768, 'Harry Potter Bruxos da Confeitaria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/511897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yHBttKi9pU9A1FdAKL1CMACBzIp.jpg'),
(165954, 11768, 'Harry Potter Bruxos da Confeitaria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/514460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yHBttKi9pU9A1FdAKL1CMACBzIp.jpg'),
(165955, 11768, 'Harry Potter Bruxos da Confeitaria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/518022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yHBttKi9pU9A1FdAKL1CMACBzIp.jpg'),
(165956, 11768, 'Harry Potter Bruxos da Confeitaria S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/523469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yHBttKi9pU9A1FdAKL1CMACBzIp.jpg'),
(165957, 11768, 'Harry Potter Bruxos da Confeitaria S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/639236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yHBttKi9pU9A1FdAKL1CMACBzIp.jpg'),
(165958, 11769, 'Harry Potter Bruxos da Confeitaria S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/891042.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yHBttKi9pU9A1FdAKL1CMACBzIp.jpg'),
(165959, 11769, 'Harry Potter Bruxos da Confeitaria S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/892211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yHBttKi9pU9A1FdAKL1CMACBzIp.jpg'),
(165960, 11769, 'Harry Potter Bruxos da Confeitaria S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/892654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yHBttKi9pU9A1FdAKL1CMACBzIp.jpg'),
(165961, 11769, 'Harry Potter Bruxos da Confeitaria S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/893361.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yHBttKi9pU9A1FdAKL1CMACBzIp.jpg'),
(165962, 11769, 'Harry Potter Bruxos da Confeitaria S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/893593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yHBttKi9pU9A1FdAKL1CMACBzIp.jpg'),
(165963, 11769, 'Harry Potter Bruxos da Confeitaria S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/894907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yHBttKi9pU9A1FdAKL1CMACBzIp.jpg'),
(165964, 11770, 'Nao Diga Nada S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502194.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uciX9G3xkIHZbeLNHkmTLjBmYBC.jpg'),
(165965, 11770, 'Nao Diga Nada S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502195.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2SUS6uJ7YhTyCIi4NXNYKD9KTmv.jpg'),
(165966, 11770, 'Nao Diga Nada S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502196.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cJr5VWwCqdGH16yYTuCch5x9cRD.jpg'),
(165967, 11770, 'Nao Diga Nada S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502197.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7qPN8lkrikMU5wutHsOfY5pdqz4.jpg'),
(165968, 11770, 'Nao Diga Nada S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502198.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8nSBspNM0hTeqAQGTyzBvuCtXhU.jpg'),
(165969, 11770, 'Nao Diga Nada S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502199.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xO1MJpWFvQ7R9fZfN6SuAJiAMZF.jpg'),
(165970, 11770, 'Nao Diga Nada S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502200.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yzHKVWuEnTXzBoMSaCyl2BHfGe8.jpg'),
(165971, 11770, 'Nao Diga Nada S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502201.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lOqxPRGGabW6WtUU2eiEA7RhTAF.jpg'),
(165972, 11770, 'Nao Diga Nada S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/669248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x5KXbN1f0YpG2Hra1ghlMBe6Zxq.jpg'),
(165973, 11771, 'O Dia Do Chacal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502189.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rdGGo715ODZCbQaZDHmp6bdcPs.jpg'),
(165974, 11771, 'O Dia Do Chacal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502190.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6Kdz5Lqdo1tqsooY2GfqUXWm8ya.jpg'),
(165975, 11771, 'O Dia Do Chacal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502191.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/33YJ3WckO3gKoSltkCCuNiy6YDW.jpg'),
(165976, 11771, 'O Dia Do Chacal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502192.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8ShIRqY8aJn21VsTrfpYRdoMTkb.jpg'),
(165977, 11771, 'O Dia Do Chacal S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502193.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sNX8Y5Ql0nXMZYsSrMFGwAS5KWe.jpg'),
(165978, 11771, 'O Dia Do Chacal S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/513321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ka7sE9ppWqCs0tueZpuryAJHpYg.jpg'),
(165979, 11771, 'O Dia Do Chacal S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/514282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ka7sE9ppWqCs0tueZpuryAJHpYg.jpg'),
(165980, 11771, 'O Dia Do Chacal S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/517799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ka7sE9ppWqCs0tueZpuryAJHpYg.jpg'),
(165981, 11771, 'O Dia Do Chacal S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/523289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ka7sE9ppWqCs0tueZpuryAJHpYg.jpg'),
(165982, 11771, 'O Dia Do Chacal S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/523290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ka7sE9ppWqCs0tueZpuryAJHpYg.jpg'),
(165983, 11772, 'Sobrevivendo em Grande Estilo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502181.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ni0zbhMTDgoQ5RFRVH6N0oGiqyl.jpg'),
(165984, 11772, 'Sobrevivendo em Grande Estilo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502182.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oFE60843dDHYPdLDiMUFP5IobN2.jpg'),
(165985, 11772, 'Sobrevivendo em Grande Estilo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502183.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xvLj6jnFC8yyHG6wknrpIHLoI9I.jpg'),
(165986, 11772, 'Sobrevivendo em Grande Estilo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502184.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/57a7t9rKTVuLEjDYZHRSEhURGbw.jpg'),
(165987, 11772, 'Sobrevivendo em Grande Estilo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502185.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hPYp0QRbp9lAitZIJgnBKjIHKXG.jpg'),
(165988, 11772, 'Sobrevivendo em Grande Estilo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502186.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2Ghmj9jFTPHXj54YwDsQdYzu1X.jpg'),
(165989, 11772, 'Sobrevivendo em Grande Estilo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502187.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t0dwYSPmVZHkKkurVo9LdHDHzJq.jpg'),
(165990, 11772, 'Sobrevivendo em Grande Estilo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502188.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vq3IwAl79v3Tl8ZAYUPqp45PrWC.jpg'),
(165991, 11773, 'Sobrevivendo em Grande Estilo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/750215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gMer2RTc20FHEbXrLkMbfAjDve4.jpg'),
(165992, 11773, 'Sobrevivendo em Grande Estilo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/750216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gMer2RTc20FHEbXrLkMbfAjDve4.jpg'),
(165993, 11773, 'Sobrevivendo em Grande Estilo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/750217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gMer2RTc20FHEbXrLkMbfAjDve4.jpg'),
(165994, 11773, 'Sobrevivendo em Grande Estilo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/750218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gMer2RTc20FHEbXrLkMbfAjDve4.jpg'),
(165995, 11773, 'Sobrevivendo em Grande Estilo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/750219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gMer2RTc20FHEbXrLkMbfAjDve4.jpg'),
(165996, 11773, 'Sobrevivendo em Grande Estilo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/750220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gMer2RTc20FHEbXrLkMbfAjDve4.jpg'),
(165997, 11773, 'Sobrevivendo em Grande Estilo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/750221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gMer2RTc20FHEbXrLkMbfAjDve4.jpg'),
(165998, 11773, 'Sobrevivendo em Grande Estilo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/750222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gMer2RTc20FHEbXrLkMbfAjDve4.jpg'),
(165999, 11774, 'As Irmas Guerra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502161.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o2GzHg39e0N106Aip5gNn67w4qq.jpg'),
(166000, 11774, 'As Irmas Guerra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502162.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lWxewptYMpSrfMr1ybOQDx4QPH5.jpg'),
(166001, 11774, 'As Irmas Guerra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502163.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3C7OvMsWLoCNTlTKBGOYWRoYz9s.jpg'),
(166002, 11774, 'As Irmas Guerra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502164.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A3jjtQM4r5QNcYry9JutJYD6ZSB.jpg'),
(166003, 11774, 'As Irmas Guerra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502165.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5cFpPlk1lqWgJuAfq8h4UIDBKlW.jpg'),
(166004, 11774, 'As Irmas Guerra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502166.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ld20f16nptWREqiPYIBKkBvukYg.jpg'),
(166005, 11774, 'As Irmas Guerra S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502167.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wWOS0LgyJPHSqgOMMDIxm26773a.jpg'),
(166006, 11774, 'As Irmas Guerra S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502168.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1gkCr3Afcrk9TQlZ5Psi88C4nnp.jpg'),
(166007, 11774, 'As Irmas Guerra S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502169.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j5J7sScSoMOXmFy8sYB4j5nrfaX.jpg'),
(166008, 11774, 'As Irmas Guerra S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502170.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/faFj2vMVcifI5RxSjgGTupiVvpe.jpg'),
(166009, 11774, 'As Irmas Guerra S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502171.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m7s57wc2ytelABWMKq2Nv8c0RoX.jpg'),
(166010, 11774, 'As Irmas Guerra S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/502172.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cSSmFUiU1PMVjZtVa3gd1qTgws2.jpg'),
(166011, 11774, 'As Irmas Guerra S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/502173.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9ncziRIgdSfArUsLuc9Q6HlIOCI.jpg'),
(166012, 11774, 'As Irmas Guerra S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/502174.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hSOXFCD5DNSF6OU5Zofz7OUYNiQ.jpg'),
(166013, 11774, 'As Irmas Guerra S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/502175.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mgkJDg4CHLmR1PQehr3Hneqedmg.jpg'),
(166014, 11774, 'As Irmas Guerra S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/502176.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lVeat9Kp1DwUYBKb65n4GPqtsPd.jpg'),
(166015, 11774, 'As Irmas Guerra S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/502177.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4fv8e2OfLSmrp9W6UHtAxRobxt2.jpg'),
(166016, 11774, 'As Irmas Guerra S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/502178.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b1Wvh7A5wcaIjWwqJa9BY3pg7G9.jpg'),
(166017, 11774, 'As Irmas Guerra S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/502179.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kVd2ImHVW1tlSnxebJdUn1Y47ww.jpg'),
(166018, 11774, 'As Irmas Guerra S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/502180.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ydynaFfNRclUvY7kGUPZ7pKUHWC.jpg'),
(166019, 11775, 'Febre do Ouro Corredeiras do Alasca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502068.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kLxFEIRTElGbd2UkbdMbbrOe3K5.jpg'),
(166020, 11775, 'Febre do Ouro Corredeiras do Alasca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502069.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9U1RKaOuUSTMJKhqbAMr3PSFTlR.jpg'),
(166021, 11775, 'Febre do Ouro Corredeiras do Alasca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502070.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gfif4kknocVHAJJ2wB9rcSJ4oBS.jpg'),
(166022, 11775, 'Febre do Ouro Corredeiras do Alasca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502071.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7fSh4v7MiNF2FQQvtGfGWEem6QC.jpg'),
(166023, 11775, 'Febre do Ouro Corredeiras do Alasca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502072.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mElRRAlBrntrUnsgqfikkIEyhDM.jpg'),
(166024, 11775, 'Febre do Ouro Corredeiras do Alasca S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502073.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2ToPXpeLt77hQzmwPlyp0C7EnR2.jpg'),
(166025, 11775, 'Febre do Ouro Corredeiras do Alasca S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502074.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cWoVzvx7ZFnK9sKNkFiO0ZbCY46.jpg'),
(166026, 11775, 'Febre do Ouro Corredeiras do Alasca S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502075.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sF83v1LDhEyBP6JGQcaXsYnC3B2.jpg'),
(166027, 11775, 'Febre do Ouro Corredeiras do Alasca S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rhefcz0wAKywJY5wAvtP41aN1hU.jpg'),
(166028, 11776, 'Febre do Ouro Corredeiras do Alasca S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rhefcz0wAKywJY5wAvtP41aN1hU.jpg'),
(166029, 11776, 'Febre do Ouro Corredeiras do Alasca S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502078.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3WYlLNElTMCFF7jbYW91O7kC02C.jpg'),
(166030, 11776, 'Febre do Ouro Corredeiras do Alasca S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502079.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sNXwj4xI0jHlELi2TXWPZon7Nqu.jpg'),
(166031, 11776, 'Febre do Ouro Corredeiras do Alasca S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502080.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cInHMXZvcdPFbhW64Gg2mSOP5cD.jpg'),
(166032, 11776, 'Febre do Ouro Corredeiras do Alasca S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502081.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oJMEumfAxGB6q3XYx0hprRSohBh.jpg'),
(166033, 11776, 'Febre do Ouro Corredeiras do Alasca S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502082.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pjTfRjI4tT3ul61HUZrSi5avA5T.jpg'),
(166034, 11776, 'Febre do Ouro Corredeiras do Alasca S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502083.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nC62CoadgdzpRpbti9pkc2mnzR8.jpg'),
(166035, 11776, 'Febre do Ouro Corredeiras do Alasca S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502084.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w70TBMW63FER1D5C4Ejm5aPVBsI.jpg'),
(166036, 11776, 'Febre do Ouro Corredeiras do Alasca S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502085.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/astUjOkapkFzP85lskW8m4EBhYC.jpg'),
(166037, 11776, 'Febre do Ouro Corredeiras do Alasca S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502086.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k5CewQb2gakRqk6JqfuvBHMErJt.jpg'),
(166038, 11776, 'Febre do Ouro Corredeiras do Alasca S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502087.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/itvptDHSOqDsVUifPOkY5CqTCRW.jpg'),
(166039, 11777, 'Febre do Ouro Corredeiras do Alasca S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rhefcz0wAKywJY5wAvtP41aN1hU.jpg'),
(166040, 11777, 'Febre do Ouro Corredeiras do Alasca S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502089.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/asF02zrMF5UjXv6c6P3Gh5I20pc.jpg'),
(166041, 11777, 'Febre do Ouro Corredeiras do Alasca S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502090.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sfgu7NF5V3MW5OcvAml2Tai8Cag.jpg'),
(166042, 11777, 'Febre do Ouro Corredeiras do Alasca S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502091.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3RDivC9M5mbXZk3n4vRucezJh43.jpg'),
(166043, 11777, 'Febre do Ouro Corredeiras do Alasca S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502092.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hrvfprYLWQzZyc7FrObSWwI0nGX.jpg'),
(166044, 11777, 'Febre do Ouro Corredeiras do Alasca S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502093.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wXoBpERqHnxJ0IqtafDDJXR53aJ.jpg'),
(166045, 11777, 'Febre do Ouro Corredeiras do Alasca S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502094.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lgQMsKYl2igHgCJkKLAx1jnlvDM.jpg'),
(166046, 11777, 'Febre do Ouro Corredeiras do Alasca S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502095.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wWyBEjry4ZkLPVYfrdZcPQrSoLe.jpg'),
(166047, 11777, 'Febre do Ouro Corredeiras do Alasca S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502096.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qCskYF0hSoFmfmbnwO11V2wALYL.jpg'),
(166048, 11777, 'Febre do Ouro Corredeiras do Alasca S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502097.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/KlI5JAd4bAOasxoftWokscjMNV.jpg'),
(166049, 11777, 'Febre do Ouro Corredeiras do Alasca S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502098.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/itvptDHSOqDsVUifPOkY5CqTCRW.jpg'),
(166050, 11777, 'Febre do Ouro Corredeiras do Alasca S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/502099.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/itvptDHSOqDsVUifPOkY5CqTCRW.jpg'),
(166051, 11777, 'Febre do Ouro Corredeiras do Alasca S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/502100.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/itvptDHSOqDsVUifPOkY5CqTCRW.jpg'),
(166052, 11777, 'Febre do Ouro Corredeiras do Alasca S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/502101.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/itvptDHSOqDsVUifPOkY5CqTCRW.jpg'),
(166053, 11777, 'Febre do Ouro Corredeiras do Alasca S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/502102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rhefcz0wAKywJY5wAvtP41aN1hU.jpg'),
(166054, 11778, 'Febre do Ouro Corredeiras do Alasca S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rhefcz0wAKywJY5wAvtP41aN1hU.jpg'),
(166055, 11778, 'Febre do Ouro Corredeiras do Alasca S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502104.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mYDg05x1TaGdvlc64aAU6tJhbsA.jpg'),
(166056, 11778, 'Febre do Ouro Corredeiras do Alasca S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502105.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bTmGEg1QpWnGPw2lHPiiWQQ7IOt.jpg'),
(166057, 11778, 'Febre do Ouro Corredeiras do Alasca S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502106.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k65gQIOtv3Z2jh2fK4rBhH7Wimk.jpg'),
(166058, 11778, 'Febre do Ouro Corredeiras do Alasca S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502107.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3T8IJRTzFzhffVM09KTX8P1kQ25.jpg'),
(166059, 11778, 'Febre do Ouro Corredeiras do Alasca S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502108.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/efw0ls0xfIH1IJJAGpTq5PGjem2.jpg'),
(166060, 11778, 'Febre do Ouro Corredeiras do Alasca S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502109.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wB8g59PoyNO1UvowVA3r0HEJuR4.jpg'),
(166061, 11778, 'Febre do Ouro Corredeiras do Alasca S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502110.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bkStPBPL4ctZ35Oxldx2sxmaZQh.jpg'),
(166062, 11778, 'Febre do Ouro Corredeiras do Alasca S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502111.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wgDIuBknOEe9SueQYPU7UUBNJjI.jpg'),
(166063, 11778, 'Febre do Ouro Corredeiras do Alasca S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502112.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/npo6mKi7GhBbw6PBi83Z5p73TET.jpg'),
(166064, 11778, 'Febre do Ouro Corredeiras do Alasca S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502113.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5ga3N7LnxheOStSCNoitnd0yb3q.jpg'),
(166065, 11778, 'Febre do Ouro Corredeiras do Alasca S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/502114.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rzXJKbKRlPlwmBeSghXmkhUkcuN.jpg'),
(166066, 11778, 'Febre do Ouro Corredeiras do Alasca S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/502115.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7mokpr34L1XItPLhcGXVZrFBr6a.jpg'),
(166067, 11778, 'Febre do Ouro Corredeiras do Alasca S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/502116.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oKJiQEWhZaI5r7aXypuIWBy8qKn.jpg'),
(166068, 11778, 'Febre do Ouro Corredeiras do Alasca S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/502117.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a61N3kx0JaxlCigWT8yQDRA72w2.jpg'),
(166069, 11778, 'Febre do Ouro Corredeiras do Alasca S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/502118.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AgKVydQv6k2ZuVMOC9A9J2AZmbx.jpg'),
(166070, 11778, 'Febre do Ouro Corredeiras do Alasca S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/502119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rhefcz0wAKywJY5wAvtP41aN1hU.jpg'),
(166071, 11779, 'Febre do Ouro Corredeiras do Alasca S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rhefcz0wAKywJY5wAvtP41aN1hU.jpg'),
(166072, 11779, 'Febre do Ouro Corredeiras do Alasca S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502121.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x9l6rvvxEIkc4OQesW8jvq3j3Yq.jpg'),
(166073, 11779, 'Febre do Ouro Corredeiras do Alasca S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502122.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pa5degPDhfD6eYd1aNBkGBAzbwS.jpg'),
(166074, 11779, 'Febre do Ouro Corredeiras do Alasca S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502123.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4VdxiDcPOU6cRLEsn7QSM9Inugs.jpg'),
(166075, 11779, 'Febre do Ouro Corredeiras do Alasca S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502124.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xgVlzZxqffRljZQzSUPZlEnwsCj.jpg'),
(166076, 11779, 'Febre do Ouro Corredeiras do Alasca S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502125.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lTpl6MNGuOguSpFrXU2Hg9ZMFWF.jpg'),
(166077, 11779, 'Febre do Ouro Corredeiras do Alasca S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502126.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gTpyUgAKNgm5cyI1ILve19tqJt4.jpg'),
(166078, 11779, 'Febre do Ouro Corredeiras do Alasca S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502127.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eGVIX5P3YUHl5EdeATyhXz6V8K9.jpg'),
(166079, 11779, 'Febre do Ouro Corredeiras do Alasca S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502128.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6Ssz5OlVz6No8n0QxqWprWWYz6T.jpg'),
(166080, 11779, 'Febre do Ouro Corredeiras do Alasca S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/502129.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7qNRcxNd4v0QVRHZDYyPbaUB6tB.jpg'),
(166081, 11779, 'Febre do Ouro Corredeiras do Alasca S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/502130.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i16nMXKEVxCQ3RN9XyXe8yZ64WE.jpg'),
(166082, 11779, 'Febre do Ouro Corredeiras do Alasca S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/502131.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7v52BV1wQVAOpMu2Kr0tn5eYBpN.jpg'),
(166083, 11779, 'Febre do Ouro Corredeiras do Alasca S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/502132.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kY5gZkUCWBc2MNAyDopG0xnBU6G.jpg'),
(166084, 11779, 'Febre do Ouro Corredeiras do Alasca S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/502133.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h2Dqyl17ObEDbkwIQnKImCSFkhU.jpg'),
(166085, 11779, 'Febre do Ouro Corredeiras do Alasca S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/502134.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9XiRCsG3ssYUCjHQgNQCX0YNnSG.jpg'),
(166086, 11779, 'Febre do Ouro Corredeiras do Alasca S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/502135.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ouy0BYy2OHYB2XO57bvYxFofJaT.jpg'),
(166087, 11779, 'Febre do Ouro Corredeiras do Alasca S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/502136.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qSOjU45rW1g8jYCUVT644AzNDIL.jpg'),
(166088, 11779, 'Febre do Ouro Corredeiras do Alasca S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/502137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rhefcz0wAKywJY5wAvtP41aN1hU.jpg'),
(166089, 11780, 'Febre do Ouro Corredeiras do Alasca S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rhefcz0wAKywJY5wAvtP41aN1hU.jpg'),
(166090, 11780, 'Febre do Ouro Corredeiras do Alasca S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502139.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/44h310xMljgSSYp5a9ueUfbsvly.jpg'),
(166091, 11780, 'Febre do Ouro Corredeiras do Alasca S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502140.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k7xLFdWHWVTMbLrzP0lJhwkdFQZ.jpg'),
(166092, 11780, 'Febre do Ouro Corredeiras do Alasca S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502141.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tGIX8lYosQVOafckljM8gxETd9U.jpg'),
(166093, 11780, 'Febre do Ouro Corredeiras do Alasca S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502142.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dDZbGTaup2Q23MX46oR0TL1XQ4d.jpg'),
(166094, 11780, 'Febre do Ouro Corredeiras do Alasca S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502143.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g9nsUn9pQyiT7hXv1dFSh6vcRHp.jpg'),
(166095, 11780, 'Febre do Ouro Corredeiras do Alasca S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502144.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5A5mKm5nsnrCio4QI7iLu1RwypA.jpg'),
(166096, 11780, 'Febre do Ouro Corredeiras do Alasca S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502145.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6MBgAgK2MOlOc0JD63IlkJNCqc1.jpg'),
(166097, 11780, 'Febre do Ouro Corredeiras do Alasca S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502146.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wDFbTLlz7AsGw8k4m2p2258AqPd.jpg'),
(166098, 11781, 'Febre do Ouro Corredeiras do Alasca S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502147.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u3U5nVVpdbnReZIdKRCaASvfCBI.jpg'),
(166099, 11781, 'Febre do Ouro Corredeiras do Alasca S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502148.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u0PalM42fcXEG6gS9tz0Yncrjx6.jpg'),
(166100, 11781, 'Febre do Ouro Corredeiras do Alasca S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502149.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u5PTNxLHDmOOsvvzzYibIfPRsya.jpg'),
(166101, 11781, 'Febre do Ouro Corredeiras do Alasca S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502150.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qsJstDBkOJoIqB3cWyTTiNqywvJ.jpg'),
(166102, 11781, 'Febre do Ouro Corredeiras do Alasca S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/502151.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c4Yt6tKYUFHuX35AYxSk0ekwoeW.jpg'),
(166103, 11781, 'Febre do Ouro Corredeiras do Alasca S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/502152.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rJpwY361UBAtzCdYLa0TE3UsaLq.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(166104, 11781, 'Febre do Ouro Corredeiras do Alasca S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/502153.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7hLkhcHvRxw9yyNHCPdUrVyU6Il.jpg'),
(166105, 11781, 'Febre do Ouro Corredeiras do Alasca S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/502154.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6hWXD47oZ0sO2FYcvXVO3UXlBHU.jpg'),
(166106, 11781, 'Febre do Ouro Corredeiras do Alasca S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/502155.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v2Glrp5Y9zzvSdJsr7lBKI0ZmPI.jpg'),
(166107, 11781, 'Febre do Ouro Corredeiras do Alasca S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/637307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rhefcz0wAKywJY5wAvtP41aN1hU.jpg'),
(166108, 11782, 'Febre do Ouro Corredeiras do Alasca S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/502157.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qJB33zSyBsQdws3OyyHzeqsSgYY.jpg'),
(166109, 11782, 'Febre do Ouro Corredeiras do Alasca S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/502158.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vGbsTysngs0DWKt6TKpfI6UmGHB.jpg'),
(166110, 11782, 'Febre do Ouro Corredeiras do Alasca S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/502159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rhefcz0wAKywJY5wAvtP41aN1hU.jpg'),
(166111, 11782, 'Febre do Ouro Corredeiras do Alasca S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/502160.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ilXlhCq0C8QbSL6gZeqcpshPqvt.jpg'),
(166112, 11782, 'Febre do Ouro Corredeiras do Alasca S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/509560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rhefcz0wAKywJY5wAvtP41aN1hU.jpg'),
(166113, 11782, 'Febre do Ouro Corredeiras do Alasca S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/515645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rhefcz0wAKywJY5wAvtP41aN1hU.jpg'),
(166114, 11782, 'Febre do Ouro Corredeiras do Alasca S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/518634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rhefcz0wAKywJY5wAvtP41aN1hU.jpg'),
(166115, 11782, 'Febre do Ouro Corredeiras do Alasca S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rhefcz0wAKywJY5wAvtP41aN1hU.jpg'),
(166116, 11782, 'Febre do Ouro Corredeiras do Alasca S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/637316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rhefcz0wAKywJY5wAvtP41aN1hU.jpg'),
(166117, 11782, 'Febre do Ouro Corredeiras do Alasca S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/675781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rhefcz0wAKywJY5wAvtP41aN1hU.jpg'),
(166118, 11782, 'Febre do Ouro Corredeiras do Alasca S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/675782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rhefcz0wAKywJY5wAvtP41aN1hU.jpg'),
(166119, 11782, 'Febre do Ouro Corredeiras do Alasca S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/675783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rhefcz0wAKywJY5wAvtP41aN1hU.jpg'),
(166120, 11782, 'Febre do Ouro Corredeiras do Alasca S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/675784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rhefcz0wAKywJY5wAvtP41aN1hU.jpg'),
(166121, 11782, 'Febre do Ouro Corredeiras do Alasca S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/675785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rhefcz0wAKywJY5wAvtP41aN1hU.jpg'),
(166122, 11783, 'Contagem Regressiva Jake Paul vs Mike Tyson S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/503869.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fuzBFqtntTXba8oUUw0XtsrMgaz.jpg'),
(166123, 11783, 'Contagem Regressiva Jake Paul vs Mike Tyson S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/503870.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rtn3oq7Aw6kjxO4lCpnWRyluMu7.jpg'),
(166124, 11783, 'Contagem Regressiva Jake Paul vs Mike Tyson S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/503871.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mVC2Eil24s20978KfUQ8Jq9QLvM.jpg'),
(166125, 11784, 'Garota Invencivel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508494.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pyhxJHdRQG33bvRtX7KWeP4208B.jpg'),
(166126, 11784, 'Garota Invencivel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508495.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rYJMSvxWwx6ugCCF6AGxQehXwY3.jpg'),
(166127, 11784, 'Garota Invencivel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508496.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3PTBLr7m9AaB3D8EhaAHMpVAeZh.jpg'),
(166128, 11784, 'Garota Invencivel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508497.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zvcNLr5P3nIzs0tl31AK5zHEuk1.jpg'),
(166129, 11784, 'Garota Invencivel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/512354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t9lcNmzb5XMksUfUq3rtxYVbQnv.jpg'),
(166130, 11784, 'Garota Invencivel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/514489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t9lcNmzb5XMksUfUq3rtxYVbQnv.jpg'),
(166131, 11784, 'Garota Invencivel S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/518508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t9lcNmzb5XMksUfUq3rtxYVbQnv.jpg'),
(166132, 11784, 'Garota Invencivel S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t9lcNmzb5XMksUfUq3rtxYVbQnv.jpg'),
(166133, 11784, 'Garota Invencivel S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/641044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t9lcNmzb5XMksUfUq3rtxYVbQnv.jpg'),
(166134, 11784, 'Garota Invencivel S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/641045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/t9lcNmzb5XMksUfUq3rtxYVbQnv.jpg'),
(166135, 11785, 'Landman S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508492.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qc8w4HacpHfaEWlqXUEg3Yi9VRx.jpg'),
(166136, 11785, 'Landman S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508493.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wpUBXa1BXxJBEhZb5PVivaZjdcB.jpg'),
(166137, 11785, 'Landman S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/511711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxWtATtTdwx0ERQjQ7BtVOMyq5r.jpg'),
(166138, 11785, 'Landman S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/514457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxWtATtTdwx0ERQjQ7BtVOMyq5r.jpg'),
(166139, 11785, 'Landman S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/517983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxWtATtTdwx0ERQjQ7BtVOMyq5r.jpg'),
(166140, 11785, 'Landman S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/525394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxWtATtTdwx0ERQjQ7BtVOMyq5r.jpg'),
(166141, 11785, 'Landman S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/638574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxWtATtTdwx0ERQjQ7BtVOMyq5r.jpg'),
(166142, 11785, 'Landman S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/659142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxWtATtTdwx0ERQjQ7BtVOMyq5r.jpg'),
(166143, 11785, 'Landman S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/659143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxWtATtTdwx0ERQjQ7BtVOMyq5r.jpg'),
(166144, 11785, 'Landman S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/660393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxWtATtTdwx0ERQjQ7BtVOMyq5r.jpg'),
(166145, 11786, 'Landman S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/892645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxWtATtTdwx0ERQjQ7BtVOMyq5r.jpg'),
(166146, 11786, 'Landman S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/893350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxWtATtTdwx0ERQjQ7BtVOMyq5r.jpg'),
(166147, 11786, 'Landman S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/893583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxWtATtTdwx0ERQjQ7BtVOMyq5r.jpg'),
(166148, 11786, 'Landman S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/894900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxWtATtTdwx0ERQjQ7BtVOMyq5r.jpg'),
(166149, 11786, 'Landman S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/896219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxWtATtTdwx0ERQjQ7BtVOMyq5r.jpg'),
(166150, 11786, 'Landman S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/896701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxWtATtTdwx0ERQjQ7BtVOMyq5r.jpg'),
(166151, 11786, 'Landman S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/897444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rxWtATtTdwx0ERQjQ7BtVOMyq5r.jpg'),
(166152, 11787, 'Duna A Profecia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508491.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tIOtr2QGGi1Ktek3vQaU8VaNAmt.jpg'),
(166153, 11787, 'Duna A Profecia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/512467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9kyqa103Ih22hT955ZaZdipAOAD.jpg'),
(166154, 11787, 'Duna A Profecia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/514520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9kyqa103Ih22hT955ZaZdipAOAD.jpg'),
(166155, 11787, 'Duna A Profecia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/518647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9kyqa103Ih22hT955ZaZdipAOAD.jpg'),
(166156, 11787, 'Duna A Profecia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/521309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9kyqa103Ih22hT955ZaZdipAOAD.jpg'),
(166157, 11787, 'Duna A Profecia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/641861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9kyqa103Ih22hT955ZaZdipAOAD.jpg'),
(166158, 11788, 'Dinoster Os Herois Quanticos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506892.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5x4coBrHq761MuIyFCnVCYrnwz0.jpg'),
(166159, 11788, 'Dinoster Os Herois Quanticos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506893.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/86sbxUcSFnTdAl0zmCJpEInSLDS.jpg'),
(166160, 11788, 'Dinoster Os Herois Quanticos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506894.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wpTD6FQ0jsesxnUMbaJTAQKXf0r.jpg'),
(166161, 11788, 'Dinoster Os Herois Quanticos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506895.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cT9XwvLMxygi52dN1nXFPT6JLgy.jpg'),
(166162, 11788, 'Dinoster Os Herois Quanticos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506896.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qk5iWjKOYTTucndFRYfgA2U9JTm.jpg'),
(166163, 11788, 'Dinoster Os Herois Quanticos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/506897.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AsdL64ZwZ98nB8aMGCQYcVfX648.jpg'),
(166164, 11788, 'Dinoster Os Herois Quanticos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/506898.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dQnUJnAKjPreLgdCfXAINBlhV1i.jpg'),
(166165, 11788, 'Dinoster Os Herois Quanticos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/506899.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bWZF3ujbfYwHgNoPLTV9O1klNWK.jpg'),
(166166, 11788, 'Dinoster Os Herois Quanticos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/506900.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jVY71tNRTwPxj2d6hfgaYo1qoUa.jpg'),
(166167, 11788, 'Dinoster Os Herois Quanticos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/506901.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cfoK8Rs4RAkwO5BbNYA7mtGSC8.jpg'),
(166168, 11788, 'Dinoster Os Herois Quanticos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/506902.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r5D7Qvp0NbHhwlCd4Yi2ZbsmDUv.jpg'),
(166169, 11788, 'Dinoster Os Herois Quanticos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/506903.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pbiIeeCC01cHFx5N3GDegoFqiO.jpg'),
(166170, 11788, 'Dinoster Os Herois Quanticos S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/506904.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/imDS1Z5888w79gzvvBBX32iJlhe.jpg'),
(166171, 11788, 'Dinoster Os Herois Quanticos S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/506905.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wlk2jnhU8aXiehlbf0hzSfur9rK.jpg'),
(166172, 11788, 'Dinoster Os Herois Quanticos S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/506906.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qwYKEOlwRCv3AGJaLRWODoGRiOQ.jpg'),
(166173, 11788, 'Dinoster Os Herois Quanticos S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/506907.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oekSxCCCdDWwV87FtUi6Uzxyioh.jpg'),
(166174, 11788, 'Dinoster Os Herois Quanticos S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/506908.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jKv1YKZFWwaFAJdL4DheMaFzEL3.jpg'),
(166175, 11788, 'Dinoster Os Herois Quanticos S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/506909.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q16jUHVMkZ9uQU3tA2g9RhE90gy.jpg'),
(166176, 11788, 'Dinoster Os Herois Quanticos S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/506910.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cGvPtVFKGOD7qfxdcaRJDPSW8Ee.jpg'),
(166177, 11788, 'Dinoster Os Herois Quanticos S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/506911.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3rkEznVDndApLEIzm0ShEYR0BjZ.jpg'),
(166178, 11788, 'Dinoster Os Herois Quanticos S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/506912.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7g2czaDcIKw76VsV7OkjQ11WLAN.jpg'),
(166179, 11788, 'Dinoster Os Herois Quanticos S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/506913.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4uJOiuyhdfakayNXd7GMqTc6bMI.jpg'),
(166180, 11788, 'Dinoster Os Herois Quanticos S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/506914.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pVJFlsYgLBE59nFlilZjtH8Rc0Q.jpg'),
(166181, 11788, 'Dinoster Os Herois Quanticos S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/506915.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a6dzmGouF7hfAQKLD8chxvP44JK.jpg'),
(166182, 11788, 'Dinoster Os Herois Quanticos S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/506916.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9y0q07MZgS9ozjEaDhs8bOp8j6h.jpg'),
(166183, 11788, 'Dinoster Os Herois Quanticos S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/506917.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/steKhE6ZAx9z0FU2uU5Odqustap.jpg'),
(166184, 11789, 'Adoracao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506738.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ouog3Z8Wg9suxjhcpqN2t8Pi7es.jpg'),
(166185, 11789, 'Adoracao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506739.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2R04USSUptHL8ztcdxo7pf8B1sT.jpg'),
(166186, 11789, 'Adoracao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506740.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wDq08TR74sJSPvmQcRKtCXY7rvi.jpg'),
(166187, 11789, 'Adoracao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506741.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wDZm0MrtUS39ltv0U6ZH2YyVlFu.jpg'),
(166188, 11789, 'Adoracao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506742.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lPesGM3QoyXd9olwKhNTKSSt9j3.jpg'),
(166189, 11789, 'Adoracao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/506743.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/13zRafF1UcyX6V9ALqkfM3linKI.jpg'),
(166190, 11790, 'Captivated S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506734.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gih2qgDHclvjyj0Imv8piGglbJd.jpg'),
(166191, 11790, 'Captivated S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506735.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ll6JKK1yFVHMrmIFFoQqtELU7f9.jpg'),
(166192, 11790, 'Captivated S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506736.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xplS9SrA2rU4bOHuZ93n9OgBp3a.jpg'),
(166193, 11790, 'Captivated S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506737.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1ENjg1vaTJJYf0Vh1xhINmNGHRE.jpg'),
(166194, 11791, 'Interior Chinatown S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506724.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f5rlrDfHHXfDqlf66QlVkoGhqBO.jpg'),
(166195, 11791, 'Interior Chinatown S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506725.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bA5vaPVrGiJhhpdBYhB9Rp0BFg2.jpg'),
(166196, 11791, 'Interior Chinatown S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506726.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kApWN8Ipb07lSgyxVfQMgFApEdb.jpg'),
(166197, 11791, 'Interior Chinatown S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506727.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5EvBwDXrEgulSmuASu7GZSyFzb2.jpg'),
(166198, 11791, 'Interior Chinatown S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506728.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/orYpdbtqHFbdBRi8w3F2zpbJOpf.jpg'),
(166199, 11791, 'Interior Chinatown S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/506729.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nkCGufezbXx5n0nTqA631kOm84j.jpg'),
(166200, 11791, 'Interior Chinatown S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/506730.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/S8wJm71W0a382a9SKcVn7oklM1.jpg'),
(166201, 11791, 'Interior Chinatown S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/506731.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sKxfPIbQyFEyVIeYs3JjW43EtEr.jpg'),
(166202, 11791, 'Interior Chinatown S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/506732.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AdeqVjOGPWWHyYI2zQg9EfbWhKm.jpg'),
(166203, 11791, 'Interior Chinatown S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/506733.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uRH5ZKVw4GEEidY7eGhr9ubgdBq.jpg'),
(166204, 11792, 'Iron Chef America Os Legendarios S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506712.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aMPttiRHU5a55vMezCgTWBAGhOT.jpg'),
(166205, 11792, 'Iron Chef America Os Legendarios S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506713.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fZ6y4vNgGCDO7x73iWDQJ6Fs0yM.jpg'),
(166206, 11792, 'Iron Chef America Os Legendarios S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506714.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8Y8jCrUmmt1MIHKp9h4FqtAy3Ha.jpg'),
(166207, 11792, 'Iron Chef America Os Legendarios S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506715.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u2Dx2hk2jyzcBIkvIohZ4fBMf3k.jpg'),
(166208, 11792, 'Iron Chef America Os Legendarios S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506716.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zwROAge2qb7QaNC0t5ReqPVbrBN.jpg'),
(166209, 11792, 'Iron Chef America Os Legendarios S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/506717.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kfPcQp0XyRamvum0eRl8EOr5ewD.jpg'),
(166210, 11793, 'Iron Chef America Os Legendarios S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ygHbGbobx9gbW4DqEKk0xiNwetF.jpg'),
(166211, 11793, 'Iron Chef America Os Legendarios S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ygHbGbobx9gbW4DqEKk0xiNwetF.jpg'),
(166212, 11793, 'Iron Chef America Os Legendarios S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ygHbGbobx9gbW4DqEKk0xiNwetF.jpg'),
(166213, 11793, 'Iron Chef America Os Legendarios S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ygHbGbobx9gbW4DqEKk0xiNwetF.jpg'),
(166214, 11793, 'Iron Chef America Os Legendarios S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ygHbGbobx9gbW4DqEKk0xiNwetF.jpg'),
(166215, 11793, 'Iron Chef America Os Legendarios S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/506723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ygHbGbobx9gbW4DqEKk0xiNwetF.jpg'),
(166216, 11794, 'MasterChef Brasil Confeitaria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYjxxI0fy9lt2gr1JE3mAcO20fw.jpg'),
(166217, 11794, 'MasterChef Brasil Confeitaria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/513331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYjxxI0fy9lt2gr1JE3mAcO20fw.jpg'),
(166218, 11794, 'MasterChef Brasil Confeitaria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/514344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYjxxI0fy9lt2gr1JE3mAcO20fw.jpg'),
(166219, 11794, 'MasterChef Brasil Confeitaria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/514345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYjxxI0fy9lt2gr1JE3mAcO20fw.jpg'),
(166220, 11794, 'MasterChef Brasil Confeitaria S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/517852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYjxxI0fy9lt2gr1JE3mAcO20fw.jpg'),
(166221, 11794, 'MasterChef Brasil Confeitaria S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/517853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYjxxI0fy9lt2gr1JE3mAcO20fw.jpg'),
(166222, 11794, 'MasterChef Brasil Confeitaria S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/523326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYjxxI0fy9lt2gr1JE3mAcO20fw.jpg'),
(166223, 11794, 'MasterChef Brasil Confeitaria S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/523327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYjxxI0fy9lt2gr1JE3mAcO20fw.jpg'),
(166224, 11794, 'MasterChef Brasil Confeitaria S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/637021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYjxxI0fy9lt2gr1JE3mAcO20fw.jpg'),
(166225, 11794, 'MasterChef Brasil Confeitaria S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/638461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYjxxI0fy9lt2gr1JE3mAcO20fw.jpg'),
(166226, 11795, 'MasterChef Brasil Confeitaria S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/883796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYjxxI0fy9lt2gr1JE3mAcO20fw.jpg'),
(166227, 11795, 'MasterChef Brasil Confeitaria S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/885316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYjxxI0fy9lt2gr1JE3mAcO20fw.jpg'),
(166228, 11795, 'MasterChef Brasil Confeitaria S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/886079.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYjxxI0fy9lt2gr1JE3mAcO20fw.jpg'),
(166229, 11795, 'MasterChef Brasil Confeitaria S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/887570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYjxxI0fy9lt2gr1JE3mAcO20fw.jpg'),
(166230, 11795, 'MasterChef Brasil Confeitaria S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/888170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYjxxI0fy9lt2gr1JE3mAcO20fw.jpg'),
(166231, 11795, 'MasterChef Brasil Confeitaria S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/889629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYjxxI0fy9lt2gr1JE3mAcO20fw.jpg'),
(166232, 11795, 'MasterChef Brasil Confeitaria S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/890682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYjxxI0fy9lt2gr1JE3mAcO20fw.jpg'),
(166233, 11795, 'MasterChef Brasil Confeitaria S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/890683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYjxxI0fy9lt2gr1JE3mAcO20fw.jpg'),
(166234, 11795, 'MasterChef Brasil Confeitaria S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/891855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYjxxI0fy9lt2gr1JE3mAcO20fw.jpg'),
(166235, 11795, 'MasterChef Brasil Confeitaria S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/892436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eYjxxI0fy9lt2gr1JE3mAcO20fw.jpg'),
(166236, 11796, 'Monster High S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506685.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3nVO47MTwgwl3zWx29QJKhg8q4l.jpg'),
(166237, 11796, 'Monster High S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506686.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7p5BPfixoR2neUY9cejltDZkLgg.jpg'),
(166238, 11796, 'Monster High S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506687.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o6Yd6VDSY69gIsX8XFcwaKtIs8V.jpg'),
(166239, 11796, 'Monster High S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506688.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ie043SZlnBazBAkMRkLMPgAQxe3.jpg'),
(166240, 11796, 'Monster High S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506689.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rbPcubws1k9ghwV9triVJFALiqR.jpg'),
(166241, 11796, 'Monster High S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/506690.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/stl7ByUTMUCYVdvqabh3iMJuqiF.jpg'),
(166242, 11796, 'Monster High S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/506691.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ifjHqHSdFpu8sR9U82Uom49n0Ps.jpg'),
(166243, 11796, 'Monster High S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/506692.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wnXZHPh4McJk6Sz79d4IXjFkXCe.jpg'),
(166244, 11796, 'Monster High S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/506693.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6BG8LmlApt1c8ShkOsm5vqU9lPb.jpg'),
(166245, 11796, 'Monster High S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/506694.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fbejOuNQg9enDUaVD7q7bEFJje.jpg'),
(166246, 11796, 'Monster High S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/506695.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/owlf5qurXFiQWDjd6RNQSmgDzjr.jpg'),
(166247, 11796, 'Monster High S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/506696.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vaIN2ryOpwc9mbbAdfppGyH4BHv.jpg'),
(166248, 11796, 'Monster High S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/506697.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pThDtUmeKXdpW2M8h8Z3sQx6uAP.jpg'),
(166249, 11796, 'Monster High S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/506698.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/myP5QK8Spfj2BkJnC9SIkgKBrjN.jpg'),
(166250, 11796, 'Monster High S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/506699.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hvoMnDfU9NlEr5o2Ir4TWXUspL2.jpg'),
(166251, 11796, 'Monster High S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/506700.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pcIQQLveu0AnOR0RJ7zhvPltczO.jpg'),
(166252, 11796, 'Monster High S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/506701.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p4vXKincgclzFW0wAW6ExKhHAS3.jpg'),
(166253, 11796, 'Monster High S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/506702.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sPQ9fhJYV5JfP4DlKUk40SgWTwF.jpg'),
(166254, 11796, 'Monster High S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/506703.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/28lDVrWWAN2lOzlAe9c722TX7Tr.jpg'),
(166255, 11796, 'Monster High S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/506704.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dBKMp3awo2g5BrbZxEdXQWIHkfC.jpg'),
(166256, 11796, 'Monster High S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/506705.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l1K8Efn0keTeEr1RB7Hlrn8X3vo.jpg'),
(166257, 11796, 'Monster High S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/506706.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sPngZxVuZnTi36meIbjKU3fkmZ0.jpg'),
(166258, 11796, 'Monster High S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/506707.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Ne0KVOse5sIgMGaWfXQxYBcDRv.jpg'),
(166259, 11796, 'Monster High S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/506708.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nK3KOqe0DldP909PWo0CMhgekzM.jpg'),
(166260, 11796, 'Monster High S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/506709.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kbrYb81u13R8hTKYhXqOKqQlTnR.jpg'),
(166261, 11796, 'Monster High S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/506710.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nmwedcdIbQtnv3q0OONgsdttff.jpg'),
(166262, 11797, 'Nossos Oceanos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506680.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/38Cjzi17UDpe0WD8WnaOTMfHrzO.jpg'),
(166263, 11797, 'Nossos Oceanos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506681.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kYDo9YedvRZraxREHXsigfBgoEb.jpg'),
(166264, 11797, 'Nossos Oceanos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506682.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s6aI4Th2hWcZhICR6ZsYKNXENOp.jpg'),
(166265, 11797, 'Nossos Oceanos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506683.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uYwpTIY4pgdb26ItbsurhWFxAWI.jpg'),
(166266, 11797, 'Nossos Oceanos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506684.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tEvC9smDplZPGOpe4hC85PJkTLx.jpg'),
(166267, 11798, 'SEAL Team [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506567.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v8VzyiIRCOslX94rFPhkNuJPjl3.jpg'),
(166268, 11798, 'SEAL Team [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506568.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kHuIKwUmN4n9NJ4kUALiV8n5hBz.jpg'),
(166269, 11798, 'SEAL Team [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506569.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/avKmJd7EmTwR1HFPmacBjnI0R0q.jpg'),
(166270, 11798, 'SEAL Team [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506570.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jvQucdxtMM43bXMoGF6lPIBTKk2.jpg'),
(166271, 11798, 'SEAL Team [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506571.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mM8oIKiooFsNNXdgLtrLH5fT6Gw.jpg'),
(166272, 11798, 'SEAL Team [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/506572.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/frNXhRhluriWb4DwqEELvCBhSTX.jpg'),
(166273, 11798, 'SEAL Team [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/506573.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tSFjp2yg87COrldWPQLYcsMpK8W.jpg'),
(166274, 11798, 'SEAL Team [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/506574.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iuJ8txqqz5WvNvVxDf0Z8kkhQUz.jpg'),
(166275, 11798, 'SEAL Team [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/506575.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uS1Zm58e0JR1Fn74MUhzRVjPmRz.jpg'),
(166276, 11798, 'SEAL Team [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/506576.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kC4UsSew1ZLBLeiOiFIu2P4XiMM.jpg'),
(166277, 11798, 'SEAL Team [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/506577.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sfewmvVFSXo7fCp2cAdk3iM0Kbj.jpg'),
(166278, 11798, 'SEAL Team [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/506578.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dnLF3wzP8zwPkv0Urr5U5Q7zdCn.jpg'),
(166279, 11798, 'SEAL Team [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/506579.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8LqmXQRon5bc8gpihaxRP9fHkU3.jpg'),
(166280, 11798, 'SEAL Team [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/506580.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hP09IthUw0muTPozGJ1kyCfZVti.jpg'),
(166281, 11798, 'SEAL Team [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/506581.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fyFz2xW8jytgIljzP2f1I3w2xqG.jpg'),
(166282, 11798, 'SEAL Team [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/506582.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bAHiUuKGYAM3icNIaPHu0hChdmw.jpg'),
(166283, 11798, 'SEAL Team [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/506583.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aY9tl9YaEGLOEgZ8BUnQswm5FUO.jpg'),
(166284, 11798, 'SEAL Team [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/506584.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fDpi7UKywpthYufil7fLBUESxr3.jpg'),
(166285, 11798, 'SEAL Team [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/506585.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9qgurMsiECi4SSTby1hXpbj0PjM.jpg'),
(166286, 11798, 'SEAL Team [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/506586.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5uFqREX1qDn8f7Iz0AED3326eLa.jpg'),
(166287, 11798, 'SEAL Team [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/506587.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pUXSBJjktMtzVYas2SqDhT7dnsw.jpg'),
(166288, 11798, 'SEAL Team [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/506588.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6DUIBTEaLQqpQ9lxOyJp1ILsrAS.jpg'),
(166289, 11799, 'SEAL Team [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506589.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wqnGvxBkUFzwuZgHcdcZTqAygNw.jpg'),
(166290, 11799, 'SEAL Team [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506590.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6qffeVl5PvWkmOje80IeS4B4RyN.jpg'),
(166291, 11799, 'SEAL Team [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506591.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sN7q7Dlc5ZQFWhyJufMP9dg7zut.jpg'),
(166292, 11799, 'SEAL Team [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506592.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rcOeOHSRURsA54iuWVFiSKDoEL9.jpg'),
(166293, 11799, 'SEAL Team [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506593.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/juGpAzXsi9iQ8pYH7vL67iFRoFt.jpg'),
(166294, 11799, 'SEAL Team [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/506594.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iFTULr60Yg4MdXq6I7dToLRNqV2.jpg'),
(166295, 11799, 'SEAL Team [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/506595.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jvgh3i5dkybPE5NaNR7laQy32jt.jpg'),
(166296, 11799, 'SEAL Team [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/506596.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8VMgYrPkQ67674uK0TOFS6Q42fX.jpg'),
(166297, 11799, 'SEAL Team [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/506597.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o9vX8jh1Sc7SKrEMDPGqGqwNwaa.jpg'),
(166298, 11799, 'SEAL Team [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/506598.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v5oRUlIvuGgzVJQVOwKeb31Sp2P.jpg'),
(166299, 11799, 'SEAL Team [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/506599.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jFkxstpz3d0vIs0ByZaMQCi0oOA.jpg'),
(166300, 11799, 'SEAL Team [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/506600.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hdgsPwK1Pbznuun9SF83oLc26GF.jpg'),
(166301, 11799, 'SEAL Team [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/506601.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6HPvbTLt89o2G4qpzKRCAf8lWKs.jpg'),
(166302, 11799, 'SEAL Team [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/506602.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xZurmjIAnWu3ItZNzbfObXC0Bc4.jpg'),
(166303, 11799, 'SEAL Team [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/506603.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/inZQUTcZW4UDVPpjV5e90mFD42Q.jpg'),
(166304, 11799, 'SEAL Team [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/506604.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/elrfuSwHZ5GP0QCQdhRd0zWUQOy.jpg'),
(166305, 11799, 'SEAL Team [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/506605.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hJm9c1kNy2K9RCN2XB7OuNabDzf.jpg'),
(166306, 11799, 'SEAL Team [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/506606.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xGf5WZi8TqGCo7FyEUrHTipKf0z.jpg'),
(166307, 11799, 'SEAL Team [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/506607.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xz72XuD8OhQh6JmC26V7nlgp4bI.jpg'),
(166308, 11799, 'SEAL Team [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/506608.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iKeJ8892hBaZGCOpexfpY3sqJdn.jpg'),
(166309, 11799, 'SEAL Team [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/506609.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cnjloAUqDQm23vMipEpZ8YVEBBW.jpg'),
(166310, 11799, 'SEAL Team [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/506610.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dqaqg7UHPaVdSC4GdAKEb0FBNgl.jpg'),
(166311, 11800, 'SEAL Team [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506611.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6rJ1LH003APwHgdhJiyd0qWG4WW.jpg'),
(166312, 11800, 'SEAL Team [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506612.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/48AeqqXbot0SDN5yZ7nw9Mz8Qfc.jpg'),
(166313, 11800, 'SEAL Team [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506613.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9fepttTdsPa46xrUnYODetecPg8.jpg'),
(166314, 11800, 'SEAL Team [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506614.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/plFZXPm0v5e4EVCA1KO9hoGlk3V.jpg'),
(166315, 11800, 'SEAL Team [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506615.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dDZEKv9tGDa2G33U8tMHq9Qzpvc.jpg'),
(166316, 11800, 'SEAL Team [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/506616.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7YU7B72pm355P86bAmemx28u3xR.jpg'),
(166317, 11800, 'SEAL Team [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/506617.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8gpLUxkDYuz7JH2GpuQoRG9K8qH.jpg'),
(166318, 11800, 'SEAL Team [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/506618.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/40rr6IlL1Ry5nOIHuFDlTe60ARP.jpg'),
(166319, 11800, 'SEAL Team [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/506619.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yh6JGpuyT3135nJkVEo9s5BKWEA.jpg'),
(166320, 11800, 'SEAL Team [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/506620.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zjALfOFeH4xEC2KYzPdIabZniV0.jpg'),
(166321, 11800, 'SEAL Team [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/506621.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zopMDLdygUcu0a2HgBhwmKKBU66.jpg'),
(166322, 11800, 'SEAL Team [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/506622.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sW4S0bVQPNX6vXqWgcjNgQbSRmf.jpg'),
(166323, 11800, 'SEAL Team [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/506623.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/swXLbnD4rnOGEOqatpaV6tl9n26.jpg'),
(166324, 11800, 'SEAL Team [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/506624.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/am87EoBevYOeEkal6mFwKSVEYAQ.jpg'),
(166325, 11800, 'SEAL Team [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/506625.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6G87yUclTDStX3ewxQbI9g7j7LP.jpg'),
(166326, 11800, 'SEAL Team [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/506626.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aypBSGW1b33zbBgz9vNMurE14Xe.jpg'),
(166327, 11800, 'SEAL Team [L] S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/506627.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7rI9Noqnzo0BvrkYXZqqueS9xW6.jpg'),
(166328, 11800, 'SEAL Team [L] S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/506628.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4bFmjQ71o1iPRnx3NzGXqooMQqj.jpg'),
(166329, 11800, 'SEAL Team [L] S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/506629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5VHLhwr9eBZEi8yVM5fRo7XMFGF.jpg'),
(166330, 11801, 'SEAL Team [L] S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506630.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g8raKTaiYxk9440Q1y0HQ3YV8ZY.jpg'),
(166331, 11801, 'SEAL Team [L] S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5VHLhwr9eBZEi8yVM5fRo7XMFGF.jpg'),
(166332, 11801, 'SEAL Team [L] S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506632.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3QsrgrzS9iYqFzoNfR3rgawLQy2.jpg'),
(166333, 11801, 'SEAL Team [L] S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506633.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7T9ETRkvlOAAM5NemTAi0rqSKQF.jpg'),
(166334, 11801, 'SEAL Team [L] S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506634.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pF71EZMhyRKaARn7sv1vam8yoZA.jpg'),
(166335, 11801, 'SEAL Team [L] S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/506635.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5XIgicxt1hpgLYepXTgnxZOKG2Q.jpg'),
(166336, 11801, 'SEAL Team [L] S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/506636.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cKwKbYWWe079kjzAnUXV6FUPJ2r.jpg'),
(166337, 11801, 'SEAL Team [L] S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/506637.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vUPCNlPgTRHx7E9pZwDUO0PLNqT.jpg'),
(166338, 11801, 'SEAL Team [L] S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/506638.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mSQgeH2ZCnrnNGJzsODJzvshhwL.jpg'),
(166339, 11801, 'SEAL Team [L] S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/506639.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vJ1SV4lmJqfFNXjKukFnrMN2293.jpg'),
(166340, 11801, 'SEAL Team [L] S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/506640.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zF44vZ80m891xMRTkGmHXtwI549.jpg'),
(166341, 11801, 'SEAL Team [L] S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/506641.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cqRbremIqpUPVKmTEyxhzO1zIKY.jpg'),
(166342, 11801, 'SEAL Team [L] S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/506642.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uXyLr9e6QX2beFABm3R7vH6y96x.jpg'),
(166343, 11801, 'SEAL Team [L] S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/506643.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y3xiAQnuRD8B8pnpo1ldqlduHDW.jpg'),
(166344, 11801, 'SEAL Team [L] S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/506644.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rDspn6zn0IpdtkK09fOEpZsFTw4.jpg'),
(166345, 11801, 'SEAL Team [L] S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/506645.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i55tbRvjzQ75SIwl7XHUmZpEKVc.jpg'),
(166346, 11802, 'SEAL Team [L] S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506646.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bSBn3SLDN8TykDjW1eC9Zo2TlPN.jpg'),
(166347, 11802, 'SEAL Team [L] S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506647.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7YCxUPP6v4sfE7iYxMb0P1SATAb.jpg'),
(166348, 11802, 'SEAL Team [L] S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506648.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pkCrp08p1NJDBHXyYr7iagD33yz.jpg'),
(166349, 11802, 'SEAL Team [L] S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506649.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8vfpa0JGTMxWAiYKUttuuIkCQOj.jpg'),
(166350, 11802, 'SEAL Team [L] S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506650.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qMTT2b3SN2CsVoX33jhpQf6g8M4.jpg'),
(166351, 11802, 'SEAL Team [L] S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/506651.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7kYpG5Qr1j8fdR9NufTJgK1eUBl.jpg'),
(166352, 11802, 'SEAL Team [L] S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/506652.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/le6P7L2fP73StFu4Edie82LAIt8.jpg'),
(166353, 11802, 'SEAL Team [L] S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/506653.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/woH8Gdrt4C8jVLEDQN4YRdRluxu.jpg'),
(166354, 11802, 'SEAL Team [L] S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/506654.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l0AJGrq0SLBPTF24U08GJF9Psv4.jpg'),
(166355, 11802, 'SEAL Team [L] S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/506655.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o7l25s5DcM7GtTHDd2bq0cWTVUL.jpg'),
(166356, 11802, 'SEAL Team [L] S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/506656.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sD8I5AQozkV3dQ08Dl8NYrA83fA.jpg'),
(166357, 11802, 'SEAL Team [L] S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/506657.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m2a7SBWvkYPx9RiLwnkGZJnkmEV.jpg'),
(166358, 11802, 'SEAL Team [L] S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/506658.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i9NjjbBmpPezMR2umazflVa0MkL.jpg'),
(166359, 11802, 'SEAL Team [L] S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/506659.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dBFAkR4Be3aEvxYJ06aXmEoSPAO.jpg'),
(166360, 11803, 'SEAL Team [L] S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506660.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wkPXP9RZ3vjhBquR8BWk2kyx7oU.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(166361, 11803, 'SEAL Team [L] S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506661.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/psU0I83qjQiU5ycdAkOecPSunvU.jpg'),
(166362, 11803, 'SEAL Team [L] S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506662.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uEvEA06aJj7sVwieNZ3H30CfYYT.jpg'),
(166363, 11803, 'SEAL Team [L] S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506663.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qqkANr0dGFY8WCTVOBcMHlNlhqQ.jpg'),
(166364, 11803, 'SEAL Team [L] S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506664.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j1ftQsd3IWy2sUZxLNTl1T2uD1s.jpg'),
(166365, 11803, 'SEAL Team [L] S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/506665.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h8W8NbQB93CPHbn3KQIHwMArQTT.jpg'),
(166366, 11803, 'SEAL Team [L] S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/506666.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tRjtRer9NCxLgFULcm60BlqpJba.jpg'),
(166367, 11803, 'SEAL Team [L] S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/506667.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6ElEvexKePBd7TLyHDzJopRBlx9.jpg'),
(166368, 11803, 'SEAL Team [L] S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/506668.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9oMeNZ3JzRUmQJUv8DuC56CVIK8.jpg'),
(166369, 11803, 'SEAL Team [L] S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/506669.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9ji7B6YxfISITUtwUR0ydfD5FFS.jpg'),
(166370, 11804, 'SEAL Team [L] S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506670.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z5HgsHJMhqy4gqwztJThZrbUWsD.jpg'),
(166371, 11804, 'SEAL Team [L] S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506671.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eKoe7tu5OBvLgBfNX2MAqC2gP2e.jpg'),
(166372, 11804, 'SEAL Team [L] S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506672.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tiVRGHVbqmYXMuHpNh6JMd75SYP.jpg'),
(166373, 11804, 'SEAL Team [L] S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506673.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mUrIPK3DtmNeYw4HpEYauPSldRR.jpg'),
(166374, 11804, 'SEAL Team [L] S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506674.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gw3dHIwwbjSV4Ef2Bz4PDCw0B3I.jpg'),
(166375, 11804, 'SEAL Team [L] S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/506675.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xTuhXFqS5QdA1SLQBx03V60Vw8e.jpg'),
(166376, 11804, 'SEAL Team [L] S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/506676.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fIK7gRKyLhccwetuvK5hnX30NtB.jpg'),
(166377, 11804, 'SEAL Team [L] S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/506677.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/urLMIwelmyAx7BbvGFpUIsRYwIl.jpg'),
(166378, 11804, 'SEAL Team [L] S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/506678.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n8BCjC932y758ZjLYnBRL0XhYCs.jpg'),
(166379, 11804, 'SEAL Team [L] S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/506679.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/biFRt6jXQYFrSfRRuuYgXf12chh.jpg'),
(166380, 11805, 'Spooksville S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506545.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cfNJJtiY8zKaR6b7rtzvUir9oDe.jpg'),
(166381, 11805, 'Spooksville S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506546.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dFcgMK0aQycdPtMlhJSuJZ07gco.jpg'),
(166382, 11805, 'Spooksville S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3V0hFx8NgYXVfHfoMOuAXs3rb1J.jpg'),
(166383, 11805, 'Spooksville S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506548.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j4IRrYiU8X4enwm2lqwLqECZdL9.jpg'),
(166384, 11805, 'Spooksville S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3V0hFx8NgYXVfHfoMOuAXs3rb1J.jpg'),
(166385, 11805, 'Spooksville S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/506550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3V0hFx8NgYXVfHfoMOuAXs3rb1J.jpg'),
(166386, 11805, 'Spooksville S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/506551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3V0hFx8NgYXVfHfoMOuAXs3rb1J.jpg'),
(166387, 11805, 'Spooksville S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/506552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3V0hFx8NgYXVfHfoMOuAXs3rb1J.jpg'),
(166388, 11805, 'Spooksville S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/506553.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/focNdxu8ljZoZYMthJldeeEeftl.jpg'),
(166389, 11805, 'Spooksville S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/506554.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hgQXVcFJYd2YShCcRvgIP6FtNBa.jpg'),
(166390, 11805, 'Spooksville S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/506555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3V0hFx8NgYXVfHfoMOuAXs3rb1J.jpg'),
(166391, 11805, 'Spooksville S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/506556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3V0hFx8NgYXVfHfoMOuAXs3rb1J.jpg'),
(166392, 11805, 'Spooksville S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/506557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3V0hFx8NgYXVfHfoMOuAXs3rb1J.jpg'),
(166393, 11805, 'Spooksville S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/506558.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3KqVIPqJrlAgXzQ1SihSMl7ZUT9.jpg'),
(166394, 11805, 'Spooksville S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/506559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3V0hFx8NgYXVfHfoMOuAXs3rb1J.jpg'),
(166395, 11805, 'Spooksville S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/506560.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sUro7vCC3fNJ1eZaYfauio0hCRS.jpg'),
(166396, 11805, 'Spooksville S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/506561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3V0hFx8NgYXVfHfoMOuAXs3rb1J.jpg'),
(166397, 11805, 'Spooksville S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/506562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3V0hFx8NgYXVfHfoMOuAXs3rb1J.jpg'),
(166398, 11805, 'Spooksville S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/506563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3V0hFx8NgYXVfHfoMOuAXs3rb1J.jpg'),
(166399, 11805, 'Spooksville S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/506564.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b1fvyNDzLXNSBOOarpRX6PfdyhL.jpg'),
(166400, 11805, 'Spooksville S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/506565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3V0hFx8NgYXVfHfoMOuAXs3rb1J.jpg'),
(166401, 11805, 'Spooksville S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/506566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3V0hFx8NgYXVfHfoMOuAXs3rb1J.jpg'),
(166402, 11806, 'Sobre Essa Pele S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/506540.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y8Nza3OZzUOe4jBYEVRp7i7bIuV.jpg'),
(166403, 11806, 'Sobre Essa Pele S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/506541.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wRlEYuc0c3KzMwzHtcxkNrQpFSj.jpg'),
(166404, 11806, 'Sobre Essa Pele S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/506542.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vjb44q2QjOL4YMTRB8Ha7CJYMnQ.jpg'),
(166405, 11806, 'Sobre Essa Pele S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/506543.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fumBLD2lRQqzfrJ5r3hk44dCSWI.jpg'),
(166406, 11806, 'Sobre Essa Pele S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/506544.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ILe0gamKvCEzRvXNY3h9pnbr9G.jpg'),
(166407, 11807, 'Las Bravas F.C S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/510530.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zQSv2yEvToEGlPosilsnyWukX3v.jpg'),
(166408, 11807, 'Las Bravas F.C S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/510531.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jdLFdzQe1NOfLeJpcbkL5ggX84p.jpg'),
(166409, 11807, 'Las Bravas F.C S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/510532.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9KIj9ZIl9lyUYdyaN8K3H5TIRH2.jpg'),
(166410, 11807, 'Las Bravas F.C S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/510533.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n48Qq1D9eA1QapZoEixYoZ6DdBg.jpg'),
(166411, 11807, 'Las Bravas F.C S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/510534.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p7FSgcXlrAzki6NGBfyH6QAhKCs.jpg'),
(166412, 11807, 'Las Bravas F.C S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/510535.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/29vOMuT3zXVME06dr1U1VqAtTJA.jpg'),
(166413, 11807, 'Las Bravas F.C S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/510536.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/95EseVOx9PTahJ7f8b6HOt56TK2.jpg'),
(166414, 11807, 'Las Bravas F.C S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/510537.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ot1uChdlKqmXUXDFo9IH3g6uLNJ.jpg'),
(166415, 11808, 'Las Bravas F.C S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/510538.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8amEohetr2YS1wgLlyYEzzrMEcx.jpg'),
(166416, 11808, 'Las Bravas F.C S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/510539.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/DZ1aKZDBM5nqGG3VQkmZegN4es.jpg'),
(166417, 11808, 'Las Bravas F.C S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/510540.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fxlHm0l6iQcYLKwphK3OgIjln6B.jpg'),
(166418, 11808, 'Las Bravas F.C S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/510541.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/746cYk4AkoQIBlA6otbBQEQqvM1.jpg'),
(166419, 11808, 'Las Bravas F.C S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/510542.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jZ8Lh0JxZfWPfbL3LzRj5b73ktc.jpg'),
(166420, 11808, 'Las Bravas F.C S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/510543.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aSMHE3JOQBo2vogEO3K7HOi3nq1.jpg'),
(166421, 11808, 'Las Bravas F.C S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/510544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/45gWJBV1JNbiP4nIPjb8oFYSjv.jpg'),
(166422, 11808, 'Las Bravas F.C S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/510545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/45gWJBV1JNbiP4nIPjb8oFYSjv.jpg'),
(166423, 11809, 'Molang S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/510400.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/19lKLnkxwfFob1tIDoADBoZwMT5.jpg'),
(166424, 11809, 'Molang S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/510401.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vgXDdhK4sSpErGCZhI8sfQ3nMMI.jpg'),
(166425, 11809, 'Molang S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/510402.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mVborfMTGYqNPSd4CwxH2zX7Cnx.jpg'),
(166426, 11809, 'Molang S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/510403.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3RDUSvr4MFL2B7K8HUbT45Ei4rf.jpg'),
(166427, 11809, 'Molang S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/510404.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/asluN9oBTWPnQOrzK3pMGIjh3hi.jpg'),
(166428, 11809, 'Molang S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/510405.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oWIIz3UNleT6e5vmMWyGFdFrD5y.jpg'),
(166429, 11809, 'Molang S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/510406.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vNY5EDnNBGcO5oSNY3tcYqnGfsu.jpg'),
(166430, 11809, 'Molang S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/510407.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yuQ3Uv6XlbiWYhi4vquC4F8ihO6.jpg'),
(166431, 11809, 'Molang S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/510408.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b4YOsTvGhOCCqy77SoUXSb2yBNE.jpg'),
(166432, 11809, 'Molang S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/510409.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8dkJzx7S3hNvIFi8M2gfUP9gUyd.jpg'),
(166433, 11809, 'Molang S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/510410.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/evUlWFs2QQEIu0qGQtKXFWzxflT.jpg'),
(166434, 11809, 'Molang S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/510411.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1g0TKCeyAriYWqNVo97sK2j9PuZ.jpg'),
(166435, 11809, 'Molang S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/510412.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oddLMlSUXiGwh5tbjcZPoOAZG9O.jpg'),
(166436, 11810, 'Molang S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/510413.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1Sc2zCWPpeNEd3JuxRHaMrTqcXJ.jpg'),
(166437, 11810, 'Molang S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/510414.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d2f0WElRIczhPtnONPS3GpcPyKM.jpg'),
(166438, 11810, 'Molang S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/510415.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o5M1sVPfpPrsR8iM8hjkblOkInu.jpg'),
(166439, 11810, 'Molang S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/510416.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c2rRw98I1Q5Q9vIooXiV5EaQAeq.jpg'),
(166440, 11810, 'Molang S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/510417.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sxwNrz91sRcGjKqeNUJGfAGscy2.jpg'),
(166441, 11810, 'Molang S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/510418.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ahONdwHhHpJN4nWvfPpE3qDgW0B.jpg'),
(166442, 11810, 'Molang S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/510419.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h9Lm5My3SymjhVJAKhaxvbZgFXH.jpg'),
(166443, 11810, 'Molang S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/510420.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/16Mdypa87DRXg2xMZXlrT0DmseD.jpg'),
(166444, 11810, 'Molang S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/510421.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/orNbqfQgBtt7YLPlVeKn8pbH4og.jpg'),
(166445, 11810, 'Molang S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/510422.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/en8YIG82wUgIyQXJPh5XIBMIzCD.jpg'),
(166446, 11810, 'Molang S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/510423.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gCXwCHZMUby22ki1jEBE9AkMbO1.jpg'),
(166447, 11810, 'Molang S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/510424.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pcWaRHMCsikbqRuvmDhmnsSNCj1.jpg'),
(166448, 11810, 'Molang S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/510425.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1FDDnNpFNGj1KCqMUmYBrKstfvS.jpg'),
(166449, 11811, 'Molang S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/510426.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qKR31TV2ZqqUb2gqCFtRSzZpNfR.jpg'),
(166450, 11811, 'Molang S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/510427.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/F0jMu9HlMrjmIlhlO5gqI9y1nr.jpg'),
(166451, 11811, 'Molang S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/510428.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pVmGOQAtGIn2b0DAaLCj8Haexim.jpg'),
(166452, 11811, 'Molang S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/510429.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uCwceWSU1AibiuVraKUpC7rCz5d.jpg'),
(166453, 11811, 'Molang S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/510430.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4nF3gEubZdyGsq1TiFhSv46asHO.jpg'),
(166454, 11811, 'Molang S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/510431.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fvCgqluIctu1FFBsydUrwH9eKPV.jpg'),
(166455, 11811, 'Molang S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/510432.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eAAkf3Wb4gADftL0hfLwOJ2JHZt.jpg'),
(166456, 11811, 'Molang S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/510433.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uzpzzSlwdyUsFr7Al7xMJHW6dL2.jpg'),
(166457, 11811, 'Molang S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/510434.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4HytXTCxklcpT6JE2I5EIDTvoW5.jpg'),
(166458, 11811, 'Molang S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/510435.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eD2rNPAf7vgqnMcjBtU2kzZvCbM.jpg'),
(166459, 11811, 'Molang S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/510436.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wHuYWc8qVLf97biNXP4rBnK9Zsj.jpg'),
(166460, 11811, 'Molang S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/510437.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mZkePP4NslyM6y4Fwy7Fp4DCxGd.jpg'),
(166461, 11811, 'Molang S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/510438.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vXEi7xxSR9CO97sHCdgf0nFVHKI.jpg'),
(166462, 11811, 'Molang S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/510439.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7SfvlY1F4AyQ854e6tlACPCJMRj.jpg'),
(166463, 11811, 'Molang S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/510440.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9cHS6vINKPiusIqrLNXxTRWIhcy.jpg'),
(166464, 11811, 'Molang S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/510441.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8gnS3TiaVKOqouC9fsN3GQyif67.jpg'),
(166465, 11811, 'Molang S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/510442.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xb8BaV4uw5CIpsSdt3SPlG5fV6K.jpg'),
(166466, 11811, 'Molang S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/510443.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qpzdP9zIDEU0JKuMaocx7iQ9g7m.jpg'),
(166467, 11811, 'Molang S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/510444.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bdaVejkzkM06TnPaxHvks9Bx3UA.jpg'),
(166468, 11811, 'Molang S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/510445.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pWv2jv2fgYkSSSi8cmhUXyKfSSF.jpg'),
(166469, 11811, 'Molang S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/510446.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lZPUqFw8yiX9mDmwYvyBO67ya2B.jpg'),
(166470, 11811, 'Molang S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/510447.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fRAOVFSTj0WwR0mOg0hPOnI8NUP.jpg'),
(166471, 11811, 'Molang S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/510448.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1jeLPR7yeYvjrkgVdN1muPiGb9N.jpg'),
(166472, 11811, 'Molang S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/510449.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8d6GtoQKevqHbVx4MFNR2CV6Mn1.jpg'),
(166473, 11811, 'Molang S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/510450.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1NoLwdLh3rS9imYVWF0X0VZfdEk.jpg'),
(166474, 11811, 'Molang S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/510451.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hXtQ3b4QvVNmYi0CetbHW8JeAjQ.jpg'),
(166475, 11811, 'Molang S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/510452.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vp2IIfei22qz78anPlvAFy3bKI9.jpg'),
(166476, 11811, 'Molang S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/510453.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1BqR5oh5oYBO4xaXaUVj3fDrHF8.jpg'),
(166477, 11811, 'Molang S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/510454.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s5vQXhd6K6NoaqjVSw7plr04li9.jpg'),
(166478, 11811, 'Molang S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/510455.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vx0COMFJE00bSqyzpJXR3A9TiUU.jpg'),
(166479, 11811, 'Molang S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/510456.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mZWqYuD3Q0T0rkmaO685Hpt8THO.jpg'),
(166480, 11811, 'Molang S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/510457.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/efZbXrwDbJsDWaljJfzm8GudppI.jpg'),
(166481, 11811, 'Molang S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/510458.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8Dwuhqyfg3eh5RWNrcoZTwetPIu.jpg'),
(166482, 11811, 'Molang S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/510459.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wQxFVhyI6hICvj3NRJttrmTVods.jpg'),
(166483, 11811, 'Molang S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/510460.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lTGycNR6ErNJPW7CQaxdfk0Aa8B.jpg'),
(166484, 11811, 'Molang S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/510461.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pHQa1j7rsDRw8IicCbijY2DgJdE.jpg'),
(166485, 11811, 'Molang S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/510462.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yWnLBhYIV0Ja4CQQ4HlFtwAfQ7Q.jpg'),
(166486, 11811, 'Molang S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/510463.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3hdM4OGiCFexSRWa3pXcnzOZxg7.jpg'),
(166487, 11811, 'Molang S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/510464.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hr9KeUNJIUDLxkFMFHdRXzJfLmg.jpg'),
(166488, 11811, 'Molang S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/510465.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qTDOLklJC1yRTSSKGwmBBGGLclj.jpg'),
(166489, 11811, 'Molang S03 E41', 'http://sinalprivado.info:80/series/1533784/1533784/510466.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7JvR7xBh1Z6rONfOGFLDFKKo5hu.jpg'),
(166490, 11811, 'Molang S03 E42', 'http://sinalprivado.info:80/series/1533784/1533784/510467.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/80mMzUB1UYTLYqG8RqhcrujUj8T.jpg'),
(166491, 11811, 'Molang S03 E43', 'http://sinalprivado.info:80/series/1533784/1533784/510468.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iVY8jIA2qBVmddKUeaz5dJ32kUI.jpg'),
(166492, 11811, 'Molang S03 E44', 'http://sinalprivado.info:80/series/1533784/1533784/510469.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qoUpVkNHp5MnDlchZ1nQ3qF5xVI.jpg'),
(166493, 11811, 'Molang S03 E45', 'http://sinalprivado.info:80/series/1533784/1533784/510470.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2sjrQI6FaLh855JRCjlyBQOcosQ.jpg'),
(166494, 11811, 'Molang S03 E46', 'http://sinalprivado.info:80/series/1533784/1533784/510471.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3MzjEynpaxVUBtGi0fFRZRIW3Su.jpg'),
(166495, 11811, 'Molang S03 E47', 'http://sinalprivado.info:80/series/1533784/1533784/510472.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/trP9qD3koWlMALCl8dxBxUYeCbR.jpg'),
(166496, 11811, 'Molang S03 E48', 'http://sinalprivado.info:80/series/1533784/1533784/510473.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/In5r8j2cqt4ZIMq0mJLwv4o7V0.jpg'),
(166497, 11811, 'Molang S03 E49', 'http://sinalprivado.info:80/series/1533784/1533784/510474.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oNh4Ol0BLwV6p39r4L0awz1HKoD.jpg'),
(166498, 11811, 'Molang S03 E50', 'http://sinalprivado.info:80/series/1533784/1533784/510475.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bS2noh1TiOqExvUbz3wmGGqIVfs.jpg'),
(166499, 11811, 'Molang S03 E51', 'http://sinalprivado.info:80/series/1533784/1533784/510476.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mSblhYzsk2UdCmuDJJH6NhCZsUx.jpg'),
(166500, 11811, 'Molang S03 E52', 'http://sinalprivado.info:80/series/1533784/1533784/510477.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yFT66GaoBCGd4V9ajU5azZduZvZ.jpg'),
(166501, 11812, 'Molang S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/510478.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yaxPYysn41DeT9yxJ8twChk05Xz.jpg'),
(166502, 11812, 'Molang S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/510479.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AviSiEqYYal9YGZi6jIeDsp2hud.jpg'),
(166503, 11812, 'Molang S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/510480.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ay1yBrw2xdEhPdWxSrdykI6uLit.jpg'),
(166504, 11812, 'Molang S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/510481.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6WWxhuTRJD9ByJ61SAwn4ZagzRw.jpg'),
(166505, 11812, 'Molang S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/510482.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vDYuynSatuj0mjw4etR2V7E7NxN.jpg'),
(166506, 11812, 'Molang S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/510483.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dJV64TmVlvo83XIHFfcoRRmSuQ1.jpg'),
(166507, 11812, 'Molang S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/510484.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qHzdnXWE6dbJXzoo39dqrEApyeu.jpg'),
(166508, 11812, 'Molang S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/510485.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rA3H9JarwS9cytlYx60nM3wWFJx.jpg'),
(166509, 11812, 'Molang S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/510486.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sQFVd235uS5CpxZmEp0AR4B1ihM.jpg'),
(166510, 11812, 'Molang S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/510487.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8G32Ez5zn1vhYH8owyMK3YnxsJA.jpg'),
(166511, 11812, 'Molang S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/510488.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eYP4iR9vweTJBPgvveg4VMq1RG4.jpg'),
(166512, 11812, 'Molang S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/510489.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aWbPZV38yfCXxQn4dpsb2yWAj8b.jpg'),
(166513, 11812, 'Molang S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/510490.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hqsraU1YiD3pineT78nCKm1dHuD.jpg'),
(166514, 11812, 'Molang S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/510491.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hENR0WhuuFj5QiUKPsFsGT0q4ri.jpg'),
(166515, 11812, 'Molang S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/510492.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/glRwJ2esWki96TDYTt0akzKt2bI.jpg'),
(166516, 11812, 'Molang S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/510493.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jFZBtFVXWSIeZr4278K3FSukQxH.jpg'),
(166517, 11812, 'Molang S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/510494.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/deq0cE62r4As152w5ITHE5Zlaqe.jpg'),
(166518, 11812, 'Molang S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/510495.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ln9isG9Y0XXABEK51a3PYBi8n9E.jpg'),
(166519, 11812, 'Molang S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/510496.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rIzzpmK0cJ2nJmI73SnFosZvY12.jpg'),
(166520, 11812, 'Molang S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/510497.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/343ke6xYtkG8NqjfTYldKrIkatL.jpg'),
(166521, 11812, 'Molang S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/510498.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mYIEILMSqpp5SDSq2OGJ1VNEEej.jpg'),
(166522, 11812, 'Molang S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/510499.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qSrnfq5dMxj47BoXfIbd8ojS2dj.jpg'),
(166523, 11812, 'Molang S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/510500.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wUHIbpswMTJAz5laNmgt8gAQtOU.jpg'),
(166524, 11812, 'Molang S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/510501.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z7MQoBvGuBJ6mTdoWTsi4hJiTL2.jpg'),
(166525, 11812, 'Molang S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/510502.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jdYIkgVsiauncMVw7Fpd72RaSUU.jpg'),
(166526, 11812, 'Molang S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/510503.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r8it1JDEQdHtqXjPBQV5koAEox4.jpg'),
(166527, 11812, 'Molang S04 E27', 'http://sinalprivado.info:80/series/1533784/1533784/510504.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xr0PadGnI4FQic8OumrMtPHDPN3.jpg'),
(166528, 11812, 'Molang S04 E28', 'http://sinalprivado.info:80/series/1533784/1533784/510505.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yO6Ht3lDPECivmTCJM3xath4ScD.jpg'),
(166529, 11812, 'Molang S04 E29', 'http://sinalprivado.info:80/series/1533784/1533784/510506.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lRjNPTtkuwN0hCYgR6pISRcXnMD.jpg'),
(166530, 11812, 'Molang S04 E30', 'http://sinalprivado.info:80/series/1533784/1533784/510507.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iC7I5ykPA1pDCjutRc61J3hGaKk.jpg'),
(166531, 11812, 'Molang S04 E31', 'http://sinalprivado.info:80/series/1533784/1533784/510508.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i1cfg9T3m1odvMeZvbJhrORVUVT.jpg'),
(166532, 11812, 'Molang S04 E32', 'http://sinalprivado.info:80/series/1533784/1533784/510509.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2gcftjGfOeHP3IbKY7Kt0nLoG4X.jpg'),
(166533, 11812, 'Molang S04 E33', 'http://sinalprivado.info:80/series/1533784/1533784/510510.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qzTBCGH8FegnSxPBDDf4WaSSrSf.jpg'),
(166534, 11812, 'Molang S04 E34', 'http://sinalprivado.info:80/series/1533784/1533784/510511.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oj1IS179htHsaIVesaPgZneFHBg.jpg'),
(166535, 11812, 'Molang S04 E35', 'http://sinalprivado.info:80/series/1533784/1533784/510512.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d23CkKq9GdC7zexULmCixBv9Zp2.jpg'),
(166536, 11812, 'Molang S04 E36', 'http://sinalprivado.info:80/series/1533784/1533784/510513.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nk1PEFlUElMNguSpdAtJ4kESvIU.jpg'),
(166537, 11812, 'Molang S04 E37', 'http://sinalprivado.info:80/series/1533784/1533784/510514.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iMFvTYGaE2HNsDhaulziuiLwfEx.jpg'),
(166538, 11812, 'Molang S04 E38', 'http://sinalprivado.info:80/series/1533784/1533784/510515.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d3wLnKpMO9ZwlPn20GIrNsJnZgK.jpg'),
(166539, 11812, 'Molang S04 E39', 'http://sinalprivado.info:80/series/1533784/1533784/510516.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vZLY4tQ8KUl5Vdq5wd74SYKw022.jpg'),
(166540, 11812, 'Molang S04 E40', 'http://sinalprivado.info:80/series/1533784/1533784/510517.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7iitNJSMD6lEOIAEAUoUmkz4qSy.jpg'),
(166541, 11812, 'Molang S04 E41', 'http://sinalprivado.info:80/series/1533784/1533784/510518.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/khKNIcYqr7Q2Hspbiq7uVbpZQYp.jpg'),
(166542, 11812, 'Molang S04 E42', 'http://sinalprivado.info:80/series/1533784/1533784/510519.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kK4etBPA62uvsombRZPIk0bBRG8.jpg'),
(166543, 11812, 'Molang S04 E43', 'http://sinalprivado.info:80/series/1533784/1533784/510520.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4VWZVXrIcLlviBu7lzlaiit9cX6.jpg'),
(166544, 11812, 'Molang S04 E44', 'http://sinalprivado.info:80/series/1533784/1533784/510521.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4g7DFZpPfwBotcGejKZebTCzSgK.jpg'),
(166545, 11812, 'Molang S04 E45', 'http://sinalprivado.info:80/series/1533784/1533784/510522.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oOVVMQlV9lahrngjO9dBBXWRNMt.jpg'),
(166546, 11812, 'Molang S04 E46', 'http://sinalprivado.info:80/series/1533784/1533784/510523.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/30yQNDg1l030I6LF3rpDSksWXvn.jpg'),
(166547, 11812, 'Molang S04 E47', 'http://sinalprivado.info:80/series/1533784/1533784/510524.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xyvUjV6JvLlGjkU21BbasKSzrro.jpg'),
(166548, 11812, 'Molang S04 E48', 'http://sinalprivado.info:80/series/1533784/1533784/510525.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zk57LwOh938l7la7TPluaL3bOP2.jpg'),
(166549, 11812, 'Molang S04 E49', 'http://sinalprivado.info:80/series/1533784/1533784/510526.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cAOaJH037lOLwgpNBfXllmgzH6P.jpg'),
(166550, 11812, 'Molang S04 E50', 'http://sinalprivado.info:80/series/1533784/1533784/510527.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3MUw57GnOntCPJpVJ41Cx9dHHqu.jpg'),
(166551, 11812, 'Molang S04 E51', 'http://sinalprivado.info:80/series/1533784/1533784/510528.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1wvAKbpDr4JtShM5Va7cykZyEl5.jpg'),
(166552, 11812, 'Molang S04 E52', 'http://sinalprivado.info:80/series/1533784/1533784/510529.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yYZeu93dE4K08Ltic5svH0EV7lk.jpg'),
(166553, 11813, 'Segundas Intencoes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/510392.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ueYUfWjaJjq0sO6qrWV8ym4D9CB.jpg'),
(166554, 11813, 'Segundas Intencoes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/510393.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lnBiKAgfKQang2F3MJmnZ0BlkKc.jpg'),
(166555, 11813, 'Segundas Intencoes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/510394.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jMjFtnPcUAk318VVWT0O6zxCUna.jpg'),
(166556, 11813, 'Segundas Intencoes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/510395.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bkSCrGXiFxpYccAuNIf0bBsounM.jpg'),
(166557, 11813, 'Segundas Intencoes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/510396.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hnMvigr9qMSey5MjYSyfanXDFLq.jpg'),
(166558, 11813, 'Segundas Intencoes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/510397.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kUUx0dDM40XW9A41By0F3YqFcls.jpg'),
(166559, 11813, 'Segundas Intencoes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/510398.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3XzF9vUORsEAmr78ThXvTDWvT78.jpg'),
(166560, 11813, 'Segundas Intencoes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/510399.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pIbF5wtXfiEuDl2VYTZ7SnSmuGl.jpg'),
(166561, 11814, 'Spinners Vivendo no Limite S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/510384.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fh6KWln7fAZRZinAt0MhY5ysl1j.jpg'),
(166562, 11814, 'Spinners Vivendo no Limite S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/510385.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gYKyz0S5B2bV4mAvWRLkfrBnRTq.jpg'),
(166563, 11814, 'Spinners Vivendo no Limite S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/510386.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nIAbOMyIGmmy0deNkcahxXH92eH.jpg'),
(166564, 11814, 'Spinners Vivendo no Limite S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/510387.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yDH9RLdaSvqyrYyBk0DE26ry9v8.jpg'),
(166565, 11814, 'Spinners Vivendo no Limite S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/510388.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vMAlpLx3nXkIdrLvfKd2O7g1vKL.jpg'),
(166566, 11814, 'Spinners Vivendo no Limite S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/510389.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7p807DF0wthtj9Bhnf37uIA6HdH.jpg'),
(166567, 11814, 'Spinners Vivendo no Limite S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/510390.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yYlMIw7doicEq5JwjPo2NTaHaNU.jpg'),
(166568, 11814, 'Spinners Vivendo no Limite S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/510391.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fv3YvjLxaAVguwXvTWAxxa9Oesc.jpg'),
(166569, 11815, 'Tokyo Override S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/510378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UGLNOXxrHSO5ftqm0HRQmv2FGk.jpg'),
(166570, 11815, 'Tokyo Override S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/510379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UGLNOXxrHSO5ftqm0HRQmv2FGk.jpg'),
(166571, 11815, 'Tokyo Override S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/510380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UGLNOXxrHSO5ftqm0HRQmv2FGk.jpg'),
(166572, 11815, 'Tokyo Override S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/510381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UGLNOXxrHSO5ftqm0HRQmv2FGk.jpg'),
(166573, 11815, 'Tokyo Override S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/510382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UGLNOXxrHSO5ftqm0HRQmv2FGk.jpg'),
(166574, 11815, 'Tokyo Override S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/510383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7UGLNOXxrHSO5ftqm0HRQmv2FGk.jpg'),
(166575, 11816, 'True Beauty S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/510365.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fekSKRH6uxndjwqUoemA0ZSTdzP.jpg'),
(166576, 11816, 'True Beauty S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/510366.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eYwLrZGyXfPefYQCTA2aGzk9ASp.jpg'),
(166577, 11816, 'True Beauty S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/510367.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p5yRxX6ssILLVH5pMgqwaz9Eou1.jpg'),
(166578, 11816, 'True Beauty S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/510368.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/72WFnZcM6KVQXzedrvd82iqPStr.jpg'),
(166579, 11816, 'True Beauty S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/510369.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w8DCfL1qQIq0gIRViWmfqMWc0nR.jpg'),
(166580, 11816, 'True Beauty S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/510370.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lNMt1efMPxLnOFyy0ut04szVGJW.jpg'),
(166581, 11816, 'True Beauty S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/510371.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hjvcTJpa2QFqOXkDulgOMjHkQBt.jpg'),
(166582, 11816, 'True Beauty S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/510372.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6XzmF4ly98hEDVf2VL6s8Na3oC2.jpg'),
(166583, 11816, 'True Beauty S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/510373.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cmph9p4k1f8csjr5XiIXhlGVNPn.jpg'),
(166584, 11816, 'True Beauty S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/510374.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4hYHjggWH1OmFO7TA4m3YFYIZ10.jpg'),
(166585, 11816, 'True Beauty S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/510375.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zhdUheTopeI5ZTxQ3zZHFSH3ZJZ.jpg'),
(166586, 11816, 'True Beauty S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/510376.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m305jwiOPGyk1fhlJnFasqHSr0B.jpg'),
(166587, 11816, 'True Beauty S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/510377.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rgXYldSo9YPZnPe8gY2C2rJiVaw.jpg'),
(166588, 11817, 'Um Espiao Infiltrado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/510357.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pwKM386LEXQjfPrDdaqqFBriIPp.jpg'),
(166589, 11817, 'Um Espiao Infiltrado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/510358.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dwCi7PbTD7Zu8E1cn97fxFYnNk.jpg'),
(166590, 11817, 'Um Espiao Infiltrado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/510359.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6AA5tRj1y12bdBxcz61DNj1IqJ0.jpg'),
(166591, 11817, 'Um Espiao Infiltrado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/510360.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mTwyTgnDQIQ4OvY76xwxjaG9H7I.jpg'),
(166592, 11817, 'Um Espiao Infiltrado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/510361.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z5JcnKxhvmdsfCV3kJBny7ACeuC.jpg'),
(166593, 11817, 'Um Espiao Infiltrado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/510362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3yYX4MBbmWFYCBF2j00FKqzLAQs.jpg'),
(166594, 11817, 'Um Espiao Infiltrado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/510363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3yYX4MBbmWFYCBF2j00FKqzLAQs.jpg'),
(166595, 11817, 'Um Espiao Infiltrado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/510364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3yYX4MBbmWFYCBF2j00FKqzLAQs.jpg'),
(166596, 11818, 'A Antartida [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/509029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wah4DZNRyFdwyA4VuEgLbOOvQoW.jpg'),
(166597, 11818, 'A Antartida [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/509030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wah4DZNRyFdwyA4VuEgLbOOvQoW.jpg'),
(166598, 11818, 'A Antartida [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/509031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wah4DZNRyFdwyA4VuEgLbOOvQoW.jpg'),
(166599, 11818, 'A Antartida [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/509032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wah4DZNRyFdwyA4VuEgLbOOvQoW.jpg'),
(166600, 11818, 'A Antartida [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/509033.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wah4DZNRyFdwyA4VuEgLbOOvQoW.jpg'),
(166601, 11818, 'A Antartida [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/509034.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wah4DZNRyFdwyA4VuEgLbOOvQoW.jpg'),
(166602, 11818, 'A Antartida [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/509035.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wah4DZNRyFdwyA4VuEgLbOOvQoW.jpg'),
(166603, 11818, 'A Antartida [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/509036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wah4DZNRyFdwyA4VuEgLbOOvQoW.jpg'),
(166604, 11818, 'A Antartida [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/509037.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wah4DZNRyFdwyA4VuEgLbOOvQoW.jpg'),
(166605, 11818, 'A Antartida [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/509038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wah4DZNRyFdwyA4VuEgLbOOvQoW.jpg'),
(166606, 11819, 'A Brava Yong Su Jeong [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508708.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qogo0mB41s96B3CZfguBKTluoQZ.jpg'),
(166607, 11819, 'A Brava Yong Su Jeong [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508709.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uWhOlVAFsIR0uEfIOBs60o5kWzj.jpg'),
(166608, 11819, 'A Brava Yong Su Jeong [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508710.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/23aUJUcm5t1IoHTYIqNzeX9vBtO.jpg'),
(166609, 11819, 'A Brava Yong Su Jeong [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508711.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166610, 11819, 'A Brava Yong Su Jeong [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508712.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166611, 11819, 'A Brava Yong Su Jeong [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508713.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166612, 11819, 'A Brava Yong Su Jeong [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166613, 11819, 'A Brava Yong Su Jeong [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/508715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166614, 11819, 'A Brava Yong Su Jeong [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/508716.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166615, 11819, 'A Brava Yong Su Jeong [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/508717.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166616, 11819, 'A Brava Yong Su Jeong [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/508718.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166617, 11819, 'A Brava Yong Su Jeong [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/508719.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166618, 11819, 'A Brava Yong Su Jeong [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/508720.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166619, 11819, 'A Brava Yong Su Jeong [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/508721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166620, 11819, 'A Brava Yong Su Jeong [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/508722.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166621, 11819, 'A Brava Yong Su Jeong [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/508723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166622, 11819, 'A Brava Yong Su Jeong [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/508724.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166623, 11819, 'A Brava Yong Su Jeong [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/508725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166624, 11819, 'A Brava Yong Su Jeong [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/508726.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166625, 11819, 'A Brava Yong Su Jeong [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/508727.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166626, 11819, 'A Brava Yong Su Jeong [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/508728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166627, 11819, 'A Brava Yong Su Jeong [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/508729.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(166628, 11819, 'A Brava Yong Su Jeong [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/508730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166629, 11819, 'A Brava Yong Su Jeong [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/508731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166630, 11819, 'A Brava Yong Su Jeong [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/508732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166631, 11819, 'A Brava Yong Su Jeong [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/508733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166632, 11819, 'A Brava Yong Su Jeong [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/508734.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166633, 11819, 'A Brava Yong Su Jeong [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/508735.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166634, 11819, 'A Brava Yong Su Jeong [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/508736.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166635, 11819, 'A Brava Yong Su Jeong [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/508737.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166636, 11819, 'A Brava Yong Su Jeong [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/508738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166637, 11819, 'A Brava Yong Su Jeong [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/508739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166638, 11819, 'A Brava Yong Su Jeong [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/508740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166639, 11819, 'A Brava Yong Su Jeong [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/508741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166640, 11819, 'A Brava Yong Su Jeong [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/508742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166641, 11819, 'A Brava Yong Su Jeong [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/508743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166642, 11819, 'A Brava Yong Su Jeong [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/508744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166643, 11819, 'A Brava Yong Su Jeong [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/508745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166644, 11819, 'A Brava Yong Su Jeong [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/508746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166645, 11819, 'A Brava Yong Su Jeong [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/508747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166646, 11819, 'A Brava Yong Su Jeong [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/508748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166647, 11819, 'A Brava Yong Su Jeong [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/508749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166648, 11819, 'A Brava Yong Su Jeong [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/508750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166649, 11819, 'A Brava Yong Su Jeong [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/508751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166650, 11819, 'A Brava Yong Su Jeong [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/508752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166651, 11819, 'A Brava Yong Su Jeong [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/508753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166652, 11819, 'A Brava Yong Su Jeong [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/508754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166653, 11819, 'A Brava Yong Su Jeong [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/508755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166654, 11819, 'A Brava Yong Su Jeong [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/508756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166655, 11819, 'A Brava Yong Su Jeong [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/508757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166656, 11819, 'A Brava Yong Su Jeong [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/508758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166657, 11819, 'A Brava Yong Su Jeong [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/508759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166658, 11819, 'A Brava Yong Su Jeong [L] S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/508760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166659, 11819, 'A Brava Yong Su Jeong [L] S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/508761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166660, 11819, 'A Brava Yong Su Jeong [L] S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/508762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166661, 11819, 'A Brava Yong Su Jeong [L] S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/508763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166662, 11819, 'A Brava Yong Su Jeong [L] S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/508764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166663, 11819, 'A Brava Yong Su Jeong [L] S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/508765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166664, 11819, 'A Brava Yong Su Jeong [L] S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/508766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166665, 11819, 'A Brava Yong Su Jeong [L] S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/508767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166666, 11819, 'A Brava Yong Su Jeong [L] S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/508768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166667, 11819, 'A Brava Yong Su Jeong [L] S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/508769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166668, 11819, 'A Brava Yong Su Jeong [L] S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/508770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166669, 11819, 'A Brava Yong Su Jeong [L] S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/508771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166670, 11819, 'A Brava Yong Su Jeong [L] S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/508772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166671, 11819, 'A Brava Yong Su Jeong [L] S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/508773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166672, 11819, 'A Brava Yong Su Jeong [L] S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/508774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166673, 11819, 'A Brava Yong Su Jeong [L] S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/508775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166674, 11819, 'A Brava Yong Su Jeong [L] S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/508776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166675, 11819, 'A Brava Yong Su Jeong [L] S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/508777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166676, 11819, 'A Brava Yong Su Jeong [L] S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/508778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166677, 11819, 'A Brava Yong Su Jeong [L] S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/508779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166678, 11819, 'A Brava Yong Su Jeong [L] S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/508780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166679, 11819, 'A Brava Yong Su Jeong [L] S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/508781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166680, 11819, 'A Brava Yong Su Jeong [L] S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/508782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166681, 11819, 'A Brava Yong Su Jeong [L] S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/508783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166682, 11819, 'A Brava Yong Su Jeong [L] S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/508784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166683, 11819, 'A Brava Yong Su Jeong [L] S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/508785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166684, 11819, 'A Brava Yong Su Jeong [L] S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/508786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166685, 11819, 'A Brava Yong Su Jeong [L] S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/508787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166686, 11819, 'A Brava Yong Su Jeong [L] S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/508788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166687, 11819, 'A Brava Yong Su Jeong [L] S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/508789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166688, 11819, 'A Brava Yong Su Jeong [L] S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/508790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166689, 11819, 'A Brava Yong Su Jeong [L] S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/508791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166690, 11819, 'A Brava Yong Su Jeong [L] S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/508792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166691, 11819, 'A Brava Yong Su Jeong [L] S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/508793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166692, 11819, 'A Brava Yong Su Jeong [L] S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/508794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166693, 11819, 'A Brava Yong Su Jeong [L] S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/508795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166694, 11819, 'A Brava Yong Su Jeong [L] S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/508796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166695, 11819, 'A Brava Yong Su Jeong [L] S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/508797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166696, 11819, 'A Brava Yong Su Jeong [L] S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/508798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166697, 11819, 'A Brava Yong Su Jeong [L] S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/508799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166698, 11819, 'A Brava Yong Su Jeong [L] S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/508800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166699, 11819, 'A Brava Yong Su Jeong [L] S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/508801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166700, 11819, 'A Brava Yong Su Jeong [L] S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/508802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166701, 11819, 'A Brava Yong Su Jeong [L] S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/508803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166702, 11819, 'A Brava Yong Su Jeong [L] S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/508804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166703, 11819, 'A Brava Yong Su Jeong [L] S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/508805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166704, 11819, 'A Brava Yong Su Jeong [L] S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/508806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166705, 11819, 'A Brava Yong Su Jeong [L] S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/508807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166706, 11819, 'A Brava Yong Su Jeong [L] S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/508808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166707, 11819, 'A Brava Yong Su Jeong [L] S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/508809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166708, 11819, 'A Brava Yong Su Jeong [L] S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/508810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166709, 11819, 'A Brava Yong Su Jeong [L] S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/508811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166710, 11819, 'A Brava Yong Su Jeong [L] S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/508812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166711, 11819, 'A Brava Yong Su Jeong [L] S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/508813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166712, 11819, 'A Brava Yong Su Jeong [L] S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/508814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166713, 11819, 'A Brava Yong Su Jeong [L] S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/508815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166714, 11819, 'A Brava Yong Su Jeong [L] S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/508816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166715, 11819, 'A Brava Yong Su Jeong [L] S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/508817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166716, 11819, 'A Brava Yong Su Jeong [L] S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/508818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166717, 11819, 'A Brava Yong Su Jeong [L] S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/508819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166718, 11819, 'A Brava Yong Su Jeong [L] S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/508820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166719, 11819, 'A Brava Yong Su Jeong [L] S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/508821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166720, 11819, 'A Brava Yong Su Jeong [L] S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/508822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166721, 11819, 'A Brava Yong Su Jeong [L] S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/508823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166722, 11819, 'A Brava Yong Su Jeong [L] S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/508824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166723, 11819, 'A Brava Yong Su Jeong [L] S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/508825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166724, 11819, 'A Brava Yong Su Jeong [L] S01 E119', 'http://sinalprivado.info:80/series/1533784/1533784/508826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166725, 11819, 'A Brava Yong Su Jeong [L] S01 E120', 'http://sinalprivado.info:80/series/1533784/1533784/508827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166726, 11819, 'A Brava Yong Su Jeong [L] S01 E121', 'http://sinalprivado.info:80/series/1533784/1533784/508828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166727, 11819, 'A Brava Yong Su Jeong [L] S01 E122', 'http://sinalprivado.info:80/series/1533784/1533784/508829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166728, 11819, 'A Brava Yong Su Jeong [L] S01 E123', 'http://sinalprivado.info:80/series/1533784/1533784/508830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166729, 11819, 'A Brava Yong Su Jeong [L] S01 E124', 'http://sinalprivado.info:80/series/1533784/1533784/508831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wTl2C0dFJLSI89obqq9AA1vADoc.jpg'),
(166730, 11820, 'A Condenada [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/509006.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1DJDmOoZamDfDNpKTdp5KMzJWoJ.jpg'),
(166731, 11820, 'A Condenada [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/509007.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/anXnkYvNA7PujdT15xPNXC2YbXz.jpg'),
(166732, 11820, 'A Condenada [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/509008.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yDBBtSL7tdD3N6cJVozqrf0WdJP.jpg'),
(166733, 11820, 'A Condenada [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/509009.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5UKuWzLrheu942CLfHqy9OSn6vc.jpg'),
(166734, 11820, 'A Condenada [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/509010.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uK2UerNk6WcTUuHY4AqrGe939Wl.jpg'),
(166735, 11820, 'A Condenada [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/509011.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rIspvBzV0pA4yyAJ78C2ddTVyvI.jpg'),
(166736, 11820, 'A Condenada [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/509012.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kCGEXwCPOJHxMNi8XQ2C13wHAIu.jpg'),
(166737, 11820, 'A Condenada [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/509013.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sROsE5HoWOsr9t9NKCQrlizMhmQ.jpg'),
(166738, 11821, 'A Condenada [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/509014.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/anypYvvCr7ewDlOiBNCB0uzJ9oM.jpg'),
(166739, 11821, 'A Condenada [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/509015.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iZA6alpMMMdRnq8NM39bVUmHfro.jpg'),
(166740, 11821, 'A Condenada [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/509016.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/17sM3GIP1inffg9Qq5UqJfTTqDO.jpg'),
(166741, 11821, 'A Condenada [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/509017.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oWMC2MCjH0rqTXZriOEVuegvLuw.jpg'),
(166742, 11821, 'A Condenada [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/509018.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zGsrQuZmeqJlxVXYJtjo4UNQvDW.jpg'),
(166743, 11821, 'A Condenada [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/509019.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vB0KZBcdoTYFziw35OjwYjGpufW.jpg'),
(166744, 11821, 'A Condenada [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/509020.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bwNb0qlejmksTqyEk7Gvi0nXlyn.jpg'),
(166745, 11821, 'A Condenada [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/509021.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/grX4U24LcFvd7jCMSCDASWievLE.jpg'),
(166746, 11822, 'A Condenada [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/509022.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4NxwtkvBbYJITO8oXg6cO1ngEjW.jpg'),
(166747, 11822, 'A Condenada [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/509023.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tWZPOvrsD4OZJ7CX51TMV1g4WqK.jpg'),
(166748, 11822, 'A Condenada [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/509024.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t0KJBX6qkwpcAU9OsHRPK2wDKhA.jpg'),
(166749, 11822, 'A Condenada [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/509025.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8C1KErth6ynYMIvRRqgM9aUo3DY.jpg'),
(166750, 11822, 'A Condenada [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/509026.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dHnt2XJFSWX2M9JhPgpvqr9lRmn.jpg'),
(166751, 11822, 'A Condenada [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/509027.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uASPClY8pX7pq5EziGEPc0OgcrJ.jpg'),
(166752, 11822, 'A Condenada [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/509028.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yfPjBKqZThhuOKHr46ZiSJAZ9iD.jpg'),
(166753, 11823, 'A Desesperada Sra Seon Ju [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/509004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166754, 11823, 'A Desesperada Sra Seon Ju [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/509005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166755, 11823, 'A Desesperada Sra Seon Ju [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166756, 11823, 'A Desesperada Sra Seon Ju [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524024.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166757, 11823, 'A Desesperada Sra Seon Ju [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524025.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166758, 11823, 'A Desesperada Sra Seon Ju [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166759, 11823, 'A Desesperada Sra Seon Ju [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166760, 11823, 'A Desesperada Sra Seon Ju [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166761, 11823, 'A Desesperada Sra Seon Ju [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166762, 11823, 'A Desesperada Sra Seon Ju [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166763, 11823, 'A Desesperada Sra Seon Ju [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524031.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166764, 11823, 'A Desesperada Sra Seon Ju [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166765, 11823, 'A Desesperada Sra Seon Ju [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/832230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166766, 11823, 'A Desesperada Sra Seon Ju [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/832231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166767, 11823, 'A Desesperada Sra Seon Ju [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/832232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166768, 11823, 'A Desesperada Sra Seon Ju [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/832233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166769, 11823, 'A Desesperada Sra Seon Ju [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/832234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166770, 11823, 'A Desesperada Sra Seon Ju [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/832235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166771, 11823, 'A Desesperada Sra Seon Ju [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/832236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166772, 11823, 'A Desesperada Sra Seon Ju [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/832237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166773, 11823, 'A Desesperada Sra Seon Ju [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/832238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166774, 11823, 'A Desesperada Sra Seon Ju [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/832239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166775, 11823, 'A Desesperada Sra Seon Ju [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/832240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166776, 11823, 'A Desesperada Sra Seon Ju [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/832241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166777, 11823, 'A Desesperada Sra Seon Ju [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/832242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166778, 11823, 'A Desesperada Sra Seon Ju [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/832243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166779, 11823, 'A Desesperada Sra Seon Ju [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/832244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166780, 11823, 'A Desesperada Sra Seon Ju [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/832245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166781, 11823, 'A Desesperada Sra Seon Ju [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/832246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166782, 11823, 'A Desesperada Sra Seon Ju [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/832247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166783, 11823, 'A Desesperada Sra Seon Ju [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/832248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166784, 11823, 'A Desesperada Sra Seon Ju [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/832249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166785, 11823, 'A Desesperada Sra Seon Ju [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/832250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166786, 11823, 'A Desesperada Sra Seon Ju [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/832251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166787, 11823, 'A Desesperada Sra Seon Ju [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/832252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166788, 11823, 'A Desesperada Sra Seon Ju [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/832253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166789, 11823, 'A Desesperada Sra Seon Ju [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/832254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166790, 11823, 'A Desesperada Sra Seon Ju [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/832255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166791, 11823, 'A Desesperada Sra Seon Ju [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/832256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166792, 11823, 'A Desesperada Sra Seon Ju [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/832257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166793, 11823, 'A Desesperada Sra Seon Ju [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/832258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166794, 11823, 'A Desesperada Sra Seon Ju [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/832259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166795, 11823, 'A Desesperada Sra Seon Ju [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/832260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166796, 11823, 'A Desesperada Sra Seon Ju [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/832261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166797, 11823, 'A Desesperada Sra Seon Ju [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/832262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166798, 11823, 'A Desesperada Sra Seon Ju [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/832263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166799, 11823, 'A Desesperada Sra Seon Ju [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/832264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166800, 11823, 'A Desesperada Sra Seon Ju [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/832265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166801, 11823, 'A Desesperada Sra Seon Ju [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/832266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166802, 11823, 'A Desesperada Sra Seon Ju [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/832267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166803, 11823, 'A Desesperada Sra Seon Ju [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/832268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166804, 11823, 'A Desesperada Sra Seon Ju [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/832269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166805, 11823, 'A Desesperada Sra Seon Ju [L] S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/832270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166806, 11823, 'A Desesperada Sra Seon Ju [L] S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/832271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166807, 11823, 'A Desesperada Sra Seon Ju [L] S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/832272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166808, 11823, 'A Desesperada Sra Seon Ju [L] S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/832273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166809, 11823, 'A Desesperada Sra Seon Ju [L] S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/832274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166810, 11823, 'A Desesperada Sra Seon Ju [L] S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/832275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166811, 11823, 'A Desesperada Sra Seon Ju [L] S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/832276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166812, 11823, 'A Desesperada Sra Seon Ju [L] S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/832277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166813, 11823, 'A Desesperada Sra Seon Ju [L] S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/832278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166814, 11823, 'A Desesperada Sra Seon Ju [L] S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/832279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166815, 11823, 'A Desesperada Sra Seon Ju [L] S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/832280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166816, 11823, 'A Desesperada Sra Seon Ju [L] S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/832281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166817, 11823, 'A Desesperada Sra Seon Ju [L] S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/832282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166818, 11823, 'A Desesperada Sra Seon Ju [L] S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/832283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166819, 11823, 'A Desesperada Sra Seon Ju [L] S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/832284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166820, 11823, 'A Desesperada Sra Seon Ju [L] S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/832285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166821, 11823, 'A Desesperada Sra Seon Ju [L] S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/832286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166822, 11823, 'A Desesperada Sra Seon Ju [L] S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/832287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166823, 11823, 'A Desesperada Sra Seon Ju [L] S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/832288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166824, 11823, 'A Desesperada Sra Seon Ju [L] S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/832289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166825, 11823, 'A Desesperada Sra Seon Ju [L] S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/832290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166826, 11823, 'A Desesperada Sra Seon Ju [L] S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/832291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166827, 11823, 'A Desesperada Sra Seon Ju [L] S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/832292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166828, 11823, 'A Desesperada Sra Seon Ju [L] S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/832293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166829, 11823, 'A Desesperada Sra Seon Ju [L] S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/832294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166830, 11823, 'A Desesperada Sra Seon Ju [L] S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/832295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166831, 11823, 'A Desesperada Sra Seon Ju [L] S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/832296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166832, 11823, 'A Desesperada Sra Seon Ju [L] S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/832297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166833, 11823, 'A Desesperada Sra Seon Ju [L] S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/832298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166834, 11823, 'A Desesperada Sra Seon Ju [L] S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/832299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166835, 11823, 'A Desesperada Sra Seon Ju [L] S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/832300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166836, 11823, 'A Desesperada Sra Seon Ju [L] S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/832301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166837, 11823, 'A Desesperada Sra Seon Ju [L] S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/832302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166838, 11823, 'A Desesperada Sra Seon Ju [L] S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/832303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166839, 11823, 'A Desesperada Sra Seon Ju [L] S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/832304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166840, 11823, 'A Desesperada Sra Seon Ju [L] S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/832305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166841, 11823, 'A Desesperada Sra Seon Ju [L] S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/832306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166842, 11823, 'A Desesperada Sra Seon Ju [L] S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/832307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166843, 11823, 'A Desesperada Sra Seon Ju [L] S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/832308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166844, 11823, 'A Desesperada Sra Seon Ju [L] S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/832309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166845, 11823, 'A Desesperada Sra Seon Ju [L] S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/832310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166846, 11823, 'A Desesperada Sra Seon Ju [L] S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/832311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166847, 11823, 'A Desesperada Sra Seon Ju [L] S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/832312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166848, 11823, 'A Desesperada Sra Seon Ju [L] S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/832313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166849, 11823, 'A Desesperada Sra Seon Ju [L] S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/832314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166850, 11823, 'A Desesperada Sra Seon Ju [L] S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/832315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166851, 11823, 'A Desesperada Sra Seon Ju [L] S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/832316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166852, 11823, 'A Desesperada Sra Seon Ju [L] S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/832317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166853, 11823, 'A Desesperada Sra Seon Ju [L] S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/832318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166854, 11823, 'A Desesperada Sra Seon Ju [L] S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/832319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166855, 11823, 'A Desesperada Sra Seon Ju [L] S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/832320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166856, 11823, 'A Desesperada Sra Seon Ju [L] S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/832321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166857, 11823, 'A Desesperada Sra Seon Ju [L] S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/832322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166858, 11823, 'A Desesperada Sra Seon Ju [L] S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/832323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166859, 11823, 'A Desesperada Sra Seon Ju [L] S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/832324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166860, 11823, 'A Desesperada Sra Seon Ju [L] S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/832325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166861, 11823, 'A Desesperada Sra Seon Ju [L] S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/832326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166862, 11823, 'A Desesperada Sra Seon Ju [L] S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/832327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166863, 11823, 'A Desesperada Sra Seon Ju [L] S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/832328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166864, 11823, 'A Desesperada Sra Seon Ju [L] S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/832329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166865, 11823, 'A Desesperada Sra Seon Ju [L] S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/832330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166866, 11823, 'A Desesperada Sra Seon Ju [L] S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/832331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166867, 11823, 'A Desesperada Sra Seon Ju [L] S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/832332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166868, 11823, 'A Desesperada Sra Seon Ju [L] S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/832333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166869, 11823, 'A Desesperada Sra Seon Ju [L] S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/832334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166870, 11823, 'A Desesperada Sra Seon Ju [L] S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/832335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166871, 11823, 'A Desesperada Sra Seon Ju [L] S01 E119', 'http://sinalprivado.info:80/series/1533784/1533784/832336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166872, 11823, 'A Desesperada Sra Seon Ju [L] S01 E120', 'http://sinalprivado.info:80/series/1533784/1533784/832337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166873, 11823, 'A Desesperada Sra Seon Ju [L] S01 E121', 'http://sinalprivado.info:80/series/1533784/1533784/832338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(166874, 11823, 'A Desesperada Sra Seon Ju [L] S01 E122', 'http://sinalprivado.info:80/series/1533784/1533784/832339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166875, 11823, 'A Desesperada Sra Seon Ju [L] S01 E123', 'http://sinalprivado.info:80/series/1533784/1533784/832340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166876, 11823, 'A Desesperada Sra Seon Ju [L] S01 E124', 'http://sinalprivado.info:80/series/1533784/1533784/832341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166877, 11823, 'A Desesperada Sra Seon Ju [L] S01 E125', 'http://sinalprivado.info:80/series/1533784/1533784/832342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166878, 11823, 'A Desesperada Sra Seon Ju [L] S01 E126', 'http://sinalprivado.info:80/series/1533784/1533784/832343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptb9knqEQmHQUT7YzITadm0gYIi.jpg'),
(166879, 11824, 'Bangkok Buddies [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508991.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vQ3UVJzz6M5bipfZkWB7YLEhOnu.jpg'),
(166880, 11824, 'Bangkok Buddies [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508992.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iA4XhI5vfnVfcq9AwTzVoCmjZPX.jpg'),
(166881, 11824, 'Bangkok Buddies [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508993.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jgUbMJtstePK7XKwP2NhmVGch7P.jpg'),
(166882, 11824, 'Bangkok Buddies [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508994.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o8wG1mBEEP3KRiVcR75sCoDGuQT.jpg'),
(166883, 11824, 'Bangkok Buddies [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508995.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zKFEuNiGRhN76HevMyibB9Nga7A.jpg'),
(166884, 11824, 'Bangkok Buddies [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508996.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xbYkO0sc0batd9tGeFgagW6frGx.jpg'),
(166885, 11824, 'Bangkok Buddies [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508997.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8dSbRoXoyiUZLBgYQrvz7cqB2Bw.jpg'),
(166886, 11824, 'Bangkok Buddies [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/508998.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/57YPVQCX0y1K3XDUta2toFAMKj4.jpg'),
(166887, 11824, 'Bangkok Buddies [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/508999.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xNiaytdYK614gePDRkWIT89oT9y.jpg'),
(166888, 11824, 'Bangkok Buddies [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/509000.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rvhXXWhKragv8ObKK5rsGqI6cUo.jpg'),
(166889, 11824, 'Bangkok Buddies [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/509001.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g65orL6gZZPEtoJgpvO2h9dHuEW.jpg'),
(166890, 11824, 'Bangkok Buddies [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/509002.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xBMFioXvgmMvu18ZY9bClQydW8s.jpg'),
(166891, 11824, 'Bangkok Buddies [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/509003.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k3BDTTjlldUc61i4TvsxBQ7jSsX.jpg'),
(166892, 11825, 'Blue Box [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508983.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iP1wh8pjHPOP7S7DewTa4KDDgVO.jpg'),
(166893, 11825, 'Blue Box [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508984.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/654vPnrKqjJufJj53Zg5uCV7jpE.jpg'),
(166894, 11825, 'Blue Box [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508985.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1PYnJ1W53ZPRyEYpp25EZbvrlJw.jpg'),
(166895, 11825, 'Blue Box [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508986.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tpNkGMMFxVaaHSUr0xi8WtxWtEs.jpg'),
(166896, 11825, 'Blue Box [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508987.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9DT2lF6SHysuBkd5vgCXK460WEk.jpg'),
(166897, 11825, 'Blue Box [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508988.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pyIWyOKZMnWBk6jAIrbnDOc0bP1.jpg'),
(166898, 11825, 'Blue Box [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508989.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sxrKwe2e9gWOVURsyHrciPXCh1k.jpg'),
(166899, 11825, 'Blue Box [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/508990.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hzvtE1H7wPCom0pHwrrlKwgrOn2.jpg'),
(166900, 11825, 'Blue Box [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/521344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnlM7h3IH0P5fl5V5FMkp8ddjxw.jpg'),
(166901, 11825, 'Blue Box [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/521345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnlM7h3IH0P5fl5V5FMkp8ddjxw.jpg'),
(166902, 11825, 'Blue Box [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/521346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnlM7h3IH0P5fl5V5FMkp8ddjxw.jpg'),
(166903, 11825, 'Blue Box [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/521347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnlM7h3IH0P5fl5V5FMkp8ddjxw.jpg'),
(166904, 11825, 'Blue Box [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/644191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnlM7h3IH0P5fl5V5FMkp8ddjxw.jpg'),
(166905, 11825, 'Blue Box [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/659756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnlM7h3IH0P5fl5V5FMkp8ddjxw.jpg'),
(166906, 11825, 'Blue Box [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/665762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnlM7h3IH0P5fl5V5FMkp8ddjxw.jpg'),
(166907, 11825, 'Blue Box [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/673631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnlM7h3IH0P5fl5V5FMkp8ddjxw.jpg'),
(166908, 11825, 'Blue Box [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/680846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnlM7h3IH0P5fl5V5FMkp8ddjxw.jpg'),
(166909, 11825, 'Blue Box [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/686824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnlM7h3IH0P5fl5V5FMkp8ddjxw.jpg'),
(166910, 11825, 'Blue Box [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/686825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnlM7h3IH0P5fl5V5FMkp8ddjxw.jpg'),
(166911, 11825, 'Blue Box [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/698664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnlM7h3IH0P5fl5V5FMkp8ddjxw.jpg'),
(166912, 11825, 'Blue Box [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/709981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnlM7h3IH0P5fl5V5FMkp8ddjxw.jpg'),
(166913, 11825, 'Blue Box [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/718949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnlM7h3IH0P5fl5V5FMkp8ddjxw.jpg'),
(166914, 11825, 'Blue Box [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/724242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnlM7h3IH0P5fl5V5FMkp8ddjxw.jpg'),
(166915, 11825, 'Blue Box [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/731602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnlM7h3IH0P5fl5V5FMkp8ddjxw.jpg'),
(166916, 11825, 'Blue Box [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/743165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nnlM7h3IH0P5fl5V5FMkp8ddjxw.jpg'),
(166917, 11826, 'Criaturinhas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508944.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5cyQtB7MGl6nCDkT6GJheFR4Pa.jpg'),
(166918, 11826, 'Criaturinhas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508945.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gv4xilJMUSVsP8GMZzD6a75vpxW.jpg'),
(166919, 11826, 'Criaturinhas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508946.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tnfnlzdduVArb88pwbgqDlhpcs7.jpg'),
(166920, 11826, 'Criaturinhas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508947.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qFdvPS7tV7mVLanALJ56nHvuqep.jpg'),
(166921, 11826, 'Criaturinhas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508948.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v5tFqwgX7MZIVFMSHZF29WqnKaR.jpg'),
(166922, 11826, 'Criaturinhas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508949.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xnSspm5BGlL53pjC3FpD75rX1jQ.jpg'),
(166923, 11826, 'Criaturinhas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508950.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z5fhFgM1vFdL1o4hTPhZ9Fmbhno.jpg'),
(166924, 11826, 'Criaturinhas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/508951.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/83V5LOxUMvhxB8LIY13b6sEw4ns.jpg'),
(166925, 11826, 'Criaturinhas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/508952.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9bzyFOMzMeWnjdM9N54CqaqWbY0.jpg'),
(166926, 11826, 'Criaturinhas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/508953.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xRI8s1A6gnpVWBvs2dKs6MTEt6M.jpg'),
(166927, 11826, 'Criaturinhas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/508954.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lTcSENe1xB0cIciInTIvkl6pyTQ.jpg'),
(166928, 11826, 'Criaturinhas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/508955.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mDeh0al9xDqLHj21jsz57xs0eld.jpg'),
(166929, 11826, 'Criaturinhas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/508956.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eKVy2ekhjwDgvK31gVzbc24UbKd.jpg'),
(166930, 11826, 'Criaturinhas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/508957.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5LQE4ekbYzJNRnnzs2M8YPvcTqZ.jpg'),
(166931, 11826, 'Criaturinhas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/508958.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nXIWfqS4nEl9bbt0qjaA1lPqcVD.jpg'),
(166932, 11826, 'Criaturinhas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/508959.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qa5fc1sD4h33dlio478cHNzrXw2.jpg'),
(166933, 11826, 'Criaturinhas S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/508960.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/toI38s97xxru2Pkde2MiIOsQMBM.jpg'),
(166934, 11826, 'Criaturinhas S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/508961.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pcHC6fXznHoZbCoYMEkhcUvr0mS.jpg'),
(166935, 11826, 'Criaturinhas S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/508962.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bZ2dmyM5QaPuazPDiFk1SLTWJxM.jpg'),
(166936, 11826, 'Criaturinhas S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/508963.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9OZmAq63rNphdZeVqnGyYCHCBTc.jpg'),
(166937, 11827, 'Criaturinhas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z5zajY25wQRFWnpH05YAjlNpZ08.jpg'),
(166938, 11827, 'Criaturinhas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508965.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z5zajY25wQRFWnpH05YAjlNpZ08.jpg'),
(166939, 11827, 'Criaturinhas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508966.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z5zajY25wQRFWnpH05YAjlNpZ08.jpg'),
(166940, 11827, 'Criaturinhas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z5zajY25wQRFWnpH05YAjlNpZ08.jpg'),
(166941, 11827, 'Criaturinhas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508968.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z5zajY25wQRFWnpH05YAjlNpZ08.jpg'),
(166942, 11827, 'Criaturinhas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508969.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z5zajY25wQRFWnpH05YAjlNpZ08.jpg'),
(166943, 11827, 'Criaturinhas S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z5zajY25wQRFWnpH05YAjlNpZ08.jpg'),
(166944, 11827, 'Criaturinhas S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/508971.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z5zajY25wQRFWnpH05YAjlNpZ08.jpg'),
(166945, 11827, 'Criaturinhas S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/508972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z5zajY25wQRFWnpH05YAjlNpZ08.jpg'),
(166946, 11827, 'Criaturinhas S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/508973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z5zajY25wQRFWnpH05YAjlNpZ08.jpg'),
(166947, 11827, 'Criaturinhas S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/508974.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z5zajY25wQRFWnpH05YAjlNpZ08.jpg'),
(166948, 11827, 'Criaturinhas S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/508975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z5zajY25wQRFWnpH05YAjlNpZ08.jpg'),
(166949, 11827, 'Criaturinhas S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/508976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z5zajY25wQRFWnpH05YAjlNpZ08.jpg'),
(166950, 11827, 'Criaturinhas S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/508977.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z5zajY25wQRFWnpH05YAjlNpZ08.jpg'),
(166951, 11827, 'Criaturinhas S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/508978.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z5zajY25wQRFWnpH05YAjlNpZ08.jpg'),
(166952, 11827, 'Criaturinhas S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/508979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z5zajY25wQRFWnpH05YAjlNpZ08.jpg'),
(166953, 11827, 'Criaturinhas S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/508980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z5zajY25wQRFWnpH05YAjlNpZ08.jpg'),
(166954, 11827, 'Criaturinhas S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/508981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z5zajY25wQRFWnpH05YAjlNpZ08.jpg'),
(166955, 11827, 'Criaturinhas S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/508982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z5zajY25wQRFWnpH05YAjlNpZ08.jpg'),
(166956, 11828, 'Dear Hyeri [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508932.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2Sv9AE3yWQt7pz6JoRCMpVfLaou.jpg'),
(166957, 11828, 'Dear Hyeri [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508933.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wyNIdXNz8otWxBM0NEzRXlLM4F3.jpg'),
(166958, 11828, 'Dear Hyeri [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508934.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2KvEnovQeUbmXchYRmGhSiV4Mvi.jpg'),
(166959, 11828, 'Dear Hyeri [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508935.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1z6FykPJIttHqWNhy5DQ1PJ6Cr9.jpg'),
(166960, 11828, 'Dear Hyeri [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508936.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/GQlamDVxrSgRZBv1SQgYsrOfns.jpg'),
(166961, 11828, 'Dear Hyeri [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508937.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7Uz09Mfnch15IfyzK2fr6RFj1Ym.jpg'),
(166962, 11828, 'Dear Hyeri [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508938.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c6zpls8jIDYBnDDwlb0lcmYZ4PX.jpg'),
(166963, 11828, 'Dear Hyeri [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/508939.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k9J4eTbO2nBqna9G2QUGdwNeWYz.jpg'),
(166964, 11828, 'Dear Hyeri [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/508940.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bnjzSQnsij71kwNOifdHKOKlfsF.jpg'),
(166965, 11828, 'Dear Hyeri [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/508941.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9Bz3LSPSKJd6zqcKsc9EgsWE4v0.jpg'),
(166966, 11828, 'Dear Hyeri [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/508942.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lPDL8lmrsEFTeTutXEaSW1j2NO4.jpg'),
(166967, 11828, 'Dear Hyeri [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/508943.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gpZyjBsr2STzz9ayGdsyiWGsoou.jpg'),
(166968, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166969, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166970, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166971, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166972, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166973, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166974, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166975, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/508924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166976, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/508925.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166977, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/508926.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166978, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/508927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166979, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/508928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166980, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/508929.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166981, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/508930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166982, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/508931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166983, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/690621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166984, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/690622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166985, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/690623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166986, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/690624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166987, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/690625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166988, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/690626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166989, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/690627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166990, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/690628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166991, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/690629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166992, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/690630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166993, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/690631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166994, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/690632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166995, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/690633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166996, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/690634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166997, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/690635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166998, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/690636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(166999, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/690637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(167000, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/690638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(167001, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/690639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(167002, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/690640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(167003, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/690641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(167004, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/690642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(167005, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/690643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(167006, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/690644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(167007, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/690645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(167008, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/690646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(167009, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/690647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(167010, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/690648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(167011, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/690649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(167012, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/690650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(167013, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/690651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(167014, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/690652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(167015, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/690653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(167016, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/690654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(167017, 11829, 'Dra Lucia Un Don Extraordinario [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/690655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/q9R75uTbbTgdMO9TcZ1y63AXp5Y.jpg'),
(167018, 4913, 'Ferinha e a Fabrica de Tudo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508897.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nw4aeldO2bL7qEiAMH2b0OgWfhG.jpg'),
(167019, 4913, 'Ferinha e a Fabrica de Tudo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPoe7ZIuCHZ4Hw8owqddf77NLOd.jpg'),
(167020, 4913, 'Ferinha e a Fabrica de Tudo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPoe7ZIuCHZ4Hw8owqddf77NLOd.jpg'),
(167021, 4913, 'Ferinha e a Fabrica de Tudo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPoe7ZIuCHZ4Hw8owqddf77NLOd.jpg'),
(167022, 4913, 'Ferinha e a Fabrica de Tudo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPoe7ZIuCHZ4Hw8owqddf77NLOd.jpg'),
(167023, 4913, 'Ferinha e a Fabrica de Tudo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPoe7ZIuCHZ4Hw8owqddf77NLOd.jpg'),
(167024, 4913, 'Ferinha e a Fabrica de Tudo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPoe7ZIuCHZ4Hw8owqddf77NLOd.jpg'),
(167025, 4913, 'Ferinha e a Fabrica de Tudo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/508904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPoe7ZIuCHZ4Hw8owqddf77NLOd.jpg'),
(167026, 4913, 'Ferinha e a Fabrica de Tudo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/508905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPoe7ZIuCHZ4Hw8owqddf77NLOd.jpg'),
(167027, 4913, 'Ferinha e a Fabrica de Tudo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/508906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPoe7ZIuCHZ4Hw8owqddf77NLOd.jpg'),
(167028, 11830, 'Ferinha e a Fabrica de Tudo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPoe7ZIuCHZ4Hw8owqddf77NLOd.jpg'),
(167029, 11830, 'Ferinha e a Fabrica de Tudo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPoe7ZIuCHZ4Hw8owqddf77NLOd.jpg'),
(167030, 11830, 'Ferinha e a Fabrica de Tudo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPoe7ZIuCHZ4Hw8owqddf77NLOd.jpg'),
(167031, 11830, 'Ferinha e a Fabrica de Tudo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPoe7ZIuCHZ4Hw8owqddf77NLOd.jpg'),
(167032, 11830, 'Ferinha e a Fabrica de Tudo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPoe7ZIuCHZ4Hw8owqddf77NLOd.jpg'),
(167033, 11830, 'Ferinha e a Fabrica de Tudo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPoe7ZIuCHZ4Hw8owqddf77NLOd.jpg'),
(167034, 11830, 'Ferinha e a Fabrica de Tudo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPoe7ZIuCHZ4Hw8owqddf77NLOd.jpg'),
(167035, 11830, 'Ferinha e a Fabrica de Tudo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/508914.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPoe7ZIuCHZ4Hw8owqddf77NLOd.jpg'),
(167036, 11830, 'Ferinha e a Fabrica de Tudo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/508915.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPoe7ZIuCHZ4Hw8owqddf77NLOd.jpg'),
(167037, 11830, 'Ferinha e a Fabrica de Tudo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/508916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mPoe7ZIuCHZ4Hw8owqddf77NLOd.jpg'),
(167038, 11831, 'Gugu Toninho e Augusto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508892.mp4', 'https://image.tmdb.org//t/p/w1280/iReprzpzz4D7oP2dj7rTzaj3dqT.jpg'),
(167039, 11831, 'Gugu Toninho e Augusto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508893.mp4', 'https://image.tmdb.org//t/p/w1280/iReprzpzz4D7oP2dj7rTzaj3dqT.jpg'),
(167040, 11831, 'Gugu Toninho e Augusto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508894.mp4', 'https://image.tmdb.org//t/p/w1280/iReprzpzz4D7oP2dj7rTzaj3dqT.jpg'),
(167041, 11831, 'Gugu Toninho e Augusto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508895.mp4', 'https://image.tmdb.org//t/p/w1280/iReprzpzz4D7oP2dj7rTzaj3dqT.jpg'),
(167042, 11831, 'Gugu Toninho e Augusto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508896.mp4', 'https://image.tmdb.org//t/p/w1280/iReprzpzz4D7oP2dj7rTzaj3dqT.jpg'),
(167043, 11832, 'Jogo de Amor e Fantasia [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/511881.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2taTZYdoPT048Yg425Ly7wIGw51.jpg'),
(167044, 11832, 'Jogo de Amor e Fantasia [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/511882.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dLBPlcWnaY1x4Z94U4Cak7ksFie.jpg'),
(167045, 11832, 'Jogo de Amor e Fantasia [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/511883.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fwwoCfoULzZvNDeuatXC5IKvVLv.jpg'),
(167046, 11832, 'Jogo de Amor e Fantasia [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/511884.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/elFv4RY0e9g3dMkEApznoBpXa0f.jpg'),
(167047, 11832, 'Jogo de Amor e Fantasia [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/511885.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9GP3v786FxlcvMest4VpUDEnpH3.jpg'),
(167048, 11832, 'Jogo de Amor e Fantasia [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/511886.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4SxR5xvkNIYlomFkq8klJgWiylF.jpg'),
(167049, 11832, 'Jogo de Amor e Fantasia [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/511887.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oRlH7B7ZCDRJd770ZTmRS6kLWUQ.jpg'),
(167050, 11832, 'Jogo de Amor e Fantasia [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/511888.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nLmkJtezy9c3M0tyaEgdIf8ReWt.jpg'),
(167051, 11832, 'Jogo de Amor e Fantasia [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/511889.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eyonz8Ka2q8OpcMTno655rnpzNN.jpg'),
(167052, 11832, 'Jogo de Amor e Fantasia [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/511890.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eUnGfVer4qtz2xgPnmGorVKSH6V.jpg'),
(167053, 11832, 'Jogo de Amor e Fantasia [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/511891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167054, 11832, 'Jogo de Amor e Fantasia [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/511892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167055, 11832, 'Jogo de Amor e Fantasia [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/511893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167056, 11832, 'Jogo de Amor e Fantasia [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/511894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167057, 11832, 'Jogo de Amor e Fantasia [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/511895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167058, 11832, 'Jogo de Amor e Fantasia [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/520209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167059, 11832, 'Jogo de Amor e Fantasia [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/520210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167060, 11832, 'Jogo de Amor e Fantasia [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/520211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167061, 11832, 'Jogo de Amor e Fantasia [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/520212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167062, 11832, 'Jogo de Amor e Fantasia [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/520213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167063, 11832, 'Jogo de Amor e Fantasia [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/520214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167064, 11832, 'Jogo de Amor e Fantasia [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/520215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167065, 11832, 'Jogo de Amor e Fantasia [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/520216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167066, 11832, 'Jogo de Amor e Fantasia [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/520217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167067, 11832, 'Jogo de Amor e Fantasia [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/520218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167068, 11832, 'Jogo de Amor e Fantasia [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/523452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167069, 11832, 'Jogo de Amor e Fantasia [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/523453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167070, 11832, 'Jogo de Amor e Fantasia [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/523454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167071, 11832, 'Jogo de Amor e Fantasia [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/523455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167072, 11832, 'Jogo de Amor e Fantasia [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/523456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167073, 11832, 'Jogo de Amor e Fantasia [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/639229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167074, 11832, 'Jogo de Amor e Fantasia [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/639230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/339mxamB2X2iz35PVezlXBRUV5n.jpg'),
(167075, 11833, 'Larva Island S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508866.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bLJ8eaMhdL3N5SRGFFl7n2O83fH.jpg'),
(167076, 11833, 'Larva Island S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508867.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aFnBbqvCy9LScacmojtK1Ko0mBD.jpg'),
(167077, 11833, 'Larva Island S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508868.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bBQZUdbo4lxwo546LxqaPwKr52t.jpg'),
(167078, 11833, 'Larva Island S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508869.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vCP2sPncuyrAum09kxy9KKQS8Zs.jpg'),
(167079, 11833, 'Larva Island S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508870.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ooriTsIUPvUeBu4d4sEHaWKj94H.jpg'),
(167080, 11833, 'Larva Island S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508871.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4Eb8lvnRD6z5x08jrPhSiPLCzK8.jpg'),
(167081, 11833, 'Larva Island S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508872.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2bdYaLscb6eXVeTcnbuS1UE6VUk.jpg'),
(167082, 11833, 'Larva Island S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/508873.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aoTE1SCgRALYJkqcfBPxKd2Afj5.jpg'),
(167083, 11833, 'Larva Island S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/508874.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5ecw9kvWCFftDcyWOv6eL73znI5.jpg'),
(167084, 11833, 'Larva Island S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/508875.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ekCaXvxJmij8CVljvn6LumJK287.jpg'),
(167085, 11833, 'Larva Island S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/508876.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8SVrAi9DzGPX2QwT00CsWY1fTwK.jpg'),
(167086, 11833, 'Larva Island S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/508877.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hv9HzvZ6CBpA1g3TWkaOs3agZpN.jpg'),
(167087, 11833, 'Larva Island S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/508878.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eycrfrLyEFMAlBGz1L4pMt1ydfY.jpg'),
(167088, 11834, 'Larva Island S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508879.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yMNin9DvXIUFN9ByMD1trXV9WE1.jpg'),
(167089, 11834, 'Larva Island S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508880.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fRRBLeuplis841vgKBfY4SKxf1I.jpg'),
(167090, 11834, 'Larva Island S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508881.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q00992Xu27P493ZabMtPJvw8Klv.jpg'),
(167091, 11834, 'Larva Island S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508882.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pY6q0DxXseHpusvQJnDeJDVd3QL.jpg'),
(167092, 11834, 'Larva Island S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508883.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3CGyQ4AiJ7ecfxpg6I7QCOGrvSP.jpg'),
(167093, 11834, 'Larva Island S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508884.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fJ3e2pnwnnSGQiY8BPdnI8eAG6E.jpg'),
(167094, 11834, 'Larva Island S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508885.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nvuirxnHKJPq1svrR7sMaSEyhJf.jpg'),
(167095, 11834, 'Larva Island S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/508886.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rFis6u3SIHT55nhBYxgOsSJM6Qj.jpg'),
(167096, 11834, 'Larva Island S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/508887.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cpPk1SzR9Iz9FO33UpoC1MV2IvE.jpg'),
(167097, 11834, 'Larva Island S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/508888.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4HWlt4XZOFL0mHRUtoLBcFjp9TZ.jpg'),
(167098, 11834, 'Larva Island S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/508889.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x05Ii3GguuY4BK6TMk4WqeIPAUR.jpg'),
(167099, 11834, 'Larva Island S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/508890.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cISQKHhqcRT9Gq0mk7KyBPBwZ9Q.jpg'),
(167100, 11834, 'Larva Island S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/508891.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fW7Hn9Eve9mO0j8zTQAbA1YgXv6.jpg'),
(167101, 11835, 'O Juiz do Inferno [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508852.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5MIE3xyUlhIzI37ZJS9cGkbvwOr.jpg'),
(167102, 11835, 'O Juiz do Inferno [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508853.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pg1w3fmV9hzes65gCuYABzgbCsA.jpg'),
(167103, 11835, 'O Juiz do Inferno [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508854.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mGcAzKMLTVyLudq6tvjRHtkTygL.jpg'),
(167104, 11835, 'O Juiz do Inferno [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508855.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1MEEU3cM33XSEfLYXnETGyATWVP.jpg'),
(167105, 11835, 'O Juiz do Inferno [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508856.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fniiwDBjlVLAZWEcBJ1xvrtgw2.jpg'),
(167106, 11835, 'O Juiz do Inferno [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508857.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tSZNZjwpHxiWP8RlWvSgKLS087E.jpg'),
(167107, 11835, 'O Juiz do Inferno [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508858.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/52KFtnWdJbxbPJtg14fCL3gFCwK.jpg'),
(167108, 11835, 'O Juiz do Inferno [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/508859.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/szrazDLahPOCYSMhGktJOCmAl4B.jpg'),
(167109, 11835, 'O Juiz do Inferno [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/508860.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dMAMDaXmMRocIq5PTCE2tCx2mh5.jpg'),
(167110, 11835, 'O Juiz do Inferno [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/508861.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uUeb1Yd82wTm0W7xBcncsN8MGBT.jpg'),
(167111, 11835, 'O Juiz do Inferno [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/508862.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xtpA77161WEt2TXv9MZn1fQ26Z2.jpg'),
(167112, 11835, 'O Juiz do Inferno [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/508863.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cQfDK3Gi3Y58UWNOVW9FQ0BdrPz.jpg'),
(167113, 11835, 'O Juiz do Inferno [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/508864.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qMs3b7Qsl2NT2xOWTrmZXlCbTCt.jpg'),
(167114, 11835, 'O Juiz do Inferno [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/508865.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tczzKNzqKF4ePAHVsUuE6uHRBIQ.jpg'),
(167115, 11836, 'O Lado Obscuro de Gangnam [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508846.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/59Q26TZkk5iNow4CQl8ckBpuWFE.jpg'),
(167116, 11836, 'O Lado Obscuro de Gangnam [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508847.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7dSLE2txVAWjkdWFYd5d9lWX1CD.jpg'),
(167117, 11836, 'O Lado Obscuro de Gangnam [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508848.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lvkSnEiCe55hpeLaHVZITiHbHxR.jpg'),
(167118, 11836, 'O Lado Obscuro de Gangnam [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508849.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gR28HGj9PH9hmHscMgeoP4PcKml.jpg'),
(167119, 11836, 'O Lado Obscuro de Gangnam [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508850.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5zZCcE0Wr2H8WQZIeW0TYsjg14a.jpg'),
(167120, 11836, 'O Lado Obscuro de Gangnam [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508851.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6v8SsMH1HzU5mPDE7hZ8GVnGpZI.jpg'),
(167121, 11837, 'See Your Love [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508840.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bHREUrLrk6jFYTxI8qPSxnZ8NMn.jpg'),
(167122, 11837, 'See Your Love [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508841.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/foB2Gpx8oD05T9GBryj9kzpVo80.jpg'),
(167123, 11837, 'See Your Love [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508842.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kwSzwKkzmy5ndzKLsZmu8wkczJt.jpg'),
(167124, 11837, 'See Your Love [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508843.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wp1RQECzxPHZJwffZo8RdfNpPxG.jpg'),
(167125, 11837, 'See Your Love [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508844.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rq0sDK0EG2wVzV3PugjkPPXye5K.jpg'),
(167126, 11837, 'See Your Love [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508845.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/swdHQLMHZHp03sGM1IFKonkRMGA.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(167127, 11837, 'See Your Love [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/521930.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nVMroDeUCiGxLIDVq5YYiq4IcuE.jpg'),
(167128, 11837, 'See Your Love [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/521931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nVMroDeUCiGxLIDVq5YYiq4IcuE.jpg'),
(167129, 11837, 'See Your Love [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/521932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nVMroDeUCiGxLIDVq5YYiq4IcuE.jpg'),
(167130, 11837, 'See Your Love [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/638995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nVMroDeUCiGxLIDVq5YYiq4IcuE.jpg'),
(167131, 11837, 'See Your Love [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/639931.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nVMroDeUCiGxLIDVq5YYiq4IcuE.jpg'),
(167132, 11837, 'See Your Love [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/657498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nVMroDeUCiGxLIDVq5YYiq4IcuE.jpg'),
(167133, 11837, 'See Your Love [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/661450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nVMroDeUCiGxLIDVq5YYiq4IcuE.jpg'),
(167134, 11838, 'The Creep Tapes [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508838.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cEzvJs5JPBUvBCMgka7HZwdllu5.jpg'),
(167135, 11838, 'The Creep Tapes [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508839.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ig1CKXZJb5oRFJE7DdAY122W2db.jpg'),
(167136, 11838, 'The Creep Tapes [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/635960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/poGDeQ5uLb7Nh8J7SWPzibUj7WU.jpg'),
(167137, 11838, 'The Creep Tapes [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/635961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/poGDeQ5uLb7Nh8J7SWPzibUj7WU.jpg'),
(167138, 11838, 'The Creep Tapes [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/635962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/poGDeQ5uLb7Nh8J7SWPzibUj7WU.jpg'),
(167139, 11838, 'The Creep Tapes [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/635963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/poGDeQ5uLb7Nh8J7SWPzibUj7WU.jpg'),
(167140, 11839, 'The Crime [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508832.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dobeFShXOmHgGxUxTSwUzH3WIH7.jpg'),
(167141, 11839, 'The Crime [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508833.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r43rUznVnRjlv9BS6ohSC6wGCch.jpg'),
(167142, 11839, 'The Crime [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508834.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qeMhEi3BvO4vyWZA6Fg4Z3xjfVE.jpg'),
(167143, 11840, 'The Crime [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508835.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hc5AwIrbXwcWidhUyJalcVgIVlG.jpg'),
(167144, 11840, 'The Crime [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508836.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fujftSMYJcRf7sCOn8juVeGh4Cl.jpg'),
(167145, 11840, 'The Crime [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508837.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s0ar2qqV22rdE5PjZxKCQTCqWJm.jpg'),
(167146, 11841, 'Whitstable Pearl [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/510947.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2z0ea0X87ohIP7YffNiNqcw1drq.jpg'),
(167147, 11841, 'Whitstable Pearl [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/510948.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fnEySqFkQvwUKp1vqdlbVesI7xs.jpg'),
(167148, 11841, 'Whitstable Pearl [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/510949.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g8flTDFlvCulDMlMZ23fjkR9H6k.jpg'),
(167149, 11841, 'Whitstable Pearl [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/510950.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yjDniSiZLZnPQIzTOefZTj79OTV.jpg'),
(167150, 11841, 'Whitstable Pearl [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/510951.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xMK1lFd7GC3AvaOO9cTKPcoKseA.jpg'),
(167151, 11841, 'Whitstable Pearl [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/510952.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hJblo2vOXKgEk6FoaE6FvZpL5q.jpg'),
(167152, 11842, 'Whitstable Pearl [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/510953.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v46k338boJlyQ2iMH4tb6mWnMzV.jpg'),
(167153, 11842, 'Whitstable Pearl [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/510954.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rTwoCofNxcUNEwMHsGAtvjdtObh.jpg'),
(167154, 11842, 'Whitstable Pearl [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/510955.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t6R8NHAN58ORlag7vjqZ8BDoC35.jpg'),
(167155, 11842, 'Whitstable Pearl [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/510956.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/llL69DlWn4Ara12dbyB5M8zV4sd.jpg'),
(167156, 11842, 'Whitstable Pearl [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/510957.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d6ayZCpMYplqu8uW2ka1WBopxh3.jpg'),
(167157, 11842, 'Whitstable Pearl [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/510958.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p9xhOyWYdGijhqWz350oLef4PAn.jpg'),
(167158, 11843, 'Whitstable Pearl [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/510959.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o4TqjdfAodvjtdcBCQYOMVOHToO.jpg'),
(167159, 11843, 'Whitstable Pearl [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/510960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wJlAOeqqHXBM6rJ5E9MrQTKUva4.jpg'),
(167160, 11843, 'Whitstable Pearl [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/514871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wJlAOeqqHXBM6rJ5E9MrQTKUva4.jpg'),
(167161, 11843, 'Whitstable Pearl [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/514872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wJlAOeqqHXBM6rJ5E9MrQTKUva4.jpg'),
(167162, 11843, 'Whitstable Pearl [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wJlAOeqqHXBM6rJ5E9MrQTKUva4.jpg'),
(167163, 11843, 'Whitstable Pearl [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wJlAOeqqHXBM6rJ5E9MrQTKUva4.jpg'),
(167164, 11844, 'Sutura A Vida por um Fio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508700.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k2BwHU5vhJ81RQf6JrDs4tKQyL.jpg'),
(167165, 11844, 'Sutura A Vida por um Fio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k2BwHU5vhJ81RQf6JrDs4tKQyL.jpg'),
(167166, 11844, 'Sutura A Vida por um Fio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508702.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k2BwHU5vhJ81RQf6JrDs4tKQyL.jpg'),
(167167, 11844, 'Sutura A Vida por um Fio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k2BwHU5vhJ81RQf6JrDs4tKQyL.jpg'),
(167168, 11844, 'Sutura A Vida por um Fio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k2BwHU5vhJ81RQf6JrDs4tKQyL.jpg'),
(167169, 11844, 'Sutura A Vida por um Fio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k2BwHU5vhJ81RQf6JrDs4tKQyL.jpg'),
(167170, 11844, 'Sutura A Vida por um Fio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k2BwHU5vhJ81RQf6JrDs4tKQyL.jpg'),
(167171, 11844, 'Sutura A Vida por um Fio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/508707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3k2BwHU5vhJ81RQf6JrDs4tKQyL.jpg'),
(167172, 11845, 'Amor da Minha Vida S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3dFVr9cMVVBuVKZTQWqBUGf3Phz.jpg'),
(167173, 11845, 'Amor da Minha Vida S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3dFVr9cMVVBuVKZTQWqBUGf3Phz.jpg'),
(167174, 11845, 'Amor da Minha Vida S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3dFVr9cMVVBuVKZTQWqBUGf3Phz.jpg'),
(167175, 11845, 'Amor da Minha Vida S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3dFVr9cMVVBuVKZTQWqBUGf3Phz.jpg'),
(167176, 11845, 'Amor da Minha Vida S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3dFVr9cMVVBuVKZTQWqBUGf3Phz.jpg'),
(167177, 11845, 'Amor da Minha Vida S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3dFVr9cMVVBuVKZTQWqBUGf3Phz.jpg'),
(167178, 11845, 'Amor da Minha Vida S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3dFVr9cMVVBuVKZTQWqBUGf3Phz.jpg'),
(167179, 11845, 'Amor da Minha Vida S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/508697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3dFVr9cMVVBuVKZTQWqBUGf3Phz.jpg'),
(167180, 11845, 'Amor da Minha Vida S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/508698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3dFVr9cMVVBuVKZTQWqBUGf3Phz.jpg'),
(167181, 11845, 'Amor da Minha Vida S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/508699.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3dFVr9cMVVBuVKZTQWqBUGf3Phz.jpg'),
(167182, 11846, 'Pantheon S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508682.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zpv9c9Ob3TY5F3qPWrciCtyGGF8.jpg'),
(167183, 11846, 'Pantheon S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508683.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nhMJoQCmErQMw6GHQEglh5LUDdk.jpg'),
(167184, 11846, 'Pantheon S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508684.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A0jWZaOgeRnCBrSiuJPdhmNz9Kp.jpg'),
(167185, 11846, 'Pantheon S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508685.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7AI8rzX3ZzYx89R1QDRR3rF0BfA.jpg'),
(167186, 11846, 'Pantheon S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508686.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h2rZoCCq9fnX0u8x8jDT0QBqpOV.jpg'),
(167187, 11846, 'Pantheon S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508687.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f0Pu9rt6tg7abkM6HD6nprhc6iz.jpg'),
(167188, 11846, 'Pantheon S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508688.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/emunHgqS5Ra410UcRp9wkZiua1B.jpg'),
(167189, 11846, 'Pantheon S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/508689.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w9rtHF9gb2sWSOmTj0lSQzOX8l1.jpg'),
(167190, 11847, 'Pantheon S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/708916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aZupC6eJhTe82e5I0JRaOBjFHOd.jpg'),
(167191, 11847, 'Pantheon S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/708917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aZupC6eJhTe82e5I0JRaOBjFHOd.jpg'),
(167192, 11847, 'Pantheon S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/708918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aZupC6eJhTe82e5I0JRaOBjFHOd.jpg'),
(167193, 11847, 'Pantheon S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/708919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aZupC6eJhTe82e5I0JRaOBjFHOd.jpg'),
(167194, 11847, 'Pantheon S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/708920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aZupC6eJhTe82e5I0JRaOBjFHOd.jpg'),
(167195, 11847, 'Pantheon S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/708921.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aZupC6eJhTe82e5I0JRaOBjFHOd.jpg'),
(167196, 11847, 'Pantheon S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/708922.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aZupC6eJhTe82e5I0JRaOBjFHOd.jpg'),
(167197, 11847, 'Pantheon S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/708923.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/aZupC6eJhTe82e5I0JRaOBjFHOd.jpg'),
(167198, 11848, 'Voo Criminoso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/508674.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gKFNMf51uLHIlMimJMbkmGFH2cf.jpg'),
(167199, 11848, 'Voo Criminoso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/508675.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vLNy3nVTAs6T34JjtldZSIZWaDS.jpg'),
(167200, 11848, 'Voo Criminoso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/508676.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w1MOXJx9op9AgqfQn0Szn3tYmAR.jpg'),
(167201, 11848, 'Voo Criminoso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/508677.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yIFS76P6n3arQVhYjlwmLRIy5pD.jpg'),
(167202, 11848, 'Voo Criminoso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/508678.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gjH1lxXo4idxMZjkjDpQwNRmqh0.jpg'),
(167203, 11848, 'Voo Criminoso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/508679.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xA0Pl9BZ29cOcPjBXJHGR89xJ1P.jpg'),
(167204, 11848, 'Voo Criminoso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/508680.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iLWLDUit9zlYXQ7kTxNBvsQQaes.jpg'),
(167205, 11848, 'Voo Criminoso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/508681.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xxjKCK9p7Le21WyKjRscmXyiGCr.jpg'),
(167206, 11849, 'Cafe com Chef S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/512479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Q27xSIiXGX858pykfzdp5iwHgx.jpg'),
(167207, 11849, 'Cafe com Chef S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/512480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Q27xSIiXGX858pykfzdp5iwHgx.jpg'),
(167208, 11849, 'Cafe com Chef S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/512481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Q27xSIiXGX858pykfzdp5iwHgx.jpg'),
(167209, 11849, 'Cafe com Chef S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/514561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Q27xSIiXGX858pykfzdp5iwHgx.jpg'),
(167210, 11849, 'Cafe com Chef S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/518815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8Q27xSIiXGX858pykfzdp5iwHgx.jpg'),
(167211, 11850, 'Mestres da Air Fryer S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/512699.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iFEckpYqb68nwtVpMkFhXARDITQ.jpg'),
(167212, 11850, 'Mestres da Air Fryer S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/517846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yp9Wn7h1KdP3gbhFleaZuaScNPz.jpg'),
(167213, 11850, 'Mestres da Air Fryer S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/517847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yp9Wn7h1KdP3gbhFleaZuaScNPz.jpg'),
(167214, 11850, 'Mestres da Air Fryer S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/525262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yp9Wn7h1KdP3gbhFleaZuaScNPz.jpg'),
(167215, 11850, 'Mestres da Air Fryer S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/638451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yp9Wn7h1KdP3gbhFleaZuaScNPz.jpg'),
(167216, 11850, 'Mestres da Air Fryer S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/658979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yp9Wn7h1KdP3gbhFleaZuaScNPz.jpg'),
(167217, 11850, 'Mestres da Air Fryer S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/658980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yp9Wn7h1KdP3gbhFleaZuaScNPz.jpg'),
(167218, 11850, 'Mestres da Air Fryer S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/660267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yp9Wn7h1KdP3gbhFleaZuaScNPz.jpg'),
(167219, 11851, 'Narco Circus S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/512695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wsWrvrXcWOgLtcQqoeKnC8D44h5.jpg'),
(167220, 11851, 'Narco Circus S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/512696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wsWrvrXcWOgLtcQqoeKnC8D44h5.jpg'),
(167221, 11851, 'Narco Circus S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/512697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wsWrvrXcWOgLtcQqoeKnC8D44h5.jpg'),
(167222, 11851, 'Narco Circus S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/512698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wsWrvrXcWOgLtcQqoeKnC8D44h5.jpg'),
(167223, 11852, 'Quando o Telefone Toca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/512693.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y346gntS17QgsjHab8vkydflZaM.jpg'),
(167224, 11852, 'Quando o Telefone Toca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/512694.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zxv8WQCiVPBwK7PgBk6oJ95AFU8.jpg'),
(167225, 11852, 'Quando o Telefone Toca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/514044.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yi1CR6FVmaO1D4e5manW1WUPL0.jpg'),
(167226, 11852, 'Quando o Telefone Toca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/514045.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yi1CR6FVmaO1D4e5manW1WUPL0.jpg'),
(167227, 11852, 'Quando o Telefone Toca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yi1CR6FVmaO1D4e5manW1WUPL0.jpg'),
(167228, 11852, 'Quando o Telefone Toca S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yi1CR6FVmaO1D4e5manW1WUPL0.jpg'),
(167229, 11852, 'Quando o Telefone Toca S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yi1CR6FVmaO1D4e5manW1WUPL0.jpg'),
(167230, 11852, 'Quando o Telefone Toca S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yi1CR6FVmaO1D4e5manW1WUPL0.jpg'),
(167231, 11852, 'Quando o Telefone Toca S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/657704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yi1CR6FVmaO1D4e5manW1WUPL0.jpg'),
(167232, 11852, 'Quando o Telefone Toca S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/657705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yi1CR6FVmaO1D4e5manW1WUPL0.jpg'),
(167233, 11852, 'Quando o Telefone Toca S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/657706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yi1CR6FVmaO1D4e5manW1WUPL0.jpg'),
(167234, 11852, 'Quando o Telefone Toca S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/657707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7yi1CR6FVmaO1D4e5manW1WUPL0.jpg'),
(167235, 7373, 'Ra e Sapo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/512645.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2BI5BVHcKV960bM6xQjZ2enGUma.jpg'),
(167236, 7373, 'Ra e Sapo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/512646.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tzvvnT1ngLWSgoXw4TJneOIPyyH.jpg'),
(167237, 7373, 'Ra e Sapo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/512647.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jIOrTPccc8C5Y2MJreZa31vsu8K.jpg'),
(167238, 7373, 'Ra e Sapo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/512648.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2xeDqxytDrzdsxUBToS6G0bV7PF.jpg'),
(167239, 7373, 'Ra e Sapo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/512649.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/goKs919LDIxhqRylB6AjI6yKoOt.jpg'),
(167240, 7373, 'Ra e Sapo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/512650.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9z7fwBkkrfC3UgLd9jiQMhbi7wR.jpg'),
(167241, 7373, 'Ra e Sapo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/512651.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8nyHiSA1sp4wgqVtdvOgsAZd5zQ.jpg'),
(167242, 7373, 'Ra e Sapo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/512652.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cu9zOOUABrhhgWc55g2knaHnMKq.jpg'),
(167243, 7373, 'Ra e Sapo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/512653.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9aAn8oq4TKBOkUYXi1v9E6lyygj.jpg'),
(167244, 11853, 'Ra e Sapo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/633217.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5KPF5slYL3y78mwGO4AuLK7Axj2.jpg'),
(167245, 11853, 'Ra e Sapo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/633220.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lb6AJmgsHQX1tzJL0ZW3zgnFwoK.jpg'),
(167246, 11853, 'Ra e Sapo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/633222.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tII8C6WbGyuR1s8yR2HXQDpwyKb.jpg'),
(167247, 11853, 'Ra e Sapo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/633223.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qul8q8ZSqrHzV5AAItqzP7xIDbP.jpg'),
(167248, 11853, 'Ra e Sapo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/633225.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t6pgtRK0vOYrYd5HXMvkSYamU4w.jpg'),
(167249, 11853, 'Ra e Sapo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/633227.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4gfOP4JqwdzgEKK4llq1yPvn8w7.jpg'),
(167250, 11853, 'Ra e Sapo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/633229.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8XvMXvSyUg6BNRES4lGPiLuvMJn.jpg'),
(167251, 11853, 'Ra e Sapo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/633232.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nGdD8OsNceeE6oyy2w1klm0FJ5T.jpg'),
(167252, 11853, 'Ra e Sapo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/633234.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ppwvwFpGIU2n7dCta7d1kFaH3vg.jpg'),
(167253, 11854, 'Ririsa Uma Garota em 2.5D S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/512672.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pVAp0pMrI5JtAL04TmvieEO0uWI.jpg'),
(167254, 11854, 'Ririsa Uma Garota em 2.5D S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/512673.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dkmJ9XGE3EssPmgIAuHaUb04AXJ.jpg'),
(167255, 11854, 'Ririsa Uma Garota em 2.5D S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/512674.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tMbBPyFdPmkIrpQzcfedILNc1ez.jpg'),
(167256, 11854, 'Ririsa Uma Garota em 2.5D S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/512675.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tOOh2nNuCSshzkskuerF72bkeiD.jpg'),
(167257, 11854, 'Ririsa Uma Garota em 2.5D S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/512676.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jGM2zbn1eCHVMSMXVhmSj91xxCR.jpg'),
(167258, 11854, 'Ririsa Uma Garota em 2.5D S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/512677.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kG0UvjKWhXgjGIxZDAgpLLa1cmN.jpg'),
(167259, 11854, 'Ririsa Uma Garota em 2.5D S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/512678.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/by0qBT78Ck11iRFonAntJgkPzZc.jpg'),
(167260, 11854, 'Ririsa Uma Garota em 2.5D S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/512679.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pER6TaAtB7UmMux9gwyrhE8RrZU.jpg'),
(167261, 11854, 'Ririsa Uma Garota em 2.5D S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/512680.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8ffnkEOWdr3u8YMkvVRLhIKC1tp.jpg'),
(167262, 11854, 'Ririsa Uma Garota em 2.5D S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/512681.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/73tQghDD9TQZsoxcBKhziQLAl4R.jpg'),
(167263, 11854, 'Ririsa Uma Garota em 2.5D S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/512682.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j42YqgnXPEMP2xYTzlupjTdD5Un.jpg'),
(167264, 11854, 'Ririsa Uma Garota em 2.5D S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/512683.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qDC9E078FSmNSn2CTpGYXVGH5Sh.jpg'),
(167265, 11854, 'Ririsa Uma Garota em 2.5D S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/512684.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/LRj3UwjA7WbmhQcuIUM6I7Zb22.jpg'),
(167266, 11854, 'Ririsa Uma Garota em 2.5D S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/512685.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eKgudX3qxOz9t3WCqiCosrH2BwC.jpg'),
(167267, 11854, 'Ririsa Uma Garota em 2.5D S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/512686.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w6kAldbDeTVDdS0HBMCa76dCiap.jpg'),
(167268, 11854, 'Ririsa Uma Garota em 2.5D S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/512687.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yaPDSA2DGJtqy3JmNMcEpqimITR.jpg'),
(167269, 11854, 'Ririsa Uma Garota em 2.5D S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/512688.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nwyvNmaWsMiRzTwaicMRoL4PT34.jpg'),
(167270, 11854, 'Ririsa Uma Garota em 2.5D S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/512689.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5aliyOZimgv4xIOyYSFjSEELtd5.jpg'),
(167271, 11854, 'Ririsa Uma Garota em 2.5D S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/512690.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pBOOy2sIVUaKxRW2u8nmcTkSgva.jpg'),
(167272, 11854, 'Ririsa Uma Garota em 2.5D S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/512691.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3jGIRHzcpGFGbHhWjHv0V4uMuFX.jpg'),
(167273, 11854, 'Ririsa Uma Garota em 2.5D S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/512692.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aVS1YtAMKwSUVBJ1d8idjnqoCkt.jpg'),
(167274, 11854, 'Ririsa Uma Garota em 2.5D S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/517311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/weal0UrYsys21fYpFFv3iGyPemq.jpg'),
(167275, 11854, 'Ririsa Uma Garota em 2.5D S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/524944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/weal0UrYsys21fYpFFv3iGyPemq.jpg'),
(167276, 11854, 'Ririsa Uma Garota em 2.5D S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/524945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/weal0UrYsys21fYpFFv3iGyPemq.jpg'),
(167277, 11855, 'A Mente do Poder S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/512637.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oiMWPoBSqn4sttyEAbKNdY2lHyY.jpg'),
(167278, 11855, 'A Mente do Poder S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/512638.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yfc3KKjhpFoLMoqA7UpttAjARGA.jpg'),
(167279, 11855, 'A Mente do Poder S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/512639.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2LFhsVqPWgZqJOU3ZL8TVfJmkI4.jpg'),
(167280, 11855, 'A Mente do Poder S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/512640.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/57dtYgJAv7mgrTaQOHy7p2HOGMZ.jpg'),
(167281, 11855, 'A Mente do Poder S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/512641.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tNbtVZEHNybwIYTDi2ahM2fxINz.jpg'),
(167282, 11855, 'A Mente do Poder S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/512642.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o8z8KScAG1RzFutrDprZAvgzcw9.jpg'),
(167283, 11855, 'A Mente do Poder S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/512643.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yg04jX1nNQqBZJ2IO0W533yPGb1.jpg'),
(167284, 11855, 'A Mente do Poder S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/512644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kniQ2yUCQtbfm7yMMwZ8mmK6ahT.jpg'),
(167285, 11856, 'Body By Beth S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/512627.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/99M3TnsR1p2fZngj9zMv0hLpnRz.jpg'),
(167286, 11856, 'Body By Beth S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/512628.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rieQucTcFkzMX1bFsifu7nm09Ub.jpg'),
(167287, 11856, 'Body By Beth S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/512629.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jsKK5c1jbOuwnV1vnumX15ENKbN.jpg'),
(167288, 11856, 'Body By Beth S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/512630.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8hiKbyWacDi6vAa6JERWu6iL4j9.jpg'),
(167289, 11856, 'Body By Beth S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/512631.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hH7PMseSHLdBL2ESnm417xoOLEI.jpg'),
(167290, 11856, 'Body By Beth S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/512632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Aj47UiX1clbtTwXohQdCKPBElnV.jpg'),
(167291, 11856, 'Body By Beth S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/512633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Aj47UiX1clbtTwXohQdCKPBElnV.jpg'),
(167292, 11856, 'Body By Beth S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/512634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Aj47UiX1clbtTwXohQdCKPBElnV.jpg'),
(167293, 11856, 'Body By Beth S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/512635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Aj47UiX1clbtTwXohQdCKPBElnV.jpg'),
(167294, 11856, 'Body By Beth S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/512636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/Aj47UiX1clbtTwXohQdCKPBElnV.jpg'),
(167295, 11857, 'Asaf S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/516709.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4pVkYBeKqPTihpHsqCSnu8Ge3jk.jpg'),
(167296, 11857, 'Asaf S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/516710.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ka5rnTRXkl0sfstst299aXShK6H.jpg'),
(167297, 11857, 'Asaf S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/516711.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nfifM68l8ExQNL89YY3JabncFa3.jpg'),
(167298, 11857, 'Asaf S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/516712.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qhOv9c1sF1zXIm87dljuT8xhVel.jpg'),
(167299, 11857, 'Asaf S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/516713.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kbfcUeDTKcYBQWX7CPcKgST7Pcp.jpg'),
(167300, 11857, 'Asaf S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/516714.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4VcfQb4V3xiJ17RgQ29CRmRzZ9g.jpg'),
(167301, 11858, 'Belo Perto Demais da Luz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/516705.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l6NRgy36kGVksuTMAfrGBd2tS4d.jpg'),
(167302, 11858, 'Belo Perto Demais da Luz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/516706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l6NRgy36kGVksuTMAfrGBd2tS4d.jpg'),
(167303, 11858, 'Belo Perto Demais da Luz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/516707.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l6NRgy36kGVksuTMAfrGBd2tS4d.jpg'),
(167304, 11858, 'Belo Perto Demais da Luz S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/516708.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/l6NRgy36kGVksuTMAfrGBd2tS4d.jpg'),
(167305, 11859, 'Caso Arquivado Quem Matou JonBenet Ramsey S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/516702.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ciE9XHYuCbINk4WWkuauq2tGl0h.jpg'),
(167306, 11859, 'Caso Arquivado Quem Matou JonBenet Ramsey S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/516703.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jCKJswGSIXrg56bQTTUYDbPxLNI.jpg'),
(167307, 11859, 'Caso Arquivado Quem Matou JonBenet Ramsey S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/516704.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qIMpsSUt6yo9j0fVL5ViI0WTK6t.jpg'),
(167308, 11860, 'Doctor Odyssey S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/516700.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hlqCbQRgLy3mkLxYf8t7Nmf6fxB.jpg'),
(167309, 11860, 'Doctor Odyssey S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/516701.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A8e9zrRzdpSc6MG01FBNJHQuLGX.jpg'),
(167310, 11860, 'Doctor Odyssey S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/523525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(167311, 11860, 'Doctor Odyssey S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/523526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(167312, 11860, 'Doctor Odyssey S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/523527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(167313, 11860, 'Doctor Odyssey S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/641083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(167314, 11860, 'Doctor Odyssey S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(167315, 11860, 'Doctor Odyssey S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/663075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(167316, 11860, 'Doctor Odyssey S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/785521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(167317, 11860, 'Doctor Odyssey S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/785522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(167318, 11860, 'Doctor Odyssey S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/787970.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(167319, 11860, 'Doctor Odyssey S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/790557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(167320, 11860, 'Doctor Odyssey S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/810236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(167321, 11860, 'Doctor Odyssey S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/822651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(167322, 11860, 'Doctor Odyssey S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/826115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(167323, 11860, 'Doctor Odyssey S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/838336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(167324, 11860, 'Doctor Odyssey S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/851445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(167325, 11860, 'Doctor Odyssey S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/851446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78KamrNZE0ZzPLBjEug16BASJ5M.jpg'),
(167326, 11861, 'Dont Give Up [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/516690.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vgfYnHiDteiAc4qpjSoPsxlbhTx.jpg'),
(167327, 11861, 'Dont Give Up [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/516691.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nvISR6HPE3o8KMmUTfcjR4ildgr.jpg'),
(167328, 11861, 'Dont Give Up [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/516692.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jB3ZWA3svE6Q8IeT115cCUVlC8k.jpg'),
(167329, 11861, 'Dont Give Up [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/516693.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iTnzzcFErJsOF2eSGyHET6uGDGU.jpg'),
(167330, 11861, 'Dont Give Up [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/516694.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8loyHwFOdbN6jiletC2vfGeuJKO.jpg'),
(167331, 11861, 'Dont Give Up [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/516695.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e8ngy3MxGEaa2jcq36AK4LDxf2B.jpg'),
(167332, 11861, 'Dont Give Up [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/516696.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ho30YHlYaTWEnHUWu1QGpVdU3PQ.jpg'),
(167333, 11861, 'Dont Give Up [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/516697.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gk2YbQl7gtEuDv9zsHLLPubJ5UB.jpg'),
(167334, 11861, 'Dont Give Up [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/516698.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lmNiQWtTcMaYpuFxHepB2MmvNCp.jpg'),
(167335, 11861, 'Dont Give Up [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/516699.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nevdsEJgPFMeFvqP95CySA2ROiI.jpg'),
(167336, 11861, 'Dont Give Up [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/665196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXU1cXEkPgklklWKOH3kczPLvx8.jpg'),
(167337, 11861, 'Dont Give Up [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/665197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXU1cXEkPgklklWKOH3kczPLvx8.jpg'),
(167338, 11861, 'Dont Give Up [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/665198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXU1cXEkPgklklWKOH3kczPLvx8.jpg'),
(167339, 11861, 'Dont Give Up [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/665199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXU1cXEkPgklklWKOH3kczPLvx8.jpg'),
(167340, 11861, 'Dont Give Up [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/665200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXU1cXEkPgklklWKOH3kczPLvx8.jpg'),
(167341, 11861, 'Dont Give Up [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/665201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXU1cXEkPgklklWKOH3kczPLvx8.jpg'),
(167342, 11861, 'Dont Give Up [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/665202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXU1cXEkPgklklWKOH3kczPLvx8.jpg'),
(167343, 11861, 'Dont Give Up [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/665203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXU1cXEkPgklklWKOH3kczPLvx8.jpg'),
(167344, 11861, 'Dont Give Up [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/665204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXU1cXEkPgklklWKOH3kczPLvx8.jpg'),
(167345, 11861, 'Dont Give Up [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/665205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXU1cXEkPgklklWKOH3kczPLvx8.jpg'),
(167346, 11861, 'Dont Give Up [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/665206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXU1cXEkPgklklWKOH3kczPLvx8.jpg'),
(167347, 11861, 'Dont Give Up [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/665207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXU1cXEkPgklklWKOH3kczPLvx8.jpg'),
(167348, 11861, 'Dont Give Up [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/665208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXU1cXEkPgklklWKOH3kczPLvx8.jpg'),
(167349, 11861, 'Dont Give Up [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/665209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lXU1cXEkPgklklWKOH3kczPLvx8.jpg'),
(167350, 11862, 'Febre do Ouro Freddy Dodge ao Resgate S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/516661.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iNmofVeQdyRCjT0fDDk8KREfYt7.jpg'),
(167351, 11862, 'Febre do Ouro Freddy Dodge ao Resgate S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/516662.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/krEvwEeasSYRW9bwYvPU73YDA4E.jpg'),
(167352, 11862, 'Febre do Ouro Freddy Dodge ao Resgate S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/516663.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v0CwmWZW92qNP8aCNMPKuzIZaYq.jpg'),
(167353, 11862, 'Febre do Ouro Freddy Dodge ao Resgate S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/516664.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/56PqLX6FczWKrpP3vmmTpbWwBMC.jpg'),
(167354, 11862, 'Febre do Ouro Freddy Dodge ao Resgate S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/516665.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A1VTGUKLGNGXp4IHfDWIvlJxj5Y.jpg'),
(167355, 11862, 'Febre do Ouro Freddy Dodge ao Resgate S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/516666.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5mBxfrBL878RS4k8iXhGN8z9MAB.jpg'),
(167356, 11863, 'Febre do Ouro Freddy Dodge ao Resgate S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/516667.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3mg6n6RbrZWdayYhMvEMqSgRCrg.jpg'),
(167357, 11863, 'Febre do Ouro Freddy Dodge ao Resgate S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/516668.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aAMKuKNGPYSmTgBmZu1uH5kyCE6.jpg'),
(167358, 11863, 'Febre do Ouro Freddy Dodge ao Resgate S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/516669.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g1hbrvcymZnzsGst1su5z8Gfnfo.jpg'),
(167359, 11863, 'Febre do Ouro Freddy Dodge ao Resgate S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/516670.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wIb99DZmdU505ejxz6vsnhFBosn.jpg'),
(167360, 11863, 'Febre do Ouro Freddy Dodge ao Resgate S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/516671.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5wWY5Tl7EeQ5mfCE1pBKmTGozPF.jpg'),
(167361, 11863, 'Febre do Ouro Freddy Dodge ao Resgate S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/516672.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g3WtEgE9JZWAuIcbzpMv267fVSn.jpg'),
(167362, 11863, 'Febre do Ouro Freddy Dodge ao Resgate S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/516673.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qVXQpOdJ7PGUnqsfI8I4JIoS47f.jpg'),
(167363, 11863, 'Febre do Ouro Freddy Dodge ao Resgate S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/516674.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AdVb7USu67oMtJUHDn6n16JDwq6.jpg'),
(167364, 11863, 'Febre do Ouro Freddy Dodge ao Resgate S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/516675.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oZO9CBmJP9IN3DSJk1ezgHR3wSe.jpg'),
(167365, 11863, 'Febre do Ouro Freddy Dodge ao Resgate S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/516676.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/53kIAHFwYYk1OG0BcWCmhOHUkQU.jpg'),
(167366, 11863, 'Febre do Ouro Freddy Dodge ao Resgate S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/637203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1TH5R8NDfbs96fGYwzNP7VIthzz.jpg'),
(167367, 11864, 'Febre do Ouro Freddy Dodge ao Resgate S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/516678.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ObrKmPACAVhG8uN8vY4HCqn2cn.jpg'),
(167368, 11864, 'Febre do Ouro Freddy Dodge ao Resgate S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/516679.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/av15duvqjEudClvuqSvNa0DL9mv.jpg'),
(167369, 11864, 'Febre do Ouro Freddy Dodge ao Resgate S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/516680.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eqmyMHhngVKjUXrSxpm1VjUO1Tr.jpg'),
(167370, 11864, 'Febre do Ouro Freddy Dodge ao Resgate S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/516681.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1MpceQgv9avRUZ9GS356CANxuTP.jpg'),
(167371, 11864, 'Febre do Ouro Freddy Dodge ao Resgate S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/516682.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fnPlQq9HT0h5mM80qPZW5CfQ3hA.jpg'),
(167372, 11864, 'Febre do Ouro Freddy Dodge ao Resgate S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/516683.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ohzH1Jt7eAzYyVQk1KQmW4Pi5PI.jpg'),
(167373, 11864, 'Febre do Ouro Freddy Dodge ao Resgate S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/516684.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e7tI2vEaT263PboYZtMYkpmkKZ.jpg'),
(167374, 11864, 'Febre do Ouro Freddy Dodge ao Resgate S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/516685.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pBuEe8egiHiCiOUi9LNKstthTAy.jpg'),
(167375, 11864, 'Febre do Ouro Freddy Dodge ao Resgate S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/516686.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dQkS6wy6nHz50HAGiXRoVALCEwR.jpg'),
(167376, 11864, 'Febre do Ouro Freddy Dodge ao Resgate S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/516687.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lfzMTAWEUCYQACuqjCXS6o7kiBB.jpg'),
(167377, 11864, 'Febre do Ouro Freddy Dodge ao Resgate S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/516688.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/31jeNyJMP6vuUJTVjDLqScDTvQR.jpg'),
(167378, 11865, 'Febre do Ouro Freddy Dodge ao Resgate S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/516689.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gP71ucZlDh5g9a8Ilw6EgdfXmAj.jpg'),
(167379, 11865, 'Febre do Ouro Freddy Dodge ao Resgate S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/518538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1TH5R8NDfbs96fGYwzNP7VIthzz.jpg'),
(167380, 11865, 'Febre do Ouro Freddy Dodge ao Resgate S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1TH5R8NDfbs96fGYwzNP7VIthzz.jpg'),
(167381, 11865, 'Febre do Ouro Freddy Dodge ao Resgate S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1TH5R8NDfbs96fGYwzNP7VIthzz.jpg'),
(167382, 11865, 'Febre do Ouro Freddy Dodge ao Resgate S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/675678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1TH5R8NDfbs96fGYwzNP7VIthzz.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(167383, 11865, 'Febre do Ouro Freddy Dodge ao Resgate S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/675679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1TH5R8NDfbs96fGYwzNP7VIthzz.jpg'),
(167384, 11865, 'Febre do Ouro Freddy Dodge ao Resgate S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/675680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1TH5R8NDfbs96fGYwzNP7VIthzz.jpg'),
(167385, 11865, 'Febre do Ouro Freddy Dodge ao Resgate S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/805905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1TH5R8NDfbs96fGYwzNP7VIthzz.jpg'),
(167386, 11865, 'Febre do Ouro Freddy Dodge ao Resgate S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/675681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1TH5R8NDfbs96fGYwzNP7VIthzz.jpg'),
(167387, 11865, 'Febre do Ouro Freddy Dodge ao Resgate S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/675682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1TH5R8NDfbs96fGYwzNP7VIthzz.jpg'),
(167388, 11866, 'Febre do Ouro Freddy Dodge ao Resgate S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/891046.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1TH5R8NDfbs96fGYwzNP7VIthzz.jpg'),
(167389, 11866, 'Febre do Ouro Freddy Dodge ao Resgate S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/894911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1TH5R8NDfbs96fGYwzNP7VIthzz.jpg'),
(167390, 11866, 'Febre do Ouro Freddy Dodge ao Resgate S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/891047.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1TH5R8NDfbs96fGYwzNP7VIthzz.jpg'),
(167391, 11866, 'Febre do Ouro Freddy Dodge ao Resgate S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/891048.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1TH5R8NDfbs96fGYwzNP7VIthzz.jpg'),
(167392, 11866, 'Febre do Ouro Freddy Dodge ao Resgate S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/894912.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1TH5R8NDfbs96fGYwzNP7VIthzz.jpg'),
(167393, 11866, 'Febre do Ouro Freddy Dodge ao Resgate S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/894913.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1TH5R8NDfbs96fGYwzNP7VIthzz.jpg'),
(167394, 11866, 'Febre do Ouro Freddy Dodge ao Resgate S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/895892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1TH5R8NDfbs96fGYwzNP7VIthzz.jpg'),
(167395, 11866, 'Febre do Ouro Freddy Dodge ao Resgate S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/895893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1TH5R8NDfbs96fGYwzNP7VIthzz.jpg'),
(167396, 11867, 'Get Millie Black S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/516660.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7Po6wY7v7R6oj6m7hlAhWjU04QI.jpg'),
(167397, 11867, 'Get Millie Black S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/518470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytXuD2ZP9Q82OzalMaGYoKUUPCG.jpg'),
(167398, 11867, 'Get Millie Black S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/520226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytXuD2ZP9Q82OzalMaGYoKUUPCG.jpg'),
(167399, 11867, 'Get Millie Black S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytXuD2ZP9Q82OzalMaGYoKUUPCG.jpg'),
(167400, 11867, 'Get Millie Black S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/640985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ytXuD2ZP9Q82OzalMaGYoKUUPCG.jpg'),
(167401, 11868, 'Irracional S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/516652.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kdxctgG5M4QCX2S5ACk3eUriQ9c.jpg'),
(167402, 11868, 'Irracional S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/516653.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zfMHPxPDRlQ6ihiIO0A0PqYURrK.jpg'),
(167403, 11868, 'Irracional S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/516654.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lxQXg9uQSVHG8IeqprZqlJPKd2Z.jpg'),
(167404, 11868, 'Irracional S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/516655.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mHNEkkWRytJWiHUDtCx0Bw3t9Pz.jpg'),
(167405, 11868, 'Irracional S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/516656.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5F1HRBE9BQHKvhSKs8qn7TG0XoM.jpg'),
(167406, 11868, 'Irracional S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/516657.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tGulHTzy2uwCPDJ55QbXc752wNg.jpg'),
(167407, 11868, 'Irracional S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/516658.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ucYruyYvoEr2y3J19o9VTWPqKgy.jpg'),
(167408, 11868, 'Irracional S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/516659.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xsirPmkAcmEWWUJ9O1CG520dny.jpg'),
(167409, 11869, 'Mansoes em Frente ao Lago S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/516644.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/38IUHoCwfPyAePhiVZKQIBcR66.jpg'),
(167410, 11869, 'Mansoes em Frente ao Lago S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/516645.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rrpXFXHPWRW3WApkzd8ZNmA8dvW.jpg'),
(167411, 11869, 'Mansoes em Frente ao Lago S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/516646.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d8OpGFvDyb6sC2GHgSKXOZnTYJW.jpg'),
(167412, 11869, 'Mansoes em Frente ao Lago S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/516647.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fzbxD7RkqIuAzUkY2zbzWxK1Zs0.jpg'),
(167413, 11869, 'Mansoes em Frente ao Lago S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/516648.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cXLM6e7Q60JGkf9ixnce4OGECUr.jpg'),
(167414, 11869, 'Mansoes em Frente ao Lago S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/516649.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w9dMZTrriiKVeLQnYhAx9krehkV.jpg'),
(167415, 11869, 'Mansoes em Frente ao Lago S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/516650.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ocWl1wOptVwDuCYp1cE0CImEtDQ.jpg'),
(167416, 11869, 'Mansoes em Frente ao Lago S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/516651.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4kjvic14A73o7sdYJWYqFQXA04I.jpg'),
(167417, 5485, 'A Agencia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/514856.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dtP8VGcSwlZp9x86cB3Y8iVmjJM.jpg'),
(167418, 11870, 'Senna S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/514850.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9OYmljYuqXRXH4jtjFOx690ljv0.jpg'),
(167419, 11870, 'Senna S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/514851.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tOWD8kvs5QgocbCaOymyijqbc09.jpg'),
(167420, 11870, 'Senna S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/514852.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2rTqmiGyFEYvkyAfAaYktmEFFKP.jpg'),
(167421, 11870, 'Senna S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/514853.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4Y4LzchPe0OQ0OiGA2LPZWMQZx.jpg'),
(167422, 11870, 'Senna S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/514854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zuAYVhC7vnKk9jsEuJQqJPB93Pm.jpg'),
(167423, 11870, 'Senna S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/514855.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tmoNp1uqzy2h3Egyhp6WuGAMHij.jpg'),
(167424, 11871, 'The Trunk S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/514842.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qNS6dkFQ4tJ1MDFT32oSSRbzI9z.jpg'),
(167425, 11871, 'The Trunk S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/514843.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dTbETOHes396ELvtqiyqreHkpqn.jpg'),
(167426, 11871, 'The Trunk S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/514844.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l5mRc6YpZYVI4pb1ccbTZ1GmYLm.jpg'),
(167427, 11871, 'The Trunk S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/514845.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qV4kkgxKJIhqyMKN67xrlQ5NMXA.jpg'),
(167428, 11871, 'The Trunk S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/514846.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5LLPKqs3uBANfXAcsqfBV29gu0Q.jpg'),
(167429, 11871, 'The Trunk S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/514847.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7808ApHPSHYWWJB1NO1VGXeVy4X.jpg'),
(167430, 11871, 'The Trunk S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/514848.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nSEZM5FeFvPvGYWhMZZje2CKpZH.jpg'),
(167431, 11871, 'The Trunk S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/514849.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bsz4GfvYZAGHuYexGSRHoz3nNY0.jpg'),
(167432, 11872, 'A Menina que Matou os Pais A Serie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/514774.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rredh5IhKPOUHk89sTBtmHxvFQa.jpg'),
(167433, 11872, 'A Menina que Matou os Pais A Serie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/514775.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fytGRRR7iottnnrYKNHWsvvYug8.jpg'),
(167434, 11872, 'A Menina que Matou os Pais A Serie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/514776.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8KWD6OMhqpW2h3DqWrz5qD0p9Bn.jpg'),
(167435, 11872, 'A Menina que Matou os Pais A Serie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/514777.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fLkRjajYVJyDRww1Ovduj7wB9K4.jpg'),
(167436, 11872, 'A Menina que Matou os Pais A Serie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/514778.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m90r8TQZgnOEUI6u5BaNCRHWrH4.jpg'),
(167437, 11872, 'A Menina que Matou os Pais A Serie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/514779.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fvR798stvJkVF0mz6LQg2JVUQ05.jpg'),
(167438, 11873, 'Amor sem Idade S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/514766.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nMptBbUQ1aBJajpvc91QV0gnQGs.jpg'),
(167439, 11873, 'Amor sem Idade S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/514767.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Zokm6ZYh01yPHdJ71pEHg8pDcZ.jpg'),
(167440, 11873, 'Amor sem Idade S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/514768.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mQlxrcP8hCKQ7t3xEitqrrMDEaE.jpg'),
(167441, 11873, 'Amor sem Idade S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/514769.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dSeRTR92KVU4X8u58qgq7pRowaH.jpg'),
(167442, 11873, 'Amor sem Idade S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/514770.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/XJlG0pJZU7Pp4oc6DFrG8lMHdI.jpg'),
(167443, 11873, 'Amor sem Idade S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/514771.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/314dCSlNHCqdXFKXqWA5UpePnjH.jpg'),
(167444, 11873, 'Amor sem Idade S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/514772.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cdOO1PZggbDvQxvFznXWqVJYBqV.jpg'),
(167445, 11873, 'Amor sem Idade S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/514773.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uhDXbqFaZh77uNOatnlzT0t19uP.jpg'),
(167446, 11874, 'Jerusalem Cidade de Fe e Guerra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/514738.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ijSdvAcYahSAS6ErpZT3jEXQuWd.jpg'),
(167447, 11874, 'Jerusalem Cidade de Fe e Guerra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/514739.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fUYz10mnv6lhT6IPwvGhJt5hXUI.jpg'),
(167448, 11874, 'Jerusalem Cidade de Fe e Guerra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/514740.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/NYAuCXw1M8kfjQHgOkY75I1uJ8.jpg'),
(167449, 11874, 'Jerusalem Cidade de Fe e Guerra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/514741.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h7L94sP3uhCNwgxQbFuuVlbROKw.jpg'),
(167450, 11874, 'Jerusalem Cidade de Fe e Guerra S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/514742.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gNf6IbGRitdHySgVPIlHOK6dwan.jpg'),
(167451, 11874, 'Jerusalem Cidade de Fe e Guerra S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/514743.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nSSGXwBbRiQYps0u5FxVOirbq6t.jpg'),
(167452, 2262, 'Pequenos Incendios por Toda Parte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/514529.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/P3L7n07BXELlNig9dlLUaQC7A6.jpg'),
(167453, 2262, 'Pequenos Incendios por Toda Parte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/514530.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pq0IFO7VMPWFxjKuzvKUrILFb39.jpg'),
(167454, 2262, 'Pequenos Incendios por Toda Parte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/514531.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jTcsmakWh6fefzvNwjDQ5xZtSNy.jpg'),
(167455, 2262, 'Pequenos Incendios por Toda Parte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/514532.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2fK7LumQKzivLT0KFwmIqtmJfe.jpg'),
(167456, 2262, 'Pequenos Incendios por Toda Parte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/514533.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2KIxosp4uOKkNL28VrkOmzYdO4i.jpg'),
(167457, 2262, 'Pequenos Incendios por Toda Parte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/514534.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kCiUFOQz35T3JJPpeyQ00Iqupd3.jpg'),
(167458, 2262, 'Pequenos Incendios por Toda Parte S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/514535.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k8Q60wAYBFUm4B2k72omfuSP5MU.jpg'),
(167459, 2262, 'Pequenos Incendios por Toda Parte S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/514536.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vOHqw28dKsHoQxeTt35D27czsGI.jpg'),
(167460, 4126, 'Raizes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519426.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/34ECnL5P9hHp6VDr9EwgoX3KSoH.jpg'),
(167461, 4126, 'Raizes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519427.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ek9eZrMGsz3QoJwTKw5AUSw5uiC.jpg'),
(167462, 4126, 'Raizes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519428.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zAG8vVfwZKEDxgCwlMCVrqzS16w.jpg'),
(167463, 4126, 'Raizes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519429.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jPo3pJax9YhMRmL2e83canp9JhR.jpg'),
(167464, 4126, 'Raizes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/grUCZEzcKtEK9BImMhM0SJCIJws.jpg'),
(167465, 4126, 'Raizes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/grUCZEzcKtEK9BImMhM0SJCIJws.jpg'),
(167466, 4126, 'Raizes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/grUCZEzcKtEK9BImMhM0SJCIJws.jpg'),
(167467, 4126, 'Raizes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/grUCZEzcKtEK9BImMhM0SJCIJws.jpg'),
(167468, 11875, 'Corrida na Lama S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519421.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qkNmYU5UycJ2pSN1ms6z0FHZI0V.jpg'),
(167469, 11875, 'Corrida na Lama S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519422.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5bd8uryvJodZMd5oBi0HdCvaqYH.jpg'),
(167470, 11875, 'Corrida na Lama S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519423.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vmw5oZ8qq9ljYBGiZYhXfp6oenj.jpg'),
(167471, 11875, 'Corrida na Lama S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519424.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ujnhzBWvLmB1PVB1h0zC7FIygHg.jpg'),
(167472, 11875, 'Corrida na Lama S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519425.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s0OGFiOukOvUfsicaMrJhoVaTA8.jpg'),
(167473, 11875, 'Corrida na Lama S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/521325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sTrMMf011UwGLDi8kKectIJ4SZQ.jpg'),
(167474, 11876, 'Hoteis Estadias Personalizadas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519411.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wBY4ChzC06X0s3FAJoWjEjNOE90.jpg'),
(167475, 11876, 'Hoteis Estadias Personalizadas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519412.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mtNk0q16R9P4E5evDpjjrxUves0.jpg'),
(167476, 11876, 'Hoteis Estadias Personalizadas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519413.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ydIdtlQqk8pLqojHKbWzGl3vvOc.jpg'),
(167477, 11876, 'Hoteis Estadias Personalizadas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519414.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gidJRPu1iCDCjwcQ7iHGKb1FII2.jpg'),
(167478, 11877, 'Hoteis Estadias Personalizadas S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519415.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pTByIJiqWnhXKEaLwYsDL0zZJBQ.jpg'),
(167479, 11877, 'Hoteis Estadias Personalizadas S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519416.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o1dnC2D3jLb8ng1sqHwLuDkbb5e.jpg'),
(167480, 11877, 'Hoteis Estadias Personalizadas S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519417.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w6IOWLLce4M3DRAplxNFUgU7H1B.jpg'),
(167481, 11877, 'Hoteis Estadias Personalizadas S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519418.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3EA4ZK6vpbnrPp1YHGyx4xHcodG.jpg'),
(167482, 11877, 'Hoteis Estadias Personalizadas S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519419.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AbRNUc2N9qXS3v9uqoLhj7ZdEvz.jpg'),
(167483, 11877, 'Hoteis Estadias Personalizadas S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519420.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y9xyp5kAuyocerUj6mTN98YMiHu.jpg'),
(167484, 11878, 'O Conto da Senhora Ok S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519410.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jVvdQTMJ01Vx10ziYaMDMEcrXmU.jpg'),
(167485, 11878, 'O Conto da Senhora Ok S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/525223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(167486, 11878, 'O Conto da Senhora Ok S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/525224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(167487, 11878, 'O Conto da Senhora Ok S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/525225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(167488, 11878, 'O Conto da Senhora Ok S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/643910.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(167489, 11878, 'O Conto da Senhora Ok S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/643911.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(167490, 11878, 'O Conto da Senhora Ok S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(167491, 11878, 'O Conto da Senhora Ok S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/656620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(167492, 11878, 'O Conto da Senhora Ok S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/660219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(167493, 11878, 'O Conto da Senhora Ok S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/660220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(167494, 11878, 'O Conto da Senhora Ok S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/667981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(167495, 11878, 'O Conto da Senhora Ok S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/667982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(167496, 11878, 'O Conto da Senhora Ok S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/671327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(167497, 11878, 'O Conto da Senhora Ok S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/671328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(167498, 11878, 'O Conto da Senhora Ok S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/679082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(167499, 11878, 'O Conto da Senhora Ok S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/679083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(167500, 11879, 'Amor no Natal S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sDBTrntPwNW473xY8R63nd8mmoy.jpg'),
(167501, 11879, 'Amor no Natal S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sDBTrntPwNW473xY8R63nd8mmoy.jpg'),
(167502, 11879, 'Amor no Natal S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sDBTrntPwNW473xY8R63nd8mmoy.jpg'),
(167503, 11879, 'Amor no Natal S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sDBTrntPwNW473xY8R63nd8mmoy.jpg'),
(167504, 11880, 'Cosme e Damiao Quase Santos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5o72hJWRazyPHjB36wygziUM28T.jpg'),
(167505, 11880, 'Cosme e Damiao Quase Santos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5o72hJWRazyPHjB36wygziUM28T.jpg'),
(167506, 11880, 'Cosme e Damiao Quase Santos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5o72hJWRazyPHjB36wygziUM28T.jpg'),
(167507, 11880, 'Cosme e Damiao Quase Santos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5o72hJWRazyPHjB36wygziUM28T.jpg'),
(167508, 11880, 'Cosme e Damiao Quase Santos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5o72hJWRazyPHjB36wygziUM28T.jpg'),
(167509, 11880, 'Cosme e Damiao Quase Santos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5o72hJWRazyPHjB36wygziUM28T.jpg'),
(167510, 11880, 'Cosme e Damiao Quase Santos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5o72hJWRazyPHjB36wygziUM28T.jpg'),
(167511, 11880, 'Cosme e Damiao Quase Santos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5o72hJWRazyPHjB36wygziUM28T.jpg'),
(167512, 11880, 'Cosme e Damiao Quase Santos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5o72hJWRazyPHjB36wygziUM28T.jpg'),
(167513, 11880, 'Cosme e Damiao Quase Santos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5o72hJWRazyPHjB36wygziUM28T.jpg'),
(167514, 11881, 'Ecos de um Pesadelo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519388.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9qJhqNjsZJuIWXg3lFVCwoKEwCB.jpg'),
(167515, 11881, 'Ecos de um Pesadelo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519389.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Zy1fHQio5OuaxdxH99b2v3Ogqi.jpg'),
(167516, 11881, 'Ecos de um Pesadelo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519390.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/di32ZcUMCJkhDndhRKC2qnVzKzP.jpg'),
(167517, 11881, 'Ecos de um Pesadelo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519391.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pFhx7ANADFS0c4cqBSS9J25ek3w.jpg'),
(167518, 11881, 'Ecos de um Pesadelo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519392.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e0yNPaC6aTeFZYvrXVJocmmyKZI.jpg'),
(167519, 11881, 'Ecos de um Pesadelo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519393.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jMDFticSmelwPUGCSenzbzICETp.jpg'),
(167520, 11881, 'Ecos de um Pesadelo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519394.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9IlFDVveVUjxNt27sG6MizKXCwR.jpg'),
(167521, 11881, 'Ecos de um Pesadelo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519395.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w7MS5xMdrZFEQrM87qo8OEwlaSk.jpg'),
(167522, 11882, 'Joan S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519382.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rbI6dTX5AGTPt8b7wvJDVNSpmpP.jpg'),
(167523, 11882, 'Joan S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519383.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/evDS5lFtyKnf6ZFbjEkblS545T1.jpg'),
(167524, 11882, 'Joan S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519384.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qGttr70vqGF6qYJnWkEKqlE2AwP.jpg'),
(167525, 11882, 'Joan S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519385.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/N8RRosxITl0bSzCeIt7XsweIRq.jpg'),
(167526, 11882, 'Joan S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519386.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vQgbXkl5dKqgnWMDGWSzCmGOAdp.jpg'),
(167527, 11882, 'Joan S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519387.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/87TOJLFOMe3nnlX4PQx5ro6ijNz.jpg'),
(167528, 11883, 'Melou S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519376.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6Ziaofers8tlWT4YL5sl54QFthQ.jpg'),
(167529, 11883, 'Melou S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519377.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r1Nkj0KQIxsyiUJl7f2Ts3YOsIr.jpg'),
(167530, 11883, 'Melou S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519378.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uUyQRSl9UAeecd89uULJUHvg8K.jpg'),
(167531, 11883, 'Melou S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519379.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iEa01ENI0NErdKTWRXgQfQfXdCj.jpg'),
(167532, 11883, 'Melou S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519380.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v2EUU3nWKhUCvZsowKiGYfRvRx1.jpg'),
(167533, 11883, 'Melou S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519381.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/98fjshe0kHbZxCwYkaZZnTVLNwt.jpg'),
(167534, 11884, 'Nina the Starry Bride S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519367.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/prZBYyxbMLyiBNq4KhX8JSPLukb.jpg'),
(167535, 11884, 'Nina the Starry Bride S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519368.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uis5LaLtPbe8ghXyXiZ0Sj306QT.jpg'),
(167536, 11884, 'Nina the Starry Bride S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519369.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wLIXV3rSliKFeCXJCTNzBTAZvOC.jpg'),
(167537, 11884, 'Nina the Starry Bride S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519370.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dFLosDDhiteBqOHZk4eqgiLhamy.jpg'),
(167538, 11884, 'Nina the Starry Bride S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519371.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wksq6JJvy2LYgy9bVyNvpE3yPhi.jpg'),
(167539, 11884, 'Nina the Starry Bride S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519372.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xkofQimKFCwCaJubsHXaetxRhK.jpg'),
(167540, 11884, 'Nina the Starry Bride S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519373.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ajDVIRaehUxZjg7wk6XGbDTIxQX.jpg'),
(167541, 11884, 'Nina the Starry Bride S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519374.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A9Gr0a8JCOnRRvpy4vh9VTJs7Cu.jpg'),
(167542, 11884, 'Nina the Starry Bride S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519375.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tlvxofpxLS3H8OrjL7Vy67KtDbm.jpg'),
(167543, 11884, 'Nina the Starry Bride S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/523300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dCO0ihJjo7y7ptzbdHuJ3UEA8MI.jpg'),
(167544, 11884, 'Nina the Starry Bride S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/636972.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dCO0ihJjo7y7ptzbdHuJ3UEA8MI.jpg'),
(167545, 11884, 'Nina the Starry Bride S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/640857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dCO0ihJjo7y7ptzbdHuJ3UEA8MI.jpg'),
(167546, 11885, 'Os Feiticeiros Alem de Waverly Place S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519363.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/28u3Uw9WGS9d4CHvhegqb7X2FRQ.jpg'),
(167547, 11885, 'Os Feiticeiros Alem de Waverly Place S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519364.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qqUPnGiW1X0ljN8jXfgSnlkWgb3.jpg'),
(167548, 11885, 'Os Feiticeiros Alem de Waverly Place S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519365.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3UsZ2BqFJns6aF7XS3rtfSRyNzt.jpg'),
(167549, 11885, 'Os Feiticeiros Alem de Waverly Place S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519366.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bbOKOZdktiE1dYSnnwfqjUGlnd7.jpg'),
(167550, 11885, 'Os Feiticeiros Alem de Waverly Place S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/525120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167551, 11885, 'Os Feiticeiros Alem de Waverly Place S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/525121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167552, 11885, 'Os Feiticeiros Alem de Waverly Place S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/525122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167553, 11885, 'Os Feiticeiros Alem de Waverly Place S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/713503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167554, 11885, 'Os Feiticeiros Alem de Waverly Place S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/640763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167555, 11885, 'Os Feiticeiros Alem de Waverly Place S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/713505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167556, 11885, 'Os Feiticeiros Alem de Waverly Place S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/713506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167557, 11885, 'Os Feiticeiros Alem de Waverly Place S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/713507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167558, 11885, 'Os Feiticeiros Alem de Waverly Place S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/713508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167559, 11885, 'Os Feiticeiros Alem de Waverly Place S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/888153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167560, 11885, 'Os Feiticeiros Alem de Waverly Place S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/789481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167561, 11885, 'Os Feiticeiros Alem de Waverly Place S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/789482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167562, 11885, 'Os Feiticeiros Alem de Waverly Place S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/713512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167563, 11885, 'Os Feiticeiros Alem de Waverly Place S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/753715.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167564, 11885, 'Os Feiticeiros Alem de Waverly Place S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/789485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167565, 11885, 'Os Feiticeiros Alem de Waverly Place S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/789486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167566, 11885, 'Os Feiticeiros Alem de Waverly Place S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/789487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167567, 11886, 'Os Feiticeiros Alem de Waverly Place S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/888154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167568, 11886, 'Os Feiticeiros Alem de Waverly Place S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/888155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167569, 11886, 'Os Feiticeiros Alem de Waverly Place S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/888156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167570, 11886, 'Os Feiticeiros Alem de Waverly Place S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/888157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167571, 11886, 'Os Feiticeiros Alem de Waverly Place S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/890051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167572, 11886, 'Os Feiticeiros Alem de Waverly Place S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/890052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167573, 11886, 'Os Feiticeiros Alem de Waverly Place S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/894874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167574, 11886, 'Os Feiticeiros Alem de Waverly Place S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/894875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167575, 11886, 'Os Feiticeiros Alem de Waverly Place S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/894876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167576, 11886, 'Os Feiticeiros Alem de Waverly Place S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/894877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6Jh8QA7kn6eijlUk9huxDZMDQOz.jpg'),
(167577, 11887, 'Star Wars Skeleton Crew S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519361.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7vv4nyiyiWzi71txLb0UpxEB3MM.jpg'),
(167578, 11887, 'Star Wars Skeleton Crew S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519362.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lsvfGlCsrvi4E9wfxyRCtXOcZt0.jpg'),
(167579, 11887, 'Star Wars Skeleton Crew S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/521867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Dr8mPDBhuSsrGBSx5n8cL1gSki.jpg'),
(167580, 11887, 'Star Wars Skeleton Crew S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/635967.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Dr8mPDBhuSsrGBSx5n8cL1gSki.jpg'),
(167581, 11887, 'Star Wars Skeleton Crew S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/639920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Dr8mPDBhuSsrGBSx5n8cL1gSki.jpg'),
(167582, 11887, 'Star Wars Skeleton Crew S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/657416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Dr8mPDBhuSsrGBSx5n8cL1gSki.jpg'),
(167583, 11887, 'Star Wars Skeleton Crew S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/661298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Dr8mPDBhuSsrGBSx5n8cL1gSki.jpg'),
(167584, 11887, 'Star Wars Skeleton Crew S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/667350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4Dr8mPDBhuSsrGBSx5n8cL1gSki.jpg'),
(167585, 2526, 'The Third Day S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519355.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fOhcF4tn3sV3s1RzzSGNRmVFESe.jpg'),
(167586, 2526, 'The Third Day S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519356.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eQIE2ZFsDDutmwNjUFw0WlrXvCE.jpg'),
(167587, 2526, 'The Third Day S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519357.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mMFdSt5ca6Mb2VWfQ6tV2axVn3h.jpg'),
(167588, 2526, 'The Third Day S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519358.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9dIll4QrrekJDjZbgnIaop77FvY.jpg'),
(167589, 2526, 'The Third Day S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519359.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3nHqwIwGIQxOv4atN35gwAsSjk.jpg'),
(167590, 2526, 'The Third Day S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519360.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rtc5W20OEVim2nKnVEP3yviRIWK.jpg'),
(167591, 11888, 'Zorro (2024) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519347.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rdj3ocwTN166zAi3fN9MdvuHx1t.jpg'),
(167592, 11888, 'Zorro (2024) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519348.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pnGh0wUJlx31itWSjI4ja9Ncsh0.jpg'),
(167593, 11888, 'Zorro (2024) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519349.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p8cElpxrVvuZXfh8LgraTNDUOB5.jpg'),
(167594, 11888, 'Zorro (2024) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519350.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fi2iWjZdoaTuPzfg26gHCyGKoDS.jpg'),
(167595, 11888, 'Zorro (2024) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519351.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qSRxfyh4lob5F8qvvPhElxNUhK2.jpg'),
(167596, 11888, 'Zorro (2024) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519352.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eM8t8gs2Dil8wkDC3ENv8OcxbXi.jpg'),
(167597, 11888, 'Zorro (2024) S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519353.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j3mX9WFKBGkdaXUPtLg956hIbmr.jpg'),
(167598, 11888, 'Zorro (2024) S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519354.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wtm7JU9voGWUhO7jvds1kNYoOU.jpg'),
(167599, 11889, 'Colin from Accounts S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/520748.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8aBvBKTfYBQbfN5M00R9coFfisk.jpg'),
(167600, 11889, 'Colin from Accounts S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/520749.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iD4WZbyJ1Jj8v84dPehCaH5dNlN.jpg'),
(167601, 11889, 'Colin from Accounts S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/520750.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/weskbtFoULTBsLkiamdSZ2Xr4U.jpg'),
(167602, 11889, 'Colin from Accounts S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/520751.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kp0zEx1cKJRUSzEEYPImi63pwpp.jpg'),
(167603, 11889, 'Colin from Accounts S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/520752.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/571sO68XSYRahZ5gwq6ahBiYFiG.jpg'),
(167604, 11889, 'Colin from Accounts S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/520753.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zjWTBiYcGuXZFH2KykNWtI1hhlH.jpg'),
(167605, 11889, 'Colin from Accounts S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/520754.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u9oNm18jJpKI6FIl8bilJOfaNm1.jpg'),
(167606, 11890, 'Colin from Accounts S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/520755.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8o7sA4PvF7mRdoBpHSvMVEbi1mI.jpg'),
(167607, 11890, 'Colin from Accounts S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/520756.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zTo0VEHOfvUYlPMnnJaK8c9ImP.jpg'),
(167608, 11890, 'Colin from Accounts S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/520757.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uFdEqTmUjRRW3h4kNTMde0Oe7Qf.jpg'),
(167609, 11890, 'Colin from Accounts S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/520758.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iUrxkWlMC09RKcqFxWZP6ZAO1pK.jpg'),
(167610, 11890, 'Colin from Accounts S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/520759.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fiVH1cF4d3NCT1glFeQwodoq9PH.jpg'),
(167611, 11890, 'Colin from Accounts S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/520760.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ie64J9TBi934sAdLZpwAOdndUGz.jpg'),
(167612, 11890, 'Colin from Accounts S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/520761.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zqsvuTwqZoZKvHGRcO4hAfOVGEp.jpg'),
(167613, 11890, 'Colin from Accounts S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/520762.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9CRMHiJmjlm3BpKZoFZ8HTPkKf0.jpg'),
(167614, 11891, 'Como Walt Disney Mudou o Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/520742.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pdU0Ohrlm64wsoCQDNi2r8YOB6h.jpg'),
(167615, 11891, 'Como Walt Disney Mudou o Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/520743.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vpjrk1GbottPiazO4alAavhpusd.jpg'),
(167616, 11891, 'Como Walt Disney Mudou o Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/520744.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fHUO50W8K73cNv2HFlIm3QCBV2q.jpg'),
(167617, 11891, 'Como Walt Disney Mudou o Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/520745.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6Op5Knov3xBzwmQa5ry7E7hU0X1.jpg'),
(167618, 11891, 'Como Walt Disney Mudou o Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/520746.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/imWbIGKQW75ssd0SMXHxsZDdNnr.jpg'),
(167619, 11891, 'Como Walt Disney Mudou o Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/520747.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6ThCOGmzPbLHsgY3XvjnxKdu4wy.jpg'),
(167620, 11892, 'Nivel Secreto S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/520734.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uTq7gH61JNxdXKJ09M9NPSb7cU3.jpg'),
(167621, 11892, 'Nivel Secreto S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/520735.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/njbNZISOfbQznEUUMHAT89E2uYH.jpg'),
(167622, 11892, 'Nivel Secreto S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/520736.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Ak8R6xbIQ5a7usseQuT6yQmBthH.jpg'),
(167623, 11892, 'Nivel Secreto S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/520737.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yM0u46C7VYDQnzs09g1x3sRZREu.jpg'),
(167624, 11892, 'Nivel Secreto S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/520738.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8rVRCKC7STJDm8qaFsfa5iLVllP.jpg'),
(167625, 11892, 'Nivel Secreto S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/520739.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iGFxEE7a6z6960GcKAD2gdntjKq.jpg'),
(167626, 11892, 'Nivel Secreto S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/520740.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u5IZe5K81ZJGpsT2LVTMXdw10p8.jpg'),
(167627, 11892, 'Nivel Secreto S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/520741.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lGR7tEaOe7lddX6XKtoneAeHCJ.jpg'),
(167628, 11892, 'Nivel Secreto S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/657242.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pdDgjTF1FEZZCu7IdSCbmOcK0r3.jpg'),
(167629, 11892, 'Nivel Secreto S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/657243.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yyKpXU19BGsUWuivNMtUZBWTsE.jpg'),
(167630, 11892, 'Nivel Secreto S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/657244.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/blNVpZv3XyVUQgAORvjwkUkEaWQ.jpg'),
(167631, 11892, 'Nivel Secreto S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/657245.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uiG9ZDBuNXT3GNhlAvos14e5e8M.jpg'),
(167632, 11892, 'Nivel Secreto S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/657246.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yKlOU6784G2FA1MRPuT6EsSMoo8.jpg'),
(167633, 11892, 'Nivel Secreto S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/657247.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pxKUuwAnI8JPI60dq1ASpYsoFJX.jpg'),
(167634, 11892, 'Nivel Secreto S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/657248.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A0eSztjkZpxf6YOSDluXnFdn3RK.jpg'),
(167635, 11893, 'Meu Querido Guardiao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519934.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eBmy21FBdpH6fcmnmqmQjpTC8iw.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(167636, 11893, 'Meu Querido Guardiao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519935.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9s8EMdiSQfAeENHOqZ9RRBS3ImY.jpg'),
(167637, 11893, 'Meu Querido Guardiao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519936.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1gut7HXRpCAMxIQNuvXPYhCukW8.jpg'),
(167638, 11893, 'Meu Querido Guardiao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519937.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fHuZBeTIwzMSzlq5LLPa1g2h3pa.jpg'),
(167639, 11893, 'Meu Querido Guardiao [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519938.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m6n7wUUU5ozi41uqNmrRVe1nQXs.jpg'),
(167640, 11893, 'Meu Querido Guardiao [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519939.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ystpPOylK8YohMRCpWrwZETN6j6.jpg'),
(167641, 11893, 'Meu Querido Guardiao [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519940.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6VTZO58PjzIGMMTpGj5FXz9elJl.jpg'),
(167642, 11893, 'Meu Querido Guardiao [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519941.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zhafbcCIgfCTU62f6QToemUqATB.jpg'),
(167643, 11893, 'Meu Querido Guardiao [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519942.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/93SqrpjxVobJNQYNU5V3ivi2IVC.jpg'),
(167644, 11893, 'Meu Querido Guardiao [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519943.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/79hRdJ9cQ80uyuSYd8qW8xGcphc.jpg'),
(167645, 11893, 'Meu Querido Guardiao [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/519944.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2RoEJl9WA3A9s8eo0ypKbzTjR0Z.jpg'),
(167646, 11893, 'Meu Querido Guardiao [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/519945.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8DFLRXKQ4XfLBCjFBv5tzAcTLR2.jpg'),
(167647, 11893, 'Meu Querido Guardiao [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/519946.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1M1opvl7209oFz17FcS5PPmwsiY.jpg'),
(167648, 11893, 'Meu Querido Guardiao [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/519947.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cnyCtG1IINn09V6jeodtU91PA7.jpg'),
(167649, 11893, 'Meu Querido Guardiao [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/519948.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9MhyvXB59vJ8zBTVdvzFDOWzfax.jpg'),
(167650, 11893, 'Meu Querido Guardiao [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/519949.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bK1sJOzVs44WKRl9fZZsVC2Rt6t.jpg'),
(167651, 11893, 'Meu Querido Guardiao [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/519950.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lvbvd1JqduelF71pk6raIWjPpqy.jpg'),
(167652, 11893, 'Meu Querido Guardiao [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/519951.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6FX4EHEMXbTqfneu2L6E8BXNbxq.jpg'),
(167653, 11893, 'Meu Querido Guardiao [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/519952.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3qxCcK04nRcAc7WO3AwTRQMGdeI.jpg'),
(167654, 11893, 'Meu Querido Guardiao [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/519953.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AgrXHDfrrKHS3VBIgT2cIqrqIsn.jpg'),
(167655, 11893, 'Meu Querido Guardiao [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/519954.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gZPcFr6bEf5Mq3Cs6EeIDStIU6S.jpg'),
(167656, 11893, 'Meu Querido Guardiao [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/519955.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h8DVQzKAAxiYGBhoAVNlfPlUFKb.jpg'),
(167657, 11893, 'Meu Querido Guardiao [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/519956.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rzglRuI08cjO1bgIQqj0JCK6T5S.jpg'),
(167658, 11893, 'Meu Querido Guardiao [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/519957.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mKwf5KmlEGJyMDqVm6EXbDCb6Zd.jpg'),
(167659, 11893, 'Meu Querido Guardiao [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/519958.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l60lDNVr2UUlROv1WBrG2t9JPTv.jpg'),
(167660, 11893, 'Meu Querido Guardiao [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/519959.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m139o7sxtsNjMc7j7AODCVMCyci.jpg'),
(167661, 11893, 'Meu Querido Guardiao [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/519960.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k5vxvl7gYjK6iDYSIk825g8N15F.jpg'),
(167662, 11893, 'Meu Querido Guardiao [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/519961.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4YYpxzT6jPfincjaMCcDW3N5ELf.jpg'),
(167663, 11893, 'Meu Querido Guardiao [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/519962.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2LTMLkshsMVf6qpksZPYUI7JGiO.jpg'),
(167664, 11893, 'Meu Querido Guardiao [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/519963.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tQpkEk7d5KBXC9zbAgE5n63zSpc.jpg'),
(167665, 11893, 'Meu Querido Guardiao [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/519964.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pij9AumMu8Oj49LV09WD0Aowh1e.jpg'),
(167666, 11893, 'Meu Querido Guardiao [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/519965.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3yVISEysML47qd8wvwqBBriNdf0.jpg'),
(167667, 11893, 'Meu Querido Guardiao [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/519966.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zlLWkGNPbBku3OoaIWIOPhTFKoD.jpg'),
(167668, 11893, 'Meu Querido Guardiao [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/519967.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ctw7yCoHorwPme1G5jg3GrAIV9E.jpg'),
(167669, 11893, 'Meu Querido Guardiao [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/519968.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u7tgewb8wiqrtMHfeYrpTlvCcte.jpg'),
(167670, 11893, 'Meu Querido Guardiao [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/519969.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h6JzFkFxqDgxdwsM4Y0NCbqNssu.jpg'),
(167671, 11893, 'Meu Querido Guardiao [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/519970.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rrolsEhtUW4j8rjBPS8DnlnCYnF.jpg'),
(167672, 11893, 'Meu Querido Guardiao [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/519971.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xJuxOwQNf30FkhkOvUocBXphXjK.jpg'),
(167673, 11893, 'Meu Querido Guardiao [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/519972.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9AJq7kn0uu7piOx0I1yWLO6zJxx.jpg'),
(167674, 11893, 'Meu Querido Guardiao [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/519973.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wQQNdr7jtMy8WIthvhOhXWb1Okv.jpg'),
(167675, 11894, 'A Cozinha do Jinny [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519915.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ejTI2eNkTKDylAFJNFxqtcHd0mF.jpg'),
(167676, 11894, 'A Cozinha do Jinny [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519916.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hBjKWwyA8Raq43c4K6BLdpnuFYG.jpg'),
(167677, 11894, 'A Cozinha do Jinny [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519917.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s9dBplzC5ZqkacHnAsvomlmgQUG.jpg'),
(167678, 11894, 'A Cozinha do Jinny [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519918.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j2SwZDQBHyszKbIQwnLyRdik97O.jpg'),
(167679, 11894, 'A Cozinha do Jinny [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519919.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wdcj1Elev1nCiFLWPxhGUE8ihf8.jpg'),
(167680, 11894, 'A Cozinha do Jinny [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519920.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wi9Jwm2vdg0djyzwSRN6U2QyxR7.jpg'),
(167681, 11894, 'A Cozinha do Jinny [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519921.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/61iImT72vYrclEpVEejQoGpzEok.jpg'),
(167682, 11894, 'A Cozinha do Jinny [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519922.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sGvV6lJ26G3z98U8u80RNja0uYE.jpg'),
(167683, 11894, 'A Cozinha do Jinny [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519923.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/grD4wFbolhJhNKmRJ2i1Crgnv6.jpg'),
(167684, 11894, 'A Cozinha do Jinny [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519924.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yAg5upKNGoZYbIq8kiB3COYRtD9.jpg'),
(167685, 11894, 'A Cozinha do Jinny [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/519925.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iTnEpmQ5yue546e8yaF6yXH6PU6.jpg'),
(167686, 11895, 'A Cozinha do Jinny [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519926.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4qfg4KNhd4sNnpIlrmCLsu1t7pc.jpg'),
(167687, 11895, 'A Cozinha do Jinny [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519927.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yAQFnh0DF1auFWYgdfpKmdYMnJR.jpg'),
(167688, 11895, 'A Cozinha do Jinny [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519928.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nrkTh2TyiuEPreDsdYQ3vsIpxqt.jpg'),
(167689, 11895, 'A Cozinha do Jinny [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519929.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6bdTLY9jwcdutVmc3LsBhSMHl2E.jpg'),
(167690, 11895, 'A Cozinha do Jinny [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519930.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4Tp3At3S6kUnoZYRnWvkSFod9qL.jpg'),
(167691, 11895, 'A Cozinha do Jinny [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519931.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7J60v4C0eE9PwrppwyASaIK52fm.jpg'),
(167692, 11895, 'A Cozinha do Jinny [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519932.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jPl8yUaipnVDhoBt5ZVuwhAEeIm.jpg'),
(167693, 11895, 'A Cozinha do Jinny [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519933.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gIIZE49cqS9tSwK7yzmYlwOZrcX.jpg'),
(167694, 11896, 'AARO All domain Anomaly Resolution Office [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519910.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qY23YI9IgXm6CEOYL0PUWcgDv9A.jpg'),
(167695, 11896, 'AARO All domain Anomaly Resolution Office [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519911.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/isVF2JvaeWmgQVq6tPEdeUPUnF.jpg'),
(167696, 11896, 'AARO All domain Anomaly Resolution Office [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519912.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cI49hBFbxT4CpfHhNip0OrGlxiS.jpg'),
(167697, 11896, 'AARO All domain Anomaly Resolution Office [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519913.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tUImH3vEvBuJCk3muUH5CwU8hfr.jpg'),
(167698, 11896, 'AARO All domain Anomaly Resolution Office [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/523996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7upF6jPqMvgouYioPiFKYHQaF6Y.jpg'),
(167699, 11896, 'AARO All domain Anomaly Resolution Office [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/660849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7upF6jPqMvgouYioPiFKYHQaF6Y.jpg'),
(167700, 11896, 'AARO All domain Anomaly Resolution Office [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/660850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7upF6jPqMvgouYioPiFKYHQaF6Y.jpg'),
(167701, 11896, 'AARO All domain Anomaly Resolution Office [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/660851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7upF6jPqMvgouYioPiFKYHQaF6Y.jpg'),
(167702, 11896, 'AARO All domain Anomaly Resolution Office [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/660852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7upF6jPqMvgouYioPiFKYHQaF6Y.jpg'),
(167703, 11896, 'AARO All domain Anomaly Resolution Office [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/660853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7upF6jPqMvgouYioPiFKYHQaF6Y.jpg'),
(167704, 11897, 'Angry Birds A Ilha Misteriosa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519886.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pYPrdGbiwcAPgMNWvmY7VQ55ohs.jpg'),
(167705, 11897, 'Angry Birds A Ilha Misteriosa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519887.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jq4tWpAB6pH1UI93GcaqIdGsf5J.jpg'),
(167706, 11897, 'Angry Birds A Ilha Misteriosa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519888.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bSNe1wGVOCgkQHxJC863H5oyBnX.jpg'),
(167707, 11897, 'Angry Birds A Ilha Misteriosa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519889.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sWW3sQazujK1RHB6weysAIrS3Mt.jpg'),
(167708, 11897, 'Angry Birds A Ilha Misteriosa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519890.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/37SDYRCk2kZelXeMeDBx6LxgmGy.jpg'),
(167709, 11897, 'Angry Birds A Ilha Misteriosa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519891.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9x6PGj4XHOCAbTqFGy1Hr1oBL6x.jpg'),
(167710, 11897, 'Angry Birds A Ilha Misteriosa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519892.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tDlvvqZ7N3jcxNdozgo5RY6wrNf.jpg'),
(167711, 11897, 'Angry Birds A Ilha Misteriosa S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519893.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rwDx6GHbL3WQTc1ZADCLdHLcb9g.jpg'),
(167712, 11897, 'Angry Birds A Ilha Misteriosa S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hCAtDMQx8cwwQZK7H7HGZhPu2GO.jpg'),
(167713, 11897, 'Angry Birds A Ilha Misteriosa S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hCAtDMQx8cwwQZK7H7HGZhPu2GO.jpg'),
(167714, 11897, 'Angry Birds A Ilha Misteriosa S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/519896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hCAtDMQx8cwwQZK7H7HGZhPu2GO.jpg'),
(167715, 11897, 'Angry Birds A Ilha Misteriosa S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/519897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hCAtDMQx8cwwQZK7H7HGZhPu2GO.jpg'),
(167716, 11897, 'Angry Birds A Ilha Misteriosa S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/519898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hCAtDMQx8cwwQZK7H7HGZhPu2GO.jpg'),
(167717, 11897, 'Angry Birds A Ilha Misteriosa S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/519899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hCAtDMQx8cwwQZK7H7HGZhPu2GO.jpg'),
(167718, 11897, 'Angry Birds A Ilha Misteriosa S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/519900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hCAtDMQx8cwwQZK7H7HGZhPu2GO.jpg'),
(167719, 11897, 'Angry Birds A Ilha Misteriosa S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/519901.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hCAtDMQx8cwwQZK7H7HGZhPu2GO.jpg'),
(167720, 11897, 'Angry Birds A Ilha Misteriosa S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/519902.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hCAtDMQx8cwwQZK7H7HGZhPu2GO.jpg'),
(167721, 11897, 'Angry Birds A Ilha Misteriosa S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/519903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hCAtDMQx8cwwQZK7H7HGZhPu2GO.jpg'),
(167722, 11897, 'Angry Birds A Ilha Misteriosa S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/519904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hCAtDMQx8cwwQZK7H7HGZhPu2GO.jpg'),
(167723, 11897, 'Angry Birds A Ilha Misteriosa S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/519905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hCAtDMQx8cwwQZK7H7HGZhPu2GO.jpg'),
(167724, 11897, 'Angry Birds A Ilha Misteriosa S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/519906.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hCAtDMQx8cwwQZK7H7HGZhPu2GO.jpg'),
(167725, 11897, 'Angry Birds A Ilha Misteriosa S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/519907.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hCAtDMQx8cwwQZK7H7HGZhPu2GO.jpg'),
(167726, 11897, 'Angry Birds A Ilha Misteriosa S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/519908.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hCAtDMQx8cwwQZK7H7HGZhPu2GO.jpg'),
(167727, 11897, 'Angry Birds A Ilha Misteriosa S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/519909.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hCAtDMQx8cwwQZK7H7HGZhPu2GO.jpg'),
(167728, 11898, 'As Aventuras de Minuano Kid S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519882.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xNClbPSOiJUOppPYAZIuACmyTEh.jpg'),
(167729, 11898, 'As Aventuras de Minuano Kid S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519883.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3RQeyAhBGzbhfC9mXlSv3UzerfL.jpg'),
(167730, 11898, 'As Aventuras de Minuano Kid S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519884.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rPLUI9zLLYC1fBQOfgl6iuKMShH.jpg'),
(167731, 11898, 'As Aventuras de Minuano Kid S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519885.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g3ReP5kbceMDAMmKV6AI5PyWVNo.jpg'),
(167732, 4699, 'As Novas Aventuras do Superman S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519848.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rTxgUc1yDLD27DrgI2ATZ2pL1ko.jpg'),
(167733, 4699, 'As Novas Aventuras do Superman S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519849.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1PI9oubkFAjGhHoEYPG00o4Gl6x.jpg'),
(167734, 4699, 'As Novas Aventuras do Superman S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519850.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fATS90FjAilkF24tRciB0r0is4B.jpg'),
(167735, 4699, 'As Novas Aventuras do Superman S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519851.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ej2LZAtpIO5JSDRSAGvhjrlIFPl.jpg'),
(167736, 4699, 'As Novas Aventuras do Superman S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519852.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vplrwOSaL1sKaW0FKxpPxCSSbsz.jpg'),
(167737, 4699, 'As Novas Aventuras do Superman S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519853.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m6Wh7QN3u1SPtneNcCBfTFn2VzD.jpg'),
(167738, 4699, 'As Novas Aventuras do Superman S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519854.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6NMEmzXep5FHL2rEJiwWZc1RUBU.jpg'),
(167739, 4699, 'As Novas Aventuras do Superman S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519855.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7Z3Vpv0GckNKOsZRAOSdXGN478c.jpg'),
(167740, 4699, 'As Novas Aventuras do Superman S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519856.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9Wygc1rwo1JzubB5iU0bz6jngdA.jpg'),
(167741, 4699, 'As Novas Aventuras do Superman S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519857.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fA2ZBERezRxoW2YtzWa2D3uTwBm.jpg'),
(167742, 4699, 'As Novas Aventuras do Superman S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/519858.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/daTfLUH8xWEJfffjoCIG6ADWYBm.jpg'),
(167743, 4699, 'As Novas Aventuras do Superman S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/519859.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jeNvSZ1tZFvVOr66OFwUD8Jecxc.jpg'),
(167744, 4699, 'As Novas Aventuras do Superman S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/519860.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1UMDQXmNfKyLJaw0H7v2lGtyoNf.jpg'),
(167745, 4699, 'As Novas Aventuras do Superman S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/519861.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nU35B9R18Kgpm0VPGDT9HEEeaZP.jpg'),
(167746, 4699, 'As Novas Aventuras do Superman S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/519862.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t57B39QCr2lTn4pv9jlbbzXXZiQ.jpg'),
(167747, 4699, 'As Novas Aventuras do Superman S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/519863.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4kMCb7uWCq6MSF8Io2LKB9WUdvg.jpg'),
(167748, 4699, 'As Novas Aventuras do Superman S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/519864.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bBGvHN8xBEr8s6DJBzAXSGazi36.jpg'),
(167749, 4699, 'As Novas Aventuras do Superman S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/519865.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hkY8kCQTKwVCp8tAfEIkdExsFpu.jpg'),
(167750, 4700, 'As Novas Aventuras do Superman S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(167751, 4700, 'As Novas Aventuras do Superman S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(167752, 4700, 'As Novas Aventuras do Superman S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(167753, 4700, 'As Novas Aventuras do Superman S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(167754, 4700, 'As Novas Aventuras do Superman S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(167755, 4700, 'As Novas Aventuras do Superman S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(167756, 4700, 'As Novas Aventuras do Superman S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(167757, 4700, 'As Novas Aventuras do Superman S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(167758, 4701, 'As Novas Aventuras do Superman S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(167759, 4701, 'As Novas Aventuras do Superman S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(167760, 4701, 'As Novas Aventuras do Superman S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(167761, 4701, 'As Novas Aventuras do Superman S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(167762, 4701, 'As Novas Aventuras do Superman S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(167763, 4701, 'As Novas Aventuras do Superman S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(167764, 4701, 'As Novas Aventuras do Superman S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(167765, 4701, 'As Novas Aventuras do Superman S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/btvQB1z7UxivCJxUfViFNKMxbNk.jpg'),
(167766, 11899, 'Bela Vida [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519837.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a6hGSQZsqW9uDBMQBpE3vE7Oyfe.jpg'),
(167767, 11899, 'Bela Vida [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519838.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qaItqmleYLLdc9V91DhmP2DRgBw.jpg'),
(167768, 11899, 'Bela Vida [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519839.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bb7PMQgusnWHgEHD9HD76xXr7DI.jpg'),
(167769, 11899, 'Bela Vida [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519840.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sAm7zHQMiH4O1rFPw5GLxrzxL8p.jpg'),
(167770, 11899, 'Bela Vida [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519841.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k42CVftwgYNm7jYUysqgV2YXNaq.jpg'),
(167771, 11899, 'Bela Vida [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519842.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i0f7SzR1xwQQmEuaMsPhOYlasBb.jpg'),
(167772, 11899, 'Bela Vida [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519843.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d35k9KYSCXY277DX7Zu1B2Jfz2S.jpg'),
(167773, 11899, 'Bela Vida [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519844.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1HKyenYDmgsFkQMlIYUOcMHs2HK.jpg'),
(167774, 11899, 'Bela Vida [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519845.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v1fU3Ej8TKr4NnivbqjTlbeNmQt.jpg'),
(167775, 11899, 'Bela Vida [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519846.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gIN0L6bpaN5HdeY7pUNqimToxk5.jpg'),
(167776, 11899, 'Bela Vida [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/519847.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5LnIMYH6AqhbNuTTpUwV9PrsawD.jpg'),
(167777, 11900, 'Biduzidos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/phrRoWxoOZTlZxy1V2MDtIfvGgL.jpg'),
(167778, 11901, 'Black Doves S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519830.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ctFX9iQwMSqhcdiN9BqigzDKQzC.jpg'),
(167779, 11901, 'Black Doves S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519831.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rUWap4kNKKvvOLOZrwrII8RM6U0.jpg'),
(167780, 11901, 'Black Doves S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519832.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kx2PdT0WNFH9AElJCp9coUVAqaP.jpg'),
(167781, 11901, 'Black Doves S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519833.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zMmFARe3eOOtisNpRla3lHzvnJD.jpg'),
(167782, 11901, 'Black Doves S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519834.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uxJjXlsaerWrjPOCowoxtbnVIgL.jpg'),
(167783, 11901, 'Black Doves S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519835.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jpOGtvNoPNfn8DO69RIiPiZhuRn.jpg'),
(167784, 11902, 'Can You Hear My Heart [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjZm22oqpTY7luCl13X8XlhhsKt.jpg'),
(167785, 11902, 'Can You Hear My Heart [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjZm22oqpTY7luCl13X8XlhhsKt.jpg'),
(167786, 11902, 'Can You Hear My Heart [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjZm22oqpTY7luCl13X8XlhhsKt.jpg'),
(167787, 11902, 'Can You Hear My Heart [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjZm22oqpTY7luCl13X8XlhhsKt.jpg'),
(167788, 11902, 'Can You Hear My Heart [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjZm22oqpTY7luCl13X8XlhhsKt.jpg'),
(167789, 11902, 'Can You Hear My Heart [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjZm22oqpTY7luCl13X8XlhhsKt.jpg'),
(167790, 11902, 'Can You Hear My Heart [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjZm22oqpTY7luCl13X8XlhhsKt.jpg'),
(167791, 11902, 'Can You Hear My Heart [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjZm22oqpTY7luCl13X8XlhhsKt.jpg'),
(167792, 11902, 'Can You Hear My Heart [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjZm22oqpTY7luCl13X8XlhhsKt.jpg'),
(167793, 11902, 'Can You Hear My Heart [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjZm22oqpTY7luCl13X8XlhhsKt.jpg'),
(167794, 11902, 'Can You Hear My Heart [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/519824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjZm22oqpTY7luCl13X8XlhhsKt.jpg'),
(167795, 11902, 'Can You Hear My Heart [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/519825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjZm22oqpTY7luCl13X8XlhhsKt.jpg'),
(167796, 11902, 'Can You Hear My Heart [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/519826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjZm22oqpTY7luCl13X8XlhhsKt.jpg'),
(167797, 11902, 'Can You Hear My Heart [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/519827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjZm22oqpTY7luCl13X8XlhhsKt.jpg'),
(167798, 11902, 'Can You Hear My Heart [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/519828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjZm22oqpTY7luCl13X8XlhhsKt.jpg'),
(167799, 11902, 'Can You Hear My Heart [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/519829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fjZm22oqpTY7luCl13X8XlhhsKt.jpg'),
(167800, 11903, 'Churchill em Guerra S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519810.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4cLLgnOsWRwGcecVkcCabxZWybp.jpg'),
(167801, 11903, 'Churchill em Guerra S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519811.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yOqdUOYLdAFjKy1v9j1PGERddzd.jpg'),
(167802, 11903, 'Churchill em Guerra S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519812.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/62tzafFuZyOOtr0t2XZfRNIbl9v.jpg'),
(167803, 11903, 'Churchill em Guerra S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519813.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iTezpSbC4urpKSof7FG4Pve3UBe.jpg'),
(167804, 11904, 'Cinderella Game [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167805, 11904, 'Cinderella Game [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167806, 11904, 'Cinderella Game [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167807, 11904, 'Cinderella Game [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167808, 11904, 'Cinderella Game [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/637342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167809, 11904, 'Cinderella Game [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/637343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167810, 11904, 'Cinderella Game [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167811, 11904, 'Cinderella Game [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167812, 11904, 'Cinderella Game [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/637346.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167813, 11904, 'Cinderella Game [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/637347.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167814, 11904, 'Cinderella Game [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/783488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167815, 11904, 'Cinderella Game [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/783489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167816, 11904, 'Cinderella Game [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/783490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167817, 11904, 'Cinderella Game [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/783491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167818, 11904, 'Cinderella Game [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/783492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167819, 11904, 'Cinderella Game [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/783493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167820, 11904, 'Cinderella Game [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/783494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167821, 11904, 'Cinderella Game [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/783495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167822, 11904, 'Cinderella Game [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/783496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167823, 11904, 'Cinderella Game [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/783497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167824, 11904, 'Cinderella Game [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/783498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167825, 11904, 'Cinderella Game [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/783499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167826, 11904, 'Cinderella Game [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/783500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167827, 11904, 'Cinderella Game [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/783501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167828, 11904, 'Cinderella Game [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/783502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167829, 11904, 'Cinderella Game [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/783503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167830, 11904, 'Cinderella Game [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/783504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167831, 11904, 'Cinderella Game [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/783505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167832, 11904, 'Cinderella Game [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/783506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167833, 11904, 'Cinderella Game [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/783507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167834, 11904, 'Cinderella Game [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/783508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167835, 11904, 'Cinderella Game [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/783509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167836, 11904, 'Cinderella Game [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/783510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167837, 11904, 'Cinderella Game [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/783511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167838, 11904, 'Cinderella Game [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/783512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167839, 11904, 'Cinderella Game [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/783513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167840, 11904, 'Cinderella Game [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/783514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167841, 11904, 'Cinderella Game [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/783515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167842, 11904, 'Cinderella Game [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/783516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167843, 11904, 'Cinderella Game [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/783517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167844, 11904, 'Cinderella Game [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/783518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167845, 11904, 'Cinderella Game [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/783519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167846, 11904, 'Cinderella Game [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/783520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167847, 11904, 'Cinderella Game [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/783521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167848, 11904, 'Cinderella Game [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/783522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167849, 11904, 'Cinderella Game [L] S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/783523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167850, 11904, 'Cinderella Game [L] S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/783524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167851, 11904, 'Cinderella Game [L] S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/783525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167852, 11904, 'Cinderella Game [L] S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/783526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167853, 11904, 'Cinderella Game [L] S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/783527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167854, 11904, 'Cinderella Game [L] S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/783528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167855, 11904, 'Cinderella Game [L] S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/783529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167856, 11904, 'Cinderella Game [L] S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/783530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167857, 11904, 'Cinderella Game [L] S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/783531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167858, 11904, 'Cinderella Game [L] S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/783532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167859, 11904, 'Cinderella Game [L] S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/783533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167860, 11904, 'Cinderella Game [L] S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/783534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167861, 11904, 'Cinderella Game [L] S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/783535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167862, 11904, 'Cinderella Game [L] S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/783536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167863, 11904, 'Cinderella Game [L] S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/783537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167864, 11904, 'Cinderella Game [L] S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/783538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167865, 11904, 'Cinderella Game [L] S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/783539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167866, 11904, 'Cinderella Game [L] S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/783540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167867, 11904, 'Cinderella Game [L] S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/783541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167868, 11904, 'Cinderella Game [L] S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/783542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167869, 11904, 'Cinderella Game [L] S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/783543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167870, 11904, 'Cinderella Game [L] S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/783544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167871, 11904, 'Cinderella Game [L] S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/783545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167872, 11904, 'Cinderella Game [L] S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/783546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167873, 11904, 'Cinderella Game [L] S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/783547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167874, 11904, 'Cinderella Game [L] S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/783548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167875, 11904, 'Cinderella Game [L] S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/783549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167876, 11904, 'Cinderella Game [L] S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/783550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167877, 11904, 'Cinderella Game [L] S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/783551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167878, 11904, 'Cinderella Game [L] S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/783552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167879, 11904, 'Cinderella Game [L] S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/783553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167880, 11904, 'Cinderella Game [L] S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/783554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167881, 11904, 'Cinderella Game [L] S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/783555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167882, 11904, 'Cinderella Game [L] S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/783556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167883, 11904, 'Cinderella Game [L] S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/783557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167884, 11904, 'Cinderella Game [L] S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/783558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167885, 11904, 'Cinderella Game [L] S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/783559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(167886, 11904, 'Cinderella Game [L] S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/783560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167887, 11904, 'Cinderella Game [L] S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/783561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167888, 11904, 'Cinderella Game [L] S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/783562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167889, 11904, 'Cinderella Game [L] S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/783563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167890, 11904, 'Cinderella Game [L] S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/783564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167891, 11904, 'Cinderella Game [L] S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/783565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167892, 11904, 'Cinderella Game [L] S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/783566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167893, 11904, 'Cinderella Game [L] S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/783567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167894, 11904, 'Cinderella Game [L] S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/783568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167895, 11904, 'Cinderella Game [L] S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/783569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167896, 11904, 'Cinderella Game [L] S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/783570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167897, 11904, 'Cinderella Game [L] S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/783571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167898, 11904, 'Cinderella Game [L] S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/783572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167899, 11904, 'Cinderella Game [L] S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/783573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167900, 11904, 'Cinderella Game [L] S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/783574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167901, 11904, 'Cinderella Game [L] S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/783575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167902, 11904, 'Cinderella Game [L] S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/783576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167903, 11904, 'Cinderella Game [L] S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/783577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167904, 11904, 'Cinderella Game [L] S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/783578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d9e3lllSb9NISv6vf1q6KQzAueY.jpg'),
(167905, 11905, 'Comando das Criaturas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519805.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5mCMDiAh0AE4EicA8nY1jr28Kom.jpg'),
(167906, 11905, 'Comando das Criaturas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519806.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xdIQ9pNmNzdxU2AHJeESFSwMjFT.jpg'),
(167907, 11905, 'Comando das Criaturas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/523541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cZ3VuXRare4XUE3z2DSH6zwBNp9.jpg'),
(167908, 11905, 'Comando das Criaturas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/639308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cZ3VuXRare4XUE3z2DSH6zwBNp9.jpg'),
(167909, 11905, 'Comando das Criaturas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/641088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cZ3VuXRare4XUE3z2DSH6zwBNp9.jpg'),
(167910, 11905, 'Comando das Criaturas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/659668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cZ3VuXRare4XUE3z2DSH6zwBNp9.jpg'),
(167911, 11905, 'Comando das Criaturas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/663088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cZ3VuXRare4XUE3z2DSH6zwBNp9.jpg'),
(167912, 11906, 'Doug O Robo Curioso S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519779.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wLPvdpmYw89Zj5dR22VvQH07H4Y.jpg'),
(167913, 11906, 'Doug O Robo Curioso S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519780.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7SujjE6RQQ077FTc33KaEvSEriz.jpg'),
(167914, 11906, 'Doug O Robo Curioso S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519781.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jOMaAfZFRNxNSxS7ZmM5laryj7D.jpg'),
(167915, 11906, 'Doug O Robo Curioso S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519782.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wdqLW1rexvf7J4axfaL1fxzA6sz.jpg'),
(167916, 11906, 'Doug O Robo Curioso S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519783.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lYbbyLDd6wLNZlsiK8bwwB42uq8.jpg'),
(167917, 11906, 'Doug O Robo Curioso S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519784.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v5SGHBfIheGRAoNSV3Ykj3LqrAP.jpg'),
(167918, 11906, 'Doug O Robo Curioso S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519785.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kj4kriyoRHkJzyB1rdCUkaOHoTZ.jpg'),
(167919, 11906, 'Doug O Robo Curioso S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r0h6WfIkogHpGejHj7NIimBXBtI.jpg'),
(167920, 11906, 'Doug O Robo Curioso S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r0h6WfIkogHpGejHj7NIimBXBtI.jpg'),
(167921, 11906, 'Doug O Robo Curioso S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r0h6WfIkogHpGejHj7NIimBXBtI.jpg'),
(167922, 11906, 'Doug O Robo Curioso S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/519789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r0h6WfIkogHpGejHj7NIimBXBtI.jpg'),
(167923, 11906, 'Doug O Robo Curioso S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/519790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r0h6WfIkogHpGejHj7NIimBXBtI.jpg'),
(167924, 11906, 'Doug O Robo Curioso S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/519791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r0h6WfIkogHpGejHj7NIimBXBtI.jpg'),
(167925, 11907, 'Doug O Robo Curioso S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519792.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6GKhc9a2ixlZCc2qL9faBxbBPya.jpg'),
(167926, 11907, 'Doug O Robo Curioso S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519793.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qK4FUGspiTGkZELWw2WIS3U97v4.jpg'),
(167927, 11907, 'Doug O Robo Curioso S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519794.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3d0P8mEXwxoSyZG6S1YGZIJ0SmE.jpg'),
(167928, 11907, 'Doug O Robo Curioso S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519795.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jE6LKrLZDEDmSf7HJy6cx225AdO.jpg'),
(167929, 11907, 'Doug O Robo Curioso S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519796.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bRYzPg2HwssPRsnCFeuUu6CXBgR.jpg'),
(167930, 11907, 'Doug O Robo Curioso S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519797.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kaokIW8PR8QzHnf05jLf6X0aAde.jpg'),
(167931, 11907, 'Doug O Robo Curioso S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519798.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8q6lm3E8pE67Jr7PNLuAfNaYYyt.jpg'),
(167932, 11907, 'Doug O Robo Curioso S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r0h6WfIkogHpGejHj7NIimBXBtI.jpg'),
(167933, 11907, 'Doug O Robo Curioso S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r0h6WfIkogHpGejHj7NIimBXBtI.jpg'),
(167934, 11907, 'Doug O Robo Curioso S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r0h6WfIkogHpGejHj7NIimBXBtI.jpg'),
(167935, 11907, 'Doug O Robo Curioso S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/519802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r0h6WfIkogHpGejHj7NIimBXBtI.jpg'),
(167936, 11907, 'Doug O Robo Curioso S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/519803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r0h6WfIkogHpGejHj7NIimBXBtI.jpg'),
(167937, 11907, 'Doug O Robo Curioso S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/519804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/r0h6WfIkogHpGejHj7NIimBXBtI.jpg'),
(167938, 11908, 'Escandalo Bem Britanico S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519776.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zOfB3aTTAq4tNIMLPF3HeHPClhu.jpg'),
(167939, 11908, 'Escandalo Bem Britanico S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519777.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wMpe4nprKjE0TadbKFggSClUufg.jpg'),
(167940, 11908, 'Escandalo Bem Britanico S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519778.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/si6ZtSk367PrHh40QQSZCYm72cs.jpg'),
(167941, 11909, 'Good Casting [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519760.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zWxlx4bA9UCQcTYr1lZteika1oq.jpg'),
(167942, 11909, 'Good Casting [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519761.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2JIML6rja6E95SzJOFzDYghFnHW.jpg'),
(167943, 11909, 'Good Casting [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519762.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zOzvXo3G8w4YO9BYKPFgdeL2Ss3.jpg'),
(167944, 11909, 'Good Casting [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519763.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oDF7LIz5ZtdKKBd5w58uX6TD4NH.jpg'),
(167945, 11909, 'Good Casting [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519764.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jXnzZwCr3qmGuz3qx5SWnqamiva.jpg'),
(167946, 11909, 'Good Casting [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519765.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/49w9G7Es6vZnrH3QuSYuVg06VyT.jpg'),
(167947, 11909, 'Good Casting [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519766.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/riRGtkmAVGMaxGqxhTNzBYEzimt.jpg'),
(167948, 11909, 'Good Casting [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519767.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bdpJGm0MJWdBfPjRsMn6Ve7kqAA.jpg'),
(167949, 11909, 'Good Casting [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519768.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z2qmMtEFGbP6tpD3x3x4J49zHIg.jpg'),
(167950, 11909, 'Good Casting [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519769.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6NovR8sbGKlQjlUQPIvKiTPWvgO.jpg'),
(167951, 11909, 'Good Casting [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/519770.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3x9JVAiplWf1Uh3Lmt9NoG4fIyb.jpg'),
(167952, 11909, 'Good Casting [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/519771.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gO2usAxtYUvs7Oya7BZkZjlIClf.jpg'),
(167953, 11909, 'Good Casting [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/519772.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yt3bhl3PPVj4fie3RGrc4l7kfcg.jpg'),
(167954, 11909, 'Good Casting [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/519773.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jfMGYI8blPTY6ObzMPWnGarnQ2g.jpg'),
(167955, 11909, 'Good Casting [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/519774.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zbi0luZbqwGUwfNytZ1BpAx8oab.jpg'),
(167956, 11909, 'Good Casting [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/519775.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/XJOOXa44iPkamoFK9c6UIH0YwP.jpg'),
(167957, 11910, 'Invasor Zim S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519733.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9zGBhwSS4cNRF0cNzwSf2rQ0lS1.jpg'),
(167958, 11910, 'Invasor Zim S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519734.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o9cjmkNczUkYMzV7hqVmlBrM2bc.jpg'),
(167959, 11910, 'Invasor Zim S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519735.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o9cjmkNczUkYMzV7hqVmlBrM2bc.jpg'),
(167960, 11910, 'Invasor Zim S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519736.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hjkSUPGR832ppdtSO4Nh4p4eOhQ.jpg'),
(167961, 11910, 'Invasor Zim S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519737.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hjkSUPGR832ppdtSO4Nh4p4eOhQ.jpg'),
(167962, 11910, 'Invasor Zim S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519738.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eG5XkK4RDbSf9WiXf1Gcu3MYG88.jpg'),
(167963, 11910, 'Invasor Zim S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519739.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eG5XkK4RDbSf9WiXf1Gcu3MYG88.jpg'),
(167964, 11910, 'Invasor Zim S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519740.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/inakCV59Nx9f3irxbXuYEMepmyi.jpg'),
(167965, 11910, 'Invasor Zim S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519741.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/inakCV59Nx9f3irxbXuYEMepmyi.jpg'),
(167966, 11910, 'Invasor Zim S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519742.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1qeMWKtsZrcuAXhbE027z097oes.jpg'),
(167967, 11910, 'Invasor Zim S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/519743.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1qeMWKtsZrcuAXhbE027z097oes.jpg'),
(167968, 11910, 'Invasor Zim S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/519744.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2tHPQsMnoOE56kVabw9165NexYc.jpg'),
(167969, 11910, 'Invasor Zim S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/519745.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2tHPQsMnoOE56kVabw9165NexYc.jpg'),
(167970, 11910, 'Invasor Zim S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/519746.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vmdc11qEcsaQ1enn7ydFBn1Rggz.jpg'),
(167971, 11910, 'Invasor Zim S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/519747.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vmdc11qEcsaQ1enn7ydFBn1Rggz.jpg'),
(167972, 11910, 'Invasor Zim S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/519748.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jQODUIeNX4Ob6niFEv5sLk3aMlj.jpg'),
(167973, 11910, 'Invasor Zim S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/519749.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jQODUIeNX4Ob6niFEv5sLk3aMlj.jpg'),
(167974, 11910, 'Invasor Zim S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/519750.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nwsz7nt5ziGWYgk4hZI8AvaLKCp.jpg'),
(167975, 11910, 'Invasor Zim S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/519751.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nwsz7nt5ziGWYgk4hZI8AvaLKCp.jpg'),
(167976, 11910, 'Invasor Zim S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/519752.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x4MOl65cKphrQs1IcNwIYgjFMF4.jpg'),
(167977, 11911, 'Invasor Zim S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519753.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v1oPzGY8oixCAqsKXRWn7Rt8RpD.jpg'),
(167978, 11911, 'Invasor Zim S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519754.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/40YHS3kbUQgpLBH6lJetNDVZrLd.jpg'),
(167979, 11911, 'Invasor Zim S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519755.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3opncu5nZt2IFppinYTjNUmIDLo.jpg'),
(167980, 11911, 'Invasor Zim S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519756.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mUJJKhp4TQlLyjaLVhlQbLWwHmX.jpg'),
(167981, 11911, 'Invasor Zim S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519757.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7VmIpRExm1gZSnyIZXyk8NED2o1.jpg'),
(167982, 11911, 'Invasor Zim S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519758.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mkJqcjsUJGgQzz4nbSNhmltNHuU.jpg'),
(167983, 11911, 'Invasor Zim S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519759.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uKe4KTzB6TtVlLCSXHdrIK341uK.jpg'),
(167984, 11912, 'Jack e Joker Voce Roubou Meu Coracao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519721.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3x06RZHeX2eFcGzXNv8NPjcIxC1.jpg'),
(167985, 11912, 'Jack e Joker Voce Roubou Meu Coracao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519722.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wN9sLIStUzfvGNhCoAbehK3flQD.jpg'),
(167986, 11912, 'Jack e Joker Voce Roubou Meu Coracao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519723.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o8FHaAnHGe9Ozg3nMCUakikpQk8.jpg'),
(167987, 11912, 'Jack e Joker Voce Roubou Meu Coracao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519724.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lglcX3igCAzIrlONr1TiI6K1oQX.jpg'),
(167988, 11912, 'Jack e Joker Voce Roubou Meu Coracao [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519725.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u0YT1cbe5wljEBrpTm8TSTIkEVh.jpg'),
(167989, 11912, 'Jack e Joker Voce Roubou Meu Coracao [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519726.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e7MZTVFkhO7r9a2AFBYfZQn3Wua.jpg'),
(167990, 11912, 'Jack e Joker Voce Roubou Meu Coracao [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519727.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AwjBPpSW3u6eBiePlZP7poCXtJd.jpg'),
(167991, 11912, 'Jack e Joker Voce Roubou Meu Coracao [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519728.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xuTGz2tHKoEgVaytNZLH6eSBNkr.jpg'),
(167992, 11912, 'Jack e Joker Voce Roubou Meu Coracao [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519729.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sHLdjf2rG7YhA7aMRvYYR1bjRKt.jpg'),
(167993, 11912, 'Jack e Joker Voce Roubou Meu Coracao [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519730.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ny8jrFRN5JexRznW09KIiYOVkV5.jpg'),
(167994, 11912, 'Jack e Joker Voce Roubou Meu Coracao [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/519731.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sp6yxvaGPL0G9Kb2AtEbDIKNndG.jpg'),
(167995, 11912, 'Jack e Joker Voce Roubou Meu Coracao [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/519732.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ircN1czMcpEP0QQG1iy1zI4Vg3q.jpg'),
(167996, 11912, 'Jack e Joker Voce Roubou Meu Coracao [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/888106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/45dVPhxV5UdRftkk427ZvnKDvGL.jpg'),
(167997, 11913, 'Jentry Chau contra O Submundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519708.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3yZxunlC8hKk7oLDjUtcgJzMUaR.jpg'),
(167998, 11913, 'Jentry Chau contra O Submundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519709.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6TRakab3YjPVn6yxf89Hk6Wmw88.jpg'),
(167999, 11913, 'Jentry Chau contra O Submundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519710.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uX009t2zKBVQ4H0dUMGpzc20j6N.jpg'),
(168000, 11913, 'Jentry Chau contra O Submundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519711.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/es0IG3njWSXfIyOy80H0IQ77rxl.jpg'),
(168001, 11913, 'Jentry Chau contra O Submundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519712.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r61umfv1ZdelxlLY8objHz8TD3d.jpg'),
(168002, 11913, 'Jentry Chau contra O Submundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519713.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6SJMqsjyD7ftUboYH7JvbwhRIGu.jpg'),
(168003, 11913, 'Jentry Chau contra O Submundo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519714.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xMskphePIWp5bAD1dohvGpkEYy6.jpg'),
(168004, 11913, 'Jentry Chau contra O Submundo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519715.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qxiqWYvpI88sTNrxFOz0dUkgsx7.jpg'),
(168005, 11913, 'Jentry Chau contra O Submundo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519716.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rID9NNgmNWEYLxOjSanoXo5UMjv.jpg'),
(168006, 11913, 'Jentry Chau contra O Submundo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519717.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a0qwQNfSFh1VTEQycfgqRwh4lTi.jpg'),
(168007, 11913, 'Jentry Chau contra O Submundo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/519718.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jF13iUpFmn4lB3rogp45pWFkhA6.jpg'),
(168008, 11913, 'Jentry Chau contra O Submundo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/519719.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zdOdF9LDQoT2O3mRt7gGgO99ixm.jpg'),
(168009, 11913, 'Jentry Chau contra O Submundo S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/519720.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iMSec9snwMn9RG8tbIIfRPh0RnJ.jpg'),
(168010, 11914, 'Jin [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519686.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/77getwVO4eSHTfQdDYIAEDooWWY.jpg'),
(168011, 11914, 'Jin [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519687.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rUvnFx6M6VoVcfadPppTTMX8cQy.jpg'),
(168012, 11914, 'Jin [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519688.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kQEWAoUEW1ruTcvQkzEMBQJlDRA.jpg'),
(168013, 11914, 'Jin [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519689.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qjQFfN9xPWyNgjlnLI2mb6sv5XF.jpg'),
(168014, 11914, 'Jin [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519690.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nxHKnrxVqpSj397L5w6OAJI42Cx.jpg'),
(168015, 11914, 'Jin [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519691.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cD3p6v0m90R61kINBYfwXgYxsQM.jpg'),
(168016, 11914, 'Jin [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519692.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sdRc0PNBAXHTwCHMLyIfJ86qNCb.jpg'),
(168017, 11914, 'Jin [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519693.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eNreltxm1Ae3GqjRUe33M4LK7Lc.jpg'),
(168018, 11914, 'Jin [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519694.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/twhsiW1vW4IAp7trndviVZdOKqD.jpg'),
(168019, 11914, 'Jin [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519695.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AdGSAdRRYMqfS99Y0pS9Gd1ssq1.jpg'),
(168020, 11914, 'Jin [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/519696.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mwZs3KVr20ZUZ20ItNJ86nL3yrz.jpg'),
(168021, 11915, 'Jin [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519697.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gbWMpRXCRw5UB1Cv5XqmIOEpc7K.jpg'),
(168022, 11915, 'Jin [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519698.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bDIOlXikm8M6z5NGhz8NWp4t8kU.jpg'),
(168023, 11915, 'Jin [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519699.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fEYmoXGQkSCuFpZYlVCQDbsIG26.jpg'),
(168024, 11915, 'Jin [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519700.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nt2VjghCjSEXy3CmOzCOjCmCkCf.jpg'),
(168025, 11915, 'Jin [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519701.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ph8GnS4PPWmZF3JnJQw5Jv5g9yX.jpg'),
(168026, 11915, 'Jin [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519702.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vJe7AdrlyGuTrX0CR8ez16KQ7a4.jpg'),
(168027, 11915, 'Jin [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519703.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7orhdr9aykbg8bdRYthwJTzkjQs.jpg'),
(168028, 11915, 'Jin [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519704.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A22MtemfKU7faXzTr7mzK6PK78n.jpg'),
(168029, 11915, 'Jin [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519705.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iFQkhMyneNksdwntqHQcNt2Xfkk.jpg'),
(168030, 11915, 'Jin [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519706.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dLwrk3HwxPDZZFLofLhyezkTLlV.jpg'),
(168031, 11915, 'Jin [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/519707.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1EYhXhttrY7jrqA3hmoCGc4yA0A.jpg'),
(168032, 11916, 'Light Shop Entre a Vida e a Morte S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519680.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/acttFDts7w6mf8alI5C4B9C7f0S.jpg'),
(168033, 11916, 'Light Shop Entre a Vida e a Morte S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519681.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g5zjaLkF4UX0eKwLbeVguU5qzDF.jpg'),
(168034, 11916, 'Light Shop Entre a Vida e a Morte S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519682.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mi7id1oUl3bGSpIZUmxfjtMmQMT.jpg'),
(168035, 11916, 'Light Shop Entre a Vida e a Morte S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519683.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mCLBTaSPyuhqcDFYRlwgdvP8wGT.jpg'),
(168036, 11916, 'Light Shop Entre a Vida e a Morte S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519684.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iagPd0rWGNMvoRjmTMP4oWwIhhi.jpg'),
(168037, 11916, 'Light Shop Entre a Vida e a Morte S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519685.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hYsi5MV39hRQqw9vWTENYlU0Uei.jpg'),
(168038, 11916, 'Light Shop Entre a Vida e a Morte S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x78cChnNf7opVNbZIf9jGTglGG8.jpg'),
(168039, 11916, 'Light Shop Entre a Vida e a Morte S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x78cChnNf7opVNbZIf9jGTglGG8.jpg'),
(168040, 11917, 'Ludwig [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519678.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/perMuyDoEMDpwFNC1ilctJoypHJ.jpg'),
(168041, 11917, 'Ludwig [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519679.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ydLP8Nisju3Im2gPuxq81DPEtEY.jpg'),
(168042, 11917, 'Ludwig [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/668649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/okPERzZxAiVWbd3B9qFepxa2Vfq.jpg'),
(168043, 11917, 'Ludwig [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/668650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/okPERzZxAiVWbd3B9qFepxa2Vfq.jpg'),
(168044, 11917, 'Ludwig [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/682648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/okPERzZxAiVWbd3B9qFepxa2Vfq.jpg'),
(168045, 11917, 'Ludwig [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/682649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/okPERzZxAiVWbd3B9qFepxa2Vfq.jpg'),
(168046, 11918, 'Mesmo Assim As Formas do Amor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519675.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aXeQx6QUqIffdoX9TSGyUExitRh.jpg'),
(168047, 11918, 'Mesmo Assim As Formas do Amor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519676.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oqm5L5mCLtYVRECdyotd658gUzo.jpg'),
(168048, 11918, 'Mesmo Assim As Formas do Amor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519677.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mVyqLg2ZQ6J4lOeAUnHHgQpxLdV.jpg'),
(168049, 11918, 'Mesmo Assim As Formas do Amor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sXcBExmlcnRysMBZfcJs3Tci4xZ.jpg'),
(168050, 11918, 'Mesmo Assim As Formas do Amor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/637012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sXcBExmlcnRysMBZfcJs3Tci4xZ.jpg'),
(168051, 11918, 'Mesmo Assim As Formas do Amor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sXcBExmlcnRysMBZfcJs3Tci4xZ.jpg'),
(168052, 11918, 'Mesmo Assim As Formas do Amor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sXcBExmlcnRysMBZfcJs3Tci4xZ.jpg'),
(168053, 11919, 'Mrs Cop [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7iyjqUEperLUrcFi3oC4UVEtd4Y.jpg'),
(168054, 11919, 'Mrs Cop [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7iyjqUEperLUrcFi3oC4UVEtd4Y.jpg'),
(168055, 11919, 'Mrs Cop [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7iyjqUEperLUrcFi3oC4UVEtd4Y.jpg'),
(168056, 11919, 'Mrs Cop [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7iyjqUEperLUrcFi3oC4UVEtd4Y.jpg'),
(168057, 11919, 'Mrs Cop [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7iyjqUEperLUrcFi3oC4UVEtd4Y.jpg'),
(168058, 11919, 'Mrs Cop [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7iyjqUEperLUrcFi3oC4UVEtd4Y.jpg'),
(168059, 11919, 'Mrs Cop [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7iyjqUEperLUrcFi3oC4UVEtd4Y.jpg'),
(168060, 11919, 'Mrs Cop [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7iyjqUEperLUrcFi3oC4UVEtd4Y.jpg'),
(168061, 11919, 'Mrs Cop [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7iyjqUEperLUrcFi3oC4UVEtd4Y.jpg'),
(168062, 11919, 'Mrs Cop [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7iyjqUEperLUrcFi3oC4UVEtd4Y.jpg'),
(168063, 11919, 'Mrs Cop [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/519669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7iyjqUEperLUrcFi3oC4UVEtd4Y.jpg'),
(168064, 11919, 'Mrs Cop [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/519670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7iyjqUEperLUrcFi3oC4UVEtd4Y.jpg'),
(168065, 11919, 'Mrs Cop [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/519671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7iyjqUEperLUrcFi3oC4UVEtd4Y.jpg'),
(168066, 11919, 'Mrs Cop [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/519672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7iyjqUEperLUrcFi3oC4UVEtd4Y.jpg'),
(168067, 11919, 'Mrs Cop [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/519673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7iyjqUEperLUrcFi3oC4UVEtd4Y.jpg'),
(168068, 11919, 'Mrs Cop [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/519674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7iyjqUEperLUrcFi3oC4UVEtd4Y.jpg'),
(168069, 11920, 'O Amanha e Eu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519655.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2VsIUeVJTxomCrNRFezUbeDJfuj.jpg'),
(168070, 11920, 'O Amanha e Eu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519656.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rnaa9ZukDRG7s28EsBrNiY6xN16.jpg'),
(168071, 11920, 'O Amanha e Eu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519657.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/olosyQPzUG7RMY6kjdezR5L77vY.jpg'),
(168072, 11920, 'O Amanha e Eu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519658.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bUIxsstxaa6lHAWBYVcZgh4X4AF.jpg'),
(168073, 11921, 'O Conto da Senhora Ok [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519652.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jVvdQTMJ01Vx10ziYaMDMEcrXmU.jpg'),
(168074, 11921, 'O Conto da Senhora Ok [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519653.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yErhicM2Whk0a4KgWnpsPZuJxGY.jpg'),
(168075, 11921, 'O Conto da Senhora Ok [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(168076, 11921, 'O Conto da Senhora Ok [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/636943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(168077, 11921, 'O Conto da Senhora Ok [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/638364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(168078, 11921, 'O Conto da Senhora Ok [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/641721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(168079, 11921, 'O Conto da Senhora Ok [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/658958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(168080, 11921, 'O Conto da Senhora Ok [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/658959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(168081, 11921, 'O Conto da Senhora Ok [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/658960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(168082, 11921, 'O Conto da Senhora Ok [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/658961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(168083, 11921, 'O Conto da Senhora Ok [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/660231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(168084, 11921, 'O Conto da Senhora Ok [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/667994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(168085, 11921, 'O Conto da Senhora Ok [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/674940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(168086, 11921, 'O Conto da Senhora Ok [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/674941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/g5vriJY8b7JLna3qYv2ksWFRR4.jpg'),
(168087, 11922, 'O Misterioso Triangulo do Alasca S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519632.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7HKWz9es9byYmwAvZL51oF8MSbl.jpg'),
(168088, 11922, 'O Misterioso Triangulo do Alasca S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519633.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bJJKd2n5EAwM3f4jXVR80lsoWzA.jpg'),
(168089, 11922, 'O Misterioso Triangulo do Alasca S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519634.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yHlZNgXhLWsr3a2QjRNwo7bjyP4.jpg'),
(168090, 11922, 'O Misterioso Triangulo do Alasca S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519635.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4EqsZMvjtiCTg5Dc7F3KLQTQdId.jpg'),
(168091, 11922, 'O Misterioso Triangulo do Alasca S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519636.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wjeuRHs39u0eeeAL2aiQgAHR4EA.jpg'),
(168092, 11922, 'O Misterioso Triangulo do Alasca S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519637.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2Lea9sxU60dgL2lNdidpEA34V73.jpg'),
(168093, 11922, 'O Misterioso Triangulo do Alasca S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519638.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xRO5gJ8jPiJdqZVDNBTnTmenCJL.jpg'),
(168094, 11922, 'O Misterioso Triangulo do Alasca S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519639.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3hKujVBAolyx5zqFH5ZWBkupK4c.jpg'),
(168095, 11922, 'O Misterioso Triangulo do Alasca S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519640.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7KPEuQb7qa2WGD0CEP9qMLUxiY.jpg'),
(168096, 11922, 'O Misterioso Triangulo do Alasca S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519641.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5jrbqZJkRBuOK2OuiBPnkCNvee2.jpg'),
(168097, 11923, 'O Misterioso Triangulo do Alasca S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519642.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z7FNA376vrQM4LlyjhW2Ggfwvqm.jpg'),
(168098, 11923, 'O Misterioso Triangulo do Alasca S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519643.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bBC2v7Zccb5SXJYxfcAUavGSVab.jpg'),
(168099, 11923, 'O Misterioso Triangulo do Alasca S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519644.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uyszOSoZAb7JiWy4JIJ9vVFF4Yo.jpg'),
(168100, 11923, 'O Misterioso Triangulo do Alasca S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519645.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1w3pDbIxhOyjMfnJKKkJgHLWChz.jpg'),
(168101, 11923, 'O Misterioso Triangulo do Alasca S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519646.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l3kc25UfLaONDlDbWekE4SI8uJj.jpg'),
(168102, 11923, 'O Misterioso Triangulo do Alasca S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519647.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sPVpvPCkvfsoL0itqMVxwR7BkKs.jpg'),
(168103, 11923, 'O Misterioso Triangulo do Alasca S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519648.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7w96tGoPuXPpSusT6WSdjIeSYyM.jpg'),
(168104, 11923, 'O Misterioso Triangulo do Alasca S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519649.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8yb4BHowXkz8LEICFZQWl2mVdbV.jpg'),
(168105, 11923, 'O Misterioso Triangulo do Alasca S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519650.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iLiRuWTAm6LDwPu6Vo5IJChPf3t.jpg'),
(168106, 11923, 'O Misterioso Triangulo do Alasca S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519651.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xxwSSK3mLxXE0clgKsZUHT5w8RO.jpg'),
(168107, 11924, 'O Tempo ao Seu Lado S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519624.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qyirMrBGQwMsMocqVt5l5kIRFcS.jpg'),
(168108, 11924, 'O Tempo ao Seu Lado S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519625.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mYdFiVk9bgGQrOwP9esajRt9jze.jpg'),
(168109, 11924, 'O Tempo ao Seu Lado S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519626.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3gnEdaYm6pxz6DrMifxlQQ5H80L.jpg'),
(168110, 11924, 'O Tempo ao Seu Lado S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519627.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2cs1BVbMNzMr1QOO64oh1wHUTtn.jpg'),
(168111, 11924, 'O Tempo ao Seu Lado S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519628.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8lES8hIzdUX0dYXsjdkXAOwmRyy.jpg'),
(168112, 11924, 'O Tempo ao Seu Lado S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519629.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ipMejFhjYFgzsYBCLg8QuXl3II9.jpg'),
(168113, 11924, 'O Tempo ao Seu Lado S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519630.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lOLwsguR5b9Ucrs0QbM0oeVvDcJ.jpg'),
(168114, 11924, 'O Tempo ao Seu Lado S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519631.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nwBtHJCG1kY7jZM4qieMzQrXo3l.jpg'),
(168115, 11925, 'Oh The Mysterious [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519584.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1KpAl1uzxcRPN864ZkQ05c7t7pP.jpg'),
(168116, 11925, 'Oh The Mysterious [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519585.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kJOzkDIXbhFJhrvbdIeU0JGuTK6.jpg'),
(168117, 11925, 'Oh The Mysterious [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519586.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i9VeAMsqjzZx752ce1Wk0QOkLPR.jpg'),
(168118, 11925, 'Oh The Mysterious [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519587.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sD2SBe5HcoDS1r173evDDWh4ZyK.jpg'),
(168119, 11925, 'Oh The Mysterious [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519588.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uBCDL62cykOcusNKdUZhOpmX0dY.jpg'),
(168120, 11925, 'Oh The Mysterious [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168121, 11925, 'Oh The Mysterious [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168122, 11925, 'Oh The Mysterious [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168123, 11925, 'Oh The Mysterious [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/523189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168124, 11925, 'Oh The Mysterious [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/523190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168125, 11925, 'Oh The Mysterious [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/523191.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168126, 11925, 'Oh The Mysterious [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/523192.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168127, 11925, 'Oh The Mysterious [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/523193.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168128, 11925, 'Oh The Mysterious [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/523194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168129, 11925, 'Oh The Mysterious [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/523195.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168130, 11925, 'Oh The Mysterious [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/523196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168131, 11925, 'Oh The Mysterious [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/523197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168132, 11925, 'Oh The Mysterious [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/523198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168133, 11925, 'Oh The Mysterious [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/523199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168134, 11925, 'Oh The Mysterious [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/523200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168135, 11925, 'Oh The Mysterious [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/523201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168136, 11925, 'Oh The Mysterious [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/523202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168137, 11925, 'Oh The Mysterious [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/523203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168138, 11925, 'Oh The Mysterious [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/523204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168139, 11925, 'Oh The Mysterious [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/523205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168140, 11925, 'Oh The Mysterious [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/523206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(168141, 11925, 'Oh The Mysterious [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/523207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168142, 11925, 'Oh The Mysterious [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/523208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168143, 11925, 'Oh The Mysterious [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/523209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168144, 11925, 'Oh The Mysterious [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/523210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168145, 11925, 'Oh The Mysterious [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/523211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168146, 11925, 'Oh The Mysterious [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/523212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168147, 11925, 'Oh The Mysterious [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/523213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168148, 11925, 'Oh The Mysterious [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/523214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168149, 11925, 'Oh The Mysterious [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/523215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168150, 11925, 'Oh The Mysterious [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/523216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168151, 11925, 'Oh The Mysterious [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/523217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168152, 11925, 'Oh The Mysterious [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/523218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168153, 11925, 'Oh The Mysterious [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/523219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168154, 11925, 'Oh The Mysterious [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/523220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yr1u5rhG3vbwNQuRC5f29Sa7Tnp.jpg'),
(168155, 11926, 'Producao de Sonhos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519580.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ctNrx6OZSuatdVW1NidIi9bhrdH.jpg'),
(168156, 11926, 'Producao de Sonhos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519581.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lypX5LerHWilGfCuHlgbkzLJN0u.jpg'),
(168157, 11926, 'Producao de Sonhos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519582.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hAuLbhb50r2b7THRCWqP6AK6ABC.jpg'),
(168158, 11926, 'Producao de Sonhos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519583.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xaioy7HW4FKRGtRVVODWIiQC1LG.jpg'),
(168159, 11927, 'Sobrevivente Primitivo com Hazen Audel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519554.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kUQw8WFFbZZhQQuXExxAUX5F45V.jpg'),
(168160, 11927, 'Sobrevivente Primitivo com Hazen Audel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519555.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oUZfqP4rtYwKctU3csJ1TKrjNog.jpg'),
(168161, 11927, 'Sobrevivente Primitivo com Hazen Audel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519556.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pZYjBsEJilxq7ykUO17vTJFBiVT.jpg'),
(168162, 11927, 'Sobrevivente Primitivo com Hazen Audel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519557.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hxEypjR6Vd3VhBYMU5IM44szXYF.jpg'),
(168163, 11927, 'Sobrevivente Primitivo com Hazen Audel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519558.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4bXZers87s0q6Gy0QMAd4mv6VY0.jpg'),
(168164, 11927, 'Sobrevivente Primitivo com Hazen Audel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519559.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/SEYAmTvVOF21Eilkd6y8j6fQut.jpg'),
(168165, 11928, 'Sobrevivente Primitivo com Hazen Audel S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519560.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c3ORcVSkLvnqZmDfDLdf5G2LEWZ.jpg'),
(168166, 11928, 'Sobrevivente Primitivo com Hazen Audel S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519561.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qgCjK6GKQLDn2Hh031jXy0fcFR0.jpg'),
(168167, 11928, 'Sobrevivente Primitivo com Hazen Audel S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519562.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p4eKBvhNBeiEIdRjg1ED4ATK9eh.jpg'),
(168168, 11928, 'Sobrevivente Primitivo com Hazen Audel S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519563.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4OrMElWXuztzeYNiXU2J0PQwtqP.jpg'),
(168169, 11928, 'Sobrevivente Primitivo com Hazen Audel S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519564.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/muOPYS29hCoEQvt9O63e6F9xkub.jpg'),
(168170, 11928, 'Sobrevivente Primitivo com Hazen Audel S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519565.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qNDRWRJZFcke1oTJvVldTRJlpH7.jpg'),
(168171, 11928, 'Sobrevivente Primitivo com Hazen Audel S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iiw244PvDnjFLma16xdcj4jOUO0.jpg'),
(168172, 11929, 'Sobrevivente Primitivo com Hazen Audel S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iiw244PvDnjFLma16xdcj4jOUO0.jpg'),
(168173, 11929, 'Sobrevivente Primitivo com Hazen Audel S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iiw244PvDnjFLma16xdcj4jOUO0.jpg'),
(168174, 11929, 'Sobrevivente Primitivo com Hazen Audel S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iiw244PvDnjFLma16xdcj4jOUO0.jpg'),
(168175, 11929, 'Sobrevivente Primitivo com Hazen Audel S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iiw244PvDnjFLma16xdcj4jOUO0.jpg'),
(168176, 11929, 'Sobrevivente Primitivo com Hazen Audel S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iiw244PvDnjFLma16xdcj4jOUO0.jpg'),
(168177, 11929, 'Sobrevivente Primitivo com Hazen Audel S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iiw244PvDnjFLma16xdcj4jOUO0.jpg'),
(168178, 11930, 'Sobrevivente Primitivo com Hazen Audel S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519573.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9mfVEmKGCalDYzbCnVXSaWsLoC5.jpg'),
(168179, 11930, 'Sobrevivente Primitivo com Hazen Audel S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519574.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8a7n0fTa0hs5SFhuzm0JVfnIUPi.jpg'),
(168180, 11930, 'Sobrevivente Primitivo com Hazen Audel S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519575.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tyPHSCaAeoGEQTeNOC4V9pza2QR.jpg'),
(168181, 11931, 'Sobrevivente Primitivo com Hazen Audel S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519576.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8fm0gikF8wiAoK2A3HhxyfzQzB2.jpg'),
(168182, 11931, 'Sobrevivente Primitivo com Hazen Audel S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519577.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/coWEaMysx1r9Iy2P3sXCXb5ZqOW.jpg'),
(168183, 11931, 'Sobrevivente Primitivo com Hazen Audel S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519578.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/39F1IjPuNKD6pWDRimfaffgPfvA.jpg'),
(168184, 11931, 'Sobrevivente Primitivo com Hazen Audel S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519579.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fl7bMI3UrqzO5bCGfXXnOkoiPzZ.jpg'),
(168185, 11932, 'Tintin S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519528.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6NWRmHE6eAnqBMRc8wOkAf0mfRL.jpg'),
(168186, 11932, 'Tintin S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519529.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A9vbqHI0OpXqWdQxhX6NSqjyqRV.jpg'),
(168187, 11932, 'Tintin S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519530.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oMkzqArlhUqjCHRbo6FXjgB26Fx.jpg'),
(168188, 11932, 'Tintin S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519531.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jzvhclZUotS1Se0s9k7ctKziG9d.jpg'),
(168189, 11932, 'Tintin S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519532.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ohKPbleViZ0Jcs8iph465JuieuN.jpg'),
(168190, 11932, 'Tintin S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519533.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iqov13i9hqnA59wmBuO6lcj63ay.jpg'),
(168191, 11932, 'Tintin S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519534.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6uPOJ3FOcKPBVEnq9MXAZnGH5Wi.jpg'),
(168192, 11932, 'Tintin S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519535.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oes7qmU60FO4URnw8H9ctwLXaE3.jpg'),
(168193, 11932, 'Tintin S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519536.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/XrZUi3wyBXfaAjGW48M9gUQI4f.jpg'),
(168194, 11932, 'Tintin S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519537.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uDcVKtP4H6aoWTZTpE4X3YHjFYq.jpg'),
(168195, 11932, 'Tintin S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/519538.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ivRrgqqaOHFMuSiss5pQ95yCxOq.jpg'),
(168196, 11932, 'Tintin S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/519539.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/867Eb0MAgT6lThHhARLkjMQlyN8.jpg'),
(168197, 11932, 'Tintin S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/519540.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/44JYDAZ1OkQ9OzOfrjNeNDT6Ast.jpg'),
(168198, 11932, 'Tintin S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/519541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umlovDiFIbnR0mkFsDzmiHoxVOH.jpg'),
(168199, 11932, 'Tintin S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/519542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umlovDiFIbnR0mkFsDzmiHoxVOH.jpg'),
(168200, 11932, 'Tintin S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/519543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umlovDiFIbnR0mkFsDzmiHoxVOH.jpg'),
(168201, 11932, 'Tintin S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/519544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umlovDiFIbnR0mkFsDzmiHoxVOH.jpg'),
(168202, 11932, 'Tintin S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/519545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umlovDiFIbnR0mkFsDzmiHoxVOH.jpg'),
(168203, 11932, 'Tintin S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/519546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umlovDiFIbnR0mkFsDzmiHoxVOH.jpg'),
(168204, 11932, 'Tintin S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/519547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umlovDiFIbnR0mkFsDzmiHoxVOH.jpg'),
(168205, 11932, 'Tintin S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/519548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umlovDiFIbnR0mkFsDzmiHoxVOH.jpg'),
(168206, 11932, 'Tintin S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/519549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umlovDiFIbnR0mkFsDzmiHoxVOH.jpg'),
(168207, 11932, 'Tintin S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/519550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umlovDiFIbnR0mkFsDzmiHoxVOH.jpg'),
(168208, 11932, 'Tintin S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/519551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umlovDiFIbnR0mkFsDzmiHoxVOH.jpg'),
(168209, 11932, 'Tintin S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/519552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umlovDiFIbnR0mkFsDzmiHoxVOH.jpg'),
(168210, 11932, 'Tintin S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/519553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/umlovDiFIbnR0mkFsDzmiHoxVOH.jpg'),
(168211, 11933, 'Tying the Knot with an Amagami Sister S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519520.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fixT2K0lolqqg7VtLtjoUsCu62m.jpg'),
(168212, 11933, 'Tying the Knot with an Amagami Sister S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519521.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3p4VSbsFMGb5IOAGIlrpJqvsOiV.jpg'),
(168213, 11933, 'Tying the Knot with an Amagami Sister S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519522.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zylq3FNjQxziseJBvhyKzutGc2f.jpg'),
(168214, 11933, 'Tying the Knot with an Amagami Sister S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519523.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rWsVdKauv99X3CevDLCIgS71GiT.jpg'),
(168215, 11933, 'Tying the Knot with an Amagami Sister S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519524.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vZxTE0Ew0UGOQldbWZt6j1qUW75.jpg'),
(168216, 11933, 'Tying the Knot with an Amagami Sister S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519525.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hXBpt8D8rhzQfiVbIacsRewE34V.jpg'),
(168217, 11933, 'Tying the Knot with an Amagami Sister S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519526.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/siemkbOvXySYx0GkkPtraVxnYpk.jpg'),
(168218, 11933, 'Tying the Knot with an Amagami Sister S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519527.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sU2jZGzdi2DzB2MGzLAjOc1wMOU.jpg'),
(168219, 11933, 'Tying the Knot with an Amagami Sister S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/635881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168220, 11933, 'Tying the Knot with an Amagami Sister S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/639869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168221, 11933, 'Tying the Knot with an Amagami Sister S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/657374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168222, 11933, 'Tying the Knot with an Amagami Sister S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/661291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168223, 11933, 'Tying the Knot with an Amagami Sister S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/684454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168224, 11933, 'Tying the Knot with an Amagami Sister S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/684455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168225, 11933, 'Tying the Knot with an Amagami Sister S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/692307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168226, 11933, 'Tying the Knot with an Amagami Sister S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/701070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168227, 11933, 'Tying the Knot with an Amagami Sister S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/708703.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168228, 11933, 'Tying the Knot with an Amagami Sister S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/722903.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168229, 11933, 'Tying the Knot with an Amagami Sister S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/727505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168230, 11933, 'Tying the Knot with an Amagami Sister S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/731982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168231, 11933, 'Tying the Knot with an Amagami Sister S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/739706.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168232, 11933, 'Tying the Knot with an Amagami Sister S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/753273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168233, 11933, 'Tying the Knot with an Amagami Sister S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/763065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168234, 11933, 'Tying the Knot with an Amagami Sister S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/777385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168235, 11934, 'Zouk a Bruxinha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2UDpDZfcoAOULyjD1ucdexG1G7E.jpg'),
(168236, 11934, 'Zouk a Bruxinha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2UDpDZfcoAOULyjD1ucdexG1G7E.jpg'),
(168237, 11934, 'Zouk a Bruxinha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2UDpDZfcoAOULyjD1ucdexG1G7E.jpg'),
(168238, 11934, 'Zouk a Bruxinha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2UDpDZfcoAOULyjD1ucdexG1G7E.jpg'),
(168239, 11934, 'Zouk a Bruxinha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2UDpDZfcoAOULyjD1ucdexG1G7E.jpg'),
(168240, 11934, 'Zouk a Bruxinha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2UDpDZfcoAOULyjD1ucdexG1G7E.jpg'),
(168241, 11934, 'Zouk a Bruxinha S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2UDpDZfcoAOULyjD1ucdexG1G7E.jpg'),
(168242, 11934, 'Zouk a Bruxinha S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2UDpDZfcoAOULyjD1ucdexG1G7E.jpg'),
(168243, 11934, 'Zouk a Bruxinha S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2UDpDZfcoAOULyjD1ucdexG1G7E.jpg'),
(168244, 11934, 'Zouk a Bruxinha S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2UDpDZfcoAOULyjD1ucdexG1G7E.jpg'),
(168245, 11934, 'Zouk a Bruxinha S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/519517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2UDpDZfcoAOULyjD1ucdexG1G7E.jpg'),
(168246, 11934, 'Zouk a Bruxinha S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/519518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2UDpDZfcoAOULyjD1ucdexG1G7E.jpg'),
(168247, 11934, 'Zouk a Bruxinha S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/519519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2UDpDZfcoAOULyjD1ucdexG1G7E.jpg'),
(168248, 11935, 'Cem Anos de Solidao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519499.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9GNp1qDvSkxVn1ejgPyLsWyxU5Q.jpg'),
(168249, 11935, 'Cem Anos de Solidao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519500.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vizdx41QJay475Tvcrjony050BM.jpg'),
(168250, 11935, 'Cem Anos de Solidao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519501.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xr1x0JvdpaYi8HARSBFtGznKEWN.jpg'),
(168251, 11935, 'Cem Anos de Solidao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519502.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/94qArX0KxcKaU0j5XgSncvL2UoO.jpg'),
(168252, 11935, 'Cem Anos de Solidao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519503.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lvdPr8tGZ33fWKzXy4VQqECsNj3.jpg'),
(168253, 11935, 'Cem Anos de Solidao S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519504.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cH6XtbYEeDC8xevQhV6pSX7kP9K.jpg'),
(168254, 11935, 'Cem Anos de Solidao S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519505.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nDv2jtduI4fz9XWjnJlaHzLLoio.jpg'),
(168255, 11935, 'Cem Anos de Solidao S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519506.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/adzLSgzmxT1HN3oi5XfFgLPqlG0.jpg'),
(168256, 11936, 'Em que lugar da Terra esta Carmen Sandiego S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168257, 11936, 'Em que lugar da Terra esta Carmen Sandiego S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168258, 11936, 'Em que lugar da Terra esta Carmen Sandiego S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168259, 11936, 'Em que lugar da Terra esta Carmen Sandiego S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168260, 11936, 'Em que lugar da Terra esta Carmen Sandiego S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168261, 11936, 'Em que lugar da Terra esta Carmen Sandiego S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168262, 11936, 'Em que lugar da Terra esta Carmen Sandiego S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168263, 11936, 'Em que lugar da Terra esta Carmen Sandiego S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168264, 11936, 'Em que lugar da Terra esta Carmen Sandiego S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168265, 11936, 'Em que lugar da Terra esta Carmen Sandiego S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/519469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168266, 11936, 'Em que lugar da Terra esta Carmen Sandiego S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/519470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168267, 11936, 'Em que lugar da Terra esta Carmen Sandiego S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/519471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168268, 11936, 'Em que lugar da Terra esta Carmen Sandiego S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/519472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168269, 11937, 'Em que lugar da Terra esta Carmen Sandiego S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168270, 11937, 'Em que lugar da Terra esta Carmen Sandiego S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168271, 11937, 'Em que lugar da Terra esta Carmen Sandiego S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168272, 11937, 'Em que lugar da Terra esta Carmen Sandiego S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168273, 11937, 'Em que lugar da Terra esta Carmen Sandiego S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168274, 11937, 'Em que lugar da Terra esta Carmen Sandiego S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168275, 11937, 'Em que lugar da Terra esta Carmen Sandiego S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168276, 11937, 'Em que lugar da Terra esta Carmen Sandiego S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168277, 11938, 'Em que lugar da Terra esta Carmen Sandiego S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168278, 11938, 'Em que lugar da Terra esta Carmen Sandiego S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168279, 11938, 'Em que lugar da Terra esta Carmen Sandiego S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168280, 11938, 'Em que lugar da Terra esta Carmen Sandiego S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168281, 11938, 'Em que lugar da Terra esta Carmen Sandiego S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168282, 11938, 'Em que lugar da Terra esta Carmen Sandiego S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168283, 11938, 'Em que lugar da Terra esta Carmen Sandiego S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168284, 11938, 'Em que lugar da Terra esta Carmen Sandiego S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168285, 11938, 'Em que lugar da Terra esta Carmen Sandiego S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168286, 11939, 'Em que lugar da Terra esta Carmen Sandiego S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168287, 11939, 'Em que lugar da Terra esta Carmen Sandiego S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168288, 11939, 'Em que lugar da Terra esta Carmen Sandiego S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168289, 11939, 'Em que lugar da Terra esta Carmen Sandiego S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168290, 11939, 'Em que lugar da Terra esta Carmen Sandiego S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168291, 11939, 'Em que lugar da Terra esta Carmen Sandiego S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168292, 11939, 'Em que lugar da Terra esta Carmen Sandiego S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168293, 11939, 'Em que lugar da Terra esta Carmen Sandiego S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/519497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168294, 11939, 'Em que lugar da Terra esta Carmen Sandiego S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/519498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fhTM59RBy1W6d5lGWHVpJ2BHsSy.jpg'),
(168295, 11940, 'Inferno em La Palma S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylwR62svIok0eq6HlE8ILwOa4fp.jpg'),
(168296, 11940, 'Inferno em La Palma S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylwR62svIok0eq6HlE8ILwOa4fp.jpg'),
(168297, 11940, 'Inferno em La Palma S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylwR62svIok0eq6HlE8ILwOa4fp.jpg'),
(168298, 11940, 'Inferno em La Palma S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ylwR62svIok0eq6HlE8ILwOa4fp.jpg'),
(168299, 11941, 'Mentes Extraordinarias S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/igxwBc3KqWrumv0hx6LgvMNdVbO.jpg'),
(168300, 11941, 'Mentes Extraordinarias S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/igxwBc3KqWrumv0hx6LgvMNdVbO.jpg'),
(168301, 11941, 'Mentes Extraordinarias S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/igxwBc3KqWrumv0hx6LgvMNdVbO.jpg'),
(168302, 11941, 'Mentes Extraordinarias S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/igxwBc3KqWrumv0hx6LgvMNdVbO.jpg'),
(168303, 11941, 'Mentes Extraordinarias S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/igxwBc3KqWrumv0hx6LgvMNdVbO.jpg'),
(168304, 11941, 'Mentes Extraordinarias S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/658986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/igxwBc3KqWrumv0hx6LgvMNdVbO.jpg'),
(168305, 11941, 'Mentes Extraordinarias S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/658987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/igxwBc3KqWrumv0hx6LgvMNdVbO.jpg'),
(168306, 11941, 'Mentes Extraordinarias S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/658988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/igxwBc3KqWrumv0hx6LgvMNdVbO.jpg'),
(168307, 11941, 'Mentes Extraordinarias S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/662175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/igxwBc3KqWrumv0hx6LgvMNdVbO.jpg'),
(168308, 11941, 'Mentes Extraordinarias S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/668530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/igxwBc3KqWrumv0hx6LgvMNdVbO.jpg'),
(168309, 11941, 'Mentes Extraordinarias S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/673591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/igxwBc3KqWrumv0hx6LgvMNdVbO.jpg'),
(168310, 11941, 'Mentes Extraordinarias S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/687240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/igxwBc3KqWrumv0hx6LgvMNdVbO.jpg'),
(168311, 11941, 'Mentes Extraordinarias S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/687241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/igxwBc3KqWrumv0hx6LgvMNdVbO.jpg'),
(168312, 11942, 'Misterios Revelados Enigmas Militares S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519445.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vgLrn1wmNXeaaHEEVNcvi73NqXl.jpg'),
(168313, 11942, 'Misterios Revelados Enigmas Militares S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519446.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lw0SPwgqE0H08MjEQq5G2azNeXC.jpg'),
(168314, 11942, 'Misterios Revelados Enigmas Militares S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519447.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3Frajh7NjwoD28WPc471ARLQzss.jpg'),
(168315, 11942, 'Misterios Revelados Enigmas Militares S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519448.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dOCDNmqiTowT81w41crgWE2CjMA.jpg'),
(168316, 11942, 'Misterios Revelados Enigmas Militares S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519449.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/12mpTLwU5YH86smE3N69qrRNw7t.jpg'),
(168317, 11942, 'Misterios Revelados Enigmas Militares S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519450.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/OZ5vczm4iYhlFxy7VMemje3BO1.jpg'),
(168318, 11943, 'Os Reis de Tupelo Crime e Conspiracao nos Estados Unidos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519442.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1v1DAcsTmN3QNXAHFrweosgfPt4.jpg'),
(168319, 11943, 'Os Reis de Tupelo Crime e Conspiracao nos Estados Unidos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519443.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tk1ETRFJkddYNq4NMOL6KINeO4F.jpg'),
(168320, 11943, 'Os Reis de Tupelo Crime e Conspiracao nos Estados Unidos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519444.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jIs0CQ35UfRTlC82ZEuRVVYr9pi.jpg'),
(168321, 11944, 'Quem Ve Casa S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/519435.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pDbE4DSF1GJOnu5peAkncwrrk8A.jpg'),
(168322, 11944, 'Quem Ve Casa S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/519436.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/atpG01oWGHuVArKKfYW56YPxUI6.jpg'),
(168323, 11944, 'Quem Ve Casa S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/519437.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/opRbECzWRY54rSpv3G4PG3P4AyU.jpg'),
(168324, 11944, 'Quem Ve Casa S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/519438.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wL8JJe0VrSYqRQOJOKjeSC8Fdgy.jpg'),
(168325, 11944, 'Quem Ve Casa S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/519439.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xaPJczhrjqg3GSUofmTzbc7pk0x.jpg'),
(168326, 11944, 'Quem Ve Casa S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/519440.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8FlQcLp93LHGfQf7Bc6RVPGLHAp.jpg'),
(168327, 11944, 'Quem Ve Casa S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/519441.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mjPhOATETdGRMDDCeDgzF7uy5LV.jpg'),
(168328, 11945, 'A Historia da Garota Perola [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524232.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6hxbnn0XpWwEm59rMQLeBpsW1BL.jpg'),
(168329, 11945, 'A Historia da Garota Perola [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524233.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ifiOdvSrEHUf5MXURmVrfF2uJ.jpg'),
(168330, 11945, 'A Historia da Garota Perola [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524234.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qnw9Hj1W7qe26EtdGhLwpnbSqSy.jpg'),
(168331, 11945, 'A Historia da Garota Perola [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524235.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1AP9UNHjy6YYfReRhG151EtepfU.jpg'),
(168332, 11945, 'A Historia da Garota Perola [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524236.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yo8TH6mIeJflQpntmAQG0wpffL2.jpg'),
(168333, 11945, 'A Historia da Garota Perola [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524237.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qygOh6VHH8QBzRZfFmCynTqUsRP.jpg'),
(168334, 11945, 'A Historia da Garota Perola [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524238.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4Ef7ldlhoRZHeV0wsan3JCuNEdj.jpg'),
(168335, 11945, 'A Historia da Garota Perola [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524239.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/daIHnmIY2yohb1P1eRXAIDqeyN2.jpg'),
(168336, 11945, 'A Historia da Garota Perola [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524240.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2kxavVEhApTrFUO2xyvkAsTGx1H.jpg'),
(168337, 11945, 'A Historia da Garota Perola [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524241.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iAWmVg36Lftd9FnhzDDNHd8EnNi.jpg'),
(168338, 11945, 'A Historia da Garota Perola [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524242.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aEOrr3gSGdRw2qVN2Fssm98amdi.jpg'),
(168339, 11945, 'A Historia da Garota Perola [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524243.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2CnI1k6fLy2D1VAXVrd1safaiWU.jpg'),
(168340, 11945, 'A Historia da Garota Perola [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/524244.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ihABRC005sTQS41MD3iiU8ohxja.jpg'),
(168341, 11945, 'A Historia da Garota Perola [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/524245.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/25JNGdNgQSmzipLhy295bByHpN0.jpg'),
(168342, 11945, 'A Historia da Garota Perola [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/524246.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qathrXiRCTn4xead8tHY96IdFb0.jpg'),
(168343, 11946, 'A Rainha do Misterio [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524201.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mQnKTxguWq0pk3ZYGa2DGLKQ0eV.jpg'),
(168344, 11946, 'A Rainha do Misterio [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524202.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fK9jxzTPMRn1CqrZRWXQy6PDQ1T.jpg'),
(168345, 11946, 'A Rainha do Misterio [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524203.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t9MXoXcUJ7Sv3D3dke3zki8BMTY.jpg'),
(168346, 11946, 'A Rainha do Misterio [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524204.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xe7Q92iL6JMwAOOtXYmrujKVKYI.jpg'),
(168347, 11946, 'A Rainha do Misterio [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524205.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7rYUCjw8mSTUnrrheLG5GRIaB6l.jpg'),
(168348, 11946, 'A Rainha do Misterio [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524206.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3H0A6IJnBlXHnPCBS5ZIZdvGxQD.jpg'),
(168349, 11946, 'A Rainha do Misterio [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524207.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k246eThxRqeKp8rFe0rxGx034Fh.jpg'),
(168350, 11946, 'A Rainha do Misterio [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524208.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1dlAeSEsBx0NgAJg2ratQg0dA1f.jpg'),
(168351, 11946, 'A Rainha do Misterio [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524209.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uNq8Ll9CGr81CeKQfoVVKgzOj0I.jpg'),
(168352, 11946, 'A Rainha do Misterio [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524210.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r9a7AZDY6KxdQtkKRh51AHX5z9C.jpg'),
(168353, 11946, 'A Rainha do Misterio [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524211.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ninZWiIT49gdJ9kUxYhv9A06tRJ.jpg'),
(168354, 11946, 'A Rainha do Misterio [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524212.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qmjEV5ks50yAY0ud8eXGUdhzWCw.jpg'),
(168355, 11946, 'A Rainha do Misterio [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/524213.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3y67QQztTohaIqe9b86qxovfKUU.jpg'),
(168356, 11946, 'A Rainha do Misterio [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/524214.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bAfQgOetitzkqgQHDDClYA6O1uh.jpg'),
(168357, 11946, 'A Rainha do Misterio [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/524215.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rm1YB0RXFUey0rra9x0JVHyyewH.jpg'),
(168358, 11946, 'A Rainha do Misterio [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/524216.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oaIn3UYdf4zmKKpgOx9SS3hONfy.jpg'),
(168359, 11947, 'A Rainha do Misterio [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrGfWgftZS1EyRCwv8ypOnPHJi2.jpg'),
(168360, 11947, 'A Rainha do Misterio [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrGfWgftZS1EyRCwv8ypOnPHJi2.jpg'),
(168361, 11947, 'A Rainha do Misterio [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrGfWgftZS1EyRCwv8ypOnPHJi2.jpg'),
(168362, 11947, 'A Rainha do Misterio [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrGfWgftZS1EyRCwv8ypOnPHJi2.jpg'),
(168363, 11947, 'A Rainha do Misterio [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrGfWgftZS1EyRCwv8ypOnPHJi2.jpg'),
(168364, 11947, 'A Rainha do Misterio [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrGfWgftZS1EyRCwv8ypOnPHJi2.jpg'),
(168365, 11947, 'A Rainha do Misterio [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrGfWgftZS1EyRCwv8ypOnPHJi2.jpg'),
(168366, 11947, 'A Rainha do Misterio [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrGfWgftZS1EyRCwv8ypOnPHJi2.jpg'),
(168367, 11947, 'A Rainha do Misterio [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrGfWgftZS1EyRCwv8ypOnPHJi2.jpg'),
(168368, 11947, 'A Rainha do Misterio [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrGfWgftZS1EyRCwv8ypOnPHJi2.jpg'),
(168369, 11947, 'A Rainha do Misterio [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrGfWgftZS1EyRCwv8ypOnPHJi2.jpg'),
(168370, 11947, 'A Rainha do Misterio [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrGfWgftZS1EyRCwv8ypOnPHJi2.jpg'),
(168371, 11947, 'A Rainha do Misterio [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/524229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrGfWgftZS1EyRCwv8ypOnPHJi2.jpg'),
(168372, 11947, 'A Rainha do Misterio [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/524230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrGfWgftZS1EyRCwv8ypOnPHJi2.jpg'),
(168373, 11947, 'A Rainha do Misterio [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/524231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nrGfWgftZS1EyRCwv8ypOnPHJi2.jpg'),
(168374, 11948, 'Baseado Numa Historia Real [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524190.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y3pufuW1UcyBD0rLbTzFwXqqBlH.jpg'),
(168375, 11948, 'Baseado Numa Historia Real [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524191.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zQXxEJovttK43G9zFqGhj3Hasyw.jpg'),
(168376, 11948, 'Baseado Numa Historia Real [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524192.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/srPu3SboiXG252smcffshvJoy4r.jpg'),
(168377, 11948, 'Baseado Numa Historia Real [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524193.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u3sJwNSczEHzMGBeN1vdBY6FYmo.jpg'),
(168378, 11948, 'Baseado Numa Historia Real [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524194.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xi6SwwTVz8d19vaTCa4fMiR4tkR.jpg'),
(168379, 11948, 'Baseado Numa Historia Real [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524195.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/86dO5fdY4PWrepcyNVIxd17dEth.jpg'),
(168380, 11948, 'Baseado Numa Historia Real [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524196.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/no7PJd7ffXgCfHdFbSdGWm9nYLT.jpg'),
(168381, 11948, 'Baseado Numa Historia Real [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524197.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/29lEoBgfZd1c8kSzNHnYj8nBgDl.jpg'),
(168382, 11949, 'Baseado Numa Historia Real [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524198.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8gDMXKqDsuk59VHwg67kZikdFSL.jpg'),
(168383, 11949, 'Baseado Numa Historia Real [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524199.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j5uNNoldKWsLKRzoEvqV5PHZVQI.jpg'),
(168384, 11949, 'Baseado Numa Historia Real [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524200.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1daIqluVwK9ZiaN9aMJwjh3bUHY.jpg'),
(168385, 11949, 'Baseado Numa Historia Real [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637359.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/22j9HjAzpKURhaZJ6D4ecSngL9o.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(168386, 11949, 'Baseado Numa Historia Real [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/638662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/22j9HjAzpKURhaZJ6D4ecSngL9o.jpg'),
(168387, 11949, 'Baseado Numa Historia Real [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/659774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/22j9HjAzpKURhaZJ6D4ecSngL9o.jpg'),
(168388, 11949, 'Baseado Numa Historia Real [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/659775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/22j9HjAzpKURhaZJ6D4ecSngL9o.jpg'),
(168389, 11949, 'Baseado Numa Historia Real [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/659776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/22j9HjAzpKURhaZJ6D4ecSngL9o.jpg'),
(168390, 11950, 'Blues de Madrasta e Enteada [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524180.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lD9qjJqeOJqYVTfpCyl1OmUs69T.jpg'),
(168391, 11950, 'Blues de Madrasta e Enteada [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524181.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4ZZzDpuJYS39NsIQjTqO82UW554.jpg'),
(168392, 11950, 'Blues de Madrasta e Enteada [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524182.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6jPwAzNWOFXTn2ChEGMWGxZMWWO.jpg'),
(168393, 11950, 'Blues de Madrasta e Enteada [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524183.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r5SWK3rMBXArpbfZzxLArNxcU6z.jpg'),
(168394, 11950, 'Blues de Madrasta e Enteada [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524184.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6j73RwHmMsM6rx4Z787PlULtgXi.jpg'),
(168395, 11950, 'Blues de Madrasta e Enteada [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524185.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ts26lhVzXFYwU1TmHgnFKh011XS.jpg'),
(168396, 11950, 'Blues de Madrasta e Enteada [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524186.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/khdXY8zOVK5VpVVfMhvgL7nDM3w.jpg'),
(168397, 11950, 'Blues de Madrasta e Enteada [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524187.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/28iyS0mvo0AxfXq7ZXBPCNq2xeU.jpg'),
(168398, 11950, 'Blues de Madrasta e Enteada [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524188.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i4YpGj3AXhCn6EvqVr2q4kurMeA.jpg'),
(168399, 11950, 'Blues de Madrasta e Enteada [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524189.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fNSSGWcXxEWA9tntJsNilTMDwFk.jpg'),
(168400, 11951, 'Dario Gomez El rey del despecho [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168401, 11951, 'Dario Gomez El rey del despecho [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168402, 11951, 'Dario Gomez El rey del despecho [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168403, 11951, 'Dario Gomez El rey del despecho [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168404, 11951, 'Dario Gomez El rey del despecho [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168405, 11951, 'Dario Gomez El rey del despecho [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168406, 11951, 'Dario Gomez El rey del despecho [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168407, 11951, 'Dario Gomez El rey del despecho [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168408, 11951, 'Dario Gomez El rey del despecho [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168409, 11951, 'Dario Gomez El rey del despecho [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168410, 11951, 'Dario Gomez El rey del despecho [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168411, 11951, 'Dario Gomez El rey del despecho [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168412, 11951, 'Dario Gomez El rey del despecho [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/524147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168413, 11951, 'Dario Gomez El rey del despecho [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/524148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168414, 11951, 'Dario Gomez El rey del despecho [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/524149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168415, 11951, 'Dario Gomez El rey del despecho [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/524150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168416, 11951, 'Dario Gomez El rey del despecho [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/524151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168417, 11951, 'Dario Gomez El rey del despecho [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/524152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168418, 11951, 'Dario Gomez El rey del despecho [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/524153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168419, 11951, 'Dario Gomez El rey del despecho [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/524154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168420, 11951, 'Dario Gomez El rey del despecho [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/524155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168421, 11951, 'Dario Gomez El rey del despecho [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/524156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168422, 11951, 'Dario Gomez El rey del despecho [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/524157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168423, 11951, 'Dario Gomez El rey del despecho [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/524158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168424, 11951, 'Dario Gomez El rey del despecho [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/524159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168425, 11951, 'Dario Gomez El rey del despecho [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/524160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168426, 11951, 'Dario Gomez El rey del despecho [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/524161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168427, 11951, 'Dario Gomez El rey del despecho [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/524162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168428, 11951, 'Dario Gomez El rey del despecho [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/524163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168429, 11951, 'Dario Gomez El rey del despecho [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/524164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168430, 11951, 'Dario Gomez El rey del despecho [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/524165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168431, 11951, 'Dario Gomez El rey del despecho [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/524166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168432, 11951, 'Dario Gomez El rey del despecho [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/524167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168433, 11951, 'Dario Gomez El rey del despecho [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/524168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168434, 11951, 'Dario Gomez El rey del despecho [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/524169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168435, 11951, 'Dario Gomez El rey del despecho [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/524170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168436, 11951, 'Dario Gomez El rey del despecho [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/524171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168437, 11951, 'Dario Gomez El rey del despecho [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/524172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168438, 11951, 'Dario Gomez El rey del despecho [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/524173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168439, 11951, 'Dario Gomez El rey del despecho [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/524174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168440, 11951, 'Dario Gomez El rey del despecho [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/524175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168441, 11951, 'Dario Gomez El rey del despecho [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/524176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168442, 11951, 'Dario Gomez El rey del despecho [L] S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/524177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168443, 11951, 'Dario Gomez El rey del despecho [L] S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/524178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168444, 11951, 'Dario Gomez El rey del despecho [L] S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/524179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVYgLakPa2GHqdP6ycdsnidcR4p.jpg'),
(168445, 11952, 'Dexter Pecado Original S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524134.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nGZOvkHqBC5stXrIfuXdwDsVhHg.jpg'),
(168446, 11952, 'Dexter Pecado Original S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/638576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/At6blg1yLncx72blFE8xHv0bWXY.jpg'),
(168447, 11952, 'Dexter Pecado Original S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/638577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/At6blg1yLncx72blFE8xHv0bWXY.jpg'),
(168448, 11952, 'Dexter Pecado Original S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/644071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/At6blg1yLncx72blFE8xHv0bWXY.jpg'),
(168449, 11952, 'Dexter Pecado Original S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/659652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/At6blg1yLncx72blFE8xHv0bWXY.jpg'),
(168450, 11952, 'Dexter Pecado Original S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/663081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/At6blg1yLncx72blFE8xHv0bWXY.jpg'),
(168451, 11952, 'Dexter Pecado Original S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/677725.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/At6blg1yLncx72blFE8xHv0bWXY.jpg'),
(168452, 11952, 'Dexter Pecado Original S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/693430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/At6blg1yLncx72blFE8xHv0bWXY.jpg'),
(168453, 11952, 'Dexter Pecado Original S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/693431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/At6blg1yLncx72blFE8xHv0bWXY.jpg'),
(168454, 11952, 'Dexter Pecado Original S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/698324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/At6blg1yLncx72blFE8xHv0bWXY.jpg'),
(168455, 11953, 'Mononoke [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524122.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yD4L8eOIKrY7EqBeJgaSRsndeje.jpg'),
(168456, 11953, 'Mononoke [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524123.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8kBaik0r7I0ZgiUYh0MgovDulrx.jpg'),
(168457, 11953, 'Mononoke [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524124.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Mwq2KfGunUkRJfVm2qLEYhMCaa.jpg'),
(168458, 11953, 'Mononoke [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524125.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4kLGuaEnTNvt6sJ2sZhKk5jClhd.jpg'),
(168459, 11953, 'Mononoke [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524126.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/19TCgv5XFham3fwwU2oKk42G3rr.jpg'),
(168460, 11953, 'Mononoke [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524127.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cua4n87AzTfemeMYwftZNY4laRy.jpg'),
(168461, 11953, 'Mononoke [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524128.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bxz5Gh6qrt7kSNXnKXO5UA5RzIP.jpg'),
(168462, 11953, 'Mononoke [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524129.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vQwpUzIgmwke8QClhjdniZcwlFu.jpg'),
(168463, 11953, 'Mononoke [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524130.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aUhGA699BBovonSPEgdOQQvJJst.jpg'),
(168464, 11953, 'Mononoke [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524131.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a3euoMeaqDi5B6gPhEe4Iq0NXMP.jpg'),
(168465, 11953, 'Mononoke [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524132.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kVTXJ3HjUc0nMP7uB1UKj1ZMX7i.jpg'),
(168466, 11953, 'Mononoke [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524133.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nOIygXtdzzo9T7eJnAfYHTCO0o9.jpg'),
(168467, 11954, 'Okura Casos Esquecidos [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524117.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wEZfMtijW7NttFjom15jo6HqnXd.jpg'),
(168468, 11954, 'Okura Casos Esquecidos [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524118.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o0ALXv03eQ3rZmaYggscpWsSyRJ.jpg'),
(168469, 11954, 'Okura Casos Esquecidos [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524119.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4zjB32gTEmjilh2a19hpI4o6H6k.jpg'),
(168470, 11954, 'Okura Casos Esquecidos [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524120.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9m4Ybor1qnPOJwKFdpxI1t3V9cV.jpg'),
(168471, 11954, 'Okura Casos Esquecidos [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524121.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tYhLUeD4AVmscfmZiWeUFZ6CM9q.jpg'),
(168472, 11954, 'Okura Casos Esquecidos [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/667916.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lpmar1IFlEkJxMwmIBSqsVZ3eHb.jpg'),
(168473, 11954, 'Okura Casos Esquecidos [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/667917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lpmar1IFlEkJxMwmIBSqsVZ3eHb.jpg'),
(168474, 11954, 'Okura Casos Esquecidos [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/667918.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lpmar1IFlEkJxMwmIBSqsVZ3eHb.jpg'),
(168475, 11954, 'Okura Casos Esquecidos [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/667919.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lpmar1IFlEkJxMwmIBSqsVZ3eHb.jpg'),
(168476, 11954, 'Okura Casos Esquecidos [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/667920.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lpmar1IFlEkJxMwmIBSqsVZ3eHb.jpg'),
(168477, 11955, 'See You in Another Life [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524113.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jkFzkpkIYhkwJZhd9kn1xuxltrg.jpg'),
(168478, 11955, 'See You in Another Life [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524114.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sbNtSVbiyCwiEQAegZr06k3ooGZ.jpg'),
(168479, 11955, 'See You in Another Life [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524115.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bfcgrR0yxtIKjXcqCb7JlUC3obC.jpg'),
(168480, 11955, 'See You in Another Life [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524116.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jtL6125z3csSVs9gOk2v1IEpQUB.jpg'),
(168481, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524102.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fixT2K0lolqqg7VtLtjoUsCu62m.jpg'),
(168482, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524103.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3p4VSbsFMGb5IOAGIlrpJqvsOiV.jpg'),
(168483, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524104.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zylq3FNjQxziseJBvhyKzutGc2f.jpg'),
(168484, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524105.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rWsVdKauv99X3CevDLCIgS71GiT.jpg'),
(168485, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524106.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vZxTE0Ew0UGOQldbWZt6j1qUW75.jpg'),
(168486, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524107.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hXBpt8D8rhzQfiVbIacsRewE34V.jpg'),
(168487, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524108.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/siemkbOvXySYx0GkkPtraVxnYpk.jpg'),
(168488, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524109.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sU2jZGzdi2DzB2MGzLAjOc1wMOU.jpg'),
(168489, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524110.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5uZuXuZDDkAdLZNCPzFnnFQoIWm.jpg'),
(168490, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524111.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yQiJAgR0RYPF5pdkulCfEOg4bms.jpg'),
(168491, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524112.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pYLxwQjxLRKvQof1YjKlSncOLKb.jpg'),
(168492, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/635893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168493, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/639882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168494, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/667198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168495, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/671208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168496, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/678235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168497, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/685012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168498, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/692638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168499, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/701089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168500, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/708723.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168501, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/722924.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168502, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/727527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168503, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/732005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168504, 11956, 'Tying the Knot with an Amagami Sister [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/739730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zLECU0vhFL0bABkQGHe8ziz9VBF.jpg'),
(168505, 11957, 'Youth Water Polo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524090.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7RGRpzAXAKFvdMJuz07KZ9CxyIi.jpg'),
(168506, 11957, 'Youth Water Polo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524091.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/148JRIklWGUHGSDqhqf48W4KavA.jpg'),
(168507, 11957, 'Youth Water Polo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524092.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3wFfcAeJmcVYDz45g9J4jpumrs6.jpg'),
(168508, 11957, 'Youth Water Polo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524093.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8iyBtMPM4L8elAqez8CM7kfWH02.jpg'),
(168509, 11957, 'Youth Water Polo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524094.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ilONDeeqG9qTRTFaGxVFp5C985Z.jpg'),
(168510, 11957, 'Youth Water Polo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524095.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/etKjpBwZ41iUcJBtwaip27WGDOh.jpg'),
(168511, 11957, 'Youth Water Polo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524096.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b1Y31zIUUtsAosJV4JUDNZWAyu.jpg'),
(168512, 11957, 'Youth Water Polo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524097.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n0XvTgliRB4vHDU4iuLqQGpdZc7.jpg'),
(168513, 11957, 'Youth Water Polo [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524098.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lv2bg7Ft3lRsIpUI1cR1fyuMwPy.jpg'),
(168514, 11957, 'Youth Water Polo [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524099.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rRXZrHI91VJfvkPj8f7hRqYtlkw.jpg'),
(168515, 11957, 'Youth Water Polo [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524100.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4aXtEy5MEpz0kCu9VXdDQX3uwGu.jpg'),
(168516, 11957, 'Youth Water Polo [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524101.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oqCqQd3nkm0kgny37huDkDUcPhO.jpg'),
(168517, 11958, 'Zero no Tsukaima [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524065.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iEtt2MUt80DZt9bvH7qz30kZmg8.jpg'),
(168518, 11958, 'Zero no Tsukaima [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524066.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jzLY3DyMXBHkh5woUMq4mi80DCp.jpg'),
(168519, 11958, 'Zero no Tsukaima [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524067.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eTP3HZHy7bWgaqYJJX4mnCWNt9T.jpg'),
(168520, 11958, 'Zero no Tsukaima [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524068.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/un4X7QOMa9QIV0P9XcqnvAssMmF.jpg'),
(168521, 11958, 'Zero no Tsukaima [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524069.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w89BEBPM8SNyx6x8PXIGPkq1kpB.jpg'),
(168522, 11958, 'Zero no Tsukaima [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524070.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1RaeQzjTsB7lbK5Im4STQtW0qoo.jpg'),
(168523, 11958, 'Zero no Tsukaima [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524071.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1O3p6EF3XUZQWBcCJY385wWJo7G.jpg'),
(168524, 11958, 'Zero no Tsukaima [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524072.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rXu11UPN6Yrq50KxXm6Fbn9HnXK.jpg'),
(168525, 11958, 'Zero no Tsukaima [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524073.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5RHhiYU1uVfO3AYzLEC0eQXRu7N.jpg'),
(168526, 11958, 'Zero no Tsukaima [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524074.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cUHQxokCPzk0UfnaM6bwGCc5LBN.jpg'),
(168527, 11958, 'Zero no Tsukaima [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524075.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nj9KKANGEMTqlL8nePJeCzWbpb7.jpg'),
(168528, 11958, 'Zero no Tsukaima [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524076.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u2zc3cPqNMdpATKqaUnKCfX6EMB.jpg'),
(168529, 11958, 'Zero no Tsukaima [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/524077.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k63rwAJaLhSTJvOV1tqfP4CnvjQ.jpg'),
(168530, 11959, 'Zero no Tsukaima [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524078.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zvuxqeMkyGAZrDZirlbhAE8uOgN.jpg'),
(168531, 11959, 'Zero no Tsukaima [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524079.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zjk2oGYxRhgEgHNw0weAQ4aBmwf.jpg'),
(168532, 11959, 'Zero no Tsukaima [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524080.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nThE2w1Wqd9ln80dkfZKMfB1tZh.jpg'),
(168533, 11959, 'Zero no Tsukaima [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524081.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cvVlLRH2055Bwn2Kl4Tv6t2wGc6.jpg'),
(168534, 11959, 'Zero no Tsukaima [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524082.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c7KZ9UxirU3BtUQchIstdPoWj54.jpg'),
(168535, 11959, 'Zero no Tsukaima [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524083.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3SEbamIj5npC3QJJULvaed4p2is.jpg'),
(168536, 11959, 'Zero no Tsukaima [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524084.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pLcyBgld4LKxjXxezgrAVdhw6WD.jpg'),
(168537, 11959, 'Zero no Tsukaima [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524085.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bz0ps5blh5mLJ7CkZi2fR9KfQje.jpg'),
(168538, 11959, 'Zero no Tsukaima [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524086.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nocj9DAGAFskSfzzc3lH40NXts9.jpg'),
(168539, 11959, 'Zero no Tsukaima [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524087.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8ZAOCOahCsPK7I41WM7sicX7jVW.jpg'),
(168540, 11959, 'Zero no Tsukaima [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524088.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fWlfqhucqnEIlGVHnWGl9gdCwfL.jpg'),
(168541, 11959, 'Zero no Tsukaima [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524089.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m2Tzy4YRL0nVdbvfyxvZVYu2caP.jpg'),
(168542, 11960, 'Luluzinha S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/521647.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168543, 11960, 'Luluzinha S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/521648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168544, 11960, 'Luluzinha S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/521649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168545, 11960, 'Luluzinha S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/521650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168546, 11960, 'Luluzinha S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/521651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168547, 11960, 'Luluzinha S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/521652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168548, 11961, 'Luluzinha S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/521653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168549, 11961, 'Luluzinha S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/521654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168550, 11961, 'Luluzinha S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/521655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168551, 11961, 'Luluzinha S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/521656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168552, 11961, 'Luluzinha S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/521657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168553, 11961, 'Luluzinha S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/521658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168554, 11961, 'Luluzinha S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/521659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168555, 11962, 'Luluzinha S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/521660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168556, 11962, 'Luluzinha S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/521661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168557, 11962, 'Luluzinha S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/521662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168558, 11962, 'Luluzinha S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/521663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168559, 11962, 'Luluzinha S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/521664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168560, 11962, 'Luluzinha S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/521665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168561, 11962, 'Luluzinha S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/521666.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168562, 11962, 'Luluzinha S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/521667.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168563, 11962, 'Luluzinha S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/521668.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168564, 11962, 'Luluzinha S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/521669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168565, 11962, 'Luluzinha S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/521670.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168566, 11962, 'Luluzinha S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/521671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168567, 11962, 'Luluzinha S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/521672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168568, 11963, 'Luluzinha S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/521673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168569, 11963, 'Luluzinha S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/521674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168570, 11963, 'Luluzinha S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/521675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168571, 11963, 'Luluzinha S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/521676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168572, 11963, 'Luluzinha S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/521677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168573, 11963, 'Luluzinha S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/521678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168574, 11963, 'Luluzinha S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/521679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168575, 11963, 'Luluzinha S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/521680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168576, 11963, 'Luluzinha S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/521681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168577, 11963, 'Luluzinha S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/521682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168578, 11963, 'Luluzinha S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/521683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168579, 11963, 'Luluzinha S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/521684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168580, 11963, 'Luluzinha S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/521685.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168581, 11963, 'Luluzinha S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/521686.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168582, 11963, 'Luluzinha S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/521687.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168583, 11963, 'Luluzinha S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/521688.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168584, 11963, 'Luluzinha S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/521689.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168585, 11963, 'Luluzinha S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/521690.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168586, 11963, 'Luluzinha S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/521691.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168587, 11963, 'Luluzinha S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/521692.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168588, 11963, 'Luluzinha S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/521693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168589, 11963, 'Luluzinha S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/521694.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168590, 11963, 'Luluzinha S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/521695.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168591, 11963, 'Luluzinha S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/521696.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168592, 11963, 'Luluzinha S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/521697.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168593, 11963, 'Luluzinha S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/521698.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/o7rZ1xjS9Ecg4dAngqjzVza3sHV.jpg'),
(168594, 11964, 'O Mundo dos Casados S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/521631.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5hCPQUYoVQYP3WvjOy8Ur8Owc1M.jpg'),
(168595, 11964, 'O Mundo dos Casados S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/521632.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AnBBKc8xdA0ZsC3Dog8byzvJ7oc.jpg'),
(168596, 11964, 'O Mundo dos Casados S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/521633.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cRCinIhUXhQMiHE3fmyOvYTizxh.jpg'),
(168597, 11964, 'O Mundo dos Casados S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/521634.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uhsDIkhkGSJWzRnaSGfZHnWZzDk.jpg'),
(168598, 11964, 'O Mundo dos Casados S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/521635.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qRXG9clKpFSsgOfwWEPPjVWirqn.jpg'),
(168599, 11964, 'O Mundo dos Casados S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/521636.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/43KuflTYMxANTCQcgM9qVxpj9wk.jpg'),
(168600, 11964, 'O Mundo dos Casados S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/521637.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rpknx7q92SBaE3GTFjNFnQBSwQe.jpg'),
(168601, 11964, 'O Mundo dos Casados S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/521638.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sglkeUYAIYWbdck5tQ56RWbUE3K.jpg'),
(168602, 11964, 'O Mundo dos Casados S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/521639.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sp9AIXiSgW5uE0GYAAMAOPGN5m9.jpg'),
(168603, 11964, 'O Mundo dos Casados S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/521640.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/thcUJeSKDuT1nPKTNPD7i1en7MQ.jpg'),
(168604, 11964, 'O Mundo dos Casados S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/521641.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dd4N3qcunLVsBjICGswRkU6ymj7.jpg'),
(168605, 11964, 'O Mundo dos Casados S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/521642.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wJiErDp8yxCRATBrAyNmJPZvQm8.jpg'),
(168606, 11964, 'O Mundo dos Casados S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/521643.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9B0rzAUTR4IARCPXNHzJmPH7Cpq.jpg'),
(168607, 11964, 'O Mundo dos Casados S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/521644.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/saOV63ob4P5HY4WyPzmYLsfdj9n.jpg'),
(168608, 11964, 'O Mundo dos Casados S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/521645.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jwYtazhV0jtq7NtquhS5JwpVIot.jpg'),
(168609, 11964, 'O Mundo dos Casados S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/634674.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/46Nnt876QY15YnUv7CkA5c5CSTk.jpg'),
(168610, 11965, 'O Show da Luna S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/521422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168611, 11965, 'O Show da Luna S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/521423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168612, 11965, 'O Show da Luna S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/521424.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xSI6iN7N6XpxXO3TOXF70vT4Icr.jpg'),
(168613, 11965, 'O Show da Luna S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/521425.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tkJtEosOs1E8oHyzu2voPYZFyr9.jpg'),
(168614, 11965, 'O Show da Luna S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/521426.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q2UhhWeVMScwIoPkOOtK3u2IYkY.jpg'),
(168615, 11965, 'O Show da Luna S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/521427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168616, 11965, 'O Show da Luna S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/521428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168617, 11965, 'O Show da Luna S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/521429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168618, 11965, 'O Show da Luna S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/521430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168619, 11965, 'O Show da Luna S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/521431.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4N4HNyY9etpgQRfEDSUSdUzVf2t.jpg'),
(168620, 11965, 'O Show da Luna S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/521432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168621, 11965, 'O Show da Luna S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/521433.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eN7vbW1LgbRawVTvt1cfu4kNtKx.jpg'),
(168622, 11965, 'O Show da Luna S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/521434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168623, 11965, 'O Show da Luna S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/521435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168624, 11965, 'O Show da Luna S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/521436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168625, 11965, 'O Show da Luna S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/521437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168626, 11965, 'O Show da Luna S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/521438.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kjxxyBXo9LtXjgls9MzfuTl5xTA.jpg'),
(168627, 11965, 'O Show da Luna S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/521439.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Act4AsOb7mvdPenvqTtfR87Yi3E.jpg'),
(168628, 11965, 'O Show da Luna S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/521440.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w8Zmgp7RExLrOg3IIs2JPDQB2tZ.jpg'),
(168629, 11965, 'O Show da Luna S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/521441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168630, 11965, 'O Show da Luna S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/634470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168631, 11965, 'O Show da Luna S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/521443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168632, 11965, 'O Show da Luna S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/521444.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/taY2NpemTGjn2OfOYfgT8Ly9gKW.jpg'),
(168633, 11965, 'O Show da Luna S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/521445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168634, 11965, 'O Show da Luna S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/521446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168635, 11965, 'O Show da Luna S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/521447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168636, 11966, 'O Show da Luna S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/521448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168637, 11966, 'O Show da Luna S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/521449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(168638, 11966, 'O Show da Luna S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/521450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168639, 11966, 'O Show da Luna S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/521451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168640, 11966, 'O Show da Luna S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/521452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168641, 11966, 'O Show da Luna S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/521453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168642, 11966, 'O Show da Luna S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/521454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168643, 11966, 'O Show da Luna S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/521455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168644, 11966, 'O Show da Luna S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/521456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168645, 11966, 'O Show da Luna S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/521457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168646, 11966, 'O Show da Luna S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/634486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168647, 11966, 'O Show da Luna S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/521459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168648, 11966, 'O Show da Luna S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/634488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168649, 11966, 'O Show da Luna S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/521461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168650, 11966, 'O Show da Luna S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/521462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168651, 11966, 'O Show da Luna S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/521463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168652, 11966, 'O Show da Luna S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/521464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168653, 11966, 'O Show da Luna S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/521465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168654, 11966, 'O Show da Luna S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/521466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168655, 11966, 'O Show da Luna S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/521467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168656, 11966, 'O Show da Luna S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/521468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168657, 11966, 'O Show da Luna S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/521469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168658, 11966, 'O Show da Luna S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/521470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168659, 11966, 'O Show da Luna S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/521471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168660, 11966, 'O Show da Luna S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/521472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168661, 11966, 'O Show da Luna S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/521473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168662, 11967, 'O Show da Luna S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/521474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168663, 11967, 'O Show da Luna S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/634503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168664, 11967, 'O Show da Luna S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/521476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168665, 11967, 'O Show da Luna S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/521477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168666, 11967, 'O Show da Luna S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/521478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168667, 11967, 'O Show da Luna S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/521479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168668, 11967, 'O Show da Luna S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/521480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168669, 11967, 'O Show da Luna S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/521481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168670, 11967, 'O Show da Luna S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/521482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168671, 11967, 'O Show da Luna S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/521483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168672, 11967, 'O Show da Luna S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/521484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168673, 11967, 'O Show da Luna S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/521485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168674, 11967, 'O Show da Luna S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/521486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168675, 11967, 'O Show da Luna S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/521487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168676, 11967, 'O Show da Luna S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/521488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168677, 11967, 'O Show da Luna S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/521489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168678, 11967, 'O Show da Luna S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/634518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168679, 11967, 'O Show da Luna S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/521491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168680, 11967, 'O Show da Luna S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/634520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168681, 11967, 'O Show da Luna S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/521493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168682, 11967, 'O Show da Luna S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/521494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168683, 11967, 'O Show da Luna S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/521495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168684, 11967, 'O Show da Luna S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/521496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168685, 11967, 'O Show da Luna S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/521497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168686, 11967, 'O Show da Luna S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/521498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168687, 11967, 'O Show da Luna S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/521499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168688, 11968, 'O Show da Luna S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/521500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168689, 11968, 'O Show da Luna S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/521501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168690, 11968, 'O Show da Luna S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/521502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168691, 11968, 'O Show da Luna S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/521503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168692, 11968, 'O Show da Luna S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/521504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168693, 11968, 'O Show da Luna S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/521505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168694, 11968, 'O Show da Luna S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/521506.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168695, 11968, 'O Show da Luna S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/521507.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168696, 11968, 'O Show da Luna S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/521508.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168697, 11968, 'O Show da Luna S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/521509.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168698, 11968, 'O Show da Luna S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/521510.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168699, 11968, 'O Show da Luna S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/521511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168700, 11968, 'O Show da Luna S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/521512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168701, 11968, 'O Show da Luna S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/521513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168702, 11968, 'O Show da Luna S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/521514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168703, 11968, 'O Show da Luna S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/521515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168704, 11968, 'O Show da Luna S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/521516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168705, 11968, 'O Show da Luna S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/521517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168706, 11968, 'O Show da Luna S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/521518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168707, 11968, 'O Show da Luna S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/521519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168708, 11968, 'O Show da Luna S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/521520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168709, 11968, 'O Show da Luna S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/521521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168710, 11968, 'O Show da Luna S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/521522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168711, 11968, 'O Show da Luna S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/521523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168712, 11968, 'O Show da Luna S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/521524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168713, 11968, 'O Show da Luna S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/521525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168714, 11969, 'O Show da Luna S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/634554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168715, 11969, 'O Show da Luna S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/521527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168716, 11969, 'O Show da Luna S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/634556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168717, 11969, 'O Show da Luna S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/521529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168718, 11969, 'O Show da Luna S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/521530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168719, 11969, 'O Show da Luna S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/521531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168720, 11969, 'O Show da Luna S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/521532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168721, 11969, 'O Show da Luna S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/521533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168722, 11969, 'O Show da Luna S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/521534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168723, 11969, 'O Show da Luna S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/521535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168724, 11969, 'O Show da Luna S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/521536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168725, 11969, 'O Show da Luna S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/521537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168726, 11969, 'O Show da Luna S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/521538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168727, 11969, 'O Show da Luna S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/521539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168728, 11969, 'O Show da Luna S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/521540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168729, 11969, 'O Show da Luna S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/521541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168730, 11969, 'O Show da Luna S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/521542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168731, 11969, 'O Show da Luna S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/521543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168732, 11969, 'O Show da Luna S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/521544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168733, 11969, 'O Show da Luna S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/521545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168734, 11969, 'O Show da Luna S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/521546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168735, 11969, 'O Show da Luna S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/521547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168736, 11969, 'O Show da Luna S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/521548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168737, 11969, 'O Show da Luna S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/521549.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168738, 11969, 'O Show da Luna S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/521550.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168739, 11969, 'O Show da Luna S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/521551.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168740, 11969, 'O Show da Luna S05 E27', 'http://sinalprivado.info:80/series/1533784/1533784/521552.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168741, 11970, 'O Show da Luna S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/521553.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168742, 11970, 'O Show da Luna S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/521554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168743, 11970, 'O Show da Luna S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/521555.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168744, 11970, 'O Show da Luna S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/521556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168745, 11970, 'O Show da Luna S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/521557.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168746, 11970, 'O Show da Luna S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/521558.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168747, 11970, 'O Show da Luna S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/521559.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168748, 11970, 'O Show da Luna S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/521560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168749, 11970, 'O Show da Luna S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/521561.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168750, 11970, 'O Show da Luna S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/521562.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168751, 11970, 'O Show da Luna S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/521563.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168752, 11970, 'O Show da Luna S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/521564.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168753, 11970, 'O Show da Luna S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/521565.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168754, 11970, 'O Show da Luna S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/521566.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168755, 11970, 'O Show da Luna S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/521567.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168756, 11970, 'O Show da Luna S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/521568.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168757, 11970, 'O Show da Luna S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/521569.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168758, 11970, 'O Show da Luna S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/521570.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168759, 11970, 'O Show da Luna S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/521571.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168760, 11970, 'O Show da Luna S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/521572.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168761, 11970, 'O Show da Luna S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/521573.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168762, 11970, 'O Show da Luna S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/521574.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168763, 11970, 'O Show da Luna S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/521575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168764, 11970, 'O Show da Luna S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/521576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168765, 11970, 'O Show da Luna S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/521577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168766, 11970, 'O Show da Luna S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/521578.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168767, 11971, 'O Show da Luna S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/521579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168768, 11971, 'O Show da Luna S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/521580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168769, 11971, 'O Show da Luna S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/521581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168770, 11971, 'O Show da Luna S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/521582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168771, 11971, 'O Show da Luna S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/521583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168772, 11971, 'O Show da Luna S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/521584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168773, 11971, 'O Show da Luna S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/521585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168774, 11971, 'O Show da Luna S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/521586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168775, 11971, 'O Show da Luna S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/521587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168776, 11971, 'O Show da Luna S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/521588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168777, 11971, 'O Show da Luna S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/521589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168778, 11971, 'O Show da Luna S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/521590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168779, 11971, 'O Show da Luna S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/521591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168780, 11971, 'O Show da Luna S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/521592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168781, 11971, 'O Show da Luna S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/521593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168782, 11971, 'O Show da Luna S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/521594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168783, 11971, 'O Show da Luna S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/521595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168784, 11971, 'O Show da Luna S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/521596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168785, 11971, 'O Show da Luna S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/521597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168786, 11971, 'O Show da Luna S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/521598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168787, 11971, 'O Show da Luna S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/521599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168788, 11971, 'O Show da Luna S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/521600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168789, 11971, 'O Show da Luna S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/521601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168790, 11971, 'O Show da Luna S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/521602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168791, 11971, 'O Show da Luna S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/521603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168792, 11971, 'O Show da Luna S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/521604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168793, 11972, 'O Show da Luna S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/521605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168794, 11972, 'O Show da Luna S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/521606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168795, 11972, 'O Show da Luna S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/521607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168796, 11972, 'O Show da Luna S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/521608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168797, 11972, 'O Show da Luna S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/521609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168798, 11972, 'O Show da Luna S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/521610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168799, 11972, 'O Show da Luna S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/521611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168800, 11972, 'O Show da Luna S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/521612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168801, 11972, 'O Show da Luna S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/521613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168802, 11972, 'O Show da Luna S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/521614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168803, 11972, 'O Show da Luna S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/521615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168804, 11972, 'O Show da Luna S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/521616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168805, 11972, 'O Show da Luna S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/521617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168806, 11972, 'O Show da Luna S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/521618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168807, 11972, 'O Show da Luna S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/521619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168808, 11972, 'O Show da Luna S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/521620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168809, 11972, 'O Show da Luna S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/521621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168810, 11972, 'O Show da Luna S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/521622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168811, 11972, 'O Show da Luna S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/521623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168812, 11972, 'O Show da Luna S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/521624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168813, 11972, 'O Show da Luna S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/521625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168814, 11972, 'O Show da Luna S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/521626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168815, 11972, 'O Show da Luna S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/521627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168816, 11972, 'O Show da Luna S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/521628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168817, 11972, 'O Show da Luna S08 E25', 'http://sinalprivado.info:80/series/1533784/1533784/521629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168818, 11972, 'O Show da Luna S08 E26', 'http://sinalprivado.info:80/series/1533784/1533784/521630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hYRwRganCESkloQydyEgGz7lYV.jpg'),
(168819, 11973, 'Popeye e Filho S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/521411.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Aadf7lQlKBA5aWHIAVAqiOM5oLK.jpg'),
(168820, 11973, 'Popeye e Filho S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/521412.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/axDgDsSYFeOvQiBzf2nSoxDfSUV.jpg'),
(168821, 11973, 'Popeye e Filho S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/521413.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/GCeqnr03TZVteHPMUVOGMm2wwg.jpg'),
(168822, 11973, 'Popeye e Filho S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/521414.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t7XqUcSo94uynyf4qffmONDZrDN.jpg'),
(168823, 11973, 'Popeye e Filho S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/521415.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nBf82n069XrkpEt9ODj7cO0YxLc.jpg'),
(168824, 11973, 'Popeye e Filho S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/521416.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wN5bSmVEtgDgI1rAcpatlY1dGUz.jpg'),
(168825, 11973, 'Popeye e Filho S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/521417.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jTXcaheUIcQfjVSN2L0ZT5pzPmW.jpg'),
(168826, 11973, 'Popeye e Filho S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/521418.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9A0n3FFbC3Ix38lx4kVwYP9UagU.jpg'),
(168827, 11973, 'Popeye e Filho S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/521419.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qACYXdS9OtGwRFHGnd26x8MFHxs.jpg'),
(168828, 11973, 'Popeye e Filho S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/521420.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4vrV1VzQv7WevoBT1GIh0qXHjdl.jpg'),
(168829, 11973, 'Popeye e Filho S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/521421.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tgY1qjEKrrsiyIYU1JFy7QuaXsm.jpg'),
(168830, 11974, 'As Prisoes Mais Notorias do Mundo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/521408.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nMTO0ggLTglyly83QZUfpGbZQwz.jpg'),
(168831, 11974, 'As Prisoes Mais Notorias do Mundo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/521409.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w0zggIeNKWVEmvbd4YZ7iVyvpHC.jpg'),
(168832, 11974, 'As Prisoes Mais Notorias do Mundo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/521410.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6p32ek2bFd1CEks7StgPif1FEkV.jpg'),
(168833, 11974, 'As Prisoes Mais Notorias do Mundo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptew2dufAFDuJIFBAQMqUhmjuKt.jpg'),
(168834, 11974, 'As Prisoes Mais Notorias do Mundo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/637466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptew2dufAFDuJIFBAQMqUhmjuKt.jpg'),
(168835, 11974, 'As Prisoes Mais Notorias do Mundo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/637467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptew2dufAFDuJIFBAQMqUhmjuKt.jpg'),
(168836, 11974, 'As Prisoes Mais Notorias do Mundo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptew2dufAFDuJIFBAQMqUhmjuKt.jpg'),
(168837, 11974, 'As Prisoes Mais Notorias do Mundo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptew2dufAFDuJIFBAQMqUhmjuKt.jpg'),
(168838, 11974, 'As Prisoes Mais Notorias do Mundo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/637470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptew2dufAFDuJIFBAQMqUhmjuKt.jpg'),
(168839, 11974, 'As Prisoes Mais Notorias do Mundo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/692435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptew2dufAFDuJIFBAQMqUhmjuKt.jpg'),
(168840, 11974, 'As Prisoes Mais Notorias do Mundo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/692436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptew2dufAFDuJIFBAQMqUhmjuKt.jpg'),
(168841, 11974, 'As Prisoes Mais Notorias do Mundo S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/692437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ptew2dufAFDuJIFBAQMqUhmjuKt.jpg'),
(168842, 11975, 'Meu Estranho Perfeito [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524723.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1S7IVOU5WK1ojnz5nWlav3MtzBd.jpg'),
(168843, 11975, 'Meu Estranho Perfeito [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524724.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dYxMOSfVeyVUqJFyE6S5YLsbef2.jpg'),
(168844, 11975, 'Meu Estranho Perfeito [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524725.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cCbGE6SRyQhPHOBZWYz4yLRPshO.jpg'),
(168845, 11975, 'Meu Estranho Perfeito [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524726.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ir5I9HkZa2DktTghvxqkn5oFHLc.jpg'),
(168846, 11975, 'Meu Estranho Perfeito [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524727.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nn80mfWtxZMePNGtKvighjOe57s.jpg'),
(168847, 11975, 'Meu Estranho Perfeito [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524728.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nRw4N2gDWoTtv3ehVL1fK6pxE10.jpg'),
(168848, 11975, 'Meu Estranho Perfeito [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524729.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9ReBI1HXvU0RLP4o7zNQduBA8XQ.jpg'),
(168849, 11975, 'Meu Estranho Perfeito [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524730.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1D4e97bYlg7g9xmz06iOaXSb0dS.jpg'),
(168850, 11975, 'Meu Estranho Perfeito [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524731.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7ahdhAuHl99lasx7NwZpmczMtjS.jpg'),
(168851, 11975, 'Meu Estranho Perfeito [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524732.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xV6IqfhdmtVfM4Imrh3AN2377JE.jpg'),
(168852, 11975, 'Meu Estranho Perfeito [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524733.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wAoqQUZ9ZA1k4JwMSjsBgqB7zQ9.jpg'),
(168853, 11975, 'Meu Estranho Perfeito [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524734.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kCeSs4z9ITyuFj1oRYW1UZVQbxZ.jpg'),
(168854, 11975, 'Meu Estranho Perfeito [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/524735.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m9ybvigluwOCf6dPEjdLAZkXlZi.jpg'),
(168855, 11975, 'Meu Estranho Perfeito [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/524736.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y8XYFl798D7sUpk0KWhdiZWR1qF.jpg'),
(168856, 11975, 'Meu Estranho Perfeito [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/524737.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2nfPlM0nDU1xpX64jdzt66PWyiT.jpg'),
(168857, 11975, 'Meu Estranho Perfeito [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/524738.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4RmGDIVB8XscjvJEhoJU6PDHkVn.jpg'),
(168858, 11976, 'Justica Verdadeira S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524697.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/anHe8EwEytm1jOoEDNSYgwGN3DN.jpg'),
(168859, 11976, 'Justica Verdadeira S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524698.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f0D8xr0IJzKyA5xaBCtocCQhWEc.jpg'),
(168860, 11976, 'Justica Verdadeira S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524699.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tu84DHaMqTDaMW9ATR322wzXQrF.jpg'),
(168861, 11976, 'Justica Verdadeira S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524700.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/918tgDPJ8Er10TFrMTLJtGmRETr.jpg'),
(168862, 11976, 'Justica Verdadeira S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524701.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qeAyBRXZAiqe74z75ZaU7GLUtVW.jpg'),
(168863, 11976, 'Justica Verdadeira S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524702.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rBpBmBPze8cRxE4W1bX27cCAgz7.jpg'),
(168864, 11976, 'Justica Verdadeira S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524703.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o2HsHQ5pd3QPoKQq6JF61V6SeQ0.jpg'),
(168865, 11976, 'Justica Verdadeira S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524704.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3UJgORmwaqhL5nESXXySgl4RqGF.jpg'),
(168866, 11976, 'Justica Verdadeira S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524705.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gFPAnxIDNfUytiyDgPsVMRk1jFq.jpg'),
(168867, 11976, 'Justica Verdadeira S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524706.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2EBCcOJyw3HwBGIT0Eod9KMOoGT.jpg'),
(168868, 11976, 'Justica Verdadeira S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524707.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dAVkBBAUreB1CtJvUP4bCGRdvTS.jpg'),
(168869, 11976, 'Justica Verdadeira S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524708.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5lNYPk0iZtFk9UUb3T6TjryVXjT.jpg'),
(168870, 11976, 'Justica Verdadeira S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/524709.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gpAodGFhmRMT1SoQsRmmK10dpdS.jpg'),
(168871, 11977, 'Justica Verdadeira S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524710.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3AbXI8Y8ppECgJalUBA2cDbLq8R.jpg'),
(168872, 11977, 'Justica Verdadeira S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524711.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xvbKi8KUIYINxsgQP1LJ5kdqM9t.jpg'),
(168873, 11977, 'Justica Verdadeira S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524712.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b4Lazsev50mjT7g6NQcxHIIHv9a.jpg'),
(168874, 11977, 'Justica Verdadeira S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524713.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/umXJRcoLBxCln8J5b7HglluvdOD.jpg'),
(168875, 11977, 'Justica Verdadeira S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524714.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gyyZZ5gVUJ2TDekWhlRRm31YxU8.jpg'),
(168876, 11977, 'Justica Verdadeira S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524715.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f3vsjWTp9rLegWIHHGZE4GPwbPo.jpg'),
(168877, 11977, 'Justica Verdadeira S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524716.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5M36YIGNK5T5iVuyouZZGycen0C.jpg'),
(168878, 11977, 'Justica Verdadeira S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524717.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xJXwVybjbldOyk4jUKrloaOOWSV.jpg'),
(168879, 11977, 'Justica Verdadeira S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524718.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p387b8DaOUN31idM0t4QX6q6Hht.jpg'),
(168880, 11977, 'Justica Verdadeira S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524719.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2jgBdmMPoeJ8JGgCkFAGMcBiDb1.jpg'),
(168881, 11977, 'Justica Verdadeira S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524720.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9j6ByGIZEN5BZtJphLW8teXxezL.jpg'),
(168882, 11977, 'Justica Verdadeira S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524721.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mTRo7I63dcWdZr1P4Lh2S46RWfr.jpg'),
(168883, 11977, 'Justica Verdadeira S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/524722.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/TV8GgSbJb5gMZpnt7p6wfZDHgG.jpg'),
(168884, 11978, 'Parenthood Minha Familia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524594.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uwCcbpQ8WilYUsLwayGN0bShQN9.jpg'),
(168885, 11978, 'Parenthood Minha Familia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524595.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/525nb3M6EEwOXo2il0Q0Kxv6gKN.jpg'),
(168886, 11978, 'Parenthood Minha Familia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524596.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/poigH4OKlbaXjAzK4Kor8lirPO5.jpg'),
(168887, 11978, 'Parenthood Minha Familia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524597.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/53fTaxaUuLE1tm0M5vECOlbDl05.jpg'),
(168888, 11978, 'Parenthood Minha Familia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524598.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3ktKKcmfTsTlFthdC26VlYKJ7f6.jpg'),
(168889, 11978, 'Parenthood Minha Familia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524599.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kjnjjQIlL05Y8kY1RwlM57YQclt.jpg'),
(168890, 11978, 'Parenthood Minha Familia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524600.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nI3PlYzwlmVKK2prG8NfQwqonxU.jpg'),
(168891, 11978, 'Parenthood Minha Familia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524601.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dbNspRA4KeZQqrVcuuj2XSO6maY.jpg'),
(168892, 11978, 'Parenthood Minha Familia S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524602.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/doKshv1CTKx3i0AKPlJZPqItBVL.jpg'),
(168893, 11978, 'Parenthood Minha Familia S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524603.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kdQFegBFHd2OBYCToTVBKlIT3CZ.jpg'),
(168894, 11978, 'Parenthood Minha Familia S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524604.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9mzV5zgkI1fTRM7hAgwrLnbP6TL.jpg'),
(168895, 11978, 'Parenthood Minha Familia S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524605.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/13aki0flzUNX47V8UivmNwHTvin.jpg'),
(168896, 11978, 'Parenthood Minha Familia S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/524606.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jgxagsrRdMluI6MX1Tm2aiGxT7p.jpg'),
(168897, 11979, 'Parenthood Minha Familia S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524607.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/59zvncszJEEYsGsyHhNaFaVkQRv.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(168898, 11979, 'Parenthood Minha Familia S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524608.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/731E88COBo9mhdcPmisgzSeEC4l.jpg'),
(168899, 11979, 'Parenthood Minha Familia S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524609.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jdL6W8mayaYNxNyQJbWfdqVy1Yx.jpg'),
(168900, 11979, 'Parenthood Minha Familia S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524610.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AoJIUJP4cxsHLwyYnxfmYJOR20q.jpg'),
(168901, 11979, 'Parenthood Minha Familia S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524611.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dMNX4i9qtdDtjFERPbHSWw5JMih.jpg'),
(168902, 11979, 'Parenthood Minha Familia S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524612.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5uQEUSumQdnuhKCNfrDxqUAioq9.jpg'),
(168903, 11979, 'Parenthood Minha Familia S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524613.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ykOGyGZDQFmqvDdU7BkcJeiZPL6.jpg'),
(168904, 11979, 'Parenthood Minha Familia S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524614.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w99RwPIIvzBG7ozo28QEFpvbsjz.jpg'),
(168905, 11979, 'Parenthood Minha Familia S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524615.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bIg3YXWd4fvhbaNWLWP55Jox0sK.jpg'),
(168906, 11979, 'Parenthood Minha Familia S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524616.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s1Plqyy8R13RVKUeZwdPQ3An7Es.jpg'),
(168907, 11979, 'Parenthood Minha Familia S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524617.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x7MFAtBz85KVbYq2IVYchFf12K3.jpg'),
(168908, 11979, 'Parenthood Minha Familia S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524618.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Ap0c5P701S8D73cPGxL9KPSgvf.jpg'),
(168909, 11979, 'Parenthood Minha Familia S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/524619.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uPwsZ3VUAMhvVHZVOQsSygXN64n.jpg'),
(168910, 11979, 'Parenthood Minha Familia S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/524620.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lsPZWdxVkx9VZF18Z8wv9Bnst1U.jpg'),
(168911, 11979, 'Parenthood Minha Familia S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/524621.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kmXvo5JblIIVgaIfdhVqRuNmE8F.jpg'),
(168912, 11979, 'Parenthood Minha Familia S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/524622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9dbPtRxWYj6Ch9kPerhks0XoH7.jpg'),
(168913, 11979, 'Parenthood Minha Familia S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/524623.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1Y5XM9sC5QRkeo93RsNvewvTE2q.jpg'),
(168914, 11979, 'Parenthood Minha Familia S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/524624.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gv72UuxlxZrZqWvCcfKfEpw304M.jpg'),
(168915, 11979, 'Parenthood Minha Familia S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/524625.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g7e6KUMLNrXCd4thEMOk8kEHGEq.jpg'),
(168916, 11979, 'Parenthood Minha Familia S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/524626.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5U5GhAtIVIaxTShyPHt2NqLvylz.jpg'),
(168917, 11979, 'Parenthood Minha Familia S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/524627.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rPUZl4GZi7Yhew7T9dN6xLHj6gD.jpg'),
(168918, 11979, 'Parenthood Minha Familia S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/524628.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9gGtaRmmNwRk3HKhIuas9Wk8UvF.jpg'),
(168919, 11980, 'Parenthood Minha Familia S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524629.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/59E5bbRF4rlYM8Qy0tA9oNab6z5.jpg'),
(168920, 11980, 'Parenthood Minha Familia S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524630.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oJpVjoH0qsfYcaWV0S6G5dozNgf.jpg'),
(168921, 11980, 'Parenthood Minha Familia S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524631.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9DrxlOlzdfSPARBdHAaUi9bin2w.jpg'),
(168922, 11980, 'Parenthood Minha Familia S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524632.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6GTb4ToAbl9sChdUX6eNBysNNrM.jpg'),
(168923, 11980, 'Parenthood Minha Familia S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524633.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vTiS2Y75Pz4UE6dOJUMMTpQzFtc.jpg'),
(168924, 11980, 'Parenthood Minha Familia S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524634.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cVOi0qJaFCrHz6X5OkJJIROLWEJ.jpg'),
(168925, 11980, 'Parenthood Minha Familia S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524635.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cr2uLjA0iSQ1iTQsC7NO3ZdsBid.jpg'),
(168926, 11980, 'Parenthood Minha Familia S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524636.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1EdM5fyeRRrvGaIrGn68uppgch5.jpg'),
(168927, 11980, 'Parenthood Minha Familia S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524637.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u39v8LZNyCnj25KVAcN5bW2y5FF.jpg'),
(168928, 11980, 'Parenthood Minha Familia S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524638.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vcpGjGHxv8maZgjSRxY3gDjs8Xr.jpg'),
(168929, 11980, 'Parenthood Minha Familia S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524639.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yCBmY2XoITiV5CWSJyKN2CYyhhe.jpg'),
(168930, 11980, 'Parenthood Minha Familia S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524640.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lPYeA5xNbnPwoLzVOZnIuouFeJ8.jpg'),
(168931, 11980, 'Parenthood Minha Familia S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/524641.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hx5IcbFbpRX5sGA9Fun1xYqhWbo.jpg'),
(168932, 11980, 'Parenthood Minha Familia S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/524642.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bpyPzvDSvQmbSxXQSGdKNCJVDW8.jpg'),
(168933, 11980, 'Parenthood Minha Familia S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/524643.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zClR3sDJRXMfZcelPRhXgfPQ5kq.jpg'),
(168934, 11980, 'Parenthood Minha Familia S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/524644.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tfXAGldwsi4z7p52hn3j4LHva3j.jpg'),
(168935, 11980, 'Parenthood Minha Familia S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/524645.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5uf7XymsKhW03kV1DDOvGfSd3tW.jpg'),
(168936, 11980, 'Parenthood Minha Familia S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/524646.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iBVRr8wXt2wy27r5QA5pe05P4TE.jpg'),
(168937, 11981, 'Parenthood Minha Familia S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524647.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wsOWKp4OjBEzdcJrnZL4lssByaJ.jpg'),
(168938, 11981, 'Parenthood Minha Familia S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524648.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A5FrSipacb0A2AFwY1u2u0QgRev.jpg'),
(168939, 11981, 'Parenthood Minha Familia S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524649.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7H4DYP0SVF9jKhOOjbTVxkW0teL.jpg'),
(168940, 11981, 'Parenthood Minha Familia S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524650.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bGzFrT7mC6pOwzwbbO6cYZJ1uzh.jpg'),
(168941, 11981, 'Parenthood Minha Familia S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524651.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2EtosmG37NWDDnBPeynWcrskSIe.jpg'),
(168942, 11981, 'Parenthood Minha Familia S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524652.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d4gaVin6wAet5AdLPBSOPi1bsWk.jpg'),
(168943, 11981, 'Parenthood Minha Familia S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524653.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gAZNgbU9ymmP7PBAFthCo0Li3HW.jpg'),
(168944, 11981, 'Parenthood Minha Familia S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524654.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ekUiJ6SYVFEnXMaP1YXmof7zRze.jpg'),
(168945, 11981, 'Parenthood Minha Familia S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524655.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/stpX4FiPSrOMlrtFLiUONxNU9QE.jpg'),
(168946, 11981, 'Parenthood Minha Familia S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524656.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ljjkbJMYvljcmWjkRAyxuY24n9Y.jpg'),
(168947, 11981, 'Parenthood Minha Familia S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524657.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eB2NPmnfE9KzAmN6LtBOLfU5soj.jpg'),
(168948, 11981, 'Parenthood Minha Familia S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524658.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eZOqyyVVoJiBVmDQkrneIKP82o5.jpg'),
(168949, 11981, 'Parenthood Minha Familia S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/524659.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/inRoeFH97ZjNeL6mDMsWnJxVcps.jpg'),
(168950, 11981, 'Parenthood Minha Familia S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/524660.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tIK801MlzyhEzGypkqYdfuK8z9D.jpg'),
(168951, 11981, 'Parenthood Minha Familia S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/524661.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/plARgtv63neLP5944WYUFLTFsui.jpg'),
(168952, 11982, 'Parenthood Minha Familia S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524662.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tmqYTbF8wdNNSLziaCjL6BXrXpz.jpg'),
(168953, 11982, 'Parenthood Minha Familia S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524663.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t4G0U0lqLcKufaJ7HR4DA5WlwHe.jpg'),
(168954, 11982, 'Parenthood Minha Familia S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524664.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o6veSF5IAC2xC5xfYOtyNjeWLQB.jpg'),
(168955, 11982, 'Parenthood Minha Familia S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524665.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/miCbh4xKIC4Fg4EPOfpbEzcjfR8.jpg'),
(168956, 11982, 'Parenthood Minha Familia S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524666.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hY9MAkXDUkqBK1Mpe1bFSCA9tgb.jpg'),
(168957, 11982, 'Parenthood Minha Familia S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524667.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wffCYGaJ4SihkTL0JjcbSY1RcVs.jpg'),
(168958, 11982, 'Parenthood Minha Familia S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524668.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pUi5vTANmnoiDAhAYrXGyx5razk.jpg'),
(168959, 11982, 'Parenthood Minha Familia S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524669.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bgIlzxbEaJcy1E6LkSdwURB0xRu.jpg'),
(168960, 11982, 'Parenthood Minha Familia S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524670.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7gclaL1te4hTQi0KQChxA5kZoVh.jpg'),
(168961, 11982, 'Parenthood Minha Familia S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524671.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9dbPtRxWYj6Ch9kPerhks0XoH7.jpg'),
(168962, 11982, 'Parenthood Minha Familia S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524672.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9dbPtRxWYj6Ch9kPerhks0XoH7.jpg'),
(168963, 11982, 'Parenthood Minha Familia S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524673.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9dbPtRxWYj6Ch9kPerhks0XoH7.jpg'),
(168964, 11982, 'Parenthood Minha Familia S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/524674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9dbPtRxWYj6Ch9kPerhks0XoH7.jpg'),
(168965, 11982, 'Parenthood Minha Familia S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/524675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9dbPtRxWYj6Ch9kPerhks0XoH7.jpg'),
(168966, 11982, 'Parenthood Minha Familia S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/524676.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9dbPtRxWYj6Ch9kPerhks0XoH7.jpg'),
(168967, 11982, 'Parenthood Minha Familia S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/524677.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9dbPtRxWYj6Ch9kPerhks0XoH7.jpg'),
(168968, 11982, 'Parenthood Minha Familia S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/524678.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9dbPtRxWYj6Ch9kPerhks0XoH7.jpg'),
(168969, 11982, 'Parenthood Minha Familia S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/524679.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9dbPtRxWYj6Ch9kPerhks0XoH7.jpg'),
(168970, 11982, 'Parenthood Minha Familia S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/524680.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9dbPtRxWYj6Ch9kPerhks0XoH7.jpg'),
(168971, 11982, 'Parenthood Minha Familia S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/524681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9dbPtRxWYj6Ch9kPerhks0XoH7.jpg'),
(168972, 11982, 'Parenthood Minha Familia S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/524682.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9dbPtRxWYj6Ch9kPerhks0XoH7.jpg'),
(168973, 11982, 'Parenthood Minha Familia S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/524683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/v9dbPtRxWYj6Ch9kPerhks0XoH7.jpg'),
(168974, 11983, 'Parenthood Minha Familia S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524684.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3NjQTVET3uy192ASNia4zscLpkB.jpg'),
(168975, 11983, 'Parenthood Minha Familia S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524685.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/spg8U8FQXR0cwk23lwz342ygkGR.jpg'),
(168976, 11983, 'Parenthood Minha Familia S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524686.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ucYqMQzcuaeFL6C1K4beCWmV7RG.jpg'),
(168977, 11983, 'Parenthood Minha Familia S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524687.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5bjZnuYSzw6ajyr2SOkTzGNVm9G.jpg'),
(168978, 11983, 'Parenthood Minha Familia S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524688.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rvXxLHnNZkvqdu6q7m4OdVjtrqe.jpg'),
(168979, 11983, 'Parenthood Minha Familia S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524689.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vGFB44i03EOINEDQck4XCDelq4J.jpg'),
(168980, 11983, 'Parenthood Minha Familia S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524690.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zGtAgKE2TPrTMIigOcJqeVRDQJ2.jpg'),
(168981, 11983, 'Parenthood Minha Familia S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524691.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kaj7TTVnHcgtaquBgil4JgYwyrF.jpg'),
(168982, 11983, 'Parenthood Minha Familia S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524692.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cdiKMNk5a395zMBvRKiDdIgq41m.jpg'),
(168983, 11983, 'Parenthood Minha Familia S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524693.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2FpYzTS3oOaKWCrMa6l0U2A64DP.jpg'),
(168984, 11983, 'Parenthood Minha Familia S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524694.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6m8JIKpDKU3lnyHuiQrwAgYjtQc.jpg'),
(168985, 11983, 'Parenthood Minha Familia S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524695.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3Y1RV2V8wFSK8WAi0LXcKn1T2RM.jpg'),
(168986, 11983, 'Parenthood Minha Familia S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/524696.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sVAXC4wfTlvLqsqHLIsLwt6zxNQ.jpg'),
(168987, 11984, 'Tres Espias Demais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524421.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nNPUyhCFf8AyQz0s9Cs9vfDJJG8.jpg'),
(168988, 11984, 'Tres Espias Demais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524422.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4jJr6areqO8YZFBhJQiiUUyvcB0.jpg'),
(168989, 11984, 'Tres Espias Demais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524423.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t97lFyUP0Q2lQ1xmVHjSV4ZEde9.jpg'),
(168990, 11984, 'Tres Espias Demais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524424.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/trNOELDzfGi2wBNnd6mOK7CozXM.jpg'),
(168991, 11984, 'Tres Espias Demais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524425.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gHpUzbwOGR21I5S221Q6BYiw2Zz.jpg'),
(168992, 11984, 'Tres Espias Demais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524426.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pK6j5ssvukN1ROCTYge6dycTsgS.jpg'),
(168993, 11984, 'Tres Espias Demais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524427.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3G1RwpJCeg8ji1AoQfkPVKVLgJI.jpg'),
(168994, 11984, 'Tres Espias Demais S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524428.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cGz5UGwPZiYklhgMzvtFsrjK2NT.jpg'),
(168995, 11984, 'Tres Espias Demais S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524429.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2xaHIJHoPcStPs9vvXQIhx8IVOm.jpg'),
(168996, 11984, 'Tres Espias Demais S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524430.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ozEqhmEeSinLwW2bLGXdhXaNNoK.jpg'),
(168997, 11984, 'Tres Espias Demais S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524431.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yTxKQYnyWUdNyidhxKfFupddEFs.jpg'),
(168998, 11984, 'Tres Espias Demais S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524432.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lqg9hI0MCXkSFDIVJWjgtUyP5HB.jpg'),
(168999, 11984, 'Tres Espias Demais S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/524433.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4Ki6BdMbUgKKUkIcLbmbVCF9vkr.jpg'),
(169000, 11984, 'Tres Espias Demais S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/524434.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r02ojyCe2w9suhiXE2VF6vRIhuY.jpg'),
(169001, 11984, 'Tres Espias Demais S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/524435.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zoJ67a5ZKt9xCq4aK9IuYdHEGb2.jpg'),
(169002, 11984, 'Tres Espias Demais S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/524436.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6tQKSGwMznbFoSsJTHT9V8FPpF7.jpg'),
(169003, 11984, 'Tres Espias Demais S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/524437.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gSmB63ypgaFeSJNqJaGVG79SvXG.jpg'),
(169004, 11984, 'Tres Espias Demais S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/524438.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i5Fv722yU0kW6WNLju2fekjgdlX.jpg'),
(169005, 11984, 'Tres Espias Demais S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/524439.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jKdXOKVF5SNMvzOz7iB66IP9GKA.jpg'),
(169006, 11984, 'Tres Espias Demais S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/524440.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/axBPr1y2AD7i4x0CjMUVFinI8tl.jpg'),
(169007, 11984, 'Tres Espias Demais S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/524441.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vajb18EFP6il8RbB6tsh9DYuFLw.jpg'),
(169008, 11984, 'Tres Espias Demais S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/524442.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lofErx7XvGfaLihtRAEVh78Ug1L.jpg'),
(169009, 11984, 'Tres Espias Demais S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/524443.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fjIyDCEohGgkNQFJssmKILE0QiY.jpg'),
(169010, 11984, 'Tres Espias Demais S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/524444.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gKwgP2kO8EZnP6PohdpuSF26Zo3.jpg'),
(169011, 11984, 'Tres Espias Demais S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/524445.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8TxCI61nJoeoTT7TSzt9dPLtIAX.jpg'),
(169012, 11984, 'Tres Espias Demais S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/524446.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e5IhcCgvgZeAlKOZ3nQ6VFqsQkT.jpg'),
(169013, 11985, 'Tres Espias Demais S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524447.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qXTfrldpNZVIZtNBlzjS28IqcDh.jpg'),
(169014, 11985, 'Tres Espias Demais S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524448.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ujJr7TMgLlXkrQWvSB8V0JIgbnf.jpg'),
(169015, 11985, 'Tres Espias Demais S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524449.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bAaTy0aPkkD49OYURSrC1rfM6qX.jpg'),
(169016, 11985, 'Tres Espias Demais S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524450.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aFCxMrWk8ovynM2jkwDrzFDmd2l.jpg'),
(169017, 11985, 'Tres Espias Demais S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524451.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o4wQfn34TlICD4LS2yk2KL91oB4.jpg'),
(169018, 11985, 'Tres Espias Demais S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524452.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wmDfvDmWsDhbpBOrjVqFYpML71x.jpg'),
(169019, 11985, 'Tres Espias Demais S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524453.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gdNYbtDTquNP6yK6v4Z8NpY5EpA.jpg'),
(169020, 11985, 'Tres Espias Demais S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524454.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k2flvCEkQmNxIike55ObpELN17f.jpg'),
(169021, 11985, 'Tres Espias Demais S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524455.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cFM4UVuK39kY2t8l4W39N7sPRK5.jpg'),
(169022, 11985, 'Tres Espias Demais S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524456.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y0tZCoqNs2UIjyfmu3zd8ms3isi.jpg'),
(169023, 11985, 'Tres Espias Demais S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524457.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eu67BXnn8iwfEiiX7mwBBIx4Mlo.jpg'),
(169024, 11985, 'Tres Espias Demais S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524458.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mLFZIciO78b0MvZfV8Ztl1G63yA.jpg'),
(169025, 11985, 'Tres Espias Demais S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/524459.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cizLnjSXvBQ54nrh13I7Fj71aA9.jpg'),
(169026, 11985, 'Tres Espias Demais S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/524460.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zmX6pbfHEgGPpBp46yCrP42KUIe.jpg'),
(169027, 11985, 'Tres Espias Demais S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/524461.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dXF5Vo0vZt927MPsLaSoenrmrie.jpg'),
(169028, 11985, 'Tres Espias Demais S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/524462.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2DhTngG5550zT9w1881m23k5YjK.jpg'),
(169029, 11985, 'Tres Espias Demais S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/524463.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e0Pc5eUZUs0M1g5HGocbniLWHgJ.jpg'),
(169030, 11985, 'Tres Espias Demais S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/524464.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/irfmaUlifjWHm0dbSxygbwlAd7y.jpg'),
(169031, 11985, 'Tres Espias Demais S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/524465.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1vlkG8yOnNsefetnjMCFWYeYeM0.jpg'),
(169032, 11985, 'Tres Espias Demais S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/524466.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8Ga6KUMvPrsoDadMZnuYMfWaQxP.jpg'),
(169033, 11985, 'Tres Espias Demais S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/524467.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kw3ZRAWM6EPGP8e7Ml0D88SfWLm.jpg'),
(169034, 11985, 'Tres Espias Demais S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/524468.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hheug7cT0QbD5mGvKd0ioRWEYju.jpg'),
(169035, 11985, 'Tres Espias Demais S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/524469.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/abcRSgS5Rel8brdpZrWJpq3yG52.jpg'),
(169036, 11985, 'Tres Espias Demais S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/524470.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xb0MOTWzqFgvF0yZwZDJjM8gTG.jpg'),
(169037, 11985, 'Tres Espias Demais S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/524471.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ty6NAUiVQKvRTNIlvVd9Yxkwvbx.jpg'),
(169038, 11985, 'Tres Espias Demais S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/524472.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1e8wilVcYTbAHqzRnmKOBAAZ7Fw.jpg'),
(169039, 11986, 'Tres Espias Demais S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524473.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vCsU0WQ5qWoVafkWCE7attgcqvi.jpg'),
(169040, 11986, 'Tres Espias Demais S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524474.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Z02rlcjiGoErns1J2pbnC3z9Y3.jpg'),
(169041, 11986, 'Tres Espias Demais S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524475.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bFXrROIjHAQqAMpMIlp3uXeViT6.jpg'),
(169042, 11986, 'Tres Espias Demais S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524476.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dSvQbLHgxDMOHV2t9f8VicvXDcc.jpg'),
(169043, 11986, 'Tres Espias Demais S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524477.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dJVFRopmpOGgzgKss8Neng2KOmB.jpg'),
(169044, 11986, 'Tres Espias Demais S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524478.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3pmp8Woaxk0CqsfaLx9T50y9hGR.jpg'),
(169045, 11986, 'Tres Espias Demais S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524479.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yvzVB71lyOkre80RQIG9l4jySai.jpg'),
(169046, 11986, 'Tres Espias Demais S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524480.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ruj2A3ET1chSa0xngl0TrjNlNmW.jpg'),
(169047, 11986, 'Tres Espias Demais S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524481.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/haJ59rMXW5Upz7ejTxQRje3hLkl.jpg'),
(169048, 11986, 'Tres Espias Demais S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524482.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yoNZGp4Xe8DYsWrX4pPOnyOilng.jpg'),
(169049, 11986, 'Tres Espias Demais S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524483.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/keEPvlLx9NfFEtOSNlOE7uLQMOx.jpg'),
(169050, 11986, 'Tres Espias Demais S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524484.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/65ZU5rCKiMyUrliOfVvd0htzdqH.jpg'),
(169051, 11986, 'Tres Espias Demais S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/524485.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qDulfnGwuIVyrfX7TQyzwIfy98A.jpg'),
(169052, 11986, 'Tres Espias Demais S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/524486.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3JgodoZNkc9gRSRhNGHlwMTrQiW.jpg'),
(169053, 11986, 'Tres Espias Demais S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/524487.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4etKlhu98FsRWENrtyAypu6a5kp.jpg'),
(169054, 11986, 'Tres Espias Demais S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/524488.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yZomqzBXKuoN23Z4gEgvCgmB5Vj.jpg'),
(169055, 11986, 'Tres Espias Demais S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/524489.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ab7OdowaSrnNj9peZdzVQUfTlOa.jpg'),
(169056, 11986, 'Tres Espias Demais S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/524490.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sbueio6rVYJyFwWRY6ysQDMWsMO.jpg'),
(169057, 11986, 'Tres Espias Demais S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/524491.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4Wt1OQW6zIDRp3Z29vC8ZVJJx4a.jpg'),
(169058, 11986, 'Tres Espias Demais S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/524492.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kWC7o7hIeu8WbjB8KwRim8o3TWT.jpg'),
(169059, 11986, 'Tres Espias Demais S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/524493.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wRAfCEQX0YeR5klGcEqogJBHr1.jpg'),
(169060, 11986, 'Tres Espias Demais S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/524494.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cGkHCVcKOVP3buKx7aa0fXb0Uwn.jpg'),
(169061, 11986, 'Tres Espias Demais S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/524495.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/za5j40fknGjG2kjo1E8OHBBXAVJ.jpg'),
(169062, 11986, 'Tres Espias Demais S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/524496.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aj6HiL3ajXTLyy3YeCBVdRXc6IW.jpg'),
(169063, 11986, 'Tres Espias Demais S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/524497.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/esr9MpnsnYFacicWK2LXhr0fcda.jpg'),
(169064, 11986, 'Tres Espias Demais S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/524498.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8mCOTirfJd5MM5cY750n7l9x57m.jpg'),
(169065, 11987, 'Tres Espias Demais S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524499.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8phHwVdPO4KR6Pg64p9UH7js0xK.jpg'),
(169066, 11987, 'Tres Espias Demais S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524500.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/47bKApeKss4W8Fub7jQ1895SRzK.jpg'),
(169067, 11987, 'Tres Espias Demais S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524501.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/momrVBeR3hf8lvHkoqGiv7QCb3h.jpg'),
(169068, 11987, 'Tres Espias Demais S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524502.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nRtdph43gevqLdmWLirgKacQ9D6.jpg'),
(169069, 11987, 'Tres Espias Demais S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524503.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uTdrE6aZ8pMXmBK034UuC2OTRvK.jpg'),
(169070, 11987, 'Tres Espias Demais S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524504.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7WTYMmgIvgPBs4E9ZIiD7zOra5s.jpg'),
(169071, 11987, 'Tres Espias Demais S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524505.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/477RgybqBs4VwEDuRtCh9s3FmTb.jpg'),
(169072, 11987, 'Tres Espias Demais S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524506.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eAt6IMQRAJrcipTxZkShevilI1M.jpg'),
(169073, 11987, 'Tres Espias Demais S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524507.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1kGOfKwsNWr4i3vxYZOoAjRvkCJ.jpg'),
(169074, 11987, 'Tres Espias Demais S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524508.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8cNqnI4WQM83N1kLwChdADXzZbQ.jpg'),
(169075, 11987, 'Tres Espias Demais S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524509.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/luFKAP6pD9h5qeTboWkL49uQtbd.jpg'),
(169076, 11987, 'Tres Espias Demais S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524510.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rdsDXBD0mzTbkkqlRxleZXWeCfq.jpg'),
(169077, 11987, 'Tres Espias Demais S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/524511.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i2HhFkWX8XbsLKlzGANUBf5tRjW.jpg'),
(169078, 11987, 'Tres Espias Demais S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/524512.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zqjPwaUH2hXsLSE95Tp3KKmh2R7.jpg'),
(169079, 11987, 'Tres Espias Demais S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/524513.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n53Pq1s4wlds92LIJQRak5DRIyO.jpg'),
(169080, 11987, 'Tres Espias Demais S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/524514.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pboOQF2PBVzzWZrNSAyYQB5yl4K.jpg'),
(169081, 11987, 'Tres Espias Demais S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/524515.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lNlRHiB73cXRNG4IePHtheMCIM4.jpg'),
(169082, 11987, 'Tres Espias Demais S04 E18', 'http://sinalprivado.info:80/series/1533784/1533784/524516.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8Oewk82gi47S2hhSRco9o2DUEjr.jpg'),
(169083, 11987, 'Tres Espias Demais S04 E19', 'http://sinalprivado.info:80/series/1533784/1533784/524517.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rDfAbZJmDTgvR84ttQJkVanPIPs.jpg'),
(169084, 11987, 'Tres Espias Demais S04 E20', 'http://sinalprivado.info:80/series/1533784/1533784/524518.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r7XYAJqS3t0hcL38ZLpDomA76Jv.jpg'),
(169085, 11987, 'Tres Espias Demais S04 E21', 'http://sinalprivado.info:80/series/1533784/1533784/524519.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p3CoEJLZbVV2cU58dBVCypAWAab.jpg'),
(169086, 11987, 'Tres Espias Demais S04 E22', 'http://sinalprivado.info:80/series/1533784/1533784/524520.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hsiGU0E4601R8FIue9HR0yXEoUy.jpg'),
(169087, 11987, 'Tres Espias Demais S04 E23', 'http://sinalprivado.info:80/series/1533784/1533784/524521.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e8GEO9sgfNwVTEyZTIz2KJp5Xbc.jpg'),
(169088, 11987, 'Tres Espias Demais S04 E24', 'http://sinalprivado.info:80/series/1533784/1533784/524522.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qWxiTq181mbPPY4wVGNUmn0YqDW.jpg'),
(169089, 11987, 'Tres Espias Demais S04 E25', 'http://sinalprivado.info:80/series/1533784/1533784/524523.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8A7zOdU6cukNjlvxtJXCbI18Nhg.jpg'),
(169090, 11987, 'Tres Espias Demais S04 E26', 'http://sinalprivado.info:80/series/1533784/1533784/524524.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bydO6Nw7NqdPwpBSTd7sUUtmco0.jpg'),
(169091, 11988, 'Tres Espias Demais S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524525.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ulZE9ExgqJXHqxBcmI7E6cm8amP.jpg'),
(169092, 11988, 'Tres Espias Demais S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524526.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/klkScRp6Y9I2PUvR0B03GQQ0UB5.jpg'),
(169093, 11988, 'Tres Espias Demais S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524527.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/59POLBUBWBwcKYdHYOSNrWXL1Mz.jpg'),
(169094, 11988, 'Tres Espias Demais S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524528.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hcJhaGaiKpOuIfXVamcjG62AHIK.jpg'),
(169095, 11988, 'Tres Espias Demais S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524529.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vfI83QUw6aMS9Rm6OzOAB7QUxLq.jpg'),
(169096, 11988, 'Tres Espias Demais S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524530.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p8uMNKg7qfVFqmUpafq4il1umA6.jpg'),
(169097, 11988, 'Tres Espias Demais S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524531.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f3fWgptgH6p6lfCDl6lJ6eYJcg1.jpg'),
(169098, 11988, 'Tres Espias Demais S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524532.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/saykc1dfpHRBdu8LCtClK5vamK0.jpg'),
(169099, 11988, 'Tres Espias Demais S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524533.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7TFcgf78Zya3MsTwVaqfH5A3dQ4.jpg'),
(169100, 11988, 'Tres Espias Demais S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524534.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iJE9TOehqdZdUuBxY9RqS9pktka.jpg'),
(169101, 11988, 'Tres Espias Demais S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524535.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xweDn6yDdPeCkIKKVRbuwMA3Svo.jpg'),
(169102, 11988, 'Tres Espias Demais S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524536.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qWjKklJk68eWoHXzC9RR3NHVGWq.jpg'),
(169103, 11988, 'Tres Espias Demais S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/524537.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A5SvDgh5WbbgNmRLx53LHCEgNak.jpg'),
(169104, 11988, 'Tres Espias Demais S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/524538.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3H4urlL62inlC54rMYKlwz2gsMo.jpg'),
(169105, 11988, 'Tres Espias Demais S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/524539.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9D0vJrEY3f0QsUbKxtKgAbrMr4x.jpg'),
(169106, 11988, 'Tres Espias Demais S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/524540.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i0zDHVyUxRgWL6d53mfduPshj35.jpg'),
(169107, 11988, 'Tres Espias Demais S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/524541.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hDxWrPUxolIuzsnW2EtH8wVkPLn.jpg'),
(169108, 11988, 'Tres Espias Demais S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/524542.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6v1vqo4nSxstGktWfSx2Gz6YIv8.jpg'),
(169109, 11988, 'Tres Espias Demais S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/524543.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/53Xr9MejP3FrhIwntmUhP8CJHSi.jpg'),
(169110, 11988, 'Tres Espias Demais S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/524544.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x8rufguC9G6ietEdaT356jvI4IY.jpg'),
(169111, 11988, 'Tres Espias Demais S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/524545.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h3v4xXYUWhQyMP3xAQZVjSSiBYV.jpg'),
(169112, 11988, 'Tres Espias Demais S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/524546.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u02JAi6ansrIqIf1MG4U1llzXaA.jpg'),
(169113, 11988, 'Tres Espias Demais S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/524547.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y0ky7QmYpVzR5PyTiHtZ2w6DHHa.jpg'),
(169114, 11988, 'Tres Espias Demais S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/524548.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ztypL3q5bcLznUl6VV1FRbrHWI5.jpg'),
(169115, 11988, 'Tres Espias Demais S05 E25', 'http://sinalprivado.info:80/series/1533784/1533784/524549.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yJLXDzmxpTRwsapfcEl1xH2cYgR.jpg'),
(169116, 11988, 'Tres Espias Demais S05 E26', 'http://sinalprivado.info:80/series/1533784/1533784/524550.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Afsr9EKjOx2ibRbuflAHA1tyDYs.jpg'),
(169117, 11989, 'Tres Espias Demais S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524551.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xuncYAUnB9fs6tjUw3hPqtYW06F.jpg'),
(169118, 11989, 'Tres Espias Demais S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524552.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ud2ACpB5WNasa3oDsEIfNtAO4fM.jpg'),
(169119, 11989, 'Tres Espias Demais S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524553.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z5JzgOOcykEZcsUWqXzNU561Fef.jpg'),
(169120, 11989, 'Tres Espias Demais S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524554.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u0ns9ee98iFIN5wOe1tGnnAtKOt.jpg'),
(169121, 11989, 'Tres Espias Demais S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524555.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z08JO2JXliqeA4P8bSoyvDQDZt1.jpg'),
(169122, 11989, 'Tres Espias Demais S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524556.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mA9VsASAZnjPOmlWox4KlB3875w.jpg'),
(169123, 11989, 'Tres Espias Demais S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524557.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b9vvXqDLYY8yPPb7er9FrPDfofL.jpg'),
(169124, 11989, 'Tres Espias Demais S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524558.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xHtq38N4kyKIj1fDGVyXAhlo9ZH.jpg'),
(169125, 11989, 'Tres Espias Demais S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524559.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mMv7JnqLoIy6PZRTdbrCSTYSXjG.jpg'),
(169126, 11989, 'Tres Espias Demais S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524560.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gvKxZmuAxWJ0wegSqPsPJzUVpVO.jpg'),
(169127, 11989, 'Tres Espias Demais S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524561.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/elWv7MexspQtlOK8Cs2q50JDc77.jpg'),
(169128, 11989, 'Tres Espias Demais S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524562.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4pC17YR73hTBDv6JNv3PbhIowqi.jpg'),
(169129, 11989, 'Tres Espias Demais S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/524563.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lWOocPRTsoe06sAkDeuEPlz80ZV.jpg'),
(169130, 11989, 'Tres Espias Demais S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/524564.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mUlY3ZLgJ1TJovhWwl3HpQKJwtT.jpg'),
(169131, 11989, 'Tres Espias Demais S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/524565.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6gvtW7wIxKQkOzneXKMC4nnMnzu.jpg'),
(169132, 11989, 'Tres Espias Demais S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/524566.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1RL7Vn9bq70p8uazB2Bun1YWazX.jpg'),
(169133, 11989, 'Tres Espias Demais S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/524567.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/egV4llAOSoc58dpLt4hFJ2RkCaf.jpg'),
(169134, 11989, 'Tres Espias Demais S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/524568.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eGsFcxkRM22gkGqXMSAEjlz86RG.jpg'),
(169135, 11989, 'Tres Espias Demais S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/524569.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n8Lgh6lbIYuv2xyOX7ruTVicqpy.jpg'),
(169136, 11989, 'Tres Espias Demais S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/524570.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8XbTC82TVMGVrTvqBLWdVCwx4Dx.jpg'),
(169137, 11989, 'Tres Espias Demais S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/524571.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yBB7U8jK5g7DvV5ZvXCsudIl1X1.jpg'),
(169138, 11989, 'Tres Espias Demais S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/524572.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6ZVQyppFOu5WpT5xi8TYbuknuID.jpg'),
(169139, 11989, 'Tres Espias Demais S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/524573.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/43xgnPnbwk083A0i7pLrC1BblKQ.jpg'),
(169140, 11989, 'Tres Espias Demais S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/524574.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pOrxxGrOQXrVIo96QoOaXIFuh91.jpg'),
(169141, 11989, 'Tres Espias Demais S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/524575.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9sCE5yGLFt61AgF3rSZB5ViM8jJ.jpg'),
(169142, 11989, 'Tres Espias Demais S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/524576.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a6c8uQADyKDViDgjmd2SIjTmvQX.jpg'),
(169143, 11990, 'Tres Espias Demais S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524577.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jIzfhmRyFsXrli3cjox0OWKfg7x.jpg'),
(169144, 11990, 'Tres Espias Demais S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524578.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4K9wDyVoyPfHZlBy6gPx6oghaYy.jpg'),
(169145, 11990, 'Tres Espias Demais S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524579.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xuPrVGQKdeQRVP6HKNypyXtwkpy.jpg'),
(169146, 11990, 'Tres Espias Demais S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524580.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ien9vNkVNWQK5fu2MsgkgMTAD9U.jpg'),
(169147, 11990, 'Tres Espias Demais S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524581.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vnu2E5JtuAHNyL6TVoNTG6zKEJC.jpg'),
(169148, 11990, 'Tres Espias Demais S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524582.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yfH5oIQLqdmiB2ClDIhUEULLBsE.jpg'),
(169149, 11990, 'Tres Espias Demais S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524583.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bVRJgUPfisHQaMa7ZQAhxfEDipw.jpg'),
(169150, 11990, 'Tres Espias Demais S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524584.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mrxFbrgJe44kf4vV1JT2RTnnpqT.jpg'),
(169151, 11990, 'Tres Espias Demais S07 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524585.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7mky7T8V49Xy74EuI2UBuLpPcRt.jpg'),
(169152, 11990, 'Tres Espias Demais S07 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524586.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cf45WMGW3RtaVq21c1LsWFkDIhr.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(169153, 11990, 'Tres Espias Demais S07 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524587.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fPQlajKJU4RMtbBEBkrSwsXlA7c.jpg'),
(169154, 11990, 'Tres Espias Demais S07 E12', 'http://sinalprivado.info:80/series/1533784/1533784/524588.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7oiPa44nZ7qKLypoirHQ0UfrtKq.jpg'),
(169155, 11990, 'Tres Espias Demais S07 E13', 'http://sinalprivado.info:80/series/1533784/1533784/524589.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fJL5tCBCEDH8fILdSCeM7fDyIrh.jpg'),
(169156, 11990, 'Tres Espias Demais S07 E14', 'http://sinalprivado.info:80/series/1533784/1533784/524590.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a2HEPkpLsl9GQNO5OxrB9T5DrRw.jpg'),
(169157, 11990, 'Tres Espias Demais S07 E15', 'http://sinalprivado.info:80/series/1533784/1533784/524591.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3SxGHClFKF0kx0TIx8Ze7KgO8a0.jpg'),
(169158, 11990, 'Tres Espias Demais S07 E16', 'http://sinalprivado.info:80/series/1533784/1533784/524592.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s4ZPURPzItrTUE5mqg9Z9rFVkqA.jpg'),
(169159, 11990, 'Tres Espias Demais S07 E17', 'http://sinalprivado.info:80/series/1533784/1533784/524593.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/82oYymbxAlKmnz1xy7Ho1rdD8ob.jpg'),
(169160, 11990, 'Tres Espias Demais S07 E18', 'http://sinalprivado.info:80/series/1533784/1533784/733979.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5z5NiXdx7z30ZLzthaEyjY6asvF.jpg'),
(169161, 11990, 'Tres Espias Demais S07 E19', 'http://sinalprivado.info:80/series/1533784/1533784/733980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5z5NiXdx7z30ZLzthaEyjY6asvF.jpg'),
(169162, 11990, 'Tres Espias Demais S07 E20', 'http://sinalprivado.info:80/series/1533784/1533784/733981.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5z5NiXdx7z30ZLzthaEyjY6asvF.jpg'),
(169163, 11990, 'Tres Espias Demais S07 E21', 'http://sinalprivado.info:80/series/1533784/1533784/733982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5z5NiXdx7z30ZLzthaEyjY6asvF.jpg'),
(169164, 11990, 'Tres Espias Demais S07 E22', 'http://sinalprivado.info:80/series/1533784/1533784/733983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5z5NiXdx7z30ZLzthaEyjY6asvF.jpg'),
(169165, 11990, 'Tres Espias Demais S07 E23', 'http://sinalprivado.info:80/series/1533784/1533784/733984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5z5NiXdx7z30ZLzthaEyjY6asvF.jpg'),
(169166, 11990, 'Tres Espias Demais S07 E24', 'http://sinalprivado.info:80/series/1533784/1533784/733985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5z5NiXdx7z30ZLzthaEyjY6asvF.jpg'),
(169167, 11990, 'Tres Espias Demais S07 E25', 'http://sinalprivado.info:80/series/1533784/1533784/733986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5z5NiXdx7z30ZLzthaEyjY6asvF.jpg'),
(169168, 11990, 'Tres Espias Demais S07 E26', 'http://sinalprivado.info:80/series/1533784/1533784/733987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5z5NiXdx7z30ZLzthaEyjY6asvF.jpg'),
(169169, 11991, 'A Melhor Pior Funcionaria [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524413.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fBASryuDk9WA1IXsUeg9cF6L9mh.jpg'),
(169170, 11991, 'A Melhor Pior Funcionaria [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524414.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eLkddAe0bh4tTmJnQmRTCBy0cxe.jpg'),
(169171, 11991, 'A Melhor Pior Funcionaria [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524415.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tp5AJcCZY4RqJghdmLTmFvuWMRl.jpg'),
(169172, 11991, 'A Melhor Pior Funcionaria [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524416.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gjCz2D6i6NFM1SxyZeJKXq80Z6b.jpg'),
(169173, 11991, 'A Melhor Pior Funcionaria [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524417.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2n8ZX0feEZkq0UEDOD7ym2YQJM6.jpg'),
(169174, 11991, 'A Melhor Pior Funcionaria [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524418.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cVCE3tUQrLFULfug2aEAW6Nq3KC.jpg'),
(169175, 11991, 'A Melhor Pior Funcionaria [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524419.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iqad7WJ8LRZFIQnoYahEgp8D6IZ.jpg'),
(169176, 11991, 'A Melhor Pior Funcionaria [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524420.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ajqv11fMurURrEzxqBruilCuYG3.jpg'),
(169177, 11992, 'A Terra Permanece [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524410.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/msPG2NdWAEfs37mlfz7NlNKPQdA.jpg'),
(169178, 11992, 'A Terra Permanece [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524411.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/77APttVyVFQoFpaKcQyD7wJemad.jpg'),
(169179, 11992, 'A Terra Permanece [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524412.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i0RljVgbOVvuFvIeAXMOjKu1AR4.jpg'),
(169180, 11993, 'Anjo da Morte [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524389.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lj6YApmvPEsnyvIq0XK1bnCSNbf.jpg'),
(169181, 11993, 'Anjo da Morte [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524390.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2AxaSTr5F06B73W00DqdWLmeyBx.jpg'),
(169182, 11993, 'Anjo da Morte [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524391.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wzbGiGQEsGDfGNIg3xkVlJPeLEI.jpg'),
(169183, 11993, 'Anjo da Morte [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524392.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h6X2UzQALvZV9w104bsemfX5XPd.jpg'),
(169184, 11993, 'Anjo da Morte [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524393.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tVPGCKgFKEqfopdnRIQveUeY5Dr.jpg'),
(169185, 11993, 'Anjo da Morte [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524394.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mxg7lNDJCaw21fWkAFaVfk1dRvf.jpg'),
(169186, 11993, 'Anjo da Morte [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524395.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sRLUHB9hyCP3KoPGvBTBAaV1Lr5.jpg'),
(169187, 11994, 'Anjo da Morte [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524396.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ho5tPKqDvWGy41W5zY2JXqXyC2j.jpg'),
(169188, 11994, 'Anjo da Morte [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524397.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6Ik2BYVwF8W6iSWxGsfbU4CTspI.jpg'),
(169189, 11994, 'Anjo da Morte [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524398.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ddYA9yXra8Hr3RRFD3IenyjTYYP.jpg'),
(169190, 11994, 'Anjo da Morte [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524399.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xQ2I9LIDFhxEfH946ycG42GbLqu.jpg'),
(169191, 11994, 'Anjo da Morte [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524400.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fb4yh2YkfNAYH2lHWSQleGTzG2S.jpg'),
(169192, 11994, 'Anjo da Morte [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524401.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yXhlVazYj5IUmhCeqXbs7pKb9j6.jpg'),
(169193, 11994, 'Anjo da Morte [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524402.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dap04numEcOH6AfC8SRZluOf2jB.jpg'),
(169194, 11995, 'Anjo da Morte [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524403.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mCNvA2YuoAut13GMzjJhiXvr0b9.jpg'),
(169195, 11995, 'Anjo da Morte [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524404.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dO2UCARufYQeOtYOIouVjRMNHjI.jpg'),
(169196, 11995, 'Anjo da Morte [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524405.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bBrFIZbTKozCshlg9cs1gEjFhxQ.jpg'),
(169197, 11995, 'Anjo da Morte [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524406.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6Og6YGneeftLh6MwOjA78bhnZdl.jpg'),
(169198, 11995, 'Anjo da Morte [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524407.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6LBXdFl5i0GXJ4MOaStEfAgklYa.jpg'),
(169199, 11995, 'Anjo da Morte [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524408.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oTzdNryruaU6rcNhyQwDRbAlRxz.jpg'),
(169200, 11995, 'Anjo da Morte [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524409.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jW7wZMxjIg8TjF1bh4leBI3aMAh.jpg'),
(169201, 11996, 'Casar com VOCE [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524383.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/10BdvyrkPRItabVdHzwuXZS6RvQ.jpg'),
(169202, 11996, 'Casar com VOCE [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524384.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x66pnsQvsNBjDe8ET5gW8bjf5vB.jpg'),
(169203, 11996, 'Casar com VOCE [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524385.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jeTaQvXwLUyt4uAWqgcEgm8M2rj.jpg'),
(169204, 11996, 'Casar com VOCE [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524386.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h8QevI7K4bSGIMzHJ28Rp8S4Nu5.jpg'),
(169205, 11996, 'Casar com VOCE [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524387.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lIz7Ujx0Ubm9nbayIGM6JH96s9A.jpg'),
(169206, 11996, 'Casar com VOCE [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524388.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zFkeiitmcx9a8wEZKZf1moXVHvk.jpg'),
(169207, 11996, 'Casar com VOCE [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/641095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x2nQQPyZPhY2zC4XxWZMtELapn1.jpg'),
(169208, 11996, 'Casar com VOCE [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/641096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x2nQQPyZPhY2zC4XxWZMtELapn1.jpg'),
(169209, 11996, 'Casar com VOCE [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/641097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x2nQQPyZPhY2zC4XxWZMtELapn1.jpg'),
(169210, 11996, 'Casar com VOCE [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/641098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x2nQQPyZPhY2zC4XxWZMtELapn1.jpg'),
(169211, 11997, 'Fermentando o Amor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524372.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xsCa4Mfy4vAhQr05E1ZE8mtYtt2.jpg'),
(169212, 11997, 'Fermentando o Amor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524373.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5CNpSeCkSOtuqUSyFdAXADbcGUs.jpg'),
(169213, 11997, 'Fermentando o Amor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524374.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x151X4NHh1y4SeUP2Q6QWOYJYFf.jpg'),
(169214, 11997, 'Fermentando o Amor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524375.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cetAioxyFNB2pQYc6fe773JtNfF.jpg'),
(169215, 11997, 'Fermentando o Amor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524376.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lZZmGNRKNf19AaMdwQebTXXBLR7.jpg'),
(169216, 11997, 'Fermentando o Amor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524377.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w6X8oIJoVElUnpuRYJQplG5W9WG.jpg'),
(169217, 11997, 'Fermentando o Amor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524378.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/86HiLaDY1P8cqfzfdIWu9vSGSLP.jpg'),
(169218, 11997, 'Fermentando o Amor [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524379.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vPjWHwXjixbuq4YQwcV0BGZRDTc.jpg'),
(169219, 11997, 'Fermentando o Amor [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524380.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8Q5pAMcGW41m3aY3syk4dKK0LS1.jpg'),
(169220, 11997, 'Fermentando o Amor [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524381.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/WDjQa0PGl66g59RnnY99WEIrAw.jpg'),
(169221, 11997, 'Fermentando o Amor [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524382.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tWvYJPPXEr863KvgZLiIN7ZKEya.jpg'),
(169222, 11998, 'Obituary [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524369.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9fdJuQ6ty6QmEVnZGJyVzHa7Sob.jpg'),
(169223, 11998, 'Obituary [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524370.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zB0HzD7jP4nqwiFvfWfvDQscIZh.jpg'),
(169224, 11998, 'Obituary [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524371.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cRrswq7NueMIn77LGYjGcX5Hlqi.jpg'),
(169225, 11998, 'Obituary [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/640767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1cgisNvMeBDEf1nOoDNa7CEGwLR.jpg'),
(169226, 11998, 'Obituary [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/640768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1cgisNvMeBDEf1nOoDNa7CEGwLR.jpg'),
(169227, 11998, 'Obituary [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/658832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1cgisNvMeBDEf1nOoDNa7CEGwLR.jpg'),
(169228, 11999, 'Poppas House [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524362.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQnhk8bOFHlFI7KZ12NT24yW8iw.jpg'),
(169229, 11999, 'Poppas House [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524363.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQnhk8bOFHlFI7KZ12NT24yW8iw.jpg'),
(169230, 11999, 'Poppas House [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524364.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQnhk8bOFHlFI7KZ12NT24yW8iw.jpg'),
(169231, 11999, 'Poppas House [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524365.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQnhk8bOFHlFI7KZ12NT24yW8iw.jpg'),
(169232, 11999, 'Poppas House [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524366.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQnhk8bOFHlFI7KZ12NT24yW8iw.jpg'),
(169233, 11999, 'Poppas House [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524367.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQnhk8bOFHlFI7KZ12NT24yW8iw.jpg'),
(169234, 11999, 'Poppas House [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524368.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQnhk8bOFHlFI7KZ12NT24yW8iw.jpg'),
(169235, 11999, 'Poppas House [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/639980.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQnhk8bOFHlFI7KZ12NT24yW8iw.jpg'),
(169236, 11999, 'Poppas House [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/687174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQnhk8bOFHlFI7KZ12NT24yW8iw.jpg'),
(169237, 11999, 'Poppas House [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/697560.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQnhk8bOFHlFI7KZ12NT24yW8iw.jpg'),
(169238, 11999, 'Poppas House [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/717575.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQnhk8bOFHlFI7KZ12NT24yW8iw.jpg'),
(169239, 11999, 'Poppas House [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/720992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hQnhk8bOFHlFI7KZ12NT24yW8iw.jpg'),
(169240, 12000, 'Yakuza Fiance Raise wa Tanin ga Ii [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/524351.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dcZjtc7xVJqsk1cFmo84GOihYuu.jpg'),
(169241, 12000, 'Yakuza Fiance Raise wa Tanin ga Ii [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/524352.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fG777fgvptkaL4Hkn1ohnHuEZ3s.jpg'),
(169242, 12000, 'Yakuza Fiance Raise wa Tanin ga Ii [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/524353.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8MozN3fFudQMUDCA6RmfJ8cQtgM.jpg'),
(169243, 12000, 'Yakuza Fiance Raise wa Tanin ga Ii [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/524354.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tSeHiyTwFS5BbA17UqIeq95UeFZ.jpg'),
(169244, 12000, 'Yakuza Fiance Raise wa Tanin ga Ii [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/524355.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oppGTjER2LawziahjgGLz62XlFO.jpg'),
(169245, 12000, 'Yakuza Fiance Raise wa Tanin ga Ii [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/524356.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e8Zkk8drFEwb4nKzWERXuNrpZxH.jpg'),
(169246, 12000, 'Yakuza Fiance Raise wa Tanin ga Ii [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/524357.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/neoaitcrPNiRrIuZCT9YqXlWp5I.jpg'),
(169247, 12000, 'Yakuza Fiance Raise wa Tanin ga Ii [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/524358.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uPOKw54BcOKdLjqIrnE0dmSHFFb.jpg'),
(169248, 12000, 'Yakuza Fiance Raise wa Tanin ga Ii [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/524359.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ickI6hWZBJntT3c0xr4iJ5s8MfP.jpg'),
(169249, 12000, 'Yakuza Fiance Raise wa Tanin ga Ii [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/524360.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ptFPhaSDv3hm9hxLOSVVsBUkDTU.jpg'),
(169250, 12000, 'Yakuza Fiance Raise wa Tanin ga Ii [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/524361.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zemM6S5wREkISFN764MftdRYhiH.jpg'),
(169251, 12000, 'Yakuza Fiance Raise wa Tanin ga Ii [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/667109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9xztd5hoq0OstNRru024aAxSNWd.jpg'),
(169252, 12001, 'A Vida Secreta dos Animais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637587.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mEVfXprMtbaSfzgJArHWHlI2juK.jpg'),
(169253, 12001, 'A Vida Secreta dos Animais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/637588.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qpND72IjJUpUhBcN2txcp1QHTjI.jpg'),
(169254, 12001, 'A Vida Secreta dos Animais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637589.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q3gLROjscTTtCMMDzFeQJQOzKs7.jpg'),
(169255, 12001, 'A Vida Secreta dos Animais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637590.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c3A7ELhxE0AjJjoknFvqZJAUF4S.jpg'),
(169256, 12001, 'A Vida Secreta dos Animais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/637591.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uGvhHSW9DFUeQnpQJo69hS790iN.jpg'),
(169257, 12001, 'A Vida Secreta dos Animais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/637592.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p2bWQh8z0EMaDRh232NBcpTrVrJ.jpg'),
(169258, 12001, 'A Vida Secreta dos Animais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637593.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tFSs6C3gv3GAlttXSNTrSKQGd2d.jpg'),
(169259, 12001, 'A Vida Secreta dos Animais S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637594.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mPkOXfAupVEN8DK9Lvm66WMag8Z.jpg'),
(169260, 12001, 'A Vida Secreta dos Animais S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/637595.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tsade11osvKT1ehzrhuAqJAZXJu.jpg'),
(169261, 12001, 'A Vida Secreta dos Animais S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/637596.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yfjeGVw8QRfAeg8kArdyRs0LlAd.jpg'),
(169262, 12002, 'Sorry Not Sorry [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hBA52mKuUfo7BaQl8Qrm8Iq8T6v.jpg'),
(169263, 12002, 'Sorry Not Sorry [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/637586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hBA52mKuUfo7BaQl8Qrm8Iq8T6v.jpg'),
(169264, 12002, 'Sorry Not Sorry [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/667353.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hBA52mKuUfo7BaQl8Qrm8Iq8T6v.jpg'),
(169265, 12002, 'Sorry Not Sorry [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/667354.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hBA52mKuUfo7BaQl8Qrm8Iq8T6v.jpg'),
(169266, 12002, 'Sorry Not Sorry [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/667355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hBA52mKuUfo7BaQl8Qrm8Iq8T6v.jpg'),
(169267, 12002, 'Sorry Not Sorry [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/716858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hBA52mKuUfo7BaQl8Qrm8Iq8T6v.jpg'),
(169268, 12002, 'Sorry Not Sorry [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/716859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hBA52mKuUfo7BaQl8Qrm8Iq8T6v.jpg'),
(169269, 12002, 'Sorry Not Sorry [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/716860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hBA52mKuUfo7BaQl8Qrm8Iq8T6v.jpg'),
(169270, 12002, 'Sorry Not Sorry [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/716861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hBA52mKuUfo7BaQl8Qrm8Iq8T6v.jpg'),
(169271, 12002, 'Sorry Not Sorry [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/716862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hBA52mKuUfo7BaQl8Qrm8Iq8T6v.jpg'),
(169272, 12002, 'Sorry Not Sorry [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/716863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hBA52mKuUfo7BaQl8Qrm8Iq8T6v.jpg'),
(169273, 12002, 'Sorry Not Sorry [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/716864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hBA52mKuUfo7BaQl8Qrm8Iq8T6v.jpg'),
(169274, 12003, 'Akudama Drive S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/635861.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6REAocUKM1zk3BnIblKyEFp5l7M.jpg'),
(169275, 12003, 'Akudama Drive S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/635862.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yZ0nodskc5olcxTzU2PaRyC9AyL.jpg'),
(169276, 12003, 'Akudama Drive S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/635863.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iV9vx7Tr9NcFZdV6itaqVA5YcbC.jpg'),
(169277, 12003, 'Akudama Drive S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/635864.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aEcwtt2sevzH4eHBv60DN5DuFrc.jpg'),
(169278, 12003, 'Akudama Drive S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/635865.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iBJwnHvNsL1gOpcK36sZ1RdZ77q.jpg'),
(169279, 12003, 'Akudama Drive S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/635866.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1MGDb8TlZRdMjJxMjlyHG2GUtVx.jpg'),
(169280, 12003, 'Akudama Drive S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/635867.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wS4DiHAMa5LbErD9uQHkvGsxzwa.jpg'),
(169281, 12003, 'Akudama Drive S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/635868.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3u8VxaQ8FyTasqLvizkLh8NcCEo.jpg'),
(169282, 12003, 'Akudama Drive S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/635869.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zj1WniDvLhlNyFM0lncrL5ipOFC.jpg'),
(169283, 12003, 'Akudama Drive S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/635870.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fGuYByAnyoQrJPbzb28qhidiUvO.jpg'),
(169284, 12003, 'Akudama Drive S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/635871.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/baURnstoJbyn5EFBx95QeZxhMO.jpg'),
(169285, 12003, 'Akudama Drive S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/635872.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/roqdBIqGxvbXqEdNoKmQ5AqOPzw.jpg'),
(169286, 12004, 'Assassination Classroom S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/635814.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yyfmxAialvEXve36GmyEX8L4h7F.jpg'),
(169287, 12004, 'Assassination Classroom S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/635815.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hsAD2kMfHWSMLjZwjlsbtl1g2YA.jpg'),
(169288, 12004, 'Assassination Classroom S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/635816.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2QjjvI7543ohcpFaPInws32LDub.jpg'),
(169289, 12004, 'Assassination Classroom S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/635817.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cjw0gwNlaChltGCPTVr9M1FtYOx.jpg'),
(169290, 12004, 'Assassination Classroom S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/635818.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/58m7wAOe7kNaltpU1qWLfbgADPF.jpg'),
(169291, 12004, 'Assassination Classroom S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/635819.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4Xb0rWnHzA6M2ep7EbZp3bOE9TN.jpg'),
(169292, 12004, 'Assassination Classroom S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/635820.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vBNcy4o7CBYwcKphJhHJ7ACG8mt.jpg'),
(169293, 12004, 'Assassination Classroom S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/635821.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8pRYftU5QXxa5NUqPLxZRPh8GWE.jpg'),
(169294, 12004, 'Assassination Classroom S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/635822.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bIu7zmFe5UF71dqoDY1EUWM8aGx.jpg'),
(169295, 12004, 'Assassination Classroom S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/635823.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/drBHbHXWcE2fc54JqUEtFXInVBg.jpg'),
(169296, 12004, 'Assassination Classroom S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/635824.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vv8xKdRahhbgeAUuTbofGDTmwNC.jpg'),
(169297, 12004, 'Assassination Classroom S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/635825.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xR9unZ9HuhczlcgDTSG6ex4G9xL.jpg'),
(169298, 12004, 'Assassination Classroom S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/635826.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d2f4685BTxxxvrpJnidX7BMiFQU.jpg'),
(169299, 12004, 'Assassination Classroom S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/635827.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cyIBKcwzrHPTT1PZa8V41Krh3f.jpg'),
(169300, 12004, 'Assassination Classroom S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/635828.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rK4MdiKSxiXt9dK0Jr4MVzRye4O.jpg'),
(169301, 12004, 'Assassination Classroom S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/635829.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3i4pExGkKdjok94UQNbanDsyzHd.jpg'),
(169302, 12004, 'Assassination Classroom S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/635830.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zYMdCixdKzQaFN2rLAqsYBLpgdQ.jpg'),
(169303, 12004, 'Assassination Classroom S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/635831.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5ZzTT1dJ9VpXaQIUXZVOEwtFJG2.jpg'),
(169304, 12004, 'Assassination Classroom S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/635832.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x2axJqE9pjc170BkkGC5Fx8TPK4.jpg'),
(169305, 12004, 'Assassination Classroom S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/635833.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fDCYhCEaRGpFjWm9kdO4DFxIiab.jpg'),
(169306, 12004, 'Assassination Classroom S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/635834.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2DuXVfQBl3Wy8Sl6IAs1WuY8lIG.jpg'),
(169307, 12004, 'Assassination Classroom S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/635835.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wfwoOGNlAdfiavBYCyh7ag3E2ir.jpg'),
(169308, 12005, 'Assassination Classroom S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/635836.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vmoNbsKWqnzihOPbVdT64f6u5Qk.jpg'),
(169309, 12005, 'Assassination Classroom S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/635837.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dMzDeHcgyqPCJSZ3OGY7tfcTgcZ.jpg'),
(169310, 12005, 'Assassination Classroom S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/635838.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zH9l1Gzkt1WuyBEmjFHX2CUmM9D.jpg'),
(169311, 12005, 'Assassination Classroom S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/635839.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iqaQeWqXeifS0z2jMW1KVABbdZh.jpg'),
(169312, 12005, 'Assassination Classroom S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/635840.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oM6A4WrGaxFttinI2M3pWNVnQ21.jpg'),
(169313, 12005, 'Assassination Classroom S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/635841.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p6ea7peGuC03JSaR7EiOyITjfpi.jpg'),
(169314, 12005, 'Assassination Classroom S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/635842.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4Sv8druY1xLEy41hXZG5MwfROca.jpg'),
(169315, 12005, 'Assassination Classroom S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/635843.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i8Nlb0eLPPVFKQbAqoYeUY1ZjsV.jpg'),
(169316, 12005, 'Assassination Classroom S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/635844.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aqGUJ9Uhdcuogw2owRb2zxykAXS.jpg'),
(169317, 12005, 'Assassination Classroom S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/635845.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/igD4qgaCPTsltKxMTx7CwTlNI0U.jpg'),
(169318, 12005, 'Assassination Classroom S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/635846.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/muH51Q5WIEQOeyMJAcUJZIkHD1E.jpg'),
(169319, 12005, 'Assassination Classroom S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/635847.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p2lTYvfukuLVyMOJU4WbntnrWQz.jpg'),
(169320, 12005, 'Assassination Classroom S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/635848.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fr3ya4vXiy5BaGbjh2UQtFk88vs.jpg'),
(169321, 12005, 'Assassination Classroom S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/635854.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j87xQhK6SACWvsQ9hDnNKmPSjWv.jpg'),
(169322, 12005, 'Assassination Classroom S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/635855.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hecv2s6DQaJn3ABKkea0QRzgGeJ.jpg'),
(169323, 12005, 'Assassination Classroom S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/635856.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pMPmtgtLJL95KuaSyCkOQelTzcd.jpg'),
(169324, 12005, 'Assassination Classroom S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/635857.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/61WG2kl16UNDuS7zMxYI8OOkbEq.jpg'),
(169325, 12005, 'Assassination Classroom S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/635858.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k0jFjW2i9VLRNPhTeIz27rJSNCO.jpg'),
(169326, 12005, 'Assassination Classroom S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/635859.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bjmqJZlCLTo4UJKcTyoPpXqYvMa.jpg'),
(169327, 12005, 'Assassination Classroom S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/635860.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kiLifALGs9Srw7dWMTLNEo7jEFA.jpg'),
(169328, 12006, 'Rezero Starting Life in Another World S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/635755.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4t07rKWcAEjV08nHRUXFnkP7PER.jpg'),
(169329, 12006, 'Rezero Starting Life in Another World S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/635756.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4ylSynAX5K8Wz5GvmxPGSJHQhQR.jpg'),
(169330, 12006, 'Rezero Starting Life in Another World S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/635757.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/niDOnDau8oTa9PpXPJOdIbhBRoI.jpg'),
(169331, 12006, 'Rezero Starting Life in Another World S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/635758.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/727cwDQrkzpx2XoFTBsTSRMAEnr.jpg'),
(169332, 12006, 'Rezero Starting Life in Another World S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/635759.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yX9GgwxRHFPZUbsUXYKcxEHsnr0.jpg'),
(169333, 12006, 'Rezero Starting Life in Another World S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/635760.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cELlH8Oda3U5JYd1vsa3oRAOCTr.jpg'),
(169334, 12006, 'Rezero Starting Life in Another World S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/635761.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fb2ZSWUnc4JiRWqVJLjRTjYz4z2.jpg'),
(169335, 12006, 'Rezero Starting Life in Another World S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/635762.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yPbigieNZ5BYXpuiPuelIWvIr54.jpg'),
(169336, 12006, 'Rezero Starting Life in Another World S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/635763.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pn8E0BWhsdMfvftHqAyI89FQ7Le.jpg'),
(169337, 12006, 'Rezero Starting Life in Another World S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/635764.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/axHoU0FGDmeFBM3YyZwVW0Lpnjg.jpg'),
(169338, 12006, 'Rezero Starting Life in Another World S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/635765.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b68FUUavbuz1biWRizhfdTUNTaK.jpg'),
(169339, 12006, 'Rezero Starting Life in Another World S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/635766.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hWfNLTRet0fr72vRAtAkWWW77Z8.jpg'),
(169340, 12006, 'Rezero Starting Life in Another World S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/635767.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9pCau2MNoKdtoAEyjt4H5XgdkMG.jpg'),
(169341, 12006, 'Rezero Starting Life in Another World S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/635768.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uvZBiKv0TnmKv5DsC9zoYSDcB1G.jpg'),
(169342, 12006, 'Rezero Starting Life in Another World S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/635769.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/80T61OnEm3ZrCeuZwyVyypIpIBg.jpg'),
(169343, 12006, 'Rezero Starting Life in Another World S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/635770.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jcDPfVhJcOISIhQcvXBSOFiOynP.jpg'),
(169344, 12006, 'Rezero Starting Life in Another World S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/635771.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ud112QQ0PLvdYhnuSYwy9RL8hWH.jpg'),
(169345, 12006, 'Rezero Starting Life in Another World S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/635772.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/glOKMiNcuMpme1HAAJTIatWps6d.jpg'),
(169346, 12006, 'Rezero Starting Life in Another World S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/635773.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hzTmqZEshNVIFkQfa9DQpevGfJI.jpg'),
(169347, 12006, 'Rezero Starting Life in Another World S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/635774.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3fHfgh8vHxo4DACVbF0P33WYewC.jpg'),
(169348, 12006, 'Rezero Starting Life in Another World S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/635775.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xuqXqkfurMAcEGzlm3oKfk9fiGD.jpg'),
(169349, 12006, 'Rezero Starting Life in Another World S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/635776.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cQPU3GoOEoxGBgknNSEjoqpEzFm.jpg'),
(169350, 12006, 'Rezero Starting Life in Another World S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/635777.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s7ZZ812Fgsk7nk0bhony8nATPxB.jpg'),
(169351, 12006, 'Rezero Starting Life in Another World S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/635778.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2MxuHIzxxZ0jLk0CcBqRJhY8LZD.jpg'),
(169352, 12006, 'Rezero Starting Life in Another World S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/635779.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8WPUoiykJJEmXS7Skz9bZeJRw2m.jpg'),
(169353, 12006, 'Rezero Starting Life in Another World S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/635780.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hwXba8aHTZvXnoSB7XTs6b121h6.jpg'),
(169354, 12007, 'Rezero Starting Life in Another World S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/635781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169355, 12007, 'Rezero Starting Life in Another World S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/635782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169356, 12007, 'Rezero Starting Life in Another World S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/635783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169357, 12007, 'Rezero Starting Life in Another World S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/635784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169358, 12007, 'Rezero Starting Life in Another World S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/635785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169359, 12007, 'Rezero Starting Life in Another World S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/635786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169360, 12007, 'Rezero Starting Life in Another World S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/635787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169361, 12007, 'Rezero Starting Life in Another World S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/635788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169362, 12007, 'Rezero Starting Life in Another World S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/635789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169363, 12007, 'Rezero Starting Life in Another World S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/635790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169364, 12007, 'Rezero Starting Life in Another World S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/635791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169365, 12007, 'Rezero Starting Life in Another World S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/635792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169366, 12007, 'Rezero Starting Life in Another World S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/635793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169367, 12007, 'Rezero Starting Life in Another World S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/635794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169368, 12007, 'Rezero Starting Life in Another World S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/635795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169369, 12007, 'Rezero Starting Life in Another World S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/635796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169370, 12007, 'Rezero Starting Life in Another World S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/635797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169371, 12007, 'Rezero Starting Life in Another World S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/635798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169372, 12007, 'Rezero Starting Life in Another World S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/635799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169373, 12007, 'Rezero Starting Life in Another World S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/635800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169374, 12007, 'Rezero Starting Life in Another World S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/635801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169375, 12007, 'Rezero Starting Life in Another World S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/635802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169376, 12007, 'Rezero Starting Life in Another World S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/635803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169377, 12007, 'Rezero Starting Life in Another World S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/635804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169378, 12007, 'Rezero Starting Life in Another World S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/635805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169379, 12008, 'Rezero Starting Life in Another World S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/635806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169380, 12008, 'Rezero Starting Life in Another World S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/635807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169381, 12008, 'Rezero Starting Life in Another World S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/635808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169382, 12008, 'Rezero Starting Life in Another World S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/635809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169383, 12008, 'Rezero Starting Life in Another World S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/635810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169384, 12008, 'Rezero Starting Life in Another World S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/635811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169385, 12008, 'Rezero Starting Life in Another World S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/635812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169386, 12008, 'Rezero Starting Life in Another World S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/635813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169387, 12008, 'Rezero Starting Life in Another World S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/713358.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169388, 12008, 'Rezero Starting Life in Another World S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/717050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169389, 12008, 'Rezero Starting Life in Another World S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/724414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169390, 12008, 'Rezero Starting Life in Another World S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/730975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169391, 12008, 'Rezero Starting Life in Another World S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/741050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169392, 12008, 'Rezero Starting Life in Another World S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/753489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169393, 12008, 'Rezero Starting Life in Another World S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/763733.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169394, 12008, 'Rezero Starting Life in Another World S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/772085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kLJonmVSDWyLKs7iVq7MaFqTn5V.jpg'),
(169395, 12009, 'Seirei Gensouki Spirit Chronicles S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/635732.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1UCeTALM67CP4rPV096fGLHSBOR.jpg'),
(169396, 12009, 'Seirei Gensouki Spirit Chronicles S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/635733.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tkFfHfZp9x7oPv3E9v87V26J22d.jpg'),
(169397, 12009, 'Seirei Gensouki Spirit Chronicles S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/635734.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4wQfAHugvjJBTSdQzZxoVcsozQZ.jpg'),
(169398, 12009, 'Seirei Gensouki Spirit Chronicles S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/635735.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4W1HYsC7su5RFB1iK9QJoR3JF0e.jpg'),
(169399, 12009, 'Seirei Gensouki Spirit Chronicles S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/635736.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2pzBtPFS1jRKZqUfAq3hnLHLx5n.jpg'),
(169400, 12009, 'Seirei Gensouki Spirit Chronicles S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/635737.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d90Qq0lz5bRUcH36yfUSef4yTLe.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(169401, 12009, 'Seirei Gensouki Spirit Chronicles S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/635738.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fzOh9NrM3cIfT13ZzRivFdw0YfQ.jpg'),
(169402, 12009, 'Seirei Gensouki Spirit Chronicles S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/635739.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9c9BCvM1O5faEk09czzbKdCJtaU.jpg'),
(169403, 12009, 'Seirei Gensouki Spirit Chronicles S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/635740.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ilCs5opytdL0n94HrcXbx7VEO6B.jpg'),
(169404, 12009, 'Seirei Gensouki Spirit Chronicles S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/635741.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hCmTRvPgjHxxvQGVxDY2dr3SzTy.jpg'),
(169405, 12009, 'Seirei Gensouki Spirit Chronicles S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/635742.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6DhIfRI4N4E35EPQTwxeHcqGDx7.jpg'),
(169406, 12009, 'Seirei Gensouki Spirit Chronicles S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/635743.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hrfIsrtgZp0WUPm5gMJ5CJ5HJdf.jpg'),
(169407, 12010, 'Seirei Gensouki Spirit Chronicles S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/635744.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wFPsRc1w8nyDelJKTsofnDAuCLG.jpg'),
(169408, 12010, 'Seirei Gensouki Spirit Chronicles S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/635745.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pszw4sJjCaUu0pcK8rycaHtrwSl.jpg'),
(169409, 12010, 'Seirei Gensouki Spirit Chronicles S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/635746.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fr6UF1Coel3fk7H93XZCKS9OP7I.jpg'),
(169410, 12010, 'Seirei Gensouki Spirit Chronicles S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/635747.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yGbzX6mIobU7W9cWpVKX8I1GfpF.jpg'),
(169411, 12010, 'Seirei Gensouki Spirit Chronicles S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/635748.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rISqEF6F38lk4SvqK7MphL3ATVQ.jpg'),
(169412, 12010, 'Seirei Gensouki Spirit Chronicles S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/635749.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bPOVu3Ca1PoWZfdFuji8Z93eX0t.jpg'),
(169413, 12010, 'Seirei Gensouki Spirit Chronicles S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/635750.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xfw5wNfdqovygQ9rCz0Yf0z7OA6.jpg'),
(169414, 12010, 'Seirei Gensouki Spirit Chronicles S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/635751.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hnOPLqD0WJ9bXf6kq4nVxJbpdmQ.jpg'),
(169415, 12010, 'Seirei Gensouki Spirit Chronicles S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/635752.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eRAKSYkmfx18WddEIeQuXg8HKjL.jpg'),
(169416, 12010, 'Seirei Gensouki Spirit Chronicles S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/635753.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5ty7fipdZphZwVEwuBhNnqH378E.jpg'),
(169417, 12010, 'Seirei Gensouki Spirit Chronicles S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/635754.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r6AuBH5lU6Ba09IzBGeY6BVWtfo.jpg'),
(169418, 12011, 'Soul Eater S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/635681.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mpObk51DgsnJMDoAS9Q4SSxWb2o.jpg'),
(169419, 12011, 'Soul Eater S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/635682.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a3UB3at47XeMTqeqtohRdo4ygHe.jpg'),
(169420, 12011, 'Soul Eater S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/635683.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tu5vmhD7b5kbgYm7ZOAi1zB2AjC.jpg'),
(169421, 12011, 'Soul Eater S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/635684.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AvHlAWJdIfykXOKE4adqYRmMci2.jpg'),
(169422, 12011, 'Soul Eater S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/635685.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xyRMmDUm52I6rXUrqypSGj42imt.jpg'),
(169423, 12011, 'Soul Eater S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/635686.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dO9PnaK8P9Obz31wfiOatuvhBKP.jpg'),
(169424, 12011, 'Soul Eater S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/635687.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dXV7X7wq0nko7cKl6kC93tNtZav.jpg'),
(169425, 12011, 'Soul Eater S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/635688.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j94RjOVAT5hZxaZwhzncDwvtjR7.jpg'),
(169426, 12011, 'Soul Eater S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/635689.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zOYB7eqyJtLZxv6BN16bk0mYnTS.jpg'),
(169427, 12011, 'Soul Eater S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/635690.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wz1L3lN0nmB87zlYQ3L5edLON7S.jpg'),
(169428, 12011, 'Soul Eater S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/635691.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dWDdEw3Y4oppvRydfDFGw1nO9AQ.jpg'),
(169429, 12011, 'Soul Eater S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/635692.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gVlPu1HRjVF60mVyq64hYx1Go3P.jpg'),
(169430, 12011, 'Soul Eater S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/635693.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cI8eYd6BY4KLEtIXp3yWvbjcoV3.jpg'),
(169431, 12011, 'Soul Eater S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/635694.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fb2CGwhZ5A2wd4A17FcOFBjp0FH.jpg'),
(169432, 12011, 'Soul Eater S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/635695.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wZw0EK8ZHAgzRg61ccFmqmaLjEA.jpg'),
(169433, 12011, 'Soul Eater S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/635696.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dESUj2bmnoM9YzALdp5X3vozCJE.jpg'),
(169434, 12011, 'Soul Eater S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/635697.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7YfybH5R1EZDZo6vVTT9mGdrRyQ.jpg'),
(169435, 12011, 'Soul Eater S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/635698.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1qxiBUoycy51nLRe5jEhLntnn6C.jpg'),
(169436, 12011, 'Soul Eater S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/635699.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gnbH4jvYzw48exXSArowtdj5wYK.jpg'),
(169437, 12011, 'Soul Eater S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/635700.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9xNpQtqmBdy5qMZQrGmYlpA9ng5.jpg'),
(169438, 12011, 'Soul Eater S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/635701.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a7r6ozdD5r7gGXsBf5weLnnbpGf.jpg'),
(169439, 12011, 'Soul Eater S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/635702.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vucGl2jNVht1DB0FR8XoTudkWHD.jpg'),
(169440, 12011, 'Soul Eater S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/635703.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/reDhihcgjSJpq3QTxrDZtLo0v83.jpg'),
(169441, 12011, 'Soul Eater S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/635704.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gC8veeCaV9v3ophjZQ5CxYdU7Oz.jpg'),
(169442, 12011, 'Soul Eater S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/635705.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zH6x9BvgYc3EOhe1TqrPfw9ulmA.jpg'),
(169443, 12011, 'Soul Eater S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/635706.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/icxhdfXiUjwuRSHkrKDBjXLSnzl.jpg'),
(169444, 12011, 'Soul Eater S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/635707.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d6ZYkLehxbRYMqdIwlav4l0YAWE.jpg'),
(169445, 12011, 'Soul Eater S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/635708.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aQ5b7Y9ccqLnCJ83c45cdu806Js.jpg'),
(169446, 12011, 'Soul Eater S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/635709.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xfZjPqtxC7eIPcR70GWekQJGKov.jpg'),
(169447, 12011, 'Soul Eater S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/635710.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g6k4W6YLgTgWrZ4VTZNk9eqlbzK.jpg'),
(169448, 12011, 'Soul Eater S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/635711.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9ed8tgTOCrPJynuW7VlimGkzfk1.jpg'),
(169449, 12011, 'Soul Eater S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/635712.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8odfTSrXOX1eY6iCv86kIzloSHR.jpg'),
(169450, 12011, 'Soul Eater S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/635713.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/839xfPFpzz4WURIGtf7Otg1rOwg.jpg'),
(169451, 12011, 'Soul Eater S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/635714.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nQwutYCvQGKdeflU5bhRA2oaAId.jpg'),
(169452, 12011, 'Soul Eater S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/635715.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y3q8hwXejhRn6NehKgXuGHKuuBN.jpg'),
(169453, 12011, 'Soul Eater S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/635716.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m29FqDxUZ2wz5YuGwqbNWJdD1Oh.jpg'),
(169454, 12011, 'Soul Eater S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/635717.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5n0y1yf3nS9ZbOWusMNmVmlKeIu.jpg'),
(169455, 12011, 'Soul Eater S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/635718.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eT4ClfY0ssTrzmlsMS9Zy6ovsDh.jpg'),
(169456, 12011, 'Soul Eater S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/635719.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cDE4r7YNDbFniPU15sLSZxjXppG.jpg'),
(169457, 12011, 'Soul Eater S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/635720.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/EUCyxs839AllK5aJNHculLfvYd.jpg'),
(169458, 12011, 'Soul Eater S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/635721.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dZ4JcBBZfA9yLkOHaE220dHePcN.jpg'),
(169459, 12011, 'Soul Eater S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/635722.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vqTj0Vch5Z58E7MVtP4x3e7HNEG.jpg'),
(169460, 12011, 'Soul Eater S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/635723.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eEHfK3iLBkraGssZbhWp4r7ntLF.jpg'),
(169461, 12011, 'Soul Eater S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/635724.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/swjwtrNs4b27nFVNe2mo2cBx1Fs.jpg'),
(169462, 12011, 'Soul Eater S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/635725.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/arFs0pw59Szdk7atpHoEsmecuaf.jpg'),
(169463, 12011, 'Soul Eater S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/635726.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9sYL8gCO0T1buZyI5gx0eRdVERB.jpg'),
(169464, 12011, 'Soul Eater S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/635727.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ptjTan3i1kqIS3wdM1Ovhhbajz9.jpg'),
(169465, 12011, 'Soul Eater S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/635728.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9HQXbvPmWRi9VyDyaRzIP83sP8N.jpg'),
(169466, 12011, 'Soul Eater S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/635729.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w1djjtwokzb9xyX71H0pSzgTmvl.jpg'),
(169467, 12011, 'Soul Eater S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/635730.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bEZjb1RQAgQLxxYrFw85kYouoHV.jpg'),
(169468, 12011, 'Soul Eater S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/635731.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7R6Ue5Y2Bsi70Av4alAMAnspfqV.jpg'),
(169469, 12012, 'Wayward Pines S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/635662.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tXDVmpR2tzDhbRrIMxoY2CyzRK5.jpg'),
(169470, 12012, 'Wayward Pines S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/635663.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4MOjxxgRolxzUNHzmVABNqC37wv.jpg'),
(169471, 12012, 'Wayward Pines S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/635664.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q6niz8AjgI47uMsFCUl1CSaWBQE.jpg'),
(169472, 12012, 'Wayward Pines S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/635665.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jeBqZmNmRbhOBej3R5KL3miJSYg.jpg'),
(169473, 12012, 'Wayward Pines S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/635666.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w4tl80Hg4L32I1e1eKcCsrlgpQ6.jpg'),
(169474, 12012, 'Wayward Pines S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/635667.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eVVOOED7ThyNs4onJbEACmxldEF.jpg'),
(169475, 12012, 'Wayward Pines S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/635668.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4X11pfYbwoQQNt5OauWeZr2vGut.jpg'),
(169476, 12012, 'Wayward Pines S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/635669.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4wvLiFpvSOq8mG4af1xnDGndNPF.jpg'),
(169477, 12012, 'Wayward Pines S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/635670.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1KsvsghXLI2YdbPlvda3jTtdxJ6.jpg'),
(169478, 12013, 'Wayward Pines S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/635671.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1RhdayfnTIxDPoWfFkO6UqBAScA.jpg'),
(169479, 12013, 'Wayward Pines S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/635672.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iP1DxYlKAqOSMAI6QaGvcHmcVee.jpg'),
(169480, 12013, 'Wayward Pines S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/635673.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ktJHglygLyDp4hnuEzZqxEuTeON.jpg'),
(169481, 12013, 'Wayward Pines S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/635674.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6Z1fI5QHCksE8iUVIV5SEK7NPmd.jpg'),
(169482, 12013, 'Wayward Pines S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/635675.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tVe96akabuAiG2SIctgnkk3JHew.jpg'),
(169483, 12013, 'Wayward Pines S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/635676.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ayrrUcdsiGM3o3vyaE9b3RkruWf.jpg'),
(169484, 12013, 'Wayward Pines S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/635677.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zAPUKn6ZPyQgaG4HSPJbtVyQkpj.jpg'),
(169485, 12013, 'Wayward Pines S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/635678.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1UxKRVhveCBnslN9XdCoHBUxfpg.jpg'),
(169486, 12013, 'Wayward Pines S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/635679.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w5Gelc9AykD6MT7SY2kxlq2xVFV.jpg'),
(169487, 12013, 'Wayward Pines S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/635680.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mxji4IEToM65shdXUOIhMVhtDd4.jpg'),
(169488, 12014, 'Beast Games S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/635660.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wXW9DAuzWwRP6cYBA83yoW0SUil.jpg'),
(169489, 12014, 'Beast Games S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/635661.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w4pW3bt0oEniODSioG0ltLS4uXP.jpg'),
(169490, 12014, 'Beast Games S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/644194.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/57Hx4gtYTkIrhagoo16i88jFJuy.jpg'),
(169491, 12014, 'Beast Games S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/659760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/57Hx4gtYTkIrhagoo16i88jFJuy.jpg'),
(169492, 12014, 'Beast Games S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/663106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/57Hx4gtYTkIrhagoo16i88jFJuy.jpg'),
(169493, 12014, 'Beast Games S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/665879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/57Hx4gtYTkIrhagoo16i88jFJuy.jpg'),
(169494, 12014, 'Beast Games S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/673638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/57Hx4gtYTkIrhagoo16i88jFJuy.jpg'),
(169495, 12014, 'Beast Games S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/680983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/57Hx4gtYTkIrhagoo16i88jFJuy.jpg'),
(169496, 12014, 'Beast Games S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/687818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/57Hx4gtYTkIrhagoo16i88jFJuy.jpg'),
(169497, 12014, 'Beast Games S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/696276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/57Hx4gtYTkIrhagoo16i88jFJuy.jpg'),
(169498, 12015, 'Caillou S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/635647.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hxNgvJNDS8jCNQokSoxzBbWHl08.jpg'),
(169499, 12015, 'Caillou S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/635648.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/86fn0dy8u6vVa2KahZEkc31msm4.jpg'),
(169500, 12015, 'Caillou S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/635649.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5IsA1gARr742qAuI11ecoPAjLk7.jpg'),
(169501, 12015, 'Caillou S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/635650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/86fn0dy8u6vVa2KahZEkc31msm4.jpg'),
(169502, 12015, 'Caillou S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/635651.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/86fn0dy8u6vVa2KahZEkc31msm4.jpg'),
(169503, 12015, 'Caillou S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/635652.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/86fn0dy8u6vVa2KahZEkc31msm4.jpg'),
(169504, 12015, 'Caillou S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/635653.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/86fn0dy8u6vVa2KahZEkc31msm4.jpg'),
(169505, 12015, 'Caillou S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/635654.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/86fn0dy8u6vVa2KahZEkc31msm4.jpg'),
(169506, 12015, 'Caillou S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/635655.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/86fn0dy8u6vVa2KahZEkc31msm4.jpg'),
(169507, 12015, 'Caillou S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/635656.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/86fn0dy8u6vVa2KahZEkc31msm4.jpg'),
(169508, 12015, 'Caillou S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/635657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/86fn0dy8u6vVa2KahZEkc31msm4.jpg'),
(169509, 12015, 'Caillou S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/635658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/86fn0dy8u6vVa2KahZEkc31msm4.jpg'),
(169510, 12015, 'Caillou S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/635659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/86fn0dy8u6vVa2KahZEkc31msm4.jpg'),
(169511, 12016, 'Minha Menina S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/635555.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iPwtCk9zk80sed4heluxdPu72sD.jpg'),
(169512, 12016, 'Minha Menina S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/635556.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uXvKcWyqFN3ukl0lwZGvLAOWRt8.jpg'),
(169513, 12016, 'Minha Menina S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/635557.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k9VjcO0QN9kRR0vGrIIJD5RNmrJ.jpg'),
(169514, 12016, 'Minha Menina S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/635558.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q6pyOkTqYtNwrTvclGC4VaYypop.jpg'),
(169515, 12016, 'Minha Menina S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/635559.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7oKrL8PFpc4Bdu74pLjLBwMEPjj.jpg'),
(169516, 12016, 'Minha Menina S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/635560.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9Ky5yrQvqCePDyhgKJxHWc5Om8P.jpg'),
(169517, 12016, 'Minha Menina S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/635561.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4qH9wcroN5wIkQOdYiA1iCRpT08.jpg'),
(169518, 12016, 'Minha Menina S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/635562.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uO8QhIYXPVxqx9cdujSYRR2uTFX.jpg'),
(169519, 12016, 'Minha Menina S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/635563.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jZ1DRSiFoEVYXZ7yKyFy4jbdcLe.jpg'),
(169520, 12016, 'Minha Menina S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/635564.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jvzcKtPtyytoYdMNsMsZfQkWe8J.jpg'),
(169521, 12016, 'Minha Menina S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/635565.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f4enR43nwNNOS0GPLRDP8CnUEZE.jpg'),
(169522, 12016, 'Minha Menina S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/635566.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/piSu9GN4SNkdecOTKxeKUZ4u1pB.jpg'),
(169523, 12016, 'Minha Menina S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/635567.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zEvcIOty76vRx8ToKRdsKHVuEMv.jpg'),
(169524, 12016, 'Minha Menina S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/635568.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ktMX80EKndgWya5dK5cBRDGCvIM.jpg'),
(169525, 12016, 'Minha Menina S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/635569.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bG0Ju9rgLDfSMF74jDxPr1XRzQY.jpg'),
(169526, 12016, 'Minha Menina S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/635570.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jwHNtIiRkyEz3JCFiZyF57Lm62f.jpg'),
(169527, 12016, 'Minha Menina S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/635571.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c04wL1U4SSua3dWc3RGBV9ryFUm.jpg'),
(169528, 12016, 'Minha Menina S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/635572.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8HJKnbyEQ8o5ULUKnUmkY0Uk6T1.jpg'),
(169529, 12016, 'Minha Menina S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/635573.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x84QzqgDY3E009aH2OsTcK3wokM.jpg'),
(169530, 12016, 'Minha Menina S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/635574.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mpKEqorWwZhrvH6klXUAM2Ps6YA.jpg'),
(169531, 12016, 'Minha Menina S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/635575.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vgr9o1bdFTP9O2s2tcyeeeR3phC.jpg'),
(169532, 12016, 'Minha Menina S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/635576.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x4w9dX3BEw4T7M8EacIhC08vksW.jpg'),
(169533, 12016, 'Minha Menina S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/635577.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wW0GjpHFE4KYrsOLO282Thqbf7D.jpg'),
(169534, 12016, 'Minha Menina S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/635578.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jBVexkgLcp5C4Ix8GtOsqhpkzeL.jpg'),
(169535, 12016, 'Minha Menina S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/635579.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h1itRIj9MWqwCXn9gzdTPeJwvqI.jpg'),
(169536, 12016, 'Minha Menina S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/635580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169537, 12016, 'Minha Menina S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/635581.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169538, 12016, 'Minha Menina S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/635582.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169539, 12016, 'Minha Menina S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/635583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169540, 12016, 'Minha Menina S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/635584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169541, 12016, 'Minha Menina S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/635585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169542, 12016, 'Minha Menina S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/635586.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169543, 12016, 'Minha Menina S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/635587.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169544, 12016, 'Minha Menina S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/635588.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169545, 12016, 'Minha Menina S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/635589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169546, 12016, 'Minha Menina S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/635590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169547, 12016, 'Minha Menina S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/635591.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169548, 12016, 'Minha Menina S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/635592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169549, 12016, 'Minha Menina S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/635593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169550, 12016, 'Minha Menina S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/635594.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169551, 12016, 'Minha Menina S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/635595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169552, 12016, 'Minha Menina S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/635596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169553, 12016, 'Minha Menina S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/635597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169554, 12016, 'Minha Menina S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/635598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169555, 12016, 'Minha Menina S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/635599.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169556, 12016, 'Minha Menina S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/635600.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169557, 12016, 'Minha Menina S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/635601.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169558, 12016, 'Minha Menina S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/635602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169559, 12016, 'Minha Menina S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/635603.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169560, 12016, 'Minha Menina S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/635604.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169561, 12016, 'Minha Menina S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/635605.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169562, 12016, 'Minha Menina S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/635606.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169563, 12016, 'Minha Menina S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/635607.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169564, 12016, 'Minha Menina S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/635608.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169565, 12016, 'Minha Menina S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/635609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169566, 12016, 'Minha Menina S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/635610.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169567, 12016, 'Minha Menina S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/635611.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169568, 12016, 'Minha Menina S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/635612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169569, 12016, 'Minha Menina S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/635613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169570, 12016, 'Minha Menina S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/635614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169571, 12016, 'Minha Menina S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/635615.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169572, 12016, 'Minha Menina S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/635616.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169573, 12016, 'Minha Menina S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/635617.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169574, 12016, 'Minha Menina S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/635618.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169575, 12016, 'Minha Menina S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/635619.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169576, 12016, 'Minha Menina S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/635620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169577, 12016, 'Minha Menina S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/635621.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169578, 12016, 'Minha Menina S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/635622.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169579, 12016, 'Minha Menina S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/635623.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169580, 12016, 'Minha Menina S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/635624.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169581, 12016, 'Minha Menina S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/635625.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169582, 12016, 'Minha Menina S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/635626.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169583, 12016, 'Minha Menina S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/635627.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169584, 12016, 'Minha Menina S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/635628.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169585, 12016, 'Minha Menina S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/635629.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169586, 12016, 'Minha Menina S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/635630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169587, 12016, 'Minha Menina S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/635631.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169588, 12016, 'Minha Menina S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/635632.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169589, 12016, 'Minha Menina S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/635633.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169590, 12016, 'Minha Menina S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/635634.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169591, 12016, 'Minha Menina S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/635635.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169592, 12016, 'Minha Menina S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/635636.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169593, 12016, 'Minha Menina S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/635637.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169594, 12016, 'Minha Menina S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/635638.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169595, 12016, 'Minha Menina S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/635639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169596, 12016, 'Minha Menina S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/635640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169597, 12016, 'Minha Menina S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/635641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169598, 12016, 'Minha Menina S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/635642.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169599, 12016, 'Minha Menina S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/635643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169600, 12016, 'Minha Menina S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/635644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169601, 12016, 'Minha Menina S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/635645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169602, 12016, 'Minha Menina S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/635646.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tY91Tln9WjipWLte8b3mbcsgPny.jpg'),
(169603, 12017, '365 Days To The Wedding S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/638668.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5AXEV67Emih1xSJ6fd8MyCYmfUZ.jpg'),
(169604, 12017, '365 Days To The Wedding S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/638669.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9kWMHFMbuuC7kJA57bGeRaTTWHU.jpg'),
(169605, 12017, '365 Days To The Wedding S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/638670.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1Aqj3KehvCu8pvlfBvJxArrZS0C.jpg'),
(169606, 12017, '365 Days To The Wedding S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/638671.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fXvrJjZzaQIt4EeVNTA4aJmKcCf.jpg'),
(169607, 12017, '365 Days To The Wedding S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/638672.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1URGtI8PXCWFCku0g9ca9PHVVxj.jpg'),
(169608, 12017, '365 Days To The Wedding S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/638673.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y3BGfrtJSdsodtupJrD5BgzMGLZ.jpg'),
(169609, 12017, '365 Days To The Wedding S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/638674.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iVjbBLPwqVx5AqDoWsl0SgTXXWa.jpg'),
(169610, 12017, '365 Days To The Wedding S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/638675.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jB2WLaZ5x1QWZZpCHFLZIPEVcMB.jpg'),
(169611, 12017, '365 Days To The Wedding S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/638676.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jrS8IeH0UcmPaLPkcVfVld8eOGH.jpg'),
(169612, 12017, '365 Days To The Wedding S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/666397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xNuXxVR4P3oWGUcJFVJzOBesxeB.jpg'),
(169613, 12017, '365 Days To The Wedding S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/666398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xNuXxVR4P3oWGUcJFVJzOBesxeB.jpg'),
(169614, 12017, '365 Days To The Wedding S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/666399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xNuXxVR4P3oWGUcJFVJzOBesxeB.jpg'),
(169615, 12018, 'Assassino do Zodiaco S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/638663.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hrkvvEN86CE3tzUNLyMJxO2nDaS.jpg'),
(169616, 12018, 'Assassino do Zodiaco S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/638664.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k8WnGymwFpPVjZ83prYKRTcGn0y.jpg'),
(169617, 12018, 'Assassino do Zodiaco S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/638665.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/76xxyF7RyYSBZPTfE2UMOQcyP8F.jpg'),
(169618, 12018, 'Assassino do Zodiaco S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/638666.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7BLhqVvRRWIt8SEmbTDLpyDfUCa.jpg'),
(169619, 12018, 'Assassino do Zodiaco S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/638667.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ko1t0pzastxoa9NTiJ7dqTuMw1P.jpg'),
(169620, 12019, '365 Days To The Wedding [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637821.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5AXEV67Emih1xSJ6fd8MyCYmfUZ.jpg'),
(169621, 12019, '365 Days To The Wedding [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/637822.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9kWMHFMbuuC7kJA57bGeRaTTWHU.jpg'),
(169622, 12019, '365 Days To The Wedding [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637823.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1Aqj3KehvCu8pvlfBvJxArrZS0C.jpg'),
(169623, 12019, '365 Days To The Wedding [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637824.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fXvrJjZzaQIt4EeVNTA4aJmKcCf.jpg'),
(169624, 12019, '365 Days To The Wedding [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/637825.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1URGtI8PXCWFCku0g9ca9PHVVxj.jpg'),
(169625, 12019, '365 Days To The Wedding [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/637826.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y3BGfrtJSdsodtupJrD5BgzMGLZ.jpg'),
(169626, 12019, '365 Days To The Wedding [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637827.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iVjbBLPwqVx5AqDoWsl0SgTXXWa.jpg'),
(169627, 12019, '365 Days To The Wedding [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637828.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jB2WLaZ5x1QWZZpCHFLZIPEVcMB.jpg'),
(169628, 12019, '365 Days To The Wedding [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/637829.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jrS8IeH0UcmPaLPkcVfVld8eOGH.jpg'),
(169629, 12019, '365 Days To The Wedding [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/637830.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hBO7VcPyCKv5hEeNyPK1d0nedvL.jpg'),
(169630, 12019, '365 Days To The Wedding [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/637831.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jycfyUaf6B6eDx7G4mjpaVKg3Ny.jpg'),
(169631, 12019, '365 Days To The Wedding [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/637832.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/on0qIx2fluFEXUBV3spcaJGi6Xb.jpg'),
(169632, 12020, 'Bad Prosecutor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637809.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sfoBWrdvOOni18IkB05HrZyP1Tx.jpg'),
(169633, 12020, 'Bad Prosecutor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/637810.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nfhPEVKvHPgpx6PsA0f6jjwXvZK.jpg'),
(169634, 12020, 'Bad Prosecutor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637811.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iYkF5Vrrmzcj4AlZNi8RqzvtSRv.jpg'),
(169635, 12020, 'Bad Prosecutor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637812.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rLeZQPYBr4SV6ZZmwGku0PAwGFg.jpg'),
(169636, 12020, 'Bad Prosecutor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/637813.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8ZfGJimAQSb3Xz3koxoUZPfo31y.jpg'),
(169637, 12020, 'Bad Prosecutor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/637814.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/afVqwlmXzjOxMSckYGtWdGTkdpW.jpg'),
(169638, 12020, 'Bad Prosecutor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637815.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/DUWOwUKfPteCrBBY3RrVsyvJHV.jpg'),
(169639, 12020, 'Bad Prosecutor [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637816.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5zNiynuSqHRQb0yJxFZ167FRXNZ.jpg'),
(169640, 12020, 'Bad Prosecutor [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/637817.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ifNuUUJR3MrMJqVTjjhN6XAWoCl.jpg'),
(169641, 12020, 'Bad Prosecutor [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/637818.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/96GqJJL0aUIey5uGVStNC3xtByq.jpg'),
(169642, 12020, 'Bad Prosecutor [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/637819.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qvhbsbsndquvKljDRSMs4MFhXf6.jpg'),
(169643, 12020, 'Bad Prosecutor [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/637820.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sKDaQqVjDvt7606zwhJR2pgf0R6.jpg'),
(169644, 12021, 'Come Back Mister [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637793.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xnZUZvcUoTdVcSUarHasO4rl1cV.jpg'),
(169645, 12021, 'Come Back Mister [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/637794.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tjNoOVJBiFuQHcFmLYr3qAVpfH1.jpg'),
(169646, 12021, 'Come Back Mister [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637795.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lSfWKYdxlGSd1Uao8L4FG8rlW27.jpg'),
(169647, 12021, 'Come Back Mister [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637796.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4GW4AzhJAzanwV3ILOewDxeaPvf.jpg'),
(169648, 12021, 'Come Back Mister [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/637797.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hFbN8Gypn8MNoyj075CrdNmOit3.jpg'),
(169649, 12021, 'Come Back Mister [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/637798.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sbHiyppEpXr8nuX2NkF2XmqoGWF.jpg'),
(169650, 12021, 'Come Back Mister [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637799.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lBENl2k4IPDG0IQGycpW5K7KLnC.jpg'),
(169651, 12021, 'Come Back Mister [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637800.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cMjjXZkIs949YxluUf78Akasojp.jpg'),
(169652, 12021, 'Come Back Mister [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/637801.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2Cq1c4Kl4oY24FQ8FBGlHf3XsbV.jpg'),
(169653, 12021, 'Come Back Mister [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/637802.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w94ofzhQ9ou88P3anB8cqtZBgFN.jpg'),
(169654, 12021, 'Come Back Mister [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/637803.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zQN83vla7TC2bUZzYSuunob6tEP.jpg'),
(169655, 12021, 'Come Back Mister [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/637804.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3PTWwzektVC2MSDHNxmVUJJHd8n.jpg'),
(169656, 12021, 'Come Back Mister [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/637805.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oOVHawVlrheuQtbGjO070hn7Yz5.jpg'),
(169657, 12021, 'Come Back Mister [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/637806.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fikwrH6kOJcRFGfj6anqYqRMvWG.jpg'),
(169658, 12021, 'Come Back Mister [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/637807.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lA6UeqzOESaUWHeQuU6ZILSSaJP.jpg'),
(169659, 12021, 'Come Back Mister [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/637808.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/32JrWd3eAQtOdHdBrRDaYWLG8gj.jpg'),
(169660, 12022, 'DEMON LORD 2099 S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637785.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wYr3HWgCkBUK2xfSnzbAHbua6WZ.jpg'),
(169661, 12022, 'DEMON LORD 2099 S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/637786.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dV8zxzgQTWE2O1msnwJ9aQ1bKzr.jpg'),
(169662, 12022, 'DEMON LORD 2099 S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637787.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pCLu1OYl4WVdyhxqjwtSwFy9MFr.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(169663, 12022, 'DEMON LORD 2099 S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637788.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ecnudmJT27zvJYE5H9TZMBwzwxY.jpg'),
(169664, 12022, 'DEMON LORD 2099 S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/637789.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8OCev7WSr4iLrGHDBDEQNUELIuL.jpg'),
(169665, 12022, 'DEMON LORD 2099 S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/637790.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/quFWM6Y7p8irwQpf3EpZzMjlvYS.jpg'),
(169666, 12022, 'DEMON LORD 2099 S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637791.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hP7hJX790ykj9Y3MSA09RHWmqdS.jpg'),
(169667, 12022, 'DEMON LORD 2099 S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637792.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJyE05fNJDY3XX05BowGOhsjGt.jpg'),
(169668, 12022, 'DEMON LORD 2099 S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/659661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mU7QgTm2WadwVoT7jDyMY9Czpsj.jpg'),
(169669, 12022, 'DEMON LORD 2099 S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/659662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mU7QgTm2WadwVoT7jDyMY9Czpsj.jpg'),
(169670, 12022, 'DEMON LORD 2099 S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/660500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mU7QgTm2WadwVoT7jDyMY9Czpsj.jpg'),
(169671, 12022, 'DEMON LORD 2099 S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/669868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mU7QgTm2WadwVoT7jDyMY9Czpsj.jpg'),
(169672, 12023, 'DEMON LORD 2099 [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637774.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wYr3HWgCkBUK2xfSnzbAHbua6WZ.jpg'),
(169673, 12023, 'DEMON LORD 2099 [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/637775.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dV8zxzgQTWE2O1msnwJ9aQ1bKzr.jpg'),
(169674, 12023, 'DEMON LORD 2099 [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637776.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pCLu1OYl4WVdyhxqjwtSwFy9MFr.jpg'),
(169675, 12023, 'DEMON LORD 2099 [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637777.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ecnudmJT27zvJYE5H9TZMBwzwxY.jpg'),
(169676, 12023, 'DEMON LORD 2099 [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/637778.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8OCev7WSr4iLrGHDBDEQNUELIuL.jpg'),
(169677, 12023, 'DEMON LORD 2099 [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/637779.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/quFWM6Y7p8irwQpf3EpZzMjlvYS.jpg'),
(169678, 12023, 'DEMON LORD 2099 [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637780.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hP7hJX790ykj9Y3MSA09RHWmqdS.jpg'),
(169679, 12023, 'DEMON LORD 2099 [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637781.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jRJyE05fNJDY3XX05BowGOhsjGt.jpg'),
(169680, 12023, 'DEMON LORD 2099 [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/637782.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hvIle9xqPJbpq6WsGne6kmMsimo.jpg'),
(169681, 12023, 'DEMON LORD 2099 [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/637783.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gUSOnODrc45dS0XZ8EYEWSqbwQc.jpg'),
(169682, 12023, 'DEMON LORD 2099 [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/637784.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hbNSGFwkeAuqZJcRXCMocy7jQy.jpg'),
(169683, 12023, 'DEMON LORD 2099 [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/665370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mU7QgTm2WadwVoT7jDyMY9Czpsj.jpg'),
(169684, 12024, 'Duas Semanas [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637758.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qat2DLfoJogvlfNnEPrxnXg3LXJ.jpg'),
(169685, 12024, 'Duas Semanas [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/637759.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x4ucB6F2kARSETF46quKPJq1UBl.jpg'),
(169686, 12024, 'Duas Semanas [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637760.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o9XayjFOhoBpS1Ksyx9v21QkkEQ.jpg'),
(169687, 12024, 'Duas Semanas [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637761.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ucJ8uigBsm6QX5W4T19rvyn9MpJ.jpg'),
(169688, 12024, 'Duas Semanas [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/637762.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kePA17dcl9gj9UTTUoKDC56NlTp.jpg'),
(169689, 12024, 'Duas Semanas [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/637763.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lJk5tjkxfrv7tYZqbIyteMVzPdt.jpg'),
(169690, 12024, 'Duas Semanas [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637764.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8Xmh0GRPLAtGKVZmCNauins50sy.jpg'),
(169691, 12024, 'Duas Semanas [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637765.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2jG6pWs2b1tHCa6FC5x5CpJR1vK.jpg'),
(169692, 12024, 'Duas Semanas [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/637766.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vgCHp7dseKyFbVwTQ6g75h0LFgn.jpg'),
(169693, 12024, 'Duas Semanas [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/637767.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zqRlv0yzVhP9Wt5IIJxAvqlY7Vw.jpg'),
(169694, 12024, 'Duas Semanas [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/637768.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/szSSiLQPSxMYsPRrz6Q76gDjykm.jpg'),
(169695, 12024, 'Duas Semanas [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/637769.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9uYNdaGh7S2GtBFzfeUwU76DztE.jpg'),
(169696, 12024, 'Duas Semanas [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/637770.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9tP3PtFhdxfLUoRhcJzmaCke8r1.jpg'),
(169697, 12024, 'Duas Semanas [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/637771.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cnKhSUTom3zowTayuwAyk6xwN5E.jpg'),
(169698, 12024, 'Duas Semanas [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/637772.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5ADlvmY0vhY6Fy7YUurn9cwUaGs.jpg'),
(169699, 12024, 'Duas Semanas [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/637773.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lIKRsRmQ1S3nEJTwZRb7dhdjIQX.jpg'),
(169700, 12025, 'Locodol [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637743.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bFHeYLkSSS3edBMVzqEnDMWsN6O.jpg'),
(169701, 12025, 'Locodol [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/637744.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lx14yvulDYjUJc7rED11T8yheRr.jpg'),
(169702, 12025, 'Locodol [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637745.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/beqOYSrefGddPD3C0EVGLhi7E4K.jpg'),
(169703, 12025, 'Locodol [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637746.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sRwk8PylXZIYhEL1FYN6csTbNwA.jpg'),
(169704, 12025, 'Locodol [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/637747.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fMnHtpErUOYUQ5ErSz7zmUocxoD.jpg'),
(169705, 12025, 'Locodol [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/637748.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ifQtCvLRJft4j0lWWY3u5BWSsHR.jpg'),
(169706, 12025, 'Locodol [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637749.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/17bi7lwm1p01hALtX1WeE7yZr3G.jpg'),
(169707, 12025, 'Locodol [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637750.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oi4m3EZmne0y8tzfB9VDcnamUHm.jpg'),
(169708, 12025, 'Locodol [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/637751.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jniewLrE2rjYrYGZBNvA6SuMnNy.jpg'),
(169709, 12025, 'Locodol [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/637752.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mjl4BzhBbC7VXzaE32ORryxYhcQ.jpg'),
(169710, 12025, 'Locodol [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/637753.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dflj5nSPFU562NFmWJAGfbZkYTL.jpg'),
(169711, 12025, 'Locodol [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/637754.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3Pz6M52kod21iVtDe4kL52JFquv.jpg'),
(169712, 12025, 'Locodol [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/637755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ciJydt7dsKSaL2KtkyRiwKse3YZ.jpg'),
(169713, 12025, 'Locodol [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/637756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ciJydt7dsKSaL2KtkyRiwKse3YZ.jpg'),
(169714, 12025, 'Locodol [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/637757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ciJydt7dsKSaL2KtkyRiwKse3YZ.jpg'),
(169715, 12026, 'Love Sea [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637733.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yR2UK2UXp30a5daqNh2Ou9r44d6.jpg'),
(169716, 12026, 'Love Sea [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/637734.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1AjMRV0x16VAAtjifikxLPeDG9V.jpg'),
(169717, 12026, 'Love Sea [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637735.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kEOd3Dr2mFkUGz1s3HU28DTOQkD.jpg'),
(169718, 12026, 'Love Sea [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637736.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bFPsfJ3p7v7o9MbBRlfiI3lvv58.jpg'),
(169719, 12026, 'Love Sea [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/637737.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gGqfoqqIFBOxabVladQUYexvU23.jpg'),
(169720, 12026, 'Love Sea [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/637738.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1cMJKeYxzuqUCnIKsQfhZU8HMI6.jpg'),
(169721, 12026, 'Love Sea [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637739.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/54TThY1k2FOJA6U8k4gJruqFQMz.jpg'),
(169722, 12026, 'Love Sea [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637740.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6kkXwxWwqLeAKG1Kf1hh65if1dT.jpg'),
(169723, 12026, 'Love Sea [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/637741.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oS4V1QQHyNjcIZzI7BwnIXPrpSH.jpg'),
(169724, 12026, 'Love Sea [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/637742.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ySGuQKovZRb0ulIkkaq8IdTQM54.jpg'),
(169725, 12027, 'Meus Pes Estao Me Matando Reino Unido S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637725.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jcMHkWbJzGBATwYfxFVhQ2DidAN.jpg'),
(169726, 12027, 'Meus Pes Estao Me Matando Reino Unido S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/637726.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p4ZgE2NJLJ0M2tkdm1grEDlxdx0.jpg'),
(169727, 12027, 'Meus Pes Estao Me Matando Reino Unido S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637727.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/84UyyIJMuF73dFSrTVpedR9bHNi.jpg'),
(169728, 12027, 'Meus Pes Estao Me Matando Reino Unido S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637728.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dra7r3hKxpryLE92YYYmBnr9QZa.jpg'),
(169729, 12027, 'Meus Pes Estao Me Matando Reino Unido S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/637729.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nfDD0tK5mKG9CD4MAFj2urpB3GZ.jpg'),
(169730, 12027, 'Meus Pes Estao Me Matando Reino Unido S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/637730.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gNwr2tkpQZU3YWo4qn4SnH71weF.jpg'),
(169731, 12027, 'Meus Pes Estao Me Matando Reino Unido S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637731.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gNwr2tkpQZU3YWo4qn4SnH71weF.jpg'),
(169732, 12027, 'Meus Pes Estao Me Matando Reino Unido S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637732.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gNwr2tkpQZU3YWo4qn4SnH71weF.jpg'),
(169733, 12028, 'Moorim School Saga of the Brave [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637711.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Md9x0OHguZmVw5J7WcGOhlClt.jpg'),
(169734, 12028, 'Moorim School Saga of the Brave [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/637712.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zmUHbyoQ9PwMSbIkZVK06ufbknN.jpg'),
(169735, 12028, 'Moorim School Saga of the Brave [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637713.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fgIIu1HKhBOdaPZRmqmz01YJizO.jpg'),
(169736, 12028, 'Moorim School Saga of the Brave [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637714.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1t73487LfFnTYlwDVqFZF6qfPCf.jpg'),
(169737, 12028, 'Moorim School Saga of the Brave [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/637716.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cnhxcppBQyJ756BDD5Z1VS0J50L.jpg'),
(169738, 12028, 'Moorim School Saga of the Brave [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/637719.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sUErs9ldk66CzlDmMMfPq9FWZMv.jpg'),
(169739, 12028, 'Moorim School Saga of the Brave [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637720.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fvbTRH3DTbrC9aKgyJMTyHrJPDR.jpg'),
(169740, 12028, 'Moorim School Saga of the Brave [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637721.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/92X1x9bT05a353PyvlkJcEA8lho.jpg'),
(169741, 12028, 'Moorim School Saga of the Brave [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/637722.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/51dAbJaWreYydDJYiFgHHXMIyKt.jpg'),
(169742, 12028, 'Moorim School Saga of the Brave [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/637723.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qK7qg9tqtaZsMK6J9k0DHSP2YWo.jpg'),
(169743, 12028, 'Moorim School Saga of the Brave [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/637724.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fX5y4ARTJfU84D1KhzuSJ2ybyau.jpg'),
(169744, 12029, 'Nascidos de Novo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637679.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gXN5ZnuAKaujFGukUaa9SEtVYLH.jpg'),
(169745, 12029, 'Nascidos de Novo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/637680.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iduBjoY79dZg32Q9XwzFtFtWXbq.jpg'),
(169746, 12029, 'Nascidos de Novo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637681.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Am8esC7gyQTwaTU0p9hRr6mdVnG.jpg'),
(169747, 12029, 'Nascidos de Novo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637682.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tu5VcghvuBFnqDeKzeXKQjirzMt.jpg'),
(169748, 12029, 'Nascidos de Novo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/637683.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iQZkifwowsPonucjD63vqkDkDHi.jpg'),
(169749, 12029, 'Nascidos de Novo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/637684.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/weHX8OfNz0Snwq6jAdruXtRsDwn.jpg'),
(169750, 12029, 'Nascidos de Novo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637685.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vlddeUdwJe2KY1yN1nPafa9oLvw.jpg'),
(169751, 12029, 'Nascidos de Novo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637686.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qSZBQHWn3XDq9wQQMH6ydQd795w.jpg'),
(169752, 12029, 'Nascidos de Novo [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/637687.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lfMr8BM8eVdOfpNbJqvdrFkQU3G.jpg'),
(169753, 12029, 'Nascidos de Novo [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/637688.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xwYlGbZH2wOZqzoODuppk2EVFiw.jpg'),
(169754, 12029, 'Nascidos de Novo [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/637689.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7uNNgC6vXhkP67wgIzJmlACb8hg.jpg'),
(169755, 12029, 'Nascidos de Novo [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/637690.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bbzmyWGbYo5hK46hCwCeF8g0pqD.jpg'),
(169756, 12029, 'Nascidos de Novo [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/637691.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dWFSHjkwbJExczTVwFmByx0a0QM.jpg'),
(169757, 12029, 'Nascidos de Novo [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/637692.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AouSqjjAklguVz0w1MEwPmE7l1J.jpg'),
(169758, 12029, 'Nascidos de Novo [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/637693.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AtffH4xx5xLeeW3mXe3y7ubhFkN.jpg'),
(169759, 12029, 'Nascidos de Novo [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/637694.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ezRQH0a46cUhThHcyPLZ0soHDVN.jpg'),
(169760, 12029, 'Nascidos de Novo [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/637695.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pHuU5Ny3zeGYpLplPT5Ql5dkdlj.jpg'),
(169761, 12029, 'Nascidos de Novo [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/637696.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qgqHCh14lGGIwK2xqJGPSe6FV3K.jpg'),
(169762, 12029, 'Nascidos de Novo [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/637697.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3mn5FwYzZB1fVExNOvFb1uvyWZp.jpg'),
(169763, 12029, 'Nascidos de Novo [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/637698.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pUoVemHxTI3gXfzERHldHLbQN1.jpg'),
(169764, 12029, 'Nascidos de Novo [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/637699.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3E3z16jOZKNzG8Lxf8BL2eCCFqV.jpg'),
(169765, 12029, 'Nascidos de Novo [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/637700.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tEImrSF6SDP5AB26NASX0gukkQL.jpg'),
(169766, 12029, 'Nascidos de Novo [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/637701.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/srqfLiNZBU7K8gAR3XGBtPSxpkh.jpg'),
(169767, 12029, 'Nascidos de Novo [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/637702.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qMrpamF1KKol2qLME7kAFz891XD.jpg'),
(169768, 12029, 'Nascidos de Novo [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/637703.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sCN7xZwEFCm7WeIUlmBiH462KUt.jpg'),
(169769, 12029, 'Nascidos de Novo [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/637704.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fJSbajnPJUuVY8glkyP0ELxt55P.jpg'),
(169770, 12029, 'Nascidos de Novo [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/637705.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9kRUYSA1nlRhe3JrByCfXWpxobP.jpg'),
(169771, 12029, 'Nascidos de Novo [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/637706.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8QQplDBseiaihXPCpN2rxVPUdnq.jpg'),
(169772, 12029, 'Nascidos de Novo [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/637707.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yIa7Y81YMsGtH3oy6SpSgVIgQyF.jpg'),
(169773, 12029, 'Nascidos de Novo [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/637708.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jgmsfucznOp1sCIFPS5mo6bFBfj.jpg'),
(169774, 12029, 'Nascidos de Novo [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/637709.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9DTFmIgzSQKcPw8DazW4jZ0JfCE.jpg'),
(169775, 12029, 'Nascidos de Novo [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/637710.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xRcL0fCmkwzgOR5M567eehDIlBa.jpg'),
(169776, 12030, 'Nobody Knows [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637663.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/waIfemgrNsIKTJdsvmqcxPpo1s.jpg'),
(169777, 12030, 'Nobody Knows [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/637664.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iNNgEPnF1tx5aJeE3VJ4FiT1Cuk.jpg'),
(169778, 12030, 'Nobody Knows [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637665.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/93MXCdNubim26sxdDsHpgrk0wXz.jpg'),
(169779, 12030, 'Nobody Knows [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637666.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xXYHE8Hx9kQYXWREyb1GMR6HvrU.jpg'),
(169780, 12030, 'Nobody Knows [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/637667.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9Y9IbJiQRCQtv9TMAir9vFGkwx9.jpg'),
(169781, 12030, 'Nobody Knows [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/637668.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1BI3V61xIoYNrUgYQFb7tGwEr0o.jpg'),
(169782, 12030, 'Nobody Knows [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637669.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4dU0bCkb0POutGdSENNNVdJLNY2.jpg'),
(169783, 12030, 'Nobody Knows [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637670.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kEnBr1vEmKdf8Q3PUoUVsc7dWXy.jpg'),
(169784, 12030, 'Nobody Knows [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/637671.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3K5H4uuo6PTX4h7lGMuWyICxMd8.jpg'),
(169785, 12030, 'Nobody Knows [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/637672.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AmTgHbfkswr0RZrkg9qkm1juBBN.jpg'),
(169786, 12030, 'Nobody Knows [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/637673.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2i4OovA7rj3yX01eMIUXXrDmW50.jpg'),
(169787, 12030, 'Nobody Knows [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/637674.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pNiQGgeosoWO9Ujg5wY9LlPFAtX.jpg'),
(169788, 12030, 'Nobody Knows [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/637675.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gLjIOVfc0txZuZVLZLuKl9isAT.jpg'),
(169789, 12030, 'Nobody Knows [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/637676.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8ZYoqCOPQ91gAqAlNBGU1xGBcfb.jpg'),
(169790, 12030, 'Nobody Knows [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/637677.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/be7DUMGvbvPcwwyOJ5vPSgtknrB.jpg'),
(169791, 12030, 'Nobody Knows [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/637678.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/loTQ5og9VtI8LhUmYzZXqeCkZrx.jpg'),
(169792, 12031, 'Reis do Crime S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637660.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m12feLWBrpDBpP3sPpKoI9pRBUq.jpg'),
(169793, 12031, 'Reis do Crime S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/637661.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Ddr1pwmF1aTBco9ISHhOH7mH5W.jpg'),
(169794, 12031, 'Reis do Crime S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637662.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qJ380MVPJi2TtWnQyqLRchxlRjp.jpg'),
(169795, 12031, 'Reis do Crime S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/643662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/gxEdHGBqaM3kL35AmEAhbfwaE6n.jpg'),
(169796, 12032, 'Ruyi [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637640.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vSkkfWmgQXfl0nPv7XIxFi5F5rj.jpg'),
(169797, 12032, 'Ruyi [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/637641.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/caFy4yNZ86RKHqRpHTMBwDyrRCl.jpg'),
(169798, 12032, 'Ruyi [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637642.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ylShVUP27JZHpkPeIHHP4uGL4gZ.jpg'),
(169799, 12032, 'Ruyi [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637643.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rBb1WxN7keEW4sFrZynKFe56QpU.jpg'),
(169800, 12032, 'Ruyi [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/637644.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pqlmEdLtfuwiOypML6Max0vxhmG.jpg'),
(169801, 12032, 'Ruyi [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/637645.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tohJIEPdByhsMVMKgM92LRwM5Nt.jpg'),
(169802, 12032, 'Ruyi [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637646.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1QrodSs5dzvfOT7AstiQeRaklhL.jpg'),
(169803, 12032, 'Ruyi [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637647.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ypXtpIlTplpHMT1G7C9gOWsOOlS.jpg'),
(169804, 12032, 'Ruyi [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/637648.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9KuXJH1WXaGIFRlFaQ3XnwcEyza.jpg'),
(169805, 12032, 'Ruyi [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/637649.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3THQ41lAxb2JaKVyH8kq7KoBWU4.jpg'),
(169806, 12032, 'Ruyi [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/637650.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kTtWlscyKCBzS3q7LJg70DJPKBh.jpg'),
(169807, 12032, 'Ruyi [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/637651.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oKCPhcEPj6RFP0Qo6gwxh9H4AKl.jpg'),
(169808, 12032, 'Ruyi [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/637652.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AiH7tccrnizWFj3JZT96cq2zFWJ.jpg'),
(169809, 12032, 'Ruyi [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/637653.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/quHDsxUSv1GPYGllvG9YDzFSvmR.jpg'),
(169810, 12032, 'Ruyi [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/637654.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g4kJdcuU8MTwtcCAeVP7mfCk04Y.jpg'),
(169811, 12032, 'Ruyi [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/637655.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6McA9vVy6wo3GWdYFNVjDE4I0KJ.jpg'),
(169812, 12032, 'Ruyi [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/637656.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/edMB1oocaUQhv1VSsc00V39qlgK.jpg'),
(169813, 12032, 'Ruyi [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/637657.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8cQTO8zfRwbCmFYtKbNVrWkmQr8.jpg'),
(169814, 12032, 'Ruyi [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/637658.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yNtSeqKFakCQEj8odk69kwUcnvz.jpg'),
(169815, 12032, 'Ruyi [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/637659.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ym4IS2dF4V7EF30FZ21BBLaPAld.jpg'),
(169816, 12033, 'Sakli [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637630.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zMdEL3AT5D3UoqdvSm1RSH6YJNq.jpg'),
(169817, 12033, 'Sakli [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/637631.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aazHavTwmxgdy4B6i8NmFNOsGS1.jpg'),
(169818, 12033, 'Sakli [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637632.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hJb1eeL9HeOlRcdTnbPny2ms9at.jpg'),
(169819, 12033, 'Sakli [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637633.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tYQsaGFRGwq7CeYwNEjRZhhrdDs.jpg'),
(169820, 12033, 'Sakli [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/637634.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zBphydbsOT4Ece5LmWqhDA42pcY.jpg'),
(169821, 12033, 'Sakli [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/637635.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oNRqVhJMTXB8bPY70kVx8pyHIrl.jpg'),
(169822, 12033, 'Sakli [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637636.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qnv1dCvQxQlYUG03tWUt1oSpb6F.jpg'),
(169823, 12033, 'Sakli [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637637.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w521GzotIPZA9P6OwpSWw6ZFmbB.jpg'),
(169824, 12033, 'Sakli [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/637638.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/PwIm4eW9zS5JBUx6bqHlIe20if.jpg'),
(169825, 12033, 'Sakli [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/637639.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cERoOC2VDl5jPUAtWgLSDZoZNw3.jpg'),
(169826, 12034, 'The Game Towards Zero [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/637598.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rnXZI2qe74XD1b1CrtlWYETENPz.jpg'),
(169827, 12034, 'The Game Towards Zero [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/637599.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6dYImPbH78Xw8nrBWtoyQ4ZVmeA.jpg'),
(169828, 12034, 'The Game Towards Zero [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/637600.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tBTCrR0mKsIymswFbpzf0IBoBnX.jpg'),
(169829, 12034, 'The Game Towards Zero [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/637601.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A3RTcMNurCjWgW9DY8O322faR6O.jpg'),
(169830, 12034, 'The Game Towards Zero [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/637602.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7r16Ix3v1Qp1lE80XjETf8k2WsC.jpg'),
(169831, 12034, 'The Game Towards Zero [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/637603.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yekNKgooTUqNnNFY9E3TPingLl6.jpg'),
(169832, 12034, 'The Game Towards Zero [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/637604.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eJWYfGKEPw4STMJDP1OAs043J92.jpg'),
(169833, 12034, 'The Game Towards Zero [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/637605.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qVFPwSedOjE9vfdKuAqcYtAVCH5.jpg'),
(169834, 12034, 'The Game Towards Zero [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/637606.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7HzMKfJEmfFJzrNIT3nSJSUMPLn.jpg'),
(169835, 12034, 'The Game Towards Zero [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/637607.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lwrXb3GHFmaHbpgmbGDWyOLJv6r.jpg'),
(169836, 12034, 'The Game Towards Zero [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/637608.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wnIjHTiBsVOVHklmKNDsQX4MQRg.jpg'),
(169837, 12034, 'The Game Towards Zero [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/637609.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bBOxcB94VLZlpHuMul7KNuCGXZ1.jpg'),
(169838, 12034, 'The Game Towards Zero [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/637610.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Avxr4UeYMeZFSTPm3AWRBhIKGpM.jpg'),
(169839, 12034, 'The Game Towards Zero [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/637611.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zi6gSArXJGNzJqp6VHvThlT6Dr5.jpg'),
(169840, 12034, 'The Game Towards Zero [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/637613.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bLYW9tHZJB3JpEJgmPqDie4ULE1.jpg'),
(169841, 12034, 'The Game Towards Zero [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/637614.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qCoE53Oo4TeJLn3cYy4Vv0nK6P.jpg'),
(169842, 12034, 'The Game Towards Zero [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/637615.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4epQQzgIW7XW1CBnqOM7c3XSO0t.jpg'),
(169843, 12034, 'The Game Towards Zero [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/637616.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jK50DFtBE8L1g5ksB62iNNW4w44.jpg'),
(169844, 12034, 'The Game Towards Zero [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/637617.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rhdXmiqSImvzxDsr6GfSZfa1F5z.jpg'),
(169845, 12034, 'The Game Towards Zero [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/637618.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cpm5vYZhYGg5KwQevMSfvVSjuXa.jpg'),
(169846, 12034, 'The Game Towards Zero [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/637619.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kgHJrBIDaPxUBBVSTnRoFLa0c5P.jpg'),
(169847, 12034, 'The Game Towards Zero [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/637620.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/um2MrM1FdeapvTf30qLG55vlEmF.jpg'),
(169848, 12034, 'The Game Towards Zero [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/637621.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vBw3YHXCtJmK0Nk3K7wFFl9QcqJ.jpg'),
(169849, 12034, 'The Game Towards Zero [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/637622.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fTOTlqQIFAdtJnVckF69ktyPYdI.jpg'),
(169850, 12034, 'The Game Towards Zero [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/637623.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3tcZABzcUFM64mT16gsC7olwTNv.jpg'),
(169851, 12034, 'The Game Towards Zero [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/637624.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bzEQr5EvEolB0NevTfxrUrh33CL.jpg'),
(169852, 12034, 'The Game Towards Zero [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/637625.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zjOz4ox2Zu0vpnA648qpCPHT33u.jpg'),
(169853, 12034, 'The Game Towards Zero [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/637626.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iMpxjiTiTygWn0VXYbcofbc9yLz.jpg'),
(169854, 12034, 'The Game Towards Zero [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/637627.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pxBsnbw2mueHbwheAYmLq1uLjha.jpg'),
(169855, 12034, 'The Game Towards Zero [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/637628.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rOQurUfYr52NpicpbTM83HnsSPl.jpg'),
(169856, 12034, 'The Game Towards Zero [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/637629.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jQx9LDJ49URHPee65yIR6JZGgw0.jpg'),
(169857, 12035, 'Rainha Woo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/642314.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3GzsD3Cs2aeCPsCyqX9Q5RAWtg6.jpg'),
(169858, 12035, 'Rainha Woo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/642315.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/utqZ5UvSQKBmmHvSqEOMEQXNAkF.jpg'),
(169859, 12035, 'Rainha Woo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/642316.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e0HbZv2G7AAXf1fagPYeNisLnuy.jpg'),
(169860, 12035, 'Rainha Woo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/642317.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hItHS9R8Cn9rL1wr6evELVLBmJq.jpg'),
(169861, 12035, 'Rainha Woo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/642318.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cmrV0tVuU1uQG0AsZa16L4wDqpA.jpg'),
(169862, 12035, 'Rainha Woo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/642319.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h8NgUEIvxO5aIMZbovbAUgUxpRd.jpg'),
(169863, 12035, 'Rainha Woo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/642320.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fviQfsLwLNekNAG6QStNbdKKBh0.jpg'),
(169864, 12035, 'Rainha Woo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/642321.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9e7Os6gYkqyrNalfNFBYBDTFZvL.jpg'),
(169865, 12036, 'Who Is She [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/642312.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t2bOhqdmrdHy5fvMGxcJHgNkFSN.jpg'),
(169866, 12036, 'Who Is She [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/642313.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sGkHPzE6XVUt2ntbCRnIIiKBiqz.jpg'),
(169867, 12036, 'Who Is She [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/667147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9JzL5NG2yXHOEkFY95vsboWhiy.jpg'),
(169868, 12036, 'Who Is She [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/667148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9JzL5NG2yXHOEkFY95vsboWhiy.jpg'),
(169869, 12036, 'Who Is She [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/667149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9JzL5NG2yXHOEkFY95vsboWhiy.jpg'),
(169870, 12036, 'Who Is She [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/667150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9JzL5NG2yXHOEkFY95vsboWhiy.jpg'),
(169871, 12036, 'Who Is She [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/667151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9JzL5NG2yXHOEkFY95vsboWhiy.jpg'),
(169872, 12036, 'Who Is She [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/667152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9JzL5NG2yXHOEkFY95vsboWhiy.jpg'),
(169873, 12036, 'Who Is She [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/667153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9JzL5NG2yXHOEkFY95vsboWhiy.jpg'),
(169874, 12036, 'Who Is She [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/667154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9JzL5NG2yXHOEkFY95vsboWhiy.jpg'),
(169875, 12036, 'Who Is She [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/674576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9JzL5NG2yXHOEkFY95vsboWhiy.jpg'),
(169876, 12036, 'Who Is She [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/674577.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9JzL5NG2yXHOEkFY95vsboWhiy.jpg'),
(169877, 12037, 'A Batalha dos Biscoitos Natalinos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/641608.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gdHCXaEKOkqK65EYxlYWcPvXE4z.jpg'),
(169878, 12037, 'A Batalha dos Biscoitos Natalinos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/641609.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dnjXecU0XxAsxjmlOQkVEYMl4PY.jpg'),
(169879, 12037, 'A Batalha dos Biscoitos Natalinos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/641610.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/srjTYplVXoaa8DvUYzowF0amu7X.jpg'),
(169880, 12037, 'A Batalha dos Biscoitos Natalinos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/641611.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mhnyBxSpp0TM5sSWlFXwq1EODuS.jpg'),
(169881, 12038, 'A Batalha dos Biscoitos Natalinos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/641612.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/htTCLBSC3EGZqJZ0obrbvjiFEd.jpg'),
(169882, 12038, 'A Batalha dos Biscoitos Natalinos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/641613.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u1VxUQuyGg3ZMdWneF3SVF487dD.jpg'),
(169883, 12038, 'A Batalha dos Biscoitos Natalinos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/641614.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gkYzCewYwDW3dXkL3R5VmmBTEsn.jpg'),
(169884, 12038, 'A Batalha dos Biscoitos Natalinos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/641615.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/urHAL65LsxksY7LKeZRyKU5wC5v.jpg'),
(169885, 12039, 'Cidade das Esmeraldas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/641598.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lj8pQDOm1VCRDUNgbhD1FODn0vt.jpg'),
(169886, 12039, 'Cidade das Esmeraldas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/641599.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w6aowD8sIvpCgF3hUYZPaZS5zKv.jpg'),
(169887, 12039, 'Cidade das Esmeraldas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/641600.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fwFWmNBRNi3bYhDHrwNiaoj3jte.jpg'),
(169888, 12039, 'Cidade das Esmeraldas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/641601.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hhZG6EqiFSzcLvc1MYx08zc4YHK.jpg'),
(169889, 12039, 'Cidade das Esmeraldas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/641602.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z0TC4mzuyhTNKEguxa7HKgTtElC.jpg'),
(169890, 12039, 'Cidade das Esmeraldas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/641603.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/39oYwxDSKDA9IbbEhjB1jezcF6J.jpg'),
(169891, 12039, 'Cidade das Esmeraldas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/641604.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lMdeYDpKdyOVxGMTfugmo4NEPNf.jpg'),
(169892, 12039, 'Cidade das Esmeraldas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/641605.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qEP7PvcsvDmHCwEUb9cJIFHTvfp.jpg'),
(169893, 12039, 'Cidade das Esmeraldas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/641606.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1KE2T7CJWTtqerheOPa1Yuosmda.jpg'),
(169894, 12039, 'Cidade das Esmeraldas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/641607.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a93wKRFOjAXbFylZhcHkkGkKAcr.jpg'),
(169895, 12040, 'Maravilhas Sagradas com Dennis Quaid S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/641594.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mSno3P2g59jVZP34urrHw7aHW32.jpg'),
(169896, 12040, 'Maravilhas Sagradas com Dennis Quaid S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/641595.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s59fydANeyY23B2q5gwNAB1GjfK.jpg'),
(169897, 12040, 'Maravilhas Sagradas com Dennis Quaid S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/641596.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4zM3SbRq88uVvekTUN5wrfrDJIp.jpg'),
(169898, 12040, 'Maravilhas Sagradas com Dennis Quaid S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/641597.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/igndq0V6KsxtWrXFSnpp6gULoze.jpg'),
(169899, 12040, 'Maravilhas Sagradas com Dennis Quaid S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/658993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hX041djMMaOHYELQgE6upC5QpKJ.jpg'),
(169900, 12040, 'Maravilhas Sagradas com Dennis Quaid S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/660275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hX041djMMaOHYELQgE6upC5QpKJ.jpg'),
(169901, 12040, 'Maravilhas Sagradas com Dennis Quaid S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/660276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hX041djMMaOHYELQgE6upC5QpKJ.jpg'),
(169902, 12040, 'Maravilhas Sagradas com Dennis Quaid S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/660277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hX041djMMaOHYELQgE6upC5QpKJ.jpg'),
(169903, 12041, 'Oficina TexMex S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/641584.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3n1uC6kAMR0EjX253sUxGUoigHb.jpg'),
(169904, 12041, 'Oficina TexMex S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/641585.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5GfS1KPIPkALQJ38cuAN1A1K3Hh.jpg'),
(169905, 12041, 'Oficina TexMex S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/641586.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/81e8UOmJ5BJYkjluEmEyU18PfGr.jpg'),
(169906, 12041, 'Oficina TexMex S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/641587.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hZutuHNNyRzhxYAEZCAqYJCBZjx.jpg'),
(169907, 12041, 'Oficina TexMex S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/641588.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pgWYmquhhyQhSDSO5aizGmMBWdd.jpg'),
(169908, 12041, 'Oficina TexMex S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/641589.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/avVcixysvojrNlHyYPlZx5ngIEY.jpg'),
(169909, 12041, 'Oficina TexMex S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/641590.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zQ2yQJvvUFBpqTWRK3KS0ktzPpc.jpg'),
(169910, 12041, 'Oficina TexMex S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/641591.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4V8XY2BVi7NCerfEylsbujAa1Ad.jpg'),
(169911, 12041, 'Oficina TexMex S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/641592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qTH66eJeGvnGd61cF6dZ5wQs3Vh.jpg'),
(169912, 12041, 'Oficina TexMex S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/641593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qTH66eJeGvnGd61cF6dZ5wQs3Vh.jpg'),
(169913, 12042, 'Arquivos Secretos do Vaticano O Papa e o Demonio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657026.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtnrXjiHZ1ZkH6oxyDRr36UFvUo.jpg'),
(169914, 12042, 'Arquivos Secretos do Vaticano O Papa e o Demonio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657027.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtnrXjiHZ1ZkH6oxyDRr36UFvUo.jpg'),
(169915, 12042, 'Arquivos Secretos do Vaticano O Papa e o Demonio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtnrXjiHZ1ZkH6oxyDRr36UFvUo.jpg'),
(169916, 12042, 'Arquivos Secretos do Vaticano O Papa e o Demonio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/657029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/xtnrXjiHZ1ZkH6oxyDRr36UFvUo.jpg'),
(169917, 12043, 'Ben Hur S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657024.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mGYPEYJwi7OeJ52nClWzyAXVIHD.jpg'),
(169918, 12043, 'Ben Hur S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657025.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hvhMvvQGpwD1nLbWvMyqaBlkLIE.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(169919, 12044, 'Desenhos Biblicos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169920, 12044, 'Desenhos Biblicos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169921, 12044, 'Desenhos Biblicos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169922, 12044, 'Desenhos Biblicos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169923, 12044, 'Desenhos Biblicos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169924, 12044, 'Desenhos Biblicos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169925, 12044, 'Desenhos Biblicos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169926, 12044, 'Desenhos Biblicos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/656995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169927, 12044, 'Desenhos Biblicos S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/656996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169928, 12044, 'Desenhos Biblicos S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/656997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169929, 12044, 'Desenhos Biblicos S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/656998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169930, 12044, 'Desenhos Biblicos S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/656999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169931, 12045, 'Desenhos Biblicos S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169932, 12045, 'Desenhos Biblicos S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169933, 12045, 'Desenhos Biblicos S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169934, 12045, 'Desenhos Biblicos S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/657003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169935, 12045, 'Desenhos Biblicos S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/657004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169936, 12045, 'Desenhos Biblicos S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/657005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169937, 12045, 'Desenhos Biblicos S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/657006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169938, 12045, 'Desenhos Biblicos S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/657007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169939, 12045, 'Desenhos Biblicos S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/657008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169940, 12045, 'Desenhos Biblicos S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/657009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169941, 12045, 'Desenhos Biblicos S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/657010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169942, 12045, 'Desenhos Biblicos S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/657011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169943, 12045, 'Desenhos Biblicos S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/657012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169944, 12045, 'Desenhos Biblicos S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/657013.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169945, 12045, 'Desenhos Biblicos S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/657014.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169946, 12045, 'Desenhos Biblicos S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/657015.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169947, 12045, 'Desenhos Biblicos S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/657016.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169948, 12045, 'Desenhos Biblicos S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/657017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169949, 12045, 'Desenhos Biblicos S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/657018.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169950, 12045, 'Desenhos Biblicos S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/657019.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169951, 12045, 'Desenhos Biblicos S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/657020.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169952, 12045, 'Desenhos Biblicos S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/657021.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169953, 12045, 'Desenhos Biblicos S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/657022.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169954, 12045, 'Desenhos Biblicos S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/657023.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ff5PImQk9ztt042EqammaG5rKme.jpg'),
(169955, 12046, 'Deuses Egipcios S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wyD0xL4xejiKon8HsxWWNU25jeu.jpg'),
(169956, 12046, 'Deuses Egipcios S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wyD0xL4xejiKon8HsxWWNU25jeu.jpg'),
(169957, 12046, 'Deuses Egipcios S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/wyD0xL4xejiKon8HsxWWNU25jeu.jpg'),
(169958, 12047, 'O Canto do Passaro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656380.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uQlssgkqnXwjYlpUo1tmavnb7pn.jpg'),
(169959, 12047, 'O Canto do Passaro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656381.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4wTZLK4Ixxl0f28jFe6Ul0ijwL9.jpg'),
(169960, 12047, 'O Canto do Passaro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656382.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b3ez4sVLP7E7jVrPTn355O8yej4.jpg'),
(169961, 12047, 'O Canto do Passaro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656383.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/36sZvJhehuUN1rekpwdTpF3HrpC.jpg'),
(169962, 12047, 'O Canto do Passaro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656384.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1X0Wpa5af5liUppcA2eQ8ClbNmy.jpg'),
(169963, 12047, 'O Canto do Passaro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656385.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rpGNE28WRKQpPmj7dMQRdGt3fLa.jpg'),
(169964, 12047, 'O Canto do Passaro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656386.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1LCkIbdmVWTUoh2geLRIBBg0MdC.jpg'),
(169965, 12047, 'O Canto do Passaro S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/656387.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nxQ5BlsTb620rcHLiZ4CCKHBOQ0.jpg'),
(169966, 12047, 'O Canto do Passaro S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/656388.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fUw18b7f1HS8dvjD0zdke49Pt08.jpg'),
(169967, 12047, 'O Canto do Passaro S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/656389.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aIs7CPYodgLkEIOh48RmEOHtJuZ.jpg'),
(169968, 12047, 'O Canto do Passaro S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/656390.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ibeB66JFbaybc7B32gs2QP8ujHb.jpg'),
(169969, 12047, 'O Canto do Passaro S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/656391.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vTEVh0lQLoJfLeKFycHIebly9ue.jpg'),
(169970, 12047, 'O Canto do Passaro S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/656392.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3alkrjiWPKbWc9RogR3rEMcArMf.jpg'),
(169971, 12047, 'O Canto do Passaro S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/656393.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gnujx1zUWKmjrjtnhsZrLYFlKUP.jpg'),
(169972, 12047, 'O Canto do Passaro S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/656394.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8kOYZ0BhkxkzIid1I2Xg2TJrNEU.jpg'),
(169973, 12047, 'O Canto do Passaro S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/656395.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Xnk3Gi6dDgPhdZPRdfQr7AjedY.jpg'),
(169974, 12047, 'O Canto do Passaro S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/656396.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4yqbNd4aqqvtCaxMYb3Ac95JfvD.jpg'),
(169975, 12047, 'O Canto do Passaro S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/656397.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bAvsiDMPqyG7pOT0Oyux4bggVqx.jpg'),
(169976, 12047, 'O Canto do Passaro S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/656398.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fjDSUkfAY05g34wwBxJnzuZ0Kno.jpg'),
(169977, 12047, 'O Canto do Passaro S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/656399.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n0a2dHaNEjg926sCU0QsWjQKp3I.jpg'),
(169978, 12047, 'O Canto do Passaro S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/656400.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kmEgvGQX2Zdjq9DExKfTC8Jftp0.jpg'),
(169979, 12047, 'O Canto do Passaro S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/656401.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yzZtVwcSldj2qFZaQTzDvtYF2fm.jpg'),
(169980, 12047, 'O Canto do Passaro S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/656402.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/idfiIXqekh6ifXQpDUG6TcVQAca.jpg'),
(169981, 12047, 'O Canto do Passaro S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/656403.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k64MKt7BbUO2kzQoJTBVR9vkkbz.jpg'),
(169982, 12047, 'O Canto do Passaro S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/656404.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pmGNIBHRhucln3Ab1mkoacT9g9P.jpg'),
(169983, 12047, 'O Canto do Passaro S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/656405.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3GA771ydye499r4oLmYbvM9FAVE.jpg'),
(169984, 12047, 'O Canto do Passaro S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/656406.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mMmE3cuXfL1lUN1n2lGmY2brB4M.jpg'),
(169985, 12047, 'O Canto do Passaro S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/656407.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/npxwXIiabvJ2bv5OzkDaSMzPAQM.jpg'),
(169986, 12047, 'O Canto do Passaro S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/656408.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rzJfz8yuMQyfIGWUNQHrSdbViiJ.jpg'),
(169987, 12047, 'O Canto do Passaro S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/656409.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g2pw8Y7PKRRBPB3cPh3c7oZXPQC.jpg'),
(169988, 12047, 'O Canto do Passaro S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/656410.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/743rIS7VjnnaYjfxQ7L3JVEflVV.jpg'),
(169989, 12047, 'O Canto do Passaro S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/656411.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/55SuzWxokDqXvridZGukuL5AaGu.jpg'),
(169990, 12047, 'O Canto do Passaro S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/656412.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mJYuHR6d05xReulMgF3dIvgshXQ.jpg'),
(169991, 12047, 'O Canto do Passaro S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/656413.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1lk0PhTtk3di8A3qrYL3bPlodwX.jpg'),
(169992, 12047, 'O Canto do Passaro S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/656414.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kgzMyJ1FaRVlEmDqKQMdvTBR3vw.jpg'),
(169993, 12047, 'O Canto do Passaro S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/656415.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pFYNVumB481imG2EIZqMqLpLZ3Y.jpg'),
(169994, 12047, 'O Canto do Passaro S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/656416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(169995, 12047, 'O Canto do Passaro S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/656417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(169996, 12047, 'O Canto do Passaro S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/656418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(169997, 12047, 'O Canto do Passaro S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/656419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(169998, 12047, 'O Canto do Passaro S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/656420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(169999, 12047, 'O Canto do Passaro S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/656421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170000, 12047, 'O Canto do Passaro S01 E43', 'http://sinalprivado.info:80/series/1533784/1533784/656422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170001, 12047, 'O Canto do Passaro S01 E44', 'http://sinalprivado.info:80/series/1533784/1533784/656423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170002, 12047, 'O Canto do Passaro S01 E45', 'http://sinalprivado.info:80/series/1533784/1533784/656424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170003, 12047, 'O Canto do Passaro S01 E46', 'http://sinalprivado.info:80/series/1533784/1533784/656425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170004, 12047, 'O Canto do Passaro S01 E47', 'http://sinalprivado.info:80/series/1533784/1533784/656426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170005, 12047, 'O Canto do Passaro S01 E48', 'http://sinalprivado.info:80/series/1533784/1533784/656427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170006, 12047, 'O Canto do Passaro S01 E49', 'http://sinalprivado.info:80/series/1533784/1533784/656428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170007, 12047, 'O Canto do Passaro S01 E50', 'http://sinalprivado.info:80/series/1533784/1533784/656429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170008, 12047, 'O Canto do Passaro S01 E51', 'http://sinalprivado.info:80/series/1533784/1533784/656430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170009, 12047, 'O Canto do Passaro S01 E52', 'http://sinalprivado.info:80/series/1533784/1533784/656431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170010, 12047, 'O Canto do Passaro S01 E53', 'http://sinalprivado.info:80/series/1533784/1533784/656432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170011, 12047, 'O Canto do Passaro S01 E54', 'http://sinalprivado.info:80/series/1533784/1533784/656433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170012, 12047, 'O Canto do Passaro S01 E55', 'http://sinalprivado.info:80/series/1533784/1533784/656434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170013, 12047, 'O Canto do Passaro S01 E56', 'http://sinalprivado.info:80/series/1533784/1533784/656435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170014, 12047, 'O Canto do Passaro S01 E57', 'http://sinalprivado.info:80/series/1533784/1533784/656436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170015, 12047, 'O Canto do Passaro S01 E58', 'http://sinalprivado.info:80/series/1533784/1533784/656437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170016, 12047, 'O Canto do Passaro S01 E59', 'http://sinalprivado.info:80/series/1533784/1533784/656438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170017, 12047, 'O Canto do Passaro S01 E60', 'http://sinalprivado.info:80/series/1533784/1533784/656439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170018, 12047, 'O Canto do Passaro S01 E61', 'http://sinalprivado.info:80/series/1533784/1533784/656440.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170019, 12047, 'O Canto do Passaro S01 E62', 'http://sinalprivado.info:80/series/1533784/1533784/656441.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170020, 12047, 'O Canto do Passaro S01 E63', 'http://sinalprivado.info:80/series/1533784/1533784/656442.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170021, 12047, 'O Canto do Passaro S01 E64', 'http://sinalprivado.info:80/series/1533784/1533784/656443.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170022, 12047, 'O Canto do Passaro S01 E65', 'http://sinalprivado.info:80/series/1533784/1533784/656444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170023, 12047, 'O Canto do Passaro S01 E66', 'http://sinalprivado.info:80/series/1533784/1533784/656445.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170024, 12047, 'O Canto do Passaro S01 E67', 'http://sinalprivado.info:80/series/1533784/1533784/656446.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170025, 12047, 'O Canto do Passaro S01 E68', 'http://sinalprivado.info:80/series/1533784/1533784/656447.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170026, 12047, 'O Canto do Passaro S01 E69', 'http://sinalprivado.info:80/series/1533784/1533784/656448.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170027, 12047, 'O Canto do Passaro S01 E70', 'http://sinalprivado.info:80/series/1533784/1533784/656449.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170028, 12047, 'O Canto do Passaro S01 E71', 'http://sinalprivado.info:80/series/1533784/1533784/656450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170029, 12047, 'O Canto do Passaro S01 E72', 'http://sinalprivado.info:80/series/1533784/1533784/656451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170030, 12047, 'O Canto do Passaro S01 E73', 'http://sinalprivado.info:80/series/1533784/1533784/656452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170031, 12047, 'O Canto do Passaro S01 E74', 'http://sinalprivado.info:80/series/1533784/1533784/656453.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170032, 12047, 'O Canto do Passaro S01 E75', 'http://sinalprivado.info:80/series/1533784/1533784/656454.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170033, 12047, 'O Canto do Passaro S01 E76', 'http://sinalprivado.info:80/series/1533784/1533784/656455.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170034, 12047, 'O Canto do Passaro S01 E77', 'http://sinalprivado.info:80/series/1533784/1533784/656456.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170035, 12047, 'O Canto do Passaro S01 E78', 'http://sinalprivado.info:80/series/1533784/1533784/656457.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170036, 12047, 'O Canto do Passaro S01 E79', 'http://sinalprivado.info:80/series/1533784/1533784/656458.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170037, 12047, 'O Canto do Passaro S01 E80', 'http://sinalprivado.info:80/series/1533784/1533784/656459.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170038, 12047, 'O Canto do Passaro S01 E81', 'http://sinalprivado.info:80/series/1533784/1533784/656460.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170039, 12047, 'O Canto do Passaro S01 E82', 'http://sinalprivado.info:80/series/1533784/1533784/656461.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170040, 12047, 'O Canto do Passaro S01 E83', 'http://sinalprivado.info:80/series/1533784/1533784/656462.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170041, 12047, 'O Canto do Passaro S01 E84', 'http://sinalprivado.info:80/series/1533784/1533784/656463.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170042, 12047, 'O Canto do Passaro S01 E85', 'http://sinalprivado.info:80/series/1533784/1533784/656464.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170043, 12047, 'O Canto do Passaro S01 E86', 'http://sinalprivado.info:80/series/1533784/1533784/656465.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170044, 12047, 'O Canto do Passaro S01 E87', 'http://sinalprivado.info:80/series/1533784/1533784/656466.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170045, 12047, 'O Canto do Passaro S01 E88', 'http://sinalprivado.info:80/series/1533784/1533784/656467.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170046, 12047, 'O Canto do Passaro S01 E89', 'http://sinalprivado.info:80/series/1533784/1533784/656468.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170047, 12047, 'O Canto do Passaro S01 E90', 'http://sinalprivado.info:80/series/1533784/1533784/656469.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170048, 12047, 'O Canto do Passaro S01 E91', 'http://sinalprivado.info:80/series/1533784/1533784/656470.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170049, 12047, 'O Canto do Passaro S01 E92', 'http://sinalprivado.info:80/series/1533784/1533784/656471.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170050, 12047, 'O Canto do Passaro S01 E93', 'http://sinalprivado.info:80/series/1533784/1533784/656472.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170051, 12047, 'O Canto do Passaro S01 E94', 'http://sinalprivado.info:80/series/1533784/1533784/656473.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170052, 12047, 'O Canto do Passaro S01 E95', 'http://sinalprivado.info:80/series/1533784/1533784/656474.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170053, 12047, 'O Canto do Passaro S01 E96', 'http://sinalprivado.info:80/series/1533784/1533784/656475.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170054, 12047, 'O Canto do Passaro S01 E97', 'http://sinalprivado.info:80/series/1533784/1533784/656476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170055, 12047, 'O Canto do Passaro S01 E98', 'http://sinalprivado.info:80/series/1533784/1533784/656477.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170056, 12047, 'O Canto do Passaro S01 E99', 'http://sinalprivado.info:80/series/1533784/1533784/656478.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170057, 12047, 'O Canto do Passaro S01 E100', 'http://sinalprivado.info:80/series/1533784/1533784/656479.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170058, 12047, 'O Canto do Passaro S01 E101', 'http://sinalprivado.info:80/series/1533784/1533784/656480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170059, 12047, 'O Canto do Passaro S01 E102', 'http://sinalprivado.info:80/series/1533784/1533784/656481.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170060, 12047, 'O Canto do Passaro S01 E103', 'http://sinalprivado.info:80/series/1533784/1533784/656482.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170061, 12047, 'O Canto do Passaro S01 E104', 'http://sinalprivado.info:80/series/1533784/1533784/656483.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170062, 12047, 'O Canto do Passaro S01 E105', 'http://sinalprivado.info:80/series/1533784/1533784/656484.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170063, 12047, 'O Canto do Passaro S01 E106', 'http://sinalprivado.info:80/series/1533784/1533784/656485.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170064, 12047, 'O Canto do Passaro S01 E107', 'http://sinalprivado.info:80/series/1533784/1533784/656486.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170065, 12047, 'O Canto do Passaro S01 E108', 'http://sinalprivado.info:80/series/1533784/1533784/656487.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170066, 12047, 'O Canto do Passaro S01 E109', 'http://sinalprivado.info:80/series/1533784/1533784/656488.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170067, 12047, 'O Canto do Passaro S01 E110', 'http://sinalprivado.info:80/series/1533784/1533784/656489.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170068, 12047, 'O Canto do Passaro S01 E111', 'http://sinalprivado.info:80/series/1533784/1533784/656490.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170069, 12047, 'O Canto do Passaro S01 E112', 'http://sinalprivado.info:80/series/1533784/1533784/656491.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170070, 12047, 'O Canto do Passaro S01 E113', 'http://sinalprivado.info:80/series/1533784/1533784/656492.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170071, 12047, 'O Canto do Passaro S01 E114', 'http://sinalprivado.info:80/series/1533784/1533784/656493.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170072, 12047, 'O Canto do Passaro S01 E115', 'http://sinalprivado.info:80/series/1533784/1533784/656494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170073, 12047, 'O Canto do Passaro S01 E116', 'http://sinalprivado.info:80/series/1533784/1533784/656495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170074, 12047, 'O Canto do Passaro S01 E117', 'http://sinalprivado.info:80/series/1533784/1533784/656496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170075, 12047, 'O Canto do Passaro S01 E118', 'http://sinalprivado.info:80/series/1533784/1533784/656497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170076, 12048, 'O Canto do Passaro S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/830738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170077, 12048, 'O Canto do Passaro S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/830739.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170078, 12048, 'O Canto do Passaro S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/830740.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170079, 12048, 'O Canto do Passaro S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/830741.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170080, 12048, 'O Canto do Passaro S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/830742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170081, 12048, 'O Canto do Passaro S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/830743.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170082, 12048, 'O Canto do Passaro S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/830744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170083, 12048, 'O Canto do Passaro S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/830745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170084, 12048, 'O Canto do Passaro S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/830746.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170085, 12048, 'O Canto do Passaro S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/830747.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170086, 12048, 'O Canto do Passaro S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/830748.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170087, 12048, 'O Canto do Passaro S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/830749.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170088, 12048, 'O Canto do Passaro S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/830750.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170089, 12048, 'O Canto do Passaro S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/830751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170090, 12048, 'O Canto do Passaro S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/830752.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170091, 12048, 'O Canto do Passaro S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/830753.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170092, 12048, 'O Canto do Passaro S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/830754.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170093, 12048, 'O Canto do Passaro S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/830755.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170094, 12048, 'O Canto do Passaro S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/830756.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170095, 12048, 'O Canto do Passaro S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/830757.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170096, 12048, 'O Canto do Passaro S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/830758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170097, 12048, 'O Canto do Passaro S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/830759.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170098, 12048, 'O Canto do Passaro S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/830760.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170099, 12048, 'O Canto do Passaro S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/830761.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170100, 12048, 'O Canto do Passaro S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/830762.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170101, 12048, 'O Canto do Passaro S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/830763.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170102, 12048, 'O Canto do Passaro S02 E27', 'http://sinalprivado.info:80/series/1533784/1533784/830764.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170103, 12048, 'O Canto do Passaro S02 E28', 'http://sinalprivado.info:80/series/1533784/1533784/830765.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170104, 12048, 'O Canto do Passaro S02 E29', 'http://sinalprivado.info:80/series/1533784/1533784/830766.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170105, 12048, 'O Canto do Passaro S02 E30', 'http://sinalprivado.info:80/series/1533784/1533784/830767.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170106, 12048, 'O Canto do Passaro S02 E31', 'http://sinalprivado.info:80/series/1533784/1533784/830768.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170107, 12048, 'O Canto do Passaro S02 E32', 'http://sinalprivado.info:80/series/1533784/1533784/830769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170108, 12048, 'O Canto do Passaro S02 E33', 'http://sinalprivado.info:80/series/1533784/1533784/830770.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170109, 12048, 'O Canto do Passaro S02 E34', 'http://sinalprivado.info:80/series/1533784/1533784/830771.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170110, 12048, 'O Canto do Passaro S02 E35', 'http://sinalprivado.info:80/series/1533784/1533784/830772.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170111, 12048, 'O Canto do Passaro S02 E36', 'http://sinalprivado.info:80/series/1533784/1533784/830773.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170112, 12048, 'O Canto do Passaro S02 E37', 'http://sinalprivado.info:80/series/1533784/1533784/830774.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170113, 12048, 'O Canto do Passaro S02 E38', 'http://sinalprivado.info:80/series/1533784/1533784/830775.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170114, 12048, 'O Canto do Passaro S02 E39', 'http://sinalprivado.info:80/series/1533784/1533784/830776.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170115, 12048, 'O Canto do Passaro S02 E40', 'http://sinalprivado.info:80/series/1533784/1533784/830777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170116, 12048, 'O Canto do Passaro S02 E41', 'http://sinalprivado.info:80/series/1533784/1533784/830778.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170117, 12048, 'O Canto do Passaro S02 E42', 'http://sinalprivado.info:80/series/1533784/1533784/830779.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170118, 12048, 'O Canto do Passaro S02 E43', 'http://sinalprivado.info:80/series/1533784/1533784/830780.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170119, 12048, 'O Canto do Passaro S02 E44', 'http://sinalprivado.info:80/series/1533784/1533784/830781.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170120, 12048, 'O Canto do Passaro S02 E45', 'http://sinalprivado.info:80/series/1533784/1533784/830782.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170121, 12048, 'O Canto do Passaro S02 E46', 'http://sinalprivado.info:80/series/1533784/1533784/830783.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170122, 12048, 'O Canto do Passaro S02 E47', 'http://sinalprivado.info:80/series/1533784/1533784/830784.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170123, 12048, 'O Canto do Passaro S02 E48', 'http://sinalprivado.info:80/series/1533784/1533784/830785.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170124, 12048, 'O Canto do Passaro S02 E49', 'http://sinalprivado.info:80/series/1533784/1533784/830786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170125, 12048, 'O Canto do Passaro S02 E50', 'http://sinalprivado.info:80/series/1533784/1533784/830787.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170126, 12048, 'O Canto do Passaro S02 E51', 'http://sinalprivado.info:80/series/1533784/1533784/830788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170127, 12048, 'O Canto do Passaro S02 E52', 'http://sinalprivado.info:80/series/1533784/1533784/830789.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170128, 12048, 'O Canto do Passaro S02 E53', 'http://sinalprivado.info:80/series/1533784/1533784/830790.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170129, 12048, 'O Canto do Passaro S02 E54', 'http://sinalprivado.info:80/series/1533784/1533784/830791.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170130, 12048, 'O Canto do Passaro S02 E55', 'http://sinalprivado.info:80/series/1533784/1533784/830792.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170131, 12048, 'O Canto do Passaro S02 E56', 'http://sinalprivado.info:80/series/1533784/1533784/830793.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170132, 12048, 'O Canto do Passaro S02 E57', 'http://sinalprivado.info:80/series/1533784/1533784/830794.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170133, 12048, 'O Canto do Passaro S02 E58', 'http://sinalprivado.info:80/series/1533784/1533784/830795.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170134, 12048, 'O Canto do Passaro S02 E59', 'http://sinalprivado.info:80/series/1533784/1533784/830796.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170135, 12048, 'O Canto do Passaro S02 E60', 'http://sinalprivado.info:80/series/1533784/1533784/830797.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170136, 12048, 'O Canto do Passaro S02 E61', 'http://sinalprivado.info:80/series/1533784/1533784/830798.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170137, 12048, 'O Canto do Passaro S02 E62', 'http://sinalprivado.info:80/series/1533784/1533784/830799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170138, 12048, 'O Canto do Passaro S02 E63', 'http://sinalprivado.info:80/series/1533784/1533784/830800.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170139, 12048, 'O Canto do Passaro S02 E64', 'http://sinalprivado.info:80/series/1533784/1533784/830801.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170140, 12048, 'O Canto do Passaro S02 E65', 'http://sinalprivado.info:80/series/1533784/1533784/830802.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170141, 12048, 'O Canto do Passaro S02 E66', 'http://sinalprivado.info:80/series/1533784/1533784/830803.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170142, 12048, 'O Canto do Passaro S02 E67', 'http://sinalprivado.info:80/series/1533784/1533784/830804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170143, 12048, 'O Canto do Passaro S02 E68', 'http://sinalprivado.info:80/series/1533784/1533784/830805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170144, 12048, 'O Canto do Passaro S02 E69', 'http://sinalprivado.info:80/series/1533784/1533784/830806.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170145, 12048, 'O Canto do Passaro S02 E70', 'http://sinalprivado.info:80/series/1533784/1533784/830807.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170146, 12048, 'O Canto do Passaro S02 E71', 'http://sinalprivado.info:80/series/1533784/1533784/830808.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170147, 12048, 'O Canto do Passaro S02 E72', 'http://sinalprivado.info:80/series/1533784/1533784/830809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170148, 12048, 'O Canto do Passaro S02 E73', 'http://sinalprivado.info:80/series/1533784/1533784/830810.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170149, 12048, 'O Canto do Passaro S02 E74', 'http://sinalprivado.info:80/series/1533784/1533784/830811.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170150, 12048, 'O Canto do Passaro S02 E75', 'http://sinalprivado.info:80/series/1533784/1533784/830812.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170151, 12048, 'O Canto do Passaro S02 E76', 'http://sinalprivado.info:80/series/1533784/1533784/830813.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170152, 12048, 'O Canto do Passaro S02 E77', 'http://sinalprivado.info:80/series/1533784/1533784/830814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170153, 12048, 'O Canto do Passaro S02 E78', 'http://sinalprivado.info:80/series/1533784/1533784/830815.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170154, 12048, 'O Canto do Passaro S02 E79', 'http://sinalprivado.info:80/series/1533784/1533784/830816.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170155, 12048, 'O Canto do Passaro S02 E80', 'http://sinalprivado.info:80/series/1533784/1533784/830817.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170156, 12048, 'O Canto do Passaro S02 E81', 'http://sinalprivado.info:80/series/1533784/1533784/830818.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170157, 12048, 'O Canto do Passaro S02 E82', 'http://sinalprivado.info:80/series/1533784/1533784/830819.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170158, 12048, 'O Canto do Passaro S02 E83', 'http://sinalprivado.info:80/series/1533784/1533784/830820.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170159, 12048, 'O Canto do Passaro S02 E84', 'http://sinalprivado.info:80/series/1533784/1533784/830821.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170160, 12048, 'O Canto do Passaro S02 E85', 'http://sinalprivado.info:80/series/1533784/1533784/830822.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170161, 12048, 'O Canto do Passaro S02 E86', 'http://sinalprivado.info:80/series/1533784/1533784/830823.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170162, 12048, 'O Canto do Passaro S02 E87', 'http://sinalprivado.info:80/series/1533784/1533784/830824.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170163, 12048, 'O Canto do Passaro S02 E88', 'http://sinalprivado.info:80/series/1533784/1533784/830825.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170164, 12048, 'O Canto do Passaro S02 E89', 'http://sinalprivado.info:80/series/1533784/1533784/830826.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170165, 12048, 'O Canto do Passaro S02 E90', 'http://sinalprivado.info:80/series/1533784/1533784/830827.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170166, 12048, 'O Canto do Passaro S02 E91', 'http://sinalprivado.info:80/series/1533784/1533784/830828.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170167, 12048, 'O Canto do Passaro S02 E92', 'http://sinalprivado.info:80/series/1533784/1533784/830829.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170168, 12048, 'O Canto do Passaro S02 E93', 'http://sinalprivado.info:80/series/1533784/1533784/830830.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170169, 12048, 'O Canto do Passaro S02 E94', 'http://sinalprivado.info:80/series/1533784/1533784/830831.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170170, 12048, 'O Canto do Passaro S02 E95', 'http://sinalprivado.info:80/series/1533784/1533784/830832.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170171, 12048, 'O Canto do Passaro S02 E96', 'http://sinalprivado.info:80/series/1533784/1533784/830833.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170172, 12048, 'O Canto do Passaro S02 E97', 'http://sinalprivado.info:80/series/1533784/1533784/830834.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170173, 12048, 'O Canto do Passaro S02 E98', 'http://sinalprivado.info:80/series/1533784/1533784/830835.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170174, 12048, 'O Canto do Passaro S02 E99', 'http://sinalprivado.info:80/series/1533784/1533784/830836.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170175, 12048, 'O Canto do Passaro S02 E100', 'http://sinalprivado.info:80/series/1533784/1533784/830837.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(170176, 12048, 'O Canto do Passaro S02 E101', 'http://sinalprivado.info:80/series/1533784/1533784/830838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170177, 12048, 'O Canto do Passaro S02 E102', 'http://sinalprivado.info:80/series/1533784/1533784/830839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170178, 12048, 'O Canto do Passaro S02 E103', 'http://sinalprivado.info:80/series/1533784/1533784/830840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170179, 12048, 'O Canto do Passaro S02 E104', 'http://sinalprivado.info:80/series/1533784/1533784/830841.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170180, 12048, 'O Canto do Passaro S02 E105', 'http://sinalprivado.info:80/series/1533784/1533784/830842.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170181, 12048, 'O Canto do Passaro S02 E106', 'http://sinalprivado.info:80/series/1533784/1533784/830843.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170182, 12048, 'O Canto do Passaro S02 E107', 'http://sinalprivado.info:80/series/1533784/1533784/830844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170183, 12048, 'O Canto do Passaro S02 E108', 'http://sinalprivado.info:80/series/1533784/1533784/830845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170184, 12048, 'O Canto do Passaro S02 E109', 'http://sinalprivado.info:80/series/1533784/1533784/830846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170185, 12048, 'O Canto do Passaro S02 E110', 'http://sinalprivado.info:80/series/1533784/1533784/830847.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170186, 12048, 'O Canto do Passaro S02 E111', 'http://sinalprivado.info:80/series/1533784/1533784/830848.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170187, 12048, 'O Canto do Passaro S02 E112', 'http://sinalprivado.info:80/series/1533784/1533784/830849.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170188, 12048, 'O Canto do Passaro S02 E113', 'http://sinalprivado.info:80/series/1533784/1533784/830850.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170189, 12048, 'O Canto do Passaro S02 E114', 'http://sinalprivado.info:80/series/1533784/1533784/830851.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170190, 12048, 'O Canto do Passaro S02 E115', 'http://sinalprivado.info:80/series/1533784/1533784/830852.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170191, 12048, 'O Canto do Passaro S02 E116', 'http://sinalprivado.info:80/series/1533784/1533784/830853.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170192, 12048, 'O Canto do Passaro S02 E117', 'http://sinalprivado.info:80/series/1533784/1533784/830854.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170193, 12048, 'O Canto do Passaro S02 E118', 'http://sinalprivado.info:80/series/1533784/1533784/830855.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170194, 12048, 'O Canto do Passaro S02 E119', 'http://sinalprivado.info:80/series/1533784/1533784/830856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170195, 12048, 'O Canto do Passaro S02 E120', 'http://sinalprivado.info:80/series/1533784/1533784/830857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170196, 12048, 'O Canto do Passaro S02 E121', 'http://sinalprivado.info:80/series/1533784/1533784/830858.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170197, 12048, 'O Canto do Passaro S02 E122', 'http://sinalprivado.info:80/series/1533784/1533784/830859.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170198, 12048, 'O Canto do Passaro S02 E123', 'http://sinalprivado.info:80/series/1533784/1533784/830860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170199, 12048, 'O Canto do Passaro S02 E124', 'http://sinalprivado.info:80/series/1533784/1533784/830861.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170200, 12048, 'O Canto do Passaro S02 E125', 'http://sinalprivado.info:80/series/1533784/1533784/830862.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170201, 12049, 'O Canto do Passaro S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/830863.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170202, 12049, 'O Canto do Passaro S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/830864.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170203, 12049, 'O Canto do Passaro S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/830865.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170204, 12049, 'O Canto do Passaro S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/830866.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170205, 12049, 'O Canto do Passaro S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/830867.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170206, 12049, 'O Canto do Passaro S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/830868.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170207, 12049, 'O Canto do Passaro S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/830869.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170208, 12049, 'O Canto do Passaro S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/830870.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170209, 12049, 'O Canto do Passaro S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/830871.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170210, 12049, 'O Canto do Passaro S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/830872.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170211, 12049, 'O Canto do Passaro S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/830873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170212, 12049, 'O Canto do Passaro S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/830874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170213, 12049, 'O Canto do Passaro S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/830875.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170214, 12049, 'O Canto do Passaro S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/830876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170215, 12049, 'O Canto do Passaro S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/830877.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170216, 12049, 'O Canto do Passaro S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/830878.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170217, 12049, 'O Canto do Passaro S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/830879.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170218, 12049, 'O Canto do Passaro S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/830880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170219, 12049, 'O Canto do Passaro S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/830881.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170220, 12049, 'O Canto do Passaro S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/830882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170221, 12049, 'O Canto do Passaro S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/830883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170222, 12049, 'O Canto do Passaro S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/830884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170223, 12049, 'O Canto do Passaro S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/830885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170224, 12049, 'O Canto do Passaro S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/830886.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170225, 12049, 'O Canto do Passaro S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/830887.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170226, 12049, 'O Canto do Passaro S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/830888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170227, 12049, 'O Canto do Passaro S03 E27', 'http://sinalprivado.info:80/series/1533784/1533784/830889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170228, 12049, 'O Canto do Passaro S03 E28', 'http://sinalprivado.info:80/series/1533784/1533784/830890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170229, 12049, 'O Canto do Passaro S03 E29', 'http://sinalprivado.info:80/series/1533784/1533784/830891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170230, 12049, 'O Canto do Passaro S03 E30', 'http://sinalprivado.info:80/series/1533784/1533784/830892.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170231, 12049, 'O Canto do Passaro S03 E31', 'http://sinalprivado.info:80/series/1533784/1533784/830893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170232, 12049, 'O Canto do Passaro S03 E32', 'http://sinalprivado.info:80/series/1533784/1533784/830894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170233, 12049, 'O Canto do Passaro S03 E33', 'http://sinalprivado.info:80/series/1533784/1533784/830895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170234, 12049, 'O Canto do Passaro S03 E34', 'http://sinalprivado.info:80/series/1533784/1533784/887369.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170235, 12049, 'O Canto do Passaro S03 E35', 'http://sinalprivado.info:80/series/1533784/1533784/887370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170236, 12049, 'O Canto do Passaro S03 E36', 'http://sinalprivado.info:80/series/1533784/1533784/887371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170237, 12049, 'O Canto do Passaro S03 E37', 'http://sinalprivado.info:80/series/1533784/1533784/887372.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170238, 12049, 'O Canto do Passaro S03 E38', 'http://sinalprivado.info:80/series/1533784/1533784/887373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170239, 12049, 'O Canto do Passaro S03 E39', 'http://sinalprivado.info:80/series/1533784/1533784/887374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170240, 12049, 'O Canto do Passaro S03 E40', 'http://sinalprivado.info:80/series/1533784/1533784/887375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170241, 12049, 'O Canto do Passaro S03 E41', 'http://sinalprivado.info:80/series/1533784/1533784/887376.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170242, 12049, 'O Canto do Passaro S03 E42', 'http://sinalprivado.info:80/series/1533784/1533784/887377.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170243, 12049, 'O Canto do Passaro S03 E43', 'http://sinalprivado.info:80/series/1533784/1533784/887378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170244, 12049, 'O Canto do Passaro S03 E44', 'http://sinalprivado.info:80/series/1533784/1533784/887379.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170245, 12049, 'O Canto do Passaro S03 E45', 'http://sinalprivado.info:80/series/1533784/1533784/887380.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170246, 12049, 'O Canto do Passaro S03 E46', 'http://sinalprivado.info:80/series/1533784/1533784/887381.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170247, 12049, 'O Canto do Passaro S03 E47', 'http://sinalprivado.info:80/series/1533784/1533784/887382.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170248, 12049, 'O Canto do Passaro S03 E48', 'http://sinalprivado.info:80/series/1533784/1533784/887383.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170249, 12049, 'O Canto do Passaro S03 E49', 'http://sinalprivado.info:80/series/1533784/1533784/887384.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170250, 12049, 'O Canto do Passaro S03 E50', 'http://sinalprivado.info:80/series/1533784/1533784/887385.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170251, 12049, 'O Canto do Passaro S03 E51', 'http://sinalprivado.info:80/series/1533784/1533784/887386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170252, 12049, 'O Canto do Passaro S03 E52', 'http://sinalprivado.info:80/series/1533784/1533784/887387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170253, 12049, 'O Canto do Passaro S03 E53', 'http://sinalprivado.info:80/series/1533784/1533784/887388.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170254, 12049, 'O Canto do Passaro S03 E54', 'http://sinalprivado.info:80/series/1533784/1533784/887389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170255, 12049, 'O Canto do Passaro S03 E55', 'http://sinalprivado.info:80/series/1533784/1533784/887390.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170256, 12049, 'O Canto do Passaro S03 E56', 'http://sinalprivado.info:80/series/1533784/1533784/887391.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170257, 12049, 'O Canto do Passaro S03 E57', 'http://sinalprivado.info:80/series/1533784/1533784/887392.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170258, 12049, 'O Canto do Passaro S03 E58', 'http://sinalprivado.info:80/series/1533784/1533784/887393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170259, 12049, 'O Canto do Passaro S03 E59', 'http://sinalprivado.info:80/series/1533784/1533784/887394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170260, 12049, 'O Canto do Passaro S03 E60', 'http://sinalprivado.info:80/series/1533784/1533784/887395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170261, 12049, 'O Canto do Passaro S03 E61', 'http://sinalprivado.info:80/series/1533784/1533784/887396.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170262, 12049, 'O Canto do Passaro S03 E62', 'http://sinalprivado.info:80/series/1533784/1533784/887397.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170263, 12049, 'O Canto do Passaro S03 E63', 'http://sinalprivado.info:80/series/1533784/1533784/887398.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170264, 12049, 'O Canto do Passaro S03 E64', 'http://sinalprivado.info:80/series/1533784/1533784/887399.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170265, 12049, 'O Canto do Passaro S03 E65', 'http://sinalprivado.info:80/series/1533784/1533784/887400.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170266, 12049, 'O Canto do Passaro S03 E66', 'http://sinalprivado.info:80/series/1533784/1533784/887401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170267, 12049, 'O Canto do Passaro S03 E67', 'http://sinalprivado.info:80/series/1533784/1533784/887402.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170268, 12049, 'O Canto do Passaro S03 E68', 'http://sinalprivado.info:80/series/1533784/1533784/887403.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170269, 12049, 'O Canto do Passaro S03 E69', 'http://sinalprivado.info:80/series/1533784/1533784/887404.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170270, 12049, 'O Canto do Passaro S03 E70', 'http://sinalprivado.info:80/series/1533784/1533784/887405.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170271, 12049, 'O Canto do Passaro S03 E71', 'http://sinalprivado.info:80/series/1533784/1533784/887406.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170272, 12049, 'O Canto do Passaro S03 E72', 'http://sinalprivado.info:80/series/1533784/1533784/887407.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170273, 12049, 'O Canto do Passaro S03 E73', 'http://sinalprivado.info:80/series/1533784/1533784/887408.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170274, 12049, 'O Canto do Passaro S03 E74', 'http://sinalprivado.info:80/series/1533784/1533784/887409.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170275, 12049, 'O Canto do Passaro S03 E75', 'http://sinalprivado.info:80/series/1533784/1533784/887410.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170276, 12049, 'O Canto do Passaro S03 E76', 'http://sinalprivado.info:80/series/1533784/1533784/887411.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170277, 12049, 'O Canto do Passaro S03 E77', 'http://sinalprivado.info:80/series/1533784/1533784/887412.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170278, 12049, 'O Canto do Passaro S03 E78', 'http://sinalprivado.info:80/series/1533784/1533784/887413.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170279, 12049, 'O Canto do Passaro S03 E79', 'http://sinalprivado.info:80/series/1533784/1533784/887414.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170280, 12049, 'O Canto do Passaro S03 E80', 'http://sinalprivado.info:80/series/1533784/1533784/887415.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170281, 12049, 'O Canto do Passaro S03 E81', 'http://sinalprivado.info:80/series/1533784/1533784/887416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170282, 12049, 'O Canto do Passaro S03 E82', 'http://sinalprivado.info:80/series/1533784/1533784/887417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170283, 12049, 'O Canto do Passaro S03 E83', 'http://sinalprivado.info:80/series/1533784/1533784/887418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170284, 12049, 'O Canto do Passaro S03 E84', 'http://sinalprivado.info:80/series/1533784/1533784/887419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170285, 12049, 'O Canto do Passaro S03 E85', 'http://sinalprivado.info:80/series/1533784/1533784/887420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170286, 12049, 'O Canto do Passaro S03 E86', 'http://sinalprivado.info:80/series/1533784/1533784/887421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170287, 12049, 'O Canto do Passaro S03 E87', 'http://sinalprivado.info:80/series/1533784/1533784/887422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170288, 12049, 'O Canto do Passaro S03 E88', 'http://sinalprivado.info:80/series/1533784/1533784/887423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170289, 12049, 'O Canto do Passaro S03 E89', 'http://sinalprivado.info:80/series/1533784/1533784/887424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/1nJA6ARS2UCZi3iyP0JnVUPPf2n.jpg'),
(170290, 12050, 'Haikyu S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656313.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uAJLekUVGWfujK7WA8ySViXytae.jpg'),
(170291, 12050, 'Haikyu S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656314.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/13veoxgCDkHWZ7udNunYUoYYmyx.jpg'),
(170292, 12050, 'Haikyu S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656315.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sHPlqAd1ATdJSmhRLhHCB7oC1bb.jpg'),
(170293, 12050, 'Haikyu S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656316.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lAQCODHD5uZVzMGke6Gmd0JcFoP.jpg'),
(170294, 12050, 'Haikyu S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656317.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p4aTNURBB1eDniBuFx1MRxxamqx.jpg'),
(170295, 12050, 'Haikyu S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656318.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xMNuvl6RpHPDssIcFh2mVCkx9gE.jpg'),
(170296, 12050, 'Haikyu S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656319.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3eipHCY7IK4Ewx7fBBRC4U6k9rQ.jpg'),
(170297, 12050, 'Haikyu S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/656320.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tHkFN0tsKbj35q3N1G1rBhHCojz.jpg'),
(170298, 12050, 'Haikyu S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/656321.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iJF7vRs68rEI90JO4ydj9erPNWR.jpg'),
(170299, 12050, 'Haikyu S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/656322.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wMYjYRzlI9OL771EcjNUvlpTaom.jpg'),
(170300, 12050, 'Haikyu S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/656323.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8JMjXKsS0q6dr1lH5hntXX37E5f.jpg'),
(170301, 12050, 'Haikyu S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/656324.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pHLwqsSvtNDClPdkF00K0qdxeJ1.jpg'),
(170302, 12050, 'Haikyu S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/656325.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8aMMGbSjQUllusjrrylmp8BQstB.jpg'),
(170303, 12050, 'Haikyu S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/656326.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bUtd0n6oOxlRT2pVRUXcclI5nc5.jpg'),
(170304, 12050, 'Haikyu S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/656327.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7zK3InK5novylPrnDMrWeNIVZ5R.jpg'),
(170305, 12050, 'Haikyu S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/656328.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5wPBUC5SfOAhuUmbLvDRJkJQEUm.jpg'),
(170306, 12050, 'Haikyu S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/656329.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xgnRGtlDtnSzCWtnkeIcnsoYI4C.jpg'),
(170307, 12050, 'Haikyu S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/656330.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qvXdmW4l7vCUtcGfg7eTONN1LYA.jpg'),
(170308, 12050, 'Haikyu S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/656331.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gWLznyPut2F5M1LNCPClzRW8OWN.jpg'),
(170309, 12050, 'Haikyu S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/656332.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/srSV43c6TejmvuJriWxnBFRmGeA.jpg'),
(170310, 12050, 'Haikyu S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/656333.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gMUXejexNSfzzjZS4SArj4MoxLb.jpg'),
(170311, 12050, 'Haikyu S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/656334.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a1c8B6tOFLcAxjCHf98dQAApZFp.jpg'),
(170312, 12050, 'Haikyu S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/656335.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dKBddR63bTD8C3EXtG9nGQL4BJf.jpg'),
(170313, 12050, 'Haikyu S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/656336.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yjl7D8tbhp39X8hLUKcbYPxE2DW.jpg'),
(170314, 12050, 'Haikyu S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/656337.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eUzfwBrJU7pwdF8rpdGEOu6fT54.jpg'),
(170315, 12051, 'Haikyu S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656338.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kEVvQvjb3mhESngZ7hPGFY9WTVn.jpg'),
(170316, 12051, 'Haikyu S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656339.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gAoOftCQ3bhMzdsnZXIWaP94rHg.jpg'),
(170317, 12051, 'Haikyu S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656340.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/67ry0UY5cZFjUrwrHLcMYvMLSW0.jpg'),
(170318, 12051, 'Haikyu S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656341.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mThlgISEs3VmXajHp2YmcJjpXAZ.jpg'),
(170319, 12051, 'Haikyu S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656342.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yvCEcMfmXcL3k7NOGGIiVgTdh1O.jpg'),
(170320, 12051, 'Haikyu S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656343.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/40aXYh5oAL1wJ2bJxSQJzhJAMHG.jpg'),
(170321, 12051, 'Haikyu S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656344.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gDcvcRAqreTuH7vgfC42VBGrx6y.jpg'),
(170322, 12051, 'Haikyu S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/656345.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wIR8o20mk8U5Lr3sKzBuDtjGO0C.jpg'),
(170323, 12051, 'Haikyu S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/656346.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sobaESSCtYErAxWDswcDyPswCY6.jpg'),
(170324, 12051, 'Haikyu S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/656347.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xxplyVnacmWXDYPwqt2s4tIXQzC.jpg'),
(170325, 12051, 'Haikyu S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/656348.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Ru50zI6v8UgjgghtoiHkMmd6MZ.jpg'),
(170326, 12051, 'Haikyu S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/656349.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pBtPbd3oHM3oT94HkraEO7W97Xa.jpg'),
(170327, 12051, 'Haikyu S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/656350.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rmOmKewUSfZVGYsMtHbvGvMlELs.jpg'),
(170328, 12051, 'Haikyu S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/656351.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j59yQ47PCjNSiPRZGca6kaYeKIM.jpg'),
(170329, 12051, 'Haikyu S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/656352.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8cEpkDQlpU2RX3tj7bErMCcgxXM.jpg'),
(170330, 12051, 'Haikyu S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/656353.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ulCDFwEzuNqFsfuhQYSMNXjKnaX.jpg'),
(170331, 12051, 'Haikyu S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/656354.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2FLRyKX0qLipLwghrK0W1a7V6ob.jpg'),
(170332, 12051, 'Haikyu S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/656355.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/boTsMwp1QAMNhkr7Q50m2DrkK3g.jpg'),
(170333, 12051, 'Haikyu S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/656356.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4jZY3sUwfVxgd3YrXjUaqWVKp8G.jpg'),
(170334, 12051, 'Haikyu S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/656357.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sSaU2gFQwX4m6MJB9bgnytU3tos.jpg'),
(170335, 12051, 'Haikyu S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/656358.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4wjRzQrVGJwNcx6xMfJMhUs2RKc.jpg'),
(170336, 12051, 'Haikyu S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/656359.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qoOmoWnKJ2TdCBkT15SWnCUboYC.jpg'),
(170337, 12051, 'Haikyu S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/656360.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i4OcrkgJ4whfcgjlKt41OmC4TEO.jpg'),
(170338, 12051, 'Haikyu S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/656361.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cNSNpPoIUd80QTi5naxUQn2KyrY.jpg'),
(170339, 12052, 'Desafios Culinarios Julia Child S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUblh2SZTeWQHRfnDEsnCaxNV52.jpg'),
(170340, 12052, 'Desafios Culinarios Julia Child S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUblh2SZTeWQHRfnDEsnCaxNV52.jpg'),
(170341, 12052, 'Desafios Culinarios Julia Child S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUblh2SZTeWQHRfnDEsnCaxNV52.jpg'),
(170342, 12052, 'Desafios Culinarios Julia Child S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUblh2SZTeWQHRfnDEsnCaxNV52.jpg'),
(170343, 12052, 'Desafios Culinarios Julia Child S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUblh2SZTeWQHRfnDEsnCaxNV52.jpg'),
(170344, 12052, 'Desafios Culinarios Julia Child S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oUblh2SZTeWQHRfnDEsnCaxNV52.jpg'),
(170345, 12053, 'Que Falta Voce Me Faz S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656302.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rkQGFXFyxF28PoSTrCYMUw2B1fT.jpg'),
(170346, 12053, 'Que Falta Voce Me Faz S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656303.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/whbB7dr6oXkDOv2VAf7i4ztCA56.jpg'),
(170347, 12053, 'Que Falta Voce Me Faz S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656304.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6UbQXukUupt8rd5IK0m7jrXTR35.jpg'),
(170348, 12053, 'Que Falta Voce Me Faz S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656305.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bWxE3FKMghI5MRzruUUlHUKuQN2.jpg'),
(170349, 12053, 'Que Falta Voce Me Faz S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656306.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ixmds63ik3qjMgL7avgc7IzboRZ.jpg'),
(170350, 12054, 'Rivais S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656294.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wsMEubeiyNu9McePaI1xosn54WO.jpg'),
(170351, 12054, 'Rivais S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656295.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tHOQ6SFSLGKumWz2hmYebleGrIF.jpg'),
(170352, 12054, 'Rivais S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656296.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pC2KipXFRk8KBO6UQy6zhu5qAAj.jpg'),
(170353, 12054, 'Rivais S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656297.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fVtsqExwiZwGYL3GeIHAgALtDiP.jpg'),
(170354, 12054, 'Rivais S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656298.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/srpczFfu9SlSUnzdcNzA5XbiYLN.jpg'),
(170355, 12054, 'Rivais S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656299.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mfjdLkIFWaNu89tyiGffJXQNlZv.jpg'),
(170356, 12054, 'Rivais S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656300.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qNM8628tywJ3SxJOip0zyxh3IOr.jpg'),
(170357, 12054, 'Rivais S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/656301.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iEHiYAJIcixMT2VlRApHqwdmRGd.jpg'),
(170358, 12055, 'A Chama de Recca [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656252.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pRuPFjzWxQhzxWkVPQ0EOZjpZ4h.jpg'),
(170359, 12055, 'A Chama de Recca [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656253.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x3keGO5DgzxZEePxOWakcK1JwFx.jpg'),
(170360, 12055, 'A Chama de Recca [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656254.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sGzLkwqYEIhqpjlLSmJVubQEWYf.jpg'),
(170361, 12055, 'A Chama de Recca [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656255.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t0vgt5IXTCGyOWVCgmsFFuOO5aN.jpg'),
(170362, 12055, 'A Chama de Recca [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656256.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/airw2MAvQ32E9moUmtLG63SoGvL.jpg'),
(170363, 12055, 'A Chama de Recca [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656257.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4k71KXxlNvjuz9VVLhtKCfOXc2B.jpg'),
(170364, 12055, 'A Chama de Recca [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656258.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4H3e4SdSwlWCHad6UxltUvH5hDs.jpg'),
(170365, 12055, 'A Chama de Recca [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/656259.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4HMudEzGASBFg4Y3vrny3b7LDop.jpg'),
(170366, 12055, 'A Chama de Recca [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/656260.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/elC2sGIIfJq9BjM3VEmQtfmD2ot.jpg'),
(170367, 12055, 'A Chama de Recca [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/656261.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nLKGwJCA4AK6CeFttTetuzZN3jK.jpg'),
(170368, 12055, 'A Chama de Recca [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/656262.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wKd1RiezKGMbKMwJV8HmsIkQFDv.jpg'),
(170369, 12055, 'A Chama de Recca [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/656263.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/keO9h9ZwHwqpt0kqVku2ZRigQyG.jpg'),
(170370, 12055, 'A Chama de Recca [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/656264.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8KIdaCxDaNx6GDctQ7dmNvoJWLZ.jpg'),
(170371, 12055, 'A Chama de Recca [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/656265.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uFTd9oUGZJVOzV5cWvVRSHwzIWo.jpg'),
(170372, 12055, 'A Chama de Recca [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/656266.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aPCFrczxgrIhrEYypFMV6cuW6Kl.jpg'),
(170373, 12055, 'A Chama de Recca [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/656267.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eUwMA9nguBpiYRywAkHjiHOHvJC.jpg'),
(170374, 12055, 'A Chama de Recca [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/656268.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mbpcY4j2y1oKn02fihLApEvrdbR.jpg'),
(170375, 12055, 'A Chama de Recca [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/656269.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k9WahpVMxSSb5uvABTX1iI1bbPN.jpg'),
(170376, 12055, 'A Chama de Recca [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/656270.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5MFci98ZvnAps7oV0XMmLpsDdZP.jpg'),
(170377, 12055, 'A Chama de Recca [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/656271.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j1jc77Bt8jrsmqoO6Q3Evpx0jFH.jpg'),
(170378, 12055, 'A Chama de Recca [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/656272.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qJGMhCs28TXxbFWYhym6kIVLR8h.jpg'),
(170379, 12055, 'A Chama de Recca [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/656273.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/viEOkeI7tHtfhsN2FOonMYbIftn.jpg'),
(170380, 12055, 'A Chama de Recca [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/656274.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dQx6BfOTGaCwGWsB2PkFJRhBOVN.jpg'),
(170381, 12055, 'A Chama de Recca [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/656275.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vjtchP7mhLeQiN1XRJEGW6OzVgZ.jpg'),
(170382, 12055, 'A Chama de Recca [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/656276.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o9e7EuRJIZCAyz9sdnBiQd10oED.jpg'),
(170383, 12055, 'A Chama de Recca [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/656277.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5ws6YiMXKmZck5CHrf9MtLuo7SV.jpg'),
(170384, 12055, 'A Chama de Recca [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/656278.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9kihIgetahYtavylhksW5bnkbvH.jpg'),
(170385, 12055, 'A Chama de Recca [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/656279.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hkIzsq8XFgNvIbqhfi9cuEpRS9V.jpg'),
(170386, 12055, 'A Chama de Recca [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/656280.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8Mb99asm0SgSseoNHMSTN5F1pde.jpg'),
(170387, 12055, 'A Chama de Recca [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/656281.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qIT9RBwd6RNG8rLWQVHQ54tmuv.jpg'),
(170388, 12055, 'A Chama de Recca [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/656282.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fyG7BgsnAxCpW9n5rRGAeiesO5Y.jpg'),
(170389, 12055, 'A Chama de Recca [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/656283.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bLm4QAusI66uNSSONgk2hL75QhA.jpg'),
(170390, 12055, 'A Chama de Recca [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/656284.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/brLPKiTN2Xux1TxBtqHjSdserUq.jpg'),
(170391, 12055, 'A Chama de Recca [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/656285.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8JcppfZuKRm2yu16Ed1vGHjDMF0.jpg'),
(170392, 12055, 'A Chama de Recca [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/656286.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3s3tKdO3CwNvpGw0ltsgzpfHCYQ.jpg'),
(170393, 12055, 'A Chama de Recca [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/656287.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ptmwPKLouvRgiqqJTsfD9zPPHhD.jpg'),
(170394, 12055, 'A Chama de Recca [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/656288.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rejAdvgCxLGbR8uApbIZellmDGg.jpg'),
(170395, 12055, 'A Chama de Recca [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/656289.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iaGgikC9pFTaYa6BeVzh7Qqj18a.jpg'),
(170396, 12055, 'A Chama de Recca [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/656290.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ubJkAFg9k8tFuhrz0LYxbTiqicc.jpg'),
(170397, 12055, 'A Chama de Recca [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/656291.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v0nMKNOmiMM5t0SkmfxBcmUuWKC.jpg'),
(170398, 12055, 'A Chama de Recca [L] S01 E41', 'http://sinalprivado.info:80/series/1533784/1533784/656292.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wlJxmVXzskfuLuJ0sm919Uoyr0i.jpg'),
(170399, 12055, 'A Chama de Recca [L] S01 E42', 'http://sinalprivado.info:80/series/1533784/1533784/656293.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5oTT7V04Sutg1q2OLGpXyeWuJnY.jpg'),
(170400, 11945, 'A Historia da Garota Perola [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656212.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6hxbnn0XpWwEm59rMQLeBpsW1BL.jpg'),
(170401, 11945, 'A Historia da Garota Perola [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656213.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s5ifiOdvSrEHUf5MXURmVrfF2uJ.jpg'),
(170402, 11945, 'A Historia da Garota Perola [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656214.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qnw9Hj1W7qe26EtdGhLwpnbSqSy.jpg'),
(170403, 11945, 'A Historia da Garota Perola [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656215.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1AP9UNHjy6YYfReRhG151EtepfU.jpg'),
(170404, 11945, 'A Historia da Garota Perola [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656216.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yo8TH6mIeJflQpntmAQG0wpffL2.jpg'),
(170405, 11945, 'A Historia da Garota Perola [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656217.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qygOh6VHH8QBzRZfFmCynTqUsRP.jpg'),
(170406, 11945, 'A Historia da Garota Perola [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656218.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4Ef7ldlhoRZHeV0wsan3JCuNEdj.jpg'),
(170407, 11945, 'A Historia da Garota Perola [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/656219.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/daIHnmIY2yohb1P1eRXAIDqeyN2.jpg'),
(170408, 11945, 'A Historia da Garota Perola [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/656220.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2kxavVEhApTrFUO2xyvkAsTGx1H.jpg'),
(170409, 11945, 'A Historia da Garota Perola [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/656221.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iAWmVg36Lftd9FnhzDDNHd8EnNi.jpg'),
(170410, 11945, 'A Historia da Garota Perola [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/656222.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aEOrr3gSGdRw2qVN2Fssm98amdi.jpg'),
(170411, 11945, 'A Historia da Garota Perola [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/656223.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2CnI1k6fLy2D1VAXVrd1safaiWU.jpg'),
(170412, 11945, 'A Historia da Garota Perola [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/656224.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ihABRC005sTQS41MD3iiU8ohxja.jpg'),
(170413, 11945, 'A Historia da Garota Perola [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/656225.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/25JNGdNgQSmzipLhy295bByHpN0.jpg'),
(170414, 11945, 'A Historia da Garota Perola [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/656226.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qathrXiRCTn4xead8tHY96IdFb0.jpg'),
(170415, 11945, 'A Historia da Garota Perola [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/656227.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5mqLnc2wjLVM9zpxZAMhFrTcUUK.jpg'),
(170416, 11945, 'A Historia da Garota Perola [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/656228.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/b6WAA8ViWrR5I4aXkEyRPqMF2SP.jpg'),
(170417, 11945, 'A Historia da Garota Perola [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/656229.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aPfQHwVMLKiPm5dTeqU9nkpV8Ev.jpg'),
(170418, 11945, 'A Historia da Garota Perola [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/656230.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dLnPH635dIqZqdWP644VLBEPEKj.jpg'),
(170419, 11945, 'A Historia da Garota Perola [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/656231.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1D6oWWbZsBS2jLXe8IyemWNjqOg.jpg'),
(170420, 11945, 'A Historia da Garota Perola [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/656232.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mf1MV4btkN7sZYSRyYRGaa0fLCE.jpg'),
(170421, 11945, 'A Historia da Garota Perola [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/656233.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nKOiW9LRnFVMl5GCKBkAlHXvDJy.jpg'),
(170422, 11945, 'A Historia da Garota Perola [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/656234.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Ey3ygCjdO1w4bW0IIVLd8QfrPm.jpg'),
(170423, 11945, 'A Historia da Garota Perola [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/656235.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rczusd0bItSf0FKrkcmNpn8rFYq.jpg'),
(170424, 11945, 'A Historia da Garota Perola [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/656236.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eu41MO9PXNSWfSEkLqI63gVol7c.jpg'),
(170425, 11945, 'A Historia da Garota Perola [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/656237.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e8LQsjCMMWMsIjPWgeCQGYHK0jx.jpg'),
(170426, 11945, 'A Historia da Garota Perola [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/656238.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pNpSBpjeqBKnnJ95Mt0NsADRK2X.jpg'),
(170427, 11945, 'A Historia da Garota Perola [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/656239.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Wv9lqpe8eDJIR4rRttWFwfNO5n.jpg'),
(170428, 11945, 'A Historia da Garota Perola [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/656240.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/frADLh22bulFNhzGPRuVrR1yckH.jpg'),
(170429, 11945, 'A Historia da Garota Perola [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/656241.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pcGch1LGiK4TAG1xS4i7Ma8KYUl.jpg'),
(170430, 11945, 'A Historia da Garota Perola [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/656242.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j5HZaPCzPIfdOuyQ7p1fvBpG6qh.jpg'),
(170431, 11945, 'A Historia da Garota Perola [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/656243.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/d8HKPyApIAO84IVNOdwnOVFoELh.jpg'),
(170432, 11945, 'A Historia da Garota Perola [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/656244.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rFaWKgNjB1HHOUqpwdEygtmfXjr.jpg'),
(170433, 11945, 'A Historia da Garota Perola [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/656245.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iMxC4YtOo1CL019yu1G0EgVCuhd.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(170434, 11945, 'A Historia da Garota Perola [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/656246.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/70DmAtGMA6R3ACdREEQoc8pqXst.jpg'),
(170435, 11945, 'A Historia da Garota Perola [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/656247.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cc2H8lkXblFyNRfS0DgsjygrHmQ.jpg'),
(170436, 11945, 'A Historia da Garota Perola [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/656248.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6TlLhRbuhvsRSDOp7xfw5LMfMCb.jpg'),
(170437, 11945, 'A Historia da Garota Perola [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/656249.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sC4guMZq83eaeY0K82GolKnsS4k.jpg'),
(170438, 11945, 'A Historia da Garota Perola [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/656250.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/az9UarmDtrum5T3cYXY0YT3voYP.jpg'),
(170439, 11945, 'A Historia da Garota Perola [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/656251.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ih15kJgz3tcYJjwCTCnpVtT3rY0.jpg'),
(170440, 12056, 'So a Terra Permanece [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656206.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/msPG2NdWAEfs37mlfz7NlNKPQdA.jpg'),
(170441, 12056, 'So a Terra Permanece [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656207.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/77APttVyVFQoFpaKcQyD7wJemad.jpg'),
(170442, 12056, 'So a Terra Permanece [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656208.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i0RljVgbOVvuFvIeAXMOjKu1AR4.jpg'),
(170443, 12056, 'So a Terra Permanece [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656209.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k6gqC5bwgUJfBt8E2U9rkhp2c6L.jpg'),
(170444, 12056, 'So a Terra Permanece [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656210.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aa6EyA1XKUe4tQtYxflKBgGSb1d.jpg'),
(170445, 12056, 'So a Terra Permanece [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656211.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hfNpsUIBCCRgi5OuXtntMiFb7yZ.jpg'),
(170446, 12057, 'After the Rain [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656194.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vFxhspXB31fnvXJeSPXMS3MRL1a.jpg'),
(170447, 12057, 'After the Rain [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656195.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xr8TtplTc1s0zi0Nj3yxSeNCqTL.jpg'),
(170448, 12057, 'After the Rain [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/puALWMH7M8FT42tgI5Zbj2JWh24.jpg'),
(170449, 12057, 'After the Rain [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/puALWMH7M8FT42tgI5Zbj2JWh24.jpg'),
(170450, 12057, 'After the Rain [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/puALWMH7M8FT42tgI5Zbj2JWh24.jpg'),
(170451, 12057, 'After the Rain [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/puALWMH7M8FT42tgI5Zbj2JWh24.jpg'),
(170452, 12057, 'After the Rain [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/puALWMH7M8FT42tgI5Zbj2JWh24.jpg'),
(170453, 12057, 'After the Rain [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/656201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/puALWMH7M8FT42tgI5Zbj2JWh24.jpg'),
(170454, 12057, 'After the Rain [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/656202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/puALWMH7M8FT42tgI5Zbj2JWh24.jpg'),
(170455, 12057, 'After the Rain [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/656203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/puALWMH7M8FT42tgI5Zbj2JWh24.jpg'),
(170456, 12057, 'After the Rain [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/656204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/puALWMH7M8FT42tgI5Zbj2JWh24.jpg'),
(170457, 12057, 'After the Rain [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/656205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/puALWMH7M8FT42tgI5Zbj2JWh24.jpg'),
(170458, 12058, 'Beleza Sombrias [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656181.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ntl5Z2mqQU1cSltyuoyPA8wUfxP.jpg'),
(170459, 12058, 'Beleza Sombrias [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656182.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g46beNeGqnFiGAyxcmYHYUjBvOj.jpg'),
(170460, 12058, 'Beleza Sombrias [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656183.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s69f0cDc7mLBHTrQtb3WWxP82mL.jpg'),
(170461, 12058, 'Beleza Sombrias [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656184.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aKQbPTXC0H68p5roKdjBuj4vOiv.jpg'),
(170462, 12058, 'Beleza Sombrias [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656185.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/knHRR0hjfiqR0oXnUFINywsCKXt.jpg'),
(170463, 12058, 'Beleza Sombrias [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656186.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7YUhUcu5KoLj9ix1iLi8WIt7Ibp.jpg'),
(170464, 12058, 'Beleza Sombrias [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656187.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9YbnWHnvcHcuJiagTpBzGFpWmaS.jpg'),
(170465, 12058, 'Beleza Sombrias [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/656188.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3z3xCiXnoX0UXGyfzCUsx2DtLtj.jpg'),
(170466, 12058, 'Beleza Sombrias [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/656189.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A1Mb6kI3KdmdukvZmn4dRh4m9G3.jpg'),
(170467, 12058, 'Beleza Sombrias [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/656190.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7HzJBWw8Xzuc5FSZ3w0kdF5QQ46.jpg'),
(170468, 12058, 'Beleza Sombrias [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/656191.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/knZNcsvrtKbv1EbuMHPxxVwNqMd.jpg'),
(170469, 12058, 'Beleza Sombrias [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/656192.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vKZuuMODAGY3Mo8fhufTxFj17np.jpg'),
(170470, 12058, 'Beleza Sombrias [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/656193.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rG0Tl3kWBRQr6VGciukOJ54vQRX.jpg'),
(170471, 12059, 'Bloody Game [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oAYzEjKXLF0eW8GkeA4ghwX6uaQ.jpg'),
(170472, 12059, 'Bloody Game [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oAYzEjKXLF0eW8GkeA4ghwX6uaQ.jpg'),
(170473, 12059, 'Bloody Game [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656171.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oAYzEjKXLF0eW8GkeA4ghwX6uaQ.jpg'),
(170474, 12059, 'Bloody Game [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oAYzEjKXLF0eW8GkeA4ghwX6uaQ.jpg'),
(170475, 12059, 'Bloody Game [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656173.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oAYzEjKXLF0eW8GkeA4ghwX6uaQ.jpg'),
(170476, 12059, 'Bloody Game [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656174.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oAYzEjKXLF0eW8GkeA4ghwX6uaQ.jpg'),
(170477, 12059, 'Bloody Game [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656175.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oAYzEjKXLF0eW8GkeA4ghwX6uaQ.jpg'),
(170478, 12059, 'Bloody Game [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/656176.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oAYzEjKXLF0eW8GkeA4ghwX6uaQ.jpg'),
(170479, 12059, 'Bloody Game [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/656177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oAYzEjKXLF0eW8GkeA4ghwX6uaQ.jpg'),
(170480, 12059, 'Bloody Game [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/656178.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oAYzEjKXLF0eW8GkeA4ghwX6uaQ.jpg'),
(170481, 12059, 'Bloody Game [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/656179.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oAYzEjKXLF0eW8GkeA4ghwX6uaQ.jpg'),
(170482, 12059, 'Bloody Game [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/656180.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/oAYzEjKXLF0eW8GkeA4ghwX6uaQ.jpg'),
(170483, 12060, 'Deixe me Apresenta la [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656129.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/SGJDcCIdGFgJaj15qBVBtASsZb.jpg'),
(170484, 12060, 'Deixe me Apresenta la [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656130.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170485, 12060, 'Deixe me Apresenta la [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656131.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170486, 12060, 'Deixe me Apresenta la [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656132.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170487, 12060, 'Deixe me Apresenta la [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656133.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170488, 12060, 'Deixe me Apresenta la [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170489, 12060, 'Deixe me Apresenta la [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656135.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170490, 12060, 'Deixe me Apresenta la [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/656136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170491, 12060, 'Deixe me Apresenta la [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/656137.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170492, 12060, 'Deixe me Apresenta la [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/656138.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170493, 12060, 'Deixe me Apresenta la [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/656139.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170494, 12060, 'Deixe me Apresenta la [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/656140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170495, 12060, 'Deixe me Apresenta la [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/656141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170496, 12060, 'Deixe me Apresenta la [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/656142.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170497, 12060, 'Deixe me Apresenta la [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/656143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170498, 12060, 'Deixe me Apresenta la [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/656144.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170499, 12060, 'Deixe me Apresenta la [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/656145.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170500, 12060, 'Deixe me Apresenta la [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/656146.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170501, 12060, 'Deixe me Apresenta la [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/656147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170502, 12060, 'Deixe me Apresenta la [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/656148.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170503, 12060, 'Deixe me Apresenta la [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/656149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170504, 12060, 'Deixe me Apresenta la [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/656150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170505, 12060, 'Deixe me Apresenta la [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/656151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170506, 12060, 'Deixe me Apresenta la [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/656152.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170507, 12060, 'Deixe me Apresenta la [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/656153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170508, 12060, 'Deixe me Apresenta la [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/656154.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170509, 12060, 'Deixe me Apresenta la [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/656155.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170510, 12060, 'Deixe me Apresenta la [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/656156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170511, 12060, 'Deixe me Apresenta la [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/656157.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170512, 12060, 'Deixe me Apresenta la [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/656158.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170513, 12060, 'Deixe me Apresenta la [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/656159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170514, 12060, 'Deixe me Apresenta la [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/656160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170515, 12060, 'Deixe me Apresenta la [L] S01 E33', 'http://sinalprivado.info:80/series/1533784/1533784/656161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170516, 12060, 'Deixe me Apresenta la [L] S01 E34', 'http://sinalprivado.info:80/series/1533784/1533784/656162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170517, 12060, 'Deixe me Apresenta la [L] S01 E35', 'http://sinalprivado.info:80/series/1533784/1533784/656163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170518, 12060, 'Deixe me Apresenta la [L] S01 E36', 'http://sinalprivado.info:80/series/1533784/1533784/656164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170519, 12060, 'Deixe me Apresenta la [L] S01 E37', 'http://sinalprivado.info:80/series/1533784/1533784/656165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170520, 12060, 'Deixe me Apresenta la [L] S01 E38', 'http://sinalprivado.info:80/series/1533784/1533784/656166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170521, 12060, 'Deixe me Apresenta la [L] S01 E39', 'http://sinalprivado.info:80/series/1533784/1533784/656167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170522, 12060, 'Deixe me Apresenta la [L] S01 E40', 'http://sinalprivado.info:80/series/1533784/1533784/656168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cmPZ93Vc9ciib8xUVGRSCY6QzB6.jpg'),
(170523, 12061, 'Ginyuu Mokushiroku Meine Liebe [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656116.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u4ZQC6DLwpIVaT8z0NBJte12KLY.jpg'),
(170524, 12061, 'Ginyuu Mokushiroku Meine Liebe [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656117.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u4ZQC6DLwpIVaT8z0NBJte12KLY.jpg'),
(170525, 12061, 'Ginyuu Mokushiroku Meine Liebe [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u4ZQC6DLwpIVaT8z0NBJte12KLY.jpg'),
(170526, 12061, 'Ginyuu Mokushiroku Meine Liebe [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656119.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u4ZQC6DLwpIVaT8z0NBJte12KLY.jpg'),
(170527, 12061, 'Ginyuu Mokushiroku Meine Liebe [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u4ZQC6DLwpIVaT8z0NBJte12KLY.jpg'),
(170528, 12061, 'Ginyuu Mokushiroku Meine Liebe [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u4ZQC6DLwpIVaT8z0NBJte12KLY.jpg'),
(170529, 12061, 'Ginyuu Mokushiroku Meine Liebe [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656122.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u4ZQC6DLwpIVaT8z0NBJte12KLY.jpg'),
(170530, 12061, 'Ginyuu Mokushiroku Meine Liebe [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/656123.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u4ZQC6DLwpIVaT8z0NBJte12KLY.jpg'),
(170531, 12061, 'Ginyuu Mokushiroku Meine Liebe [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/656124.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u4ZQC6DLwpIVaT8z0NBJte12KLY.jpg'),
(170532, 12061, 'Ginyuu Mokushiroku Meine Liebe [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/656125.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u4ZQC6DLwpIVaT8z0NBJte12KLY.jpg'),
(170533, 12061, 'Ginyuu Mokushiroku Meine Liebe [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/656126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u4ZQC6DLwpIVaT8z0NBJte12KLY.jpg'),
(170534, 12061, 'Ginyuu Mokushiroku Meine Liebe [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/656127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u4ZQC6DLwpIVaT8z0NBJte12KLY.jpg'),
(170535, 12061, 'Ginyuu Mokushiroku Meine Liebe [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/656128.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/u4ZQC6DLwpIVaT8z0NBJte12KLY.jpg'),
(170536, 12062, 'Heard It Through the Grapevine [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170537, 12062, 'Heard It Through the Grapevine [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170538, 12062, 'Heard It Through the Grapevine [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170539, 12062, 'Heard It Through the Grapevine [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170540, 12062, 'Heard It Through the Grapevine [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170541, 12062, 'Heard It Through the Grapevine [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170542, 12062, 'Heard It Through the Grapevine [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170543, 12062, 'Heard It Through the Grapevine [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/656093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170544, 12062, 'Heard It Through the Grapevine [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/656094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170545, 12062, 'Heard It Through the Grapevine [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/656095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170546, 12062, 'Heard It Through the Grapevine [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/656096.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170547, 12062, 'Heard It Through the Grapevine [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/656097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170548, 12062, 'Heard It Through the Grapevine [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/656098.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170549, 12062, 'Heard It Through the Grapevine [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/656099.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170550, 12062, 'Heard It Through the Grapevine [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/656100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170551, 12062, 'Heard It Through the Grapevine [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/656101.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170552, 12062, 'Heard It Through the Grapevine [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/656102.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170553, 12062, 'Heard It Through the Grapevine [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/656103.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170554, 12062, 'Heard It Through the Grapevine [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/656104.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170555, 12062, 'Heard It Through the Grapevine [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/656105.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170556, 12062, 'Heard It Through the Grapevine [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/656106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170557, 12062, 'Heard It Through the Grapevine [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/656107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170558, 12062, 'Heard It Through the Grapevine [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/656108.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170559, 12062, 'Heard It Through the Grapevine [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/656109.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170560, 12062, 'Heard It Through the Grapevine [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/656110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170561, 12062, 'Heard It Through the Grapevine [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/656111.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170562, 12062, 'Heard It Through the Grapevine [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/656112.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170563, 12062, 'Heard It Through the Grapevine [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/656113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170564, 12062, 'Heard It Through the Grapevine [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/656114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170565, 12062, 'Heard It Through the Grapevine [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/656115.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zq2AvpvMURDXcLIoHy8jOypjTy1.jpg'),
(170566, 12063, 'Joshikousei no Mudazukai [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656074.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vX03mmbQklgbDql0axHY33fRbYI.jpg'),
(170567, 12063, 'Joshikousei no Mudazukai [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656075.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c8023JcTcJfQw9NI6pH7vl0E1dq.jpg'),
(170568, 12063, 'Joshikousei no Mudazukai [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656076.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lQudPGdany0iK8BboPow1QUokUg.jpg'),
(170569, 12063, 'Joshikousei no Mudazukai [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656077.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dxRBylgp5STT5kT2EgV02xLV2Ly.jpg'),
(170570, 12063, 'Joshikousei no Mudazukai [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656078.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zufjTXLMdF7zECjgm6MgJyNr5qT.jpg'),
(170571, 12063, 'Joshikousei no Mudazukai [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656079.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aFF8ED8zYHGspC1STgN6uhnkQMJ.jpg'),
(170572, 12063, 'Joshikousei no Mudazukai [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656080.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6yqHNTk6sjoOaRV2gPrL5093mRM.jpg'),
(170573, 12063, 'Joshikousei no Mudazukai [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/656081.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c25E8isTDb4AkdG6s3kShoONhyF.jpg'),
(170574, 12063, 'Joshikousei no Mudazukai [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/656082.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t1B1vTSmEM68xL2V9RYYIW5Mqnq.jpg'),
(170575, 12063, 'Joshikousei no Mudazukai [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/656083.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vxB0vFWSkcTqURPyOniWBKREm3p.jpg'),
(170576, 12063, 'Joshikousei no Mudazukai [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/656084.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rJAKz2B25Wucm0Tbs16ioZTj5GX.jpg'),
(170577, 12063, 'Joshikousei no Mudazukai [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/656085.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4FIgI3xkRcWMuXy1ePtASagKv1D.jpg'),
(170578, 12064, 'Kisarazu Cats Eye [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656065.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z9uSERpcJag3CsGMBsdBHHVUizQ.jpg'),
(170579, 12064, 'Kisarazu Cats Eye [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z9uSERpcJag3CsGMBsdBHHVUizQ.jpg'),
(170580, 12064, 'Kisarazu Cats Eye [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656067.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z9uSERpcJag3CsGMBsdBHHVUizQ.jpg'),
(170581, 12064, 'Kisarazu Cats Eye [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656068.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z9uSERpcJag3CsGMBsdBHHVUizQ.jpg'),
(170582, 12064, 'Kisarazu Cats Eye [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z9uSERpcJag3CsGMBsdBHHVUizQ.jpg'),
(170583, 12064, 'Kisarazu Cats Eye [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656070.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z9uSERpcJag3CsGMBsdBHHVUizQ.jpg'),
(170584, 12064, 'Kisarazu Cats Eye [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z9uSERpcJag3CsGMBsdBHHVUizQ.jpg'),
(170585, 12064, 'Kisarazu Cats Eye [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/656072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z9uSERpcJag3CsGMBsdBHHVUizQ.jpg'),
(170586, 12064, 'Kisarazu Cats Eye [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/656073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/z9uSERpcJag3CsGMBsdBHHVUizQ.jpg'),
(170587, 11740, 'Love Sick [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656049.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dRcxO3x4P8eu4c9VFCTpznNugIG.jpg'),
(170588, 11740, 'Love Sick [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656050.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u0Xx6FVoIxJO6HAzEQwd6WDyMZI.jpg'),
(170589, 11740, 'Love Sick [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656051.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ySPQvjjG0cIMmbQ4nfCANFWE0UD.jpg'),
(170590, 11740, 'Love Sick [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656052.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aWou9WBy8eehZnMX6kzyg9x8pOv.jpg'),
(170591, 11740, 'Love Sick [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656053.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p7AYyx6ckdlLfuVgbEzMdsSUDht.jpg'),
(170592, 11740, 'Love Sick [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656054.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/evTM1Zuwt4xUQZwW0NIixVFNZw1.jpg'),
(170593, 11740, 'Love Sick [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656055.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/saZLUHnrBuNBUI8owu0uPykbJzx.jpg'),
(170594, 11740, 'Love Sick [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/656056.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nNQOl2vPI36gy1j4vSbrAoC6ybB.jpg'),
(170595, 11740, 'Love Sick [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/656057.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hMe57Qs3a8gra13sH45ZgF43JzH.jpg'),
(170596, 11740, 'Love Sick [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/656058.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/liLDtVHMKOgiOTb2bivdKtCUZgr.jpg'),
(170597, 11740, 'Love Sick [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/656059.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mQ8dykHPb0TzbmZ1DF5PUWWe4lp.jpg'),
(170598, 11740, 'Love Sick [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/656060.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fqidZLIF8H6Jbr0Kyj4jBdep0Ze.jpg'),
(170599, 11740, 'Love Sick [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/656061.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uGmnCKVlSSudKkDhhu3cKPBYnXb.jpg'),
(170600, 11740, 'Love Sick [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/656062.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jnk3hKEl6SCP46HL8hF6iuB5OdM.jpg'),
(170601, 11740, 'Love Sick [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/656063.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fgXhCV24rLIEXxeu9kXhH0FwsWn.jpg'),
(170602, 11740, 'Love Sick [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/656064.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rmQZrOpWQwHN3MGX712EjL9cfc0.jpg'),
(170603, 12065, 'Luz do Meu Leao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656038.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bvpEjwFiOaYmQcKUhyQcwDNoLSM.jpg'),
(170604, 12065, 'Luz do Meu Leao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656039.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m84n3U3mRyTE74Z8xyEF6k9Q6FJ.jpg'),
(170605, 12065, 'Luz do Meu Leao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656040.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tnL8s1p8xwvPycMvv1jYGNf8EKI.jpg'),
(170606, 12065, 'Luz do Meu Leao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656041.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/prxrvrRUCJIInI7uiQTCrcjPLvt.jpg'),
(170607, 12065, 'Luz do Meu Leao [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656042.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hCUBOn6eKMSzz5ZQ7yvvb9fO4M2.jpg'),
(170608, 12065, 'Luz do Meu Leao [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656043.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9NJW4fzVVlYJnoTZnS9C1PWFOCc.jpg'),
(170609, 12065, 'Luz do Meu Leao [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656044.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1871iUJNLzgmCCFUrDJza9vn9wq.jpg'),
(170610, 12065, 'Luz do Meu Leao [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/656045.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mXXG4dYDCxCRNQcXmhzLwauWw6U.jpg'),
(170611, 12065, 'Luz do Meu Leao [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/656046.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wU1cUAZOYC76yJDF1wgi3iThTIV.jpg'),
(170612, 12065, 'Luz do Meu Leao [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/656047.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/apqXcyi8qFjwHZCQbTXhdPt7d82.jpg'),
(170613, 12065, 'Luz do Meu Leao [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/656048.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6CFSaLtIVuWcTchIYZMgAUgJLgE.jpg'),
(170614, 12066, 'Magi [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/656013.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qvHr60A8cWiZcDhcyrPQBbxd24q.jpg'),
(170615, 12066, 'Magi [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/656014.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5xPsvLYqHmMyeE21TwBftPDiPp9.jpg'),
(170616, 12066, 'Magi [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/656015.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/UXAnyyrbeBM2mFXUsitqnWvP7w.jpg'),
(170617, 12066, 'Magi [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/656016.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tSD6TcGTHDGIydvqBjOvX3hUIas.jpg'),
(170618, 12066, 'Magi [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/656017.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dN0wWL54jFOtUD39i9gqWPSqqqA.jpg'),
(170619, 12066, 'Magi [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/656018.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5E61X2feMnYM2IRWjEMcCCuhzJO.jpg'),
(170620, 12066, 'Magi [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/656019.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wm5m8lJigr0gPlULfQpKw9bchlq.jpg'),
(170621, 12066, 'Magi [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/656020.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8obDiABjSEddEj5MEAlsYLVjOA1.jpg'),
(170622, 12066, 'Magi [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/656021.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lMVY65q8WUTwnkHspdUXbBWowZk.jpg'),
(170623, 12066, 'Magi [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/656022.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mmfG2C9SvvCu6hTiIEwHIdHCppt.jpg'),
(170624, 12066, 'Magi [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/656023.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jVANA2L22vQo5as4pe366OSLJK4.jpg'),
(170625, 12066, 'Magi [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/656024.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tTtH2UPJkx41VTfv8NxK2YRCsxK.jpg'),
(170626, 12066, 'Magi [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/656025.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9gMoV7VUEs5wUZ9Af7uBjSXCqug.jpg'),
(170627, 12066, 'Magi [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/656026.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i6p1a9haFzUjwrgCkocPbaFvS4E.jpg'),
(170628, 12066, 'Magi [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/656027.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kHGJT1k4Hnf7aMxIPnBf0sP5ZHi.jpg'),
(170629, 12066, 'Magi [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/656028.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/elVyXi5E7oMcLeWUJcXAfMHyB6z.jpg'),
(170630, 12066, 'Magi [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/656029.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4Cs7RwGHxec7qHff5CJwptsrj1k.jpg'),
(170631, 12066, 'Magi [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/656030.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hL564cR6nWOhZmbSyqjQ8AfD033.jpg'),
(170632, 12066, 'Magi [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/656031.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zTaxuuvTIvnkggcv1SV6Ii9EKAA.jpg'),
(170633, 12066, 'Magi [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/656032.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xTOHbZuHdxkrsLGmZYOXnCr0Qad.jpg'),
(170634, 12066, 'Magi [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/656033.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2apsPAhW7h1giAh8s0OXFSh6fjy.jpg'),
(170635, 12066, 'Magi [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/656034.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zt814g9cgPf1J9ATeUvYulZt0eW.jpg'),
(170636, 12066, 'Magi [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/656035.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qnP895CEe3DDzCdIt9bvbTmw8sa.jpg'),
(170637, 12066, 'Magi [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/656036.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/23DcpENw7iuMjZuDSTTAp0Uhnkw.jpg'),
(170638, 12066, 'Magi [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/656037.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pYgdjeShF9sL1UQfLgEAPUkkLCi.jpg'),
(170639, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/655982.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170640, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/655983.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170641, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/655984.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170642, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/655985.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170643, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/655986.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170644, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/655987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170645, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/655988.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170646, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/655989.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170647, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/655990.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170648, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/655991.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170649, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/655992.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170650, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/655993.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170651, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/655994.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170652, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/655995.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170653, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/655996.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170654, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/655997.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170655, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/655998.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170656, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/655999.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170657, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/656000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170658, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/656001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170659, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/656002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170660, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/656003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170661, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/656004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170662, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/656005.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170663, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/656006.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170664, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/656007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170665, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/656008.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170666, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/656009.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170667, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/656010.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170668, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/656011.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170669, 12067, 'Mau Ladrao Bom Ladrao [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/656012.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zF4FM3tGXrpNB2h9I2wUshr48F.jpg'),
(170670, 11918, 'Mesmo Assim As Formas do Amor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/655974.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hPXEwYiUmXFS9SY7yUXoX45tmHv.jpg'),
(170671, 11918, 'Mesmo Assim As Formas do Amor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/655975.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fKH3LTQdrKg0OY6KGvDkBLpGmtp.jpg'),
(170672, 11918, 'Mesmo Assim As Formas do Amor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/655976.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1AS8zvQ2ZG1YvyrsRvacU3xAUTA.jpg'),
(170673, 11918, 'Mesmo Assim As Formas do Amor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/655977.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/weti72AloTzZEWVK25frkQPqjR7.jpg'),
(170674, 11918, 'Mesmo Assim As Formas do Amor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/655978.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dFlUv0nCU5Qn99l4JOsEraRxuV5.jpg'),
(170675, 11918, 'Mesmo Assim As Formas do Amor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/655979.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2PPPIljBub4EBk7in0flvI8MtGa.jpg'),
(170676, 11918, 'Mesmo Assim As Formas do Amor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/655980.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6IXH75jU1McO7JPMC25bzkVn2ll.jpg'),
(170677, 11918, 'Mesmo Assim As Formas do Amor [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/655981.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v4bD1lWmwcAYi4ShqcOZQ14Ggkc.jpg'),
(170678, 12068, 'Meu Empregado Domestico Nagisa [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/655964.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mGEscFohgq4QKWNbso8mIeabSLA.jpg'),
(170679, 12068, 'Meu Empregado Domestico Nagisa [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/655965.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zXnlYoSeD9Ts39rOhlPTdEyWjUX.jpg'),
(170680, 12068, 'Meu Empregado Domestico Nagisa [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/655966.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bbVKxAQTuKB9OqSyEoPGx9nxxjc.jpg'),
(170681, 12068, 'Meu Empregado Domestico Nagisa [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/655967.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mBmyV05GGIIKvNgo3wvPBncuSYS.jpg'),
(170682, 12068, 'Meu Empregado Domestico Nagisa [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/655968.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bj6udO7GZsszogVrjtEnppyFKCj.jpg'),
(170683, 12068, 'Meu Empregado Domestico Nagisa [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/655969.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/orbsb1x0r3zAjAuf7cA38Fw53Sl.jpg'),
(170684, 12068, 'Meu Empregado Domestico Nagisa [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/655970.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eXLQvdsxR1F7XbrmoSi77PHFCdF.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(170685, 12068, 'Meu Empregado Domestico Nagisa [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/655971.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vraQ6ykt7Hxgz1xIibf8slJXALS.jpg'),
(170686, 12068, 'Meu Empregado Domestico Nagisa [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/655972.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iV1QBNyiQQKd0GXWMxXNs5lXEjd.jpg'),
(170687, 12068, 'Meu Empregado Domestico Nagisa [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/655973.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/djStdZH33QYMtcvYCojB0c14OaX.jpg'),
(170688, 12069, 'Ms Ma Nemesis [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/655932.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170689, 12069, 'Ms Ma Nemesis [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/655933.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170690, 12069, 'Ms Ma Nemesis [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/655934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170691, 12069, 'Ms Ma Nemesis [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/655935.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170692, 12069, 'Ms Ma Nemesis [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/655936.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170693, 12069, 'Ms Ma Nemesis [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/655937.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170694, 12069, 'Ms Ma Nemesis [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/655938.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170695, 12069, 'Ms Ma Nemesis [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/655939.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170696, 12069, 'Ms Ma Nemesis [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/655940.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170697, 12069, 'Ms Ma Nemesis [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/655941.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170698, 12069, 'Ms Ma Nemesis [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/655942.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170699, 12069, 'Ms Ma Nemesis [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/655943.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170700, 12069, 'Ms Ma Nemesis [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/655944.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170701, 12069, 'Ms Ma Nemesis [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/655945.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170702, 12069, 'Ms Ma Nemesis [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/655946.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170703, 12069, 'Ms Ma Nemesis [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/655947.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170704, 12069, 'Ms Ma Nemesis [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/655948.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170705, 12069, 'Ms Ma Nemesis [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/655949.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170706, 12069, 'Ms Ma Nemesis [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/655950.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170707, 12069, 'Ms Ma Nemesis [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/655951.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170708, 12069, 'Ms Ma Nemesis [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/655952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170709, 12069, 'Ms Ma Nemesis [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/655953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170710, 12069, 'Ms Ma Nemesis [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/655954.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170711, 12069, 'Ms Ma Nemesis [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/655955.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170712, 12069, 'Ms Ma Nemesis [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/655956.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170713, 12069, 'Ms Ma Nemesis [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/655957.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170714, 12069, 'Ms Ma Nemesis [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/655958.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170715, 12069, 'Ms Ma Nemesis [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/655959.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170716, 12069, 'Ms Ma Nemesis [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/655960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170717, 12069, 'Ms Ma Nemesis [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/655961.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170718, 12069, 'Ms Ma Nemesis [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/655962.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170719, 12069, 'Ms Ma Nemesis [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/655963.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/4FnMzT8x3fwXEGlD0XcYPtvkTC8.jpg'),
(170720, 12070, 'Ressuscite Meu Coracao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/655925.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gyJLGpiJT8AnyNEu8EwMCZzm9id.jpg'),
(170721, 12070, 'Ressuscite Meu Coracao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/655926.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wqt4B78CEHX1bXwoFwAKeHuoLiz.jpg'),
(170722, 12070, 'Ressuscite Meu Coracao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/655927.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jU5E96pHuTdFJ7NiZDjfmzBm4nQ.jpg'),
(170723, 12070, 'Ressuscite Meu Coracao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/655928.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vUlA6dkp7TFqgFsTYhi2Qj40ncS.jpg'),
(170724, 12070, 'Ressuscite Meu Coracao [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/655929.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aQwrSIZ6TbhNPRi2WwHYwJLNvRI.jpg'),
(170725, 12070, 'Ressuscite Meu Coracao [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/655930.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8nQvK2KbmpnemUyuxnoThF4iP8T.jpg'),
(170726, 12070, 'Ressuscite Meu Coracao [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/655931.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/btiaBH4QYHLEj1Ximk1Ce9RZgDg.jpg'),
(170727, 12071, 'Saiki Kusuo no Psi nan [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/655901.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jqX5diOEMpQEvZKjR1jQcptrbcc.jpg'),
(170728, 12071, 'Saiki Kusuo no Psi nan [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/655902.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k5YXgdznD35iNN7KbaPfXnid9mR.jpg'),
(170729, 12071, 'Saiki Kusuo no Psi nan [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/655903.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/MlRRzY8G3jTWxxY6jXtU0kWx8d.jpg'),
(170730, 12071, 'Saiki Kusuo no Psi nan [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/655904.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ajSJwLytND93hwwCN8nFIRf1Qj7.jpg'),
(170731, 12071, 'Saiki Kusuo no Psi nan [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/655905.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g1QDDVtwHotklzGGBRRPOeAIVta.jpg'),
(170732, 12071, 'Saiki Kusuo no Psi nan [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/655906.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3D0kBrFZPBPcL4WloyZRoMgo0nk.jpg'),
(170733, 12071, 'Saiki Kusuo no Psi nan [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/655907.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5AQqyF8gXRQeiMe46thTNIwhY87.jpg'),
(170734, 12071, 'Saiki Kusuo no Psi nan [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/655908.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nv9jDMpCgeMvGgNbJ5KkPVrk4sz.jpg'),
(170735, 12071, 'Saiki Kusuo no Psi nan [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/655909.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cNdKWc6JSLpUShpvfnvFFDSakM0.jpg'),
(170736, 12071, 'Saiki Kusuo no Psi nan [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/655910.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mHkHiO8iibcxfICVdrHk1SQQUjj.jpg'),
(170737, 12071, 'Saiki Kusuo no Psi nan [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/655911.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vFKA8XIBUrL4AA2XWYhiMDQiyaV.jpg'),
(170738, 12071, 'Saiki Kusuo no Psi nan [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/655912.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uOh1nXmhunrT8x2lekBsuFheSTB.jpg'),
(170739, 12071, 'Saiki Kusuo no Psi nan [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/655913.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o8tQQ9sOpoj3e6uz4jXCYIjsYCW.jpg'),
(170740, 12071, 'Saiki Kusuo no Psi nan [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/655914.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zPPvoP2kHeEZj80WlEuWPFFcxAB.jpg'),
(170741, 12071, 'Saiki Kusuo no Psi nan [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/655915.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a7DaJC84zgOzp1RmWZxBA3o8mp5.jpg'),
(170742, 12071, 'Saiki Kusuo no Psi nan [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/655916.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1QZPo7u54ahobrj05DjhNl9IDTy.jpg'),
(170743, 12071, 'Saiki Kusuo no Psi nan [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/655917.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sHnJP34wNFgOQtDoEeI3k8FKFm6.jpg'),
(170744, 12071, 'Saiki Kusuo no Psi nan [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/655918.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rK5V7T5bXcTCJZeI84XnKJClxhR.jpg'),
(170745, 12071, 'Saiki Kusuo no Psi nan [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/655919.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y1E33w0f4zN3SknX5kylX2JcQRJ.jpg'),
(170746, 12071, 'Saiki Kusuo no Psi nan [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/655920.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6OBqbGFa0bndWanec5LjByUDj3u.jpg'),
(170747, 12071, 'Saiki Kusuo no Psi nan [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/655921.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kTJmriLD5UWnweAoNebxp3no9Ue.jpg'),
(170748, 12071, 'Saiki Kusuo no Psi nan [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/655922.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bS1MeQCBcC8Z6i34dCP115wvWHS.jpg'),
(170749, 12071, 'Saiki Kusuo no Psi nan [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/655923.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lq4V1POVqfjwDqk5G6DlslgBNX3.jpg'),
(170750, 12071, 'Saiki Kusuo no Psi nan [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/655924.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4FwCs0TFgitlLdDDrLrR2p0Wvsy.jpg'),
(170751, 12072, 'Saiki Kusuo no Psi nan [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/667416.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170752, 12072, 'Saiki Kusuo no Psi nan [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/667417.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170753, 12072, 'Saiki Kusuo no Psi nan [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/667418.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170754, 12072, 'Saiki Kusuo no Psi nan [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/667419.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170755, 12072, 'Saiki Kusuo no Psi nan [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/667420.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170756, 12072, 'Saiki Kusuo no Psi nan [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/667421.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170757, 12072, 'Saiki Kusuo no Psi nan [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/667422.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170758, 12072, 'Saiki Kusuo no Psi nan [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/667423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170759, 12072, 'Saiki Kusuo no Psi nan [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/667424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170760, 12072, 'Saiki Kusuo no Psi nan [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/667425.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170761, 12072, 'Saiki Kusuo no Psi nan [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/667426.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170762, 12072, 'Saiki Kusuo no Psi nan [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/667427.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170763, 12072, 'Saiki Kusuo no Psi nan [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/667428.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170764, 12072, 'Saiki Kusuo no Psi nan [L] S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/667429.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170765, 12072, 'Saiki Kusuo no Psi nan [L] S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/667430.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170766, 12072, 'Saiki Kusuo no Psi nan [L] S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/667431.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170767, 12072, 'Saiki Kusuo no Psi nan [L] S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/667432.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170768, 12072, 'Saiki Kusuo no Psi nan [L] S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/667433.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170769, 12072, 'Saiki Kusuo no Psi nan [L] S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/667434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170770, 12072, 'Saiki Kusuo no Psi nan [L] S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/667435.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170771, 12072, 'Saiki Kusuo no Psi nan [L] S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/667436.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170772, 12072, 'Saiki Kusuo no Psi nan [L] S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/667437.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170773, 12072, 'Saiki Kusuo no Psi nan [L] S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/667438.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170774, 12072, 'Saiki Kusuo no Psi nan [L] S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/667439.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tpym31HVeQgenaubvCxkMF3kFHy.jpg'),
(170775, 12073, 'Seis Zeros [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/655893.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56X2nhHmGLmpSxZEhEkQ3Rqsa0A.jpg'),
(170776, 12073, 'Seis Zeros [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/655894.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56X2nhHmGLmpSxZEhEkQ3Rqsa0A.jpg'),
(170777, 12073, 'Seis Zeros [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/655895.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56X2nhHmGLmpSxZEhEkQ3Rqsa0A.jpg'),
(170778, 12073, 'Seis Zeros [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/655896.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56X2nhHmGLmpSxZEhEkQ3Rqsa0A.jpg'),
(170779, 12073, 'Seis Zeros [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/655897.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56X2nhHmGLmpSxZEhEkQ3Rqsa0A.jpg'),
(170780, 12073, 'Seis Zeros [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/655898.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56X2nhHmGLmpSxZEhEkQ3Rqsa0A.jpg'),
(170781, 12073, 'Seis Zeros [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/655899.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56X2nhHmGLmpSxZEhEkQ3Rqsa0A.jpg'),
(170782, 12073, 'Seis Zeros [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/655900.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/56X2nhHmGLmpSxZEhEkQ3Rqsa0A.jpg'),
(170783, 12074, 'UniteUp [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/655881.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8yjAs7TCGX7sWHpGSXR5Ryjh5rW.jpg'),
(170784, 12074, 'UniteUp [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/655882.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zq138tI0KDTZT5ri27JCf8ua5Zg.jpg'),
(170785, 12074, 'UniteUp [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/655883.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5kOZvATORJwgwJWjt1sbRQfhnJr.jpg'),
(170786, 12074, 'UniteUp [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/655884.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kNQGm589SL0qg97ipDWBD5tOtKp.jpg'),
(170787, 12074, 'UniteUp [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/655885.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xY1rIPsP9hvAYAQcCeI0Cuqe6bu.jpg'),
(170788, 12074, 'UniteUp [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/655886.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/67BgZokTQ5FJaUk41mwvwAdrWyR.jpg'),
(170789, 12074, 'UniteUp [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/655887.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vLUcCinJ4nsr5elEDOsNwISkCIw.jpg'),
(170790, 12074, 'UniteUp [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/655888.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ivdPuoZPv3XG9cnj7KKBSGIcOsq.jpg'),
(170791, 12074, 'UniteUp [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/655889.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xwrCQtdGbZtfWTNF7xHmGiaIvbJ.jpg'),
(170792, 12074, 'UniteUp [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/655890.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h3ySV18kJbs0r6ihp8rTfK13kQF.jpg'),
(170793, 12074, 'UniteUp [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/655891.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Wz8edOjAHM938IfMpop4XhdVMa.jpg'),
(170794, 12074, 'UniteUp [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/655892.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/os2Dc5FCfq7iwBjAmApgIJBCfzj.jpg'),
(170795, 12075, 'UniteUp [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/674593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hTmTMf5MyQbizGGfcY6dkYJcAwP.jpg'),
(170796, 12075, 'UniteUp [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/667182.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hTmTMf5MyQbizGGfcY6dkYJcAwP.jpg'),
(170797, 12075, 'UniteUp [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/674595.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hTmTMf5MyQbizGGfcY6dkYJcAwP.jpg'),
(170798, 12075, 'UniteUp [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/688206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hTmTMf5MyQbizGGfcY6dkYJcAwP.jpg'),
(170799, 12075, 'UniteUp [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/697160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hTmTMf5MyQbizGGfcY6dkYJcAwP.jpg'),
(170800, 12075, 'UniteUp [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/703751.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hTmTMf5MyQbizGGfcY6dkYJcAwP.jpg'),
(170801, 12075, 'UniteUp [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/736660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hTmTMf5MyQbizGGfcY6dkYJcAwP.jpg'),
(170802, 12075, 'UniteUp [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/736661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hTmTMf5MyQbizGGfcY6dkYJcAwP.jpg'),
(170803, 12075, 'UniteUp [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/749964.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hTmTMf5MyQbizGGfcY6dkYJcAwP.jpg'),
(170804, 12075, 'UniteUp [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/757744.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hTmTMf5MyQbizGGfcY6dkYJcAwP.jpg'),
(170805, 12075, 'UniteUp [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/757745.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hTmTMf5MyQbizGGfcY6dkYJcAwP.jpg'),
(170806, 12075, 'UniteUp [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/736662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hTmTMf5MyQbizGGfcY6dkYJcAwP.jpg'),
(170807, 12075, 'UniteUp [L] S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/736663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hTmTMf5MyQbizGGfcY6dkYJcAwP.jpg'),
(170808, 12076, 'Venha E Me Abrace [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/655849.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fapN6veC3jf0fsOGHdPxeTPmqbZ.jpg'),
(170809, 12076, 'Venha E Me Abrace [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/655850.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v7HF9yxdoMbgqzoCNnpeVGivWs5.jpg'),
(170810, 12076, 'Venha E Me Abrace [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/655851.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oDNIJy70AH7mosNLqSbTa4FBLDy.jpg'),
(170811, 12076, 'Venha E Me Abrace [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/655852.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c9lbDbDB45vJpzaHax94hZwHXkL.jpg'),
(170812, 12076, 'Venha E Me Abrace [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/655853.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mKCIImY7wvB8N1Ft1dVQ6L0uEB5.jpg'),
(170813, 12076, 'Venha E Me Abrace [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/655854.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mKgowfbuYhDpzsMpYn7AmhJaagV.jpg'),
(170814, 12076, 'Venha E Me Abrace [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/655855.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lDB6mjD1PO00JcxkLMRDG4ytfNt.jpg'),
(170815, 12076, 'Venha E Me Abrace [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/655856.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l8pdnJ8oydRJJHwKA7XFz7y6lzb.jpg'),
(170816, 12076, 'Venha E Me Abrace [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/655857.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/53IfDcGnOVAK3lLuNvFfug49lun.jpg'),
(170817, 12076, 'Venha E Me Abrace [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/655858.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aXnDChYWUhkVO1btntdkYZXRvXn.jpg'),
(170818, 12076, 'Venha E Me Abrace [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/655859.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xR3OPXBOKZfw3XxJal9RuxlejPl.jpg'),
(170819, 12076, 'Venha E Me Abrace [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/655860.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bs6l4LWOuYAwpIvTvRFkKxBSspJ.jpg'),
(170820, 12076, 'Venha E Me Abrace [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/655861.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q40i9NJfIk2md1EtD47Od7GQZao.jpg'),
(170821, 12076, 'Venha E Me Abrace [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/655862.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fMpyJvJuYvijbfetv8x7DC5NvLa.jpg'),
(170822, 12076, 'Venha E Me Abrace [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/655863.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jw6sLmy9rpes8c8605MeteQq3hA.jpg'),
(170823, 12076, 'Venha E Me Abrace [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/655864.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w2rClXwom7to7HLU04akafMoIQM.jpg'),
(170824, 12076, 'Venha E Me Abrace [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/655865.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q9txjyKBtzNS6ZqvZH5dDgMqz1O.jpg'),
(170825, 12076, 'Venha E Me Abrace [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/655866.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gc4OwZO6kPgHzVQERShM1BXNTx6.jpg'),
(170826, 12076, 'Venha E Me Abrace [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/655867.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5vua8bDGyFNIEqyFKiZyOxS3yhC.jpg'),
(170827, 12076, 'Venha E Me Abrace [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/655868.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/onj6qwjRKlpBuGfKUy9MHnz0hjC.jpg'),
(170828, 12076, 'Venha E Me Abrace [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/655869.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8qwfnSkYtNkOQp6H4FNmpRXFBlN.jpg'),
(170829, 12076, 'Venha E Me Abrace [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/655870.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hDM5kIRNsqlXHfpNSLsIr88VCb3.jpg'),
(170830, 12076, 'Venha E Me Abrace [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/655871.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8gC4ltV8c5bmbqZZFrFBtrwlCPG.jpg'),
(170831, 12076, 'Venha E Me Abrace [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/655872.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vdwdZpRcU1Jymp9gQjA9WZy8I5u.jpg'),
(170832, 12076, 'Venha E Me Abrace [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/655873.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xv6hnObNXF0u7z5J6zxQFxSaSlz.jpg'),
(170833, 12076, 'Venha E Me Abrace [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/655874.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4ofs2eqnOxEjRCL0Rb3fshEZb1Y.jpg'),
(170834, 12076, 'Venha E Me Abrace [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/655875.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wiXnYCdJDpwxVRdgppbO5HaR8SC.jpg'),
(170835, 12076, 'Venha E Me Abrace [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/655876.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8SpPovKX4raMwEuJerH5xTDNsyq.jpg'),
(170836, 12076, 'Venha E Me Abrace [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/655877.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ejmcEPgvjlU5XXCHnReQnlYr8CV.jpg'),
(170837, 12076, 'Venha E Me Abrace [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/655878.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/stU5z2ZbBYuwaY5HmRFKpr27nwf.jpg'),
(170838, 12076, 'Venha E Me Abrace [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/655879.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c1RxM1nTudHaOu4IGbUScfhDYkY.jpg'),
(170839, 12076, 'Venha E Me Abrace [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/655880.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4tlXfG87NprxAt8H8fJINZc0kcq.jpg'),
(170840, 12077, 'Woman of 9 9 Billion [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/655817.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ikt5Uhc8r5RUYZksmrxBvRqk9hY.jpg'),
(170841, 12077, 'Woman of 9 9 Billion [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/655818.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gKgHiNQzAMUf0e7VzLEqo4Pe50k.jpg'),
(170842, 12077, 'Woman of 9 9 Billion [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/655819.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/19bmrKOmcDsUmGgUCaeoWoENP0c.jpg'),
(170843, 12077, 'Woman of 9 9 Billion [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/655820.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lkHLXt5dAtDXXNn29MrEqhqOOiZ.jpg'),
(170844, 12077, 'Woman of 9 9 Billion [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/655821.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/85d4oy6ZaJj3dCSGTH8zpiKY27.jpg'),
(170845, 12077, 'Woman of 9 9 Billion [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/655822.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1ee4A8xX4PMXRcdDrQAmepc37T6.jpg'),
(170846, 12077, 'Woman of 9 9 Billion [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/655823.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pr5kNzpRwipfqSmLIi5Uk5eQHvo.jpg'),
(170847, 12077, 'Woman of 9 9 Billion [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/655824.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1bifAKbdHOTIn8i2QriOdU9DEQu.jpg'),
(170848, 12077, 'Woman of 9 9 Billion [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/655825.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1bRg9gjFLhBvzo7zro3c6JxivwV.jpg'),
(170849, 12077, 'Woman of 9 9 Billion [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/655826.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ebco2wFPjL7uAqNxDNVxGhyemMB.jpg'),
(170850, 12077, 'Woman of 9 9 Billion [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/655827.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iH3D7uxMQumwWFH1rzyjrS7UWtP.jpg'),
(170851, 12077, 'Woman of 9 9 Billion [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/655828.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fIkxdGFrQdsOOv0kNyrr1w9MWOG.jpg'),
(170852, 12077, 'Woman of 9 9 Billion [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/655829.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/af2nJJXbdoUtfYcIGqhRplIxnsD.jpg'),
(170853, 12077, 'Woman of 9 9 Billion [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/655830.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vaE81bZJfPtp8t4hia21PH1CGm7.jpg'),
(170854, 12077, 'Woman of 9 9 Billion [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/655831.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6Kx2IMPTSMBqlECncof1SduVAjg.jpg'),
(170855, 12077, 'Woman of 9 9 Billion [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/655832.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9tnmofWuluQeICDbVeWDhZiSHC5.jpg'),
(170856, 12077, 'Woman of 9 9 Billion [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/655833.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8E7nQN1wdsvDH4jTRJlcHCJBOcD.jpg'),
(170857, 12077, 'Woman of 9 9 Billion [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/655834.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w6SIe4fgcrqrajWTuxEgN24jhPN.jpg'),
(170858, 12077, 'Woman of 9 9 Billion [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/655835.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/smGldh7X990VnZ3hETAzekz9MoI.jpg'),
(170859, 12077, 'Woman of 9 9 Billion [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/655836.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eZv8SJe5nDEdGIRe2aXCLdI5p6p.jpg'),
(170860, 12077, 'Woman of 9 9 Billion [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/655837.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7mMAYkoF3WJ0Ntq4RvP5sMjbGoG.jpg'),
(170861, 12077, 'Woman of 9 9 Billion [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/655838.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/maLv2VFmwN4LaqKeArzkgcYazx.jpg'),
(170862, 12077, 'Woman of 9 9 Billion [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/655839.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lEdl3RHYk2h4nONG0jcLtD6qdRx.jpg'),
(170863, 12077, 'Woman of 9 9 Billion [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/655840.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rRoYcE5IZVO0pup5RKPkokGAHkJ.jpg'),
(170864, 12077, 'Woman of 9 9 Billion [L] S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/655841.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aAQHyRKYXynEX6hZXkFRNNYm2gt.jpg'),
(170865, 12077, 'Woman of 9 9 Billion [L] S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/655842.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6aMYM2yBjSR6tpJeIgLzdzljKPN.jpg'),
(170866, 12077, 'Woman of 9 9 Billion [L] S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/655843.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f7G1Zw3L6gTdFlZujQK3rrNdCbN.jpg'),
(170867, 12077, 'Woman of 9 9 Billion [L] S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/655844.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ksAAHwONK1qp5SGfLYbJAVZltl2.jpg'),
(170868, 12077, 'Woman of 9 9 Billion [L] S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/655845.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dj4sfKfagZQiPKPhtfuCERpEU3K.jpg'),
(170869, 12077, 'Woman of 9 9 Billion [L] S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/655846.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bPOz3i6ytnwquVC4hizk8wmjnS.jpg'),
(170870, 12077, 'Woman of 9 9 Billion [L] S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/655847.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jMana1S7HgVNRbULgOLedLIzzze.jpg'),
(170871, 12077, 'Woman of 9 9 Billion [L] S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/655848.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/itXNDvoBDy935Kci0FyryOSVDrE.jpg'),
(170872, 12078, 'Pergunte as Estrelas S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/655816.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vwmlAnqJQ6ekiJeavrVgsHLutEa.jpg'),
(170873, 12078, 'Pergunte as Estrelas S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/660197.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FncOYHHibrvOhePbaTXokd6QbV.jpg'),
(170874, 12078, 'Pergunte as Estrelas S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/660198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FncOYHHibrvOhePbaTXokd6QbV.jpg'),
(170875, 12078, 'Pergunte as Estrelas S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/660199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FncOYHHibrvOhePbaTXokd6QbV.jpg'),
(170876, 12078, 'Pergunte as Estrelas S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/667777.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FncOYHHibrvOhePbaTXokd6QbV.jpg'),
(170877, 12078, 'Pergunte as Estrelas S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/669227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FncOYHHibrvOhePbaTXokd6QbV.jpg'),
(170878, 12078, 'Pergunte as Estrelas S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/674904.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FncOYHHibrvOhePbaTXokd6QbV.jpg'),
(170879, 12078, 'Pergunte as Estrelas S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/674905.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FncOYHHibrvOhePbaTXokd6QbV.jpg'),
(170880, 12078, 'Pergunte as Estrelas S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/871001.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nvNTiYSVy4h77aLxLx2EgsnEiOl.jpg'),
(170881, 12078, 'Pergunte as Estrelas S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/871002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/M3qXNUZG13WQLiSwXjWXgnEoW.jpg'),
(170882, 12078, 'Pergunte as Estrelas S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/688450.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FncOYHHibrvOhePbaTXokd6QbV.jpg'),
(170883, 12078, 'Pergunte as Estrelas S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/688451.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FncOYHHibrvOhePbaTXokd6QbV.jpg'),
(170884, 12078, 'Pergunte as Estrelas S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/699579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FncOYHHibrvOhePbaTXokd6QbV.jpg'),
(170885, 12078, 'Pergunte as Estrelas S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/699580.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FncOYHHibrvOhePbaTXokd6QbV.jpg'),
(170886, 12078, 'Pergunte as Estrelas S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/704373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FncOYHHibrvOhePbaTXokd6QbV.jpg'),
(170887, 12078, 'Pergunte as Estrelas S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/704374.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3FncOYHHibrvOhePbaTXokd6QbV.jpg'),
(170888, 12079, 'ZENSHU S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/655815.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tUsDiWuaB2YC2B79FkvgF6H2LYd.jpg'),
(170889, 12079, 'ZENSHU S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/667073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hiLf3JKUghjhCjDCv3hKKsWtA4S.jpg'),
(170890, 12079, 'ZENSHU S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/671069.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hiLf3JKUghjhCjDCv3hKKsWtA4S.jpg'),
(170891, 12079, 'ZENSHU S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/674540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hiLf3JKUghjhCjDCv3hKKsWtA4S.jpg'),
(170892, 12079, 'ZENSHU S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/688078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hiLf3JKUghjhCjDCv3hKKsWtA4S.jpg'),
(170893, 12079, 'ZENSHU S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/699423.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hiLf3JKUghjhCjDCv3hKKsWtA4S.jpg'),
(170894, 12079, 'ZENSHU S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/703576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hiLf3JKUghjhCjDCv3hKKsWtA4S.jpg'),
(170895, 12079, 'ZENSHU S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/720612.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hiLf3JKUghjhCjDCv3hKKsWtA4S.jpg'),
(170896, 12079, 'ZENSHU S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/720613.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hiLf3JKUghjhCjDCv3hKKsWtA4S.jpg'),
(170897, 12079, 'ZENSHU S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/728371.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hiLf3JKUghjhCjDCv3hKKsWtA4S.jpg'),
(170898, 12079, 'ZENSHU S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/736476.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hiLf3JKUghjhCjDCv3hKKsWtA4S.jpg'),
(170899, 12080, 'Tower of God S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657249.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hhDXLaY8458wbL1k7oOm6sUrTZy.jpg'),
(170900, 12080, 'Tower of God S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657250.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3luCcef8HLyX0xSvo1dDxXxDMLA.jpg'),
(170901, 12080, 'Tower of God S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657251.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ssQDfI6iXtdHKeTTHGG4j1bSgiC.jpg'),
(170902, 12080, 'Tower of God S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/657252.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sURF143QfDcJ2FPpB7cNHgvfY4B.jpg'),
(170903, 12080, 'Tower of God S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/657253.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c9pKszVjPF0Fk3o0CSyzwhjGPAq.jpg'),
(170904, 12080, 'Tower of God S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/657254.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xgan2UAwoiuA7nwS7UjBZVuDQOy.jpg'),
(170905, 12080, 'Tower of God S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/657255.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3SsyBk35fB99VF0ZaTpAhFkRX85.jpg'),
(170906, 12080, 'Tower of God S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/657256.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hmGXloYCfQwOk0WLnB7DDPrzwvI.jpg'),
(170907, 12080, 'Tower of God S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/657257.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fmlzGoaC5bMkFaluAMqWnTPhUIh.jpg'),
(170908, 12080, 'Tower of God S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/657258.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gqjmyCpTDdqK7OhxATkG02aOTBA.jpg'),
(170909, 12080, 'Tower of God S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/657259.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1bYHFRXrDjfKwnMnq6TPbBGJn2O.jpg'),
(170910, 12080, 'Tower of God S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/657260.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dPX1YxQhI6eaWYb5ckbAOZWltPE.jpg'),
(170911, 12080, 'Tower of God S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/657261.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tBuI6Hcq1lSWmMdxLnWknCWgX0V.jpg'),
(170912, 12081, 'Tower of God S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/667221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170913, 12081, 'Tower of God S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/667222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170914, 12081, 'Tower of God S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/667223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170915, 12081, 'Tower of God S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/667224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170916, 12081, 'Tower of God S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/667225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170917, 12081, 'Tower of God S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/667226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170918, 12081, 'Tower of God S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/667227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170919, 12081, 'Tower of God S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/667228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170920, 12081, 'Tower of God S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/667229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170921, 12081, 'Tower of God S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/667230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170922, 12081, 'Tower of God S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/667231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170923, 12081, 'Tower of God S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/667232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170924, 12081, 'Tower of God S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/667233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170925, 12081, 'Tower of God S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/667234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170926, 12081, 'Tower of God S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/667235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170927, 12081, 'Tower of God S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/667236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170928, 12081, 'Tower of God S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/667237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170929, 12081, 'Tower of God S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/667238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170930, 12081, 'Tower of God S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/667239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170931, 12081, 'Tower of God S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/667240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170932, 12081, 'Tower of God S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/667241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170933, 12081, 'Tower of God S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/667242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170934, 12081, 'Tower of God S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/669129.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170935, 12081, 'Tower of God S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/674675.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170936, 12081, 'Tower of God S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/688251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fUs9KMgEJj3wYJGa75MtPSdyJXk.jpg'),
(170937, 12082, 'A Grande Descoberta S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657230.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1YJupAvyd3ueKx8vpWVhEgoaeww.jpg'),
(170938, 12082, 'A Grande Descoberta S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657231.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2NyovgUn6ICRofbxnROtjw7Kwrz.jpg'),
(170939, 12082, 'A Grande Descoberta S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657232.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/igP1pIVBWFlQx8mXDkPGbKhPF5Z.jpg'),
(170940, 12082, 'A Grande Descoberta S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/657233.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/br2U3nZnaODku9NM11HYj8esQ3n.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(170941, 12083, 'Jerry Springer Brigas Camera Acao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657228.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nsYQh9zF5gnWzMtACuZyfzfQHzU.jpg'),
(170942, 12083, 'Jerry Springer Brigas Camera Acao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657229.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aD4UpGFwkvE9GrQh82GxX49LPZm.jpg'),
(170943, 12084, 'Mexicanicos Sem Fronteiras S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657224.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uquJHaloWfU7IA87aUnL1AHLyrg.jpg'),
(170944, 12084, 'Mexicanicos Sem Fronteiras S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657225.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y104w3fvwU0VriGhUTNrPhCdOFS.jpg'),
(170945, 12084, 'Mexicanicos Sem Fronteiras S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657226.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tGJB1r2iF4c2zKrmWn3By1mteSF.jpg'),
(170946, 12084, 'Mexicanicos Sem Fronteiras S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/657227.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6wzNC3gbSRd8yMoX1KQpz7pckJp.jpg'),
(170947, 12085, 'A Agencia (2024) S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657219.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dtP8VGcSwlZp9x86cB3Y8iVmjJM.jpg'),
(170948, 12085, 'A Agencia (2024) S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657220.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qhPqaFdHuZ6DLoQbrxAt1QQphdH.jpg'),
(170949, 12085, 'A Agencia (2024) S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657221.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uv3kWNuqaFG0rMoWBr4NVVTNtKX.jpg'),
(170950, 12085, 'A Agencia (2024) S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/657222.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gF6BlJvV5gJHQiqzyVh4r5Bbka.jpg'),
(170951, 12085, 'A Agencia (2024) S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/657223.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y3nFQeSkeLrJvxzTmRokJ7Ou7ox.jpg'),
(170952, 12085, 'A Agencia (2024) S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/666387.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRgfl4J0tVt3twmQ3C2zs8N5rG9.jpg'),
(170953, 12085, 'A Agencia (2024) S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/670036.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRgfl4J0tVt3twmQ3C2zs8N5rG9.jpg'),
(170954, 12085, 'A Agencia (2024) S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/676147.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRgfl4J0tVt3twmQ3C2zs8N5rG9.jpg'),
(170955, 12085, 'A Agencia (2024) S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/684198.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRgfl4J0tVt3twmQ3C2zs8N5rG9.jpg'),
(170956, 12085, 'A Agencia (2024) S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/688007.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/mRgfl4J0tVt3twmQ3C2zs8N5rG9.jpg'),
(170957, 12086, '90 Dias De Volta Pra Pista S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657135.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/An4hAFjCu0hseqLn0TFVOkzKbej.jpg'),
(170958, 12086, '90 Dias De Volta Pra Pista S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657136.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fu0tYje9w9nsmqkezBcZ7TSvMaj.jpg'),
(170959, 12086, '90 Dias De Volta Pra Pista S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657137.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sd1DecrzYYfQWiNwWFudSNPrGub.jpg'),
(170960, 12086, '90 Dias De Volta Pra Pista S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/657138.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4DldZKfEfawiS9SKC7nZah7P0Mu.jpg'),
(170961, 12086, '90 Dias De Volta Pra Pista S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/657139.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nDP3TyJKpVcu6EhEPQIhetp17RG.jpg'),
(170962, 12086, '90 Dias De Volta Pra Pista S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/657140.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bsi68dgEbuItGQ2pgFbrDHdyYXS.jpg'),
(170963, 12086, '90 Dias De Volta Pra Pista S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/657141.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z9p0FxP9Of0fVpgPzrWvgPqKEKX.jpg'),
(170964, 12086, '90 Dias De Volta Pra Pista S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/657142.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bX2RvMalLVh1syqc4w43NhmRGtH.jpg'),
(170965, 12086, '90 Dias De Volta Pra Pista S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/657143.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8hLBZRveOc0i2jzwcQXtte7OVL4.jpg'),
(170966, 12086, '90 Dias De Volta Pra Pista S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/657144.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a4foNDiy3EOoEsBMh3x5wa61org.jpg'),
(170967, 12086, '90 Dias De Volta Pra Pista S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/657145.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1UWV2T3RuBFFaiy8MuwbCa9MpHR.jpg'),
(170968, 12086, '90 Dias De Volta Pra Pista S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/657146.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jBooSOoKMj3VonmywJvYwXT7bDw.jpg'),
(170969, 12086, '90 Dias De Volta Pra Pista S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/657147.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8ywORpjhfdBxcAxXxvRUk1KggEr.jpg'),
(170970, 12086, '90 Dias De Volta Pra Pista S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/657148.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7e2RZWHk2sICzJ1ywKmKSx2hnGA.jpg'),
(170971, 12086, '90 Dias De Volta Pra Pista S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/657149.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qAsBn1H3SANMtjjf2QT2ungtuGd.jpg'),
(170972, 12086, '90 Dias De Volta Pra Pista S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/657150.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6BRzxGbXGEgyVTdW3MK69vpMQtw.jpg'),
(170973, 12087, 'A Colina do Cao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657130.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wE1UZRG3NMb62OiN2sJ018QC1XA.jpg'),
(170974, 12087, 'A Colina do Cao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657131.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pobmdiHxk5Oh7VsFsGEHE8fI3nG.jpg'),
(170975, 12087, 'A Colina do Cao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657132.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w6IuoRSJGpLKdI1owikWOVDwlB2.jpg'),
(170976, 12087, 'A Colina do Cao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/657133.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/poKkytE2Q46xtmUslOQ0z68S7zj.jpg'),
(170977, 12087, 'A Colina do Cao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/657134.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y8XtqaTe3OzykUUcQW5VUpAZbNC.jpg'),
(170978, 12088, 'Arifureta Shokugyou de Sekai Saikyou S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657093.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vYRwsbbeJaPqee9SuOncIHylzWs.jpg'),
(170979, 12088, 'Arifureta Shokugyou de Sekai Saikyou S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657094.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wP5v2vwzYRllPcHMoAZM1hDpscn.jpg'),
(170980, 12088, 'Arifureta Shokugyou de Sekai Saikyou S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657095.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cKlNiuPs8CQ7nmShzEQEfhPeTpj.jpg'),
(170981, 12088, 'Arifureta Shokugyou de Sekai Saikyou S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/657096.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ujqe8gUdN1G1YoSwtUXTJOlWiKd.jpg'),
(170982, 12088, 'Arifureta Shokugyou de Sekai Saikyou S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/657097.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bT9TvTW2irw4vfnjKe2VUFx4fEd.jpg'),
(170983, 12088, 'Arifureta Shokugyou de Sekai Saikyou S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/657098.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jRWHz8qE5XZGhyS4pzwwRNuAYAS.jpg'),
(170984, 12088, 'Arifureta Shokugyou de Sekai Saikyou S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/657099.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Ar5awzepQC8KXJ2IkM1JDLiTOYr.jpg'),
(170985, 12088, 'Arifureta Shokugyou de Sekai Saikyou S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/657100.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aAw9VccOTlRKF4WmmJE9Iy3GeA8.jpg'),
(170986, 12088, 'Arifureta Shokugyou de Sekai Saikyou S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/657101.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eS16JWTo1LoARoqyWshA6fT6zWB.jpg'),
(170987, 12088, 'Arifureta Shokugyou de Sekai Saikyou S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/657102.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nv2wouuE85ZIJhQJqRFs55PWPru.jpg'),
(170988, 12088, 'Arifureta Shokugyou de Sekai Saikyou S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/657103.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tBcEiVBIj7oNL3C5dzyvWudhqwp.jpg'),
(170989, 12088, 'Arifureta Shokugyou de Sekai Saikyou S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/657104.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4DzUIncMcKUNxkrmuspdCZHcTlK.jpg'),
(170990, 12088, 'Arifureta Shokugyou de Sekai Saikyou S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/657105.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ifh7i8hcGOPb6YfRvEuZaPH3gwr.jpg'),
(170991, 12088, 'Arifureta Shokugyou de Sekai Saikyou S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/657106.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3vwcB2MtQA1VZMCljCRSrDzNzdj.jpg'),
(170992, 12088, 'Arifureta Shokugyou de Sekai Saikyou S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/657107.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3vwcB2MtQA1VZMCljCRSrDzNzdj.jpg'),
(170993, 12089, 'Arifureta Shokugyou de Sekai Saikyou S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657108.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dRFkdtXawUJVztvL16iP1FbHYH6.jpg'),
(170994, 12089, 'Arifureta Shokugyou de Sekai Saikyou S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657109.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wYlovCZ3qJnXKE6OU71u98nmSHf.jpg'),
(170995, 12089, 'Arifureta Shokugyou de Sekai Saikyou S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657110.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s9FtKw1aGlnelP2JTnNNctIJzhC.jpg'),
(170996, 12089, 'Arifureta Shokugyou de Sekai Saikyou S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/657111.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oHs0gU1P9NuIxqa17pA3aE41VMJ.jpg'),
(170997, 12089, 'Arifureta Shokugyou de Sekai Saikyou S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/657112.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6ee1pgZ5010VosDgdaEXvhrwvIf.jpg'),
(170998, 12089, 'Arifureta Shokugyou de Sekai Saikyou S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/657113.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yVAJvZOjbpD0qSXC1rFGWLevEAL.jpg'),
(170999, 12089, 'Arifureta Shokugyou de Sekai Saikyou S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/657114.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/giXGNGvlT3Ds9Hjr5VTCyyovfos.jpg'),
(171000, 12089, 'Arifureta Shokugyou de Sekai Saikyou S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/657115.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/byKrAZJvLkbq391zMY8dlqbs8TT.jpg'),
(171001, 12089, 'Arifureta Shokugyou de Sekai Saikyou S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/657116.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/TA0diTYjdp1IN8NyjwE7TgrvYM.jpg'),
(171002, 12089, 'Arifureta Shokugyou de Sekai Saikyou S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/657117.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2cmGMCWolD1b48irc97QgXnEBWW.jpg'),
(171003, 12089, 'Arifureta Shokugyou de Sekai Saikyou S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/657118.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5U6Vjtch2yY1DqLn1VAn4nCEBrZ.jpg'),
(171004, 12089, 'Arifureta Shokugyou de Sekai Saikyou S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/657119.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9BWmveIadKPFdYA9vUUxX8bLEdO.jpg'),
(171005, 12089, 'Arifureta Shokugyou de Sekai Saikyou S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/657120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3vwcB2MtQA1VZMCljCRSrDzNzdj.jpg'),
(171006, 12089, 'Arifureta Shokugyou de Sekai Saikyou S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/657121.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3vwcB2MtQA1VZMCljCRSrDzNzdj.jpg'),
(171007, 12090, 'Arifureta Shokugyou de Sekai Saikyou S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657122.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wPgcOctbPZPm5C72gkzhEi9DX33.jpg'),
(171008, 12090, 'Arifureta Shokugyou de Sekai Saikyou S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657123.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k0odd8CI6QyvzQ8ZUsq7YgEua4L.jpg'),
(171009, 12090, 'Arifureta Shokugyou de Sekai Saikyou S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657124.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2gRUEy63Pn4U59p77G24aXmVebF.jpg'),
(171010, 12090, 'Arifureta Shokugyou de Sekai Saikyou S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/657125.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pM1JJBlFz4W88RNzYNfwTRPNuRn.jpg'),
(171011, 12090, 'Arifureta Shokugyou de Sekai Saikyou S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/657126.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zWk2vnsVxOzytuoJ7nFLNRS24kq.jpg'),
(171012, 12090, 'Arifureta Shokugyou de Sekai Saikyou S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/657127.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zveyCXUFnJKdwfhBDPYhppyiHNZ.jpg'),
(171013, 12090, 'Arifureta Shokugyou de Sekai Saikyou S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/657128.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zVy5IOos06AoNdrp2getJWuQGxH.jpg'),
(171014, 12090, 'Arifureta Shokugyou de Sekai Saikyou S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/657129.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ahfjB8XwBSgfGVHrGQriQ06ZkZ2.jpg'),
(171015, 12090, 'Arifureta Shokugyou de Sekai Saikyou S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/672279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3vwcB2MtQA1VZMCljCRSrDzNzdj.jpg'),
(171016, 12090, 'Arifureta Shokugyou de Sekai Saikyou S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/672280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3vwcB2MtQA1VZMCljCRSrDzNzdj.jpg'),
(171017, 12090, 'Arifureta Shokugyou de Sekai Saikyou S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/681072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3vwcB2MtQA1VZMCljCRSrDzNzdj.jpg'),
(171018, 12090, 'Arifureta Shokugyou de Sekai Saikyou S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/693480.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3vwcB2MtQA1VZMCljCRSrDzNzdj.jpg'),
(171019, 12090, 'Arifureta Shokugyou de Sekai Saikyou S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/703244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3vwcB2MtQA1VZMCljCRSrDzNzdj.jpg'),
(171020, 12090, 'Arifureta Shokugyou de Sekai Saikyou S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/711758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3vwcB2MtQA1VZMCljCRSrDzNzdj.jpg'),
(171021, 12090, 'Arifureta Shokugyou de Sekai Saikyou S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/727838.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3vwcB2MtQA1VZMCljCRSrDzNzdj.jpg'),
(171022, 12091, 'Chopped Nova Geracao S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657088.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AvXqdy6fIohEHphsyaoun287DCH.jpg'),
(171023, 12091, 'Chopped Nova Geracao S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657089.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m6KmZ0exjAR1Ik2bOC7J46dSOBs.jpg'),
(171024, 12091, 'Chopped Nova Geracao S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657090.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h0gpIm3EbWZWRGVx6FOmXXJqMAU.jpg'),
(171025, 12091, 'Chopped Nova Geracao S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/657091.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jh1TEz6C06MfXDTQORaNuGyaUiS.jpg'),
(171026, 12091, 'Chopped Nova Geracao S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/657092.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nF3o9JjiPQI2l3fOnIRK0eWqn2p.jpg'),
(171027, 1924, 'Fast Layne S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657080.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/genOyORYvNvXl4tAXiO1jf7UO91.jpg'),
(171028, 1924, 'Fast Layne S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657081.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v7kkHSRARCJjLThLPWU8DtCbCFO.jpg'),
(171029, 1924, 'Fast Layne S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657082.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r2IYTBlLDUkuYBc92FKYepm7RMZ.jpg'),
(171030, 1924, 'Fast Layne S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/657083.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u2euJJpzfaVawkOCLbhHql5HQ3l.jpg'),
(171031, 1924, 'Fast Layne S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/657084.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/66y0XHKnkbJjzjIXwqww0STLiQ7.jpg'),
(171032, 1924, 'Fast Layne S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/657085.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2rGXRnvkQer0fdYNETUhOInpjDq.jpg'),
(171033, 1924, 'Fast Layne S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/657086.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/balyNRAx7rKbq6LG63kXDMNsHiM.jpg'),
(171034, 1924, 'Fast Layne S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/657087.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bE8F8r6rgqNyCR0cxF6B3bvpvRa.jpg'),
(171035, 12092, 'Medalist S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657079.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/muBADhIfwTYg6nXztGBDUwWEzeb.jpg'),
(171036, 12092, 'Medalist S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/660269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7DXsDnyOTTlqcj1fKrNQz8Ftxco.jpg'),
(171037, 12092, 'Medalist S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/668533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7DXsDnyOTTlqcj1fKrNQz8Ftxco.jpg'),
(171038, 12092, 'Medalist S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/675424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7DXsDnyOTTlqcj1fKrNQz8Ftxco.jpg'),
(171039, 12092, 'Medalist S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/682643.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7DXsDnyOTTlqcj1fKrNQz8Ftxco.jpg'),
(171040, 12092, 'Medalist S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/689857.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7DXsDnyOTTlqcj1fKrNQz8Ftxco.jpg'),
(171041, 12092, 'Medalist S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/697738.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7DXsDnyOTTlqcj1fKrNQz8Ftxco.jpg'),
(171042, 12092, 'Medalist S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/705118.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7DXsDnyOTTlqcj1fKrNQz8Ftxco.jpg'),
(171043, 12092, 'Medalist S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/716597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7DXsDnyOTTlqcj1fKrNQz8Ftxco.jpg'),
(171044, 12092, 'Medalist S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/721120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7DXsDnyOTTlqcj1fKrNQz8Ftxco.jpg'),
(171045, 12092, 'Medalist S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/729097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7DXsDnyOTTlqcj1fKrNQz8Ftxco.jpg'),
(171046, 12092, 'Medalist S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/738602.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7DXsDnyOTTlqcj1fKrNQz8Ftxco.jpg'),
(171047, 12092, 'Medalist S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/751693.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/7DXsDnyOTTlqcj1fKrNQz8Ftxco.jpg'),
(171048, 12093, 'Misterios e Lendas da Historia S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657071.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7pFNTnSXY8ss9bKBruyIE1aUgd.jpg'),
(171049, 12093, 'Misterios e Lendas da Historia S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657072.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7pFNTnSXY8ss9bKBruyIE1aUgd.jpg'),
(171050, 12093, 'Misterios e Lendas da Historia S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657073.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7pFNTnSXY8ss9bKBruyIE1aUgd.jpg'),
(171051, 12093, 'Misterios e Lendas da Historia S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/657074.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7pFNTnSXY8ss9bKBruyIE1aUgd.jpg'),
(171052, 12093, 'Misterios e Lendas da Historia S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/657075.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7pFNTnSXY8ss9bKBruyIE1aUgd.jpg'),
(171053, 12093, 'Misterios e Lendas da Historia S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/657076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7pFNTnSXY8ss9bKBruyIE1aUgd.jpg'),
(171054, 12093, 'Misterios e Lendas da Historia S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/657077.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7pFNTnSXY8ss9bKBruyIE1aUgd.jpg'),
(171055, 12093, 'Misterios e Lendas da Historia S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/657078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/w7pFNTnSXY8ss9bKBruyIE1aUgd.jpg'),
(171056, 12094, 'Subteran S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657065.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3z6ii14aH0KqcYomTTWt2ulwjeu.jpg'),
(171057, 12094, 'Subteran S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657066.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kVbOEFFMJ0qwSOVIQAmPIpLZJHQ.jpg'),
(171058, 12094, 'Subteran S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657067.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7SnYksHzHd7URfhqRavHjIgG1wd.jpg'),
(171059, 12094, 'Subteran S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/657068.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7BGBp5LqDSqReksqRjNHcjeZpDY.jpg'),
(171060, 12094, 'Subteran S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/657069.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A66wLWNx1qfexZhYVDhH3rzcu58.jpg'),
(171061, 12094, 'Subteran S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/657070.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xSd4KqgtD8sf3b30n7tulkX8qpg.jpg'),
(171062, 12095, 'Asura S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWLWPrAZIxns2yHguCUghsiKi1b.jpg'),
(171063, 12095, 'Asura S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657059.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWLWPrAZIxns2yHguCUghsiKi1b.jpg'),
(171064, 12095, 'Asura S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657060.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWLWPrAZIxns2yHguCUghsiKi1b.jpg'),
(171065, 12095, 'Asura S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/657061.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWLWPrAZIxns2yHguCUghsiKi1b.jpg'),
(171066, 12095, 'Asura S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/657062.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWLWPrAZIxns2yHguCUghsiKi1b.jpg'),
(171067, 12095, 'Asura S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/657063.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWLWPrAZIxns2yHguCUghsiKi1b.jpg'),
(171068, 12095, 'Asura S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/657064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sWLWPrAZIxns2yHguCUghsiKi1b.jpg'),
(171069, 12096, 'Fairyland A Era das Tentacoes S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657050.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKjUVnDcCRoOGrija4GDuKPuzML.jpg'),
(171070, 12096, 'Fairyland A Era das Tentacoes S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657051.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKjUVnDcCRoOGrija4GDuKPuzML.jpg'),
(171071, 12096, 'Fairyland A Era das Tentacoes S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657052.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKjUVnDcCRoOGrija4GDuKPuzML.jpg'),
(171072, 12096, 'Fairyland A Era das Tentacoes S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/657053.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKjUVnDcCRoOGrija4GDuKPuzML.jpg'),
(171073, 12096, 'Fairyland A Era das Tentacoes S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/657054.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKjUVnDcCRoOGrija4GDuKPuzML.jpg'),
(171074, 12096, 'Fairyland A Era das Tentacoes S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/657055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKjUVnDcCRoOGrija4GDuKPuzML.jpg'),
(171075, 12096, 'Fairyland A Era das Tentacoes S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/657056.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKjUVnDcCRoOGrija4GDuKPuzML.jpg'),
(171076, 12096, 'Fairyland A Era das Tentacoes S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/657057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cKjUVnDcCRoOGrija4GDuKPuzML.jpg'),
(171077, 12097, 'Plantao Policial S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657042.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7OX2RHEYcqpUU0cBWuTUBso31YV.jpg'),
(171078, 12097, 'Plantao Policial S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657043.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/obSfS1Ul0YbLp0CojjViX1kkbmy.jpg'),
(171079, 12097, 'Plantao Policial S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657044.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AjirmjWh7Ae6LaA0toHC1n13mNZ.jpg'),
(171080, 12097, 'Plantao Policial S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/657045.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3bNGtn9e8ovWHV0cYGK7JIlZ7PB.jpg'),
(171081, 12097, 'Plantao Policial S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/657046.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1zf9vmUZ5l903K4UbEaP1XbZZ95.jpg'),
(171082, 12097, 'Plantao Policial S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/657047.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/toBS8x3DI2V4YUU0Bzf7i1gi7To.jpg'),
(171083, 12097, 'Plantao Policial S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/657048.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v3pfnolOUVax5rocY8JF53gxyRK.jpg'),
(171084, 12097, 'Plantao Policial S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/657049.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dnW5Xwd5aPt5LROvIDeMZiY0qZM.jpg'),
(171085, 12098, 'Terra Indomavel S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657036.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vc0Q4g850WtyUztUPDTdQZI20av.jpg'),
(171086, 12098, 'Terra Indomavel S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657037.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mTmWbzziLprFnvpHWYZDCd1qty5.jpg'),
(171087, 12098, 'Terra Indomavel S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657038.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wtrefM12BXANus3sZOTSt0GGphZ.jpg'),
(171088, 12098, 'Terra Indomavel S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/657039.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rYbmrGSSDeWqdgiSSwHNCSLYxG6.jpg'),
(171089, 12098, 'Terra Indomavel S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/657040.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/orIOZ2hWWWx4ElT3wL7jnzORRU0.jpg'),
(171090, 12098, 'Terra Indomavel S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/657041.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ur3yBm2TC475elsfSBU02jv0pRc.jpg'),
(171091, 12099, 'I Am Ilary S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/657031.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a1hTa9aXQEnzKcseswrC17wQ1PD.jpg'),
(171092, 12099, 'I Am Ilary S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/657032.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bC9iI7icLsZtAc659aSQ9L0oRII.jpg'),
(171093, 12099, 'I Am Ilary S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/657033.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ndb4dgydJLU7MMckzUxylkZlxAg.jpg'),
(171094, 12099, 'I Am Ilary S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/657034.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cuaxBIwG62KYwFVstKjT2pWMY4s.jpg'),
(171095, 12099, 'I Am Ilary S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/657035.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1n9qDEb8aw0JwyauOjj78TqPCoq.jpg'),
(171096, 12100, 'The Pitt S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/663178.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5s0ToSmeP5ewpShkwxf3vopOGz5.jpg'),
(171097, 12100, 'The Pitt S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/663179.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ulUkzlM0YKd3M1wBizF6j5gNZxQ.jpg'),
(171098, 12100, 'The Pitt S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/667245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6fMGktEDXMZZPACJ5cWkVQ6TSte.jpg'),
(171099, 12100, 'The Pitt S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/677219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6fMGktEDXMZZPACJ5cWkVQ6TSte.jpg'),
(171100, 12100, 'The Pitt S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/678276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6fMGktEDXMZZPACJ5cWkVQ6TSte.jpg'),
(171101, 12100, 'The Pitt S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/687084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6fMGktEDXMZZPACJ5cWkVQ6TSte.jpg'),
(171102, 12100, 'The Pitt S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/697172.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6fMGktEDXMZZPACJ5cWkVQ6TSte.jpg'),
(171103, 12100, 'The Pitt S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/703805.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6fMGktEDXMZZPACJ5cWkVQ6TSte.jpg'),
(171104, 12100, 'The Pitt S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/713159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6fMGktEDXMZZPACJ5cWkVQ6TSte.jpg'),
(171105, 12100, 'The Pitt S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/722934.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6fMGktEDXMZZPACJ5cWkVQ6TSte.jpg'),
(171106, 12100, 'The Pitt S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/723650.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6fMGktEDXMZZPACJ5cWkVQ6TSte.jpg'),
(171107, 12100, 'The Pitt S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/730160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6fMGktEDXMZZPACJ5cWkVQ6TSte.jpg'),
(171108, 12100, 'The Pitt S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/750064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6fMGktEDXMZZPACJ5cWkVQ6TSte.jpg'),
(171109, 12100, 'The Pitt S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/757814.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6fMGktEDXMZZPACJ5cWkVQ6TSte.jpg'),
(171110, 12100, 'The Pitt S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/763234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6fMGktEDXMZZPACJ5cWkVQ6TSte.jpg'),
(171111, 12101, 'Bogus Skill Fruitmaster [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/661265.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vMe15txW08UJty137E9HY4O5TtH.jpg'),
(171112, 12101, 'Bogus Skill Fruitmaster [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/661266.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l6YoD9N7YEK2Me4LgWVLQrE0PY8.jpg'),
(171113, 12101, 'Bogus Skill Fruitmaster [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/665424.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sy8OTK68SerisyO3QaoSAp4NehX.jpg'),
(171114, 12101, 'Bogus Skill Fruitmaster [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/672185.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sy8OTK68SerisyO3QaoSAp4NehX.jpg'),
(171115, 12101, 'Bogus Skill Fruitmaster [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/680583.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sy8OTK68SerisyO3QaoSAp4NehX.jpg'),
(171116, 12101, 'Bogus Skill Fruitmaster [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/686221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sy8OTK68SerisyO3QaoSAp4NehX.jpg'),
(171117, 12101, 'Bogus Skill Fruitmaster [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/692645.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sy8OTK68SerisyO3QaoSAp4NehX.jpg'),
(171118, 12101, 'Bogus Skill Fruitmaster [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/702153.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sy8OTK68SerisyO3QaoSAp4NehX.jpg'),
(171119, 12101, 'Bogus Skill Fruitmaster [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/709960.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sy8OTK68SerisyO3QaoSAp4NehX.jpg'),
(171120, 12101, 'Bogus Skill Fruitmaster [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/711590.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sy8OTK68SerisyO3QaoSAp4NehX.jpg'),
(171121, 12101, 'Bogus Skill Fruitmaster [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/727769.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sy8OTK68SerisyO3QaoSAp4NehX.jpg'),
(171122, 12101, 'Bogus Skill Fruitmaster [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/733085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sy8OTK68SerisyO3QaoSAp4NehX.jpg'),
(171123, 12102, 'Headhunted to Another World From Salaryman to Big Four [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/661263.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oKEvmIgwBHw2DMcYZ4pfsnyWEwj.jpg'),
(171124, 12102, 'Headhunted to Another World From Salaryman to Big Four [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/661264.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aRcbIKJKchJxrBejhIH0NLaS0po.jpg'),
(171125, 12102, 'Headhunted to Another World From Salaryman to Big Four [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664669.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ruNn68lcGc7z6rqGelM0uMswZ3e.jpg'),
(171126, 12102, 'Headhunted to Another World From Salaryman to Big Four [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/672055.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ruNn68lcGc7z6rqGelM0uMswZ3e.jpg'),
(171127, 12102, 'Headhunted to Another World From Salaryman to Big Four [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/679444.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ruNn68lcGc7z6rqGelM0uMswZ3e.jpg'),
(171128, 12102, 'Headhunted to Another World From Salaryman to Big Four [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/686215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ruNn68lcGc7z6rqGelM0uMswZ3e.jpg'),
(171129, 12102, 'Headhunted to Another World From Salaryman to Big Four [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/693641.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ruNn68lcGc7z6rqGelM0uMswZ3e.jpg'),
(171130, 12102, 'Headhunted to Another World From Salaryman to Big Four [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/701701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ruNn68lcGc7z6rqGelM0uMswZ3e.jpg'),
(171131, 12102, 'Headhunted to Another World From Salaryman to Big Four [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/709081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ruNn68lcGc7z6rqGelM0uMswZ3e.jpg'),
(171132, 12102, 'Headhunted to Another World From Salaryman to Big Four [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/716684.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ruNn68lcGc7z6rqGelM0uMswZ3e.jpg'),
(171133, 12102, 'Headhunted to Another World From Salaryman to Big Four [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/727758.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ruNn68lcGc7z6rqGelM0uMswZ3e.jpg'),
(171134, 12102, 'Headhunted to Another World From Salaryman to Big Four [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/734229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ruNn68lcGc7z6rqGelM0uMswZ3e.jpg'),
(171135, 12103, 'Abracadavers S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/661252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDMBf5MDGIo8pGn2zc9VlQF6fXx.jpg'),
(171136, 12103, 'Abracadavers S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/661253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDMBf5MDGIo8pGn2zc9VlQF6fXx.jpg'),
(171137, 12103, 'Abracadavers S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/661254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDMBf5MDGIo8pGn2zc9VlQF6fXx.jpg'),
(171138, 12103, 'Abracadavers S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/661255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDMBf5MDGIo8pGn2zc9VlQF6fXx.jpg'),
(171139, 12104, 'Abracadavers S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/661256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDMBf5MDGIo8pGn2zc9VlQF6fXx.jpg'),
(171140, 12104, 'Abracadavers S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/661257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDMBf5MDGIo8pGn2zc9VlQF6fXx.jpg'),
(171141, 12104, 'Abracadavers S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/661258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDMBf5MDGIo8pGn2zc9VlQF6fXx.jpg'),
(171142, 12104, 'Abracadavers S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/661259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDMBf5MDGIo8pGn2zc9VlQF6fXx.jpg'),
(171143, 12104, 'Abracadavers S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/661260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDMBf5MDGIo8pGn2zc9VlQF6fXx.jpg'),
(171144, 12104, 'Abracadavers S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/661261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDMBf5MDGIo8pGn2zc9VlQF6fXx.jpg'),
(171145, 12104, 'Abracadavers S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/661262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pDMBf5MDGIo8pGn2zc9VlQF6fXx.jpg'),
(171146, 12105, 'Do Rio ao Mar S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/661250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y3P0owy4NZR9ETPwxd4CKFONoyO.jpg'),
(171147, 12105, 'Do Rio ao Mar S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/661251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/y3P0owy4NZR9ETPwxd4CKFONoyO.jpg'),
(171148, 12106, 'Futebol de Rua S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/661172.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eaSZ2NqBmUet85vPehWFJ7FP6MM.jpg'),
(171149, 12106, 'Futebol de Rua S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/661173.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hD46613Nc1lAR8D8jdlCVBCkijI.jpg'),
(171150, 12106, 'Futebol de Rua S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/661174.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2lELMCDZdd1ILmM8yOgAobpWnOt.jpg'),
(171151, 12106, 'Futebol de Rua S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/661175.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vEgWIPRRnaa74MQCN1R6qdvIAsf.jpg'),
(171152, 12106, 'Futebol de Rua S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/661176.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AkeWmA1o3OtrybzpAsYD69VkSda.jpg'),
(171153, 12106, 'Futebol de Rua S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/661177.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xVOaMM0OPOQxq9NLDVG6XDcL9Eq.jpg'),
(171154, 12106, 'Futebol de Rua S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/661178.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cJYHXv3dJ2zTkeVe0cDRTwezhVx.jpg'),
(171155, 12106, 'Futebol de Rua S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/661179.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/llVpOlb3qkWrkWlgZJebfNmDhBc.jpg'),
(171156, 12106, 'Futebol de Rua S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/661180.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/begU3OTWMFUaYNnRp5DgeOkGob2.jpg'),
(171157, 12106, 'Futebol de Rua S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/661181.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nbZ2gOpAv46wEfBAg5pAv2DJSjQ.jpg'),
(171158, 12106, 'Futebol de Rua S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/661182.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6qXbFmcDg8sdkKXBblepi9zMteY.jpg'),
(171159, 12106, 'Futebol de Rua S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/661183.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nTRR08mc2agmFUNLtzNTdYusoXJ.jpg'),
(171160, 12106, 'Futebol de Rua S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/661184.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ifhEW3VlKynq6z1A4i8fAEkkUpO.jpg'),
(171161, 12106, 'Futebol de Rua S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/661185.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sDyRWgrSwIlga5dbhYNp1x8oBrj.jpg'),
(171162, 12106, 'Futebol de Rua S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/661186.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dChyBGcnYFCZp7lUkG1vaoN99ap.jpg'),
(171163, 12106, 'Futebol de Rua S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/661187.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rALcXIKYn9J2liBUzTvUiRizQY6.jpg'),
(171164, 12106, 'Futebol de Rua S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/661188.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/90w6YNhoc5fjhpWI9Cw2IVpSEsl.jpg'),
(171165, 12106, 'Futebol de Rua S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/661189.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tWJysEZEViuybGBM9uoikfVLBHa.jpg'),
(171166, 12106, 'Futebol de Rua S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/661190.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rSeYtNMnNiGZR7L217E6WlHBwtd.jpg'),
(171167, 12106, 'Futebol de Rua S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/661191.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6sqQaXRS2jZjgwcMjcRJrZMb7zN.jpg'),
(171168, 12106, 'Futebol de Rua S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/661192.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dTahJSOqZixg5QfS0HeP7QIFTFa.jpg'),
(171169, 12106, 'Futebol de Rua S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/661193.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/85MXCQ52nLzQhB4CBrwTX3QuzmD.jpg'),
(171170, 12106, 'Futebol de Rua S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/661194.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jkJtrweMttX4OsynNDod4E0UaLZ.jpg'),
(171171, 12106, 'Futebol de Rua S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/661195.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wMurkMuVK004n0M3Qs8HTATvPGQ.jpg'),
(171172, 12106, 'Futebol de Rua S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/661196.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2pQjFhmFUySDZkZmdm1vcIKeO4r.jpg'),
(171173, 12106, 'Futebol de Rua S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/661197.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wnbcfFrwiTrXfZk4JuEyVvGT6jH.jpg'),
(171174, 12107, 'Futebol de Rua S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/661198.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aCe1YHOEsls8dZ1yKTJWm4ifOqn.jpg'),
(171175, 12107, 'Futebol de Rua S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/661199.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uktM7j1KKzklbKJ95NhaGuoKitB.jpg'),
(171176, 12107, 'Futebol de Rua S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/661200.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wsSFoZaVSQsWxlWt07xlAwsvfu5.jpg'),
(171177, 12107, 'Futebol de Rua S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/661201.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5Vb8xpbZtGBHMjFeXPyxjeE2y7b.jpg'),
(171178, 12107, 'Futebol de Rua S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/661202.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9lMEltoyLXPv732iI2PFKicAh5s.jpg'),
(171179, 12107, 'Futebol de Rua S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/661203.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7rg3Zk0OrkA0ukHQJsUuiQx4whd.jpg'),
(171180, 12107, 'Futebol de Rua S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/661204.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eVq8VYEQ0XWpvPMrvtn9DwwArNF.jpg'),
(171181, 12107, 'Futebol de Rua S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/661205.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AqTVGseP06zNYGuRJTz1ON4LQNU.jpg'),
(171182, 12107, 'Futebol de Rua S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/661206.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/swUOft5Sn5mVI0t3IvEdGci0uZ0.jpg'),
(171183, 12107, 'Futebol de Rua S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/661207.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wppBZLcaiyEvFEfCJnCH5FYA7of.jpg'),
(171184, 12107, 'Futebol de Rua S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/661208.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qFlPwvczBO5GYp98qRh2gf9joCl.jpg'),
(171185, 12107, 'Futebol de Rua S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/661209.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/crOttDoBm6RfiklJllBv2xOT71T.jpg'),
(171186, 12107, 'Futebol de Rua S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/661210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3ifDicPsEnOzdgOQvS3J2pQvfLF.jpg'),
(171187, 12107, 'Futebol de Rua S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/661211.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AeUdjke2CqUMcuavX2Bk0lt63Uw.jpg'),
(171188, 12107, 'Futebol de Rua S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/661212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3ifDicPsEnOzdgOQvS3J2pQvfLF.jpg'),
(171189, 12107, 'Futebol de Rua S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/661213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3ifDicPsEnOzdgOQvS3J2pQvfLF.jpg'),
(171190, 12107, 'Futebol de Rua S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/661214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3ifDicPsEnOzdgOQvS3J2pQvfLF.jpg'),
(171191, 12107, 'Futebol de Rua S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/661215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3ifDicPsEnOzdgOQvS3J2pQvfLF.jpg'),
(171192, 12107, 'Futebol de Rua S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/661216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3ifDicPsEnOzdgOQvS3J2pQvfLF.jpg'),
(171193, 12107, 'Futebol de Rua S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/661217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3ifDicPsEnOzdgOQvS3J2pQvfLF.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(171194, 12107, 'Futebol de Rua S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/661218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3ifDicPsEnOzdgOQvS3J2pQvfLF.jpg'),
(171195, 12107, 'Futebol de Rua S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/661219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3ifDicPsEnOzdgOQvS3J2pQvfLF.jpg'),
(171196, 12107, 'Futebol de Rua S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/661220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3ifDicPsEnOzdgOQvS3J2pQvfLF.jpg'),
(171197, 12107, 'Futebol de Rua S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/661221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3ifDicPsEnOzdgOQvS3J2pQvfLF.jpg'),
(171198, 12107, 'Futebol de Rua S02 E25', 'http://sinalprivado.info:80/series/1533784/1533784/661222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3ifDicPsEnOzdgOQvS3J2pQvfLF.jpg'),
(171199, 12107, 'Futebol de Rua S02 E26', 'http://sinalprivado.info:80/series/1533784/1533784/661223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3ifDicPsEnOzdgOQvS3J2pQvfLF.jpg'),
(171200, 12108, 'Futebol de Rua S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/661224.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8M5EIQxeqO4njwuJvUKF3naxTh6.jpg'),
(171201, 12108, 'Futebol de Rua S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/661225.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nBsT3F0A9ZcakgsSDdFHmVAAPAZ.jpg'),
(171202, 12108, 'Futebol de Rua S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/661226.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iPwSb8x2x7WgjGrt9vJm2aHoC4b.jpg'),
(171203, 12108, 'Futebol de Rua S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/661227.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oVk3tbjzG1fc4X0L06EJXqoaKRn.jpg'),
(171204, 12108, 'Futebol de Rua S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/661228.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9gylfeRizaeOkbsQZnkAdn5RL1U.jpg'),
(171205, 12108, 'Futebol de Rua S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/661229.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zLpPE0AhzYDRbUSSmN1Fahg03Sl.jpg'),
(171206, 12108, 'Futebol de Rua S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/661230.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7qyyyYnKtA9WLsMSU9Xouh17AZW.jpg'),
(171207, 12108, 'Futebol de Rua S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/661231.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9GIXExyAuXBHmEyjj0fMtLUCdD1.jpg'),
(171208, 12108, 'Futebol de Rua S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/661232.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/snULwFOWtMY6XvQfvt1QZRw9zgk.jpg'),
(171209, 12108, 'Futebol de Rua S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/661233.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8zhFlw264Clur8xKdXBl44uc0pe.jpg'),
(171210, 12108, 'Futebol de Rua S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/661234.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tXw4R2ZQ11jJmSrvjcL0SPsvEBl.jpg'),
(171211, 12108, 'Futebol de Rua S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/661235.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4iGYRErpnUAzdEmdGkvbC0YKYUW.jpg'),
(171212, 12108, 'Futebol de Rua S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/661236.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n6ldlUKKac39BKI7jHh5FJBaWrZ.jpg'),
(171213, 12108, 'Futebol de Rua S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/661237.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nRG8o11i6cNXua9xyckXnVI8o7Q.jpg'),
(171214, 12108, 'Futebol de Rua S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/661238.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4ZjHFVyAL8jtZHCmekRngvxbSIi.jpg'),
(171215, 12108, 'Futebol de Rua S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/661239.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8v1xjETj5My9NjrimD5fOuDt9qa.jpg'),
(171216, 12108, 'Futebol de Rua S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/661240.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t0ynT6VaTgNDjaxdbYZLXFHXTzY.jpg'),
(171217, 12108, 'Futebol de Rua S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/661241.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4VMHsSfQBEK9SksE5SJgIw7QB6S.jpg'),
(171218, 12108, 'Futebol de Rua S03 E19', 'http://sinalprivado.info:80/series/1533784/1533784/661242.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/awByPGTKpX2B3Ax3m5beHg8EYOS.jpg'),
(171219, 12108, 'Futebol de Rua S03 E20', 'http://sinalprivado.info:80/series/1533784/1533784/661243.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bUazSRjx7m8YLiVEWQQkisf5YX0.jpg'),
(171220, 12108, 'Futebol de Rua S03 E21', 'http://sinalprivado.info:80/series/1533784/1533784/661244.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eSey7Qq0lRzzzxwT3yjtizYdhuK.jpg'),
(171221, 12108, 'Futebol de Rua S03 E22', 'http://sinalprivado.info:80/series/1533784/1533784/661245.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1df90aoowrrWGgMy6Wv9H6TnqXp.jpg'),
(171222, 12108, 'Futebol de Rua S03 E23', 'http://sinalprivado.info:80/series/1533784/1533784/661246.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yEY7Q2YUpjd7PZPkrtdeK2v9UHY.jpg'),
(171223, 12108, 'Futebol de Rua S03 E24', 'http://sinalprivado.info:80/series/1533784/1533784/661247.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/id4frkCltxuOf6WPeMTWEn9SYvz.jpg'),
(171224, 12108, 'Futebol de Rua S03 E25', 'http://sinalprivado.info:80/series/1533784/1533784/661248.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/12haLynkoCk06H7v174IrTkyLqi.jpg'),
(171225, 12108, 'Futebol de Rua S03 E26', 'http://sinalprivado.info:80/series/1533784/1533784/661249.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fZxCM7qqWhf5VGY4I34aQ0QEzpN.jpg'),
(171226, 12109, 'Hysteria S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/661171.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aQ8lC1AyRSl0KTDjdc2mJTt652a.jpg'),
(171227, 12109, 'Hysteria S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/669840.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rG3mGUouuSACs2KLdJWjEHpuG8L.jpg'),
(171228, 12109, 'Hysteria S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/675620.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rG3mGUouuSACs2KLdJWjEHpuG8L.jpg'),
(171229, 12109, 'Hysteria S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/683579.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rG3mGUouuSACs2KLdJWjEHpuG8L.jpg'),
(171230, 12109, 'Hysteria S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/690375.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rG3mGUouuSACs2KLdJWjEHpuG8L.jpg'),
(171231, 12109, 'Hysteria S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/700134.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rG3mGUouuSACs2KLdJWjEHpuG8L.jpg'),
(171232, 12109, 'Hysteria S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/706097.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rG3mGUouuSACs2KLdJWjEHpuG8L.jpg'),
(171233, 12109, 'Hysteria S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/716674.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rG3mGUouuSACs2KLdJWjEHpuG8L.jpg'),
(171234, 12110, 'LEGO Friends O Proximo Capitulo S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/661148.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/30IytGj7PRRoM3zyBL9Sio0Nld3.jpg'),
(171235, 12110, 'LEGO Friends O Proximo Capitulo S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/661149.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8Q4xCiOghP4G4ouFrH32GJ6c5vi.jpg'),
(171236, 12110, 'LEGO Friends O Proximo Capitulo S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/661150.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kF7GinPzENMt7We2XXMPvaj4pUJ.jpg'),
(171237, 12110, 'LEGO Friends O Proximo Capitulo S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/661151.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kF7GinPzENMt7We2XXMPvaj4pUJ.jpg'),
(171238, 12110, 'LEGO Friends O Proximo Capitulo S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/661152.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eEndz213LnRfAnRywMSYxGQs1XD.jpg'),
(171239, 12110, 'LEGO Friends O Proximo Capitulo S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/661153.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AfOp9vIHJafwrTTrAIMptAIEn1B.jpg'),
(171240, 12110, 'LEGO Friends O Proximo Capitulo S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/661154.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tLBYQ841e63rit386nEaP4PnNEC.jpg'),
(171241, 12110, 'LEGO Friends O Proximo Capitulo S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/661155.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n13jIDdF97XGnDfZA5GXeHc1fab.jpg'),
(171242, 12110, 'LEGO Friends O Proximo Capitulo S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/661156.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tvH0XNSI7JV6LnwJWdH8fbUj9JT.jpg'),
(171243, 12110, 'LEGO Friends O Proximo Capitulo S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/661157.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tvH0XNSI7JV6LnwJWdH8fbUj9JT.jpg'),
(171244, 12110, 'LEGO Friends O Proximo Capitulo S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/661158.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z21oUowUdjB2i6IUvPpK8ztPgKy.jpg'),
(171245, 12111, 'LEGO Friends O Proximo Capitulo S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/661159.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ZmO5NoszmfKP6ZFQrxNWIdgUqD.jpg'),
(171246, 12111, 'LEGO Friends O Proximo Capitulo S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/661160.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ZmO5NoszmfKP6ZFQrxNWIdgUqD.jpg'),
(171247, 12111, 'LEGO Friends O Proximo Capitulo S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/661161.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ZmO5NoszmfKP6ZFQrxNWIdgUqD.jpg'),
(171248, 12111, 'LEGO Friends O Proximo Capitulo S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/661162.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ZmO5NoszmfKP6ZFQrxNWIdgUqD.jpg'),
(171249, 12111, 'LEGO Friends O Proximo Capitulo S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/661163.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ZmO5NoszmfKP6ZFQrxNWIdgUqD.jpg'),
(171250, 12111, 'LEGO Friends O Proximo Capitulo S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/661164.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ZmO5NoszmfKP6ZFQrxNWIdgUqD.jpg'),
(171251, 12111, 'LEGO Friends O Proximo Capitulo S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/661165.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ZmO5NoszmfKP6ZFQrxNWIdgUqD.jpg'),
(171252, 12111, 'LEGO Friends O Proximo Capitulo S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/661166.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ZmO5NoszmfKP6ZFQrxNWIdgUqD.jpg'),
(171253, 12111, 'LEGO Friends O Proximo Capitulo S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/661167.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ZmO5NoszmfKP6ZFQrxNWIdgUqD.jpg'),
(171254, 12111, 'LEGO Friends O Proximo Capitulo S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/661168.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ZmO5NoszmfKP6ZFQrxNWIdgUqD.jpg'),
(171255, 12111, 'LEGO Friends O Proximo Capitulo S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/661169.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ZmO5NoszmfKP6ZFQrxNWIdgUqD.jpg'),
(171256, 12111, 'LEGO Friends O Proximo Capitulo S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/661170.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8ZmO5NoszmfKP6ZFQrxNWIdgUqD.jpg'),
(171257, 12112, 'Memorias de Um Carcereiro S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/661141.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z0TgVLrjaC692vVpuUMYhHBjenE.jpg'),
(171258, 12112, 'Memorias de Um Carcereiro S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/661142.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/saSxmBijMOfWv5XbYMq99HR5apZ.jpg'),
(171259, 12112, 'Memorias de Um Carcereiro S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/661143.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A5V863V3LJzZtXgTa8l3GbFn5m8.jpg'),
(171260, 12112, 'Memorias de Um Carcereiro S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/661144.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9uHXW64Ja9vJtDW8LtZzwJQelzI.jpg'),
(171261, 12112, 'Memorias de Um Carcereiro S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/661145.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nQTfNZmYtU4vKv0clS1w8DofCxS.jpg'),
(171262, 12112, 'Memorias de Um Carcereiro S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/661146.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8OxECTuoPyumhBGNySuwZHeACLD.jpg'),
(171263, 12112, 'Memorias de Um Carcereiro S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/661147.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7tKnqw5TTf5nuANGdY18H1ky71i.jpg'),
(171264, 12113, 'O Vazio S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/661121.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oyh45TZHVk6vYRdSAYeP1uCSIXf.jpg'),
(171265, 12113, 'O Vazio S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/661122.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jWULrDbHaEuHJddz0sKHG4MAM0E.jpg'),
(171266, 12113, 'O Vazio S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/661123.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x3jDm0Lk1doa2W6njZzHS5P2ouc.jpg'),
(171267, 12113, 'O Vazio S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/661124.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/w8UFpjckHTJGeOVRVoGBzWCE7C4.jpg'),
(171268, 12113, 'O Vazio S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/661125.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hQtgDAIHdrNsgsQ5eaLwsoGM88u.jpg'),
(171269, 12113, 'O Vazio S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/661126.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/97b6NUoQD5BfOXC54SnN9AS1exD.jpg'),
(171270, 12113, 'O Vazio S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/661127.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3KntfVkWi63fuo5hmwsc3j0oiKc.jpg'),
(171271, 12113, 'O Vazio S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/661128.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rm7Dx51TEd1uQ4cxBmZYyT9pab1.jpg'),
(171272, 12113, 'O Vazio S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/661129.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/da1R3xB6X1RHjG40Uv2TQXxFLs.jpg'),
(171273, 12113, 'O Vazio S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/661130.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h2Bif1j2otVLSE8jcbibSHOGMjA.jpg'),
(171274, 12114, 'O Vazio S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/661131.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7xUItu1QrGpJctV5FUPzKsNnNmJ.jpg'),
(171275, 12114, 'O Vazio S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/661132.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zoOH6eeYSoKplDkNLHBdFVT7ioW.jpg'),
(171276, 12114, 'O Vazio S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/661133.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bcEpfXua813IkDY8nuq0sWi4E1d.jpg'),
(171277, 12114, 'O Vazio S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/661134.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5lpTS8A34ODqnrnvynBnzOKKerJ.jpg'),
(171278, 12114, 'O Vazio S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/661135.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fqHWRWfYgNbC5oYH12qZt49ukaQ.jpg'),
(171279, 12114, 'O Vazio S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/661136.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3u3RIoYYtkDIXuzh6BSosJdmFo1.jpg'),
(171280, 12114, 'O Vazio S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/661137.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ohpELIGUV6jIbYHwjOno4sdMtot.jpg'),
(171281, 12114, 'O Vazio S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/661138.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eyM3HxqIB5jxBcCXKF9cuqjk73V.jpg'),
(171282, 12114, 'O Vazio S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/661139.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iRY9eHuZFDGltV4RmhlXG5MX54C.jpg'),
(171283, 12114, 'O Vazio S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/661140.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mTFDZFXZNxbJ2348XUvA3KYDfCo.jpg'),
(171284, 12115, 'A Vinganca do Casamento Perfeito [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/661109.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r47CtEAhwxNnVgMnuzXbKtU7Nq1.jpg'),
(171285, 12115, 'A Vinganca do Casamento Perfeito [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/661110.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zqW3KQq594uVDV52VGA8GS0hHVQ.jpg'),
(171286, 12115, 'A Vinganca do Casamento Perfeito [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/661111.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xbvFE5x4rwIOGFJ8wLSLBS02aNj.jpg'),
(171287, 12115, 'A Vinganca do Casamento Perfeito [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/661112.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lNRKVFS8WdFVw7bl7tNAegpbjir.jpg'),
(171288, 12115, 'A Vinganca do Casamento Perfeito [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/661113.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/phf3zJiOAxZovAoBq0Wm6h0tcqO.jpg'),
(171289, 12115, 'A Vinganca do Casamento Perfeito [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/661114.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sbXlrdSBnPkEY0Ge3hCDBZz1QwE.jpg'),
(171290, 12115, 'A Vinganca do Casamento Perfeito [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/661115.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lJmlE3hmmLXdwvSx4hKzzlraO7T.jpg'),
(171291, 12115, 'A Vinganca do Casamento Perfeito [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/661116.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f7Yl68ftqDWX0ghPQLdcAjsdGHq.jpg'),
(171292, 12115, 'A Vinganca do Casamento Perfeito [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/661117.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1gtlFednzcgnrTNt9YWTkJ7Xgxu.jpg'),
(171293, 12115, 'A Vinganca do Casamento Perfeito [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/661118.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hiPKpv3DaLD93U151Tfm8d77aa2.jpg'),
(171294, 12115, 'A Vinganca do Casamento Perfeito [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/661119.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nUlwMCBdyZXiLwuibzVr2hth5Iz.jpg'),
(171295, 12115, 'A Vinganca do Casamento Perfeito [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/661120.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2629Yd57eG15iC3tYLbKOfultGa.jpg'),
(171296, 12116, 'Naruto Shippuden S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/681785.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lFg0YnHI7sJkPSv38a8ctE96sqr.jpg'),
(171297, 12116, 'Naruto Shippuden S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/681786.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zbvJ4ts4JJmqP6koMNnLzBX6qiJ.jpg'),
(171298, 12116, 'Naruto Shippuden S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/681787.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3ZhyOj5btCsLximupjKCBvNgNnd.jpg'),
(171299, 12116, 'Naruto Shippuden S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/681788.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qiYNA4LdqhBZbM0kBqBv5MASvVs.jpg'),
(171300, 12116, 'Naruto Shippuden S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/681789.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vxaK3b4JLtz44ApG7xp7xrCtdoS.jpg'),
(171301, 12116, 'Naruto Shippuden S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/681790.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k5SJCke8KUXgN9LZ5OfyqMOXRsu.jpg'),
(171302, 12116, 'Naruto Shippuden S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/681791.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lDRKaN01rj4SGlWJG5kSiBSVHKj.jpg'),
(171303, 12116, 'Naruto Shippuden S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/681792.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uiDIPjTcLNj3ymGO1Z1YkXAtzhi.jpg'),
(171304, 12116, 'Naruto Shippuden S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/681793.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6FUS8cyaBOW3FzKWF68mrgOH13T.jpg'),
(171305, 12116, 'Naruto Shippuden S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/681794.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7FdrgAHug8AKSWrCZPPw4VLcJPq.jpg'),
(171306, 12116, 'Naruto Shippuden S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/681795.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/juL5lB6hKrWFUwjmoRZpzNOFIVK.jpg'),
(171307, 12116, 'Naruto Shippuden S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/681796.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/do3dNQ1BwaqZ0PwF9s0yCTvySV0.jpg'),
(171308, 12116, 'Naruto Shippuden S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/681797.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m5C2sunvcKbJ1LqqSOJTuRXVjar.jpg'),
(171309, 12116, 'Naruto Shippuden S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/681798.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cdXw2ys28tyoVaIlEge1XTp4WOM.jpg'),
(171310, 12116, 'Naruto Shippuden S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/681799.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fRnBxk4pN5eSgYCJ5RAUuFd0DBw.jpg'),
(171311, 12116, 'Naruto Shippuden S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/681800.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9bsOtfEDl3dpNLzIJ85JmijavWI.jpg'),
(171312, 12116, 'Naruto Shippuden S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/681801.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/twrwa4aBaWFHyXruG22xSQ6NbRQ.jpg'),
(171313, 12116, 'Naruto Shippuden S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/681802.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2pPkQ45K4yuegU3Co4wrtlY5Pyq.jpg'),
(171314, 12116, 'Naruto Shippuden S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/681803.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jaa9sZMu8p5fZxH6EbF1Bc7hwSX.jpg'),
(171315, 12116, 'Naruto Shippuden S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/681804.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hJ8SR2uQLEONJdawQBbYFrZ3ay6.jpg'),
(171316, 12116, 'Naruto Shippuden S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/681805.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/naf00mOdEW1tAVKwXLdzO2Ioqbn.jpg'),
(171317, 12116, 'Naruto Shippuden S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/681806.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jhQSqelyjjKuKtISyIUklFYMCb7.jpg'),
(171318, 12116, 'Naruto Shippuden S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/681807.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xmapRLza2UjXxnrFfRD62iGADC9.jpg'),
(171319, 12116, 'Naruto Shippuden S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/681808.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6P2KJqTU7Zj8Y0hiJJwvg1CgnFF.jpg'),
(171320, 12116, 'Naruto Shippuden S01 E25', 'http://sinalprivado.info:80/series/1533784/1533784/681809.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/OT1f9segNUhJmLy2jHRa94l81w.jpg'),
(171321, 12116, 'Naruto Shippuden S01 E26', 'http://sinalprivado.info:80/series/1533784/1533784/681810.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/me1B0bG1l2FPF2iteE4RIrqbS2P.jpg'),
(171322, 12116, 'Naruto Shippuden S01 E27', 'http://sinalprivado.info:80/series/1533784/1533784/681811.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yVPoKYXuVqtIBvv7PfgCqBUPx7b.jpg'),
(171323, 12116, 'Naruto Shippuden S01 E28', 'http://sinalprivado.info:80/series/1533784/1533784/681812.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gpAeiA7Z3t10Np4CNKMf5OGt2CU.jpg'),
(171324, 12116, 'Naruto Shippuden S01 E29', 'http://sinalprivado.info:80/series/1533784/1533784/681813.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4fzTiGiM7DMQzAj1BIcCsBJGMB9.jpg'),
(171325, 12116, 'Naruto Shippuden S01 E30', 'http://sinalprivado.info:80/series/1533784/1533784/681814.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fx5rfs67NxCBhjCdRhci0leqQaP.jpg'),
(171326, 12116, 'Naruto Shippuden S01 E31', 'http://sinalprivado.info:80/series/1533784/1533784/681815.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pvI7YBet2tpyj17HILb9DPInhJ7.jpg'),
(171327, 12116, 'Naruto Shippuden S01 E32', 'http://sinalprivado.info:80/series/1533784/1533784/681816.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6WyyG7GElHndRw1EhPrqCB57vO9.jpg'),
(171328, 12117, 'Naruto Shippuden S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/681817.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/97O9irZPuV08ZLPQIPea434UG6R.jpg'),
(171329, 12117, 'Naruto Shippuden S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/681818.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pfno022tcGELshUKfakUYfpUXHj.jpg'),
(171330, 12117, 'Naruto Shippuden S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/681819.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1L2kE3X4ZNU6dfzmD1d06F6nmoX.jpg'),
(171331, 12117, 'Naruto Shippuden S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/681820.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qk3fmPQgaaIxiPLMWVHpWPiG7tB.jpg'),
(171332, 12117, 'Naruto Shippuden S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/681821.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aN2VYpRtSD2rG82saKMBb6WyCNO.jpg'),
(171333, 12117, 'Naruto Shippuden S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/681822.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8GIHNqP7ti5Mr7zNuYAqtW3PQiG.jpg'),
(171334, 12117, 'Naruto Shippuden S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/681823.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/owaf7A2h80Z4wpO5uk7FyGI0aJC.jpg'),
(171335, 12117, 'Naruto Shippuden S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/681824.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zrLTiKHKCLpL6wIYktHeuqzReLd.jpg'),
(171336, 12117, 'Naruto Shippuden S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/681825.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iV0P2IAXXwT4Xi7u6mPaVdj6uiG.jpg'),
(171337, 12117, 'Naruto Shippuden S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/681826.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mbK86gFlL1LpnKOc1vqEHz0kzz9.jpg'),
(171338, 12117, 'Naruto Shippuden S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/681827.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aInrN4C4JZ20frxCABnr20Hzowg.jpg'),
(171339, 12117, 'Naruto Shippuden S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/681828.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wInPhXCXXuS39jeUi01zyRVmVff.jpg'),
(171340, 12117, 'Naruto Shippuden S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/681829.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a6WHDJiuS0Wa6fpinFKlCwEySlt.jpg'),
(171341, 12117, 'Naruto Shippuden S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/681830.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zCStDEj5HJ9dLHuYrD98VaF0x7a.jpg'),
(171342, 12117, 'Naruto Shippuden S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/681831.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ok86X8HZtq6f9dmJhm936WzoBz1.jpg'),
(171343, 12117, 'Naruto Shippuden S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/681832.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gNgVDS4Iz7mMvKJm3zZErsdfXrK.jpg'),
(171344, 12117, 'Naruto Shippuden S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/681833.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/notIng3dglR8oDxpn2eqqcbAlQ.jpg'),
(171345, 12117, 'Naruto Shippuden S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/681834.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pkVMxjubxaU2Wh7ebmHHFXKxgag.jpg'),
(171346, 12117, 'Naruto Shippuden S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/681835.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r2O3hE9gmqEIrknIvyD51OW8iqQ.jpg'),
(171347, 12117, 'Naruto Shippuden S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/681836.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vsodOg2ZFsduzmDjF91XfpajD4B.jpg'),
(171348, 12117, 'Naruto Shippuden S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/681837.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fs8m5qm6wLtDDPAId9DYSeBM9vr.jpg'),
(171349, 12118, 'Naruto Shippuden S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/681838.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/idGgNw7PluhW3ZVwAYTBNwAoNrv.jpg'),
(171350, 12118, 'Naruto Shippuden S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/681839.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ggFFr4J0BqbFC4gAJFYQdFul7P3.jpg'),
(171351, 12118, 'Naruto Shippuden S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/681840.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1vX2ZCv9aENT1HCOeBR4QTBLyOp.jpg'),
(171352, 12118, 'Naruto Shippuden S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/681841.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wMLSD4XehwOnGmATBCr3p6YsSf7.jpg'),
(171353, 12118, 'Naruto Shippuden S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/681842.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9SDMawGryb29Q5GClwsCklcJbcU.jpg'),
(171354, 12118, 'Naruto Shippuden S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/681843.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9QUftXbQ6rFN5vJB3QhWAmB9hxk.jpg'),
(171355, 12118, 'Naruto Shippuden S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/681844.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x8X5Dz9lV7dcwmdR4fkPc885kue.jpg'),
(171356, 12118, 'Naruto Shippuden S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/681845.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kNN8SAElsBrEdzxm0I1cVLAXhLR.jpg'),
(171357, 12118, 'Naruto Shippuden S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/681846.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k3Rm34fGhISm0QtrUugH44bpdJ3.jpg'),
(171358, 12118, 'Naruto Shippuden S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/681847.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zTJzNYTbBQ0dkL3rlFWfoJbDiaI.jpg'),
(171359, 12118, 'Naruto Shippuden S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/681848.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l7PFUKej6eqjCbIObmJtuaQOvQM.jpg'),
(171360, 12118, 'Naruto Shippuden S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/681849.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A3lMXjjsHP36t3qcsbM29LuZlnf.jpg'),
(171361, 12118, 'Naruto Shippuden S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/681850.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m6eyufJWMwtPVKM9LV36PIhmuBD.jpg'),
(171362, 12118, 'Naruto Shippuden S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/681851.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/arcifmnDuI79PXQI19xxaZ80dkX.jpg'),
(171363, 12118, 'Naruto Shippuden S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/681852.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/agHzRnWo0EGYhg64MUxbd2xFIIU.jpg'),
(171364, 12118, 'Naruto Shippuden S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/681853.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wRKivVGHvPHHb1fzHYNGPbJA6jA.jpg'),
(171365, 12118, 'Naruto Shippuden S03 E17', 'http://sinalprivado.info:80/series/1533784/1533784/681854.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xqr5XULcg8mcYjmBHjiEM1FacBa.jpg'),
(171366, 12118, 'Naruto Shippuden S03 E18', 'http://sinalprivado.info:80/series/1533784/1533784/681855.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q7IYMg3nF7e6yZrmVcq5mVhyJKO.jpg'),
(171367, 12119, 'Naruto Shippuden S04 E01', 'http://sinalprivado.info:80/series/1533784/1533784/681856.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uCsjd8M7e5k3hCBCzI7EBGxz2R3.jpg'),
(171368, 12119, 'Naruto Shippuden S04 E02', 'http://sinalprivado.info:80/series/1533784/1533784/681857.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xPmo2frDG1k54QClZAlVqEYFsue.jpg'),
(171369, 12119, 'Naruto Shippuden S04 E03', 'http://sinalprivado.info:80/series/1533784/1533784/681858.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q7IYMg3nF7e6yZrmVcq5mVhyJKO.jpg'),
(171370, 12119, 'Naruto Shippuden S04 E04', 'http://sinalprivado.info:80/series/1533784/1533784/681859.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uVGZLTQu5GW219pO5qzA8Poruij.jpg'),
(171371, 12119, 'Naruto Shippuden S04 E05', 'http://sinalprivado.info:80/series/1533784/1533784/681860.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xPmo2frDG1k54QClZAlVqEYFsue.jpg'),
(171372, 12119, 'Naruto Shippuden S04 E06', 'http://sinalprivado.info:80/series/1533784/1533784/681861.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mtNQH2Ek3V0YwBZFpp51oZYSTtf.jpg'),
(171373, 12119, 'Naruto Shippuden S04 E07', 'http://sinalprivado.info:80/series/1533784/1533784/681862.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/agSol2UnGeGiqaZ3oPpOlBS4vPO.jpg'),
(171374, 12119, 'Naruto Shippuden S04 E08', 'http://sinalprivado.info:80/series/1533784/1533784/681863.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kcOZ3ofIPGn74TA2J8zZw5A8kbT.jpg'),
(171375, 12119, 'Naruto Shippuden S04 E09', 'http://sinalprivado.info:80/series/1533784/1533784/681864.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6aATUasY99UqEDRf1nOVS8CDdLU.jpg'),
(171376, 12119, 'Naruto Shippuden S04 E10', 'http://sinalprivado.info:80/series/1533784/1533784/681865.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/glnI8hv8M4vysdYxeHiNMNnJYQS.jpg'),
(171377, 12119, 'Naruto Shippuden S04 E11', 'http://sinalprivado.info:80/series/1533784/1533784/681866.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/weWJZ8Bl9sOkLQwK5EOtiG3mnHL.jpg'),
(171378, 12119, 'Naruto Shippuden S04 E12', 'http://sinalprivado.info:80/series/1533784/1533784/681867.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lxJJSKmdsAVlCuuNlE52NlQH4fB.jpg'),
(171379, 12119, 'Naruto Shippuden S04 E13', 'http://sinalprivado.info:80/series/1533784/1533784/681868.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l59wRzVo7cs9UVGyRm1ATomMzNw.jpg'),
(171380, 12119, 'Naruto Shippuden S04 E14', 'http://sinalprivado.info:80/series/1533784/1533784/681869.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wfx6exN2JzyKFzP39QKeruT3wZv.jpg'),
(171381, 12119, 'Naruto Shippuden S04 E15', 'http://sinalprivado.info:80/series/1533784/1533784/681870.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dykuoBHD5lkmGz4NFT0Q8wA5I8E.jpg'),
(171382, 12119, 'Naruto Shippuden S04 E16', 'http://sinalprivado.info:80/series/1533784/1533784/681871.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y2LneBwhQp55tYnjGgHCQrhOsbW.jpg'),
(171383, 12119, 'Naruto Shippuden S04 E17', 'http://sinalprivado.info:80/series/1533784/1533784/681872.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yhdYMSvmsZ6QR21W7YvwkheWsC4.jpg'),
(171384, 12120, 'Naruto Shippuden S05 E01', 'http://sinalprivado.info:80/series/1533784/1533784/681873.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9oKWHve7gEkfd7SAS5fsMTT6j7Z.jpg'),
(171385, 12120, 'Naruto Shippuden S05 E02', 'http://sinalprivado.info:80/series/1533784/1533784/681874.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iqje2y5P22OVOBN8yUsd5IcMSgG.jpg'),
(171386, 12120, 'Naruto Shippuden S05 E03', 'http://sinalprivado.info:80/series/1533784/1533784/681875.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dPBafKIG8uGhoyCH2EERbZELA0S.jpg'),
(171387, 12120, 'Naruto Shippuden S05 E04', 'http://sinalprivado.info:80/series/1533784/1533784/681876.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jikqUvtf9ehZSpOA5KDq4gMlBEo.jpg'),
(171388, 12120, 'Naruto Shippuden S05 E05', 'http://sinalprivado.info:80/series/1533784/1533784/681877.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qszwr0V4XNdGwmgl4v1g9RH6Cvm.jpg'),
(171389, 12120, 'Naruto Shippuden S05 E06', 'http://sinalprivado.info:80/series/1533784/1533784/681878.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e7WOKR7OMiz4jMGAlsrOlgAljki.jpg'),
(171390, 12120, 'Naruto Shippuden S05 E07', 'http://sinalprivado.info:80/series/1533784/1533784/681879.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s8LzvuVykG9nl1hj24yMZzp5Mxt.jpg'),
(171391, 12120, 'Naruto Shippuden S05 E08', 'http://sinalprivado.info:80/series/1533784/1533784/681880.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/j3ZzeJww0pVWWjOo4UGqqvUgKAD.jpg'),
(171392, 12120, 'Naruto Shippuden S05 E09', 'http://sinalprivado.info:80/series/1533784/1533784/681881.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jv61JF7zcyyZveusgFnrtZqc57p.jpg'),
(171393, 12120, 'Naruto Shippuden S05 E10', 'http://sinalprivado.info:80/series/1533784/1533784/681882.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kTIeFqVRR8U78XG433ZkGVjohO3.jpg'),
(171394, 12120, 'Naruto Shippuden S05 E11', 'http://sinalprivado.info:80/series/1533784/1533784/681883.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9kV4GLBi4LNnj3XgpcVUsS2JHZD.jpg'),
(171395, 12120, 'Naruto Shippuden S05 E12', 'http://sinalprivado.info:80/series/1533784/1533784/681884.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6N9nyj9tRByDYyuLrxtiglZ7SmC.jpg'),
(171396, 12120, 'Naruto Shippuden S05 E13', 'http://sinalprivado.info:80/series/1533784/1533784/681885.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fqCAShbd8A5DVwYO09494gj8VmF.jpg'),
(171397, 12120, 'Naruto Shippuden S05 E14', 'http://sinalprivado.info:80/series/1533784/1533784/681886.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k6pCmpuHLwAaCiELxJ5EhbEijTY.jpg'),
(171398, 12120, 'Naruto Shippuden S05 E15', 'http://sinalprivado.info:80/series/1533784/1533784/681887.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p6rl5bZlX2dZwTeOsYP3dmof7z8.jpg'),
(171399, 12120, 'Naruto Shippuden S05 E16', 'http://sinalprivado.info:80/series/1533784/1533784/681888.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/36tRxqpxzMaWKj8OT8dHQdltOZw.jpg'),
(171400, 12120, 'Naruto Shippuden S05 E17', 'http://sinalprivado.info:80/series/1533784/1533784/681889.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kck31inOoyv59IN37HI9E89xRWB.jpg'),
(171401, 12120, 'Naruto Shippuden S05 E18', 'http://sinalprivado.info:80/series/1533784/1533784/681890.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/shWT6Wo5EfGtARL2cLts9QxPgkb.jpg'),
(171402, 12120, 'Naruto Shippuden S05 E19', 'http://sinalprivado.info:80/series/1533784/1533784/681891.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2UcI5ioWsfrS47psxCGHxDCamUe.jpg'),
(171403, 12120, 'Naruto Shippuden S05 E20', 'http://sinalprivado.info:80/series/1533784/1533784/681892.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qfNQpBK9mtw8RDhedGsuy8qiV7N.jpg'),
(171404, 12120, 'Naruto Shippuden S05 E21', 'http://sinalprivado.info:80/series/1533784/1533784/681893.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aS7T5zj18PcZOvHuiYdRzC8Mith.jpg'),
(171405, 12120, 'Naruto Shippuden S05 E22', 'http://sinalprivado.info:80/series/1533784/1533784/681894.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fKzB0HrC8ZXYn0ziOgXqObVSVYm.jpg'),
(171406, 12120, 'Naruto Shippuden S05 E23', 'http://sinalprivado.info:80/series/1533784/1533784/681895.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sV1vhtlycIDikpkQyskRSwuQR93.jpg'),
(171407, 12120, 'Naruto Shippuden S05 E24', 'http://sinalprivado.info:80/series/1533784/1533784/681896.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8nksz2F3y5lGP2wZM40DiBWK9cR.jpg'),
(171408, 12121, 'Naruto Shippuden S06 E01', 'http://sinalprivado.info:80/series/1533784/1533784/681897.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3DEJomeV3bGlGJxFO7ZGwa3U8bW.jpg'),
(171409, 12121, 'Naruto Shippuden S06 E02', 'http://sinalprivado.info:80/series/1533784/1533784/681898.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1jMpTzzmH8hS1UBcSHGAiWJ8yh2.jpg'),
(171410, 12121, 'Naruto Shippuden S06 E03', 'http://sinalprivado.info:80/series/1533784/1533784/681899.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rnjUd6FcZMTnefCS4LaDOvfQiUR.jpg'),
(171411, 12121, 'Naruto Shippuden S06 E04', 'http://sinalprivado.info:80/series/1533784/1533784/681900.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c6jONdyk02upLc8FL3kpCFaEXyQ.jpg'),
(171412, 12121, 'Naruto Shippuden S06 E05', 'http://sinalprivado.info:80/series/1533784/1533784/681901.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vIwhyAGmiE2fMme4gbRj58G0FOj.jpg'),
(171413, 12121, 'Naruto Shippuden S06 E06', 'http://sinalprivado.info:80/series/1533784/1533784/681902.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/GCCjrOuUU0HcVgYZqgipKoC86q.jpg'),
(171414, 12121, 'Naruto Shippuden S06 E07', 'http://sinalprivado.info:80/series/1533784/1533784/681903.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fWvmjtinPjPkTHRtrcDnR7GtCqw.jpg'),
(171415, 12121, 'Naruto Shippuden S06 E08', 'http://sinalprivado.info:80/series/1533784/1533784/681904.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eAoDOAqlHrrn9nbuKGeJwwiHEsF.jpg'),
(171416, 12121, 'Naruto Shippuden S06 E09', 'http://sinalprivado.info:80/series/1533784/1533784/681905.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AsNKbZuK85L57owwDPu5BPmTEF7.jpg'),
(171417, 12121, 'Naruto Shippuden S06 E10', 'http://sinalprivado.info:80/series/1533784/1533784/681906.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wDBuyfEHLvFdELrp6C5L87WQPP7.jpg'),
(171418, 12121, 'Naruto Shippuden S06 E11', 'http://sinalprivado.info:80/series/1533784/1533784/681907.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aCGBVD4ojyerrmWbEgMUcTzoZfz.jpg'),
(171419, 12121, 'Naruto Shippuden S06 E12', 'http://sinalprivado.info:80/series/1533784/1533784/681908.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q82Th2fRyYx9mjJIW8shmp95X7M.jpg'),
(171420, 12121, 'Naruto Shippuden S06 E13', 'http://sinalprivado.info:80/series/1533784/1533784/681909.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kfR7oaPZGavG7A8UD6zXRRLtqQb.jpg'),
(171421, 12121, 'Naruto Shippuden S06 E14', 'http://sinalprivado.info:80/series/1533784/1533784/681910.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uAl5S4c0WAyKVRsyKfTuHahrwiF.jpg'),
(171422, 12121, 'Naruto Shippuden S06 E15', 'http://sinalprivado.info:80/series/1533784/1533784/681911.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rFvWHw5UdanChiaitDUhRa8eoTY.jpg'),
(171423, 12121, 'Naruto Shippuden S06 E16', 'http://sinalprivado.info:80/series/1533784/1533784/681912.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/e0V4LOXJiWWpzpaJxOHJzySzdRP.jpg'),
(171424, 12121, 'Naruto Shippuden S06 E17', 'http://sinalprivado.info:80/series/1533784/1533784/681913.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/se2hngfJqzBSh4sG6jNVdzpo6uQ.jpg'),
(171425, 12121, 'Naruto Shippuden S06 E18', 'http://sinalprivado.info:80/series/1533784/1533784/681914.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6HmKEyGAUHbJ6KaPaLRBrmxWbM9.jpg'),
(171426, 12121, 'Naruto Shippuden S06 E19', 'http://sinalprivado.info:80/series/1533784/1533784/681915.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dI7XeFo03BNWAELOQ4jcbYa4eXv.jpg'),
(171427, 12121, 'Naruto Shippuden S06 E20', 'http://sinalprivado.info:80/series/1533784/1533784/681916.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aQkXQhJ5OMJtHvYGhcNsNWWpjwF.jpg'),
(171428, 12121, 'Naruto Shippuden S06 E21', 'http://sinalprivado.info:80/series/1533784/1533784/681917.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tRezdSyTC0N4oDbREiJaczrSy4P.jpg'),
(171429, 12121, 'Naruto Shippuden S06 E22', 'http://sinalprivado.info:80/series/1533784/1533784/681918.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hDx47H3s58FrgRqMQ4Zy99eoadA.jpg'),
(171430, 12121, 'Naruto Shippuden S06 E23', 'http://sinalprivado.info:80/series/1533784/1533784/681919.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pPqLXzdKeksvY2kptss2w115bvU.jpg'),
(171431, 12121, 'Naruto Shippuden S06 E24', 'http://sinalprivado.info:80/series/1533784/1533784/681920.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nwYfltiJHeeCphxhANk77lGIbUm.jpg'),
(171432, 12121, 'Naruto Shippuden S06 E25', 'http://sinalprivado.info:80/series/1533784/1533784/681921.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9vmWWgkau3lnpAqpEJ6c1Ah3Lbe.jpg'),
(171433, 12121, 'Naruto Shippuden S06 E26', 'http://sinalprivado.info:80/series/1533784/1533784/681922.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4nFSYt7uU0170f7cj8AL9auE46c.jpg'),
(171434, 12121, 'Naruto Shippuden S06 E27', 'http://sinalprivado.info:80/series/1533784/1533784/681923.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kWCDmeEsRzy0ZzSVgpGWTCIQlqd.jpg'),
(171435, 12121, 'Naruto Shippuden S06 E28', 'http://sinalprivado.info:80/series/1533784/1533784/681924.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/c1E7IhpaVqr0UqlLuxBCqHbYm8h.jpg'),
(171436, 12121, 'Naruto Shippuden S06 E29', 'http://sinalprivado.info:80/series/1533784/1533784/681925.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eK8TWfMKatvQcZ7caY2pQCFoyoZ.jpg'),
(171437, 12121, 'Naruto Shippuden S06 E30', 'http://sinalprivado.info:80/series/1533784/1533784/681926.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xIcceUEn1F089EMWbvQ72ncgVMe.jpg'),
(171438, 12121, 'Naruto Shippuden S06 E31', 'http://sinalprivado.info:80/series/1533784/1533784/681927.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ui5yD2HDArZ4htRS4AJ0NcgDu4x.jpg'),
(171439, 12122, 'Naruto Shippuden S07 E01', 'http://sinalprivado.info:80/series/1533784/1533784/681928.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9CVAFqU80BQaX5sS4iUOmdmN7Gj.jpg'),
(171440, 12122, 'Naruto Shippuden S07 E02', 'http://sinalprivado.info:80/series/1533784/1533784/681929.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2I7iAuYg00Vwb2Dya5xihWVB9Gy.jpg'),
(171441, 12122, 'Naruto Shippuden S07 E03', 'http://sinalprivado.info:80/series/1533784/1533784/681930.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n1MrjdOqi1OauhiJwdzVZGZsMAo.jpg'),
(171442, 12122, 'Naruto Shippuden S07 E04', 'http://sinalprivado.info:80/series/1533784/1533784/681931.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pyX4o0NzT5NHMjkBaloPLYmuj9P.jpg'),
(171443, 12122, 'Naruto Shippuden S07 E05', 'http://sinalprivado.info:80/series/1533784/1533784/681932.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eQhM3Q2zd57nieLF3SolVYIpO66.jpg'),
(171444, 12122, 'Naruto Shippuden S07 E06', 'http://sinalprivado.info:80/series/1533784/1533784/681933.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/f70RcT4jl9lSchZurHxsTEChnjX.jpg'),
(171445, 12122, 'Naruto Shippuden S07 E07', 'http://sinalprivado.info:80/series/1533784/1533784/681934.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4DgxcdSYA5WRjMMHF5UTmvwgOJL.jpg'),
(171446, 12122, 'Naruto Shippuden S07 E08', 'http://sinalprivado.info:80/series/1533784/1533784/681935.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qTypCsMzxQh0fc1ya4vmpyXfNbt.jpg'),
(171447, 12123, 'Naruto Shippuden S08 E01', 'http://sinalprivado.info:80/series/1533784/1533784/681936.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fQy5LVIYzMO2LWAn82YHcRLGUpz.jpg'),
(171448, 12123, 'Naruto Shippuden S08 E02', 'http://sinalprivado.info:80/series/1533784/1533784/681937.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vp1IKTYeeIgo08NMvGLfbvCfHV1.jpg'),
(171449, 12123, 'Naruto Shippuden S08 E03', 'http://sinalprivado.info:80/series/1533784/1533784/681938.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zrbQiHfZR7MAlTNmtYqP0WXlp6F.jpg'),
(171450, 12123, 'Naruto Shippuden S08 E04', 'http://sinalprivado.info:80/series/1533784/1533784/681939.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8pAl5NYIOJdVPyFIidrTO5ukW5F.jpg'),
(171451, 12123, 'Naruto Shippuden S08 E05', 'http://sinalprivado.info:80/series/1533784/1533784/681940.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nBH9IJAHHFemLIB0S4PNrQqka1q.jpg'),
(171452, 12123, 'Naruto Shippuden S08 E06', 'http://sinalprivado.info:80/series/1533784/1533784/681941.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5G4612ixdbw3FeXX4oesk9yDNgu.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(171453, 12123, 'Naruto Shippuden S08 E07', 'http://sinalprivado.info:80/series/1533784/1533784/681942.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qTcG2VUOlu4D0QSy8p0tFQvUzJZ.jpg'),
(171454, 12123, 'Naruto Shippuden S08 E08', 'http://sinalprivado.info:80/series/1533784/1533784/681943.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xaM20oKDdYp5GASAmR2XbdlJCcF.jpg'),
(171455, 12123, 'Naruto Shippuden S08 E09', 'http://sinalprivado.info:80/series/1533784/1533784/681944.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5fzNjcc77xQ6C0wjRJ5e950uK0z.jpg'),
(171456, 12123, 'Naruto Shippuden S08 E10', 'http://sinalprivado.info:80/series/1533784/1533784/681945.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AdNOvP39wJcDa6tkaPcrT76YCjE.jpg'),
(171457, 12123, 'Naruto Shippuden S08 E11', 'http://sinalprivado.info:80/series/1533784/1533784/681946.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vywLiwhCwV3CSyinKzwmljL5L1A.jpg'),
(171458, 12123, 'Naruto Shippuden S08 E12', 'http://sinalprivado.info:80/series/1533784/1533784/681947.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sLMENh6CdYhWv99r7fkkM9g6Kvi.jpg'),
(171459, 12123, 'Naruto Shippuden S08 E13', 'http://sinalprivado.info:80/series/1533784/1533784/681948.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zJx4HNhRHuezCGIVFDn3uwW0nXb.jpg'),
(171460, 12123, 'Naruto Shippuden S08 E14', 'http://sinalprivado.info:80/series/1533784/1533784/681949.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ejnSRdNTLAkzaUTROSYQvinrG33.jpg'),
(171461, 12123, 'Naruto Shippuden S08 E15', 'http://sinalprivado.info:80/series/1533784/1533784/681950.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hfq7gnNl6qdiStHA4Yh4g3j96Bd.jpg'),
(171462, 12123, 'Naruto Shippuden S08 E16', 'http://sinalprivado.info:80/series/1533784/1533784/681951.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/enKVEjxnAlan27u5NU97tRDOSl6.jpg'),
(171463, 12123, 'Naruto Shippuden S08 E17', 'http://sinalprivado.info:80/series/1533784/1533784/681952.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hIB0A0TkpwXKcZy0xLmmS9lUlGe.jpg'),
(171464, 12123, 'Naruto Shippuden S08 E18', 'http://sinalprivado.info:80/series/1533784/1533784/681953.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pnMtDhkrrvEjYhIYvnpu1V0uZox.jpg'),
(171465, 12123, 'Naruto Shippuden S08 E19', 'http://sinalprivado.info:80/series/1533784/1533784/681954.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iNVrPCWmID2h4xjzO1HDtvZteac.jpg'),
(171466, 12123, 'Naruto Shippuden S08 E20', 'http://sinalprivado.info:80/series/1533784/1533784/681955.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/p4SooI9J93ZU1Nzfo9xJYzzZNub.jpg'),
(171467, 12123, 'Naruto Shippuden S08 E21', 'http://sinalprivado.info:80/series/1533784/1533784/681956.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5pXbIc9hVXrFYToaxK8Rx7UqLcD.jpg'),
(171468, 12123, 'Naruto Shippuden S08 E22', 'http://sinalprivado.info:80/series/1533784/1533784/681957.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aVBUUj70LejeLOpJHIvgLfx03An.jpg'),
(171469, 12123, 'Naruto Shippuden S08 E23', 'http://sinalprivado.info:80/series/1533784/1533784/681958.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/joyTrrO0LNTDi3QLxHTkiwRqrtN.jpg'),
(171470, 12123, 'Naruto Shippuden S08 E24', 'http://sinalprivado.info:80/series/1533784/1533784/681959.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dZyOizROq6WZ9dP0y5vTCyI6Ht1.jpg'),
(171471, 12124, 'Naruto Shippuden S09 E01', 'http://sinalprivado.info:80/series/1533784/1533784/681960.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cBwmVioMYZrInqO6sBQcXgRKvxS.jpg'),
(171472, 12124, 'Naruto Shippuden S09 E02', 'http://sinalprivado.info:80/series/1533784/1533784/681961.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/of9SJDTmKwoyBGhhbJWQqo1QtKV.jpg'),
(171473, 12124, 'Naruto Shippuden S09 E03', 'http://sinalprivado.info:80/series/1533784/1533784/681962.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ssHJtHoARbrtFPg4xl2Jy91EADa.jpg'),
(171474, 12124, 'Naruto Shippuden S09 E04', 'http://sinalprivado.info:80/series/1533784/1533784/681963.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bApipaJPCXQIGUubRhIACTvzgcb.jpg'),
(171475, 12124, 'Naruto Shippuden S09 E05', 'http://sinalprivado.info:80/series/1533784/1533784/681964.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lUFFqhc11a1GJWbSIDGSbmt59kc.jpg'),
(171476, 12124, 'Naruto Shippuden S09 E06', 'http://sinalprivado.info:80/series/1533784/1533784/681965.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5RlcKufD2o0rDJk2HFP652ZuDUD.jpg'),
(171477, 12124, 'Naruto Shippuden S09 E07', 'http://sinalprivado.info:80/series/1533784/1533784/681966.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ruElGoLebZy2DTKKqnMCkULBE2r.jpg'),
(171478, 12124, 'Naruto Shippuden S09 E08', 'http://sinalprivado.info:80/series/1533784/1533784/681967.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o7EVLp3Jn7fOQekGx1N5NY7EgUt.jpg'),
(171479, 12124, 'Naruto Shippuden S09 E09', 'http://sinalprivado.info:80/series/1533784/1533784/681968.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tc8DZn1G4gsDuPIKxKrOKLuyhT3.jpg'),
(171480, 12124, 'Naruto Shippuden S09 E10', 'http://sinalprivado.info:80/series/1533784/1533784/681969.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mZWqqQVCZfK6RNuGxjbVBeVvYjH.jpg'),
(171481, 12124, 'Naruto Shippuden S09 E11', 'http://sinalprivado.info:80/series/1533784/1533784/681970.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u5vGLLcnvHZOOM8IoEPuJT5p7Mt.jpg'),
(171482, 12124, 'Naruto Shippuden S09 E12', 'http://sinalprivado.info:80/series/1533784/1533784/681971.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zbOlAN0TdIsGZwZoYfir333VNHD.jpg'),
(171483, 12124, 'Naruto Shippuden S09 E13', 'http://sinalprivado.info:80/series/1533784/1533784/681972.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tWfDVXbfvXk0JQnDCSh4cLExH1H.jpg'),
(171484, 12124, 'Naruto Shippuden S09 E14', 'http://sinalprivado.info:80/series/1533784/1533784/681973.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qlBD3X7EngeJOVE9dWcMvu6jZSe.jpg'),
(171485, 12124, 'Naruto Shippuden S09 E15', 'http://sinalprivado.info:80/series/1533784/1533784/681974.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tfKkfq3lgLZxsCv8SrbwwlSlWGu.jpg'),
(171486, 12124, 'Naruto Shippuden S09 E16', 'http://sinalprivado.info:80/series/1533784/1533784/681975.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5G4rnpNZdDgJKhZfBMzulu5Rq5N.jpg'),
(171487, 12124, 'Naruto Shippuden S09 E17', 'http://sinalprivado.info:80/series/1533784/1533784/681976.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/y47cuXkBEdhmGnZQMZA0uYNyvya.jpg'),
(171488, 12124, 'Naruto Shippuden S09 E18', 'http://sinalprivado.info:80/series/1533784/1533784/681977.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xkfbOQifbExZPMRdVu1IkDeGy5K.jpg'),
(171489, 12124, 'Naruto Shippuden S09 E19', 'http://sinalprivado.info:80/series/1533784/1533784/681978.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oEzLPaKvKhxsVVK3sfxdPwEuWTQ.jpg'),
(171490, 12124, 'Naruto Shippuden S09 E20', 'http://sinalprivado.info:80/series/1533784/1533784/681979.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xHbJW7Kbg8C5TF8Ke6TL8goLFPe.jpg'),
(171491, 12124, 'Naruto Shippuden S09 E21', 'http://sinalprivado.info:80/series/1533784/1533784/681980.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yNzm9KtOMiYMKyeStzmDpG4wF66.jpg'),
(171492, 12125, 'Naruto Shippuden S10 E01', 'http://sinalprivado.info:80/series/1533784/1533784/681981.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pwvA39RanKWk0NyiRZFraUYgKzH.jpg'),
(171493, 12125, 'Naruto Shippuden S10 E02', 'http://sinalprivado.info:80/series/1533784/1533784/681982.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gVMCEToEShzeX1uvWSAMeJjhuJY.jpg'),
(171494, 12125, 'Naruto Shippuden S10 E03', 'http://sinalprivado.info:80/series/1533784/1533784/681983.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/upMuTdqBfrHzqTkScZBw3Td8B0U.jpg'),
(171495, 12125, 'Naruto Shippuden S10 E04', 'http://sinalprivado.info:80/series/1533784/1533784/681984.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oj3Q6NlkpjzGDwaFgM7CiUyKsvl.jpg'),
(171496, 12125, 'Naruto Shippuden S10 E05', 'http://sinalprivado.info:80/series/1533784/1533784/681985.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9XgGPw2OYIFYVgIqneoSEkXGZ0c.jpg'),
(171497, 12125, 'Naruto Shippuden S10 E06', 'http://sinalprivado.info:80/series/1533784/1533784/681986.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4560DTkqMu5xX5Bg9x3rWnGpdXn.jpg'),
(171498, 12125, 'Naruto Shippuden S10 E07', 'http://sinalprivado.info:80/series/1533784/1533784/681987.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6WstPGyyh32urHnYNH1wo61dRBA.jpg'),
(171499, 12125, 'Naruto Shippuden S10 E08', 'http://sinalprivado.info:80/series/1533784/1533784/681988.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/v4xUsTEe54ZbCs0vOYG11T238qR.jpg'),
(171500, 12125, 'Naruto Shippuden S10 E09', 'http://sinalprivado.info:80/series/1533784/1533784/681989.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/HXe7sMV7ynNqyv5IDArAczkx9z.jpg'),
(171501, 12125, 'Naruto Shippuden S10 E10', 'http://sinalprivado.info:80/series/1533784/1533784/681990.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eCIBF5jWrK8MUuNHEgPOEMIOj6R.jpg'),
(171502, 12125, 'Naruto Shippuden S10 E11', 'http://sinalprivado.info:80/series/1533784/1533784/681991.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pmenp5p5KemqhSnrUt2c7YaLQGh.jpg'),
(171503, 12125, 'Naruto Shippuden S10 E12', 'http://sinalprivado.info:80/series/1533784/1533784/681992.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tcdb8GDlW7UQRzOKyTHJhnWFIx4.jpg'),
(171504, 12125, 'Naruto Shippuden S10 E13', 'http://sinalprivado.info:80/series/1533784/1533784/681993.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/h5h16LBGMaJQmpeu2pqPCMWnsjn.jpg'),
(171505, 12125, 'Naruto Shippuden S10 E14', 'http://sinalprivado.info:80/series/1533784/1533784/681994.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yxWJmpGnNeUkKOZYNYF3dla3Anz.jpg'),
(171506, 12125, 'Naruto Shippuden S10 E15', 'http://sinalprivado.info:80/series/1533784/1533784/681995.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dekrX8Qo7IPhAwpkq6AsyqzCVvD.jpg'),
(171507, 12125, 'Naruto Shippuden S10 E16', 'http://sinalprivado.info:80/series/1533784/1533784/681996.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7jG4eX6r1oeS1QPweXT5k7R5dUU.jpg'),
(171508, 12125, 'Naruto Shippuden S10 E17', 'http://sinalprivado.info:80/series/1533784/1533784/681997.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4RNImttMwLF9HvHOPTarcbx6S4L.jpg'),
(171509, 12125, 'Naruto Shippuden S10 E18', 'http://sinalprivado.info:80/series/1533784/1533784/681998.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3IdEHiCzZsOwmxa5JIfjiVcvnZ8.jpg'),
(171510, 12125, 'Naruto Shippuden S10 E19', 'http://sinalprivado.info:80/series/1533784/1533784/681999.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tvxAfxx9uUAplUw4mmI7fSJxkzV.jpg'),
(171511, 12125, 'Naruto Shippuden S10 E20', 'http://sinalprivado.info:80/series/1533784/1533784/682000.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/RaHo2uLlQhg0wFxqU4NiCFqAaw.jpg'),
(171512, 12125, 'Naruto Shippuden S10 E21', 'http://sinalprivado.info:80/series/1533784/1533784/682001.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eHTkbNb3G6ITS5MaqRw0rF8Lkfs.jpg'),
(171513, 12125, 'Naruto Shippuden S10 E22', 'http://sinalprivado.info:80/series/1533784/1533784/682002.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hdlbofXkzYigOrIN6sUOTkcPS58.jpg'),
(171514, 12125, 'Naruto Shippuden S10 E23', 'http://sinalprivado.info:80/series/1533784/1533784/682003.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cDyTiuZ1B9eudT5tFUDdUnlxl23.jpg'),
(171515, 12125, 'Naruto Shippuden S10 E24', 'http://sinalprivado.info:80/series/1533784/1533784/682004.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fvN8sFB0S2EmTAkZPXhhuIh3jqM.jpg'),
(171516, 12125, 'Naruto Shippuden S10 E25', 'http://sinalprivado.info:80/series/1533784/1533784/682005.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bvwY9mjYYjPgb4utBKMUFIYw69P.jpg'),
(171517, 12126, 'Naruto Shippuden S11 E01', 'http://sinalprivado.info:80/series/1533784/1533784/682006.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Ej4Ej5Y60mQTuBm2R5BYNmycuC.jpg'),
(171518, 12126, 'Naruto Shippuden S11 E02', 'http://sinalprivado.info:80/series/1533784/1533784/682007.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2ogU6uxZardUqnK1ERQzSixIOkz.jpg'),
(171519, 12126, 'Naruto Shippuden S11 E03', 'http://sinalprivado.info:80/series/1533784/1533784/682008.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s4ns8U0MBUt1WmkJlPX4sSxZjiq.jpg'),
(171520, 12126, 'Naruto Shippuden S11 E04', 'http://sinalprivado.info:80/series/1533784/1533784/682009.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x1fwh9H6nHNTyIuaZKSSyJGrzh.jpg'),
(171521, 12126, 'Naruto Shippuden S11 E05', 'http://sinalprivado.info:80/series/1533784/1533784/682010.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s5nvna0W2Ox2qEFEOG3f4nrhznG.jpg'),
(171522, 12126, 'Naruto Shippuden S11 E06', 'http://sinalprivado.info:80/series/1533784/1533784/682011.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/m3Cylm8RsUdvZ5a7DVVszpovX8p.jpg'),
(171523, 12126, 'Naruto Shippuden S11 E07', 'http://sinalprivado.info:80/series/1533784/1533784/682012.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r3WEVJj8vzRSDBlpUajk4uO9ZJW.jpg'),
(171524, 12126, 'Naruto Shippuden S11 E08', 'http://sinalprivado.info:80/series/1533784/1533784/682013.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bbqPGaNwumTDaWsXvno71Y1Teo9.jpg'),
(171525, 12126, 'Naruto Shippuden S11 E09', 'http://sinalprivado.info:80/series/1533784/1533784/682014.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5k1xDzSZSwCVPZlQfgy92UnG6p2.jpg'),
(171526, 12126, 'Naruto Shippuden S11 E10', 'http://sinalprivado.info:80/series/1533784/1533784/682015.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oeyGCX605wxbRuntEFNDWYTQ3wI.jpg'),
(171527, 12126, 'Naruto Shippuden S11 E11', 'http://sinalprivado.info:80/series/1533784/1533784/682016.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Amalzet732jv2AmTkOyNqaz4g8T.jpg'),
(171528, 12126, 'Naruto Shippuden S11 E12', 'http://sinalprivado.info:80/series/1533784/1533784/682017.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/meXZCjShKv1AL5xb8UNpS0vlfyC.jpg'),
(171529, 12126, 'Naruto Shippuden S11 E13', 'http://sinalprivado.info:80/series/1533784/1533784/682018.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wHQtjPKrDzxuBV9uEWn7ujhnpFb.jpg'),
(171530, 12126, 'Naruto Shippuden S11 E14', 'http://sinalprivado.info:80/series/1533784/1533784/682019.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/psavh90EW1nw8i8yhLOm04VHUgu.jpg'),
(171531, 12126, 'Naruto Shippuden S11 E15', 'http://sinalprivado.info:80/series/1533784/1533784/682020.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1L5GNZd9BfU5bzybah5otdJ7udA.jpg'),
(171532, 12126, 'Naruto Shippuden S11 E16', 'http://sinalprivado.info:80/series/1533784/1533784/682021.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xxhh36LrDZCGchw55EK1Lmdg1lz.jpg'),
(171533, 12126, 'Naruto Shippuden S11 E17', 'http://sinalprivado.info:80/series/1533784/1533784/682022.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6gCOYUksAWGk45ICdjcx4hpqo33.jpg'),
(171534, 12126, 'Naruto Shippuden S11 E18', 'http://sinalprivado.info:80/series/1533784/1533784/682023.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sJJljtuVY0LrrGZb3aXYYPIBJYD.jpg'),
(171535, 12126, 'Naruto Shippuden S11 E19', 'http://sinalprivado.info:80/series/1533784/1533784/682024.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mwcxYOpl6VkAuhwixURvRzM6qBL.jpg'),
(171536, 12126, 'Naruto Shippuden S11 E20', 'http://sinalprivado.info:80/series/1533784/1533784/682025.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hJmhVoZhPAYU4qanohbkq8IEzjJ.jpg'),
(171537, 12126, 'Naruto Shippuden S11 E21', 'http://sinalprivado.info:80/series/1533784/1533784/682026.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xVtDy2h7sxfFmaG3gTlw8yk7mtA.jpg'),
(171538, 12127, 'Naruto Shippuden S12 E01', 'http://sinalprivado.info:80/series/1533784/1533784/682027.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ahZ3LDTDnnzrdix8A77mxMJMVEW.jpg'),
(171539, 12127, 'Naruto Shippuden S12 E02', 'http://sinalprivado.info:80/series/1533784/1533784/682028.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aUAI5P2JYksYcolkLlQ31I8nLRa.jpg'),
(171540, 12127, 'Naruto Shippuden S12 E03', 'http://sinalprivado.info:80/series/1533784/1533784/682029.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qbDtohKtARZXn4jRGzugk6oR0tl.jpg'),
(171541, 12127, 'Naruto Shippuden S12 E04', 'http://sinalprivado.info:80/series/1533784/1533784/682030.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/abOz9XydMx0P3EK22zsE0Xs4qi5.jpg'),
(171542, 12127, 'Naruto Shippuden S12 E05', 'http://sinalprivado.info:80/series/1533784/1533784/682031.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qheaSFLbuphQYGjtj5aM82k9vIi.jpg'),
(171543, 12127, 'Naruto Shippuden S12 E06', 'http://sinalprivado.info:80/series/1533784/1533784/682032.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t9dC9AREe8p9pqxtIdfSklGtcoV.jpg'),
(171544, 12127, 'Naruto Shippuden S12 E07', 'http://sinalprivado.info:80/series/1533784/1533784/682033.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kFSbieZWQ38LydROPpL83aPetFl.jpg'),
(171545, 12127, 'Naruto Shippuden S12 E08', 'http://sinalprivado.info:80/series/1533784/1533784/682034.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oRr3TSdNkuweiTwwNscd047cGfr.jpg'),
(171546, 12127, 'Naruto Shippuden S12 E09', 'http://sinalprivado.info:80/series/1533784/1533784/682035.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hd4Zm0UDBc1AXIpyx9A0tOSUzsG.jpg'),
(171547, 12127, 'Naruto Shippuden S12 E10', 'http://sinalprivado.info:80/series/1533784/1533784/682036.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/l5Gaq93lYyMjnH6jyWfuUh6O23S.jpg'),
(171548, 12127, 'Naruto Shippuden S12 E11', 'http://sinalprivado.info:80/series/1533784/1533784/682037.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/negHHtcWuK7vrdFRzNSktYUfs4A.jpg'),
(171549, 12127, 'Naruto Shippuden S12 E12', 'http://sinalprivado.info:80/series/1533784/1533784/682038.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ky6Ky6cpvqLn2VmRYGKzJ2bCLTo.jpg'),
(171550, 12127, 'Naruto Shippuden S12 E13', 'http://sinalprivado.info:80/series/1533784/1533784/682039.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nKFkOTvN53Vs7YcXBcPOnaIdNHo.jpg'),
(171551, 12127, 'Naruto Shippuden S12 E14', 'http://sinalprivado.info:80/series/1533784/1533784/682040.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5ateBKVQFLTtLxc5OseVATx8UbX.jpg'),
(171552, 12127, 'Naruto Shippuden S12 E15', 'http://sinalprivado.info:80/series/1533784/1533784/682041.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zbkZLJ1x39LGIK87cjY4kTjZO22.jpg'),
(171553, 12127, 'Naruto Shippuden S12 E16', 'http://sinalprivado.info:80/series/1533784/1533784/682042.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uDEpWPsggFkCnkHILHSV6yOXRBt.jpg'),
(171554, 12127, 'Naruto Shippuden S12 E17', 'http://sinalprivado.info:80/series/1533784/1533784/682043.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t7DS2TlHhOqQPbXkiSlGTqjhcfT.jpg'),
(171555, 12127, 'Naruto Shippuden S12 E18', 'http://sinalprivado.info:80/series/1533784/1533784/682044.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ktcfSW2ShqzAYbXi1q5TvKX714w.jpg'),
(171556, 12127, 'Naruto Shippuden S12 E19', 'http://sinalprivado.info:80/series/1533784/1533784/682045.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uTLSPX8jMZlaH3ozQhoiWjF0oGQ.jpg'),
(171557, 12127, 'Naruto Shippuden S12 E20', 'http://sinalprivado.info:80/series/1533784/1533784/682046.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iC4XUKpaBqJ1KEIr6b9oDRR2ndt.jpg'),
(171558, 12127, 'Naruto Shippuden S12 E21', 'http://sinalprivado.info:80/series/1533784/1533784/682047.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1ilQe6VlFuNxVPJPaP5O0eNsTu.jpg'),
(171559, 12127, 'Naruto Shippuden S12 E22', 'http://sinalprivado.info:80/series/1533784/1533784/682048.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fnFkDDIHchtZFSdOV39aHUvPTdd.jpg'),
(171560, 12127, 'Naruto Shippuden S12 E23', 'http://sinalprivado.info:80/series/1533784/1533784/682049.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6esQ1wgZhkpsGWYZlPqyrOF1ZT5.jpg'),
(171561, 12127, 'Naruto Shippuden S12 E24', 'http://sinalprivado.info:80/series/1533784/1533784/682050.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uc37l6oMLfqu7Hr2O0vhxjvVIzt.jpg'),
(171562, 12127, 'Naruto Shippuden S12 E25', 'http://sinalprivado.info:80/series/1533784/1533784/682051.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ePWi4MtdHf042b7ViocHf9gCJsK.jpg'),
(171563, 12127, 'Naruto Shippuden S12 E26', 'http://sinalprivado.info:80/series/1533784/1533784/682052.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xw9jkmqCAgZOf10gOlWJF4hUwjs.jpg'),
(171564, 12127, 'Naruto Shippuden S12 E27', 'http://sinalprivado.info:80/series/1533784/1533784/682053.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4qM9RcRtLsdWPZ5AfcyTTJxtuIY.jpg'),
(171565, 12127, 'Naruto Shippuden S12 E28', 'http://sinalprivado.info:80/series/1533784/1533784/682054.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4PRM6HycIcxPLr91uuqYsvn0TAj.jpg'),
(171566, 12127, 'Naruto Shippuden S12 E29', 'http://sinalprivado.info:80/series/1533784/1533784/682055.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eFvhGPUJq8eCwiPIJ0KmSYl4hFK.jpg'),
(171567, 12127, 'Naruto Shippuden S12 E30', 'http://sinalprivado.info:80/series/1533784/1533784/682056.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nP1FAvy77qxr493gstvtQzCoSNb.jpg'),
(171568, 12127, 'Naruto Shippuden S12 E31', 'http://sinalprivado.info:80/series/1533784/1533784/682057.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xYfwvYBgYrPQjLfuNUlEoJHlnHM.jpg'),
(171569, 12127, 'Naruto Shippuden S12 E32', 'http://sinalprivado.info:80/series/1533784/1533784/682058.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kB4bqTnSorNzFt33GScnu2TwEmJ.jpg'),
(171570, 12127, 'Naruto Shippuden S12 E33', 'http://sinalprivado.info:80/series/1533784/1533784/682059.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bL1G61OwrJhfo41UEuIaVbG3Fbt.jpg'),
(171571, 12128, 'Naruto Shippuden S13 E01', 'http://sinalprivado.info:80/series/1533784/1533784/682060.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gzxgewfqFV3JRDDojlRZjYLFBQ.jpg'),
(171572, 12128, 'Naruto Shippuden S13 E02', 'http://sinalprivado.info:80/series/1533784/1533784/682061.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pHHrRmlCxL5aI24HV72ULQLdrvZ.jpg'),
(171573, 12128, 'Naruto Shippuden S13 E03', 'http://sinalprivado.info:80/series/1533784/1533784/682062.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8HgzIKSJzt4IfNuwcg9yj4Mtrq0.jpg'),
(171574, 12128, 'Naruto Shippuden S13 E04', 'http://sinalprivado.info:80/series/1533784/1533784/682063.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/A5C6a4lCbdmt1PL0skYFFjAgqGB.jpg'),
(171575, 12128, 'Naruto Shippuden S13 E05', 'http://sinalprivado.info:80/series/1533784/1533784/682064.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1qX57RD95dU9Zmk8lzdKkYvFg3h.jpg'),
(171576, 12128, 'Naruto Shippuden S13 E06', 'http://sinalprivado.info:80/series/1533784/1533784/682065.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jn9bBgoCtmmbbyzrNFWw2tT8CMR.jpg'),
(171577, 12128, 'Naruto Shippuden S13 E07', 'http://sinalprivado.info:80/series/1533784/1533784/682066.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cFmJrGnbLSEUIgdpoBrwBKtmHBB.jpg'),
(171578, 12128, 'Naruto Shippuden S13 E08', 'http://sinalprivado.info:80/series/1533784/1533784/682067.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jaf7g2v38NJrJeRcafuae5Hb2f3.jpg'),
(171579, 12128, 'Naruto Shippuden S13 E09', 'http://sinalprivado.info:80/series/1533784/1533784/682068.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gVRArlSTmnr1u0oafFHqXmQ5CUJ.jpg'),
(171580, 12128, 'Naruto Shippuden S13 E10', 'http://sinalprivado.info:80/series/1533784/1533784/682069.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9w88h2qEdcFykeHkD2pHmn5LjAU.jpg'),
(171581, 12128, 'Naruto Shippuden S13 E11', 'http://sinalprivado.info:80/series/1533784/1533784/682070.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cdnBZYcOL5u39iOqN8QLJWZ13xe.jpg'),
(171582, 12128, 'Naruto Shippuden S13 E12', 'http://sinalprivado.info:80/series/1533784/1533784/682071.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cKLQQ2frr6CjklYjy9i5T22iiIy.jpg'),
(171583, 12128, 'Naruto Shippuden S13 E13', 'http://sinalprivado.info:80/series/1533784/1533784/682072.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fciZvJwUJj9QZTHAbXjbbzmN19E.jpg'),
(171584, 12128, 'Naruto Shippuden S13 E14', 'http://sinalprivado.info:80/series/1533784/1533784/682073.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eljL1TV7MhNKhxDJgpg0x2phoCX.jpg'),
(171585, 12128, 'Naruto Shippuden S13 E15', 'http://sinalprivado.info:80/series/1533784/1533784/682074.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dNt2v7vw4wVnENbsXxnLHdPwr62.jpg'),
(171586, 12128, 'Naruto Shippuden S13 E16', 'http://sinalprivado.info:80/series/1533784/1533784/682075.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/z0MzTw0Tb7RAhQjsPDNjOcqICiC.jpg'),
(171587, 12128, 'Naruto Shippuden S13 E17', 'http://sinalprivado.info:80/series/1533784/1533784/682076.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s65Ds6RmmwoQqJLnEpWXuuvmwK6.jpg'),
(171588, 12128, 'Naruto Shippuden S13 E18', 'http://sinalprivado.info:80/series/1533784/1533784/682077.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ArAWtoGNxRVcpb3vIsnU4gSvyYf.jpg'),
(171589, 12128, 'Naruto Shippuden S13 E19', 'http://sinalprivado.info:80/series/1533784/1533784/682078.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fl5XXURWqYuxOPwgBQtL2tpfH1x.jpg'),
(171590, 12128, 'Naruto Shippuden S13 E20', 'http://sinalprivado.info:80/series/1533784/1533784/682079.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Ajd2R9NuAx0qDRaUe5Qlp0l721M.jpg'),
(171591, 12129, 'Naruto Shippuden S14 E01', 'http://sinalprivado.info:80/series/1533784/1533784/682080.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171592, 12129, 'Naruto Shippuden S14 E02', 'http://sinalprivado.info:80/series/1533784/1533784/682081.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171593, 12129, 'Naruto Shippuden S14 E03', 'http://sinalprivado.info:80/series/1533784/1533784/682082.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171594, 12129, 'Naruto Shippuden S14 E04', 'http://sinalprivado.info:80/series/1533784/1533784/682083.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171595, 12129, 'Naruto Shippuden S14 E05', 'http://sinalprivado.info:80/series/1533784/1533784/682084.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171596, 12129, 'Naruto Shippuden S14 E06', 'http://sinalprivado.info:80/series/1533784/1533784/682085.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171597, 12129, 'Naruto Shippuden S14 E07', 'http://sinalprivado.info:80/series/1533784/1533784/682086.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171598, 12129, 'Naruto Shippuden S14 E08', 'http://sinalprivado.info:80/series/1533784/1533784/682087.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171599, 12129, 'Naruto Shippuden S14 E09', 'http://sinalprivado.info:80/series/1533784/1533784/682088.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171600, 12129, 'Naruto Shippuden S14 E10', 'http://sinalprivado.info:80/series/1533784/1533784/682089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171601, 12129, 'Naruto Shippuden S14 E11', 'http://sinalprivado.info:80/series/1533784/1533784/682090.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171602, 12129, 'Naruto Shippuden S14 E12', 'http://sinalprivado.info:80/series/1533784/1533784/682091.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171603, 12129, 'Naruto Shippuden S14 E13', 'http://sinalprivado.info:80/series/1533784/1533784/682092.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171604, 12129, 'Naruto Shippuden S14 E14', 'http://sinalprivado.info:80/series/1533784/1533784/682093.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171605, 12129, 'Naruto Shippuden S14 E15', 'http://sinalprivado.info:80/series/1533784/1533784/682094.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171606, 12129, 'Naruto Shippuden S14 E16', 'http://sinalprivado.info:80/series/1533784/1533784/682095.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171607, 12129, 'Naruto Shippuden S14 E17', 'http://sinalprivado.info:80/series/1533784/1533784/879512.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171608, 12129, 'Naruto Shippuden S14 E18', 'http://sinalprivado.info:80/series/1533784/1533784/879513.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/eC3lcqbgMCwpgsoER1ac9fZzuLo.jpg'),
(171609, 12129, 'Naruto Shippuden S14 E19', 'http://sinalprivado.info:80/series/1533784/1533784/879514.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bx0Lq6Trgx1p0QH9Y9rrt9K4PFu.jpg'),
(171610, 12129, 'Naruto Shippuden S14 E20', 'http://sinalprivado.info:80/series/1533784/1533784/879515.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5wzEmYEO1NLCvbGcB1G4CvKdrAE.jpg'),
(171611, 12129, 'Naruto Shippuden S14 E21', 'http://sinalprivado.info:80/series/1533784/1533784/879516.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fTanORW8xOnH96bVf8Qwnu1dpSR.jpg'),
(171612, 12129, 'Naruto Shippuden S14 E22', 'http://sinalprivado.info:80/series/1533784/1533784/879517.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hrkbaVydNe2mqqVmJcKGwnc1BPc.jpg'),
(171613, 12129, 'Naruto Shippuden S14 E23', 'http://sinalprivado.info:80/series/1533784/1533784/879518.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/i6n4bqygw7hM0M8URNAlKF3oGlg.jpg'),
(171614, 12129, 'Naruto Shippuden S14 E24', 'http://sinalprivado.info:80/series/1533784/1533784/879519.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tvxs3NvQDSU32wJwnmLyj0pmlRP.jpg'),
(171615, 12129, 'Naruto Shippuden S14 E25', 'http://sinalprivado.info:80/series/1533784/1533784/879520.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/drlvnY5c4VZXeELJpOrI4T2oyfc.jpg'),
(171616, 12130, 'Naruto Shippuden S15 E01', 'http://sinalprivado.info:80/series/1533784/1533784/879521.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/b1mhhD5GFi2RZXotgLO0aI0gP1u.jpg'),
(171617, 12130, 'Naruto Shippuden S15 E02', 'http://sinalprivado.info:80/series/1533784/1533784/879522.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9tNh3rw3ATMyNy06NSpTiHY6qoZ.jpg'),
(171618, 12130, 'Naruto Shippuden S15 E03', 'http://sinalprivado.info:80/series/1533784/1533784/879523.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9iYZ4B6TfLWh6wdTqjSLuYhSVUT.jpg'),
(171619, 12130, 'Naruto Shippuden S15 E04', 'http://sinalprivado.info:80/series/1533784/1533784/879524.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/tPh0qENp7ndqFajRnhcXmccrt8z.jpg'),
(171620, 12130, 'Naruto Shippuden S15 E05', 'http://sinalprivado.info:80/series/1533784/1533784/879525.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/hLdTu8uY0BD34xuEf7HsGY79TDa.jpg'),
(171621, 12130, 'Naruto Shippuden S15 E06', 'http://sinalprivado.info:80/series/1533784/1533784/879526.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pU0iR2qhDXQfggIK7d70llDZcXv.jpg'),
(171622, 12130, 'Naruto Shippuden S15 E07', 'http://sinalprivado.info:80/series/1533784/1533784/879527.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/bdpCLiBSYBd3ofGGBKQq1pJarOZ.jpg'),
(171623, 12130, 'Naruto Shippuden S15 E08', 'http://sinalprivado.info:80/series/1533784/1533784/879528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dozR5WXDs6e07Z8xyjAzXcoEAhC.jpg'),
(171624, 12130, 'Naruto Shippuden S15 E09', 'http://sinalprivado.info:80/series/1533784/1533784/879529.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qXWNsNdlDw4ZBE373ku9ezkWwp5.jpg'),
(171625, 12130, 'Naruto Shippuden S15 E10', 'http://sinalprivado.info:80/series/1533784/1533784/879530.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rWGOIB02ZO1CPGgCM2ar5jYZPM7.jpg'),
(171626, 12130, 'Naruto Shippuden S15 E11', 'http://sinalprivado.info:80/series/1533784/1533784/879531.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/5z3h4Dw0zaKN4VLwFHhsUhQDDOU.jpg'),
(171627, 12130, 'Naruto Shippuden S15 E12', 'http://sinalprivado.info:80/series/1533784/1533784/879532.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/6VE542qJ6DUxwQcjjumrVgCVxfH.jpg'),
(171628, 12130, 'Naruto Shippuden S15 E13', 'http://sinalprivado.info:80/series/1533784/1533784/879533.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/n325jajBAIEWEmjGzHIP33MSfHB.jpg'),
(171629, 12130, 'Naruto Shippuden S15 E14', 'http://sinalprivado.info:80/series/1533784/1533784/879534.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/ne0C8gEZlE7KAXsPXzLjIrAGrTB.jpg'),
(171630, 12130, 'Naruto Shippuden S15 E15', 'http://sinalprivado.info:80/series/1533784/1533784/879535.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/a58QQ3PTWLZgRSJHIYxoawnt2t5.jpg'),
(171631, 12130, 'Naruto Shippuden S15 E16', 'http://sinalprivado.info:80/series/1533784/1533784/879536.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lnh90rmY0FS6e20qU1g829lkrGp.jpg'),
(171632, 12130, 'Naruto Shippuden S15 E17', 'http://sinalprivado.info:80/series/1533784/1533784/879537.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kGQOjGDcGIVHaZcscWTLRPFj6uW.jpg'),
(171633, 12130, 'Naruto Shippuden S15 E18', 'http://sinalprivado.info:80/series/1533784/1533784/879538.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/dSSqYBJ2ySxCuAuj09zRqmBNDuF.jpg'),
(171634, 12130, 'Naruto Shippuden S15 E19', 'http://sinalprivado.info:80/series/1533784/1533784/879539.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8A6FVWR5Ny1m922XGibyD5KhM5u.jpg'),
(171635, 12130, 'Naruto Shippuden S15 E20', 'http://sinalprivado.info:80/series/1533784/1533784/879540.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lPmxb82lJYJOTrPP00quhpwhwjX.jpg'),
(171636, 12130, 'Naruto Shippuden S15 E21', 'http://sinalprivado.info:80/series/1533784/1533784/879541.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/pB5wIpN0LV9PxzHOlf5MqyH1kS6.jpg'),
(171637, 12130, 'Naruto Shippuden S15 E22', 'http://sinalprivado.info:80/series/1533784/1533784/879542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/lDzd8D5v3gLVZiBx8ScTHTonY6g.jpg'),
(171638, 12130, 'Naruto Shippuden S15 E23', 'http://sinalprivado.info:80/series/1533784/1533784/879543.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/zJFBu463baKeRYpxhMxoLhg0Km3.jpg'),
(171639, 12130, 'Naruto Shippuden S15 E24', 'http://sinalprivado.info:80/series/1533784/1533784/879544.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/x4JI3xzxUOlA8mqP3E0sas1XjLt.jpg'),
(171640, 12130, 'Naruto Shippuden S15 E25', 'http://sinalprivado.info:80/series/1533784/1533784/879545.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/d2G6xIu8Mxtvv7K1vM1IHIHGdrX.jpg'),
(171641, 12130, 'Naruto Shippuden S15 E26', 'http://sinalprivado.info:80/series/1533784/1533784/879546.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/78LJx380RGcj0TH4O6vEbo0NtrJ.jpg'),
(171642, 12130, 'Naruto Shippuden S15 E27', 'http://sinalprivado.info:80/series/1533784/1533784/879547.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rONTblspeiea40d6eqlOWcK3QUm.jpg'),
(171643, 12130, 'Naruto Shippuden S15 E28', 'http://sinalprivado.info:80/series/1533784/1533784/879548.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2htxtpxdxxd0jmF9OCCzUW9gCB4.jpg'),
(171644, 12131, 'Naruto Shippuden S16 E01', 'http://sinalprivado.info:80/series/1533784/1533784/881200.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171645, 12131, 'Naruto Shippuden S16 E02', 'http://sinalprivado.info:80/series/1533784/1533784/881201.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171646, 12131, 'Naruto Shippuden S16 E03', 'http://sinalprivado.info:80/series/1533784/1533784/881202.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171647, 12131, 'Naruto Shippuden S16 E04', 'http://sinalprivado.info:80/series/1533784/1533784/881203.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171648, 12131, 'Naruto Shippuden S16 E05', 'http://sinalprivado.info:80/series/1533784/1533784/881204.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171649, 12131, 'Naruto Shippuden S16 E06', 'http://sinalprivado.info:80/series/1533784/1533784/881205.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171650, 12131, 'Naruto Shippuden S16 E07', 'http://sinalprivado.info:80/series/1533784/1533784/881206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171651, 12131, 'Naruto Shippuden S16 E08', 'http://sinalprivado.info:80/series/1533784/1533784/881207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171652, 12131, 'Naruto Shippuden S16 E09', 'http://sinalprivado.info:80/series/1533784/1533784/881208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171653, 12131, 'Naruto Shippuden S16 E10', 'http://sinalprivado.info:80/series/1533784/1533784/881209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171654, 12131, 'Naruto Shippuden S16 E11', 'http://sinalprivado.info:80/series/1533784/1533784/881210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171655, 12131, 'Naruto Shippuden S16 E12', 'http://sinalprivado.info:80/series/1533784/1533784/881211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171656, 12131, 'Naruto Shippuden S16 E13', 'http://sinalprivado.info:80/series/1533784/1533784/881212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171657, 12132, 'Naruto Shippuden S17 E01', 'http://sinalprivado.info:80/series/1533784/1533784/882206.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171658, 12132, 'Naruto Shippuden S17 E02', 'http://sinalprivado.info:80/series/1533784/1533784/882207.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171659, 12132, 'Naruto Shippuden S17 E03', 'http://sinalprivado.info:80/series/1533784/1533784/882208.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171660, 12132, 'Naruto Shippuden S17 E04', 'http://sinalprivado.info:80/series/1533784/1533784/882209.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171661, 12132, 'Naruto Shippuden S17 E05', 'http://sinalprivado.info:80/series/1533784/1533784/882210.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171662, 12132, 'Naruto Shippuden S17 E06', 'http://sinalprivado.info:80/series/1533784/1533784/882211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171663, 12132, 'Naruto Shippuden S17 E07', 'http://sinalprivado.info:80/series/1533784/1533784/882212.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171664, 12132, 'Naruto Shippuden S17 E08', 'http://sinalprivado.info:80/series/1533784/1533784/882213.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171665, 12132, 'Naruto Shippuden S17 E09', 'http://sinalprivado.info:80/series/1533784/1533784/882214.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171666, 12132, 'Naruto Shippuden S17 E10', 'http://sinalprivado.info:80/series/1533784/1533784/882215.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171667, 12132, 'Naruto Shippuden S17 E11', 'http://sinalprivado.info:80/series/1533784/1533784/882216.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171668, 12133, 'Naruto Shippuden S18 E01', 'http://sinalprivado.info:80/series/1533784/1533784/882217.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171669, 12133, 'Naruto Shippuden S18 E02', 'http://sinalprivado.info:80/series/1533784/1533784/882218.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171670, 12133, 'Naruto Shippuden S18 E03', 'http://sinalprivado.info:80/series/1533784/1533784/882219.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171671, 12133, 'Naruto Shippuden S18 E04', 'http://sinalprivado.info:80/series/1533784/1533784/882220.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171672, 12133, 'Naruto Shippuden S18 E05', 'http://sinalprivado.info:80/series/1533784/1533784/882221.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171673, 12133, 'Naruto Shippuden S18 E06', 'http://sinalprivado.info:80/series/1533784/1533784/882222.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171674, 12133, 'Naruto Shippuden S18 E07', 'http://sinalprivado.info:80/series/1533784/1533784/882223.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171675, 12133, 'Naruto Shippuden S18 E08', 'http://sinalprivado.info:80/series/1533784/1533784/882224.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171676, 12133, 'Naruto Shippuden S18 E09', 'http://sinalprivado.info:80/series/1533784/1533784/882225.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171677, 12133, 'Naruto Shippuden S18 E10', 'http://sinalprivado.info:80/series/1533784/1533784/882226.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171678, 12133, 'Naruto Shippuden S18 E11', 'http://sinalprivado.info:80/series/1533784/1533784/882227.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171679, 12133, 'Naruto Shippuden S18 E12', 'http://sinalprivado.info:80/series/1533784/1533784/882228.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171680, 12133, 'Naruto Shippuden S18 E13', 'http://sinalprivado.info:80/series/1533784/1533784/882229.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171681, 12133, 'Naruto Shippuden S18 E14', 'http://sinalprivado.info:80/series/1533784/1533784/882230.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171682, 12133, 'Naruto Shippuden S18 E15', 'http://sinalprivado.info:80/series/1533784/1533784/882231.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171683, 12133, 'Naruto Shippuden S18 E16', 'http://sinalprivado.info:80/series/1533784/1533784/882232.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171684, 12133, 'Naruto Shippuden S18 E17', 'http://sinalprivado.info:80/series/1533784/1533784/882233.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171685, 12133, 'Naruto Shippuden S18 E18', 'http://sinalprivado.info:80/series/1533784/1533784/882234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171686, 12133, 'Naruto Shippuden S18 E19', 'http://sinalprivado.info:80/series/1533784/1533784/882235.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171687, 12133, 'Naruto Shippuden S18 E20', 'http://sinalprivado.info:80/series/1533784/1533784/882236.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171688, 12133, 'Naruto Shippuden S18 E21', 'http://sinalprivado.info:80/series/1533784/1533784/882237.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171689, 12134, 'Naruto Shippuden S19 E01', 'http://sinalprivado.info:80/series/1533784/1533784/882238.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171690, 12134, 'Naruto Shippuden S19 E02', 'http://sinalprivado.info:80/series/1533784/1533784/882239.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171691, 12134, 'Naruto Shippuden S19 E03', 'http://sinalprivado.info:80/series/1533784/1533784/882240.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171692, 12134, 'Naruto Shippuden S19 E04', 'http://sinalprivado.info:80/series/1533784/1533784/882241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171693, 12134, 'Naruto Shippuden S19 E05', 'http://sinalprivado.info:80/series/1533784/1533784/882242.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171694, 12134, 'Naruto Shippuden S19 E06', 'http://sinalprivado.info:80/series/1533784/1533784/882243.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171695, 12134, 'Naruto Shippuden S19 E07', 'http://sinalprivado.info:80/series/1533784/1533784/882244.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171696, 12134, 'Naruto Shippuden S19 E08', 'http://sinalprivado.info:80/series/1533784/1533784/882245.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171697, 12134, 'Naruto Shippuden S19 E09', 'http://sinalprivado.info:80/series/1533784/1533784/882246.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171698, 12134, 'Naruto Shippuden S19 E10', 'http://sinalprivado.info:80/series/1533784/1533784/882247.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171699, 12134, 'Naruto Shippuden S19 E11', 'http://sinalprivado.info:80/series/1533784/1533784/882248.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171700, 12134, 'Naruto Shippuden S19 E12', 'http://sinalprivado.info:80/series/1533784/1533784/882249.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171701, 12134, 'Naruto Shippuden S19 E13', 'http://sinalprivado.info:80/series/1533784/1533784/882250.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171702, 12134, 'Naruto Shippuden S19 E14', 'http://sinalprivado.info:80/series/1533784/1533784/882251.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171703, 12134, 'Naruto Shippuden S19 E15', 'http://sinalprivado.info:80/series/1533784/1533784/882252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171704, 12134, 'Naruto Shippuden S19 E16', 'http://sinalprivado.info:80/series/1533784/1533784/882253.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171705, 12134, 'Naruto Shippuden S19 E17', 'http://sinalprivado.info:80/series/1533784/1533784/882254.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171706, 12134, 'Naruto Shippuden S19 E18', 'http://sinalprivado.info:80/series/1533784/1533784/882255.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171707, 12134, 'Naruto Shippuden S19 E19', 'http://sinalprivado.info:80/series/1533784/1533784/882256.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171708, 12134, 'Naruto Shippuden S19 E20', 'http://sinalprivado.info:80/series/1533784/1533784/882257.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171709, 12135, 'Naruto Shippuden S20 E01', 'http://sinalprivado.info:80/series/1533784/1533784/882258.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171710, 12135, 'Naruto Shippuden S20 E02', 'http://sinalprivado.info:80/series/1533784/1533784/882259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171711, 12135, 'Naruto Shippuden S20 E03', 'http://sinalprivado.info:80/series/1533784/1533784/882260.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171712, 12135, 'Naruto Shippuden S20 E04', 'http://sinalprivado.info:80/series/1533784/1533784/882261.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(171713, 12135, 'Naruto Shippuden S20 E05', 'http://sinalprivado.info:80/series/1533784/1533784/882262.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171714, 12135, 'Naruto Shippuden S20 E06', 'http://sinalprivado.info:80/series/1533784/1533784/882263.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171715, 12135, 'Naruto Shippuden S20 E07', 'http://sinalprivado.info:80/series/1533784/1533784/882264.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171716, 12135, 'Naruto Shippuden S20 E08', 'http://sinalprivado.info:80/series/1533784/1533784/882265.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171717, 12135, 'Naruto Shippuden S20 E09', 'http://sinalprivado.info:80/series/1533784/1533784/882266.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171718, 12135, 'Naruto Shippuden S20 E10', 'http://sinalprivado.info:80/series/1533784/1533784/882267.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171719, 12135, 'Naruto Shippuden S20 E11', 'http://sinalprivado.info:80/series/1533784/1533784/882268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171720, 12135, 'Naruto Shippuden S20 E12', 'http://sinalprivado.info:80/series/1533784/1533784/882269.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171721, 12135, 'Naruto Shippuden S20 E13', 'http://sinalprivado.info:80/series/1533784/1533784/882270.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171722, 12135, 'Naruto Shippuden S20 E14', 'http://sinalprivado.info:80/series/1533784/1533784/882271.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171723, 12135, 'Naruto Shippuden S20 E15', 'http://sinalprivado.info:80/series/1533784/1533784/882272.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171724, 12135, 'Naruto Shippuden S20 E16', 'http://sinalprivado.info:80/series/1533784/1533784/882273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171725, 12135, 'Naruto Shippuden S20 E17', 'http://sinalprivado.info:80/series/1533784/1533784/882274.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171726, 12135, 'Naruto Shippuden S20 E18', 'http://sinalprivado.info:80/series/1533784/1533784/882275.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171727, 12135, 'Naruto Shippuden S20 E19', 'http://sinalprivado.info:80/series/1533784/1533784/882276.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171728, 12135, 'Naruto Shippuden S20 E20', 'http://sinalprivado.info:80/series/1533784/1533784/882277.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171729, 12135, 'Naruto Shippuden S20 E21', 'http://sinalprivado.info:80/series/1533784/1533784/882278.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171730, 12135, 'Naruto Shippuden S20 E22', 'http://sinalprivado.info:80/series/1533784/1533784/882279.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171731, 12135, 'Naruto Shippuden S20 E23', 'http://sinalprivado.info:80/series/1533784/1533784/882280.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171732, 12135, 'Naruto Shippuden S20 E24', 'http://sinalprivado.info:80/series/1533784/1533784/882281.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171733, 12135, 'Naruto Shippuden S20 E25', 'http://sinalprivado.info:80/series/1533784/1533784/882282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171734, 12135, 'Naruto Shippuden S20 E26', 'http://sinalprivado.info:80/series/1533784/1533784/882283.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171735, 12135, 'Naruto Shippuden S20 E27', 'http://sinalprivado.info:80/series/1533784/1533784/882284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171736, 12135, 'Naruto Shippuden S20 E28', 'http://sinalprivado.info:80/series/1533784/1533784/882285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171737, 12135, 'Naruto Shippuden S20 E29', 'http://sinalprivado.info:80/series/1533784/1533784/882286.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171738, 12135, 'Naruto Shippuden S20 E30', 'http://sinalprivado.info:80/series/1533784/1533784/882287.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171739, 12135, 'Naruto Shippuden S20 E31', 'http://sinalprivado.info:80/series/1533784/1533784/882288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171740, 12135, 'Naruto Shippuden S20 E32', 'http://sinalprivado.info:80/series/1533784/1533784/882289.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171741, 12135, 'Naruto Shippuden S20 E33', 'http://sinalprivado.info:80/series/1533784/1533784/882290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171742, 12135, 'Naruto Shippuden S20 E34', 'http://sinalprivado.info:80/series/1533784/1533784/882291.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171743, 12135, 'Naruto Shippuden S20 E35', 'http://sinalprivado.info:80/series/1533784/1533784/882292.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171744, 12135, 'Naruto Shippuden S20 E36', 'http://sinalprivado.info:80/series/1533784/1533784/882293.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171745, 12135, 'Naruto Shippuden S20 E37', 'http://sinalprivado.info:80/series/1533784/1533784/882294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171746, 12135, 'Naruto Shippuden S20 E38', 'http://sinalprivado.info:80/series/1533784/1533784/882295.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171747, 12135, 'Naruto Shippuden S20 E39', 'http://sinalprivado.info:80/series/1533784/1533784/882296.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171748, 12135, 'Naruto Shippuden S20 E40', 'http://sinalprivado.info:80/series/1533784/1533784/882297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171749, 12135, 'Naruto Shippuden S20 E41', 'http://sinalprivado.info:80/series/1533784/1533784/882298.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171750, 12135, 'Naruto Shippuden S20 E42', 'http://sinalprivado.info:80/series/1533784/1533784/882299.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171751, 12135, 'Naruto Shippuden S20 E43', 'http://sinalprivado.info:80/series/1533784/1533784/882300.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171752, 12135, 'Naruto Shippuden S20 E44', 'http://sinalprivado.info:80/series/1533784/1533784/882301.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171753, 12135, 'Naruto Shippuden S20 E45', 'http://sinalprivado.info:80/series/1533784/1533784/882302.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171754, 12135, 'Naruto Shippuden S20 E46', 'http://sinalprivado.info:80/series/1533784/1533784/882303.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171755, 12135, 'Naruto Shippuden S20 E47', 'http://sinalprivado.info:80/series/1533784/1533784/882304.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171756, 12135, 'Naruto Shippuden S20 E48', 'http://sinalprivado.info:80/series/1533784/1533784/882305.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171757, 12135, 'Naruto Shippuden S20 E49', 'http://sinalprivado.info:80/series/1533784/1533784/882306.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171758, 12135, 'Naruto Shippuden S20 E50', 'http://sinalprivado.info:80/series/1533784/1533784/882307.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171759, 12135, 'Naruto Shippuden S20 E51', 'http://sinalprivado.info:80/series/1533784/1533784/882308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171760, 12135, 'Naruto Shippuden S20 E52', 'http://sinalprivado.info:80/series/1533784/1533784/882309.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171761, 12135, 'Naruto Shippuden S20 E53', 'http://sinalprivado.info:80/series/1533784/1533784/882310.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171762, 12135, 'Naruto Shippuden S20 E54', 'http://sinalprivado.info:80/series/1533784/1533784/882311.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171763, 12135, 'Naruto Shippuden S20 E55', 'http://sinalprivado.info:80/series/1533784/1533784/882312.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171764, 12135, 'Naruto Shippuden S20 E56', 'http://sinalprivado.info:80/series/1533784/1533784/882313.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171765, 12135, 'Naruto Shippuden S20 E57', 'http://sinalprivado.info:80/series/1533784/1533784/882314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171766, 12135, 'Naruto Shippuden S20 E58', 'http://sinalprivado.info:80/series/1533784/1533784/882315.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171767, 12135, 'Naruto Shippuden S20 E59', 'http://sinalprivado.info:80/series/1533784/1533784/882316.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171768, 12135, 'Naruto Shippuden S20 E60', 'http://sinalprivado.info:80/series/1533784/1533784/882317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171769, 12135, 'Naruto Shippuden S20 E61', 'http://sinalprivado.info:80/series/1533784/1533784/882318.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171770, 12135, 'Naruto Shippuden S20 E62', 'http://sinalprivado.info:80/series/1533784/1533784/882319.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171771, 12135, 'Naruto Shippuden S20 E63', 'http://sinalprivado.info:80/series/1533784/1533784/882320.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171772, 12135, 'Naruto Shippuden S20 E64', 'http://sinalprivado.info:80/series/1533784/1533784/882321.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171773, 12135, 'Naruto Shippuden S20 E65', 'http://sinalprivado.info:80/series/1533784/1533784/882322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171774, 12135, 'Naruto Shippuden S20 E66', 'http://sinalprivado.info:80/series/1533784/1533784/882323.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171775, 12135, 'Naruto Shippuden S20 E67', 'http://sinalprivado.info:80/series/1533784/1533784/882324.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171776, 12135, 'Naruto Shippuden S20 E68', 'http://sinalprivado.info:80/series/1533784/1533784/882325.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171777, 12135, 'Naruto Shippuden S20 E69', 'http://sinalprivado.info:80/series/1533784/1533784/882326.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171778, 12135, 'Naruto Shippuden S20 E70', 'http://sinalprivado.info:80/series/1533784/1533784/882327.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171779, 12135, 'Naruto Shippuden S20 E71', 'http://sinalprivado.info:80/series/1533784/1533784/882328.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171780, 12135, 'Naruto Shippuden S20 E72', 'http://sinalprivado.info:80/series/1533784/1533784/882329.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171781, 12135, 'Naruto Shippuden S20 E73', 'http://sinalprivado.info:80/series/1533784/1533784/882330.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171782, 12135, 'Naruto Shippuden S20 E74', 'http://sinalprivado.info:80/series/1533784/1533784/882331.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171783, 12135, 'Naruto Shippuden S20 E75', 'http://sinalprivado.info:80/series/1533784/1533784/882332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171784, 12135, 'Naruto Shippuden S20 E76', 'http://sinalprivado.info:80/series/1533784/1533784/882333.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171785, 12135, 'Naruto Shippuden S20 E77', 'http://sinalprivado.info:80/series/1533784/1533784/882334.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171786, 12135, 'Naruto Shippuden S20 E78', 'http://sinalprivado.info:80/series/1533784/1533784/882335.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171787, 12135, 'Naruto Shippuden S20 E79', 'http://sinalprivado.info:80/series/1533784/1533784/882336.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171788, 12135, 'Naruto Shippuden S20 E80', 'http://sinalprivado.info:80/series/1533784/1533784/882337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171789, 12135, 'Naruto Shippuden S20 E81', 'http://sinalprivado.info:80/series/1533784/1533784/882338.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171790, 12135, 'Naruto Shippuden S20 E82', 'http://sinalprivado.info:80/series/1533784/1533784/882339.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171791, 12135, 'Naruto Shippuden S20 E83', 'http://sinalprivado.info:80/series/1533784/1533784/882340.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171792, 12135, 'Naruto Shippuden S20 E84', 'http://sinalprivado.info:80/series/1533784/1533784/882341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171793, 12135, 'Naruto Shippuden S20 E85', 'http://sinalprivado.info:80/series/1533784/1533784/882342.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171794, 12135, 'Naruto Shippuden S20 E86', 'http://sinalprivado.info:80/series/1533784/1533784/882343.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171795, 12135, 'Naruto Shippuden S20 E87', 'http://sinalprivado.info:80/series/1533784/1533784/882344.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/nRJmByfK9XdtOY73VArcN8KpKVs.jpg'),
(171796, 12136, 'Amantes Anonimos S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qwQcuNVHA74e7hZH4mp3t9MoAfX.jpg'),
(171797, 12136, 'Amantes Anonimos S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664659.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qwQcuNVHA74e7hZH4mp3t9MoAfX.jpg'),
(171798, 12136, 'Amantes Anonimos S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664660.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qwQcuNVHA74e7hZH4mp3t9MoAfX.jpg'),
(171799, 12136, 'Amantes Anonimos S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/664661.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qwQcuNVHA74e7hZH4mp3t9MoAfX.jpg'),
(171800, 12136, 'Amantes Anonimos S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/664662.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qwQcuNVHA74e7hZH4mp3t9MoAfX.jpg'),
(171801, 12136, 'Amantes Anonimos S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/664663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qwQcuNVHA74e7hZH4mp3t9MoAfX.jpg'),
(171802, 12136, 'Amantes Anonimos S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/664664.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qwQcuNVHA74e7hZH4mp3t9MoAfX.jpg'),
(171803, 12136, 'Amantes Anonimos S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/664665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qwQcuNVHA74e7hZH4mp3t9MoAfX.jpg'),
(171804, 12137, 'Blade A Serie S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664645.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fO7nruvvkBzFudRR1bsvvGNhpzv.jpg'),
(171805, 12137, 'Blade A Serie S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664646.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aNLWM13KfpNUt1vYzS8PWROGtBk.jpg'),
(171806, 12137, 'Blade A Serie S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664647.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3gVA1dsqXL1ulOuGHzPeT81Mpvc.jpg'),
(171807, 12137, 'Blade A Serie S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/664648.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2QnSVlZz3fCQ74tH2GMA2yZOuLa.jpg'),
(171808, 12137, 'Blade A Serie S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/664649.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ucj7F5i5LvUAo325tj5IXgz1e9V.jpg'),
(171809, 12137, 'Blade A Serie S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/664650.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oLIb5ubhsh5C2ldBHG6iRmjvm3z.jpg'),
(171810, 12137, 'Blade A Serie S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/664651.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kIymmja5C2RkohBbucDMFobhOVh.jpg'),
(171811, 12137, 'Blade A Serie S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/664652.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/RBVe8sv66nxm7Af6e96KEsD2z9.jpg'),
(171812, 12137, 'Blade A Serie S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/664653.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5r2fGZn82JCwUqMXYSl2FDIw7rZ.jpg'),
(171813, 12137, 'Blade A Serie S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/664654.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wMSTdFBASojV6LvrLp8fPl2aBu8.jpg'),
(171814, 12137, 'Blade A Serie S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/664655.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/i0aLjdGOUe6a0SRu44lv72NBvzT.jpg'),
(171815, 12137, 'Blade A Serie S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/664656.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/igse3GZJhCKPXxD8w6PSdABrMHE.jpg'),
(171816, 12137, 'Blade A Serie S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/664657.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/2XL1XAkk4ZGUmtbc8YDfWG7LX24.jpg'),
(171817, 12138, 'Decodificando Desastres S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664644.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fJKQJluhPiW8vHf1fpOeopqyCbp.jpg'),
(171818, 12138, 'Decodificando Desastres S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/669856.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/fJKQJluhPiW8vHf1fpOeopqyCbp.jpg'),
(171819, 12139, 'Desordem Publica S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664638.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/41GOJPAoHgyZvKMKxkl0yvQGAvL.jpg'),
(171820, 12139, 'Desordem Publica S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664639.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pZea9ijIE3U1p4ksi9X0looMCq1.jpg'),
(171821, 12139, 'Desordem Publica S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664640.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9SpvknZxdOzGR4Tbd3QBrTUMvDL.jpg'),
(171822, 12139, 'Desordem Publica S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/664641.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oWw5ZgsawKSQLdYG3OyvFz4iEii.jpg'),
(171823, 12139, 'Desordem Publica S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/664642.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eRBBjW5U9GNGP6qytdZrx2T4mah.jpg'),
(171824, 12139, 'Desordem Publica S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/664643.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/syomePbFlpnU7zHoGMyrR1TG4bQ.jpg'),
(171825, 12140, 'Esquadrao Suicida Isekai S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664628.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/54VcvNvddIdynXTFrZOSLJlSOLE.jpg'),
(171826, 12140, 'Esquadrao Suicida Isekai S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664629.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4caKHpd7aDURha12cOg6UiLYnZA.jpg'),
(171827, 12140, 'Esquadrao Suicida Isekai S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664630.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vAe4pBkp381efRJ7uzX56Ciyzuu.jpg'),
(171828, 12140, 'Esquadrao Suicida Isekai S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/664631.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uGIxE7RHQzKT2omf83foBBBVmo2.jpg'),
(171829, 12140, 'Esquadrao Suicida Isekai S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/664632.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9KFg45qRUBu0lyMgVQIi9d0M2u4.jpg'),
(171830, 12140, 'Esquadrao Suicida Isekai S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/664633.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eVgwVzuR22pVGQjNmWJJEtQkwHa.jpg'),
(171831, 12140, 'Esquadrao Suicida Isekai S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/664634.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dpYEniL5sbduXfvMZCyOtaOJRHw.jpg'),
(171832, 12140, 'Esquadrao Suicida Isekai S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/664635.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2XldG3N9El6k2TqK9oejiwalPc6.jpg'),
(171833, 12140, 'Esquadrao Suicida Isekai S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/664636.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k3jIxB4uaOBTZSQarwXb9rym6DV.jpg'),
(171834, 12140, 'Esquadrao Suicida Isekai S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/664637.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3k2pzif4RF8bnNTBWc0Sh4aIape.jpg'),
(171835, 12141, 'Hanako kun e os Misterios do Colegio Kamome S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664616.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bigVQCjbEzIHJOX34ObO8LGTSE8.jpg'),
(171836, 12141, 'Hanako kun e os Misterios do Colegio Kamome S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664617.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8IqpUziQWFqXsQ6QWtqU1u5HqIP.jpg'),
(171837, 12141, 'Hanako kun e os Misterios do Colegio Kamome S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664618.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tATrJaOkmFbLTT9w5kD2ZaTbT3p.jpg'),
(171838, 12141, 'Hanako kun e os Misterios do Colegio Kamome S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/664619.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cCQDQZmPDgbtsROp8BnFifBqTdP.jpg'),
(171839, 12141, 'Hanako kun e os Misterios do Colegio Kamome S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/664620.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/n5rKhHgccXbH4UwWdl64qgSmWFF.jpg'),
(171840, 12141, 'Hanako kun e os Misterios do Colegio Kamome S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/664621.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/iQWuPQ8IUclKa3MVVB2aydWqVrJ.jpg'),
(171841, 12141, 'Hanako kun e os Misterios do Colegio Kamome S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/664622.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1PmeeKkI5N9HMaHKfCUFK5xK1fS.jpg'),
(171842, 12141, 'Hanako kun e os Misterios do Colegio Kamome S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/664623.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/hRkVmQyc4DXMKmMXLqTvZxNFH1K.jpg'),
(171843, 12141, 'Hanako kun e os Misterios do Colegio Kamome S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/664624.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/95fubp7Y8sXRXAQu3I91rZ3bBL9.jpg'),
(171844, 12141, 'Hanako kun e os Misterios do Colegio Kamome S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/664625.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cTZlZZOhV5wCV3HFXnovNo9FW5q.jpg'),
(171845, 12141, 'Hanako kun e os Misterios do Colegio Kamome S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/664626.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/o28UUt4KoCRMCsZwC0FfL0DgG9x.jpg'),
(171846, 12141, 'Hanako kun e os Misterios do Colegio Kamome S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/664627.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cebxdL4izM72W1uxnsd3JxLrAxU.jpg'),
(171847, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/683596.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171848, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/690389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171849, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/700149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171850, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/706113.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171851, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/716701.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171852, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/729149.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171853, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/752002.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171854, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/752003.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171855, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/752004.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171856, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/760151.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171857, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/766721.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171858, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/784585.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171859, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E13', 'http://sinalprivado.info:80/series/1533784/1533784/877337.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171860, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E14', 'http://sinalprivado.info:80/series/1533784/1533784/879584.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171861, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E15', 'http://sinalprivado.info:80/series/1533784/1533784/880058.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171862, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E16', 'http://sinalprivado.info:80/series/1533784/1533784/880883.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171863, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E17', 'http://sinalprivado.info:80/series/1533784/1533784/881952.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171864, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E18', 'http://sinalprivado.info:80/series/1533784/1533784/881953.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171865, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E19', 'http://sinalprivado.info:80/series/1533784/1533784/883554.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171866, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E20', 'http://sinalprivado.info:80/series/1533784/1533784/884064.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171867, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E21', 'http://sinalprivado.info:80/series/1533784/1533784/885786.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171868, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E22', 'http://sinalprivado.info:80/series/1533784/1533784/886259.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171869, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E23', 'http://sinalprivado.info:80/series/1533784/1533784/888349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171870, 12142, 'Hanako kun e os Misterios do Colegio Kamome S02 E24', 'http://sinalprivado.info:80/series/1533784/1533784/888350.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/sPXvmpUW4tFf7DuNeovSomcTWLF.jpg'),
(171871, 12143, 'Misterios do Pantano S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664610.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fMrlchZQqEPdnnGe60K8ywM1sU4.jpg'),
(171872, 12143, 'Misterios do Pantano S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664611.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ycr3RT8WIknPSVjK5OkSCt9TiBQ.jpg'),
(171873, 12143, 'Misterios do Pantano S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664612.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/egZ17rvF9zNak89FHWCj5R7YPld.jpg'),
(171874, 12143, 'Misterios do Pantano S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/664613.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ekudPbhNWgMSLzeVcvCgUkm0Dpw.jpg'),
(171875, 12143, 'Misterios do Pantano S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/664614.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wj4K5o3JDx93aydvRQ4l4ErQCCl.jpg'),
(171876, 12143, 'Misterios do Pantano S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/664615.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dfAhCqfZSEdODNW6Yjr8rIpsS5y.jpg'),
(171877, 12144, 'O Aquario S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664591.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sGfFP2Qcv0oXkh8QXuMZNT7dkRg.jpg'),
(171878, 12144, 'O Aquario S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664592.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4jgaqYEDCim5lR1BifIby0mFEEF.jpg'),
(171879, 12144, 'O Aquario S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664593.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zcoOrRVMPWLfoUpjMJ5UqmECex2.jpg'),
(171880, 12144, 'O Aquario S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/664594.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7PtbE5vRPClCwj2TkHt8z4CcAjN.jpg'),
(171881, 12144, 'O Aquario S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/664595.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tNJVfxKQwM5oWjroeTB3AOAUs9b.jpg'),
(171882, 12144, 'O Aquario S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/664596.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AnyEMmTyBsIFdo5L7B2JSNAfVNZ.jpg'),
(171883, 12144, 'O Aquario S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/664597.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yIuqYO2XlerX2pEKJAvIOhyrMTC.jpg'),
(171884, 12144, 'O Aquario S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/664598.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yIuqYO2XlerX2pEKJAvIOhyrMTC.jpg'),
(171885, 12144, 'O Aquario S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/664599.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wmsnnXbqx8nBJEyRtlmnDsKQhd5.jpg'),
(171886, 12145, 'O Aquario S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664600.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mSQFZwWVxEOjcYLhMefsUubA62j.jpg'),
(171887, 12145, 'O Aquario S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664601.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/66jZ3V98uAQ6AabWB3d26mPWnmj.jpg'),
(171888, 12145, 'O Aquario S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664602.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qNeg6x4931WFmqLVfh9oGjIjGVK.jpg'),
(171889, 12145, 'O Aquario S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/664603.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xV95gbRLweddxyb8Sa9OhSjrpSA.jpg'),
(171890, 12145, 'O Aquario S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/664604.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Aow9G22ksYkQqr4bC6Htzq3u7m4.jpg'),
(171891, 12145, 'O Aquario S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/664605.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nxQIsk1Dr86pkOGHppSpQuXlESI.jpg'),
(171892, 12145, 'O Aquario S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/664606.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/osUZbW3LqeFfeVs8fxIhweWb0eP.jpg'),
(171893, 12145, 'O Aquario S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/664607.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7uTPtGyAnNcCHl7OYavDWsu9vi3.jpg'),
(171894, 12145, 'O Aquario S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/664608.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jQkEPuZuPSNHbl6cIciaMP5gUoK.jpg'),
(171895, 12145, 'O Aquario S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/664609.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/yIuqYO2XlerX2pEKJAvIOhyrMTC.jpg'),
(171896, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664577.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pR8NwWToXiuSlxDyfAWjMIx9kgG.jpg'),
(171897, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664578.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/69pZMhVgG8eSnDmI6wLJMX46UxN.jpg'),
(171898, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664579.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eAaBRYsKKbTHtCPDyfFD1UlHf7A.jpg'),
(171899, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/664580.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s5fssOZvoAjl9E6hl0DzXYRKUru.jpg'),
(171900, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/664581.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/syiqQ16FGl5wBfmD9Hugz4YaKFb.jpg'),
(171901, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/664582.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mVtKjvyFgRr7EB6e37Mj2sfkd4Z.jpg'),
(171902, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/664583.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u5mDKZfwQWHzdsBtyFPZy9V5Q5P.jpg'),
(171903, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/664584.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2xYx5Co9BFyX8DIIySe9qLc63yK.jpg'),
(171904, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/664585.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7ErOCuzRHjL8DzRUx7zaurZOTNF.jpg'),
(171905, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/664586.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vwqNJbPKM0EYZb1IZVVV14pjutl.jpg'),
(171906, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/664587.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9HE10sIRkAHgQQdsyUuxAt5o88J.jpg'),
(171907, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/664588.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fJySTP4C5VyH2xeHU6TtKP1SI4.jpg'),
(171908, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/664589.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/71OswoOzxxSYsqxd0stSAfc8pfA.jpg'),
(171909, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/664590.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cQaMptQeJXUaYcz0KZs2c9aOFnj.jpg'),
(171910, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/672332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVKdSKAXsZezOlonygXETvP0rMl.jpg'),
(171911, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/681143.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVKdSKAXsZezOlonygXETvP0rMl.jpg'),
(171912, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/686290.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVKdSKAXsZezOlonygXETvP0rMl.jpg'),
(171913, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/692663.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVKdSKAXsZezOlonygXETvP0rMl.jpg'),
(171914, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/703322.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVKdSKAXsZezOlonygXETvP0rMl.jpg'),
(171915, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/710268.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVKdSKAXsZezOlonygXETvP0rMl.jpg'),
(171916, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/719370.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVKdSKAXsZezOlonygXETvP0rMl.jpg'),
(171917, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/727592.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVKdSKAXsZezOlonygXETvP0rMl.jpg'),
(171918, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/735589.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVKdSKAXsZezOlonygXETvP0rMl.jpg'),
(171919, 12146, 'A Terrified Teacher at Ghoul School [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/740844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/cVKdSKAXsZezOlonygXETvP0rMl.jpg'),
(171920, 12147, 'AQUARION Myth of Emotions [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664576.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gfdTUTed9q5HgZYC7CyKaXgR1JT.jpg'),
(171921, 12147, 'AQUARION Myth of Emotions [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/666341.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kAkVZy1shPh7T4BvGIlETDNv6vo.jpg'),
(171922, 12147, 'AQUARION Myth of Emotions [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/677891.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kAkVZy1shPh7T4BvGIlETDNv6vo.jpg'),
(171923, 12147, 'AQUARION Myth of Emotions [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/681127.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kAkVZy1shPh7T4BvGIlETDNv6vo.jpg'),
(171924, 12147, 'AQUARION Myth of Emotions [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/698889.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kAkVZy1shPh7T4BvGIlETDNv6vo.jpg'),
(171925, 12147, 'AQUARION Myth of Emotions [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/698890.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kAkVZy1shPh7T4BvGIlETDNv6vo.jpg'),
(171926, 12147, 'AQUARION Myth of Emotions [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/707665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kAkVZy1shPh7T4BvGIlETDNv6vo.jpg'),
(171927, 12147, 'AQUARION Myth of Emotions [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/713038.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kAkVZy1shPh7T4BvGIlETDNv6vo.jpg'),
(171928, 12147, 'AQUARION Myth of Emotions [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/719349.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kAkVZy1shPh7T4BvGIlETDNv6vo.jpg'),
(171929, 12147, 'AQUARION Myth of Emotions [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/743393.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kAkVZy1shPh7T4BvGIlETDNv6vo.jpg'),
(171930, 12147, 'AQUARION Myth of Emotions [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/743394.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kAkVZy1shPh7T4BvGIlETDNv6vo.jpg'),
(171931, 12147, 'AQUARION Myth of Emotions [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/743395.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/kAkVZy1shPh7T4BvGIlETDNv6vo.jpg'),
(171932, 12148, 'Ameku MD Doctor Detective [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664573.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/izz9rUGaGpwE8qlaSw2ZxiRdf9k.jpg'),
(171933, 12148, 'Ameku MD Doctor Detective [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664574.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lAr0KiCM7LilGtRiTk2h7atTaW4.jpg'),
(171934, 12148, 'Ameku MD Doctor Detective [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664575.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/q0cPaE88blKje9RDrDQ2U7LIHVP.jpg'),
(171935, 12148, 'Ameku MD Doctor Detective [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/673028.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jfUwdU2MSi4oZoc8hErn5cOI1Gs.jpg'),
(171936, 12148, 'Ameku MD Doctor Detective [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/681120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jfUwdU2MSi4oZoc8hErn5cOI1Gs.jpg'),
(171937, 12148, 'Ameku MD Doctor Detective [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/687880.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jfUwdU2MSi4oZoc8hErn5cOI1Gs.jpg'),
(171938, 12148, 'Ameku MD Doctor Detective [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/703297.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jfUwdU2MSi4oZoc8hErn5cOI1Gs.jpg'),
(171939, 12148, 'Ameku MD Doctor Detective [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/708066.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jfUwdU2MSi4oZoc8hErn5cOI1Gs.jpg'),
(171940, 12148, 'Ameku MD Doctor Detective [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/719332.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jfUwdU2MSi4oZoc8hErn5cOI1Gs.jpg'),
(171941, 12148, 'Ameku MD Doctor Detective [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/731681.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jfUwdU2MSi4oZoc8hErn5cOI1Gs.jpg'),
(171942, 12148, 'Ameku MD Doctor Detective [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/743078.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jfUwdU2MSi4oZoc8hErn5cOI1Gs.jpg'),
(171943, 12148, 'Ameku MD Doctor Detective [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/756029.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/jfUwdU2MSi4oZoc8hErn5cOI1Gs.jpg'),
(171944, 12149, 'Anyway Im Falling in Love with You [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664572.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bJ5IiQsJu0xDhASbu2fwYZKt1z7.jpg'),
(171945, 12149, 'Anyway Im Falling in Love with You [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/665928.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qvfrC0SViT6LUOGNDxV2L8LcENs.jpg'),
(171946, 12149, 'Anyway Im Falling in Love with You [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/677888.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qvfrC0SViT6LUOGNDxV2L8LcENs.jpg'),
(171947, 12149, 'Anyway Im Falling in Love with You [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/681114.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qvfrC0SViT6LUOGNDxV2L8LcENs.jpg'),
(171948, 12149, 'Anyway Im Falling in Love with You [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/687873.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qvfrC0SViT6LUOGNDxV2L8LcENs.jpg'),
(171949, 12149, 'Anyway Im Falling in Love with You [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/698884.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qvfrC0SViT6LUOGNDxV2L8LcENs.jpg'),
(171950, 12149, 'Anyway Im Falling in Love with You [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/707658.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qvfrC0SViT6LUOGNDxV2L8LcENs.jpg'),
(171951, 12149, 'Anyway Im Falling in Love with You [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/708057.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qvfrC0SViT6LUOGNDxV2L8LcENs.jpg'),
(171952, 12149, 'Anyway Im Falling in Love with You [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/719199.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qvfrC0SViT6LUOGNDxV2L8LcENs.jpg'),
(171953, 12149, 'Anyway Im Falling in Love with You [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/724252.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qvfrC0SViT6LUOGNDxV2L8LcENs.jpg'),
(171954, 12149, 'Anyway Im Falling in Love with You [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/730860.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qvfrC0SViT6LUOGNDxV2L8LcENs.jpg'),
(171955, 12149, 'Anyway Im Falling in Love with You [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/743373.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/qvfrC0SViT6LUOGNDxV2L8LcENs.jpg'),
(171956, 12150, 'Aoshima kun E um Valentao [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664568.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/akFVtdxcyidzPI0sePBFQUWBMnA.jpg'),
(171957, 12150, 'Aoshima kun E um Valentao [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664569.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8azpAvU6VFVhg3q1FDLG86KMlLy.jpg'),
(171958, 12150, 'Aoshima kun E um Valentao [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664570.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cQCnaR1mdz73ZLq1YZFecf1iKS7.jpg'),
(171959, 12150, 'Aoshima kun E um Valentao [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/664571.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jzNfLzMvkcCAyPx5LEOPaft7LZm.jpg'),
(171960, 12150, 'Aoshima kun E um Valentao [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/676120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8HspVcI8UUZcyN1BzakwE7hmJKf.jpg'),
(171961, 12150, 'Aoshima kun E um Valentao [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/727844.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8HspVcI8UUZcyN1BzakwE7hmJKf.jpg');
INSERT INTO `episodes` (`id`, `season_id`, `name`, `stream_url`, `cover_url`) VALUES
(171962, 12150, 'Aoshima kun E um Valentao [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/727845.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8HspVcI8UUZcyN1BzakwE7hmJKf.jpg'),
(171963, 12150, 'Aoshima kun E um Valentao [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/727846.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8HspVcI8UUZcyN1BzakwE7hmJKf.jpg'),
(171964, 12151, 'Arifureta Shokugyou de Sekai Saikyou [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664532.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vYRwsbbeJaPqee9SuOncIHylzWs.jpg'),
(171965, 12151, 'Arifureta Shokugyou de Sekai Saikyou [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664533.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wP5v2vwzYRllPcHMoAZM1hDpscn.jpg'),
(171966, 12151, 'Arifureta Shokugyou de Sekai Saikyou [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664534.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cKlNiuPs8CQ7nmShzEQEfhPeTpj.jpg'),
(171967, 12151, 'Arifureta Shokugyou de Sekai Saikyou [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/664535.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ujqe8gUdN1G1YoSwtUXTJOlWiKd.jpg'),
(171968, 12151, 'Arifureta Shokugyou de Sekai Saikyou [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/664536.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bT9TvTW2irw4vfnjKe2VUFx4fEd.jpg'),
(171969, 12151, 'Arifureta Shokugyou de Sekai Saikyou [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/664537.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jRWHz8qE5XZGhyS4pzwwRNuAYAS.jpg'),
(171970, 12151, 'Arifureta Shokugyou de Sekai Saikyou [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/664538.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/Ar5awzepQC8KXJ2IkM1JDLiTOYr.jpg'),
(171971, 12151, 'Arifureta Shokugyou de Sekai Saikyou [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/664539.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aAw9VccOTlRKF4WmmJE9Iy3GeA8.jpg'),
(171972, 12151, 'Arifureta Shokugyou de Sekai Saikyou [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/664540.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eS16JWTo1LoARoqyWshA6fT6zWB.jpg'),
(171973, 12151, 'Arifureta Shokugyou de Sekai Saikyou [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/664541.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/nv2wouuE85ZIJhQJqRFs55PWPru.jpg'),
(171974, 12151, 'Arifureta Shokugyou de Sekai Saikyou [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/664542.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tBcEiVBIj7oNL3C5dzyvWudhqwp.jpg'),
(171975, 12151, 'Arifureta Shokugyou de Sekai Saikyou [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/664543.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4DzUIncMcKUNxkrmuspdCZHcTlK.jpg'),
(171976, 12151, 'Arifureta Shokugyou de Sekai Saikyou [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/664544.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ifh7i8hcGOPb6YfRvEuZaPH3gwr.jpg'),
(171977, 12152, 'Arifureta Shokugyou de Sekai Saikyou [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664545.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/dRFkdtXawUJVztvL16iP1FbHYH6.jpg'),
(171978, 12152, 'Arifureta Shokugyou de Sekai Saikyou [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664546.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wYlovCZ3qJnXKE6OU71u98nmSHf.jpg'),
(171979, 12152, 'Arifureta Shokugyou de Sekai Saikyou [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664547.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/s9FtKw1aGlnelP2JTnNNctIJzhC.jpg'),
(171980, 12152, 'Arifureta Shokugyou de Sekai Saikyou [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/664548.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oHs0gU1P9NuIxqa17pA3aE41VMJ.jpg'),
(171981, 12152, 'Arifureta Shokugyou de Sekai Saikyou [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/664549.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6ee1pgZ5010VosDgdaEXvhrwvIf.jpg'),
(171982, 12152, 'Arifureta Shokugyou de Sekai Saikyou [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/664550.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yVAJvZOjbpD0qSXC1rFGWLevEAL.jpg'),
(171983, 12152, 'Arifureta Shokugyou de Sekai Saikyou [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/664551.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/giXGNGvlT3Ds9Hjr5VTCyyovfos.jpg'),
(171984, 12152, 'Arifureta Shokugyou de Sekai Saikyou [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/664552.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/byKrAZJvLkbq391zMY8dlqbs8TT.jpg'),
(171985, 12152, 'Arifureta Shokugyou de Sekai Saikyou [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/664553.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/TA0diTYjdp1IN8NyjwE7TgrvYM.jpg'),
(171986, 12152, 'Arifureta Shokugyou de Sekai Saikyou [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/664554.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2cmGMCWolD1b48irc97QgXnEBWW.jpg'),
(171987, 12152, 'Arifureta Shokugyou de Sekai Saikyou [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/664555.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5U6Vjtch2yY1DqLn1VAn4nCEBrZ.jpg'),
(171988, 12152, 'Arifureta Shokugyou de Sekai Saikyou [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/664556.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9BWmveIadKPFdYA9vUUxX8bLEdO.jpg'),
(171989, 12153, 'Arifureta Shokugyou de Sekai Saikyou [L] S03 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664557.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wPgcOctbPZPm5C72gkzhEi9DX33.jpg'),
(171990, 12153, 'Arifureta Shokugyou de Sekai Saikyou [L] S03 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664558.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k0odd8CI6QyvzQ8ZUsq7YgEua4L.jpg'),
(171991, 12153, 'Arifureta Shokugyou de Sekai Saikyou [L] S03 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664559.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2gRUEy63Pn4U59p77G24aXmVebF.jpg'),
(171992, 12153, 'Arifureta Shokugyou de Sekai Saikyou [L] S03 E04', 'http://sinalprivado.info:80/series/1533784/1533784/664560.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pM1JJBlFz4W88RNzYNfwTRPNuRn.jpg'),
(171993, 12153, 'Arifureta Shokugyou de Sekai Saikyou [L] S03 E05', 'http://sinalprivado.info:80/series/1533784/1533784/664561.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zWk2vnsVxOzytuoJ7nFLNRS24kq.jpg'),
(171994, 12153, 'Arifureta Shokugyou de Sekai Saikyou [L] S03 E06', 'http://sinalprivado.info:80/series/1533784/1533784/664562.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zveyCXUFnJKdwfhBDPYhppyiHNZ.jpg'),
(171995, 12153, 'Arifureta Shokugyou de Sekai Saikyou [L] S03 E07', 'http://sinalprivado.info:80/series/1533784/1533784/664563.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zVy5IOos06AoNdrp2getJWuQGxH.jpg'),
(171996, 12153, 'Arifureta Shokugyou de Sekai Saikyou [L] S03 E08', 'http://sinalprivado.info:80/series/1533784/1533784/664564.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ahfjB8XwBSgfGVHrGQriQ06ZkZ2.jpg'),
(171997, 12153, 'Arifureta Shokugyou de Sekai Saikyou [L] S03 E09', 'http://sinalprivado.info:80/series/1533784/1533784/664565.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1scRjE0LLeOIuhpYoaKUhGpX6N1.jpg'),
(171998, 12153, 'Arifureta Shokugyou de Sekai Saikyou [L] S03 E10', 'http://sinalprivado.info:80/series/1533784/1533784/664566.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/u93zqOmYIpXlqhAB1SBFoDYiyzf.jpg'),
(171999, 12153, 'Arifureta Shokugyou de Sekai Saikyou [L] S03 E11', 'http://sinalprivado.info:80/series/1533784/1533784/664567.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1nxMfMhm8hY7ntr3Yq1bJ83cJdA.jpg'),
(172000, 12153, 'Arifureta Shokugyou de Sekai Saikyou [L] S03 E12', 'http://sinalprivado.info:80/series/1533784/1533784/672317.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3vwcB2MtQA1VZMCljCRSrDzNzdj.jpg'),
(172001, 12153, 'Arifureta Shokugyou de Sekai Saikyou [L] S03 E13', 'http://sinalprivado.info:80/series/1533784/1533784/681110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3vwcB2MtQA1VZMCljCRSrDzNzdj.jpg'),
(172002, 12153, 'Arifureta Shokugyou de Sekai Saikyou [L] S03 E14', 'http://sinalprivado.info:80/series/1533784/1533784/686273.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3vwcB2MtQA1VZMCljCRSrDzNzdj.jpg'),
(172003, 12153, 'Arifureta Shokugyou de Sekai Saikyou [L] S03 E15', 'http://sinalprivado.info:80/series/1533784/1533784/694348.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3vwcB2MtQA1VZMCljCRSrDzNzdj.jpg'),
(172004, 12153, 'Arifureta Shokugyou de Sekai Saikyou [L] S03 E16', 'http://sinalprivado.info:80/series/1533784/1533784/703285.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/3vwcB2MtQA1VZMCljCRSrDzNzdj.jpg'),
(172005, 12154, 'As Bruxas Mayfair de Anne Rice [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664522.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6yO7gQhAqsjbs0tzDpyCkPOaSdA.jpg'),
(172006, 12154, 'As Bruxas Mayfair de Anne Rice [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664523.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cKA0JN44ZF1nli1ShaV7dzclq1Y.jpg'),
(172007, 12154, 'As Bruxas Mayfair de Anne Rice [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664524.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cQiDxXIbAY5qVYTy0oozJjsmGRt.jpg'),
(172008, 12154, 'As Bruxas Mayfair de Anne Rice [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/664525.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lhMMRbfv7fmL3Ct1OXexbTpv9M0.jpg'),
(172009, 12154, 'As Bruxas Mayfair de Anne Rice [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/664526.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xPQloPpjKYLMDBBHubFu9NrJpxx.jpg'),
(172010, 12154, 'As Bruxas Mayfair de Anne Rice [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/664527.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/fjI9Mr8rTTYwYCOcp4bYjdXOF2Q.jpg'),
(172011, 12154, 'As Bruxas Mayfair de Anne Rice [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/664528.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lYAcmSyKyXgdldxbN6ygcv2qiIk.jpg'),
(172012, 12154, 'As Bruxas Mayfair de Anne Rice [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/664529.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xQHEOcDbhIU3a1iYpRQXXKXtmiY.jpg'),
(172013, 12155, 'As Bruxas Mayfair de Anne Rice [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664530.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7njDD1INS8z1wyvHCFx8NrIM3mp.jpg'),
(172014, 12155, 'As Bruxas Mayfair de Anne Rice [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664531.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/k558CFDBnR7Chh4M7oLSCRS7jZk.jpg'),
(172015, 12155, 'As Bruxas Mayfair de Anne Rice [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/672241.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8TjwFIz5CfojrnUenDOEYIgJTjJ.jpg'),
(172016, 12155, 'As Bruxas Mayfair de Anne Rice [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/684189.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8TjwFIz5CfojrnUenDOEYIgJTjJ.jpg'),
(172017, 12155, 'As Bruxas Mayfair de Anne Rice [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/686234.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8TjwFIz5CfojrnUenDOEYIgJTjJ.jpg'),
(172018, 12155, 'As Bruxas Mayfair de Anne Rice [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/703150.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8TjwFIz5CfojrnUenDOEYIgJTjJ.jpg'),
(172019, 12155, 'As Bruxas Mayfair de Anne Rice [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/710156.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8TjwFIz5CfojrnUenDOEYIgJTjJ.jpg'),
(172020, 12156, 'Beheneko The Elf Girls Cat is Secretly an S Ranked Monster [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664519.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3QVw15vDPq5nUp8pdGIY1vyH9On.jpg'),
(172021, 12156, 'Beheneko The Elf Girls Cat is Secretly an S Ranked Monster [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664520.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bZXUQsGuMekJBEIaXJjLc8rtqVX.jpg'),
(172022, 12156, 'Beheneko The Elf Girls Cat is Secretly an S Ranked Monster [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664521.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8TEh9631qfyl5NUOS8wDyx87KzU.jpg'),
(172023, 12156, 'Beheneko The Elf Girls Cat is Secretly an S Ranked Monster [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/670017.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j9q6ZUfdKMHS67w82ASbYf0eDIL.jpg'),
(172024, 12156, 'Beheneko The Elf Girls Cat is Secretly an S Ranked Monster [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/680975.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j9q6ZUfdKMHS67w82ASbYf0eDIL.jpg'),
(172025, 12156, 'Beheneko The Elf Girls Cat is Secretly an S Ranked Monster [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/684126.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j9q6ZUfdKMHS67w82ASbYf0eDIL.jpg'),
(172026, 12156, 'Beheneko The Elf Girls Cat is Secretly an S Ranked Monster [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/694308.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j9q6ZUfdKMHS67w82ASbYf0eDIL.jpg'),
(172027, 12156, 'Beheneko The Elf Girls Cat is Secretly an S Ranked Monster [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/703136.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j9q6ZUfdKMHS67w82ASbYf0eDIL.jpg'),
(172028, 12156, 'Beheneko The Elf Girls Cat is Secretly an S Ranked Monster [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/710141.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j9q6ZUfdKMHS67w82ASbYf0eDIL.jpg'),
(172029, 12156, 'Beheneko The Elf Girls Cat is Secretly an S Ranked Monster [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/719120.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j9q6ZUfdKMHS67w82ASbYf0eDIL.jpg'),
(172030, 12156, 'Beheneko The Elf Girls Cat is Secretly an S Ranked Monster [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/730100.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j9q6ZUfdKMHS67w82ASbYf0eDIL.jpg'),
(172031, 12156, 'Beheneko The Elf Girls Cat is Secretly an S Ranked Monster [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/731614.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/j9q6ZUfdKMHS67w82ASbYf0eDIL.jpg'),
(172032, 12157, 'Blue Miburo [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664506.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/ArXOxfvtQOQr782OstBjSAInIok.jpg'),
(172033, 12157, 'Blue Miburo [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664507.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/gWZKlqXaNkgwYv9eai7OKVZLLsF.jpg'),
(172034, 12157, 'Blue Miburo [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664508.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xeIsBhVWzs1mrINkGfM0wp3HJCJ.jpg'),
(172035, 12157, 'Blue Miburo [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/664509.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/x21WEgHpxtRTgsKxIkuNOuCq7po.jpg'),
(172036, 12157, 'Blue Miburo [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/664510.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/upDnQevZ55JSbpnrbCRy6HWOe5v.jpg'),
(172037, 12157, 'Blue Miburo [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/664511.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/a6xKXOkUnAniLTjPjUYEawxEkmi.jpg'),
(172038, 12157, 'Blue Miburo [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/664512.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/t2dWWHWkK4TUF41QGho0LsmlkAk.jpg'),
(172039, 12157, 'Blue Miburo [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/664513.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/5WQGBSezgD2Nl0orGeZkpmAcT57.jpg'),
(172040, 12157, 'Blue Miburo [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/664514.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lDBJD07qRtzapbCiOU9pWBA8Gi4.jpg'),
(172041, 12157, 'Blue Miburo [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/664515.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/uVLvAiaxz848ulauWRMgNOBr5IV.jpg'),
(172042, 12157, 'Blue Miburo [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/664516.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rvk0de9fgxHmwQ9IfdhurRQyMk2.jpg'),
(172043, 12157, 'Blue Miburo [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/664517.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vV32Y5SRBToT0loj19daRINhxJh.jpg'),
(172044, 12157, 'Blue Miburo [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/664518.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xngD83ioVRdmuudkyh7D0KDvqjW.jpg'),
(172045, 12157, 'Blue Miburo [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/665683.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rADnozoUIkrJKBD1CMBPnOBWoqh.jpg'),
(172046, 12157, 'Blue Miburo [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/675874.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rADnozoUIkrJKBD1CMBPnOBWoqh.jpg'),
(172047, 12157, 'Blue Miburo [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/683917.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rADnozoUIkrJKBD1CMBPnOBWoqh.jpg'),
(172048, 12157, 'Blue Miburo [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/686378.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rADnozoUIkrJKBD1CMBPnOBWoqh.jpg'),
(172049, 12157, 'Blue Miburo [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/698576.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rADnozoUIkrJKBD1CMBPnOBWoqh.jpg'),
(172050, 12157, 'Blue Miburo [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/707401.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rADnozoUIkrJKBD1CMBPnOBWoqh.jpg'),
(172051, 12157, 'Blue Miburo [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/712876.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rADnozoUIkrJKBD1CMBPnOBWoqh.jpg'),
(172052, 12157, 'Blue Miburo [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/718927.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rADnozoUIkrJKBD1CMBPnOBWoqh.jpg'),
(172053, 12157, 'Blue Miburo [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/730089.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rADnozoUIkrJKBD1CMBPnOBWoqh.jpg'),
(172054, 12157, 'Blue Miburo [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/735714.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rADnozoUIkrJKBD1CMBPnOBWoqh.jpg'),
(172055, 12157, 'Blue Miburo [L] S01 E24', 'http://sinalprivado.info:80/series/1533784/1533784/743140.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rADnozoUIkrJKBD1CMBPnOBWoqh.jpg'),
(172056, 12158, 'Blue Miburo [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/896630.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rADnozoUIkrJKBD1CMBPnOBWoqh.jpg'),
(172057, 12158, 'Blue Miburo [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/897389.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/rADnozoUIkrJKBD1CMBPnOBWoqh.jpg'),
(172058, 12159, 'Cheer Up [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664478.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/eV4aGRypB8GFdZztK2OVNvVplap.jpg'),
(172059, 12159, 'Cheer Up [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664479.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/lAFlFfOjdJnHvti68hstazkzCHU.jpg'),
(172060, 12159, 'Cheer Up [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664480.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jNC6PZT7HY9opsOybzy15Q04tzx.jpg'),
(172061, 12159, 'Cheer Up [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/664481.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/da1zOgww0riQiiwgMKW88WieEsB.jpg'),
(172062, 12159, 'Cheer Up [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/664482.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/xR6yb1GUWi1y8nojC4pJ4QN9dBm.jpg'),
(172063, 12159, 'Cheer Up [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/664483.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/r9gYV3aYR876Poq0nCXwJR1M2Be.jpg'),
(172064, 12159, 'Cheer Up [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/664484.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wbXzbZjidEIL95G6JsvtYHfbcCw.jpg'),
(172065, 12159, 'Cheer Up [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/664485.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/2KiRR8PcfDFf2wxcuCuuQ4LL6Zt.jpg'),
(172066, 12159, 'Cheer Up [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/664486.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/4mk8Jw7OOByhrwbXQdkizFuvVao.jpg'),
(172067, 12159, 'Cheer Up [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/664487.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/vLWFw5xe51HMAfWySqLPAjkQCtB.jpg'),
(172068, 12159, 'Cheer Up [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/664488.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/tp8L5BCe3NMTywfpmGJ9y0t8LWW.jpg'),
(172069, 12159, 'Cheer Up [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/664489.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/8AoIeHiIpQGvgd9epWsSDSvobCP.jpg'),
(172070, 12159, 'Cheer Up [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/664490.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3hkvhrKaWwgDGLNCbcZ3YVrNAIx.jpg'),
(172071, 12159, 'Cheer Up [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/664491.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/pwoXjIMWmsFEW36BHjCff5ybDSu.jpg'),
(172072, 12159, 'Cheer Up [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/664492.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/rlQ2IALA3XNSSqG5L8CIiaEKfa5.jpg'),
(172073, 12159, 'Cheer Up [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/664493.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/6UoM4dDZXH2JgQzxqZatwy6Q2zu.jpg'),
(172074, 12160, 'Cheer Up [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664494.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uxzBLMoYTTthWM7RNNduIHwnmaM.jpg'),
(172075, 12160, 'Cheer Up [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664495.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uxzBLMoYTTthWM7RNNduIHwnmaM.jpg'),
(172076, 12160, 'Cheer Up [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664496.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uxzBLMoYTTthWM7RNNduIHwnmaM.jpg'),
(172077, 12160, 'Cheer Up [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/664497.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uxzBLMoYTTthWM7RNNduIHwnmaM.jpg'),
(172078, 12160, 'Cheer Up [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/664498.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uxzBLMoYTTthWM7RNNduIHwnmaM.jpg'),
(172079, 12160, 'Cheer Up [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/664499.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uxzBLMoYTTthWM7RNNduIHwnmaM.jpg'),
(172080, 12160, 'Cheer Up [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/664500.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uxzBLMoYTTthWM7RNNduIHwnmaM.jpg'),
(172081, 12160, 'Cheer Up [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/664501.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uxzBLMoYTTthWM7RNNduIHwnmaM.jpg'),
(172082, 12160, 'Cheer Up [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/664502.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uxzBLMoYTTthWM7RNNduIHwnmaM.jpg'),
(172083, 12160, 'Cheer Up [L] S02 E10', 'http://sinalprivado.info:80/series/1533784/1533784/664503.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uxzBLMoYTTthWM7RNNduIHwnmaM.jpg'),
(172084, 12160, 'Cheer Up [L] S02 E11', 'http://sinalprivado.info:80/series/1533784/1533784/664504.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uxzBLMoYTTthWM7RNNduIHwnmaM.jpg'),
(172085, 12160, 'Cheer Up [L] S02 E12', 'http://sinalprivado.info:80/series/1533784/1533784/664505.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/uxzBLMoYTTthWM7RNNduIHwnmaM.jpg'),
(172086, 12161, 'Doc [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664477.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kucCBhMyatYPbMEBmBgKYvh2QIP.jpg'),
(172087, 12161, 'Doc [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/665211.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPVW9gnpIpDpEzDEuS9nqyKLUu.jpg'),
(172088, 12161, 'Doc [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/677885.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPVW9gnpIpDpEzDEuS9nqyKLUu.jpg'),
(172089, 12161, 'Doc [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/683742.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPVW9gnpIpDpEzDEuS9nqyKLUu.jpg'),
(172090, 12161, 'Doc [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/687809.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPVW9gnpIpDpEzDEuS9nqyKLUu.jpg'),
(172091, 12161, 'Doc [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/698284.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPVW9gnpIpDpEzDEuS9nqyKLUu.jpg'),
(172092, 12161, 'Doc [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/706386.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPVW9gnpIpDpEzDEuS9nqyKLUu.jpg'),
(172093, 12161, 'Doc [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/707976.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPVW9gnpIpDpEzDEuS9nqyKLUu.jpg'),
(172094, 12161, 'Doc [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/730639.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPVW9gnpIpDpEzDEuS9nqyKLUu.jpg'),
(172095, 12161, 'Doc [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/730640.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPVW9gnpIpDpEzDEuS9nqyKLUu.jpg'),
(172096, 12162, 'Doc [L] S02 E01', 'http://sinalprivado.info:80/series/1533784/1533784/887288.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPVW9gnpIpDpEzDEuS9nqyKLUu.jpg'),
(172097, 12162, 'Doc [L] S02 E02', 'http://sinalprivado.info:80/series/1533784/1533784/887528.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPVW9gnpIpDpEzDEuS9nqyKLUu.jpg'),
(172098, 12162, 'Doc [L] S02 E03', 'http://sinalprivado.info:80/series/1533784/1533784/888282.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPVW9gnpIpDpEzDEuS9nqyKLUu.jpg'),
(172099, 12162, 'Doc [L] S02 E04', 'http://sinalprivado.info:80/series/1533784/1533784/889593.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPVW9gnpIpDpEzDEuS9nqyKLUu.jpg'),
(172100, 12162, 'Doc [L] S02 E05', 'http://sinalprivado.info:80/series/1533784/1533784/890000.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPVW9gnpIpDpEzDEuS9nqyKLUu.jpg'),
(172101, 12162, 'Doc [L] S02 E06', 'http://sinalprivado.info:80/series/1533784/1533784/892177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPVW9gnpIpDpEzDEuS9nqyKLUu.jpg'),
(172102, 12162, 'Doc [L] S02 E07', 'http://sinalprivado.info:80/series/1533784/1533784/893040.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPVW9gnpIpDpEzDEuS9nqyKLUu.jpg'),
(172103, 12162, 'Doc [L] S02 E08', 'http://sinalprivado.info:80/series/1533784/1533784/893434.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPVW9gnpIpDpEzDEuS9nqyKLUu.jpg'),
(172104, 12162, 'Doc [L] S02 E09', 'http://sinalprivado.info:80/series/1533784/1533784/894177.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/8MPVW9gnpIpDpEzDEuS9nqyKLUu.jpg'),
(172105, 12163, 'Escolhendo o Destino [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664454.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/1XZUZp217QKmVJ85ehlVlDiSBu8.jpg'),
(172106, 12163, 'Escolhendo o Destino [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664455.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9P2s3jxKpo2llj1i0ZB0EyNqpev.jpg'),
(172107, 12163, 'Escolhendo o Destino [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664456.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/g793X86hI2VxFupdfuUhiLYqWkf.jpg'),
(172108, 12163, 'Escolhendo o Destino [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/664457.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7wGwwhylaFQAiGBlczqVlHB17lK.jpg'),
(172109, 12163, 'Escolhendo o Destino [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/664458.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/cNi74NR4QllubNuOVD2Dx1tflpS.jpg'),
(172110, 12163, 'Escolhendo o Destino [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/664459.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9AoaHTNXOKVCi7rPBFZvCvhUQ5U.jpg'),
(172111, 12163, 'Escolhendo o Destino [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/664460.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/bPPkdEABQBqJMweqXdKtbBFTBPA.jpg'),
(172112, 12163, 'Escolhendo o Destino [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/664461.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yaNKvf0n06383qY8MBtp0mNoLE3.jpg'),
(172113, 12163, 'Escolhendo o Destino [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/664462.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3LEr0rFf7SyCoZbBWgv9oVwvlLJ.jpg'),
(172114, 12163, 'Escolhendo o Destino [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/664463.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zdwM0qSQgv0VyUj6zQ3PkfzjFWA.jpg'),
(172115, 12163, 'Escolhendo o Destino [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/664464.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/aBM7cTr5yg8MthMqgBn7lUogOwO.jpg'),
(172116, 12163, 'Escolhendo o Destino [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/664465.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qlbMoME9OH7E1mYNjKuf6YZjP0I.jpg'),
(172117, 12163, 'Escolhendo o Destino [L] S01 E13', 'http://sinalprivado.info:80/series/1533784/1533784/664466.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yyDE2fUsRe0NcarHkkK5RS0W3AV.jpg'),
(172118, 12163, 'Escolhendo o Destino [L] S01 E14', 'http://sinalprivado.info:80/series/1533784/1533784/664467.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/9BHLSHHL0NN5hDEdYGVWKoezGZY.jpg'),
(172119, 12163, 'Escolhendo o Destino [L] S01 E15', 'http://sinalprivado.info:80/series/1533784/1533784/664468.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yrtwPkssLCUkl0UnQV4czqYzy7r.jpg'),
(172120, 12163, 'Escolhendo o Destino [L] S01 E16', 'http://sinalprivado.info:80/series/1533784/1533784/664469.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/wXDcFDHgbLBcy21MS0kgeNuDJJS.jpg'),
(172121, 12163, 'Escolhendo o Destino [L] S01 E17', 'http://sinalprivado.info:80/series/1533784/1533784/664470.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/oDFPBZtDD3t1xiNu59OJ0icXqHF.jpg'),
(172122, 12163, 'Escolhendo o Destino [L] S01 E18', 'http://sinalprivado.info:80/series/1533784/1533784/664471.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/kGAsqjvaQZoT2q9ezJK9zFGSbQV.jpg'),
(172123, 12163, 'Escolhendo o Destino [L] S01 E19', 'http://sinalprivado.info:80/series/1533784/1533784/664472.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qFxdJG0Ei7dskzhzXWsE2qdrGuM.jpg'),
(172124, 12163, 'Escolhendo o Destino [L] S01 E20', 'http://sinalprivado.info:80/series/1533784/1533784/664473.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3JupQmMNc8lGpZTLzHhnFPJDLGa.jpg'),
(172125, 12163, 'Escolhendo o Destino [L] S01 E21', 'http://sinalprivado.info:80/series/1533784/1533784/664474.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/29k9YxW78YNxbjs9vPfxuQWMyJH.jpg'),
(172126, 12163, 'Escolhendo o Destino [L] S01 E22', 'http://sinalprivado.info:80/series/1533784/1533784/664475.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mCsmVjYtQM56GOFNdS4cXp5NmHd.jpg'),
(172127, 12163, 'Escolhendo o Destino [L] S01 E23', 'http://sinalprivado.info:80/series/1533784/1533784/664476.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/zyxOQUaMobh9052y2wqu0ccgmbS.jpg'),
(172128, 12164, 'Even Given the Worthless Appraiser Class Im Actually the Strongest [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664453.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/qNDhtTEoGEUAcQekRnmzhoDbEZU.jpg'),
(172129, 12164, 'Even Given the Worthless Appraiser Class Im Actually the Strongest [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/665032.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iWQchD5iAc3Ou9zTQnPuNbLPsLB.jpg'),
(172130, 12164, 'Even Given the Worthless Appraiser Class Im Actually the Strongest [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/677882.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iWQchD5iAc3Ou9zTQnPuNbLPsLB.jpg'),
(172131, 12164, 'Even Given the Worthless Appraiser Class Im Actually the Strongest [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/679804.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iWQchD5iAc3Ou9zTQnPuNbLPsLB.jpg'),
(172132, 12164, 'Even Given the Worthless Appraiser Class Im Actually the Strongest [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/687665.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iWQchD5iAc3Ou9zTQnPuNbLPsLB.jpg'),
(172133, 12164, 'Even Given the Worthless Appraiser Class Im Actually the Strongest [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/698196.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iWQchD5iAc3Ou9zTQnPuNbLPsLB.jpg'),
(172134, 12164, 'Even Given the Worthless Appraiser Class Im Actually the Strongest [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/706355.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iWQchD5iAc3Ou9zTQnPuNbLPsLB.jpg'),
(172135, 12164, 'Even Given the Worthless Appraiser Class Im Actually the Strongest [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/714987.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iWQchD5iAc3Ou9zTQnPuNbLPsLB.jpg'),
(172136, 12164, 'Even Given the Worthless Appraiser Class Im Actually the Strongest [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/718556.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iWQchD5iAc3Ou9zTQnPuNbLPsLB.jpg'),
(172137, 12164, 'Even Given the Worthless Appraiser Class Im Actually the Strongest [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/724110.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iWQchD5iAc3Ou9zTQnPuNbLPsLB.jpg'),
(172138, 12164, 'Even Given the Worthless Appraiser Class Im Actually the Strongest [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/730511.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iWQchD5iAc3Ou9zTQnPuNbLPsLB.jpg'),
(172139, 12164, 'Even Given the Worthless Appraiser Class Im Actually the Strongest [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/752314.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/iWQchD5iAc3Ou9zTQnPuNbLPsLB.jpg'),
(172140, 12165, 'FARMAGIA [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664452.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9b3WxClXnOud4JwHeWttX0sHOJV.jpg'),
(172141, 12165, 'FARMAGIA [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/665030.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9b3WxClXnOud4JwHeWttX0sHOJV.jpg'),
(172142, 12165, 'FARMAGIA [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/675788.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9b3WxClXnOud4JwHeWttX0sHOJV.jpg'),
(172143, 12165, 'FARMAGIA [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/683704.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9b3WxClXnOud4JwHeWttX0sHOJV.jpg'),
(172144, 12165, 'FARMAGIA [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/686728.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9b3WxClXnOud4JwHeWttX0sHOJV.jpg'),
(172145, 12165, 'FARMAGIA [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/698190.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9b3WxClXnOud4JwHeWttX0sHOJV.jpg'),
(172146, 12165, 'FARMAGIA [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/706345.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9b3WxClXnOud4JwHeWttX0sHOJV.jpg'),
(172147, 12165, 'FARMAGIA [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/712799.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9b3WxClXnOud4JwHeWttX0sHOJV.jpg'),
(172148, 12165, 'FARMAGIA [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/718542.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9b3WxClXnOud4JwHeWttX0sHOJV.jpg'),
(172149, 12165, 'FARMAGIA [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/729649.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9b3WxClXnOud4JwHeWttX0sHOJV.jpg'),
(172150, 12165, 'FARMAGIA [L] S01 E11', 'http://sinalprivado.info:80/series/1533784/1533784/739076.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9b3WxClXnOud4JwHeWttX0sHOJV.jpg'),
(172151, 12165, 'FARMAGIA [L] S01 E12', 'http://sinalprivado.info:80/series/1533784/1533784/752294.mp4', 'https://image.tmdb.org//t/p/w600_and_h900_bestv2/9b3WxClXnOud4JwHeWttX0sHOJV.jpg'),
(172152, 12166, 'Fate Strange Fake [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664451.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/3JK7iIywHhMq4G5UFGYz74IfDhS.jpg'),
(172153, 12167, 'Flor [L] S01 E01', 'http://sinalprivado.info:80/series/1533784/1533784/664417.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yVXPFgR3j3kNvRnQIuieR1sdFx1.jpg'),
(172154, 12167, 'Flor [L] S01 E02', 'http://sinalprivado.info:80/series/1533784/1533784/664418.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/djt9uyW6DE1LrOv6fzhwLZVHSF0.jpg'),
(172155, 12167, 'Flor [L] S01 E03', 'http://sinalprivado.info:80/series/1533784/1533784/664419.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/yggimXoZX9kqS5GJUhmkMST6UlI.jpg'),
(172156, 12167, 'Flor [L] S01 E04', 'http://sinalprivado.info:80/series/1533784/1533784/664420.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/jkkM0mMS7XGz5N3RZt5u6bx8nAA.jpg'),
(172157, 12167, 'Flor [L] S01 E05', 'http://sinalprivado.info:80/series/1533784/1533784/664421.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/mw7v0YZFJ6L4m77pqGRmP1CCsXY.jpg'),
(172158, 12167, 'Flor [L] S01 E06', 'http://sinalprivado.info:80/series/1533784/1533784/664422.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/7EwXRaImjIDgfqMcI2w8EecQ9BQ.jpg'),
(172159, 12167, 'Flor [L] S01 E07', 'http://sinalprivado.info:80/series/1533784/1533784/664423.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/21dFu2ZPd7gTEc8iuAPwVWFVLuA.jpg'),
(172160, 12167, 'Flor [L] S01 E08', 'http://sinalprivado.info:80/series/1533784/1533784/664424.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/sI6AjhwffI4abQPjk8jSIztfC5N.jpg'),
(172161, 12167, 'Flor [L] S01 E09', 'http://sinalprivado.info:80/series/1533784/1533784/664425.mp4', 'http://image.tmdb.org//t/p/w600_and_h900_bestv2/AjK5jakENHk8qUVASdfCxaVXeW2.jpg'),
(172162, 12167, 'Flor [L] S01 E10', 'http://sinalprivado.info:80/series/1533784/1533784/664426.mp4'